--
-- PostgreSQL database dump
--

-- Dumped from database version 11.5
-- Dumped by pg_dump version 12.4

SET statement_timeout = 0;
SET lock_timeout = 0;
SET idle_in_transaction_session_timeout = 0;
SET client_encoding = 'UTF8';
SET standard_conforming_strings = on;
SELECT pg_catalog.set_config('search_path', '', false);
SET check_function_bodies = false;
SET xmloption = content;
SET client_min_messages = warning;
SET row_security = off;

SET default_tablespace = '';

--
-- Name: menu; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.menu (
    id_menu integer NOT NULL,
    name character varying,
    price double precision,
    ingredients text,
    description character varying,
    photo character varying
);


--
-- Name: orders; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.orders (
    id_order integer NOT NULL,
    created_at timestamp without time zone,
    created_date date,
    order_subtotal integer,
    order_description json,
    id_user integer,
    order_type character varying,
    delivery_cost integer,
    order_total double precision
);


--
-- Name: TABLE orders; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON TABLE public.orders IS 'Each row has an order of 1 or more items from the Menu. Orders include the user who ordered, the order type (pick-up or delivery) and costs for the order';


--
-- Name: COLUMN orders.id_order; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN public.orders.id_order IS 'The unique identifier for the order';


--
-- Name: COLUMN orders.created_at; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN public.orders.created_at IS 'Timestamp in UTC the order was created at';


--
-- Name: COLUMN orders.created_date; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN public.orders.created_date IS 'Date in UTC the order was created at';


--
-- Name: COLUMN orders.order_subtotal; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN public.orders.order_subtotal IS 'The cost of the items in the order, but does not take delivery cost into account';


--
-- Name: COLUMN orders.order_description; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN public.orders.order_description IS 'A dictionary of what was in the order, including a count of the menu IDs';


--
-- Name: COLUMN orders.id_user; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN public.orders.id_user IS 'The ID User making the order The user can be found in the users table';


--
-- Name: COLUMN orders.order_type; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN public.orders.order_type IS 'How the customer received the order. Either delivery or pick-up';


--
-- Name: COLUMN orders.delivery_cost; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN public.orders.delivery_cost IS 'The price paid by the customer for a delivery';


--
-- Name: COLUMN orders.order_total; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN public.orders.order_total IS 'The total price paid by the customer for the order, including delivery';


--
-- Name: reviews; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.reviews (
    id_review integer NOT NULL,
    star_rating integer,
    id_order integer,
    id_menu integer,
    id_user integer
);


--
-- Name: TABLE reviews; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON TABLE public.reviews IS 'Each row has a review of a menu item in an order, on a scale of 1 to 5 stars. Not all orders are reviewed, but all items in a reviewed order are reviewed';


--
-- Name: COLUMN reviews.id_review; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN public.reviews.id_review IS 'The unique identifier for the review';


--
-- Name: COLUMN reviews.star_rating; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN public.reviews.star_rating IS 'The star rating for the menu item on a 1-5 star scale';


--
-- Name: COLUMN reviews.id_order; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN public.reviews.id_order IS 'The ID Order the review is associated with. The order can be found in the orders table';


--
-- Name: COLUMN reviews.id_menu; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN public.reviews.id_menu IS 'The ID Menu the review is associated with, which can be found in the menu table';


--
-- Name: COLUMN reviews.id_user; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN public.reviews.id_user IS 'The ID User making the review. The user can be found in the users table';


--
-- Name: users; Type: TABLE; Schema: public; Owner: -
--

CREATE TABLE public.users (
    id_user integer NOT NULL,
    created_at timestamp without time zone,
    created_date date,
    name character varying,
    email character varying,
    city character varying,
    state character varying,
    credit_card_number character varying,
    credit_card_hash character varying,
    credit_card_provider character varying,
    lat double precision,
    lon double precision
);


--
-- Name: TABLE users; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON TABLE public.users IS 'Each row is a user that has signed up for an account to create orders. Not all users have necessarily placed an order';


--
-- Name: COLUMN users.id_user; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN public.users.id_user IS 'The unique identifier for the user';


--
-- Name: COLUMN users.created_at; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN public.users.created_at IS 'Timestamp in UTC the user created their account';


--
-- Name: COLUMN users.created_date; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN public.users.created_date IS 'Date in UTC the user created their account';


--
-- Name: COLUMN users.name; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN public.users.name IS 'Full name of the user';


--
-- Name: COLUMN users.email; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN public.users.email IS 'Email address the user signed up with';


--
-- Name: COLUMN users.city; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN public.users.city IS 'City the user is in';


--
-- Name: COLUMN users.state; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN public.users.state IS 'State the user is in';


--
-- Name: COLUMN users.credit_card_number; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN public.users.credit_card_number IS 'Credit card number on file for user';


--
-- Name: COLUMN users.credit_card_hash; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN public.users.credit_card_hash IS 'MD5 hash of the credit card number';


--
-- Name: COLUMN users.credit_card_provider; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN public.users.credit_card_provider IS 'The type of credit card (AMEX, Visa, etc.)';


--
-- Name: COLUMN users.lat; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN public.users.lat IS 'Latitude coordinate for address of the user';


--
-- Name: COLUMN users.lon; Type: COMMENT; Schema: public; Owner: -
--

COMMENT ON COLUMN public.users.lon IS 'longitude coordinate for address of the user';


--
-- Data for Name: menu; Type: TABLE DATA; Schema: public; Owner: -
--

COPY public.menu (id_menu, name, price, ingredients, description, photo) FROM stdin;
1	Pumpkin Pie 🎃	12	flour, butter, pumpkin, eggs, spices, condensed milk	A fall classic, available year round. A custardy pumpkin filling baked in our famous butter crust.	https://timabe.me/img/pumpkin.JPG
2	Banana Cream Pie 🍌	14	flour, butter, cream, sugar, bananas, half and half	Banana infused pudding, layered with ripe bananas and topped with whipped cream. Filled in a blind baked butter crust	https://timabe.me/img/bcp.png
3	Blueberry Pie 🔵	12	flour, butter, blueberries, sugar, lemon, corn starch	A mixture of fresh, tart blueberries and sweet blueberry compote. Cooked stovetop and filled in a blind baked butter crust	https://timabe.me/img/blueberry.jpg
4	Chicken Pot Pie 🐔	17	flour, butter, chicken, carrot, onion, peas, cream	A savory pie with roasted chicken and garden vegetables, baked in our famous butter crust	https://timabe.me/img/chicken.jpg
5	Dill Pickles 🥒	8	cucumber, dill, salt, vinegar, spices	Classic dill pickles. Heavy on dill in a white vinegar and salt based brine	https://timabe.me/img/pickles.png
6	Spicy Pickles 🌶	9	cucumber, dill, salt, vinegar, spices, chilli peppers	Our dill pickles with a kick. We add habenero and serrano peppers for a healthy amount of spice	https://timabe.me/img/pickles.jpg
7	Garlic Pickles 🧄	9	cucumber, dill, salt, vinegar, spices, garlic	Kosher dill pickles with plenty of garlic	https://timabe.me/img/garlic.JPG
\.


--
-- Data for Name: orders; Type: TABLE DATA; Schema: public; Owner: -
--

COPY public.orders (id_order, created_at, created_date, order_subtotal, order_description, id_user, order_type, delivery_cost, order_total) FROM stdin;
1	2019-01-01 00:02:33	2019-01-01	9	[{"id_menu":7,"count":1}]	1	delivery	5	14
2	2019-01-01 00:17:37	2019-01-01	14	[{"id_menu":2,"count":1}]	17	pick-up	0	14
3	2019-01-01 00:27:07	2019-01-01	9	[{"id_menu":6,"count":1}]	54	delivery	5	14
4	2019-01-01 01:18:35	2019-01-01	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	72	delivery	5	34
5	2019-01-01 01:20:58	2019-01-01	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	15	pick-up	0	26
6	2019-01-01 02:15:35	2019-01-01	17	[{"id_menu":4,"count":1}]	48	pick-up	0	17
7	2019-01-01 02:28:32	2019-01-01	8	[{"id_menu":5,"count":1}]	52	pick-up	0	8
8	2019-01-01 04:43:12	2019-01-01	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	35	pick-up	0	24
9	2019-01-01 04:52:37	2019-01-01	14	[{"id_menu":2,"count":1}]	78	delivery	5	19
10	2019-01-01 05:04:27	2019-01-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	67	pick-up	0	31
11	2019-01-01 05:24:01	2019-01-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	11	pick-up	0	31
12	2019-01-01 05:58:59	2019-01-01	8	[{"id_menu":5,"count":1}]	69	pick-up	0	8
13	2019-01-01 06:36:35	2019-01-01	8	[{"id_menu":5,"count":1}]	14	delivery	5	13
14	2019-01-01 07:08:44	2019-01-01	9	[{"id_menu":6,"count":1}]	71	pick-up	0	9
15	2019-01-01 07:31:08	2019-01-01	12	[{"id_menu":1,"count":1}]	76	pick-up	0	12
16	2019-01-01 07:43:39	2019-01-01	9	[{"id_menu":6,"count":1}]	53	delivery	5	14
17	2019-01-01 08:30:18	2019-01-01	9	[{"id_menu":7,"count":1}]	27	delivery	5	14
18	2019-01-01 08:41:56	2019-01-01	14	[{"id_menu":2,"count":2}]	50	pick-up	0	14
19	2019-01-01 09:23:02	2019-01-01	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	9	delivery	5	34
20	2019-01-01 09:52:00	2019-01-01	9	[{"id_menu":7,"count":1}]	19	pick-up	0	9
21	2019-01-01 09:53:42	2019-01-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	49	pick-up	0	23
22	2019-01-01 10:07:23	2019-01-01	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1	pick-up	0	24
23	2019-01-01 10:10:28	2019-01-01	12	[{"id_menu":3,"count":1}]	26	pick-up	0	12
24	2019-01-01 11:01:03	2019-01-01	17	[{"id_menu":4,"count":1}]	56	delivery	5	22
25	2019-01-01 11:35:05	2019-01-01	17	[{"id_menu":4,"count":1}]	43	delivery	5	22
26	2019-01-01 11:49:12	2019-01-01	14	[{"id_menu":2,"count":1}]	41	delivery	5	19
27	2019-01-01 12:16:56	2019-01-01	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	22	pick-up	0	26
28	2019-01-01 12:57:37	2019-01-01	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	70	pick-up	0	26
29	2019-01-01 14:20:10	2019-01-01	17	[{"id_menu":4,"count":1}]	6	delivery	5	22
30	2019-01-01 16:02:37	2019-01-01	14	[{"id_menu":2,"count":1}]	40	pick-up	0	14
31	2019-01-01 16:43:15	2019-01-01	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	68	delivery	5	31
32	2019-01-01 16:45:00	2019-01-01	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	74	pick-up	0	20
33	2019-01-01 16:51:00	2019-01-01	14	[{"id_menu":2,"count":1}]	39	delivery	5	19
34	2019-01-01 17:35:40	2019-01-01	14	[{"id_menu":2,"count":1}]	2	pick-up	0	14
35	2019-01-01 17:50:48	2019-01-01	14	[{"id_menu":2,"count":1}]	29	pick-up	0	14
36	2019-01-01 17:53:25	2019-01-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	16	delivery	5	36
37	2019-01-01 18:17:41	2019-01-01	14	[{"id_menu":2,"count":1}]	25	pick-up	0	14
38	2019-01-01 18:55:35	2019-01-01	8	[{"id_menu":5,"count":1}]	24	delivery	5	13
39	2019-01-01 19:07:30	2019-01-01	9	[{"id_menu":6,"count":1}]	66	pick-up	0	9
40	2019-01-01 19:40:31	2019-01-01	12	[{"id_menu":3,"count":1}]	23	pick-up	0	12
41	2019-01-01 19:47:06	2019-01-01	14	[{"id_menu":2,"count":1}]	28	delivery	5	19
42	2019-01-01 19:59:18	2019-01-01	17	[{"id_menu":4,"count":1}]	36	delivery	5	22
43	2019-01-01 20:02:56	2019-01-01	14	[{"id_menu":2,"count":1}]	20	pick-up	0	14
44	2019-01-01 20:11:19	2019-01-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	45	delivery	5	23
45	2019-01-01 21:14:23	2019-01-01	9	[{"id_menu":6,"count":1}]	64	delivery	5	14
46	2019-01-01 21:15:35	2019-01-01	9	[{"id_menu":7,"count":1}]	37	pick-up	0	9
47	2019-01-01 22:15:07	2019-01-01	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	4	pick-up	0	24
48	2019-01-01 22:35:24	2019-01-01	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	51	pick-up	0	21
49	2019-01-01 23:00:45	2019-01-01	17	[{"id_menu":4,"count":1}]	55	pick-up	0	17
50	2019-01-01 23:14:44	2019-01-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	77	pick-up	0	23
51	2019-01-01 23:31:01	2019-01-01	8	[{"id_menu":5,"count":2}]	65	pick-up	0	8
52	2019-01-01 23:33:07	2019-01-01	17	[{"id_menu":4,"count":1}]	58	delivery	5	22
53	2019-01-01 23:40:15	2019-01-01	12	[{"id_menu":3,"count":1}]	38	pick-up	0	12
54	2019-01-01 23:43:05	2019-01-01	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	60	pick-up	0	26
55	2019-01-02 00:28:07	2019-01-02	12	[{"id_menu":1,"count":1}]	101	pick-up	0	12
56	2019-01-02 00:30:51	2019-01-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	80	pick-up	0	17
57	2019-01-02 01:31:35	2019-01-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	119	pick-up	0	26
58	2019-01-02 01:40:53	2019-01-02	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	114	pick-up	0	24
59	2019-01-02 01:52:37	2019-01-02	14	[{"id_menu":2,"count":2}]	87	delivery	5	19
60	2019-01-02 01:56:12	2019-01-02	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	116	pick-up	0	52
61	2019-01-02 02:09:37	2019-01-02	8	[{"id_menu":5,"count":2}]	120	pick-up	0	8
62	2019-01-02 02:51:21	2019-01-02	12	[{"id_menu":1,"count":2}]	126	pick-up	0	12
63	2019-01-02 03:08:24	2019-01-02	8	[{"id_menu":5,"count":1}]	93	pick-up	0	8
64	2019-01-02 04:58:28	2019-01-02	14	[{"id_menu":2,"count":1}]	92	delivery	5	19
65	2019-01-02 05:16:48	2019-01-02	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	117	pick-up	0	31
66	2019-01-02 05:34:47	2019-01-02	9	[{"id_menu":6,"count":1}]	96	pick-up	0	9
67	2019-01-02 05:35:09	2019-01-02	9	[{"id_menu":7,"count":1}]	124	delivery	5	14
68	2019-01-02 05:56:42	2019-01-02	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	122	delivery	5	40
69	2019-01-02 06:35:03	2019-01-02	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	99	delivery	5	31
70	2019-01-02 06:49:32	2019-01-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	112	delivery	5	31
71	2019-01-02 06:57:42	2019-01-02	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":3}]	108	pick-up	0	21
72	2019-01-02 07:08:24	2019-01-02	9	[{"id_menu":7,"count":1}]	125	delivery	5	14
73	2019-01-02 07:31:41	2019-01-02	17	[{"id_menu":4,"count":1}]	81	delivery	5	22
74	2019-01-02 07:45:04	2019-01-02	8	[{"id_menu":5,"count":1}]	105	pick-up	0	8
75	2019-01-02 08:11:46	2019-01-02	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	103	pick-up	0	26
76	2019-01-02 08:35:31	2019-01-02	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	85	pick-up	0	24
77	2019-01-02 10:40:02	2019-01-02	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	104	delivery	5	26
78	2019-01-02 10:45:09	2019-01-02	38	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	82	delivery	5	43
79	2019-01-02 11:05:04	2019-01-02	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	94	delivery	5	28
80	2019-01-02 11:16:36	2019-01-02	14	[{"id_menu":2,"count":1}]	111	pick-up	0	14
81	2019-01-02 11:17:07	2019-01-02	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	91	pick-up	0	31
82	2019-01-02 14:27:28	2019-01-02	8	[{"id_menu":5,"count":1}]	86	pick-up	0	8
83	2019-01-02 14:30:46	2019-01-02	12	[{"id_menu":1,"count":1}]	127	pick-up	0	12
84	2019-01-02 14:36:21	2019-01-02	12	[{"id_menu":3,"count":1}]	57	delivery	5	17
85	2019-01-02 15:47:04	2019-01-02	12	[{"id_menu":3,"count":1}]	121	pick-up	0	12
86	2019-01-02 15:53:20	2019-01-02	12	[{"id_menu":1,"count":1}]	83	pick-up	0	12
87	2019-01-02 16:14:10	2019-01-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	102	pick-up	0	17
88	2019-01-02 16:22:04	2019-01-02	9	[{"id_menu":7,"count":1}]	58	pick-up	0	9
89	2019-01-02 16:52:25	2019-01-02	9	[{"id_menu":7,"count":1}]	79	delivery	5	14
90	2019-01-02 17:16:06	2019-01-02	9	[{"id_menu":6,"count":1}]	98	pick-up	0	9
91	2019-01-02 17:17:10	2019-01-02	9	[{"id_menu":6,"count":1}]	123	pick-up	0	9
92	2019-01-02 17:32:30	2019-01-02	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	89	pick-up	0	21
93	2019-01-02 18:41:35	2019-01-02	8	[{"id_menu":5,"count":2}]	113	delivery	5	13
94	2019-01-02 18:56:27	2019-01-02	17	[{"id_menu":4,"count":1}]	90	pick-up	0	17
95	2019-01-02 19:20:16	2019-01-02	14	[{"id_menu":2,"count":1}]	97	pick-up	0	14
96	2019-01-02 19:54:53	2019-01-02	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	84	pick-up	0	42
97	2019-01-02 20:58:50	2019-01-02	12	[{"id_menu":1,"count":2}]	115	pick-up	0	12
98	2019-01-02 21:22:29	2019-01-02	14	[{"id_menu":2,"count":1}]	106	pick-up	0	14
99	2019-01-02 22:05:42	2019-01-02	12	[{"id_menu":1,"count":1}]	88	pick-up	0	12
100	2019-01-02 23:11:07	2019-01-02	14	[{"id_menu":2,"count":1}]	100	pick-up	0	14
101	2019-01-02 23:13:05	2019-01-02	8	[{"id_menu":5,"count":1}]	107	delivery	5	13
102	2019-01-02 23:51:47	2019-01-02	8	[{"id_menu":5,"count":1}]	110	pick-up	0	8
103	2019-01-03 00:21:23	2019-01-03	12	[{"id_menu":1,"count":1}]	138	pick-up	0	12
104	2019-01-03 00:24:47	2019-01-03	9	[{"id_menu":7,"count":1}]	152	delivery	5	14
105	2019-01-03 00:28:20	2019-01-03	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	159	pick-up	0	18
106	2019-01-03 01:09:07	2019-01-03	17	[{"id_menu":4,"count":1}]	131	pick-up	0	17
107	2019-01-03 03:56:14	2019-01-03	12	[{"id_menu":1,"count":1}]	148	delivery	5	17
108	2019-01-03 06:14:48	2019-01-03	12	[{"id_menu":1,"count":1}]	155	pick-up	0	12
109	2019-01-03 06:36:50	2019-01-03	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	137	pick-up	0	17
110	2019-01-03 06:54:49	2019-01-03	9	[{"id_menu":6,"count":1}]	135	pick-up	0	9
111	2019-01-03 08:16:24	2019-01-03	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	151	pick-up	0	18
112	2019-01-03 09:28:37	2019-01-03	17	[{"id_menu":4,"count":1}]	133	pick-up	0	17
113	2019-01-03 09:38:40	2019-01-03	14	[{"id_menu":2,"count":1}]	145	delivery	5	19
114	2019-01-03 10:51:26	2019-01-03	12	[{"id_menu":1,"count":1}]	158	delivery	5	17
115	2019-01-03 11:53:15	2019-01-03	12	[{"id_menu":3,"count":1}]	146	delivery	5	17
116	2019-01-03 12:12:27	2019-01-03	8	[{"id_menu":5,"count":1}]	150	pick-up	0	8
117	2019-01-03 12:24:28	2019-01-03	9	[{"id_menu":7,"count":1}]	156	pick-up	0	9
118	2019-01-03 13:06:15	2019-01-03	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	143	pick-up	0	26
119	2019-01-03 15:35:41	2019-01-03	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	134	delivery	5	25
120	2019-01-03 16:18:02	2019-01-03	8	[{"id_menu":5,"count":1}]	147	pick-up	0	8
121	2019-01-03 18:02:55	2019-01-03	17	[{"id_menu":4,"count":1}]	142	pick-up	0	17
122	2019-01-03 18:13:49	2019-01-03	9	[{"id_menu":6,"count":1}]	153	pick-up	0	9
123	2019-01-03 18:20:13	2019-01-03	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	149	pick-up	0	31
124	2019-01-03 18:52:09	2019-01-03	9	[{"id_menu":7,"count":1}]	136	pick-up	0	9
125	2019-01-03 18:59:20	2019-01-03	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	130	delivery	5	43
126	2019-01-03 19:52:34	2019-01-03	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	41	pick-up	0	26
127	2019-01-03 19:52:45	2019-01-03	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	141	pick-up	0	21
128	2019-01-03 21:17:23	2019-01-03	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	140	delivery	5	23
129	2019-01-03 22:23:32	2019-01-03	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	139	pick-up	0	23
130	2019-01-03 23:46:27	2019-01-03	17	[{"id_menu":4,"count":1}]	157	delivery	5	22
131	2019-01-04 00:21:46	2019-01-04	8	[{"id_menu":5,"count":1}]	189	pick-up	0	8
132	2019-01-04 00:51:45	2019-01-04	9	[{"id_menu":7,"count":1}]	172	delivery	5	14
133	2019-01-04 01:01:14	2019-01-04	8	[{"id_menu":5,"count":1}]	176	delivery	5	13
134	2019-01-04 01:22:26	2019-01-04	17	[{"id_menu":4,"count":1}]	164	pick-up	0	17
135	2019-01-04 03:25:04	2019-01-04	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	178	delivery	5	25
136	2019-01-04 06:07:54	2019-01-04	12	[{"id_menu":3,"count":2}]	170	pick-up	0	12
137	2019-01-04 06:22:53	2019-01-04	9	[{"id_menu":7,"count":1}]	174	delivery	5	14
138	2019-01-04 06:35:53	2019-01-04	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	182	delivery	5	48
139	2019-01-04 10:17:19	2019-01-04	14	[{"id_menu":2,"count":1}]	185	pick-up	0	14
140	2019-01-04 11:21:41	2019-01-04	12	[{"id_menu":3,"count":1}]	37	pick-up	0	12
141	2019-01-04 11:55:19	2019-01-04	12	[{"id_menu":1,"count":1}]	166	delivery	5	17
142	2019-01-04 12:12:11	2019-01-04	17	[{"id_menu":4,"count":1}]	165	delivery	5	22
143	2019-01-04 12:31:55	2019-01-04	17	[{"id_menu":4,"count":2}]	173	delivery	5	22
144	2019-01-04 14:23:31	2019-01-04	12	[{"id_menu":3,"count":1}]	183	pick-up	0	12
145	2019-01-04 14:46:01	2019-01-04	17	[{"id_menu":4,"count":1}]	190	pick-up	0	17
146	2019-01-04 16:00:52	2019-01-04	9	[{"id_menu":7,"count":1}]	177	pick-up	0	9
147	2019-01-04 17:09:35	2019-01-04	9	[{"id_menu":6,"count":1}]	171	pick-up	0	9
148	2019-01-04 17:32:23	2019-01-04	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	169	pick-up	0	29
149	2019-01-04 18:08:27	2019-01-04	17	[{"id_menu":4,"count":1}]	163	delivery	5	22
150	2019-01-04 22:15:15	2019-01-04	14	[{"id_menu":2,"count":1}]	186	pick-up	0	14
151	2019-01-04 22:36:04	2019-01-04	46	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	160	pick-up	0	46
152	2019-01-04 22:43:46	2019-01-04	12	[{"id_menu":3,"count":1}]	188	delivery	5	17
153	2019-01-04 22:54:51	2019-01-04	14	[{"id_menu":2,"count":1}]	184	delivery	5	19
154	2019-01-05 02:03:05	2019-01-05	9	[{"id_menu":7,"count":1}]	211	pick-up	0	9
155	2019-01-05 03:24:11	2019-01-05	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	200	delivery	5	42
156	2019-01-05 04:21:30	2019-01-05	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	215	pick-up	0	38
157	2019-01-05 04:35:19	2019-01-05	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	191	pick-up	0	26
158	2019-01-05 04:38:38	2019-01-05	9	[{"id_menu":7,"count":1}]	214	delivery	5	14
159	2019-01-05 05:06:51	2019-01-05	12	[{"id_menu":1,"count":1}]	195	delivery	5	17
160	2019-01-05 05:59:08	2019-01-05	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	192	pick-up	0	37
161	2019-01-05 07:47:42	2019-01-05	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	206	delivery	5	26
162	2019-01-05 08:09:08	2019-01-05	17	[{"id_menu":4,"count":2}]	199	pick-up	0	17
163	2019-01-05 09:46:12	2019-01-05	9	[{"id_menu":6,"count":1}]	196	pick-up	0	9
164	2019-01-05 10:24:55	2019-01-05	9	[{"id_menu":6,"count":1}]	203	pick-up	0	9
165	2019-01-05 11:53:24	2019-01-05	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	207	pick-up	0	43
166	2019-01-05 12:42:33	2019-01-05	12	[{"id_menu":3,"count":1}]	201	delivery	5	17
167	2019-01-05 14:31:34	2019-01-05	8	[{"id_menu":5,"count":1}]	204	pick-up	0	8
168	2019-01-05 15:12:23	2019-01-05	14	[{"id_menu":2,"count":1}]	208	delivery	5	19
169	2019-01-05 15:48:36	2019-01-05	9	[{"id_menu":6,"count":1}]	158	pick-up	0	9
170	2019-01-05 16:02:13	2019-01-05	9	[{"id_menu":7,"count":1}]	118	pick-up	0	9
171	2019-01-05 16:06:50	2019-01-05	12	[{"id_menu":3,"count":1}]	193	pick-up	0	12
172	2019-01-05 16:19:32	2019-01-05	12	[{"id_menu":1,"count":1}]	216	pick-up	0	12
173	2019-01-05 16:48:28	2019-01-05	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	212	delivery	5	45
174	2019-01-05 17:54:51	2019-01-05	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	209	pick-up	0	26
175	2019-01-05 19:08:42	2019-01-05	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	194	pick-up	0	21
176	2019-01-05 19:37:10	2019-01-05	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	202	pick-up	0	37
177	2019-01-05 19:58:26	2019-01-05	17	[{"id_menu":4,"count":1}]	197	delivery	5	22
178	2019-01-05 22:04:24	2019-01-05	12	[{"id_menu":1,"count":1}]	213	delivery	5	17
179	2019-01-05 23:07:14	2019-01-05	8	[{"id_menu":5,"count":1}]	198	pick-up	0	8
180	2019-01-05 23:14:50	2019-01-05	14	[{"id_menu":2,"count":1}]	205	delivery	5	19
181	2019-01-05 23:49:08	2019-01-05	12	[{"id_menu":1,"count":1}]	210	pick-up	0	12
182	2019-01-06 00:15:07	2019-01-06	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	236	delivery	5	29
183	2019-01-06 01:05:21	2019-01-06	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	153	delivery	5	34
184	2019-01-06 04:52:13	2019-01-06	9	[{"id_menu":7,"count":1}]	27	pick-up	0	9
185	2019-01-06 05:07:21	2019-01-06	12	[{"id_menu":1,"count":1}]	230	delivery	5	17
186	2019-01-06 05:13:49	2019-01-06	12	[{"id_menu":3,"count":1}]	223	delivery	5	17
187	2019-01-06 05:31:34	2019-01-06	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	226	pick-up	0	20
188	2019-01-06 05:36:35	2019-01-06	9	[{"id_menu":7,"count":1}]	220	pick-up	0	9
189	2019-01-06 06:48:14	2019-01-06	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	222	pick-up	0	26
190	2019-01-06 07:32:50	2019-01-06	8	[{"id_menu":5,"count":1}]	167	delivery	5	13
191	2019-01-06 07:42:19	2019-01-06	9	[{"id_menu":6,"count":2}]	109	pick-up	0	9
192	2019-01-06 07:58:17	2019-01-06	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	231	delivery	5	35
193	2019-01-06 09:38:20	2019-01-06	14	[{"id_menu":2,"count":1}]	234	delivery	5	19
194	2019-01-06 09:52:00	2019-01-06	12	[{"id_menu":1,"count":1}]	227	pick-up	0	12
195	2019-01-06 10:17:10	2019-01-06	17	[{"id_menu":4,"count":1}]	229	pick-up	0	17
196	2019-01-06 10:24:48	2019-01-06	9	[{"id_menu":6,"count":1}]	221	pick-up	0	9
197	2019-01-06 10:56:21	2019-01-06	14	[{"id_menu":2,"count":1}]	217	pick-up	0	14
198	2019-01-06 11:45:27	2019-01-06	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	99	pick-up	0	43
199	2019-01-06 12:33:37	2019-01-06	14	[{"id_menu":2,"count":2}]	218	pick-up	0	14
200	2019-01-06 15:20:53	2019-01-06	14	[{"id_menu":2,"count":1}]	228	pick-up	0	14
201	2019-01-06 16:39:30	2019-01-06	17	[{"id_menu":4,"count":1}]	136	pick-up	0	17
202	2019-01-06 16:54:23	2019-01-06	9	[{"id_menu":6,"count":1}]	32	pick-up	0	9
203	2019-01-06 18:07:41	2019-01-06	9	[{"id_menu":6,"count":1}]	224	pick-up	0	9
204	2019-01-06 18:14:07	2019-01-06	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	232	pick-up	0	43
205	2019-01-06 18:17:44	2019-01-06	17	[{"id_menu":4,"count":1}]	233	pick-up	0	17
206	2019-01-06 18:21:04	2019-01-06	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	235	delivery	5	39
207	2019-01-06 18:51:10	2019-01-06	9	[{"id_menu":7,"count":1}]	149	pick-up	0	9
208	2019-01-06 19:42:08	2019-01-06	14	[{"id_menu":2,"count":1}]	189	pick-up	0	14
209	2019-01-06 21:05:57	2019-01-06	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	225	pick-up	0	23
210	2019-01-06 21:36:05	2019-01-06	17	[{"id_menu":4,"count":1}]	219	delivery	5	22
211	2019-01-06 22:43:32	2019-01-06	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	37	pick-up	0	34
212	2019-01-07 01:47:08	2019-01-07	17	[{"id_menu":4,"count":1}]	245	pick-up	0	17
213	2019-01-07 07:31:30	2019-01-07	14	[{"id_menu":2,"count":1}]	247	pick-up	0	14
214	2019-01-07 08:32:21	2019-01-07	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	6	pick-up	0	32
215	2019-01-07 09:01:10	2019-01-07	12	[{"id_menu":3,"count":1}]	248	delivery	5	17
216	2019-01-07 10:40:26	2019-01-07	9	[{"id_menu":6,"count":1}]	238	pick-up	0	9
217	2019-01-07 10:42:03	2019-01-07	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	169	pick-up	0	31
218	2019-01-07 14:27:01	2019-01-07	12	[{"id_menu":1,"count":1}]	237	delivery	5	17
219	2019-01-07 14:41:47	2019-01-07	12	[{"id_menu":3,"count":1}]	242	delivery	5	17
220	2019-01-07 16:12:16	2019-01-07	17	[{"id_menu":4,"count":1}]	241	pick-up	0	17
221	2019-01-07 16:33:12	2019-01-07	17	[{"id_menu":4,"count":1}]	251	delivery	5	22
222	2019-01-07 18:23:18	2019-01-07	12	[{"id_menu":1,"count":1}]	240	pick-up	0	12
223	2019-01-07 21:11:00	2019-01-07	9	[{"id_menu":6,"count":1}]	239	pick-up	0	9
224	2019-01-07 23:37:39	2019-01-07	12	[{"id_menu":1,"count":2}]	252	pick-up	0	12
225	2019-01-08 00:07:20	2019-01-08	9	[{"id_menu":7,"count":1}]	82	pick-up	0	9
226	2019-01-08 03:23:51	2019-01-08	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	263	delivery	5	40
227	2019-01-08 04:34:43	2019-01-08	12	[{"id_menu":3,"count":1}]	260	pick-up	0	12
228	2019-01-08 05:11:25	2019-01-08	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	257	delivery	5	30
229	2019-01-08 07:02:20	2019-01-08	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	256	pick-up	0	21
230	2019-01-08 07:39:15	2019-01-08	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	254	pick-up	0	20
231	2019-01-08 09:11:50	2019-01-08	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	258	delivery	5	26
232	2019-01-08 10:03:24	2019-01-08	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	111	pick-up	0	26
233	2019-01-08 11:24:12	2019-01-08	9	[{"id_menu":6,"count":1}]	255	pick-up	0	9
234	2019-01-08 11:43:10	2019-01-08	14	[{"id_menu":2,"count":1}]	270	delivery	5	19
235	2019-01-08 14:30:55	2019-01-08	17	[{"id_menu":4,"count":1}]	269	pick-up	0	17
236	2019-01-08 15:10:10	2019-01-08	12	[{"id_menu":3,"count":1}]	261	pick-up	0	12
237	2019-01-08 15:47:31	2019-01-08	9	[{"id_menu":6,"count":1}]	265	delivery	5	14
238	2019-01-08 16:32:22	2019-01-08	17	[{"id_menu":4,"count":1}]	259	delivery	5	22
239	2019-01-09 00:04:08	2019-01-09	17	[{"id_menu":4,"count":1}]	140	delivery	5	22
240	2019-01-09 01:20:24	2019-01-09	14	[{"id_menu":2,"count":1}]	209	pick-up	0	14
241	2019-01-09 02:26:29	2019-01-09	8	[{"id_menu":5,"count":1}]	193	pick-up	0	8
242	2019-01-09 03:14:18	2019-01-09	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	122	pick-up	0	26
243	2019-01-09 03:41:33	2019-01-09	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	92	delivery	5	31
244	2019-01-09 05:40:13	2019-01-09	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	282	pick-up	0	26
245	2019-01-09 05:57:49	2019-01-09	12	[{"id_menu":3,"count":1}]	123	pick-up	0	12
246	2019-01-09 07:41:15	2019-01-09	9	[{"id_menu":6,"count":1}]	272	delivery	5	14
247	2019-01-09 09:14:55	2019-01-09	14	[{"id_menu":2,"count":1}]	273	delivery	5	19
248	2019-01-09 10:14:52	2019-01-09	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	48	pick-up	0	33
249	2019-01-09 11:01:51	2019-01-09	17	[{"id_menu":4,"count":1}]	37	delivery	5	22
250	2019-01-09 11:20:33	2019-01-09	8	[{"id_menu":5,"count":1}]	277	delivery	5	13
251	2019-01-09 11:43:59	2019-01-09	14	[{"id_menu":2,"count":1}]	271	delivery	5	19
252	2019-01-09 12:35:53	2019-01-09	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	279	pick-up	0	17
253	2019-01-09 13:59:37	2019-01-09	9	[{"id_menu":6,"count":1}]	274	pick-up	0	9
254	2019-01-09 14:22:48	2019-01-09	12	[{"id_menu":1,"count":2}]	241	delivery	5	17
255	2019-01-09 14:35:29	2019-01-09	8	[{"id_menu":5,"count":1}]	275	pick-up	0	8
256	2019-01-09 17:00:22	2019-01-09	9	[{"id_menu":7,"count":1}]	280	pick-up	0	9
257	2019-01-09 17:02:16	2019-01-09	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	283	pick-up	0	29
258	2019-01-09 17:51:10	2019-01-09	9	[{"id_menu":7,"count":1}]	276	delivery	5	14
259	2019-01-09 18:49:53	2019-01-09	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	278	delivery	5	34
260	2019-01-09 21:57:29	2019-01-09	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	281	pick-up	0	22
261	2019-01-10 00:16:28	2019-01-10	17	[{"id_menu":4,"count":1}]	292	delivery	5	22
262	2019-01-10 02:11:11	2019-01-10	8	[{"id_menu":5,"count":1}]	297	pick-up	0	8
263	2019-01-10 04:15:23	2019-01-10	9	[{"id_menu":7,"count":1}]	286	pick-up	0	9
264	2019-01-10 04:24:12	2019-01-10	9	[{"id_menu":7,"count":1}]	107	pick-up	0	9
265	2019-01-10 08:21:37	2019-01-10	12	[{"id_menu":1,"count":1}]	285	pick-up	0	12
266	2019-01-10 09:19:46	2019-01-10	9	[{"id_menu":6,"count":1}]	288	pick-up	0	9
267	2019-01-10 11:59:13	2019-01-10	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	287	pick-up	0	29
268	2019-01-10 12:03:11	2019-01-10	12	[{"id_menu":3,"count":1}]	291	delivery	5	17
269	2019-01-10 12:47:18	2019-01-10	14	[{"id_menu":2,"count":1}]	296	pick-up	0	14
270	2019-01-10 12:58:26	2019-01-10	9	[{"id_menu":6,"count":1}]	295	delivery	5	14
271	2019-01-10 13:02:12	2019-01-10	14	[{"id_menu":2,"count":1}]	294	pick-up	0	14
272	2019-01-10 14:43:35	2019-01-10	17	[{"id_menu":4,"count":1}]	284	delivery	5	22
273	2019-01-10 14:59:24	2019-01-10	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	66	pick-up	0	29
274	2019-01-10 17:49:10	2019-01-10	12	[{"id_menu":1,"count":1}]	111	delivery	5	17
275	2019-01-10 21:09:23	2019-01-10	9	[{"id_menu":7,"count":1}]	68	pick-up	0	9
276	2019-01-10 22:03:49	2019-01-10	12	[{"id_menu":1,"count":1}]	229	pick-up	0	12
277	2019-01-11 00:56:30	2019-01-11	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	306	delivery	5	36
278	2019-01-11 03:22:06	2019-01-11	12	[{"id_menu":1,"count":1}]	303	delivery	5	17
279	2019-01-11 03:50:08	2019-01-11	12	[{"id_menu":1,"count":1}]	76	delivery	5	17
280	2019-01-11 03:50:53	2019-01-11	12	[{"id_menu":1,"count":1}]	105	pick-up	0	12
281	2019-01-11 03:53:33	2019-01-11	8	[{"id_menu":5,"count":1}]	69	pick-up	0	8
282	2019-01-11 09:03:11	2019-01-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	301	delivery	5	23
283	2019-01-11 09:26:55	2019-01-11	14	[{"id_menu":2,"count":1}]	227	delivery	5	19
284	2019-01-11 09:31:34	2019-01-11	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	299	pick-up	0	26
285	2019-01-11 12:30:11	2019-01-11	12	[{"id_menu":1,"count":1}]	300	delivery	5	17
286	2019-01-11 13:59:34	2019-01-11	9	[{"id_menu":7,"count":1}]	61	delivery	5	14
287	2019-01-11 17:25:59	2019-01-11	12	[{"id_menu":3,"count":1}]	307	pick-up	0	12
288	2019-01-11 20:05:25	2019-01-11	9	[{"id_menu":7,"count":1}]	142	delivery	5	14
289	2019-01-11 20:06:26	2019-01-11	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	304	pick-up	0	20
290	2019-01-11 21:19:51	2019-01-11	9	[{"id_menu":6,"count":1}]	113	pick-up	0	9
291	2019-01-12 02:30:14	2019-01-12	9	[{"id_menu":7,"count":1}]	310	pick-up	0	9
292	2019-01-12 03:01:17	2019-01-12	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	319	pick-up	0	20
293	2019-01-12 05:53:48	2019-01-12	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	232	pick-up	0	21
294	2019-01-12 06:08:05	2019-01-12	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	321	pick-up	0	22
295	2019-01-12 07:32:35	2019-01-12	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	313	delivery	5	36
296	2019-01-12 10:45:19	2019-01-12	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	311	delivery	5	22
297	2019-01-12 10:59:26	2019-01-12	14	[{"id_menu":2,"count":1}]	314	pick-up	0	14
298	2019-01-12 11:05:09	2019-01-12	12	[{"id_menu":3,"count":1}]	322	pick-up	0	12
299	2019-01-12 13:55:56	2019-01-12	14	[{"id_menu":2,"count":1}]	312	pick-up	0	14
300	2019-01-12 14:23:55	2019-01-12	14	[{"id_menu":2,"count":1}]	317	pick-up	0	14
301	2019-01-12 16:26:09	2019-01-12	9	[{"id_menu":6,"count":1}]	315	pick-up	0	9
302	2019-01-12 18:24:02	2019-01-12	9	[{"id_menu":7,"count":1}]	320	pick-up	0	9
303	2019-01-12 19:23:51	2019-01-12	9	[{"id_menu":7,"count":1}]	316	delivery	5	14
304	2019-01-12 22:17:59	2019-01-12	14	[{"id_menu":2,"count":1}]	318	delivery	5	19
305	2019-01-12 23:40:07	2019-01-12	8	[{"id_menu":5,"count":1}]	158	pick-up	0	8
306	2019-01-13 00:29:57	2019-01-13	17	[{"id_menu":4,"count":1}]	324	delivery	5	22
307	2019-01-13 01:56:51	2019-01-13	12	[{"id_menu":1,"count":1}]	323	pick-up	0	12
308	2019-01-13 03:22:56	2019-01-13	8	[{"id_menu":5,"count":1}]	329	delivery	5	13
309	2019-01-13 03:44:54	2019-01-13	12	[{"id_menu":1,"count":1}]	256	delivery	5	17
310	2019-01-13 03:46:59	2019-01-13	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	328	delivery	5	26
311	2019-01-13 07:01:08	2019-01-13	14	[{"id_menu":2,"count":1}]	281	pick-up	0	14
312	2019-01-13 07:09:46	2019-01-13	9	[{"id_menu":7,"count":1}]	154	pick-up	0	9
313	2019-01-13 08:49:10	2019-01-13	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	332	pick-up	0	21
314	2019-01-13 10:43:54	2019-01-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	226	pick-up	0	18
315	2019-01-13 11:23:17	2019-01-13	9	[{"id_menu":6,"count":1}]	327	pick-up	0	9
316	2019-01-13 12:39:20	2019-01-13	33	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	330	delivery	5	38
317	2019-01-13 14:01:36	2019-01-13	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	212	delivery	5	34
318	2019-01-13 18:55:32	2019-01-13	8	[{"id_menu":5,"count":1}]	326	delivery	5	13
319	2019-01-13 19:34:04	2019-01-13	12	[{"id_menu":1,"count":1}]	331	delivery	5	17
320	2019-01-13 20:52:56	2019-01-13	14	[{"id_menu":2,"count":1}]	48	delivery	5	19
321	2019-01-13 21:57:35	2019-01-13	8	[{"id_menu":5,"count":1}]	325	pick-up	0	8
322	2019-01-14 00:39:04	2019-01-14	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	341	pick-up	0	29
323	2019-01-14 09:14:51	2019-01-14	14	[{"id_menu":2,"count":1}]	274	pick-up	0	14
324	2019-01-14 11:19:54	2019-01-14	9	[{"id_menu":6,"count":2}]	65	pick-up	0	9
325	2019-01-14 12:07:40	2019-01-14	8	[{"id_menu":5,"count":1}]	338	pick-up	0	8
326	2019-01-14 13:20:14	2019-01-14	9	[{"id_menu":7,"count":1}]	292	delivery	5	14
327	2019-01-14 18:35:58	2019-01-14	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	336	delivery	5	40
328	2019-01-14 19:49:01	2019-01-14	12	[{"id_menu":1,"count":1}]	227	pick-up	0	12
329	2019-01-14 21:28:00	2019-01-14	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	340	pick-up	0	21
330	2019-01-15 00:57:13	2019-01-15	12	[{"id_menu":1,"count":1}]	61	pick-up	0	12
331	2019-01-15 01:48:59	2019-01-15	12	[{"id_menu":3,"count":1}]	340	pick-up	0	12
332	2019-01-15 03:45:58	2019-01-15	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	281	pick-up	0	21
333	2019-01-15 04:10:34	2019-01-15	14	[{"id_menu":2,"count":1}]	346	delivery	5	19
334	2019-01-15 06:02:24	2019-01-15	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	342	delivery	5	25
335	2019-01-15 07:24:24	2019-01-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	173	delivery	5	28
336	2019-01-15 07:24:32	2019-01-15	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	344	delivery	5	34
337	2019-01-15 08:36:11	2019-01-15	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	44	pick-up	0	37
338	2019-01-15 09:46:28	2019-01-15	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	226	pick-up	0	24
339	2019-01-15 12:36:10	2019-01-15	14	[{"id_menu":2,"count":1}]	123	pick-up	0	14
340	2019-01-15 16:43:48	2019-01-15	12	[{"id_menu":3,"count":1}]	349	pick-up	0	12
341	2019-01-15 17:48:00	2019-01-15	12	[{"id_menu":1,"count":1}]	316	delivery	5	17
342	2019-01-15 19:31:36	2019-01-15	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	347	delivery	5	34
343	2019-01-15 19:34:56	2019-01-15	8	[{"id_menu":5,"count":1}]	4	pick-up	0	8
344	2019-01-15 20:45:06	2019-01-15	12	[{"id_menu":3,"count":1}]	283	delivery	5	17
345	2019-01-15 22:53:56	2019-01-15	9	[{"id_menu":7,"count":1}]	343	pick-up	0	9
346	2019-01-15 23:32:47	2019-01-15	14	[{"id_menu":2,"count":1}]	350	pick-up	0	14
347	2019-01-16 04:13:09	2019-01-16	9	[{"id_menu":6,"count":1}]	356	delivery	5	14
348	2019-01-16 04:36:39	2019-01-16	12	[{"id_menu":3,"count":1}]	187	delivery	5	17
349	2019-01-16 05:06:13	2019-01-16	12	[{"id_menu":1,"count":1}]	357	delivery	5	17
350	2019-01-16 05:43:42	2019-01-16	14	[{"id_menu":2,"count":1}]	354	delivery	5	19
351	2019-01-16 06:22:09	2019-01-16	17	[{"id_menu":4,"count":1}]	355	pick-up	0	17
352	2019-01-16 08:18:57	2019-01-16	9	[{"id_menu":7,"count":1}]	80	pick-up	0	9
353	2019-01-16 10:31:29	2019-01-16	8	[{"id_menu":5,"count":1}]	66	pick-up	0	8
354	2019-01-16 10:51:22	2019-01-16	12	[{"id_menu":3,"count":1}]	41	pick-up	0	12
355	2019-01-16 12:15:10	2019-01-16	12	[{"id_menu":1,"count":1}]	147	pick-up	0	12
356	2019-01-16 17:53:13	2019-01-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	227	pick-up	0	26
357	2019-01-16 18:43:37	2019-01-16	9	[{"id_menu":7,"count":1}]	37	pick-up	0	9
358	2019-01-16 20:40:27	2019-01-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	358	pick-up	0	17
359	2019-01-16 21:11:55	2019-01-16	17	[{"id_menu":4,"count":2}]	353	delivery	5	22
360	2019-01-16 21:26:31	2019-01-16	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	351	pick-up	0	38
361	2019-01-16 21:33:28	2019-01-16	17	[{"id_menu":4,"count":1}]	352	delivery	5	22
362	2019-01-16 22:02:47	2019-01-16	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	83	pick-up	0	22
363	2019-01-16 23:25:50	2019-01-16	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	89	delivery	5	31
364	2019-01-17 01:31:56	2019-01-17	9	[{"id_menu":6,"count":1}]	16	pick-up	0	9
365	2019-01-17 02:15:20	2019-01-17	29	[{"id_menu":3,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	44	delivery	5	34
366	2019-01-17 02:15:50	2019-01-17	14	[{"id_menu":2,"count":1}]	363	delivery	5	19
367	2019-01-17 04:22:42	2019-01-17	9	[{"id_menu":6,"count":1}]	257	pick-up	0	9
368	2019-01-17 07:42:24	2019-01-17	12	[{"id_menu":3,"count":1}]	365	delivery	5	17
369	2019-01-17 10:58:03	2019-01-17	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	361	delivery	5	27
370	2019-01-17 11:18:33	2019-01-17	8	[{"id_menu":5,"count":1}]	359	pick-up	0	8
371	2019-01-17 16:08:54	2019-01-17	9	[{"id_menu":7,"count":1}]	80	pick-up	0	9
372	2019-01-17 17:12:15	2019-01-17	8	[{"id_menu":5,"count":1}]	66	delivery	5	13
373	2019-01-17 19:32:28	2019-01-17	9	[{"id_menu":7,"count":1}]	364	delivery	5	14
374	2019-01-17 22:06:35	2019-01-17	37	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	360	delivery	5	42
375	2019-01-18 00:50:47	2019-01-18	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	366	delivery	5	22
376	2019-01-18 05:33:15	2019-01-18	12	[{"id_menu":3,"count":1}]	368	pick-up	0	12
377	2019-01-18 09:40:22	2019-01-18	9	[{"id_menu":6,"count":1}]	68	pick-up	0	9
378	2019-01-18 09:55:33	2019-01-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	367	delivery	5	28
379	2019-01-18 10:06:48	2019-01-18	9	[{"id_menu":7,"count":2}]	286	pick-up	0	9
380	2019-01-18 14:01:25	2019-01-18	14	[{"id_menu":2,"count":1}]	271	pick-up	0	14
381	2019-01-18 18:17:30	2019-01-18	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	370	pick-up	0	29
382	2019-01-18 21:48:57	2019-01-18	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	71	delivery	5	27
383	2019-01-18 22:31:21	2019-01-18	14	[{"id_menu":2,"count":1}]	372	pick-up	0	14
384	2019-01-19 01:26:28	2019-01-19	9	[{"id_menu":6,"count":1}]	348	pick-up	0	9
385	2019-01-19 02:34:02	2019-01-19	14	[{"id_menu":2,"count":1}]	236	pick-up	0	14
386	2019-01-19 05:55:33	2019-01-19	9	[{"id_menu":7,"count":1}]	287	delivery	5	14
387	2019-01-19 05:57:08	2019-01-19	14	[{"id_menu":2,"count":1}]	81	pick-up	0	14
388	2019-01-19 12:56:04	2019-01-19	9	[{"id_menu":6,"count":1}]	376	pick-up	0	9
389	2019-01-19 14:58:47	2019-01-19	9	[{"id_menu":7,"count":1}]	375	delivery	5	14
390	2019-01-19 15:36:49	2019-01-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	338	pick-up	0	18
391	2019-01-19 15:47:47	2019-01-19	9	[{"id_menu":6,"count":1}]	372	pick-up	0	9
392	2019-01-19 17:35:35	2019-01-19	14	[{"id_menu":2,"count":1}]	265	pick-up	0	14
393	2019-01-19 18:15:05	2019-01-19	14	[{"id_menu":2,"count":1}]	126	pick-up	0	14
394	2019-01-19 20:04:35	2019-01-19	14	[{"id_menu":2,"count":1}]	380	delivery	5	19
395	2019-01-19 20:50:28	2019-01-19	9	[{"id_menu":6,"count":1}]	377	pick-up	0	9
396	2019-01-19 21:23:35	2019-01-19	9	[{"id_menu":7,"count":1}]	378	pick-up	0	9
397	2019-01-19 22:14:48	2019-01-19	17	[{"id_menu":4,"count":1}]	381	pick-up	0	17
398	2019-01-19 23:21:09	2019-01-19	12	[{"id_menu":1,"count":1}]	379	pick-up	0	12
399	2019-01-19 23:40:03	2019-01-19	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	246	pick-up	0	29
400	2019-01-20 00:57:18	2019-01-20	9	[{"id_menu":7,"count":1}]	389	pick-up	0	9
401	2019-01-20 02:11:45	2019-01-20	17	[{"id_menu":4,"count":1}]	184	pick-up	0	17
402	2019-01-20 05:17:49	2019-01-20	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	384	delivery	5	36
403	2019-01-20 05:53:05	2019-01-20	14	[{"id_menu":2,"count":1}]	285	pick-up	0	14
404	2019-01-20 06:33:53	2019-01-20	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	386	pick-up	0	26
405	2019-01-20 06:52:08	2019-01-20	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	135	pick-up	0	26
406	2019-01-20 07:23:50	2019-01-20	9	[{"id_menu":6,"count":1}]	170	pick-up	0	9
407	2019-01-20 07:49:44	2019-01-20	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	385	delivery	5	22
408	2019-01-20 08:26:19	2019-01-20	12	[{"id_menu":3,"count":1}]	388	delivery	5	17
409	2019-01-20 09:20:42	2019-01-20	8	[{"id_menu":5,"count":1}]	340	delivery	5	13
410	2019-01-20 09:51:59	2019-01-20	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	382	delivery	5	37
411	2019-01-20 13:42:25	2019-01-20	12	[{"id_menu":1,"count":1}]	78	pick-up	0	12
412	2019-01-20 14:53:12	2019-01-20	23	[{"id_menu":2,"count":3},{"id_menu":7,"count":1}]	383	delivery	5	28
413	2019-01-20 15:12:11	2019-01-20	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	245	pick-up	0	26
414	2019-01-20 17:09:45	2019-01-20	14	[{"id_menu":2,"count":1}]	372	pick-up	0	14
415	2019-01-20 17:52:34	2019-01-20	8	[{"id_menu":5,"count":1}]	328	delivery	5	13
416	2019-01-20 20:23:56	2019-01-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	377	pick-up	0	23
417	2019-01-20 21:34:58	2019-01-20	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	357	delivery	5	38
418	2019-01-20 21:50:46	2019-01-20	14	[{"id_menu":2,"count":1}]	41	delivery	5	19
419	2019-01-20 22:15:17	2019-01-20	14	[{"id_menu":2,"count":1}]	387	pick-up	0	14
420	2019-01-20 22:44:28	2019-01-20	12	[{"id_menu":3,"count":1}]	173	pick-up	0	12
421	2019-01-21 05:41:38	2019-01-21	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	292	delivery	5	36
422	2019-01-21 06:55:51	2019-01-21	8	[{"id_menu":5,"count":1}]	393	delivery	5	13
423	2019-01-21 07:14:33	2019-01-21	17	[{"id_menu":4,"count":1}]	136	pick-up	0	17
424	2019-01-21 08:02:26	2019-01-21	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	197	pick-up	0	35
425	2019-01-21 09:42:38	2019-01-21	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	111	pick-up	0	21
426	2019-01-21 10:39:37	2019-01-21	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	48	pick-up	0	24
427	2019-01-21 10:51:44	2019-01-21	12	[{"id_menu":1,"count":1}]	396	pick-up	0	12
428	2019-01-22 01:21:27	2019-01-22	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	404	pick-up	0	29
429	2019-01-22 03:12:41	2019-01-22	17	[{"id_menu":4,"count":1}]	400	pick-up	0	17
430	2019-01-22 05:16:03	2019-01-22	8	[{"id_menu":5,"count":1}]	357	delivery	5	13
431	2019-01-22 08:34:29	2019-01-22	9	[{"id_menu":7,"count":1}]	229	pick-up	0	9
432	2019-01-22 13:05:33	2019-01-22	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	215	pick-up	0	47
433	2019-01-22 14:32:11	2019-01-22	8	[{"id_menu":5,"count":1}]	401	pick-up	0	8
434	2019-01-22 15:37:16	2019-01-22	8	[{"id_menu":5,"count":1}]	402	delivery	5	13
435	2019-01-22 16:58:50	2019-01-22	12	[{"id_menu":3,"count":2}]	399	delivery	5	17
436	2019-01-22 21:10:43	2019-01-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	398	delivery	5	36
437	2019-01-22 23:30:29	2019-01-22	9	[{"id_menu":6,"count":1}]	338	delivery	5	14
438	2019-01-23 01:58:20	2019-01-23	9	[{"id_menu":7,"count":1}]	408	delivery	5	14
439	2019-01-23 02:48:30	2019-01-23	17	[{"id_menu":4,"count":1}]	405	pick-up	0	17
440	2019-01-23 07:23:05	2019-01-23	9	[{"id_menu":7,"count":1}]	376	delivery	5	14
441	2019-01-23 13:13:55	2019-01-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	74	delivery	5	36
442	2019-01-23 14:53:03	2019-01-23	12	[{"id_menu":3,"count":1}]	299	pick-up	0	12
443	2019-01-23 14:58:42	2019-01-23	9	[{"id_menu":6,"count":1}]	67	delivery	5	14
444	2019-01-23 15:44:59	2019-01-23	12	[{"id_menu":1,"count":1}]	407	pick-up	0	12
445	2019-01-23 17:13:50	2019-01-23	12	[{"id_menu":1,"count":2}]	257	pick-up	0	12
446	2019-01-23 17:46:00	2019-01-23	14	[{"id_menu":2,"count":1}]	47	pick-up	0	14
447	2019-01-23 19:28:47	2019-01-23	14	[{"id_menu":2,"count":2}]	6	pick-up	0	14
448	2019-01-23 19:40:15	2019-01-23	17	[{"id_menu":4,"count":1}]	43	pick-up	0	17
449	2019-01-23 19:50:30	2019-01-23	17	[{"id_menu":4,"count":1}]	409	delivery	5	22
450	2019-01-23 21:03:48	2019-01-23	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	62	pick-up	0	35
451	2019-01-23 22:14:45	2019-01-23	14	[{"id_menu":2,"count":1}]	209	delivery	5	19
452	2019-01-24 03:19:15	2019-01-24	14	[{"id_menu":2,"count":1}]	153	pick-up	0	14
453	2019-01-24 07:19:44	2019-01-24	14	[{"id_menu":2,"count":1}]	414	pick-up	0	14
454	2019-01-24 07:27:47	2019-01-24	14	[{"id_menu":2,"count":1}]	286	delivery	5	19
455	2019-01-24 08:06:38	2019-01-24	17	[{"id_menu":4,"count":1}]	413	pick-up	0	17
456	2019-01-24 09:56:00	2019-01-24	8	[{"id_menu":5,"count":1}]	287	pick-up	0	8
457	2019-01-24 11:19:38	2019-01-24	8	[{"id_menu":5,"count":1}]	416	delivery	5	13
458	2019-01-24 16:08:28	2019-01-24	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	30	pick-up	0	26
459	2019-01-24 19:09:13	2019-01-24	14	[{"id_menu":2,"count":1}]	177	delivery	5	19
460	2019-01-24 20:00:44	2019-01-24	9	[{"id_menu":6,"count":1}]	111	delivery	5	14
461	2019-01-24 20:20:29	2019-01-24	9	[{"id_menu":7,"count":2}]	397	delivery	5	14
462	2019-01-24 20:49:34	2019-01-24	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	412	pick-up	0	43
463	2019-01-24 22:28:23	2019-01-24	8	[{"id_menu":5,"count":1}]	415	delivery	5	13
464	2019-01-24 22:44:59	2019-01-24	12	[{"id_menu":1,"count":1}]	73	pick-up	0	12
465	2019-01-24 23:42:12	2019-01-24	9	[{"id_menu":6,"count":1}]	382	pick-up	0	9
466	2019-01-24 23:46:18	2019-01-24	8	[{"id_menu":5,"count":1}]	411	delivery	5	13
467	2019-01-25 04:48:32	2019-01-25	17	[{"id_menu":4,"count":1}]	422	delivery	5	22
468	2019-01-25 07:22:53	2019-01-25	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	330	pick-up	0	21
469	2019-01-25 10:33:49	2019-01-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	310	delivery	5	28
470	2019-01-25 10:58:31	2019-01-25	14	[{"id_menu":2,"count":1}]	420	delivery	5	19
471	2019-01-25 14:09:01	2019-01-25	9	[{"id_menu":7,"count":1}]	417	pick-up	0	9
472	2019-01-25 19:33:06	2019-01-25	8	[{"id_menu":5,"count":1}]	269	pick-up	0	8
473	2019-01-25 20:47:19	2019-01-25	9	[{"id_menu":6,"count":1}]	421	pick-up	0	9
474	2019-01-26 02:40:26	2019-01-26	14	[{"id_menu":2,"count":1}]	48	delivery	5	19
475	2019-01-26 03:19:34	2019-01-26	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	92	pick-up	0	34
476	2019-01-26 03:56:09	2019-01-26	9	[{"id_menu":7,"count":1}]	429	delivery	5	14
477	2019-01-26 03:58:58	2019-01-26	8	[{"id_menu":5,"count":1}]	425	delivery	5	13
478	2019-01-26 07:52:21	2019-01-26	9	[{"id_menu":6,"count":1}]	337	pick-up	0	9
479	2019-01-26 08:11:04	2019-01-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	330	delivery	5	22
480	2019-01-26 08:42:59	2019-01-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	428	delivery	5	26
481	2019-01-26 08:49:46	2019-01-26	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	430	delivery	5	34
482	2019-01-26 18:00:53	2019-01-26	14	[{"id_menu":2,"count":1}]	424	pick-up	0	14
483	2019-01-26 20:07:50	2019-01-26	17	[{"id_menu":4,"count":1}]	117	pick-up	0	17
484	2019-01-26 20:47:55	2019-01-26	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	170	delivery	5	45
485	2019-01-26 22:11:03	2019-01-26	8	[{"id_menu":5,"count":1}]	427	delivery	5	13
486	2019-01-26 22:26:55	2019-01-26	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	27	pick-up	0	52
487	2019-01-26 23:37:27	2019-01-26	14	[{"id_menu":2,"count":1}]	140	pick-up	0	14
488	2019-01-26 23:48:50	2019-01-26	12	[{"id_menu":1,"count":1}]	426	pick-up	0	12
489	2019-01-27 02:50:47	2019-01-27	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	437	delivery	5	39
490	2019-01-27 03:50:37	2019-01-27	14	[{"id_menu":2,"count":1}]	431	pick-up	0	14
491	2019-01-27 06:04:02	2019-01-27	12	[{"id_menu":1,"count":1}]	167	pick-up	0	12
492	2019-01-27 06:43:38	2019-01-27	12	[{"id_menu":1,"count":1}]	434	pick-up	0	12
493	2019-01-27 06:45:12	2019-01-27	12	[{"id_menu":3,"count":1}]	109	pick-up	0	12
494	2019-01-27 07:49:50	2019-01-27	8	[{"id_menu":5,"count":1}]	71	pick-up	0	8
495	2019-01-27 08:23:49	2019-01-27	17	[{"id_menu":4,"count":1}]	376	pick-up	0	17
496	2019-01-27 08:51:02	2019-01-27	12	[{"id_menu":3,"count":1}]	433	pick-up	0	12
497	2019-01-27 09:32:31	2019-01-27	17	[{"id_menu":4,"count":1}]	123	delivery	5	22
498	2019-01-27 10:45:29	2019-01-27	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	352	pick-up	0	26
499	2019-01-27 10:47:43	2019-01-27	14	[{"id_menu":2,"count":1}]	435	delivery	5	19
500	2019-01-27 12:54:21	2019-01-27	17	[{"id_menu":4,"count":2}]	37	pick-up	0	17
501	2019-01-27 13:06:19	2019-01-27	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	401	delivery	5	25
502	2019-01-27 14:11:58	2019-01-27	9	[{"id_menu":6,"count":1}]	289	pick-up	0	9
503	2019-01-27 14:42:44	2019-01-27	14	[{"id_menu":2,"count":1}]	432	delivery	5	19
504	2019-01-27 15:11:47	2019-01-27	14	[{"id_menu":2,"count":1}]	356	delivery	5	19
505	2019-01-27 19:13:27	2019-01-27	12	[{"id_menu":3,"count":1}]	436	delivery	5	17
506	2019-01-27 19:51:28	2019-01-27	9	[{"id_menu":7,"count":2}]	381	pick-up	0	9
507	2019-01-27 22:52:45	2019-01-27	8	[{"id_menu":5,"count":1}]	330	pick-up	0	8
508	2019-01-28 04:56:05	2019-01-28	17	[{"id_menu":4,"count":1}]	438	pick-up	0	17
509	2019-01-28 05:00:56	2019-01-28	12	[{"id_menu":3,"count":1}]	195	delivery	5	17
510	2019-01-28 05:28:10	2019-01-28	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	431	delivery	5	26
511	2019-01-28 09:00:39	2019-01-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	78	pick-up	0	26
512	2019-01-28 11:22:38	2019-01-28	17	[{"id_menu":4,"count":2}]	442	delivery	5	22
513	2019-01-28 13:25:44	2019-01-28	12	[{"id_menu":3,"count":1}]	441	delivery	5	17
514	2019-01-28 16:16:17	2019-01-28	14	[{"id_menu":2,"count":1}]	440	delivery	5	19
515	2019-01-28 22:47:47	2019-01-28	14	[{"id_menu":2,"count":1}]	37	delivery	5	19
516	2019-01-29 01:50:23	2019-01-29	8	[{"id_menu":5,"count":1}]	80	pick-up	0	8
517	2019-01-29 02:50:36	2019-01-29	12	[{"id_menu":3,"count":1}]	106	pick-up	0	12
518	2019-01-29 04:00:40	2019-01-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	444	pick-up	0	31
519	2019-01-29 06:41:30	2019-01-29	8	[{"id_menu":5,"count":1}]	446	pick-up	0	8
520	2019-01-29 08:41:30	2019-01-29	12	[{"id_menu":3,"count":1}]	447	pick-up	0	12
521	2019-01-29 11:39:25	2019-01-29	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	44	pick-up	0	26
522	2019-01-29 11:49:22	2019-01-29	9	[{"id_menu":6,"count":1}]	443	delivery	5	14
523	2019-01-29 11:52:54	2019-01-29	8	[{"id_menu":5,"count":1}]	445	delivery	5	13
524	2019-01-29 12:58:26	2019-01-29	12	[{"id_menu":1,"count":1}]	226	pick-up	0	12
525	2019-01-29 14:43:34	2019-01-29	9	[{"id_menu":6,"count":1}]	135	delivery	5	14
526	2019-01-29 19:23:05	2019-01-29	9	[{"id_menu":6,"count":1}]	332	pick-up	0	9
527	2019-01-29 20:32:15	2019-01-29	8	[{"id_menu":5,"count":1}]	172	pick-up	0	8
528	2019-01-29 23:02:52	2019-01-29	9	[{"id_menu":7,"count":1}]	137	delivery	5	14
529	2019-01-29 23:41:52	2019-01-29	9	[{"id_menu":6,"count":1}]	173	pick-up	0	9
530	2019-01-30 01:20:28	2019-01-30	12	[{"id_menu":1,"count":1}]	61	pick-up	0	12
531	2019-01-30 06:19:09	2019-01-30	9	[{"id_menu":6,"count":1}]	379	pick-up	0	9
532	2019-01-30 10:30:50	2019-01-30	12	[{"id_menu":1,"count":1}]	452	delivery	5	17
533	2019-01-30 17:02:04	2019-01-30	14	[{"id_menu":2,"count":1}]	448	delivery	5	19
534	2019-01-30 22:51:03	2019-01-30	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	451	pick-up	0	33
535	2019-01-30 23:11:19	2019-01-30	9	[{"id_menu":6,"count":1}]	197	delivery	5	14
536	2019-01-30 23:52:56	2019-01-30	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	226	pick-up	0	35
537	2019-01-31 03:05:50	2019-01-31	12	[{"id_menu":3,"count":1}]	118	pick-up	0	12
538	2019-01-31 03:06:09	2019-01-31	14	[{"id_menu":2,"count":1}]	209	pick-up	0	14
539	2019-01-31 04:18:13	2019-01-31	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":2}]	455	delivery	5	28
540	2019-01-31 05:21:38	2019-01-31	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	456	delivery	5	23
541	2019-01-31 12:51:41	2019-01-31	17	[{"id_menu":4,"count":1}]	213	delivery	5	22
542	2019-01-31 13:22:10	2019-01-31	17	[{"id_menu":4,"count":1}]	453	delivery	5	22
543	2019-01-31 13:24:58	2019-01-31	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	454	delivery	5	36
544	2019-01-31 17:06:31	2019-01-31	8	[{"id_menu":5,"count":1}]	314	delivery	5	13
545	2019-01-31 17:07:43	2019-01-31	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	270	delivery	5	39
546	2019-01-31 17:39:17	2019-01-31	9	[{"id_menu":6,"count":1}]	169	delivery	5	14
547	2019-01-31 17:43:06	2019-01-31	9	[{"id_menu":7,"count":1}]	304	pick-up	0	9
548	2019-01-31 19:48:52	2019-01-31	9	[{"id_menu":7,"count":1}]	274	pick-up	0	9
549	2019-01-31 19:52:22	2019-01-31	12	[{"id_menu":3,"count":1}]	393	delivery	5	17
550	2019-01-31 21:40:25	2019-01-31	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	428	pick-up	0	35
551	2019-02-01 02:03:42	2019-02-01	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	219	delivery	5	30
552	2019-02-01 05:20:01	2019-02-01	9	[{"id_menu":6,"count":1}]	437	delivery	5	14
553	2019-02-01 07:23:46	2019-02-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	382	pick-up	0	18
554	2019-02-01 08:03:24	2019-02-01	8	[{"id_menu":5,"count":1}]	314	delivery	5	13
555	2019-02-01 10:06:22	2019-02-01	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	457	pick-up	0	26
556	2019-02-01 11:21:34	2019-02-01	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	80	pick-up	0	21
557	2019-02-01 11:46:46	2019-02-01	9	[{"id_menu":7,"count":1}]	460	delivery	5	14
558	2019-02-01 15:49:06	2019-02-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	191	pick-up	0	18
559	2019-02-01 19:26:12	2019-02-01	17	[{"id_menu":4,"count":1}]	44	delivery	5	22
560	2019-02-02 00:50:28	2019-02-02	9	[{"id_menu":7,"count":1}]	42	pick-up	0	9
561	2019-02-02 02:21:33	2019-02-02	12	[{"id_menu":1,"count":1}]	321	delivery	5	17
562	2019-02-02 03:19:57	2019-02-02	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	464	delivery	5	43
563	2019-02-02 04:10:05	2019-02-02	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	461	delivery	5	45
564	2019-02-02 05:05:33	2019-02-02	12	[{"id_menu":3,"count":1}]	462	delivery	5	17
565	2019-02-02 06:50:16	2019-02-02	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	428	delivery	5	26
566	2019-02-02 12:21:01	2019-02-02	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	463	pick-up	0	49
567	2019-02-02 12:50:12	2019-02-02	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	153	delivery	5	34
568	2019-02-02 13:50:00	2019-02-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	387	delivery	5	31
569	2019-02-02 14:08:03	2019-02-02	12	[{"id_menu":3,"count":1}]	334	delivery	5	17
570	2019-02-02 17:31:33	2019-02-02	9	[{"id_menu":6,"count":1}]	78	pick-up	0	9
571	2019-02-02 17:43:34	2019-02-02	17	[{"id_menu":4,"count":1}]	37	pick-up	0	17
572	2019-02-03 02:34:35	2019-02-03	12	[{"id_menu":3,"count":1}]	17	delivery	5	17
573	2019-02-03 03:22:35	2019-02-03	17	[{"id_menu":4,"count":1}]	223	pick-up	0	17
574	2019-02-03 06:58:07	2019-02-03	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	456	pick-up	0	24
575	2019-02-03 11:06:40	2019-02-03	17	[{"id_menu":4,"count":1}]	171	pick-up	0	17
576	2019-02-03 12:05:14	2019-02-03	14	[{"id_menu":2,"count":1}]	177	delivery	5	19
577	2019-02-03 12:13:55	2019-02-03	9	[{"id_menu":7,"count":2}]	469	delivery	5	14
578	2019-02-03 12:18:26	2019-02-03	9	[{"id_menu":7,"count":1}]	155	delivery	5	14
579	2019-02-03 12:38:50	2019-02-03	9	[{"id_menu":6,"count":1}]	466	delivery	5	14
580	2019-02-03 13:25:41	2019-02-03	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	465	delivery	5	34
581	2019-02-03 13:38:58	2019-02-03	14	[{"id_menu":2,"count":1}]	169	pick-up	0	14
582	2019-02-03 14:53:04	2019-02-03	9	[{"id_menu":7,"count":1}]	467	pick-up	0	9
583	2019-02-03 17:23:37	2019-02-03	12	[{"id_menu":3,"count":1}]	468	pick-up	0	12
584	2019-02-03 17:40:08	2019-02-03	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	136	delivery	5	26
585	2019-02-03 18:17:33	2019-02-03	17	[{"id_menu":4,"count":1}]	263	delivery	5	22
586	2019-02-03 18:47:54	2019-02-03	14	[{"id_menu":2,"count":1}]	431	pick-up	0	14
587	2019-02-03 18:50:07	2019-02-03	12	[{"id_menu":1,"count":1}]	382	pick-up	0	12
588	2019-02-03 20:16:04	2019-02-03	8	[{"id_menu":5,"count":1}]	378	pick-up	0	8
589	2019-02-04 06:15:07	2019-02-04	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	472	pick-up	0	29
590	2019-02-04 09:02:10	2019-02-04	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	285	delivery	5	30
591	2019-02-04 09:19:47	2019-02-04	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	338	pick-up	0	35
592	2019-02-04 10:18:35	2019-02-04	12	[{"id_menu":1,"count":1}]	47	pick-up	0	12
593	2019-02-04 12:23:05	2019-02-04	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	470	delivery	5	30
594	2019-02-04 12:33:28	2019-02-04	12	[{"id_menu":1,"count":1}]	209	delivery	5	17
595	2019-02-04 13:27:35	2019-02-04	14	[{"id_menu":2,"count":1}]	473	delivery	5	19
596	2019-02-05 01:39:03	2019-02-05	12	[{"id_menu":3,"count":1}]	315	delivery	5	17
597	2019-02-05 03:23:19	2019-02-05	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	476	pick-up	0	26
598	2019-02-05 06:24:11	2019-02-05	17	[{"id_menu":4,"count":1}]	356	pick-up	0	17
599	2019-02-05 09:15:29	2019-02-05	9	[{"id_menu":7,"count":1}]	223	pick-up	0	9
600	2019-02-05 11:17:44	2019-02-05	9	[{"id_menu":6,"count":1}]	140	delivery	5	14
601	2019-02-05 12:01:30	2019-02-05	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	477	pick-up	0	31
602	2019-02-05 12:09:48	2019-02-05	9	[{"id_menu":7,"count":1}]	227	pick-up	0	9
603	2019-02-05 17:24:40	2019-02-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	265	pick-up	0	18
604	2019-02-05 17:32:27	2019-02-05	9	[{"id_menu":6,"count":1}]	81	delivery	5	14
605	2019-02-05 18:29:44	2019-02-05	9	[{"id_menu":7,"count":2}]	25	pick-up	0	9
606	2019-02-05 18:30:11	2019-02-05	8	[{"id_menu":5,"count":1}]	423	pick-up	0	8
607	2019-02-05 18:49:51	2019-02-05	12	[{"id_menu":1,"count":1}]	382	pick-up	0	12
608	2019-02-05 23:51:13	2019-02-05	8	[{"id_menu":5,"count":1}]	408	pick-up	0	8
609	2019-02-06 00:23:04	2019-02-06	14	[{"id_menu":2,"count":1}]	209	pick-up	0	14
610	2019-02-06 01:09:53	2019-02-06	12	[{"id_menu":1,"count":2}]	145	pick-up	0	12
611	2019-02-06 03:59:14	2019-02-06	17	[{"id_menu":4,"count":2}]	271	pick-up	0	17
612	2019-02-06 06:52:05	2019-02-06	9	[{"id_menu":7,"count":1}]	480	delivery	5	14
613	2019-02-06 11:16:54	2019-02-06	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	382	pick-up	0	31
614	2019-02-06 12:25:05	2019-02-06	14	[{"id_menu":2,"count":1}]	337	pick-up	0	14
615	2019-02-06 12:33:19	2019-02-06	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	481	delivery	5	26
616	2019-02-06 18:08:04	2019-02-06	8	[{"id_menu":5,"count":1}]	478	delivery	5	13
617	2019-02-06 22:50:55	2019-02-06	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	299	pick-up	0	40
618	2019-02-06 23:34:54	2019-02-06	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	66	delivery	5	31
619	2019-02-06 23:42:57	2019-02-06	9	[{"id_menu":7,"count":1}]	479	delivery	5	14
620	2019-02-07 00:04:58	2019-02-07	12	[{"id_menu":1,"count":1}]	274	delivery	5	17
621	2019-02-07 00:09:15	2019-02-07	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	484	pick-up	0	43
622	2019-02-07 03:30:02	2019-02-07	9	[{"id_menu":6,"count":1}]	482	delivery	5	14
623	2019-02-07 03:53:20	2019-02-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	197	delivery	5	28
624	2019-02-07 06:02:17	2019-02-07	9	[{"id_menu":6,"count":1}]	207	pick-up	0	9
625	2019-02-07 08:41:47	2019-02-07	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	483	delivery	5	25
626	2019-02-07 11:24:08	2019-02-07	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	399	pick-up	0	29
627	2019-02-07 13:26:08	2019-02-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	86	pick-up	0	21
628	2019-02-07 16:19:03	2019-02-07	9	[{"id_menu":6,"count":1}]	92	pick-up	0	9
629	2019-02-07 18:42:42	2019-02-07	9	[{"id_menu":6,"count":1}]	396	delivery	5	14
630	2019-02-07 21:36:10	2019-02-07	14	[{"id_menu":2,"count":1}]	485	pick-up	0	14
631	2019-02-07 21:57:37	2019-02-07	8	[{"id_menu":5,"count":1}]	21	delivery	5	13
632	2019-02-08 00:59:16	2019-02-08	12	[{"id_menu":3,"count":1}]	489	delivery	5	17
633	2019-02-08 02:55:19	2019-02-08	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	56	pick-up	0	32
634	2019-02-08 04:36:31	2019-02-08	14	[{"id_menu":2,"count":1}]	488	delivery	5	19
635	2019-02-08 06:28:38	2019-02-08	9	[{"id_menu":7,"count":2}]	490	delivery	5	14
636	2019-02-08 10:15:33	2019-02-08	8	[{"id_menu":5,"count":1}]	232	delivery	5	13
637	2019-02-08 13:42:26	2019-02-08	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	125	pick-up	0	29
638	2019-02-08 17:01:49	2019-02-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	487	delivery	5	28
639	2019-02-08 18:25:21	2019-02-08	9	[{"id_menu":6,"count":1}]	304	pick-up	0	9
640	2019-02-09 03:10:50	2019-02-09	8	[{"id_menu":5,"count":1}]	491	pick-up	0	8
641	2019-02-09 06:23:07	2019-02-09	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	107	delivery	5	40
642	2019-02-09 07:25:26	2019-02-09	14	[{"id_menu":2,"count":1}]	494	pick-up	0	14
643	2019-02-09 10:34:32	2019-02-09	9	[{"id_menu":6,"count":1}]	492	delivery	5	14
644	2019-02-09 13:05:43	2019-02-09	17	[{"id_menu":4,"count":1}]	165	delivery	5	22
645	2019-02-09 13:42:28	2019-02-09	17	[{"id_menu":4,"count":1}]	154	pick-up	0	17
646	2019-02-09 14:20:22	2019-02-09	17	[{"id_menu":4,"count":1}]	226	delivery	5	22
647	2019-02-09 17:01:10	2019-02-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	390	delivery	5	28
648	2019-02-09 17:39:56	2019-02-09	12	[{"id_menu":3,"count":1}]	109	pick-up	0	12
649	2019-02-09 17:51:01	2019-02-09	9	[{"id_menu":7,"count":1}]	215	delivery	5	14
650	2019-02-09 18:21:15	2019-02-09	12	[{"id_menu":3,"count":1}]	495	delivery	5	17
651	2019-02-09 18:30:11	2019-02-09	9	[{"id_menu":7,"count":1}]	493	pick-up	0	9
652	2019-02-09 19:14:52	2019-02-09	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	292	delivery	5	36
653	2019-02-09 20:12:31	2019-02-09	9	[{"id_menu":7,"count":1}]	265	pick-up	0	9
654	2019-02-09 21:10:30	2019-02-09	14	[{"id_menu":2,"count":2}]	64	pick-up	0	14
655	2019-02-09 23:54:52	2019-02-09	14	[{"id_menu":2,"count":1}]	126	pick-up	0	14
656	2019-02-10 00:20:49	2019-02-10	17	[{"id_menu":4,"count":1}]	382	pick-up	0	17
657	2019-02-10 00:27:30	2019-02-10	9	[{"id_menu":7,"count":1}]	376	delivery	5	14
658	2019-02-10 02:49:14	2019-02-10	8	[{"id_menu":5,"count":1}]	310	delivery	5	13
659	2019-02-10 02:53:52	2019-02-10	12	[{"id_menu":1,"count":1}]	496	delivery	5	17
660	2019-02-10 04:06:57	2019-02-10	17	[{"id_menu":4,"count":1}]	74	pick-up	0	17
661	2019-02-10 05:52:15	2019-02-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	391	delivery	5	23
662	2019-02-10 09:39:47	2019-02-10	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	96	pick-up	0	21
663	2019-02-10 10:11:19	2019-02-10	12	[{"id_menu":1,"count":1}]	473	pick-up	0	12
664	2019-02-10 12:00:59	2019-02-10	9	[{"id_menu":6,"count":1}]	257	delivery	5	14
665	2019-02-10 12:23:16	2019-02-10	9	[{"id_menu":6,"count":1}]	166	delivery	5	14
666	2019-02-10 13:43:03	2019-02-10	12	[{"id_menu":3,"count":1}]	234	pick-up	0	12
667	2019-02-10 14:51:45	2019-02-10	9	[{"id_menu":6,"count":1}]	500	pick-up	0	9
668	2019-02-10 15:04:19	2019-02-10	12	[{"id_menu":3,"count":1}]	275	pick-up	0	12
669	2019-02-10 17:07:46	2019-02-10	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	214	delivery	5	40
670	2019-02-10 17:42:30	2019-02-10	12	[{"id_menu":1,"count":1}]	112	pick-up	0	12
671	2019-02-10 19:08:50	2019-02-10	9	[{"id_menu":7,"count":1}]	498	delivery	5	14
672	2019-02-10 20:25:07	2019-02-10	9	[{"id_menu":6,"count":1}]	499	delivery	5	14
673	2019-02-10 22:54:25	2019-02-10	8	[{"id_menu":5,"count":1}]	497	pick-up	0	8
674	2019-02-11 05:04:43	2019-02-11	9	[{"id_menu":7,"count":1}]	403	pick-up	0	9
675	2019-02-11 05:45:19	2019-02-11	14	[{"id_menu":2,"count":1}]	81	delivery	5	19
676	2019-02-11 05:51:30	2019-02-11	9	[{"id_menu":7,"count":2}]	235	pick-up	0	9
677	2019-02-11 12:23:41	2019-02-11	12	[{"id_menu":3,"count":1}]	177	pick-up	0	12
678	2019-02-11 12:34:55	2019-02-11	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	502	delivery	5	40
679	2019-02-11 14:05:04	2019-02-11	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	437	delivery	5	40
680	2019-02-11 20:43:21	2019-02-11	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	323	delivery	5	26
681	2019-02-11 22:06:03	2019-02-11	17	[{"id_menu":4,"count":1}]	505	pick-up	0	17
682	2019-02-11 22:16:14	2019-02-11	12	[{"id_menu":3,"count":1}]	503	delivery	5	17
683	2019-02-11 23:43:23	2019-02-11	17	[{"id_menu":4,"count":1}]	486	delivery	5	22
684	2019-02-12 01:03:20	2019-02-12	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	507	delivery	5	22
685	2019-02-12 03:00:55	2019-02-12	14	[{"id_menu":2,"count":1}]	401	pick-up	0	14
686	2019-02-12 04:12:54	2019-02-12	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	171	delivery	5	26
687	2019-02-12 04:23:22	2019-02-12	12	[{"id_menu":1,"count":1}]	510	delivery	5	17
688	2019-02-12 17:01:49	2019-02-12	9	[{"id_menu":7,"count":1}]	491	pick-up	0	9
689	2019-02-12 17:15:25	2019-02-12	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	508	delivery	5	35
690	2019-02-12 19:42:47	2019-02-12	17	[{"id_menu":4,"count":1}]	8	delivery	5	22
691	2019-02-12 21:25:12	2019-02-12	9	[{"id_menu":6,"count":2}]	506	delivery	5	14
692	2019-02-12 22:35:44	2019-02-12	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	158	delivery	5	26
693	2019-02-12 23:10:26	2019-02-12	14	[{"id_menu":2,"count":1}]	203	pick-up	0	14
694	2019-02-13 00:17:36	2019-02-13	14	[{"id_menu":2,"count":1}]	213	pick-up	0	14
695	2019-02-13 02:01:04	2019-02-13	12	[{"id_menu":3,"count":1}]	511	pick-up	0	12
696	2019-02-13 06:22:54	2019-02-13	29	[{"id_menu":3,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	513	delivery	5	34
697	2019-02-13 07:33:11	2019-02-13	8	[{"id_menu":5,"count":1}]	86	pick-up	0	8
698	2019-02-13 07:54:27	2019-02-13	9	[{"id_menu":6,"count":1}]	136	pick-up	0	9
699	2019-02-13 12:30:24	2019-02-13	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	64	pick-up	0	35
700	2019-02-13 12:48:32	2019-02-13	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	514	delivery	5	26
701	2019-02-13 12:50:23	2019-02-13	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	227	pick-up	0	29
702	2019-02-13 13:20:21	2019-02-13	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	316	delivery	5	31
703	2019-02-13 14:21:03	2019-02-13	12	[{"id_menu":1,"count":2}]	66	pick-up	0	12
704	2019-02-13 14:53:59	2019-02-13	17	[{"id_menu":4,"count":1}]	512	pick-up	0	17
705	2019-02-13 15:05:48	2019-02-13	12	[{"id_menu":3,"count":1}]	138	pick-up	0	12
706	2019-02-13 18:23:17	2019-02-13	17	[{"id_menu":4,"count":1}]	515	delivery	5	22
707	2019-02-13 20:15:12	2019-02-13	9	[{"id_menu":7,"count":1}]	482	delivery	5	14
708	2019-02-13 23:24:42	2019-02-13	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	378	pick-up	0	23
709	2019-02-14 00:21:15	2019-02-14	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	464	pick-up	0	17
710	2019-02-14 00:28:47	2019-02-14	12	[{"id_menu":3,"count":1}]	520	pick-up	0	12
711	2019-02-14 04:57:24	2019-02-14	17	[{"id_menu":4,"count":1}]	519	pick-up	0	17
712	2019-02-14 05:43:19	2019-02-14	12	[{"id_menu":1,"count":1}]	517	delivery	5	17
713	2019-02-14 06:22:24	2019-02-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	229	pick-up	0	26
714	2019-02-14 08:43:18	2019-02-14	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	213	delivery	5	31
715	2019-02-14 10:45:48	2019-02-14	8	[{"id_menu":5,"count":1}]	516	delivery	5	13
716	2019-02-14 11:15:36	2019-02-14	14	[{"id_menu":2,"count":1}]	78	delivery	5	19
717	2019-02-14 17:13:41	2019-02-14	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	518	delivery	5	34
718	2019-02-14 17:58:17	2019-02-14	8	[{"id_menu":5,"count":1}]	389	pick-up	0	8
719	2019-02-14 18:24:29	2019-02-14	14	[{"id_menu":2,"count":1}]	428	delivery	5	19
720	2019-02-15 02:09:28	2019-02-15	14	[{"id_menu":2,"count":1}]	381	delivery	5	19
721	2019-02-15 02:18:47	2019-02-15	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	379	delivery	5	51
722	2019-02-15 03:42:18	2019-02-15	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	440	delivery	5	43
723	2019-02-15 07:02:22	2019-02-15	14	[{"id_menu":2,"count":1}]	396	pick-up	0	14
724	2019-02-15 08:57:14	2019-02-15	8	[{"id_menu":5,"count":1}]	432	pick-up	0	8
725	2019-02-15 11:13:31	2019-02-15	8	[{"id_menu":5,"count":1}]	40	delivery	5	13
726	2019-02-15 13:28:05	2019-02-15	12	[{"id_menu":1,"count":1}]	281	delivery	5	17
727	2019-02-15 14:13:54	2019-02-15	34	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	521	delivery	5	39
728	2019-02-15 15:47:07	2019-02-15	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	489	pick-up	0	17
729	2019-02-15 17:10:50	2019-02-15	9	[{"id_menu":7,"count":2}]	523	delivery	5	14
730	2019-02-15 17:38:57	2019-02-15	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	522	pick-up	0	43
731	2019-02-15 20:24:29	2019-02-15	9	[{"id_menu":7,"count":1}]	525	delivery	5	14
732	2019-02-16 01:42:13	2019-02-16	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	152	pick-up	0	40
733	2019-02-16 02:12:29	2019-02-16	12	[{"id_menu":1,"count":1}]	48	pick-up	0	12
734	2019-02-16 04:48:56	2019-02-16	12	[{"id_menu":3,"count":1}]	463	pick-up	0	12
735	2019-02-16 05:14:04	2019-02-16	12	[{"id_menu":1,"count":1}]	187	pick-up	0	12
736	2019-02-16 06:08:59	2019-02-16	8	[{"id_menu":5,"count":1}]	519	delivery	5	13
737	2019-02-16 06:55:53	2019-02-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	529	pick-up	0	18
738	2019-02-16 08:07:16	2019-02-16	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	462	delivery	5	26
739	2019-02-16 09:17:00	2019-02-16	9	[{"id_menu":6,"count":1}]	528	delivery	5	14
740	2019-02-16 11:33:53	2019-02-16	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	213	pick-up	0	31
741	2019-02-16 13:45:44	2019-02-16	9	[{"id_menu":6,"count":1}]	228	delivery	5	14
742	2019-02-16 13:56:28	2019-02-16	8	[{"id_menu":5,"count":1}]	27	pick-up	0	8
743	2019-02-16 18:10:45	2019-02-16	12	[{"id_menu":1,"count":1}]	530	pick-up	0	12
744	2019-02-16 21:50:16	2019-02-16	14	[{"id_menu":2,"count":1}]	526	delivery	5	19
745	2019-02-16 23:03:19	2019-02-16	9	[{"id_menu":7,"count":1}]	527	pick-up	0	9
746	2019-02-16 23:28:00	2019-02-16	12	[{"id_menu":1,"count":1}]	113	delivery	5	17
747	2019-02-17 00:00:00	2019-02-17	9	[{"id_menu":6,"count":1}]	35	pick-up	0	9
748	2019-02-17 00:58:16	2019-02-17	17	[{"id_menu":4,"count":1}]	377	delivery	5	22
749	2019-02-17 01:56:24	2019-02-17	9	[{"id_menu":7,"count":1}]	535	delivery	5	14
750	2019-02-17 04:06:18	2019-02-17	12	[{"id_menu":3,"count":1}]	134	pick-up	0	12
751	2019-02-17 04:18:19	2019-02-17	12	[{"id_menu":3,"count":1}]	424	delivery	5	17
752	2019-02-17 04:31:23	2019-02-17	14	[{"id_menu":2,"count":1}]	131	delivery	5	19
753	2019-02-17 04:36:41	2019-02-17	12	[{"id_menu":3,"count":1}]	533	delivery	5	17
754	2019-02-17 05:20:22	2019-02-17	9	[{"id_menu":6,"count":1}]	220	pick-up	0	9
755	2019-02-17 05:26:13	2019-02-17	8	[{"id_menu":5,"count":1}]	17	pick-up	0	8
756	2019-02-17 08:58:00	2019-02-17	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	482	delivery	5	22
757	2019-02-17 09:07:48	2019-02-17	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	528	delivery	5	28
758	2019-02-17 10:25:14	2019-02-17	14	[{"id_menu":2,"count":1}]	352	pick-up	0	14
759	2019-02-17 11:03:22	2019-02-17	9	[{"id_menu":6,"count":2}]	531	pick-up	0	9
760	2019-02-17 11:20:56	2019-02-17	12	[{"id_menu":3,"count":1}]	534	pick-up	0	12
761	2019-02-17 11:31:50	2019-02-17	12	[{"id_menu":1,"count":1}]	71	pick-up	0	12
762	2019-02-17 14:01:23	2019-02-17	9	[{"id_menu":6,"count":1}]	135	pick-up	0	9
763	2019-02-17 16:48:17	2019-02-17	14	[{"id_menu":2,"count":1}]	226	pick-up	0	14
764	2019-02-17 18:18:48	2019-02-17	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	228	pick-up	0	43
765	2019-02-17 20:06:09	2019-02-17	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	484	pick-up	0	26
766	2019-02-17 20:33:37	2019-02-17	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	257	pick-up	0	20
767	2019-02-17 22:27:24	2019-02-17	14	[{"id_menu":2,"count":1}]	532	pick-up	0	14
768	2019-02-18 03:41:52	2019-02-18	12	[{"id_menu":3,"count":1}]	539	pick-up	0	12
769	2019-02-18 11:58:49	2019-02-18	9	[{"id_menu":7,"count":1}]	123	pick-up	0	9
770	2019-02-18 19:55:28	2019-02-18	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	538	delivery	5	43
771	2019-02-19 00:05:26	2019-02-19	12	[{"id_menu":1,"count":1}]	111	delivery	5	17
772	2019-02-19 07:40:19	2019-02-19	12	[{"id_menu":3,"count":1}]	274	pick-up	0	12
773	2019-02-19 09:34:20	2019-02-19	14	[{"id_menu":2,"count":1}]	542	delivery	5	19
774	2019-02-19 10:53:48	2019-02-19	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	466	delivery	5	39
775	2019-02-19 18:11:56	2019-02-19	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	541	delivery	5	34
776	2019-02-19 19:06:23	2019-02-19	17	[{"id_menu":4,"count":2}]	177	delivery	5	22
777	2019-02-19 19:20:51	2019-02-19	14	[{"id_menu":2,"count":1}]	114	pick-up	0	14
778	2019-02-19 19:21:41	2019-02-19	12	[{"id_menu":3,"count":2}]	382	pick-up	0	12
779	2019-02-19 22:03:24	2019-02-19	12	[{"id_menu":3,"count":1}]	376	delivery	5	17
780	2019-02-19 22:17:21	2019-02-19	12	[{"id_menu":1,"count":2}]	543	pick-up	0	12
781	2019-02-19 23:06:12	2019-02-19	8	[{"id_menu":5,"count":1}]	135	pick-up	0	8
782	2019-02-20 01:16:41	2019-02-20	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	126	pick-up	0	21
783	2019-02-20 01:39:20	2019-02-20	17	[{"id_menu":4,"count":1}]	389	delivery	5	22
784	2019-02-20 02:06:18	2019-02-20	17	[{"id_menu":4,"count":1}]	115	pick-up	0	17
785	2019-02-20 02:57:50	2019-02-20	9	[{"id_menu":6,"count":1}]	550	delivery	5	14
786	2019-02-20 06:29:36	2019-02-20	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	96	delivery	5	28
787	2019-02-20 06:53:10	2019-02-20	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	113	pick-up	0	26
788	2019-02-20 08:38:12	2019-02-20	14	[{"id_menu":2,"count":1}]	348	pick-up	0	14
789	2019-02-20 10:31:52	2019-02-20	17	[{"id_menu":4,"count":1}]	88	pick-up	0	17
790	2019-02-20 10:41:22	2019-02-20	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	548	pick-up	0	20
791	2019-02-20 10:47:22	2019-02-20	9	[{"id_menu":6,"count":1}]	211	delivery	5	14
792	2019-02-20 12:56:58	2019-02-20	12	[{"id_menu":3,"count":1}]	364	delivery	5	17
793	2019-02-20 17:00:04	2019-02-20	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	546	delivery	5	31
794	2019-02-20 19:30:28	2019-02-20	9	[{"id_menu":6,"count":1}]	547	delivery	5	14
795	2019-02-20 20:50:57	2019-02-20	14	[{"id_menu":2,"count":1}]	20	delivery	5	19
796	2019-02-21 00:43:35	2019-02-21	17	[{"id_menu":4,"count":1}]	511	pick-up	0	17
797	2019-02-21 02:23:45	2019-02-21	9	[{"id_menu":7,"count":1}]	150	pick-up	0	9
798	2019-02-21 04:20:59	2019-02-21	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	271	pick-up	0	43
799	2019-02-21 06:22:35	2019-02-21	14	[{"id_menu":2,"count":1}]	281	pick-up	0	14
800	2019-02-21 09:26:25	2019-02-21	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	551	pick-up	0	25
801	2019-02-21 11:23:34	2019-02-21	14	[{"id_menu":2,"count":1}]	555	delivery	5	19
802	2019-02-21 13:38:20	2019-02-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	552	delivery	5	22
803	2019-02-21 14:00:13	2019-02-21	9	[{"id_menu":7,"count":1}]	553	delivery	5	14
804	2019-02-21 16:12:39	2019-02-21	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	554	delivery	5	27
805	2019-02-21 17:00:13	2019-02-21	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	311	pick-up	0	26
806	2019-02-21 19:31:33	2019-02-21	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	443	delivery	5	43
807	2019-02-22 00:48:41	2019-02-22	12	[{"id_menu":1,"count":1}]	351	delivery	5	17
808	2019-02-22 01:00:31	2019-02-22	9	[{"id_menu":7,"count":1}]	254	pick-up	0	9
809	2019-02-22 02:47:53	2019-02-22	14	[{"id_menu":2,"count":1}]	123	delivery	5	19
810	2019-02-22 05:08:25	2019-02-22	12	[{"id_menu":3,"count":1}]	467	pick-up	0	12
811	2019-02-22 06:17:35	2019-02-22	9	[{"id_menu":6,"count":2}]	184	delivery	5	14
812	2019-02-22 07:31:47	2019-02-22	12	[{"id_menu":1,"count":2}]	337	delivery	5	17
813	2019-02-22 11:02:54	2019-02-22	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	556	pick-up	0	29
814	2019-02-22 11:12:56	2019-02-22	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	560	delivery	5	34
815	2019-02-22 11:56:19	2019-02-22	12	[{"id_menu":3,"count":2}]	304	pick-up	0	12
816	2019-02-22 13:10:26	2019-02-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	150	pick-up	0	23
817	2019-02-22 13:48:10	2019-02-22	14	[{"id_menu":2,"count":1}]	558	pick-up	0	14
818	2019-02-22 14:39:06	2019-02-22	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	54	pick-up	0	26
819	2019-02-22 16:02:38	2019-02-22	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	270	pick-up	0	21
820	2019-02-22 17:24:29	2019-02-22	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	561	pick-up	0	20
821	2019-02-22 19:17:01	2019-02-22	9	[{"id_menu":6,"count":1}]	559	delivery	5	14
822	2019-02-22 20:58:56	2019-02-22	14	[{"id_menu":2,"count":1}]	557	pick-up	0	14
823	2019-02-23 01:15:53	2019-02-23	9	[{"id_menu":7,"count":1}]	29	delivery	5	14
824	2019-02-23 02:08:56	2019-02-23	8	[{"id_menu":5,"count":1}]	37	pick-up	0	8
825	2019-02-23 02:53:38	2019-02-23	12	[{"id_menu":3,"count":1}]	236	pick-up	0	12
826	2019-02-23 03:46:04	2019-02-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	544	delivery	5	23
827	2019-02-23 04:33:45	2019-02-23	12	[{"id_menu":1,"count":1}]	566	pick-up	0	12
828	2019-02-23 04:45:29	2019-02-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	408	pick-up	0	31
829	2019-02-23 05:49:53	2019-02-23	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	562	delivery	5	42
830	2019-02-23 05:52:12	2019-02-23	12	[{"id_menu":1,"count":1}]	81	pick-up	0	12
831	2019-02-23 07:17:30	2019-02-23	14	[{"id_menu":2,"count":2}]	43	pick-up	0	14
832	2019-02-23 07:26:02	2019-02-23	17	[{"id_menu":4,"count":1}]	306	delivery	5	22
833	2019-02-23 07:54:46	2019-02-23	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	528	delivery	5	40
834	2019-02-23 09:13:15	2019-02-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	44	pick-up	0	31
835	2019-02-23 11:20:42	2019-02-23	17	[{"id_menu":4,"count":1}]	452	pick-up	0	17
836	2019-02-23 13:39:48	2019-02-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	567	delivery	5	22
837	2019-02-23 15:50:03	2019-02-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	226	pick-up	0	17
838	2019-02-23 15:56:30	2019-02-23	12	[{"id_menu":1,"count":1}]	564	delivery	5	17
839	2019-02-23 16:19:59	2019-02-23	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	213	delivery	5	25
840	2019-02-23 16:28:51	2019-02-23	8	[{"id_menu":5,"count":1}]	565	pick-up	0	8
841	2019-02-23 17:02:21	2019-02-23	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	383	delivery	5	40
842	2019-02-23 17:16:22	2019-02-23	9	[{"id_menu":7,"count":1}]	173	delivery	5	14
843	2019-02-23 17:34:55	2019-02-23	9	[{"id_menu":6,"count":1}]	563	pick-up	0	9
844	2019-02-23 18:46:58	2019-02-23	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	68	delivery	5	25
845	2019-02-24 01:31:01	2019-02-24	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	335	pick-up	0	22
846	2019-02-24 01:55:32	2019-02-24	12	[{"id_menu":3,"count":1}]	171	pick-up	0	12
847	2019-02-24 02:33:12	2019-02-24	12	[{"id_menu":1,"count":1}]	389	pick-up	0	12
848	2019-02-24 02:37:23	2019-02-24	9	[{"id_menu":6,"count":1}]	548	delivery	5	14
849	2019-02-24 03:37:26	2019-02-24	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	247	delivery	5	53
850	2019-02-24 04:52:42	2019-02-24	12	[{"id_menu":1,"count":1}]	96	pick-up	0	12
851	2019-02-24 04:56:41	2019-02-24	14	[{"id_menu":2,"count":1}]	501	delivery	5	19
852	2019-02-24 06:02:10	2019-02-24	12	[{"id_menu":3,"count":1}]	571	delivery	5	17
853	2019-02-24 06:49:52	2019-02-24	14	[{"id_menu":2,"count":1}]	569	pick-up	0	14
854	2019-02-24 07:47:47	2019-02-24	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	397	delivery	5	22
855	2019-02-24 08:53:30	2019-02-24	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	531	pick-up	0	31
856	2019-02-24 11:15:03	2019-02-24	8	[{"id_menu":5,"count":2}]	568	delivery	5	13
857	2019-02-24 11:19:49	2019-02-24	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	570	pick-up	0	37
858	2019-02-24 11:37:15	2019-02-24	12	[{"id_menu":1,"count":1}]	381	pick-up	0	12
859	2019-02-24 12:17:52	2019-02-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	376	pick-up	0	26
860	2019-02-24 12:29:31	2019-02-24	9	[{"id_menu":7,"count":1}]	450	delivery	5	14
861	2019-02-24 12:51:01	2019-02-24	14	[{"id_menu":2,"count":1}]	33	delivery	5	19
862	2019-02-24 13:03:15	2019-02-24	12	[{"id_menu":1,"count":1}]	536	delivery	5	17
863	2019-02-24 14:26:00	2019-02-24	12	[{"id_menu":3,"count":1}]	270	pick-up	0	12
864	2019-02-24 16:54:51	2019-02-24	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	217	pick-up	0	34
865	2019-02-24 17:08:55	2019-02-24	17	[{"id_menu":4,"count":1}]	245	pick-up	0	17
866	2019-02-24 19:35:37	2019-02-24	17	[{"id_menu":4,"count":1}]	573	pick-up	0	17
867	2019-02-24 22:16:31	2019-02-24	17	[{"id_menu":4,"count":1}]	228	pick-up	0	17
868	2019-02-24 22:47:26	2019-02-24	14	[{"id_menu":2,"count":1}]	439	delivery	5	19
869	2019-02-24 23:53:17	2019-02-24	8	[{"id_menu":5,"count":2}]	572	pick-up	0	8
870	2019-02-25 00:10:09	2019-02-25	17	[{"id_menu":4,"count":1}]	578	delivery	5	22
871	2019-02-25 07:16:25	2019-02-25	9	[{"id_menu":7,"count":1}]	12	pick-up	0	9
872	2019-02-25 07:34:49	2019-02-25	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	173	pick-up	0	21
873	2019-02-25 07:57:28	2019-02-25	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	227	pick-up	0	17
874	2019-02-25 08:05:55	2019-02-25	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	577	delivery	5	22
875	2019-02-25 11:26:23	2019-02-25	9	[{"id_menu":6,"count":1}]	257	pick-up	0	9
876	2019-02-25 14:16:48	2019-02-25	8	[{"id_menu":5,"count":1}]	88	pick-up	0	8
877	2019-02-25 14:22:41	2019-02-25	12	[{"id_menu":1,"count":1}]	498	pick-up	0	12
878	2019-02-25 16:45:10	2019-02-25	9	[{"id_menu":6,"count":1}]	466	delivery	5	14
879	2019-02-25 16:56:09	2019-02-25	9	[{"id_menu":7,"count":1}]	222	delivery	5	14
880	2019-02-25 23:58:36	2019-02-25	17	[{"id_menu":4,"count":1}]	563	delivery	5	22
881	2019-02-26 01:27:38	2019-02-26	14	[{"id_menu":2,"count":1}]	389	pick-up	0	14
882	2019-02-26 04:15:35	2019-02-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	31	pick-up	0	23
883	2019-02-26 08:40:04	2019-02-26	9	[{"id_menu":7,"count":1}]	394	pick-up	0	9
884	2019-02-26 09:26:36	2019-02-26	8	[{"id_menu":5,"count":1}]	364	delivery	5	13
885	2019-02-26 13:37:37	2019-02-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	581	delivery	5	26
886	2019-02-26 13:45:51	2019-02-26	17	[{"id_menu":4,"count":1}]	314	delivery	5	22
887	2019-02-26 14:03:39	2019-02-26	9	[{"id_menu":7,"count":1}]	313	pick-up	0	9
888	2019-02-26 15:05:44	2019-02-26	14	[{"id_menu":2,"count":2}]	409	delivery	5	19
889	2019-02-26 22:07:28	2019-02-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	113	delivery	5	23
890	2019-02-27 01:01:08	2019-02-27	9	[{"id_menu":7,"count":1}]	335	pick-up	0	9
891	2019-02-27 01:30:34	2019-02-27	9	[{"id_menu":6,"count":1}]	585	delivery	5	14
892	2019-02-27 03:18:16	2019-02-27	17	[{"id_menu":4,"count":1}]	229	delivery	5	22
893	2019-02-27 03:35:42	2019-02-27	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	203	pick-up	0	20
894	2019-02-27 06:57:21	2019-02-27	14	[{"id_menu":2,"count":1}]	233	pick-up	0	14
895	2019-02-27 13:05:49	2019-02-27	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	519	pick-up	0	32
896	2019-02-27 14:34:35	2019-02-27	14	[{"id_menu":2,"count":1}]	338	delivery	5	19
897	2019-02-27 15:31:18	2019-02-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	440	delivery	5	23
898	2019-02-27 17:19:38	2019-02-27	9	[{"id_menu":6,"count":1}]	446	delivery	5	14
899	2019-02-27 17:49:58	2019-02-27	9	[{"id_menu":7,"count":1}]	337	pick-up	0	9
900	2019-02-27 19:41:17	2019-02-27	17	[{"id_menu":4,"count":1}]	363	delivery	5	22
901	2019-02-27 19:56:58	2019-02-27	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	588	pick-up	0	40
902	2019-02-27 21:05:55	2019-02-27	9	[{"id_menu":7,"count":1}]	37	pick-up	0	9
903	2019-02-27 21:12:19	2019-02-27	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	135	pick-up	0	22
904	2019-02-27 22:45:33	2019-02-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27	pick-up	0	18
905	2019-02-27 22:50:18	2019-02-27	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	586	pick-up	0	38
906	2019-02-28 01:02:53	2019-02-28	14	[{"id_menu":2,"count":1}]	227	delivery	5	19
907	2019-02-28 01:11:11	2019-02-28	14	[{"id_menu":2,"count":1}]	78	pick-up	0	14
908	2019-02-28 02:07:20	2019-02-28	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	173	delivery	5	48
909	2019-02-28 03:04:04	2019-02-28	12	[{"id_menu":1,"count":1}]	68	delivery	5	17
910	2019-02-28 04:25:03	2019-02-28	14	[{"id_menu":2,"count":1}]	591	delivery	5	19
911	2019-02-28 04:32:18	2019-02-28	9	[{"id_menu":6,"count":1}]	467	delivery	5	14
912	2019-02-28 04:41:33	2019-02-28	17	[{"id_menu":4,"count":1}]	531	pick-up	0	17
913	2019-02-28 07:25:42	2019-02-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	590	delivery	5	22
914	2019-02-28 09:18:24	2019-02-28	8	[{"id_menu":5,"count":1}]	403	pick-up	0	8
915	2019-02-28 10:39:55	2019-02-28	9	[{"id_menu":6,"count":1}]	391	delivery	5	14
916	2019-02-28 11:10:31	2019-02-28	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	431	pick-up	0	40
917	2019-02-28 12:21:50	2019-02-28	8	[{"id_menu":5,"count":1}]	225	pick-up	0	8
918	2019-02-28 13:32:06	2019-02-28	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	21	pick-up	0	26
919	2019-02-28 15:05:03	2019-02-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	464	pick-up	0	26
920	2019-02-28 15:32:34	2019-02-28	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	595	pick-up	0	37
921	2019-02-28 15:33:06	2019-02-28	14	[{"id_menu":2,"count":1}]	594	pick-up	0	14
922	2019-02-28 15:44:51	2019-02-28	12	[{"id_menu":3,"count":1}]	552	delivery	5	17
923	2019-02-28 19:19:22	2019-02-28	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	593	pick-up	0	39
924	2019-02-28 20:17:32	2019-02-28	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	583	delivery	5	46
925	2019-02-28 20:19:24	2019-02-28	12	[{"id_menu":3,"count":1}]	235	delivery	5	17
926	2019-02-28 21:07:53	2019-02-28	9	[{"id_menu":7,"count":1}]	171	pick-up	0	9
927	2019-03-01 05:38:22	2019-03-01	9	[{"id_menu":6,"count":1}]	600	pick-up	0	9
928	2019-03-01 06:42:42	2019-03-01	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	418	pick-up	0	43
929	2019-03-01 08:55:43	2019-03-01	9	[{"id_menu":7,"count":1}]	184	pick-up	0	9
930	2019-03-01 09:06:22	2019-03-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	599	pick-up	0	31
931	2019-03-01 10:08:08	2019-03-01	9	[{"id_menu":7,"count":1}]	456	delivery	5	14
932	2019-03-01 10:46:22	2019-03-01	12	[{"id_menu":1,"count":1}]	598	delivery	5	17
933	2019-03-01 11:37:44	2019-03-01	12	[{"id_menu":3,"count":1}]	596	pick-up	0	12
934	2019-03-01 11:39:42	2019-03-01	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	543	pick-up	0	35
935	2019-03-01 13:04:32	2019-03-01	8	[{"id_menu":5,"count":1}]	563	pick-up	0	8
936	2019-03-01 13:27:49	2019-03-01	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	601	pick-up	0	23
937	2019-03-01 19:16:50	2019-03-01	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":2}]	397	delivery	5	25
938	2019-03-02 01:37:01	2019-03-02	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	607	delivery	5	31
939	2019-03-02 01:43:12	2019-03-02	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	437	delivery	5	51
940	2019-03-02 03:06:47	2019-03-02	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	352	pick-up	0	21
941	2019-03-02 04:25:43	2019-03-02	12	[{"id_menu":1,"count":1}]	603	delivery	5	17
942	2019-03-02 06:24:32	2019-03-02	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	605	pick-up	0	29
943	2019-03-02 07:05:40	2019-03-02	12	[{"id_menu":3,"count":1}]	223	delivery	5	17
944	2019-03-02 07:42:41	2019-03-02	9	[{"id_menu":6,"count":1}]	257	delivery	5	14
945	2019-03-02 08:10:41	2019-03-02	9	[{"id_menu":6,"count":1}]	150	pick-up	0	9
946	2019-03-02 09:44:17	2019-03-02	9	[{"id_menu":6,"count":1}]	330	pick-up	0	9
947	2019-03-02 14:53:10	2019-03-02	14	[{"id_menu":2,"count":1}]	149	pick-up	0	14
948	2019-03-02 17:11:01	2019-03-02	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	602	delivery	5	27
949	2019-03-02 17:45:25	2019-03-02	9	[{"id_menu":6,"count":1}]	255	delivery	5	14
950	2019-03-02 19:18:38	2019-03-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	606	pick-up	0	18
951	2019-03-02 19:52:51	2019-03-02	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	271	delivery	5	28
952	2019-03-02 20:29:17	2019-03-02	9	[{"id_menu":6,"count":1}]	99	pick-up	0	9
953	2019-03-02 20:47:19	2019-03-02	9	[{"id_menu":7,"count":1}]	360	delivery	5	14
954	2019-03-02 22:15:10	2019-03-02	12	[{"id_menu":3,"count":1}]	489	pick-up	0	12
955	2019-03-02 22:45:09	2019-03-02	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	604	delivery	5	43
956	2019-03-02 23:39:32	2019-03-02	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	608	pick-up	0	29
957	2019-03-03 02:12:19	2019-03-03	8	[{"id_menu":5,"count":1}]	207	delivery	5	13
958	2019-03-03 02:32:48	2019-03-03	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	226	pick-up	0	26
959	2019-03-03 03:24:54	2019-03-03	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	281	delivery	5	25
960	2019-03-03 06:32:19	2019-03-03	8	[{"id_menu":5,"count":1}]	614	delivery	5	13
961	2019-03-03 07:32:43	2019-03-03	12	[{"id_menu":3,"count":1}]	233	pick-up	0	12
962	2019-03-03 08:25:29	2019-03-03	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	526	delivery	5	34
963	2019-03-03 08:33:07	2019-03-03	12	[{"id_menu":3,"count":1}]	611	delivery	5	17
964	2019-03-03 10:30:49	2019-03-03	9	[{"id_menu":6,"count":1}]	589	delivery	5	14
965	2019-03-03 10:42:29	2019-03-03	12	[{"id_menu":3,"count":1}]	245	delivery	5	17
966	2019-03-03 12:12:50	2019-03-03	9	[{"id_menu":7,"count":1}]	338	delivery	5	14
967	2019-03-03 12:13:26	2019-03-03	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	612	pick-up	0	38
968	2019-03-03 12:15:46	2019-03-03	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	430	pick-up	0	25
969	2019-03-03 12:35:59	2019-03-03	9	[{"id_menu":7,"count":2}]	241	pick-up	0	9
970	2019-03-03 13:04:25	2019-03-03	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	613	delivery	5	34
971	2019-03-03 13:51:08	2019-03-03	14	[{"id_menu":2,"count":1}]	609	pick-up	0	14
972	2019-03-03 14:17:39	2019-03-03	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	610	pick-up	0	31
973	2019-03-03 16:31:59	2019-03-03	22	[{"id_menu":2,"count":3},{"id_menu":5,"count":1}]	48	pick-up	0	22
974	2019-03-03 18:11:09	2019-03-03	14	[{"id_menu":2,"count":1}]	260	delivery	5	19
975	2019-03-03 18:43:03	2019-03-03	12	[{"id_menu":3,"count":1}]	488	pick-up	0	12
976	2019-03-03 19:00:28	2019-03-03	9	[{"id_menu":7,"count":1}]	477	pick-up	0	9
977	2019-03-03 20:30:43	2019-03-03	12	[{"id_menu":3,"count":1}]	340	pick-up	0	12
978	2019-03-03 20:36:52	2019-03-03	14	[{"id_menu":2,"count":1}]	253	pick-up	0	14
979	2019-03-03 20:57:01	2019-03-03	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	89	pick-up	0	26
980	2019-03-03 22:44:05	2019-03-03	12	[{"id_menu":1,"count":1}]	171	delivery	5	17
981	2019-03-04 04:27:16	2019-03-04	14	[{"id_menu":2,"count":1}]	203	pick-up	0	14
982	2019-03-04 05:47:43	2019-03-04	17	[{"id_menu":4,"count":1}]	89	pick-up	0	17
983	2019-03-04 11:54:45	2019-03-04	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	543	pick-up	0	21
984	2019-03-04 11:59:35	2019-03-04	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	615	delivery	5	26
985	2019-03-04 12:17:21	2019-03-04	9	[{"id_menu":7,"count":1}]	209	pick-up	0	9
986	2019-03-04 16:25:38	2019-03-04	8	[{"id_menu":5,"count":1}]	531	delivery	5	13
987	2019-03-04 20:05:11	2019-03-04	12	[{"id_menu":3,"count":1}]	616	delivery	5	17
988	2019-03-04 20:42:41	2019-03-04	12	[{"id_menu":1,"count":1}]	619	delivery	5	17
989	2019-03-04 22:05:59	2019-03-04	12	[{"id_menu":1,"count":1}]	29	pick-up	0	12
990	2019-03-05 03:07:53	2019-03-05	9	[{"id_menu":6,"count":1}]	603	delivery	5	14
991	2019-03-05 03:13:01	2019-03-05	8	[{"id_menu":5,"count":1}]	378	pick-up	0	8
992	2019-03-05 03:52:41	2019-03-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	563	delivery	5	31
993	2019-03-05 03:58:47	2019-03-05	9	[{"id_menu":6,"count":1}]	274	pick-up	0	9
994	2019-03-05 04:19:09	2019-03-05	14	[{"id_menu":2,"count":1}]	623	pick-up	0	14
995	2019-03-05 05:41:19	2019-03-05	17	[{"id_menu":4,"count":1}]	228	pick-up	0	17
996	2019-03-05 06:26:56	2019-03-05	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	625	pick-up	0	21
997	2019-03-05 06:46:17	2019-03-05	9	[{"id_menu":6,"count":1}]	171	pick-up	0	9
998	2019-03-05 08:23:42	2019-03-05	9	[{"id_menu":6,"count":1}]	447	pick-up	0	9
999	2019-03-05 08:53:39	2019-03-05	12	[{"id_menu":3,"count":1}]	338	pick-up	0	12
1000	2019-03-05 10:54:33	2019-03-05	9	[{"id_menu":7,"count":1}]	622	delivery	5	14
1001	2019-03-05 15:32:06	2019-03-05	9	[{"id_menu":7,"count":1}]	132	delivery	5	14
1002	2019-03-05 17:12:03	2019-03-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	477	delivery	5	31
1003	2019-03-05 21:40:40	2019-03-05	12	[{"id_menu":1,"count":1}]	287	pick-up	0	12
1004	2019-03-06 06:52:30	2019-03-06	14	[{"id_menu":2,"count":1}]	630	delivery	5	19
1005	2019-03-06 08:25:18	2019-03-06	14	[{"id_menu":2,"count":1}]	626	pick-up	0	14
1006	2019-03-06 14:55:32	2019-03-06	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	264	pick-up	0	35
1007	2019-03-06 16:15:18	2019-03-06	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	629	delivery	5	27
1008	2019-03-06 16:52:57	2019-03-06	12	[{"id_menu":1,"count":1}]	370	pick-up	0	12
1009	2019-03-06 17:18:57	2019-03-06	12	[{"id_menu":3,"count":1}]	627	pick-up	0	12
1010	2019-03-06 19:07:38	2019-03-06	12	[{"id_menu":3,"count":1}]	169	pick-up	0	12
1011	2019-03-06 19:51:05	2019-03-06	9	[{"id_menu":6,"count":1}]	547	pick-up	0	9
1012	2019-03-06 20:38:16	2019-03-06	9	[{"id_menu":7,"count":1}]	628	delivery	5	14
1013	2019-03-06 22:53:49	2019-03-06	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	631	delivery	5	31
1014	2019-03-07 00:11:53	2019-03-07	17	[{"id_menu":4,"count":1}]	35	delivery	5	22
1015	2019-03-07 00:33:34	2019-03-07	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	635	delivery	5	36
1016	2019-03-07 00:56:15	2019-03-07	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	633	delivery	5	27
1017	2019-03-07 04:50:20	2019-03-07	9	[{"id_menu":6,"count":1}]	74	pick-up	0	9
1018	2019-03-07 08:02:31	2019-03-07	14	[{"id_menu":2,"count":1}]	15	pick-up	0	14
1019	2019-03-07 08:06:37	2019-03-07	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	590	delivery	5	38
1020	2019-03-07 13:27:03	2019-03-07	9	[{"id_menu":7,"count":1}]	632	pick-up	0	9
1021	2019-03-07 18:10:29	2019-03-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	293	delivery	5	26
1022	2019-03-07 19:52:29	2019-03-07	17	[{"id_menu":4,"count":1}]	634	pick-up	0	17
1023	2019-03-07 20:47:56	2019-03-07	9	[{"id_menu":7,"count":1}]	295	delivery	5	14
1024	2019-03-07 21:05:51	2019-03-07	17	[{"id_menu":4,"count":1}]	636	pick-up	0	17
1025	2019-03-08 03:28:51	2019-03-08	17	[{"id_menu":4,"count":1}]	639	delivery	5	22
1026	2019-03-08 04:58:53	2019-03-08	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	17	pick-up	0	35
1027	2019-03-08 09:23:09	2019-03-08	14	[{"id_menu":2,"count":1}]	73	pick-up	0	14
1028	2019-03-08 09:59:47	2019-03-08	14	[{"id_menu":2,"count":1}]	223	delivery	5	19
1029	2019-03-08 10:33:00	2019-03-08	12	[{"id_menu":1,"count":1}]	229	pick-up	0	12
1030	2019-03-08 10:35:35	2019-03-08	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	189	delivery	5	36
1031	2019-03-08 10:39:42	2019-03-08	17	[{"id_menu":4,"count":1}]	335	pick-up	0	17
1032	2019-03-08 11:37:26	2019-03-08	9	[{"id_menu":6,"count":1}]	456	pick-up	0	9
1033	2019-03-08 11:55:44	2019-03-08	17	[{"id_menu":4,"count":1}]	643	delivery	5	22
1034	2019-03-08 12:32:37	2019-03-08	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	227	delivery	5	36
1035	2019-03-08 13:34:50	2019-03-08	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	640	pick-up	0	21
1036	2019-03-08 18:56:11	2019-03-08	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	92	delivery	5	26
1037	2019-03-08 21:42:38	2019-03-08	17	[{"id_menu":4,"count":1}]	194	delivery	5	22
1038	2019-03-08 22:04:27	2019-03-08	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	378	delivery	5	27
1039	2019-03-09 01:21:31	2019-03-09	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	648	pick-up	0	35
1040	2019-03-09 01:42:40	2019-03-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	73	pick-up	0	23
1041	2019-03-09 02:01:47	2019-03-09	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	645	pick-up	0	26
1042	2019-03-09 06:52:05	2019-03-09	9	[{"id_menu":6,"count":1}]	647	delivery	5	14
1043	2019-03-09 06:59:07	2019-03-09	17	[{"id_menu":4,"count":1}]	10	pick-up	0	17
1044	2019-03-09 07:20:01	2019-03-09	14	[{"id_menu":2,"count":1}]	646	delivery	5	19
1045	2019-03-09 07:20:21	2019-03-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	359	pick-up	0	23
1046	2019-03-09 09:25:07	2019-03-09	9	[{"id_menu":6,"count":1}]	299	delivery	5	14
1047	2019-03-09 09:45:14	2019-03-09	8	[{"id_menu":5,"count":1}]	644	pick-up	0	8
1048	2019-03-09 12:23:00	2019-03-09	9	[{"id_menu":7,"count":1}]	177	pick-up	0	9
1049	2019-03-09 12:25:15	2019-03-09	12	[{"id_menu":3,"count":1}]	543	pick-up	0	12
1050	2019-03-09 13:54:14	2019-03-09	14	[{"id_menu":2,"count":1}]	552	pick-up	0	14
1051	2019-03-09 14:22:43	2019-03-09	14	[{"id_menu":2,"count":3}]	477	delivery	5	19
1052	2019-03-09 14:51:04	2019-03-09	17	[{"id_menu":4,"count":1}]	338	delivery	5	22
1053	2019-03-09 15:05:52	2019-03-09	9	[{"id_menu":6,"count":1}]	649	pick-up	0	9
1054	2019-03-09 15:43:47	2019-03-09	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	456	delivery	5	26
1055	2019-03-09 17:06:22	2019-03-09	21	[{"id_menu":1,"count":3},{"id_menu":6,"count":1}]	340	pick-up	0	21
1056	2019-03-09 21:38:38	2019-03-09	8	[{"id_menu":5,"count":1}]	228	pick-up	0	8
1057	2019-03-09 22:43:16	2019-03-09	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	650	delivery	5	45
1058	2019-03-10 00:30:27	2019-03-10	8	[{"id_menu":5,"count":1}]	44	pick-up	0	8
1059	2019-03-10 01:14:43	2019-03-10	14	[{"id_menu":2,"count":1}]	656	delivery	5	19
1060	2019-03-10 01:25:54	2019-03-10	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	122	pick-up	0	38
1061	2019-03-10 02:53:38	2019-03-10	12	[{"id_menu":1,"count":1}]	428	pick-up	0	12
1062	2019-03-10 02:58:19	2019-03-10	12	[{"id_menu":1,"count":1}]	653	delivery	5	17
1063	2019-03-10 03:24:56	2019-03-10	9	[{"id_menu":7,"count":1}]	437	delivery	5	14
1064	2019-03-10 03:56:55	2019-03-10	17	[{"id_menu":4,"count":1}]	338	pick-up	0	17
1065	2019-03-10 04:37:18	2019-03-10	12	[{"id_menu":3,"count":1}]	109	pick-up	0	12
1066	2019-03-10 05:05:22	2019-03-10	9	[{"id_menu":6,"count":1}]	300	delivery	5	14
1067	2019-03-10 05:17:32	2019-03-10	9	[{"id_menu":6,"count":2}]	31	pick-up	0	9
1068	2019-03-10 06:51:33	2019-03-10	8	[{"id_menu":5,"count":1}]	601	pick-up	0	8
1069	2019-03-10 08:19:21	2019-03-10	17	[{"id_menu":4,"count":1}]	287	pick-up	0	17
1070	2019-03-10 08:56:25	2019-03-10	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	377	pick-up	0	31
1071	2019-03-10 10:52:55	2019-03-10	12	[{"id_menu":1,"count":1}]	184	pick-up	0	12
1072	2019-03-10 12:06:38	2019-03-10	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	123	pick-up	0	21
1073	2019-03-10 13:53:27	2019-03-10	9	[{"id_menu":7,"count":1}]	655	pick-up	0	9
1074	2019-03-10 14:22:25	2019-03-10	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	552	delivery	5	26
1075	2019-03-10 15:04:11	2019-03-10	8	[{"id_menu":5,"count":2}]	651	pick-up	0	8
1076	2019-03-10 16:58:59	2019-03-10	9	[{"id_menu":7,"count":1}]	657	pick-up	0	9
1077	2019-03-10 18:20:40	2019-03-10	8	[{"id_menu":5,"count":1}]	652	pick-up	0	8
1078	2019-03-10 18:30:04	2019-03-10	9	[{"id_menu":7,"count":1}]	654	pick-up	0	9
1079	2019-03-10 21:23:46	2019-03-10	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	546	delivery	5	26
1080	2019-03-10 21:47:35	2019-03-10	12	[{"id_menu":1,"count":1}]	379	delivery	5	17
1081	2019-03-11 02:28:07	2019-03-11	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	208	pick-up	0	34
1082	2019-03-11 06:47:42	2019-03-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	376	pick-up	0	17
1083	2019-03-11 09:06:24	2019-03-11	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	658	delivery	5	31
1084	2019-03-11 09:31:13	2019-03-11	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	149	pick-up	0	22
1085	2019-03-11 10:13:14	2019-03-11	9	[{"id_menu":7,"count":2}]	661	delivery	5	14
1086	2019-03-11 12:25:46	2019-03-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	311	delivery	5	28
1087	2019-03-11 13:22:26	2019-03-11	9	[{"id_menu":6,"count":1}]	639	pick-up	0	9
1088	2019-03-11 13:32:34	2019-03-11	9	[{"id_menu":6,"count":1}]	662	pick-up	0	9
1089	2019-03-11 13:57:43	2019-03-11	12	[{"id_menu":3,"count":1}]	654	delivery	5	17
1090	2019-03-11 14:52:17	2019-03-11	12	[{"id_menu":1,"count":1}]	172	pick-up	0	12
1091	2019-03-11 15:37:26	2019-03-11	12	[{"id_menu":1,"count":1}]	281	pick-up	0	12
1092	2019-03-11 17:18:17	2019-03-11	9	[{"id_menu":6,"count":1}]	177	pick-up	0	9
1093	2019-03-11 19:25:38	2019-03-11	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	659	pick-up	0	21
1094	2019-03-11 20:17:56	2019-03-11	14	[{"id_menu":2,"count":1}]	76	delivery	5	19
1095	2019-03-11 21:13:47	2019-03-11	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	24	delivery	5	26
1096	2019-03-11 23:31:50	2019-03-11	12	[{"id_menu":1,"count":1}]	286	delivery	5	17
1097	2019-03-11 23:48:48	2019-03-11	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	105	pick-up	0	31
1098	2019-03-12 04:51:56	2019-03-12	8	[{"id_menu":5,"count":1}]	664	delivery	5	13
1099	2019-03-12 07:15:00	2019-03-12	12	[{"id_menu":1,"count":1}]	486	pick-up	0	12
1100	2019-03-12 08:16:17	2019-03-12	12	[{"id_menu":3,"count":1}]	669	pick-up	0	12
1101	2019-03-12 10:51:50	2019-03-12	17	[{"id_menu":4,"count":1}]	1	pick-up	0	17
1102	2019-03-12 14:56:52	2019-03-12	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	666	pick-up	0	38
1103	2019-03-12 15:30:48	2019-03-12	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	546	delivery	5	25
1104	2019-03-12 17:31:08	2019-03-12	17	[{"id_menu":4,"count":1}]	16	pick-up	0	17
1105	2019-03-12 18:37:33	2019-03-12	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	197	pick-up	0	25
1106	2019-03-12 20:45:51	2019-03-12	9	[{"id_menu":6,"count":1}]	286	pick-up	0	9
1107	2019-03-12 21:50:34	2019-03-12	9	[{"id_menu":7,"count":1}]	599	pick-up	0	9
1108	2019-03-12 22:10:19	2019-03-12	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	552	delivery	5	55
1109	2019-03-12 23:02:07	2019-03-12	17	[{"id_menu":4,"count":1}]	586	delivery	5	22
1110	2019-03-13 02:12:21	2019-03-13	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	675	delivery	5	45
1111	2019-03-13 02:15:18	2019-03-13	12	[{"id_menu":1,"count":1}]	674	pick-up	0	12
1112	2019-03-13 04:39:38	2019-03-13	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	673	pick-up	0	26
1113	2019-03-13 05:09:17	2019-03-13	14	[{"id_menu":2,"count":1}]	669	pick-up	0	14
1114	2019-03-13 08:59:05	2019-03-13	14	[{"id_menu":2,"count":1}]	452	pick-up	0	14
1115	2019-03-13 09:27:28	2019-03-13	12	[{"id_menu":1,"count":1}]	634	pick-up	0	12
1116	2019-03-13 10:14:28	2019-03-13	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	672	delivery	5	22
1117	2019-03-13 11:42:02	2019-03-13	30	[{"id_menu":1,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	671	delivery	5	35
1118	2019-03-13 12:12:56	2019-03-13	17	[{"id_menu":4,"count":1}]	419	delivery	5	22
1119	2019-03-13 12:26:46	2019-03-13	9	[{"id_menu":6,"count":1}]	171	pick-up	0	9
1120	2019-03-13 14:07:04	2019-03-13	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	6	pick-up	0	26
1121	2019-03-13 14:56:02	2019-03-13	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	270	pick-up	0	26
1122	2019-03-13 15:19:17	2019-03-13	12	[{"id_menu":1,"count":1}]	215	pick-up	0	12
1123	2019-03-13 16:43:17	2019-03-13	9	[{"id_menu":6,"count":1}]	381	pick-up	0	9
1124	2019-03-13 19:34:02	2019-03-13	12	[{"id_menu":1,"count":1}]	78	delivery	5	17
1125	2019-03-13 22:32:52	2019-03-13	12	[{"id_menu":3,"count":1}]	207	pick-up	0	12
1126	2019-03-14 01:45:09	2019-03-14	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	681	delivery	5	43
1127	2019-03-14 03:30:39	2019-03-14	8	[{"id_menu":5,"count":1}]	678	pick-up	0	8
1128	2019-03-14 03:44:21	2019-03-14	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	482	delivery	5	40
1129	2019-03-14 04:04:23	2019-03-14	14	[{"id_menu":2,"count":1}]	443	delivery	5	19
1130	2019-03-14 04:32:48	2019-03-14	14	[{"id_menu":2,"count":1}]	126	delivery	5	19
1131	2019-03-14 05:10:41	2019-03-14	9	[{"id_menu":6,"count":1}]	680	pick-up	0	9
1132	2019-03-14 05:27:10	2019-03-14	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	655	delivery	5	34
1133	2019-03-14 06:04:10	2019-03-14	14	[{"id_menu":2,"count":1}]	679	delivery	5	19
1134	2019-03-14 08:13:42	2019-03-14	9	[{"id_menu":7,"count":1}]	356	pick-up	0	9
1135	2019-03-14 08:29:23	2019-03-14	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	677	pick-up	0	34
1136	2019-03-14 09:50:13	2019-03-14	17	[{"id_menu":4,"count":1}]	623	pick-up	0	17
1137	2019-03-14 13:56:16	2019-03-14	9	[{"id_menu":6,"count":1}]	676	pick-up	0	9
1138	2019-03-14 17:17:38	2019-03-14	12	[{"id_menu":3,"count":2}]	338	pick-up	0	12
1139	2019-03-15 00:42:34	2019-03-15	9	[{"id_menu":7,"count":1}]	688	pick-up	0	9
1140	2019-03-15 01:12:58	2019-03-15	14	[{"id_menu":2,"count":2}]	300	delivery	5	19
1141	2019-03-15 01:20:52	2019-03-15	8	[{"id_menu":5,"count":1}]	687	delivery	5	13
1142	2019-03-15 01:51:59	2019-03-15	12	[{"id_menu":3,"count":1}]	265	delivery	5	17
1143	2019-03-15 01:58:13	2019-03-15	17	[{"id_menu":4,"count":1}]	684	pick-up	0	17
1144	2019-03-15 07:30:18	2019-03-15	9	[{"id_menu":7,"count":1}]	96	pick-up	0	9
1145	2019-03-15 08:47:43	2019-03-15	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	170	pick-up	0	26
1146	2019-03-15 10:06:45	2019-03-15	17	[{"id_menu":4,"count":1}]	401	pick-up	0	17
1147	2019-03-15 11:52:16	2019-03-15	8	[{"id_menu":5,"count":2}]	270	pick-up	0	8
1148	2019-03-15 13:08:16	2019-03-15	9	[{"id_menu":6,"count":1}]	82	pick-up	0	9
1149	2019-03-15 13:58:10	2019-03-15	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	437	delivery	5	39
1150	2019-03-15 14:21:00	2019-03-15	17	[{"id_menu":4,"count":1}]	352	pick-up	0	17
1151	2019-03-15 15:08:12	2019-03-15	12	[{"id_menu":3,"count":1}]	149	delivery	5	17
1152	2019-03-15 15:12:12	2019-03-15	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	381	pick-up	0	21
1153	2019-03-15 17:37:53	2019-03-15	9	[{"id_menu":7,"count":1}]	637	delivery	5	14
1154	2019-03-15 19:22:10	2019-03-15	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	685	delivery	5	36
1155	2019-03-15 19:53:44	2019-03-15	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	223	pick-up	0	29
1156	2019-03-15 21:00:50	2019-03-15	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	682	pick-up	0	29
1157	2019-03-15 22:13:43	2019-03-15	8	[{"id_menu":5,"count":1}]	292	delivery	5	13
1158	2019-03-16 00:23:18	2019-03-16	9	[{"id_menu":6,"count":1}]	694	delivery	5	14
1159	2019-03-16 02:31:25	2019-03-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	693	delivery	5	23
1160	2019-03-16 02:47:14	2019-03-16	12	[{"id_menu":1,"count":1}]	245	pick-up	0	12
1161	2019-03-16 03:20:59	2019-03-16	9	[{"id_menu":7,"count":1}]	62	delivery	5	14
1162	2019-03-16 03:40:38	2019-03-16	8	[{"id_menu":5,"count":1}]	76	delivery	5	13
1163	2019-03-16 05:25:40	2019-03-16	14	[{"id_menu":2,"count":1}]	661	pick-up	0	14
1164	2019-03-16 07:07:23	2019-03-16	12	[{"id_menu":1,"count":1}]	274	pick-up	0	12
1165	2019-03-16 08:02:56	2019-03-16	8	[{"id_menu":5,"count":1}]	97	pick-up	0	8
1166	2019-03-16 10:06:14	2019-03-16	12	[{"id_menu":1,"count":2}]	689	pick-up	0	12
1167	2019-03-16 10:42:20	2019-03-16	9	[{"id_menu":7,"count":1}]	3	pick-up	0	9
1168	2019-03-16 12:15:50	2019-03-16	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	555	delivery	5	52
1169	2019-03-16 12:49:34	2019-03-16	12	[{"id_menu":1,"count":1}]	486	pick-up	0	12
1170	2019-03-16 14:15:43	2019-03-16	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	691	pick-up	0	43
1171	2019-03-16 15:21:26	2019-03-16	12	[{"id_menu":3,"count":1}]	690	delivery	5	17
1172	2019-03-16 15:26:40	2019-03-16	17	[{"id_menu":4,"count":1}]	150	pick-up	0	17
1173	2019-03-16 17:15:17	2019-03-16	9	[{"id_menu":7,"count":2}]	160	pick-up	0	9
1174	2019-03-16 19:01:26	2019-03-16	12	[{"id_menu":3,"count":1}]	32	pick-up	0	12
1175	2019-03-16 19:05:49	2019-03-16	8	[{"id_menu":5,"count":1}]	340	delivery	5	13
1176	2019-03-16 20:40:10	2019-03-16	17	[{"id_menu":4,"count":1}]	378	pick-up	0	17
1177	2019-03-16 21:39:12	2019-03-16	12	[{"id_menu":1,"count":1}]	381	delivery	5	17
1178	2019-03-16 22:04:52	2019-03-16	9	[{"id_menu":7,"count":1}]	692	pick-up	0	9
1179	2019-03-16 22:24:11	2019-03-16	9	[{"id_menu":6,"count":1}]	696	pick-up	0	9
1180	2019-03-17 00:20:59	2019-03-17	8	[{"id_menu":5,"count":1}]	162	delivery	5	13
1181	2019-03-17 00:45:44	2019-03-17	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	635	delivery	5	34
1182	2019-03-17 01:09:59	2019-03-17	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	701	delivery	5	37
1183	2019-03-17 02:49:24	2019-03-17	9	[{"id_menu":6,"count":1}]	122	pick-up	0	9
1184	2019-03-17 03:39:22	2019-03-17	12	[{"id_menu":3,"count":1}]	528	delivery	5	17
1185	2019-03-17 04:56:05	2019-03-17	9	[{"id_menu":7,"count":1}]	265	pick-up	0	9
1186	2019-03-17 05:12:20	2019-03-17	14	[{"id_menu":2,"count":1}]	222	delivery	5	19
1187	2019-03-17 05:32:53	2019-03-17	14	[{"id_menu":2,"count":1}]	702	pick-up	0	14
1188	2019-03-17 05:35:13	2019-03-17	9	[{"id_menu":6,"count":1}]	293	pick-up	0	9
1189	2019-03-17 05:59:05	2019-03-17	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	306	delivery	5	23
1190	2019-03-17 07:07:34	2019-03-17	14	[{"id_menu":2,"count":1}]	649	pick-up	0	14
1191	2019-03-17 07:34:00	2019-03-17	14	[{"id_menu":2,"count":1}]	62	pick-up	0	14
1192	2019-03-17 07:34:49	2019-03-17	9	[{"id_menu":6,"count":1}]	376	delivery	5	14
1193	2019-03-17 08:42:31	2019-03-17	12	[{"id_menu":1,"count":1}]	21	delivery	5	17
1194	2019-03-17 12:24:21	2019-03-17	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	661	pick-up	0	29
1195	2019-03-17 12:50:22	2019-03-17	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	691	pick-up	0	21
1196	2019-03-17 13:11:23	2019-03-17	12	[{"id_menu":3,"count":1}]	697	pick-up	0	12
1197	2019-03-17 16:23:20	2019-03-17	14	[{"id_menu":2,"count":1}]	236	pick-up	0	14
1198	2019-03-17 16:30:26	2019-03-17	9	[{"id_menu":7,"count":1}]	232	pick-up	0	9
1199	2019-03-17 16:39:53	2019-03-17	12	[{"id_menu":3,"count":1}]	381	delivery	5	17
1200	2019-03-17 16:54:44	2019-03-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	640	pick-up	0	26
1201	2019-03-17 18:22:07	2019-03-17	14	[{"id_menu":2,"count":1}]	688	pick-up	0	14
1202	2019-03-17 19:15:25	2019-03-17	8	[{"id_menu":5,"count":1}]	192	pick-up	0	8
1203	2019-03-17 19:25:21	2019-03-17	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	703	delivery	5	34
1204	2019-03-17 19:56:31	2019-03-17	17	[{"id_menu":4,"count":1}]	698	pick-up	0	17
1205	2019-03-17 20:22:16	2019-03-17	8	[{"id_menu":5,"count":1}]	700	pick-up	0	8
1206	2019-03-17 20:31:05	2019-03-17	14	[{"id_menu":2,"count":2}]	92	pick-up	0	14
1207	2019-03-17 22:33:12	2019-03-17	14	[{"id_menu":2,"count":1}]	569	delivery	5	19
1208	2019-03-17 22:54:02	2019-03-17	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	699	delivery	5	40
1209	2019-03-18 00:00:32	2019-03-18	12	[{"id_menu":1,"count":1}]	179	delivery	5	17
1210	2019-03-18 00:19:10	2019-03-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	705	pick-up	0	17
1211	2019-03-18 04:09:15	2019-03-18	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	710	delivery	5	34
1212	2019-03-18 04:41:00	2019-03-18	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	670	pick-up	0	40
1213	2019-03-18 05:31:56	2019-03-18	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	486	pick-up	0	21
1214	2019-03-18 06:30:14	2019-03-18	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	482	delivery	5	29
1215	2019-03-18 10:06:04	2019-03-18	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	249	pick-up	0	25
1216	2019-03-18 11:14:32	2019-03-18	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	304	delivery	5	45
1217	2019-03-18 12:57:17	2019-03-18	8	[{"id_menu":5,"count":1}]	157	pick-up	0	8
1218	2019-03-18 15:02:28	2019-03-18	12	[{"id_menu":1,"count":1}]	158	delivery	5	17
1219	2019-03-18 16:18:28	2019-03-18	9	[{"id_menu":6,"count":1}]	502	delivery	5	14
1220	2019-03-18 18:53:28	2019-03-18	14	[{"id_menu":2,"count":1}]	684	pick-up	0	14
1221	2019-03-18 20:23:38	2019-03-18	17	[{"id_menu":4,"count":1}]	704	pick-up	0	17
1222	2019-03-19 03:04:21	2019-03-19	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	711	pick-up	0	25
1223	2019-03-19 03:28:06	2019-03-19	12	[{"id_menu":1,"count":1}]	216	delivery	5	17
1224	2019-03-19 08:45:00	2019-03-19	9	[{"id_menu":7,"count":2}]	566	delivery	5	14
1225	2019-03-19 09:25:08	2019-03-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	149	pick-up	0	31
1226	2019-03-19 12:07:21	2019-03-19	9	[{"id_menu":6,"count":1}]	357	delivery	5	14
1227	2019-03-19 12:26:45	2019-03-19	9	[{"id_menu":6,"count":1}]	714	delivery	5	14
1228	2019-03-19 13:02:00	2019-03-19	9	[{"id_menu":7,"count":1}]	41	pick-up	0	9
1229	2019-03-19 16:09:46	2019-03-19	9	[{"id_menu":6,"count":1}]	75	pick-up	0	9
1230	2019-03-19 18:50:36	2019-03-19	14	[{"id_menu":2,"count":1}]	150	delivery	5	19
1231	2019-03-19 22:26:48	2019-03-19	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	634	pick-up	0	29
1232	2019-03-19 22:35:10	2019-03-19	9	[{"id_menu":7,"count":1}]	716	pick-up	0	9
1233	2019-03-20 01:46:01	2019-03-20	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	628	delivery	5	48
1234	2019-03-20 02:00:25	2019-03-20	17	[{"id_menu":4,"count":1}]	452	delivery	5	22
1235	2019-03-20 03:15:42	2019-03-20	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	434	pick-up	0	35
1236	2019-03-20 03:29:11	2019-03-20	12	[{"id_menu":1,"count":1}]	371	pick-up	0	12
1237	2019-03-20 05:27:23	2019-03-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	717	pick-up	0	18
1238	2019-03-20 05:46:56	2019-03-20	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	722	pick-up	0	21
1239	2019-03-20 06:10:23	2019-03-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	707	pick-up	0	23
1240	2019-03-20 06:14:04	2019-03-20	14	[{"id_menu":2,"count":1}]	76	pick-up	0	14
1241	2019-03-20 06:54:09	2019-03-20	17	[{"id_menu":4,"count":1}]	324	pick-up	0	17
1242	2019-03-20 10:22:25	2019-03-20	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	169	pick-up	0	26
1243	2019-03-20 11:03:04	2019-03-20	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	207	pick-up	0	30
1244	2019-03-20 12:53:01	2019-03-20	14	[{"id_menu":2,"count":1}]	422	delivery	5	19
1245	2019-03-20 13:23:45	2019-03-20	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	718	delivery	5	37
1246	2019-03-20 13:57:43	2019-03-20	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	720	delivery	5	22
1247	2019-03-20 14:30:11	2019-03-20	17	[{"id_menu":4,"count":1}]	258	delivery	5	22
1248	2019-03-20 15:19:14	2019-03-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	375	delivery	5	22
1249	2019-03-20 19:03:39	2019-03-20	17	[{"id_menu":4,"count":1}]	593	pick-up	0	17
1250	2019-03-20 19:22:25	2019-03-20	9	[{"id_menu":6,"count":1}]	701	pick-up	0	9
1251	2019-03-20 19:57:14	2019-03-20	14	[{"id_menu":2,"count":1}]	82	pick-up	0	14
1252	2019-03-20 20:42:00	2019-03-20	17	[{"id_menu":4,"count":1}]	408	delivery	5	22
1253	2019-03-20 21:09:02	2019-03-20	17	[{"id_menu":4,"count":1}]	721	delivery	5	22
1254	2019-03-20 22:34:58	2019-03-20	12	[{"id_menu":3,"count":1}]	381	pick-up	0	12
1255	2019-03-20 23:17:10	2019-03-20	9	[{"id_menu":7,"count":1}]	719	pick-up	0	9
1256	2019-03-20 23:21:05	2019-03-20	12	[{"id_menu":3,"count":1}]	193	pick-up	0	12
1257	2019-03-21 00:17:23	2019-03-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	723	pick-up	0	23
1258	2019-03-21 01:06:31	2019-03-21	14	[{"id_menu":2,"count":1}]	599	delivery	5	19
1259	2019-03-21 01:42:48	2019-03-21	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	503	delivery	5	35
1260	2019-03-21 02:49:15	2019-03-21	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	527	pick-up	0	35
1261	2019-03-21 03:02:25	2019-03-21	9	[{"id_menu":6,"count":1}]	92	delivery	5	14
1262	2019-03-21 03:13:14	2019-03-21	17	[{"id_menu":4,"count":1}]	705	delivery	5	22
1263	2019-03-21 04:19:34	2019-03-21	9	[{"id_menu":7,"count":1}]	213	pick-up	0	9
1264	2019-03-21 06:54:55	2019-03-21	12	[{"id_menu":3,"count":1}]	634	pick-up	0	12
1265	2019-03-21 10:12:18	2019-03-21	17	[{"id_menu":4,"count":1}]	489	pick-up	0	17
1266	2019-03-21 10:15:21	2019-03-21	12	[{"id_menu":1,"count":1}]	728	pick-up	0	12
1267	2019-03-21 12:48:00	2019-03-21	14	[{"id_menu":2,"count":1}]	486	pick-up	0	14
1268	2019-03-21 13:13:23	2019-03-21	12	[{"id_menu":1,"count":2}]	167	delivery	5	17
1269	2019-03-21 14:01:01	2019-03-21	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	624	pick-up	0	26
1270	2019-03-21 14:19:07	2019-03-21	17	[{"id_menu":4,"count":1}]	165	delivery	5	22
1271	2019-03-21 15:43:55	2019-03-21	14	[{"id_menu":2,"count":1}]	437	delivery	5	19
1272	2019-03-21 16:01:23	2019-03-21	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	727	delivery	5	31
1273	2019-03-21 16:07:17	2019-03-21	9	[{"id_menu":6,"count":1}]	724	pick-up	0	9
1274	2019-03-21 16:55:15	2019-03-21	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	534	pick-up	0	29
1275	2019-03-21 17:47:51	2019-03-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	683	delivery	5	28
1276	2019-03-21 17:54:56	2019-03-21	8	[{"id_menu":5,"count":1}]	340	pick-up	0	8
1277	2019-03-21 20:21:45	2019-03-21	14	[{"id_menu":2,"count":1}]	382	pick-up	0	14
1278	2019-03-21 22:07:21	2019-03-21	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	726	delivery	5	25
1279	2019-03-21 22:43:44	2019-03-21	9	[{"id_menu":7,"count":1}]	223	delivery	5	14
1280	2019-03-22 00:52:19	2019-03-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	730	pick-up	0	23
1281	2019-03-22 03:44:59	2019-03-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	732	pick-up	0	23
1282	2019-03-22 05:49:34	2019-03-22	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	546	delivery	5	22
1283	2019-03-22 06:35:17	2019-03-22	9	[{"id_menu":6,"count":1}]	150	pick-up	0	9
1284	2019-03-22 07:37:20	2019-03-22	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	186	pick-up	0	24
1285	2019-03-22 07:44:35	2019-03-22	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	634	delivery	5	27
1286	2019-03-22 10:26:23	2019-03-22	12	[{"id_menu":1,"count":1}]	623	pick-up	0	12
1287	2019-03-22 10:59:12	2019-03-22	8	[{"id_menu":5,"count":1}]	735	delivery	5	13
1288	2019-03-22 11:13:26	2019-03-22	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	712	delivery	5	22
1289	2019-03-22 12:22:32	2019-03-22	12	[{"id_menu":1,"count":1}]	68	pick-up	0	12
1290	2019-03-22 13:28:04	2019-03-22	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	731	delivery	5	39
1291	2019-03-22 21:39:19	2019-03-22	9	[{"id_menu":7,"count":1}]	734	pick-up	0	9
1292	2019-03-22 21:57:27	2019-03-22	9	[{"id_menu":7,"count":1}]	638	delivery	5	14
1293	2019-03-22 22:29:15	2019-03-22	14	[{"id_menu":2,"count":1}]	271	delivery	5	19
1294	2019-03-22 23:37:33	2019-03-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	733	delivery	5	22
1295	2019-03-23 01:54:27	2019-03-23	12	[{"id_menu":1,"count":1}]	740	pick-up	0	12
1296	2019-03-23 01:54:58	2019-03-23	9	[{"id_menu":6,"count":1}]	27	pick-up	0	9
1297	2019-03-23 02:00:11	2019-03-23	9	[{"id_menu":6,"count":1}]	81	delivery	5	14
1298	2019-03-23 03:07:00	2019-03-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	21	pick-up	0	26
1299	2019-03-23 03:56:01	2019-03-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	736	delivery	5	23
1300	2019-03-23 04:53:41	2019-03-23	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	742	pick-up	0	25
1301	2019-03-23 06:21:29	2019-03-23	9	[{"id_menu":6,"count":1}]	114	pick-up	0	9
1302	2019-03-23 06:49:54	2019-03-23	8	[{"id_menu":5,"count":1}]	737	pick-up	0	8
1303	2019-03-23 06:53:32	2019-03-23	14	[{"id_menu":2,"count":2}]	147	delivery	5	19
1304	2019-03-23 08:18:35	2019-03-23	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	601	pick-up	0	38
1305	2019-03-23 08:57:22	2019-03-23	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	373	pick-up	0	22
1306	2019-03-23 10:06:59	2019-03-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	741	pick-up	0	26
1307	2019-03-23 11:55:50	2019-03-23	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	560	delivery	5	40
1308	2019-03-23 13:16:34	2019-03-23	12	[{"id_menu":3,"count":1}]	213	pick-up	0	12
1309	2019-03-23 14:56:59	2019-03-23	12	[{"id_menu":1,"count":1}]	660	delivery	5	17
1310	2019-03-23 15:31:38	2019-03-23	8	[{"id_menu":5,"count":1}]	486	pick-up	0	8
1311	2019-03-23 16:40:31	2019-03-23	9	[{"id_menu":6,"count":1}]	739	pick-up	0	9
1312	2019-03-23 17:03:15	2019-03-23	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	738	delivery	5	25
1313	2019-03-23 17:45:37	2019-03-23	9	[{"id_menu":6,"count":1}]	609	pick-up	0	9
1314	2019-03-23 17:55:04	2019-03-23	12	[{"id_menu":1,"count":1}]	209	pick-up	0	12
1315	2019-03-23 18:12:01	2019-03-23	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	398	delivery	5	57
1316	2019-03-23 22:51:36	2019-03-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	361	pick-up	0	23
1317	2019-03-24 00:05:43	2019-03-24	17	[{"id_menu":4,"count":1}]	136	pick-up	0	17
1318	2019-03-24 01:00:47	2019-03-24	14	[{"id_menu":2,"count":1}]	641	delivery	5	19
1319	2019-03-24 03:48:14	2019-03-24	12	[{"id_menu":1,"count":2}]	743	pick-up	0	12
1320	2019-03-24 05:15:50	2019-03-24	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	748	delivery	5	36
1321	2019-03-24 06:36:10	2019-03-24	8	[{"id_menu":5,"count":1}]	747	pick-up	0	8
1322	2019-03-24 07:06:06	2019-03-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	72	delivery	5	23
1323	2019-03-24 07:10:32	2019-03-24	17	[{"id_menu":4,"count":1}]	338	delivery	5	22
1324	2019-03-24 08:45:42	2019-03-24	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	711	pick-up	0	29
1325	2019-03-24 09:51:43	2019-03-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	660	delivery	5	28
1326	2019-03-24 12:05:18	2019-03-24	8	[{"id_menu":5,"count":1}]	285	pick-up	0	8
1327	2019-03-24 14:51:03	2019-03-24	14	[{"id_menu":2,"count":1}]	584	pick-up	0	14
1328	2019-03-24 15:14:45	2019-03-24	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	741	pick-up	0	29
1329	2019-03-24 15:55:55	2019-03-24	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	719	pick-up	0	24
1330	2019-03-24 16:29:11	2019-03-24	9	[{"id_menu":6,"count":1}]	745	delivery	5	14
1331	2019-03-24 17:24:54	2019-03-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	371	pick-up	0	26
1332	2019-03-24 18:35:45	2019-03-24	17	[{"id_menu":4,"count":1}]	744	pick-up	0	17
1333	2019-03-24 18:56:36	2019-03-24	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	750	delivery	5	28
1334	2019-03-24 19:39:43	2019-03-24	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	3	pick-up	0	26
1335	2019-03-24 20:53:44	2019-03-24	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	511	pick-up	0	21
1336	2019-03-24 20:58:18	2019-03-24	9	[{"id_menu":7,"count":1}]	456	delivery	5	14
1337	2019-03-24 21:21:06	2019-03-24	14	[{"id_menu":2,"count":1}]	71	delivery	5	19
1338	2019-03-24 22:32:46	2019-03-24	17	[{"id_menu":4,"count":1}]	749	pick-up	0	17
1339	2019-03-24 23:50:06	2019-03-24	12	[{"id_menu":1,"count":1}]	746	delivery	5	17
1340	2019-03-25 00:22:25	2019-03-25	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	256	pick-up	0	29
1341	2019-03-25 02:27:18	2019-03-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	44	pick-up	0	17
1342	2019-03-25 05:32:48	2019-03-25	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":2}]	123	delivery	5	31
1343	2019-03-25 05:55:28	2019-03-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	753	delivery	5	22
1344	2019-03-25 06:09:18	2019-03-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	48	pick-up	0	23
1345	2019-03-25 08:41:18	2019-03-25	17	[{"id_menu":4,"count":1}]	464	delivery	5	22
1346	2019-03-25 08:50:17	2019-03-25	8	[{"id_menu":5,"count":1}]	540	delivery	5	13
1347	2019-03-25 10:01:40	2019-03-25	12	[{"id_menu":1,"count":1}]	185	delivery	5	17
1348	2019-03-25 16:09:33	2019-03-25	14	[{"id_menu":2,"count":1}]	546	delivery	5	19
1349	2019-03-25 20:45:25	2019-03-25	14	[{"id_menu":2,"count":1}]	228	pick-up	0	14
1350	2019-03-25 21:18:53	2019-03-25	14	[{"id_menu":2,"count":2}]	295	pick-up	0	14
1351	2019-03-25 22:47:37	2019-03-25	8	[{"id_menu":5,"count":1}]	593	delivery	5	13
1352	2019-03-26 00:01:33	2019-03-26	17	[{"id_menu":4,"count":1}]	313	pick-up	0	17
1353	2019-03-26 00:47:07	2019-03-26	9	[{"id_menu":7,"count":1}]	684	delivery	5	14
1354	2019-03-26 02:07:19	2019-03-26	17	[{"id_menu":4,"count":1}]	507	delivery	5	22
1355	2019-03-26 03:52:16	2019-03-26	12	[{"id_menu":1,"count":1}]	762	pick-up	0	12
1356	2019-03-26 05:55:13	2019-03-26	14	[{"id_menu":2,"count":1}]	759	delivery	5	19
1357	2019-03-26 06:09:37	2019-03-26	8	[{"id_menu":5,"count":1}]	601	delivery	5	13
1358	2019-03-26 06:25:00	2019-03-26	12	[{"id_menu":1,"count":1}]	486	pick-up	0	12
1359	2019-03-26 07:26:34	2019-03-26	12	[{"id_menu":3,"count":1}]	760	delivery	5	17
1360	2019-03-26 08:59:00	2019-03-26	17	[{"id_menu":4,"count":1}]	643	pick-up	0	17
1361	2019-03-26 09:16:42	2019-03-26	17	[{"id_menu":4,"count":1}]	293	pick-up	0	17
1362	2019-03-26 10:20:17	2019-03-26	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	764	delivery	5	57
1363	2019-03-26 15:08:09	2019-03-26	14	[{"id_menu":2,"count":1}]	136	delivery	5	19
1364	2019-03-26 18:01:55	2019-03-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	154	pick-up	0	23
1365	2019-03-26 18:56:50	2019-03-26	8	[{"id_menu":5,"count":1}]	422	delivery	5	13
1366	2019-03-27 02:59:57	2019-03-27	12	[{"id_menu":1,"count":1}]	701	delivery	5	17
1367	2019-03-27 03:16:21	2019-03-27	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	304	pick-up	0	26
1368	2019-03-27 05:05:59	2019-03-27	14	[{"id_menu":2,"count":1}]	18	pick-up	0	14
1369	2019-03-27 05:23:07	2019-03-27	14	[{"id_menu":2,"count":1}]	767	delivery	5	19
1370	2019-03-27 07:33:56	2019-03-27	9	[{"id_menu":6,"count":1}]	105	pick-up	0	9
1371	2019-03-27 07:55:32	2019-03-27	12	[{"id_menu":3,"count":1}]	463	pick-up	0	12
1372	2019-03-27 08:22:25	2019-03-27	14	[{"id_menu":2,"count":1}]	766	pick-up	0	14
1373	2019-03-27 09:00:06	2019-03-27	17	[{"id_menu":4,"count":1}]	771	delivery	5	22
1374	2019-03-27 12:16:03	2019-03-27	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	482	delivery	5	31
1375	2019-03-27 13:09:08	2019-03-27	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	769	delivery	5	31
1376	2019-03-27 13:34:59	2019-03-27	14	[{"id_menu":2,"count":1}]	376	pick-up	0	14
1377	2019-03-27 14:10:56	2019-03-27	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	770	pick-up	0	29
1378	2019-03-27 14:19:00	2019-03-27	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	597	delivery	5	34
1379	2019-03-27 14:30:57	2019-03-27	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	390	pick-up	0	17
1380	2019-03-27 14:52:23	2019-03-27	12	[{"id_menu":1,"count":1}]	294	pick-up	0	12
1381	2019-03-27 16:27:44	2019-03-27	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	765	pick-up	0	43
1382	2019-03-27 16:32:02	2019-03-27	9	[{"id_menu":7,"count":1}]	464	pick-up	0	9
1383	2019-03-27 17:28:51	2019-03-27	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	267	pick-up	0	29
1384	2019-03-27 21:41:34	2019-03-27	14	[{"id_menu":2,"count":1}]	374	pick-up	0	14
1385	2019-03-27 21:45:10	2019-03-27	8	[{"id_menu":5,"count":1}]	408	pick-up	0	8
1386	2019-03-27 23:18:25	2019-03-27	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	491	pick-up	0	20
1387	2019-03-27 23:22:41	2019-03-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	768	delivery	5	28
1388	2019-03-27 23:40:53	2019-03-27	9	[{"id_menu":6,"count":1}]	617	pick-up	0	9
1389	2019-03-27 23:51:29	2019-03-27	17	[{"id_menu":4,"count":1}]	231	delivery	5	22
1390	2019-03-28 00:47:51	2019-03-28	9	[{"id_menu":6,"count":1}]	143	pick-up	0	9
1391	2019-03-28 01:25:49	2019-03-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	71	pick-up	0	18
1392	2019-03-28 01:29:03	2019-03-28	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	774	delivery	5	35
1393	2019-03-28 02:19:48	2019-03-28	8	[{"id_menu":5,"count":1}]	49	pick-up	0	8
1394	2019-03-28 02:26:12	2019-03-28	12	[{"id_menu":3,"count":1}]	763	pick-up	0	12
1395	2019-03-28 06:01:32	2019-03-28	9	[{"id_menu":7,"count":1}]	711	pick-up	0	9
1396	2019-03-28 06:08:10	2019-03-28	14	[{"id_menu":2,"count":1}]	377	pick-up	0	14
1397	2019-03-28 06:21:14	2019-03-28	12	[{"id_menu":1,"count":1}]	164	pick-up	0	12
1398	2019-03-28 06:49:16	2019-03-28	9	[{"id_menu":7,"count":1}]	543	pick-up	0	9
1399	2019-03-28 08:14:24	2019-03-28	14	[{"id_menu":2,"count":1}]	650	delivery	5	19
1400	2019-03-28 08:56:08	2019-03-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	363	delivery	5	28
1401	2019-03-28 09:43:42	2019-03-28	12	[{"id_menu":3,"count":1}]	776	delivery	5	17
1402	2019-03-28 10:09:06	2019-03-28	9	[{"id_menu":6,"count":1}]	257	pick-up	0	9
1403	2019-03-28 12:45:38	2019-03-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	209	pick-up	0	26
1404	2019-03-28 13:17:51	2019-03-28	12	[{"id_menu":3,"count":1}]	357	delivery	5	17
1405	2019-03-28 13:57:48	2019-03-28	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	147	pick-up	0	26
1406	2019-03-28 14:32:09	2019-03-28	9	[{"id_menu":6,"count":1}]	777	pick-up	0	9
1407	2019-03-28 15:09:07	2019-03-28	12	[{"id_menu":3,"count":1}]	772	pick-up	0	12
1408	2019-03-28 16:28:34	2019-03-28	9	[{"id_menu":7,"count":1}]	712	delivery	5	14
1409	2019-03-28 17:17:15	2019-03-28	9	[{"id_menu":6,"count":1}]	778	pick-up	0	9
1410	2019-03-28 17:25:22	2019-03-28	14	[{"id_menu":2,"count":1}]	360	pick-up	0	14
1411	2019-03-28 19:08:06	2019-03-28	14	[{"id_menu":2,"count":1}]	150	delivery	5	19
1412	2019-03-28 19:31:59	2019-03-28	17	[{"id_menu":4,"count":1}]	245	delivery	5	22
1413	2019-03-28 20:30:58	2019-03-28	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	773	delivery	5	25
1414	2019-03-28 20:57:58	2019-03-28	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	315	pick-up	0	21
1415	2019-03-28 21:02:05	2019-03-28	12	[{"id_menu":3,"count":1}]	775	pick-up	0	12
1416	2019-03-29 02:45:59	2019-03-29	14	[{"id_menu":2,"count":1}]	783	delivery	5	19
1417	2019-03-29 02:47:45	2019-03-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	57	pick-up	0	23
1418	2019-03-29 04:18:43	2019-03-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	48	delivery	5	31
1419	2019-03-29 04:53:58	2019-03-29	17	[{"id_menu":4,"count":1}]	62	pick-up	0	17
1420	2019-03-29 06:57:14	2019-03-29	12	[{"id_menu":1,"count":1}]	781	pick-up	0	12
1421	2019-03-29 10:48:54	2019-03-29	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	676	delivery	5	30
1422	2019-03-29 12:12:04	2019-03-29	14	[{"id_menu":2,"count":1}]	356	delivery	5	19
1423	2019-03-29 12:14:16	2019-03-29	14	[{"id_menu":2,"count":1}]	785	pick-up	0	14
1424	2019-03-29 13:52:34	2019-03-29	12	[{"id_menu":3,"count":1}]	39	pick-up	0	12
1425	2019-03-29 15:07:22	2019-03-29	9	[{"id_menu":6,"count":1}]	782	delivery	5	14
1426	2019-03-29 16:11:17	2019-03-29	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	786	pick-up	0	26
1427	2019-03-29 17:37:47	2019-03-29	8	[{"id_menu":5,"count":1}]	579	delivery	5	13
1428	2019-03-29 18:06:33	2019-03-29	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	623	pick-up	0	21
1429	2019-03-29 18:11:00	2019-03-29	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	346	delivery	5	43
1430	2019-03-29 19:21:54	2019-03-29	14	[{"id_menu":2,"count":1}]	135	pick-up	0	14
1431	2019-03-29 20:36:07	2019-03-29	17	[{"id_menu":4,"count":1}]	722	delivery	5	22
1432	2019-03-29 21:12:44	2019-03-29	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	477	pick-up	0	24
1433	2019-03-29 22:05:29	2019-03-29	9	[{"id_menu":6,"count":1}]	779	pick-up	0	9
1434	2019-03-30 00:29:27	2019-03-30	9	[{"id_menu":7,"count":1}]	351	pick-up	0	9
1435	2019-03-30 01:19:58	2019-03-30	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	350	pick-up	0	29
1436	2019-03-30 04:23:19	2019-03-30	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	793	pick-up	0	25
1437	2019-03-30 06:23:29	2019-03-30	8	[{"id_menu":5,"count":1}]	643	pick-up	0	8
1438	2019-03-30 10:23:48	2019-03-30	12	[{"id_menu":1,"count":1}]	574	pick-up	0	12
1439	2019-03-30 10:23:54	2019-03-30	12	[{"id_menu":1,"count":1}]	419	delivery	5	17
1440	2019-03-30 10:51:56	2019-03-30	17	[{"id_menu":4,"count":1}]	791	delivery	5	22
1441	2019-03-30 10:57:49	2019-03-30	8	[{"id_menu":5,"count":1}]	295	pick-up	0	8
1442	2019-03-30 11:21:04	2019-03-30	12	[{"id_menu":1,"count":1}]	788	pick-up	0	12
1443	2019-03-30 13:23:38	2019-03-30	12	[{"id_menu":1,"count":1}]	286	delivery	5	17
1444	2019-03-30 14:26:05	2019-03-30	9	[{"id_menu":7,"count":1}]	135	pick-up	0	9
1445	2019-03-30 15:46:01	2019-03-30	9	[{"id_menu":6,"count":1}]	789	delivery	5	14
1446	2019-03-30 16:50:24	2019-03-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	377	delivery	5	28
1447	2019-03-30 17:02:13	2019-03-30	17	[{"id_menu":4,"count":2}]	787	pick-up	0	17
1448	2019-03-30 17:19:33	2019-03-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	792	pick-up	0	26
1449	2019-03-30 18:42:56	2019-03-30	17	[{"id_menu":4,"count":1}]	340	delivery	5	22
1450	2019-03-30 19:11:25	2019-03-30	14	[{"id_menu":2,"count":1}]	794	pick-up	0	14
1451	2019-03-30 19:36:32	2019-03-30	17	[{"id_menu":4,"count":1}]	628	delivery	5	22
1452	2019-03-30 22:26:35	2019-03-30	14	[{"id_menu":2,"count":1}]	27	pick-up	0	14
1453	2019-03-30 22:27:34	2019-03-30	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	790	pick-up	0	26
1454	2019-03-30 23:03:16	2019-03-30	9	[{"id_menu":7,"count":1}]	627	pick-up	0	9
1455	2019-03-31 00:06:23	2019-03-31	12	[{"id_menu":3,"count":1}]	424	pick-up	0	12
1456	2019-03-31 00:47:59	2019-03-31	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	126	delivery	5	26
1457	2019-03-31 02:25:37	2019-03-31	14	[{"id_menu":2,"count":1}]	801	pick-up	0	14
1458	2019-03-31 03:04:11	2019-03-31	8	[{"id_menu":5,"count":1}]	784	pick-up	0	8
1459	2019-03-31 04:41:31	2019-03-31	17	[{"id_menu":4,"count":1}]	800	delivery	5	22
1460	2019-03-31 04:41:46	2019-03-31	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	647	delivery	5	43
1461	2019-03-31 04:59:13	2019-03-31	12	[{"id_menu":3,"count":1}]	449	delivery	5	17
1462	2019-03-31 06:02:53	2019-03-31	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	245	pick-up	0	40
1463	2019-03-31 08:19:57	2019-03-31	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	360	pick-up	0	29
1464	2019-03-31 08:27:04	2019-03-31	12	[{"id_menu":1,"count":1}]	293	pick-up	0	12
1465	2019-03-31 08:42:39	2019-03-31	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":3}]	706	delivery	5	27
1466	2019-03-31 09:22:41	2019-03-31	8	[{"id_menu":5,"count":1}]	795	pick-up	0	8
1467	2019-03-31 09:56:52	2019-03-31	12	[{"id_menu":3,"count":1}]	356	pick-up	0	12
1468	2019-03-31 10:52:23	2019-03-31	14	[{"id_menu":2,"count":2}]	796	delivery	5	19
1469	2019-03-31 11:07:48	2019-03-31	14	[{"id_menu":2,"count":1}]	138	pick-up	0	14
1470	2019-03-31 11:30:15	2019-03-31	14	[{"id_menu":2,"count":1}]	37	pick-up	0	14
1471	2019-03-31 12:19:04	2019-03-31	9	[{"id_menu":6,"count":1}]	618	pick-up	0	9
1472	2019-03-31 12:20:11	2019-03-31	14	[{"id_menu":2,"count":1}]	799	delivery	5	19
1473	2019-03-31 13:33:07	2019-03-31	14	[{"id_menu":2,"count":1}]	709	pick-up	0	14
1474	2019-03-31 14:45:30	2019-03-31	9	[{"id_menu":7,"count":2}]	319	pick-up	0	9
1475	2019-03-31 15:24:33	2019-03-31	9	[{"id_menu":6,"count":1}]	798	delivery	5	14
1476	2019-03-31 15:41:00	2019-03-31	14	[{"id_menu":2,"count":1}]	351	pick-up	0	14
1477	2019-03-31 15:57:31	2019-03-31	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	797	delivery	5	25
1478	2019-03-31 16:14:23	2019-03-31	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	229	delivery	5	26
1479	2019-03-31 16:19:36	2019-03-31	9	[{"id_menu":7,"count":1}]	802	pick-up	0	9
1480	2019-03-31 17:17:28	2019-03-31	8	[{"id_menu":5,"count":1}]	296	pick-up	0	8
1481	2019-03-31 17:31:11	2019-03-31	12	[{"id_menu":3,"count":1}]	122	delivery	5	17
1482	2019-03-31 17:32:04	2019-03-31	8	[{"id_menu":5,"count":1}]	470	delivery	5	13
1483	2019-03-31 19:49:07	2019-03-31	12	[{"id_menu":1,"count":1}]	62	pick-up	0	12
1484	2019-03-31 20:17:11	2019-03-31	14	[{"id_menu":2,"count":1}]	111	delivery	5	19
1485	2019-03-31 20:36:05	2019-03-31	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	340	delivery	5	34
1486	2019-03-31 20:42:40	2019-03-31	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	376	pick-up	0	43
1487	2019-03-31 21:14:12	2019-03-31	14	[{"id_menu":2,"count":1}]	34	pick-up	0	14
1488	2019-03-31 22:13:17	2019-03-31	12	[{"id_menu":3,"count":2}]	92	pick-up	0	12
1489	2019-03-31 22:41:13	2019-03-31	8	[{"id_menu":5,"count":3}]	585	delivery	5	13
1490	2019-04-01 04:37:45	2019-04-01	17	[{"id_menu":4,"count":1}]	806	pick-up	0	17
1491	2019-04-01 08:37:26	2019-04-01	17	[{"id_menu":4,"count":1}]	111	pick-up	0	17
1492	2019-04-01 09:09:30	2019-04-01	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	177	pick-up	0	21
1493	2019-04-01 09:52:37	2019-04-01	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	807	pick-up	0	29
1494	2019-04-01 13:19:53	2019-04-01	17	[{"id_menu":4,"count":1}]	803	pick-up	0	17
1495	2019-04-01 13:39:36	2019-04-01	8	[{"id_menu":5,"count":1}]	634	pick-up	0	8
1496	2019-04-01 14:40:07	2019-04-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	666	pick-up	0	26
1497	2019-04-01 15:34:18	2019-04-01	14	[{"id_menu":2,"count":1}]	690	pick-up	0	14
1498	2019-04-01 16:10:09	2019-04-01	14	[{"id_menu":2,"count":2}]	477	pick-up	0	14
1499	2019-04-01 19:15:56	2019-04-01	12	[{"id_menu":1,"count":1}]	620	delivery	5	17
1500	2019-04-01 19:55:45	2019-04-01	9	[{"id_menu":6,"count":1}]	604	delivery	5	14
1501	2019-04-01 19:56:41	2019-04-01	12	[{"id_menu":3,"count":1}]	684	delivery	5	17
1502	2019-04-01 23:15:40	2019-04-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	709	pick-up	0	21
1503	2019-04-02 01:53:10	2019-04-02	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":2}]	816	delivery	5	26
1504	2019-04-02 04:14:00	2019-04-02	14	[{"id_menu":2,"count":1}]	227	delivery	5	19
1505	2019-04-02 05:10:21	2019-04-02	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	749	pick-up	0	40
1506	2019-04-02 08:20:27	2019-04-02	9	[{"id_menu":7,"count":1}]	813	delivery	5	14
1507	2019-04-02 10:48:37	2019-04-02	17	[{"id_menu":4,"count":1}]	585	delivery	5	22
1508	2019-04-02 11:38:34	2019-04-02	17	[{"id_menu":4,"count":1}]	283	pick-up	0	17
1509	2019-04-02 13:38:53	2019-04-02	9	[{"id_menu":7,"count":1}]	811	pick-up	0	9
1510	2019-04-02 14:35:56	2019-04-02	12	[{"id_menu":3,"count":1}]	173	pick-up	0	12
1511	2019-04-02 15:36:46	2019-04-02	14	[{"id_menu":2,"count":1}]	814	delivery	5	19
1512	2019-04-02 17:01:33	2019-04-02	14	[{"id_menu":2,"count":1}]	519	pick-up	0	14
1513	2019-04-02 18:57:35	2019-04-02	17	[{"id_menu":4,"count":1}]	815	pick-up	0	17
1514	2019-04-02 20:58:37	2019-04-02	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	812	delivery	5	31
1515	2019-04-03 02:28:47	2019-04-03	14	[{"id_menu":2,"count":2}]	765	pick-up	0	14
1516	2019-04-03 05:28:58	2019-04-03	8	[{"id_menu":5,"count":1}]	575	pick-up	0	8
1517	2019-04-03 07:19:38	2019-04-03	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	823	delivery	5	37
1518	2019-04-03 08:36:17	2019-04-03	12	[{"id_menu":1,"count":1}]	123	pick-up	0	12
1519	2019-04-03 09:13:08	2019-04-03	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	310	delivery	5	31
1520	2019-04-03 10:40:12	2019-04-03	14	[{"id_menu":2,"count":1}]	293	pick-up	0	14
1521	2019-04-03 12:03:33	2019-04-03	9	[{"id_menu":6,"count":1}]	729	pick-up	0	9
1522	2019-04-03 13:46:10	2019-04-03	14	[{"id_menu":2,"count":1}]	820	pick-up	0	14
1523	2019-04-03 14:03:40	2019-04-03	14	[{"id_menu":2,"count":1}]	819	delivery	5	19
1524	2019-04-03 15:22:36	2019-04-03	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	713	delivery	5	35
1525	2019-04-03 15:54:29	2019-04-03	8	[{"id_menu":5,"count":1}]	818	delivery	5	13
1526	2019-04-03 15:59:13	2019-04-03	9	[{"id_menu":6,"count":1}]	825	delivery	5	14
1527	2019-04-03 16:51:43	2019-04-03	12	[{"id_menu":1,"count":1}]	821	pick-up	0	12
1528	2019-04-03 20:15:07	2019-04-03	9	[{"id_menu":6,"count":1}]	824	delivery	5	14
1529	2019-04-03 20:25:29	2019-04-03	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	822	pick-up	0	29
1530	2019-04-03 21:35:14	2019-04-03	14	[{"id_menu":2,"count":2}]	2	pick-up	0	14
1531	2019-04-04 02:47:42	2019-04-04	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	826	pick-up	0	31
1532	2019-04-04 02:49:54	2019-04-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	831	delivery	5	28
1533	2019-04-04 04:01:13	2019-04-04	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	482	delivery	5	22
1534	2019-04-04 04:22:40	2019-04-04	17	[{"id_menu":4,"count":1}]	315	pick-up	0	17
1535	2019-04-04 05:10:27	2019-04-04	17	[{"id_menu":4,"count":1}]	640	delivery	5	22
1536	2019-04-04 06:51:50	2019-04-04	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	308	delivery	5	31
1537	2019-04-04 07:15:16	2019-04-04	9	[{"id_menu":7,"count":1}]	267	pick-up	0	9
1538	2019-04-04 07:22:57	2019-04-04	9	[{"id_menu":6,"count":1}]	522	pick-up	0	9
1539	2019-04-04 08:17:46	2019-04-04	9	[{"id_menu":7,"count":1}]	601	pick-up	0	9
1540	2019-04-04 09:23:14	2019-04-04	8	[{"id_menu":5,"count":1}]	260	pick-up	0	8
1541	2019-04-04 09:40:37	2019-04-04	8	[{"id_menu":5,"count":1}]	832	pick-up	0	8
1542	2019-04-04 09:44:54	2019-04-04	14	[{"id_menu":2,"count":1}]	381	pick-up	0	14
1543	2019-04-04 10:57:18	2019-04-04	17	[{"id_menu":4,"count":1}]	46	pick-up	0	17
1544	2019-04-04 12:44:47	2019-04-04	14	[{"id_menu":2,"count":1}]	464	pick-up	0	14
1545	2019-04-04 13:15:30	2019-04-04	9	[{"id_menu":7,"count":1}]	821	pick-up	0	9
1546	2019-04-04 15:10:08	2019-04-04	9	[{"id_menu":6,"count":1}]	80	delivery	5	14
1547	2019-04-04 16:26:13	2019-04-04	9	[{"id_menu":6,"count":1}]	529	pick-up	0	9
1548	2019-04-04 17:05:37	2019-04-04	12	[{"id_menu":1,"count":1}]	53	pick-up	0	12
1549	2019-04-04 17:11:37	2019-04-04	17	[{"id_menu":4,"count":1}]	827	pick-up	0	17
1550	2019-04-04 18:27:36	2019-04-04	8	[{"id_menu":5,"count":1}]	829	pick-up	0	8
1551	2019-04-04 18:47:39	2019-04-04	8	[{"id_menu":5,"count":1}]	812	delivery	5	13
1552	2019-04-04 19:28:27	2019-04-04	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	613	pick-up	0	22
1553	2019-04-04 19:34:51	2019-04-04	14	[{"id_menu":2,"count":1}]	537	delivery	5	19
1554	2019-04-04 20:16:43	2019-04-04	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	802	pick-up	0	26
1555	2019-04-04 20:45:31	2019-04-04	9	[{"id_menu":7,"count":1}]	630	pick-up	0	9
1556	2019-04-05 00:41:26	2019-04-05	8	[{"id_menu":5,"count":1}]	840	delivery	5	13
1557	2019-04-05 03:10:04	2019-04-05	14	[{"id_menu":2,"count":1}]	833	pick-up	0	14
1558	2019-04-05 05:01:40	2019-04-05	12	[{"id_menu":1,"count":1}]	820	pick-up	0	12
1559	2019-04-05 07:22:25	2019-04-05	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	438	delivery	5	45
1560	2019-04-05 08:48:56	2019-04-05	8	[{"id_menu":5,"count":1}]	177	delivery	5	13
1561	2019-04-05 11:15:17	2019-04-05	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	313	delivery	5	34
1562	2019-04-05 11:56:36	2019-04-05	12	[{"id_menu":3,"count":1}]	92	delivery	5	17
1563	2019-04-05 12:38:56	2019-04-05	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	838	delivery	5	40
1564	2019-04-05 13:13:16	2019-04-05	14	[{"id_menu":2,"count":1}]	456	pick-up	0	14
1565	2019-04-05 15:03:30	2019-04-05	17	[{"id_menu":4,"count":1}]	232	pick-up	0	17
1566	2019-04-05 15:21:43	2019-04-05	12	[{"id_menu":3,"count":1}]	759	pick-up	0	12
1567	2019-04-05 15:46:34	2019-04-05	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	126	pick-up	0	31
1568	2019-04-05 16:23:08	2019-04-05	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	721	pick-up	0	21
1569	2019-04-05 19:35:49	2019-04-05	9	[{"id_menu":6,"count":1}]	439	pick-up	0	9
1570	2019-04-05 19:50:38	2019-04-05	17	[{"id_menu":4,"count":1}]	541	pick-up	0	17
1571	2019-04-05 21:27:25	2019-04-05	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	837	pick-up	0	26
1572	2019-04-05 21:33:51	2019-04-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	834	pick-up	0	18
1573	2019-04-05 22:42:22	2019-04-05	14	[{"id_menu":2,"count":1}]	235	pick-up	0	14
1574	2019-04-05 23:04:04	2019-04-05	12	[{"id_menu":1,"count":1}]	260	pick-up	0	12
1575	2019-04-05 23:17:42	2019-04-05	17	[{"id_menu":4,"count":1}]	660	pick-up	0	17
1576	2019-04-06 00:09:41	2019-04-06	12	[{"id_menu":1,"count":1}]	844	delivery	5	17
1577	2019-04-06 00:10:04	2019-04-06	9	[{"id_menu":7,"count":1}]	153	pick-up	0	9
1578	2019-04-06 00:20:45	2019-04-06	17	[{"id_menu":4,"count":1}]	848	pick-up	0	17
1579	2019-04-06 01:18:05	2019-04-06	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	677	delivery	5	37
1580	2019-04-06 01:41:12	2019-04-06	9	[{"id_menu":6,"count":1}]	417	pick-up	0	9
1581	2019-04-06 02:38:56	2019-04-06	9	[{"id_menu":6,"count":1}]	709	pick-up	0	9
1582	2019-04-06 03:12:30	2019-04-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	779	pick-up	0	23
1583	2019-04-06 03:31:52	2019-04-06	12	[{"id_menu":1,"count":1}]	50	pick-up	0	12
1584	2019-04-06 04:06:11	2019-04-06	14	[{"id_menu":2,"count":1}]	843	pick-up	0	14
1585	2019-04-06 06:26:22	2019-04-06	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	193	pick-up	0	22
1586	2019-04-06 08:03:07	2019-04-06	9	[{"id_menu":6,"count":1}]	448	delivery	5	14
1587	2019-04-06 08:13:40	2019-04-06	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	729	pick-up	0	38
1588	2019-04-06 08:20:24	2019-04-06	17	[{"id_menu":4,"count":2}]	654	pick-up	0	17
1589	2019-04-06 08:58:09	2019-04-06	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	157	pick-up	0	34
1590	2019-04-06 09:41:14	2019-04-06	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	123	pick-up	0	31
1591	2019-04-06 09:46:38	2019-04-06	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	847	delivery	5	29
1592	2019-04-06 10:52:28	2019-04-06	9	[{"id_menu":6,"count":2}]	66	pick-up	0	9
1593	2019-04-06 12:21:32	2019-04-06	14	[{"id_menu":2,"count":2}]	842	pick-up	0	14
1594	2019-04-06 12:22:46	2019-04-06	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	751	pick-up	0	34
1595	2019-04-06 13:37:28	2019-04-06	9	[{"id_menu":6,"count":1}]	382	pick-up	0	9
1596	2019-04-06 14:09:22	2019-04-06	17	[{"id_menu":4,"count":1}]	169	pick-up	0	17
1597	2019-04-06 14:53:22	2019-04-06	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	396	pick-up	0	25
1598	2019-04-06 17:06:15	2019-04-06	14	[{"id_menu":2,"count":2}]	845	delivery	5	19
1599	2019-04-06 19:26:07	2019-04-06	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	756	delivery	5	29
1600	2019-04-06 19:36:49	2019-04-06	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	846	pick-up	0	29
1601	2019-04-06 19:50:15	2019-04-06	9	[{"id_menu":6,"count":2}]	229	delivery	5	14
1602	2019-04-06 20:49:18	2019-04-06	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	143	delivery	5	48
1603	2019-04-06 20:56:58	2019-04-06	17	[{"id_menu":4,"count":1}]	849	delivery	5	22
1604	2019-04-06 22:11:02	2019-04-06	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	154	delivery	5	42
1605	2019-04-06 23:15:07	2019-04-06	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	332	pick-up	0	38
1606	2019-04-06 23:43:14	2019-04-06	14	[{"id_menu":2,"count":1}]	182	pick-up	0	14
1607	2019-04-07 00:05:11	2019-04-07	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	337	delivery	5	25
1608	2019-04-07 00:22:26	2019-04-07	9	[{"id_menu":7,"count":1}]	396	pick-up	0	9
1609	2019-04-07 01:36:26	2019-04-07	12	[{"id_menu":3,"count":2}]	850	pick-up	0	12
1610	2019-04-07 02:39:12	2019-04-07	17	[{"id_menu":4,"count":1}]	612	pick-up	0	17
1611	2019-04-07 02:51:29	2019-04-07	9	[{"id_menu":6,"count":1}]	855	pick-up	0	9
1612	2019-04-07 03:26:28	2019-04-07	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	97	pick-up	0	26
1613	2019-04-07 03:40:18	2019-04-07	14	[{"id_menu":2,"count":1}]	381	delivery	5	19
1614	2019-04-07 05:23:14	2019-04-07	12	[{"id_menu":3,"count":1}]	278	pick-up	0	12
1615	2019-04-07 05:30:15	2019-04-07	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	383	delivery	5	27
1616	2019-04-07 08:23:32	2019-04-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	203	delivery	5	23
1617	2019-04-07 11:47:24	2019-04-07	9	[{"id_menu":7,"count":1}]	626	delivery	5	14
1618	2019-04-07 12:12:16	2019-04-07	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	439	pick-up	0	31
1619	2019-04-07 13:44:40	2019-04-07	9	[{"id_menu":6,"count":1}]	857	delivery	5	14
1620	2019-04-07 13:52:43	2019-04-07	9	[{"id_menu":7,"count":1}]	707	delivery	5	14
1621	2019-04-07 14:36:37	2019-04-07	14	[{"id_menu":2,"count":1}]	404	delivery	5	19
1622	2019-04-07 14:36:52	2019-04-07	12	[{"id_menu":3,"count":1}]	215	pick-up	0	12
1623	2019-04-07 15:31:23	2019-04-07	14	[{"id_menu":2,"count":1}]	584	pick-up	0	14
1624	2019-04-07 15:57:32	2019-04-07	8	[{"id_menu":5,"count":1}]	150	pick-up	0	8
1625	2019-04-07 16:28:35	2019-04-07	9	[{"id_menu":7,"count":2}]	489	pick-up	0	9
1626	2019-04-07 16:57:32	2019-04-07	12	[{"id_menu":3,"count":1}]	317	delivery	5	17
1627	2019-04-07 17:55:10	2019-04-07	12	[{"id_menu":1,"count":1}]	74	delivery	5	17
1628	2019-04-07 19:03:09	2019-04-07	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	856	pick-up	0	38
1629	2019-04-07 19:12:23	2019-04-07	17	[{"id_menu":4,"count":1}]	232	delivery	5	22
1630	2019-04-07 19:37:17	2019-04-07	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	851	delivery	5	34
1631	2019-04-07 20:20:06	2019-04-07	14	[{"id_menu":2,"count":1}]	854	pick-up	0	14
1632	2019-04-07 21:02:55	2019-04-07	9	[{"id_menu":6,"count":1}]	853	delivery	5	14
1633	2019-04-07 21:39:12	2019-04-07	9	[{"id_menu":6,"count":1}]	765	delivery	5	14
1634	2019-04-07 21:57:53	2019-04-07	9	[{"id_menu":7,"count":1}]	586	delivery	5	14
1635	2019-04-07 22:19:12	2019-04-07	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	640	pick-up	0	26
1636	2019-04-07 22:55:02	2019-04-07	8	[{"id_menu":5,"count":1}]	852	delivery	5	13
1637	2019-04-08 04:01:43	2019-04-08	17	[{"id_menu":4,"count":1}]	16	pick-up	0	17
1638	2019-04-08 05:16:26	2019-04-08	12	[{"id_menu":1,"count":1}]	689	delivery	5	17
1639	2019-04-08 10:08:13	2019-04-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	561	delivery	5	22
1640	2019-04-08 10:54:13	2019-04-08	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	863	delivery	5	42
1641	2019-04-08 13:01:03	2019-04-08	14	[{"id_menu":2,"count":1}]	861	delivery	5	19
1642	2019-04-08 13:31:59	2019-04-08	12	[{"id_menu":1,"count":1}]	860	delivery	5	17
1643	2019-04-08 15:21:23	2019-04-08	12	[{"id_menu":1,"count":1}]	859	pick-up	0	12
1644	2019-04-08 15:34:06	2019-04-08	9	[{"id_menu":7,"count":1}]	248	pick-up	0	9
1645	2019-04-08 16:03:25	2019-04-08	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	684	delivery	5	30
1646	2019-04-08 19:30:47	2019-04-08	9	[{"id_menu":6,"count":1}]	27	pick-up	0	9
1647	2019-04-08 23:03:22	2019-04-08	9	[{"id_menu":7,"count":1}]	268	pick-up	0	9
1648	2019-04-09 00:28:23	2019-04-09	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":3}]	99	pick-up	0	21
1649	2019-04-09 00:39:32	2019-04-09	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	601	pick-up	0	25
1650	2019-04-09 04:17:38	2019-04-09	14	[{"id_menu":2,"count":1}]	281	delivery	5	19
1651	2019-04-09 04:22:45	2019-04-09	9	[{"id_menu":6,"count":1}]	288	delivery	5	14
1652	2019-04-09 10:36:48	2019-04-09	14	[{"id_menu":2,"count":1}]	41	pick-up	0	14
1653	2019-04-09 11:39:57	2019-04-09	17	[{"id_menu":4,"count":1}]	102	pick-up	0	17
1654	2019-04-09 11:45:03	2019-04-09	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	519	pick-up	0	20
1655	2019-04-09 16:15:31	2019-04-09	9	[{"id_menu":6,"count":1}]	870	delivery	5	14
1656	2019-04-09 17:13:10	2019-04-09	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	708	pick-up	0	29
1657	2019-04-09 17:44:04	2019-04-09	14	[{"id_menu":2,"count":1}]	265	delivery	5	19
1658	2019-04-09 18:01:42	2019-04-09	9	[{"id_menu":7,"count":2}]	81	pick-up	0	9
1659	2019-04-09 19:27:11	2019-04-09	17	[{"id_menu":4,"count":1}]	784	delivery	5	22
1660	2019-04-09 20:06:37	2019-04-09	14	[{"id_menu":2,"count":1}]	869	pick-up	0	14
1661	2019-04-09 20:16:17	2019-04-09	12	[{"id_menu":1,"count":1}]	172	pick-up	0	12
1662	2019-04-09 21:47:58	2019-04-09	12	[{"id_menu":1,"count":1}]	228	delivery	5	17
1663	2019-04-09 22:25:47	2019-04-09	14	[{"id_menu":2,"count":2}]	37	pick-up	0	14
1664	2019-04-09 22:37:59	2019-04-09	9	[{"id_menu":7,"count":1}]	868	pick-up	0	9
1665	2019-04-09 22:41:32	2019-04-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	731	delivery	5	22
1666	2019-04-10 00:31:04	2019-04-10	17	[{"id_menu":4,"count":2}]	875	delivery	5	22
1667	2019-04-10 07:22:30	2019-04-10	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	879	pick-up	0	26
1668	2019-04-10 07:38:37	2019-04-10	9	[{"id_menu":7,"count":1}]	876	delivery	5	14
1669	2019-04-10 09:18:46	2019-04-10	14	[{"id_menu":2,"count":1}]	874	delivery	5	19
1670	2019-04-10 11:18:53	2019-04-10	14	[{"id_menu":2,"count":1}]	872	pick-up	0	14
1671	2019-04-10 14:56:00	2019-04-10	14	[{"id_menu":2,"count":1}]	168	pick-up	0	14
1672	2019-04-10 15:56:13	2019-04-10	9	[{"id_menu":6,"count":1}]	528	delivery	5	14
1673	2019-04-10 16:22:48	2019-04-10	9	[{"id_menu":6,"count":1}]	126	pick-up	0	9
1674	2019-04-10 16:29:01	2019-04-10	12	[{"id_menu":1,"count":1}]	866	pick-up	0	12
1675	2019-04-10 18:15:57	2019-04-10	17	[{"id_menu":4,"count":1}]	340	delivery	5	22
1676	2019-04-10 18:19:39	2019-04-10	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	204	pick-up	0	41
1677	2019-04-10 20:33:46	2019-04-10	9	[{"id_menu":7,"count":1}]	873	delivery	5	14
1678	2019-04-10 20:56:34	2019-04-10	17	[{"id_menu":4,"count":1}]	877	pick-up	0	17
1679	2019-04-10 21:12:05	2019-04-10	8	[{"id_menu":5,"count":1}]	424	pick-up	0	8
1680	2019-04-10 23:08:15	2019-04-10	17	[{"id_menu":4,"count":1}]	408	pick-up	0	17
1681	2019-04-10 23:32:26	2019-04-10	17	[{"id_menu":4,"count":1}]	593	pick-up	0	17
1682	2019-04-10 23:40:06	2019-04-10	12	[{"id_menu":3,"count":2}]	499	delivery	5	17
1683	2019-04-10 23:55:12	2019-04-10	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	425	delivery	5	57
1684	2019-04-11 00:52:20	2019-04-11	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	884	pick-up	0	21
1685	2019-04-11 03:05:02	2019-04-11	9	[{"id_menu":6,"count":1}]	881	pick-up	0	9
1686	2019-04-11 03:26:56	2019-04-11	12	[{"id_menu":3,"count":1}]	883	delivery	5	17
1687	2019-04-11 05:55:52	2019-04-11	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	871	delivery	5	38
1688	2019-04-11 06:32:56	2019-04-11	9	[{"id_menu":6,"count":1}]	528	delivery	5	14
1689	2019-04-11 07:52:23	2019-04-11	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	880	delivery	5	37
1690	2019-04-11 08:56:45	2019-04-11	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	887	delivery	5	22
1691	2019-04-11 09:05:41	2019-04-11	14	[{"id_menu":2,"count":1}]	320	pick-up	0	14
1692	2019-04-11 15:18:51	2019-04-11	12	[{"id_menu":1,"count":1}]	882	pick-up	0	12
1693	2019-04-11 15:31:45	2019-04-11	9	[{"id_menu":7,"count":1}]	802	delivery	5	14
1694	2019-04-11 15:52:06	2019-04-11	9	[{"id_menu":7,"count":1}]	487	delivery	5	14
1695	2019-04-11 17:43:38	2019-04-11	12	[{"id_menu":1,"count":1}]	29	delivery	5	17
1696	2019-04-11 19:09:50	2019-04-11	14	[{"id_menu":2,"count":1}]	655	pick-up	0	14
1697	2019-04-11 19:39:35	2019-04-11	8	[{"id_menu":5,"count":1}]	886	delivery	5	13
1698	2019-04-11 19:50:10	2019-04-11	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	806	pick-up	0	20
1699	2019-04-11 19:52:13	2019-04-11	12	[{"id_menu":1,"count":1}]	555	delivery	5	17
1700	2019-04-11 20:53:06	2019-04-11	9	[{"id_menu":6,"count":1}]	355	pick-up	0	9
1701	2019-04-11 21:07:19	2019-04-11	17	[{"id_menu":4,"count":1}]	885	delivery	5	22
1702	2019-04-11 21:43:28	2019-04-11	14	[{"id_menu":2,"count":1}]	790	delivery	5	19
1703	2019-04-12 00:08:17	2019-04-12	12	[{"id_menu":3,"count":1}]	536	pick-up	0	12
1704	2019-04-12 00:53:39	2019-04-12	9	[{"id_menu":7,"count":1}]	389	pick-up	0	9
1705	2019-04-12 01:29:04	2019-04-12	9	[{"id_menu":6,"count":1}]	868	pick-up	0	9
1706	2019-04-12 02:21:01	2019-04-12	17	[{"id_menu":4,"count":1}]	246	delivery	5	22
1707	2019-04-12 03:17:01	2019-04-12	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	66	pick-up	0	20
1708	2019-04-12 04:52:02	2019-04-12	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	891	pick-up	0	21
1709	2019-04-12 07:10:56	2019-04-12	8	[{"id_menu":5,"count":1}]	892	delivery	5	13
1710	2019-04-12 07:15:23	2019-04-12	12	[{"id_menu":3,"count":1}]	866	pick-up	0	12
1711	2019-04-12 07:52:22	2019-04-12	8	[{"id_menu":5,"count":1}]	29	pick-up	0	8
1712	2019-04-12 07:52:52	2019-04-12	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	140	pick-up	0	31
1713	2019-04-12 10:04:21	2019-04-12	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	895	delivery	5	31
1714	2019-04-12 12:13:38	2019-04-12	17	[{"id_menu":4,"count":1}]	193	pick-up	0	17
1715	2019-04-12 12:28:41	2019-04-12	17	[{"id_menu":4,"count":1}]	623	delivery	5	22
1716	2019-04-12 12:39:11	2019-04-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	896	pick-up	0	23
1717	2019-04-12 19:26:36	2019-04-12	14	[{"id_menu":2,"count":1}]	894	pick-up	0	14
1718	2019-04-12 19:41:09	2019-04-12	9	[{"id_menu":7,"count":1}]	92	pick-up	0	9
1719	2019-04-12 21:32:23	2019-04-12	8	[{"id_menu":5,"count":1}]	819	delivery	5	13
1720	2019-04-12 22:02:40	2019-04-12	17	[{"id_menu":4,"count":1}]	377	delivery	5	22
1721	2019-04-12 22:45:23	2019-04-12	9	[{"id_menu":6,"count":1}]	601	pick-up	0	9
1722	2019-04-12 23:46:37	2019-04-12	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	889	delivery	5	34
1723	2019-04-13 00:44:41	2019-04-13	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	64	delivery	5	39
1724	2019-04-13 01:26:21	2019-04-13	12	[{"id_menu":1,"count":1}]	80	delivery	5	17
1725	2019-04-13 03:32:20	2019-04-13	17	[{"id_menu":4,"count":1}]	900	pick-up	0	17
1726	2019-04-13 05:01:20	2019-04-13	14	[{"id_menu":2,"count":1}]	898	pick-up	0	14
1727	2019-04-13 05:03:16	2019-04-13	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	414	pick-up	0	29
1728	2019-04-13 05:52:13	2019-04-13	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	612	pick-up	0	24
1729	2019-04-13 06:59:04	2019-04-13	12	[{"id_menu":1,"count":1}]	172	pick-up	0	12
1730	2019-04-13 07:31:24	2019-04-13	14	[{"id_menu":2,"count":1}]	639	delivery	5	19
1731	2019-04-13 08:01:23	2019-04-13	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	902	delivery	5	34
1732	2019-04-13 08:42:01	2019-04-13	34	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	493	delivery	5	39
1733	2019-04-13 09:02:14	2019-04-13	17	[{"id_menu":4,"count":1}]	552	pick-up	0	17
1734	2019-04-13 09:43:50	2019-04-13	17	[{"id_menu":4,"count":1}]	135	pick-up	0	17
1735	2019-04-13 11:23:49	2019-04-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	901	pick-up	0	18
1736	2019-04-13 11:27:31	2019-04-13	9	[{"id_menu":7,"count":1}]	719	pick-up	0	9
1737	2019-04-13 12:02:52	2019-04-13	9	[{"id_menu":6,"count":1}]	744	pick-up	0	9
1738	2019-04-13 12:18:14	2019-04-13	12	[{"id_menu":3,"count":1}]	547	pick-up	0	12
1739	2019-04-13 12:53:19	2019-04-13	9	[{"id_menu":7,"count":1}]	885	delivery	5	14
1740	2019-04-13 14:00:01	2019-04-13	14	[{"id_menu":2,"count":1}]	120	pick-up	0	14
1741	2019-04-13 14:42:32	2019-04-13	14	[{"id_menu":2,"count":2}]	899	pick-up	0	14
1742	2019-04-13 15:06:28	2019-04-13	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	638	pick-up	0	21
1743	2019-04-13 17:30:34	2019-04-13	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	19	delivery	5	25
1744	2019-04-13 18:04:51	2019-04-13	12	[{"id_menu":3,"count":1}]	904	delivery	5	17
1745	2019-04-13 19:54:24	2019-04-13	9	[{"id_menu":6,"count":1}]	495	delivery	5	14
1746	2019-04-14 00:20:06	2019-04-14	12	[{"id_menu":3,"count":1}]	833	delivery	5	17
1747	2019-04-14 00:31:32	2019-04-14	12	[{"id_menu":3,"count":1}]	906	delivery	5	17
1748	2019-04-14 01:37:26	2019-04-14	12	[{"id_menu":3,"count":1}]	37	delivery	5	17
1749	2019-04-14 01:58:05	2019-04-14	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	719	pick-up	0	29
1750	2019-04-14 02:04:58	2019-04-14	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	913	delivery	5	28
1751	2019-04-14 02:18:26	2019-04-14	17	[{"id_menu":4,"count":1}]	541	delivery	5	22
1752	2019-04-14 02:35:27	2019-04-14	9	[{"id_menu":6,"count":1}]	226	pick-up	0	9
1753	2019-04-14 04:23:27	2019-04-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	677	pick-up	0	31
1754	2019-04-14 04:45:49	2019-04-14	8	[{"id_menu":5,"count":1}]	383	delivery	5	13
1755	2019-04-14 05:02:51	2019-04-14	9	[{"id_menu":6,"count":1}]	572	delivery	5	14
1756	2019-04-14 05:09:53	2019-04-14	9	[{"id_menu":6,"count":1}]	909	delivery	5	14
1757	2019-04-14 06:03:17	2019-04-14	9	[{"id_menu":6,"count":1}]	763	pick-up	0	9
1758	2019-04-14 06:06:37	2019-04-14	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	876	delivery	5	28
1759	2019-04-14 06:47:54	2019-04-14	9	[{"id_menu":6,"count":1}]	223	delivery	5	14
1760	2019-04-14 07:09:21	2019-04-14	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	911	pick-up	0	20
1761	2019-04-14 08:26:52	2019-04-14	12	[{"id_menu":3,"count":2}]	801	pick-up	0	12
1762	2019-04-14 10:20:51	2019-04-14	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	626	pick-up	0	26
1763	2019-04-14 10:30:20	2019-04-14	12	[{"id_menu":1,"count":1}]	261	pick-up	0	12
1764	2019-04-14 10:49:37	2019-04-14	17	[{"id_menu":4,"count":1}]	822	pick-up	0	17
1765	2019-04-14 11:58:01	2019-04-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	905	pick-up	0	26
1766	2019-04-14 12:26:10	2019-04-14	14	[{"id_menu":2,"count":1}]	707	pick-up	0	14
1767	2019-04-14 12:51:52	2019-04-14	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	524	pick-up	0	21
1768	2019-04-14 13:56:07	2019-04-14	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	837	delivery	5	28
1769	2019-04-14 14:57:45	2019-04-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	150	pick-up	0	31
1770	2019-04-14 15:04:53	2019-04-14	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	912	delivery	5	29
1771	2019-04-14 15:51:46	2019-04-14	17	[{"id_menu":4,"count":1}]	904	delivery	5	22
1772	2019-04-14 16:01:13	2019-04-14	14	[{"id_menu":2,"count":2}]	848	pick-up	0	14
1773	2019-04-14 16:11:22	2019-04-14	12	[{"id_menu":1,"count":1}]	910	pick-up	0	12
1774	2019-04-14 16:59:32	2019-04-14	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	907	delivery	5	26
1775	2019-04-14 18:25:19	2019-04-14	8	[{"id_menu":5,"count":1}]	411	pick-up	0	8
1776	2019-04-14 20:24:10	2019-04-14	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	659	delivery	5	36
1777	2019-04-14 21:05:30	2019-04-14	14	[{"id_menu":2,"count":1}]	638	pick-up	0	14
1778	2019-04-14 21:08:57	2019-04-14	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	520	pick-up	0	30
1779	2019-04-14 21:35:37	2019-04-14	9	[{"id_menu":7,"count":1}]	908	pick-up	0	9
1780	2019-04-14 21:54:38	2019-04-14	17	[{"id_menu":4,"count":1}]	691	delivery	5	22
1781	2019-04-14 21:54:43	2019-04-14	17	[{"id_menu":4,"count":1}]	655	pick-up	0	17
1782	2019-04-14 23:21:18	2019-04-14	14	[{"id_menu":2,"count":1}]	406	pick-up	0	14
1783	2019-04-14 23:34:09	2019-04-14	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	236	delivery	5	25
1784	2019-04-15 02:34:27	2019-04-15	17	[{"id_menu":4,"count":1}]	161	pick-up	0	17
1785	2019-04-15 06:02:46	2019-04-15	9	[{"id_menu":6,"count":1}]	44	pick-up	0	9
1786	2019-04-15 06:12:35	2019-04-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	709	pick-up	0	26
1787	2019-04-15 07:00:13	2019-04-15	12	[{"id_menu":1,"count":1}]	914	delivery	5	17
1788	2019-04-15 07:23:59	2019-04-15	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	707	pick-up	0	29
1789	2019-04-15 07:38:47	2019-04-15	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	113	pick-up	0	29
1790	2019-04-15 09:20:09	2019-04-15	14	[{"id_menu":2,"count":1}]	916	delivery	5	19
1791	2019-04-15 09:26:18	2019-04-15	17	[{"id_menu":4,"count":1}]	919	delivery	5	22
1792	2019-04-15 09:48:30	2019-04-15	12	[{"id_menu":3,"count":1}]	915	delivery	5	17
1793	2019-04-15 09:50:28	2019-04-15	14	[{"id_menu":2,"count":1}]	917	delivery	5	19
1794	2019-04-15 10:30:42	2019-04-15	12	[{"id_menu":1,"count":1}]	530	pick-up	0	12
1795	2019-04-15 10:33:03	2019-04-15	17	[{"id_menu":4,"count":1}]	141	pick-up	0	17
1796	2019-04-15 11:23:07	2019-04-15	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	920	delivery	5	31
1797	2019-04-15 11:23:34	2019-04-15	8	[{"id_menu":5,"count":3}]	921	delivery	5	13
1798	2019-04-15 13:28:33	2019-04-15	14	[{"id_menu":2,"count":1}]	918	pick-up	0	14
1799	2019-04-15 13:48:04	2019-04-15	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	575	pick-up	0	21
1800	2019-04-15 21:05:53	2019-04-15	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	790	pick-up	0	29
1801	2019-04-16 02:19:00	2019-04-16	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	695	delivery	5	36
1802	2019-04-16 04:29:14	2019-04-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	923	delivery	5	28
1803	2019-04-16 04:56:56	2019-04-16	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	261	delivery	5	25
1804	2019-04-16 04:59:36	2019-04-16	12	[{"id_menu":1,"count":1}]	927	delivery	5	17
1805	2019-04-16 07:25:50	2019-04-16	17	[{"id_menu":4,"count":1}]	76	pick-up	0	17
1806	2019-04-16 07:42:28	2019-04-16	8	[{"id_menu":5,"count":1}]	110	pick-up	0	8
1807	2019-04-16 07:47:25	2019-04-16	12	[{"id_menu":1,"count":1}]	42	pick-up	0	12
1808	2019-04-16 09:03:47	2019-04-16	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	493	delivery	5	57
1809	2019-04-16 09:25:00	2019-04-16	12	[{"id_menu":3,"count":1}]	182	delivery	5	17
1810	2019-04-16 09:45:37	2019-04-16	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	880	delivery	5	26
1811	2019-04-16 12:51:12	2019-04-16	14	[{"id_menu":2,"count":1}]	929	delivery	5	19
1812	2019-04-16 14:40:25	2019-04-16	8	[{"id_menu":5,"count":1}]	532	pick-up	0	8
1813	2019-04-16 15:21:02	2019-04-16	9	[{"id_menu":7,"count":1}]	445	delivery	5	14
1814	2019-04-16 15:39:59	2019-04-16	8	[{"id_menu":5,"count":1}]	152	pick-up	0	8
1815	2019-04-16 16:30:16	2019-04-16	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	314	pick-up	0	22
1816	2019-04-16 17:54:23	2019-04-16	12	[{"id_menu":3,"count":1}]	924	delivery	5	17
1817	2019-04-16 18:00:35	2019-04-16	12	[{"id_menu":1,"count":1}]	925	pick-up	0	12
1818	2019-04-16 18:19:32	2019-04-16	9	[{"id_menu":6,"count":1}]	286	delivery	5	14
1819	2019-04-16 18:29:55	2019-04-16	12	[{"id_menu":3,"count":1}]	676	delivery	5	17
1820	2019-04-16 18:32:44	2019-04-16	12	[{"id_menu":1,"count":1}]	701	delivery	5	17
1821	2019-04-16 18:39:26	2019-04-16	14	[{"id_menu":2,"count":2}]	922	delivery	5	19
1822	2019-04-16 20:00:21	2019-04-16	12	[{"id_menu":1,"count":1}]	371	pick-up	0	12
1823	2019-04-16 20:40:13	2019-04-16	14	[{"id_menu":2,"count":1}]	287	delivery	5	19
1824	2019-04-16 22:18:53	2019-04-16	12	[{"id_menu":1,"count":1}]	913	delivery	5	17
1825	2019-04-17 00:39:47	2019-04-17	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	936	delivery	5	34
1826	2019-04-17 03:48:36	2019-04-17	9	[{"id_menu":7,"count":2}]	655	pick-up	0	9
1827	2019-04-17 04:03:53	2019-04-17	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	932	pick-up	0	26
1828	2019-04-17 04:10:10	2019-04-17	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	173	delivery	5	22
1829	2019-04-17 05:39:20	2019-04-17	8	[{"id_menu":5,"count":1}]	397	delivery	5	13
1830	2019-04-17 05:56:06	2019-04-17	12	[{"id_menu":1,"count":1}]	933	pick-up	0	12
1831	2019-04-17 07:19:05	2019-04-17	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	856	delivery	5	28
1832	2019-04-17 09:42:53	2019-04-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	937	pick-up	0	23
1833	2019-04-17 09:59:33	2019-04-17	9	[{"id_menu":7,"count":1}]	934	pick-up	0	9
1834	2019-04-17 10:43:43	2019-04-17	9	[{"id_menu":6,"count":1}]	582	delivery	5	14
1835	2019-04-17 11:19:15	2019-04-17	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	935	delivery	5	25
1836	2019-04-17 12:43:19	2019-04-17	14	[{"id_menu":2,"count":1}]	930	pick-up	0	14
1837	2019-04-17 14:19:49	2019-04-17	8	[{"id_menu":5,"count":1}]	931	pick-up	0	8
1838	2019-04-17 16:08:41	2019-04-17	9	[{"id_menu":6,"count":1}]	840	pick-up	0	9
1839	2019-04-17 17:07:28	2019-04-17	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	709	delivery	5	34
1840	2019-04-17 19:48:53	2019-04-17	12	[{"id_menu":3,"count":1}]	485	pick-up	0	12
1841	2019-04-17 20:38:37	2019-04-17	14	[{"id_menu":2,"count":1}]	188	delivery	5	19
1842	2019-04-17 22:26:51	2019-04-17	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	33	pick-up	0	32
1843	2019-04-17 23:37:05	2019-04-17	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	714	delivery	5	25
1844	2019-04-17 23:44:07	2019-04-17	12	[{"id_menu":1,"count":1}]	601	delivery	5	17
1845	2019-04-17 23:49:53	2019-04-17	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	553	pick-up	0	35
1846	2019-04-18 00:06:38	2019-04-18	12	[{"id_menu":3,"count":1}]	552	pick-up	0	12
1847	2019-04-18 00:25:22	2019-04-18	17	[{"id_menu":4,"count":1}]	940	pick-up	0	17
1848	2019-04-18 01:18:41	2019-04-18	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	790	pick-up	0	29
1849	2019-04-18 03:22:22	2019-04-18	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	518	delivery	5	36
1850	2019-04-18 03:46:46	2019-04-18	14	[{"id_menu":2,"count":1}]	867	delivery	5	19
1851	2019-04-18 04:15:02	2019-04-18	9	[{"id_menu":7,"count":1}]	755	delivery	5	14
1852	2019-04-18 06:41:29	2019-04-18	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	945	pick-up	0	38
1853	2019-04-18 06:51:25	2019-04-18	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	75	delivery	5	29
1854	2019-04-18 09:23:13	2019-04-18	9	[{"id_menu":6,"count":1}]	701	pick-up	0	9
1855	2019-04-18 10:08:03	2019-04-18	12	[{"id_menu":3,"count":1}]	942	pick-up	0	12
1856	2019-04-18 11:58:58	2019-04-18	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	135	pick-up	0	38
1857	2019-04-18 13:09:13	2019-04-18	9	[{"id_menu":6,"count":1}]	863	delivery	5	14
1858	2019-04-18 13:36:55	2019-04-18	12	[{"id_menu":3,"count":1}]	941	delivery	5	17
1859	2019-04-18 15:13:09	2019-04-18	14	[{"id_menu":2,"count":1}]	640	pick-up	0	14
1860	2019-04-18 15:16:04	2019-04-18	17	[{"id_menu":4,"count":1}]	938	delivery	5	22
1861	2019-04-18 17:26:28	2019-04-18	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	782	delivery	5	31
1862	2019-04-18 17:36:17	2019-04-18	17	[{"id_menu":4,"count":1}]	742	pick-up	0	17
1863	2019-04-18 17:42:49	2019-04-18	14	[{"id_menu":2,"count":1}]	609	pick-up	0	14
1864	2019-04-18 19:03:09	2019-04-18	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	943	delivery	5	36
1865	2019-04-18 19:50:30	2019-04-18	9	[{"id_menu":6,"count":1}]	408	pick-up	0	9
1866	2019-04-18 20:07:30	2019-04-18	17	[{"id_menu":4,"count":1}]	95	pick-up	0	17
1867	2019-04-18 22:16:22	2019-04-18	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	939	delivery	5	40
1868	2019-04-18 22:52:50	2019-04-18	14	[{"id_menu":2,"count":1}]	111	delivery	5	19
1869	2019-04-18 22:58:07	2019-04-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	944	delivery	5	28
1870	2019-04-18 23:43:35	2019-04-18	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	209	pick-up	0	21
1871	2019-04-19 01:07:25	2019-04-19	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	260	pick-up	0	34
1872	2019-04-19 02:12:45	2019-04-19	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	81	pick-up	0	26
1873	2019-04-19 02:14:07	2019-04-19	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	493	pick-up	0	26
1874	2019-04-19 03:58:56	2019-04-19	17	[{"id_menu":4,"count":1}]	429	pick-up	0	17
1875	2019-04-19 04:15:25	2019-04-19	14	[{"id_menu":2,"count":1}]	163	delivery	5	19
1876	2019-04-19 05:42:29	2019-04-19	14	[{"id_menu":2,"count":1}]	177	pick-up	0	14
1877	2019-04-19 06:38:00	2019-04-19	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	537	delivery	5	52
1878	2019-04-19 09:07:52	2019-04-19	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	425	delivery	5	36
1879	2019-04-19 09:58:59	2019-04-19	14	[{"id_menu":2,"count":2}]	954	delivery	5	19
1880	2019-04-19 11:08:03	2019-04-19	8	[{"id_menu":5,"count":2}]	948	delivery	5	13
1881	2019-04-19 11:20:58	2019-04-19	9	[{"id_menu":6,"count":1}]	41	pick-up	0	9
1882	2019-04-19 11:31:22	2019-04-19	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	763	pick-up	0	29
1883	2019-04-19 12:29:29	2019-04-19	9	[{"id_menu":6,"count":1}]	949	delivery	5	14
1884	2019-04-19 14:38:43	2019-04-19	12	[{"id_menu":3,"count":1}]	818	delivery	5	17
1885	2019-04-19 14:54:34	2019-04-19	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	584	pick-up	0	25
1886	2019-04-19 15:03:31	2019-04-19	14	[{"id_menu":2,"count":1}]	517	pick-up	0	14
1887	2019-04-19 15:35:50	2019-04-19	17	[{"id_menu":4,"count":1}]	946	pick-up	0	17
1888	2019-04-19 15:39:27	2019-04-19	14	[{"id_menu":2,"count":1}]	13	pick-up	0	14
1889	2019-04-19 17:46:46	2019-04-19	17	[{"id_menu":4,"count":1}]	567	delivery	5	22
1890	2019-04-19 17:53:07	2019-04-19	12	[{"id_menu":1,"count":1}]	341	pick-up	0	12
1891	2019-04-19 19:43:57	2019-04-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	401	pick-up	0	23
1892	2019-04-19 20:15:19	2019-04-19	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	950	pick-up	0	21
1893	2019-04-19 21:57:03	2019-04-19	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	643	pick-up	0	29
1894	2019-04-20 00:33:57	2019-04-20	14	[{"id_menu":2,"count":1}]	824	pick-up	0	14
1895	2019-04-20 00:48:16	2019-04-20	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	962	delivery	5	31
1896	2019-04-20 01:04:23	2019-04-20	9	[{"id_menu":6,"count":1}]	175	pick-up	0	9
1897	2019-04-20 01:45:38	2019-04-20	14	[{"id_menu":2,"count":1}]	963	pick-up	0	14
1898	2019-04-20 03:50:27	2019-04-20	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	477	pick-up	0	29
1899	2019-04-20 04:00:36	2019-04-20	14	[{"id_menu":2,"count":1}]	18	pick-up	0	14
1900	2019-04-20 04:17:43	2019-04-20	12	[{"id_menu":1,"count":1}]	439	delivery	5	17
1901	2019-04-20 04:58:42	2019-04-20	17	[{"id_menu":4,"count":1}]	634	pick-up	0	17
1902	2019-04-20 05:03:21	2019-04-20	9	[{"id_menu":6,"count":1}]	689	pick-up	0	9
1903	2019-04-20 05:34:54	2019-04-20	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	960	pick-up	0	46
1904	2019-04-20 07:06:58	2019-04-20	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	448	delivery	5	35
1905	2019-04-20 07:20:44	2019-04-20	17	[{"id_menu":4,"count":1}]	467	pick-up	0	17
1906	2019-04-20 07:39:17	2019-04-20	8	[{"id_menu":5,"count":1}]	958	delivery	5	13
1907	2019-04-20 07:41:29	2019-04-20	17	[{"id_menu":4,"count":1}]	486	pick-up	0	17
1908	2019-04-20 09:02:03	2019-04-20	9	[{"id_menu":6,"count":1}]	780	delivery	5	14
1909	2019-04-20 10:25:17	2019-04-20	17	[{"id_menu":4,"count":1}]	916	pick-up	0	17
1910	2019-04-20 10:41:26	2019-04-20	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	961	pick-up	0	20
1911	2019-04-20 11:14:27	2019-04-20	14	[{"id_menu":2,"count":2}]	135	pick-up	0	14
1912	2019-04-20 11:53:10	2019-04-20	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	956	pick-up	0	26
1913	2019-04-20 11:54:31	2019-04-20	8	[{"id_menu":5,"count":2}]	955	delivery	5	13
1914	2019-04-20 12:34:47	2019-04-20	17	[{"id_menu":4,"count":1}]	547	pick-up	0	17
1915	2019-04-20 12:35:45	2019-04-20	9	[{"id_menu":7,"count":1}]	173	pick-up	0	9
1916	2019-04-20 12:45:21	2019-04-20	12	[{"id_menu":3,"count":1}]	719	delivery	5	17
1917	2019-04-20 14:03:23	2019-04-20	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	95	delivery	5	37
1918	2019-04-20 15:34:03	2019-04-20	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	228	delivery	5	22
1919	2019-04-20 15:40:08	2019-04-20	34	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	889	delivery	5	39
1920	2019-04-20 16:26:49	2019-04-20	9	[{"id_menu":6,"count":1}]	567	delivery	5	14
1921	2019-04-20 16:32:23	2019-04-20	9	[{"id_menu":6,"count":1}]	964	delivery	5	14
1922	2019-04-20 17:32:05	2019-04-20	8	[{"id_menu":5,"count":1}]	339	pick-up	0	8
1923	2019-04-20 18:03:42	2019-04-20	9	[{"id_menu":6,"count":1}]	957	pick-up	0	9
1924	2019-04-20 18:45:34	2019-04-20	12	[{"id_menu":3,"count":1}]	826	pick-up	0	12
1925	2019-04-20 20:12:25	2019-04-20	12	[{"id_menu":3,"count":2}]	123	pick-up	0	12
1926	2019-04-20 20:29:51	2019-04-20	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	546	delivery	5	43
1927	2019-04-20 21:34:50	2019-04-20	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	959	pick-up	0	29
1928	2019-04-20 21:43:19	2019-04-20	8	[{"id_menu":5,"count":1}]	374	pick-up	0	8
1929	2019-04-20 23:42:04	2019-04-20	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	501	pick-up	0	24
1930	2019-04-21 00:23:18	2019-04-21	9	[{"id_menu":6,"count":1}]	128	delivery	5	14
1931	2019-04-21 01:40:38	2019-04-21	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	764	delivery	5	45
1932	2019-04-21 02:45:53	2019-04-21	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	126	pick-up	0	29
1933	2019-04-21 02:46:40	2019-04-21	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	190	pick-up	0	23
1934	2019-04-21 02:56:36	2019-04-21	12	[{"id_menu":1,"count":1}]	965	pick-up	0	12
1935	2019-04-21 03:10:56	2019-04-21	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	966	pick-up	0	21
1936	2019-04-21 03:53:52	2019-04-21	14	[{"id_menu":2,"count":1}]	973	delivery	5	19
1937	2019-04-21 04:28:52	2019-04-21	14	[{"id_menu":2,"count":1}]	756	pick-up	0	14
1938	2019-04-21 06:20:28	2019-04-21	17	[{"id_menu":4,"count":1}]	455	delivery	5	22
1939	2019-04-21 06:32:29	2019-04-21	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	968	delivery	5	34
1940	2019-04-21 07:56:54	2019-04-21	17	[{"id_menu":4,"count":2}]	970	delivery	5	22
1941	2019-04-21 08:01:23	2019-04-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	969	delivery	5	28
1942	2019-04-21 08:23:47	2019-04-21	14	[{"id_menu":2,"count":1}]	971	delivery	5	19
1943	2019-04-21 11:53:32	2019-04-21	12	[{"id_menu":1,"count":1}]	967	pick-up	0	12
1944	2019-04-21 12:10:34	2019-04-21	9	[{"id_menu":6,"count":1}]	972	delivery	5	14
1945	2019-04-21 12:38:30	2019-04-21	8	[{"id_menu":5,"count":1}]	459	delivery	5	13
1946	2019-04-21 12:43:30	2019-04-21	17	[{"id_menu":4,"count":1}]	767	delivery	5	22
1947	2019-04-21 13:11:01	2019-04-21	12	[{"id_menu":1,"count":1}]	401	pick-up	0	12
1948	2019-04-21 14:39:10	2019-04-21	9	[{"id_menu":6,"count":1}]	256	pick-up	0	9
1949	2019-04-21 14:47:53	2019-04-21	14	[{"id_menu":2,"count":3}]	930	pick-up	0	14
1950	2019-04-21 17:24:28	2019-04-21	9	[{"id_menu":7,"count":1}]	68	pick-up	0	9
1951	2019-04-21 18:12:42	2019-04-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	528	delivery	5	31
1952	2019-04-21 19:33:14	2019-04-21	9	[{"id_menu":7,"count":1}]	111	pick-up	0	9
1953	2019-04-21 19:53:03	2019-04-21	12	[{"id_menu":3,"count":1}]	452	pick-up	0	12
1954	2019-04-21 20:33:30	2019-04-21	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	599	delivery	5	34
1955	2019-04-21 21:00:42	2019-04-21	9	[{"id_menu":6,"count":1}]	787	delivery	5	14
1956	2019-04-21 21:06:02	2019-04-21	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	655	pick-up	0	41
1957	2019-04-21 21:59:48	2019-04-21	12	[{"id_menu":3,"count":1}]	640	pick-up	0	12
1958	2019-04-21 23:39:34	2019-04-21	9	[{"id_menu":7,"count":1}]	207	pick-up	0	9
1959	2019-04-21 23:45:59	2019-04-21	9	[{"id_menu":7,"count":1}]	824	delivery	5	14
1960	2019-04-22 01:16:41	2019-04-22	12	[{"id_menu":1,"count":1}]	41	pick-up	0	12
1961	2019-04-22 03:54:38	2019-04-22	12	[{"id_menu":3,"count":1}]	362	delivery	5	17
1962	2019-04-22 04:00:10	2019-04-22	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	292	delivery	5	45
1963	2019-04-22 04:32:53	2019-04-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	640	pick-up	0	23
1964	2019-04-22 05:54:38	2019-04-22	8	[{"id_menu":5,"count":1}]	204	pick-up	0	8
1965	2019-04-22 06:40:59	2019-04-22	8	[{"id_menu":5,"count":1}]	977	delivery	5	13
1966	2019-04-22 08:55:02	2019-04-22	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	406	pick-up	0	31
1967	2019-04-22 09:07:37	2019-04-22	17	[{"id_menu":4,"count":1}]	978	delivery	5	22
1968	2019-04-22 09:15:12	2019-04-22	8	[{"id_menu":5,"count":1}]	931	delivery	5	13
1969	2019-04-22 16:07:01	2019-04-22	9	[{"id_menu":7,"count":1}]	906	delivery	5	14
1970	2019-04-22 16:54:58	2019-04-22	9	[{"id_menu":6,"count":1}]	431	pick-up	0	9
1971	2019-04-22 17:14:57	2019-04-22	9	[{"id_menu":6,"count":1}]	598	delivery	5	14
1972	2019-04-22 17:58:38	2019-04-22	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	136	pick-up	0	26
1973	2019-04-22 21:40:14	2019-04-22	9	[{"id_menu":7,"count":1}]	539	pick-up	0	9
1974	2019-04-22 22:17:53	2019-04-22	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	979	pick-up	0	43
1975	2019-04-23 01:30:54	2019-04-23	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	982	delivery	5	31
1976	2019-04-23 03:34:18	2019-04-23	9	[{"id_menu":7,"count":1}]	988	delivery	5	14
1977	2019-04-23 03:47:40	2019-04-23	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	983	delivery	5	42
1978	2019-04-23 04:40:47	2019-04-23	8	[{"id_menu":5,"count":1}]	833	pick-up	0	8
1979	2019-04-23 06:27:42	2019-04-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	295	pick-up	0	26
1980	2019-04-23 07:16:46	2019-04-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":3}]	166	delivery	5	31
1981	2019-04-23 09:05:30	2019-04-23	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	985	pick-up	0	21
1982	2019-04-23 11:48:31	2019-04-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	187	delivery	5	31
1983	2019-04-23 19:49:28	2019-04-23	9	[{"id_menu":7,"count":1}]	6	pick-up	0	9
1984	2019-04-23 20:25:26	2019-04-23	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	601	pick-up	0	35
1985	2019-04-23 23:07:43	2019-04-23	17	[{"id_menu":4,"count":1}]	293	pick-up	0	17
1986	2019-04-24 00:08:48	2019-04-24	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	837	pick-up	0	26
1987	2019-04-24 00:29:13	2019-04-24	14	[{"id_menu":2,"count":1}]	910	delivery	5	19
1988	2019-04-24 01:33:58	2019-04-24	8	[{"id_menu":5,"count":1}]	474	delivery	5	13
1989	2019-04-24 02:19:29	2019-04-24	14	[{"id_menu":2,"count":1}]	422	delivery	5	19
1990	2019-04-24 02:20:21	2019-04-24	9	[{"id_menu":6,"count":1}]	991	pick-up	0	9
1991	2019-04-24 03:48:41	2019-04-24	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	993	pick-up	0	21
1992	2019-04-24 04:04:26	2019-04-24	12	[{"id_menu":1,"count":1}]	346	pick-up	0	12
1993	2019-04-24 04:06:27	2019-04-24	9	[{"id_menu":7,"count":1}]	761	pick-up	0	9
1994	2019-04-24 05:37:52	2019-04-24	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	992	delivery	5	26
1995	2019-04-24 06:56:51	2019-04-24	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	665	delivery	5	34
1996	2019-04-24 07:17:26	2019-04-24	8	[{"id_menu":5,"count":1}]	149	pick-up	0	8
1997	2019-04-24 07:17:49	2019-04-24	8	[{"id_menu":5,"count":1}]	29	pick-up	0	8
1998	2019-04-24 08:46:51	2019-04-24	9	[{"id_menu":7,"count":1}]	820	pick-up	0	9
1999	2019-04-24 09:47:32	2019-04-24	8	[{"id_menu":5,"count":1}]	213	pick-up	0	8
2000	2019-04-24 11:41:14	2019-04-24	14	[{"id_menu":2,"count":1}]	757	pick-up	0	14
2001	2019-04-24 12:46:45	2019-04-24	9	[{"id_menu":7,"count":1}]	997	pick-up	0	9
2002	2019-04-24 13:00:07	2019-04-24	17	[{"id_menu":4,"count":1}]	271	delivery	5	22
2003	2019-04-24 13:04:28	2019-04-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	48	delivery	5	31
2004	2019-04-24 14:06:08	2019-04-24	17	[{"id_menu":4,"count":1}]	996	pick-up	0	17
2005	2019-04-24 17:04:05	2019-04-24	14	[{"id_menu":2,"count":1}]	786	pick-up	0	14
2006	2019-04-24 17:57:23	2019-04-24	12	[{"id_menu":3,"count":1}]	332	pick-up	0	12
2007	2019-04-24 17:57:24	2019-04-24	8	[{"id_menu":5,"count":1}]	556	delivery	5	13
2008	2019-04-24 20:11:28	2019-04-24	9	[{"id_menu":7,"count":1}]	994	delivery	5	14
2009	2019-04-24 22:24:59	2019-04-24	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	995	delivery	5	37
2010	2019-04-24 22:26:07	2019-04-24	14	[{"id_menu":2,"count":1}]	676	delivery	5	19
2011	2019-04-24 23:37:44	2019-04-24	17	[{"id_menu":4,"count":1}]	243	delivery	5	22
2012	2019-04-24 23:55:59	2019-04-24	17	[{"id_menu":4,"count":1}]	990	pick-up	0	17
2013	2019-04-25 01:22:46	2019-04-25	12	[{"id_menu":3,"count":1}]	655	pick-up	0	12
2014	2019-04-25 01:46:49	2019-04-25	8	[{"id_menu":5,"count":1}]	21	pick-up	0	8
2015	2019-04-25 03:28:36	2019-04-25	12	[{"id_menu":3,"count":1}]	843	pick-up	0	12
2016	2019-04-25 03:40:30	2019-04-25	12	[{"id_menu":1,"count":1}]	1003	pick-up	0	12
2017	2019-04-25 04:35:28	2019-04-25	14	[{"id_menu":2,"count":1}]	788	delivery	5	19
2018	2019-04-25 05:40:53	2019-04-25	17	[{"id_menu":4,"count":1}]	847	pick-up	0	17
2019	2019-04-25 06:56:37	2019-04-25	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1000	pick-up	0	21
2020	2019-04-25 08:18:54	2019-04-25	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	691	delivery	5	36
2021	2019-04-25 08:34:20	2019-04-25	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	379	pick-up	0	26
2022	2019-04-25 09:10:00	2019-04-25	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	148	pick-up	0	21
2023	2019-04-25 09:56:47	2019-04-25	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	280	delivery	5	36
2024	2019-04-25 10:02:23	2019-04-25	12	[{"id_menu":1,"count":1}]	579	delivery	5	17
2025	2019-04-25 11:54:31	2019-04-25	8	[{"id_menu":5,"count":1}]	1002	pick-up	0	8
2026	2019-04-25 14:38:35	2019-04-25	9	[{"id_menu":7,"count":2}]	999	pick-up	0	9
2027	2019-04-25 15:28:56	2019-04-25	14	[{"id_menu":2,"count":1}]	1004	pick-up	0	14
2028	2019-04-25 16:30:19	2019-04-25	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	749	pick-up	0	26
2029	2019-04-25 18:04:35	2019-04-25	17	[{"id_menu":4,"count":1}]	533	delivery	5	22
2030	2019-04-25 19:37:56	2019-04-25	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	998	pick-up	0	29
2031	2019-04-25 20:14:33	2019-04-25	9	[{"id_menu":7,"count":1}]	546	delivery	5	14
2032	2019-04-25 20:19:13	2019-04-25	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	1005	delivery	5	27
2033	2019-04-25 20:25:44	2019-04-25	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1006	delivery	5	43
2034	2019-04-25 20:44:34	2019-04-25	14	[{"id_menu":2,"count":1}]	946	pick-up	0	14
2035	2019-04-25 22:14:46	2019-04-25	9	[{"id_menu":7,"count":1}]	944	pick-up	0	9
2036	2019-04-26 00:28:06	2019-04-26	17	[{"id_menu":4,"count":1}]	506	delivery	5	22
2037	2019-04-26 00:59:04	2019-04-26	12	[{"id_menu":1,"count":1}]	1015	delivery	5	17
2038	2019-04-26 02:15:40	2019-04-26	9	[{"id_menu":6,"count":1}]	837	delivery	5	14
2039	2019-04-26 03:58:13	2019-04-26	9	[{"id_menu":6,"count":1}]	377	pick-up	0	9
2040	2019-04-26 04:29:41	2019-04-26	14	[{"id_menu":2,"count":1}]	931	pick-up	0	14
2041	2019-04-26 05:03:29	2019-04-26	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	880	delivery	5	48
2042	2019-04-26 05:09:41	2019-04-26	14	[{"id_menu":2,"count":1}]	639	delivery	5	19
2043	2019-04-26 05:18:04	2019-04-26	12	[{"id_menu":3,"count":1}]	406	pick-up	0	12
2044	2019-04-26 06:15:04	2019-04-26	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	82	pick-up	0	21
2045	2019-04-26 07:38:13	2019-04-26	9	[{"id_menu":7,"count":1}]	397	delivery	5	14
2046	2019-04-26 09:02:19	2019-04-26	14	[{"id_menu":2,"count":1}]	173	delivery	5	19
2047	2019-04-26 09:13:41	2019-04-26	17	[{"id_menu":4,"count":1}]	1013	delivery	5	22
2048	2019-04-26 09:54:43	2019-04-26	9	[{"id_menu":7,"count":1}]	1012	pick-up	0	9
2049	2019-04-26 10:32:08	2019-04-26	17	[{"id_menu":4,"count":1}]	826	pick-up	0	17
2050	2019-04-26 10:59:58	2019-04-26	9	[{"id_menu":6,"count":1}]	1011	delivery	5	14
2051	2019-04-26 11:47:28	2019-04-26	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	424	delivery	5	36
2052	2019-04-26 14:34:48	2019-04-26	12	[{"id_menu":1,"count":1}]	76	delivery	5	17
2053	2019-04-26 15:18:41	2019-04-26	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1010	pick-up	0	32
2054	2019-04-26 15:48:01	2019-04-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	1007	pick-up	0	17
2055	2019-04-26 16:20:58	2019-04-26	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	571	delivery	5	26
2056	2019-04-26 17:35:34	2019-04-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1009	delivery	5	23
2057	2019-04-26 18:43:35	2019-04-26	12	[{"id_menu":1,"count":1}]	688	pick-up	0	12
2058	2019-04-26 19:25:32	2019-04-26	9	[{"id_menu":6,"count":1}]	1014	delivery	5	14
2059	2019-04-26 20:04:20	2019-04-26	9	[{"id_menu":6,"count":1}]	1008	pick-up	0	9
2060	2019-04-26 21:25:49	2019-04-26	12	[{"id_menu":3,"count":1}]	657	pick-up	0	12
2061	2019-04-26 21:40:17	2019-04-26	8	[{"id_menu":5,"count":1}]	1016	pick-up	0	8
2062	2019-04-26 23:29:50	2019-04-26	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	281	pick-up	0	26
2063	2019-04-27 01:09:58	2019-04-27	8	[{"id_menu":5,"count":1}]	684	pick-up	0	8
2064	2019-04-27 01:36:55	2019-04-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	834	pick-up	0	23
2065	2019-04-27 01:53:06	2019-04-27	12	[{"id_menu":3,"count":1}]	865	delivery	5	17
2066	2019-04-27 01:54:03	2019-04-27	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	707	pick-up	0	20
2067	2019-04-27 04:58:16	2019-04-27	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	508	delivery	5	34
2068	2019-04-27 05:18:05	2019-04-27	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1022	pick-up	0	20
2069	2019-04-27 05:41:28	2019-04-27	14	[{"id_menu":2,"count":1}]	874	pick-up	0	14
2070	2019-04-27 07:17:30	2019-04-27	12	[{"id_menu":1,"count":1}]	829	pick-up	0	12
2071	2019-04-27 07:32:07	2019-04-27	12	[{"id_menu":3,"count":1}]	1025	pick-up	0	12
2072	2019-04-27 08:13:53	2019-04-27	14	[{"id_menu":2,"count":1}]	1017	pick-up	0	14
2073	2019-04-27 09:44:53	2019-04-27	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	907	delivery	5	45
2074	2019-04-27 11:32:52	2019-04-27	9	[{"id_menu":7,"count":1}]	326	pick-up	0	9
2075	2019-04-27 11:39:29	2019-04-27	14	[{"id_menu":2,"count":1}]	229	pick-up	0	14
2076	2019-04-27 11:47:49	2019-04-27	17	[{"id_menu":4,"count":2}]	787	delivery	5	22
2077	2019-04-27 12:25:51	2019-04-27	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	360	pick-up	0	40
2078	2019-04-27 12:35:48	2019-04-27	17	[{"id_menu":4,"count":1}]	1023	delivery	5	22
2079	2019-04-27 13:18:18	2019-04-27	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	701	pick-up	0	40
2080	2019-04-27 15:25:40	2019-04-27	14	[{"id_menu":2,"count":1}]	1024	pick-up	0	14
2081	2019-04-27 15:38:22	2019-04-27	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1019	pick-up	0	17
2082	2019-04-27 15:42:21	2019-04-27	9	[{"id_menu":7,"count":1}]	1021	pick-up	0	9
2083	2019-04-27 16:54:24	2019-04-27	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	990	pick-up	0	20
2084	2019-04-27 17:23:44	2019-04-27	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	1018	delivery	5	31
2085	2019-04-27 17:24:17	2019-04-27	8	[{"id_menu":5,"count":1}]	67	pick-up	0	8
2086	2019-04-27 18:01:43	2019-04-27	8	[{"id_menu":5,"count":1}]	880	delivery	5	13
2087	2019-04-27 18:14:36	2019-04-27	9	[{"id_menu":6,"count":1}]	219	pick-up	0	9
2088	2019-04-27 18:57:47	2019-04-27	8	[{"id_menu":5,"count":1}]	1020	pick-up	0	8
2089	2019-04-27 20:14:24	2019-04-27	12	[{"id_menu":3,"count":1}]	552	pick-up	0	12
2090	2019-04-27 20:31:39	2019-04-27	8	[{"id_menu":5,"count":1}]	748	delivery	5	13
2091	2019-04-27 20:45:45	2019-04-27	9	[{"id_menu":6,"count":1}]	575	pick-up	0	9
2092	2019-04-27 21:34:51	2019-04-27	9	[{"id_menu":7,"count":1}]	74	pick-up	0	9
2093	2019-04-27 21:36:39	2019-04-27	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	614	delivery	5	26
2094	2019-04-27 23:20:35	2019-04-27	14	[{"id_menu":2,"count":1}]	950	delivery	5	19
2095	2019-04-27 23:40:35	2019-04-27	8	[{"id_menu":5,"count":1}]	816	pick-up	0	8
2096	2019-04-28 01:58:21	2019-04-28	9	[{"id_menu":7,"count":2}]	391	delivery	5	14
2097	2019-04-28 02:08:51	2019-04-28	14	[{"id_menu":2,"count":1}]	1026	pick-up	0	14
2098	2019-04-28 02:10:38	2019-04-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	271	delivery	5	23
2099	2019-04-28 02:24:55	2019-04-28	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	233	pick-up	0	22
2100	2019-04-28 03:03:31	2019-04-28	12	[{"id_menu":1,"count":1}]	1030	pick-up	0	12
2101	2019-04-28 03:11:19	2019-04-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1035	pick-up	0	17
2102	2019-04-28 04:04:03	2019-04-28	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1034	pick-up	0	24
2103	2019-04-28 04:23:17	2019-04-28	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	583	delivery	5	36
2104	2019-04-28 04:45:40	2019-04-28	12	[{"id_menu":1,"count":1}]	115	pick-up	0	12
2105	2019-04-28 07:56:51	2019-04-28	9	[{"id_menu":7,"count":1}]	931	pick-up	0	9
2106	2019-04-28 08:12:18	2019-04-28	9	[{"id_menu":6,"count":1}]	283	pick-up	0	9
2107	2019-04-28 08:25:20	2019-04-28	8	[{"id_menu":5,"count":1}]	497	pick-up	0	8
2108	2019-04-28 09:08:36	2019-04-28	17	[{"id_menu":4,"count":1}]	257	pick-up	0	17
2109	2019-04-28 09:35:05	2019-04-28	12	[{"id_menu":3,"count":1}]	354	delivery	5	17
2110	2019-04-28 11:17:50	2019-04-28	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	173	delivery	5	25
2111	2019-04-28 12:51:37	2019-04-28	14	[{"id_menu":2,"count":1}]	140	delivery	5	19
2112	2019-04-28 13:18:04	2019-04-28	14	[{"id_menu":2,"count":1}]	1024	pick-up	0	14
2113	2019-04-28 14:19:11	2019-04-28	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":3}]	1029	pick-up	0	21
2114	2019-04-28 15:15:53	2019-04-28	12	[{"id_menu":1,"count":1}]	292	delivery	5	17
2115	2019-04-28 15:17:38	2019-04-28	12	[{"id_menu":3,"count":1}]	42	delivery	5	17
2116	2019-04-28 15:32:10	2019-04-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	422	delivery	5	22
2117	2019-04-28 16:42:45	2019-04-28	12	[{"id_menu":3,"count":1}]	1031	delivery	5	17
2118	2019-04-28 16:56:50	2019-04-28	9	[{"id_menu":6,"count":1}]	1028	delivery	5	14
2119	2019-04-28 17:14:27	2019-04-28	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	34	pick-up	0	30
2120	2019-04-28 17:17:01	2019-04-28	12	[{"id_menu":3,"count":1}]	41	delivery	5	17
2121	2019-04-28 18:45:49	2019-04-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	48	pick-up	0	26
2122	2019-04-28 19:39:07	2019-04-28	17	[{"id_menu":4,"count":1}]	1027	pick-up	0	17
2123	2019-04-28 21:52:53	2019-04-28	17	[{"id_menu":4,"count":1}]	1032	pick-up	0	17
2124	2019-04-28 23:43:57	2019-04-28	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	227	delivery	5	31
2125	2019-04-28 23:44:14	2019-04-28	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	378	pick-up	0	21
2126	2019-04-29 01:48:25	2019-04-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1042	pick-up	0	17
2127	2019-04-29 05:07:31	2019-04-29	12	[{"id_menu":1,"count":1}]	833	delivery	5	17
2128	2019-04-29 05:10:37	2019-04-29	9	[{"id_menu":6,"count":1}]	232	pick-up	0	9
2129	2019-04-29 07:04:10	2019-04-29	8	[{"id_menu":5,"count":1}]	847	pick-up	0	8
2130	2019-04-29 09:30:46	2019-04-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	44	pick-up	0	17
2131	2019-04-29 09:34:37	2019-04-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1036	pick-up	0	26
2132	2019-04-29 11:37:24	2019-04-29	12	[{"id_menu":1,"count":1}]	932	pick-up	0	12
2133	2019-04-29 12:35:52	2019-04-29	9	[{"id_menu":7,"count":1}]	1037	pick-up	0	9
2134	2019-04-29 13:08:56	2019-04-29	14	[{"id_menu":2,"count":1}]	1039	delivery	5	19
2135	2019-04-29 15:38:21	2019-04-29	14	[{"id_menu":2,"count":1}]	385	delivery	5	19
2136	2019-04-29 16:44:34	2019-04-29	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	799	pick-up	0	20
2137	2019-04-29 18:28:59	2019-04-29	14	[{"id_menu":2,"count":1}]	459	delivery	5	19
2138	2019-04-29 21:25:39	2019-04-29	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	925	delivery	5	47
2139	2019-04-29 23:15:24	2019-04-29	9	[{"id_menu":7,"count":1}]	612	pick-up	0	9
2140	2019-04-29 23:18:46	2019-04-29	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1041	pick-up	0	20
2141	2019-04-30 00:04:12	2019-04-30	9	[{"id_menu":6,"count":1}]	403	pick-up	0	9
2142	2019-04-30 02:32:51	2019-04-30	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	58	pick-up	0	25
2143	2019-04-30 03:09:14	2019-04-30	12	[{"id_menu":3,"count":1}]	325	pick-up	0	12
2144	2019-04-30 08:39:49	2019-04-30	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	868	pick-up	0	38
2145	2019-04-30 09:19:14	2019-04-30	14	[{"id_menu":2,"count":1}]	1050	pick-up	0	14
2146	2019-04-30 09:33:18	2019-04-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1046	delivery	5	23
2147	2019-04-30 09:59:16	2019-04-30	12	[{"id_menu":1,"count":1}]	1025	pick-up	0	12
2148	2019-04-30 13:34:51	2019-04-30	9	[{"id_menu":7,"count":1}]	732	pick-up	0	9
2149	2019-04-30 14:32:02	2019-04-30	14	[{"id_menu":2,"count":1}]	754	pick-up	0	14
2150	2019-04-30 15:44:14	2019-04-30	14	[{"id_menu":2,"count":1}]	381	pick-up	0	14
2151	2019-04-30 18:56:34	2019-04-30	9	[{"id_menu":7,"count":1}]	816	pick-up	0	9
2152	2019-04-30 19:05:41	2019-04-30	17	[{"id_menu":4,"count":1}]	295	pick-up	0	17
2153	2019-04-30 20:33:41	2019-04-30	14	[{"id_menu":2,"count":1}]	1051	pick-up	0	14
2154	2019-04-30 23:57:40	2019-04-30	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	744	pick-up	0	38
2155	2019-05-01 00:15:44	2019-05-01	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	581	delivery	5	36
2156	2019-05-01 01:14:39	2019-05-01	8	[{"id_menu":5,"count":1}]	379	pick-up	0	8
2157	2019-05-01 01:25:47	2019-05-01	14	[{"id_menu":2,"count":1}]	821	pick-up	0	14
2158	2019-05-01 01:51:07	2019-05-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1055	delivery	5	31
2159	2019-05-01 02:24:45	2019-05-01	12	[{"id_menu":3,"count":2}]	798	pick-up	0	12
2160	2019-05-01 02:47:40	2019-05-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":3}]	1038	delivery	5	22
2161	2019-05-01 03:42:51	2019-05-01	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1060	pick-up	0	29
2162	2019-05-01 04:11:31	2019-05-01	12	[{"id_menu":3,"count":1}]	1061	pick-up	0	12
2163	2019-05-01 04:24:01	2019-05-01	9	[{"id_menu":6,"count":1}]	333	pick-up	0	9
2164	2019-05-01 04:58:53	2019-05-01	14	[{"id_menu":2,"count":1}]	351	pick-up	0	14
2165	2019-05-01 05:39:11	2019-05-01	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	338	pick-up	0	22
2166	2019-05-01 06:46:13	2019-05-01	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	610	delivery	5	34
2167	2019-05-01 06:49:49	2019-05-01	14	[{"id_menu":2,"count":1}]	1053	pick-up	0	14
2168	2019-05-01 09:30:39	2019-05-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1058	delivery	5	36
2169	2019-05-01 13:43:49	2019-05-01	8	[{"id_menu":5,"count":1}]	492	delivery	5	13
2170	2019-05-01 14:16:10	2019-05-01	12	[{"id_menu":1,"count":1}]	1054	delivery	5	17
2171	2019-05-01 14:46:45	2019-05-01	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	237	pick-up	0	26
2172	2019-05-01 15:04:50	2019-05-01	14	[{"id_menu":2,"count":1}]	377	pick-up	0	14
2173	2019-05-01 15:43:05	2019-05-01	12	[{"id_menu":1,"count":1}]	480	delivery	5	17
2174	2019-05-01 16:15:49	2019-05-01	14	[{"id_menu":2,"count":1}]	997	pick-up	0	14
2175	2019-05-01 16:55:49	2019-05-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1056	delivery	5	28
2176	2019-05-01 17:59:43	2019-05-01	9	[{"id_menu":6,"count":1}]	486	pick-up	0	9
2177	2019-05-01 21:53:01	2019-05-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	150	delivery	5	31
2178	2019-05-01 22:44:09	2019-05-01	14	[{"id_menu":2,"count":1}]	491	delivery	5	19
2179	2019-05-01 22:45:35	2019-05-01	12	[{"id_menu":1,"count":3}]	404	delivery	5	17
2180	2019-05-01 22:59:38	2019-05-01	17	[{"id_menu":4,"count":1}]	543	delivery	5	22
2181	2019-05-01 23:04:28	2019-05-01	8	[{"id_menu":5,"count":1}]	1059	delivery	5	13
2182	2019-05-01 23:38:37	2019-05-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	149	delivery	5	26
2183	2019-05-02 01:24:53	2019-05-02	8	[{"id_menu":5,"count":1}]	2	pick-up	0	8
2184	2019-05-02 01:31:36	2019-05-02	12	[{"id_menu":1,"count":3}]	676	pick-up	0	12
2185	2019-05-02 01:49:25	2019-05-02	9	[{"id_menu":7,"count":1}]	1062	delivery	5	14
2186	2019-05-02 03:03:21	2019-05-02	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	656	delivery	5	53
2187	2019-05-02 03:49:54	2019-05-02	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	204	pick-up	0	20
2188	2019-05-02 05:09:34	2019-05-02	14	[{"id_menu":2,"count":1}]	1070	pick-up	0	14
2189	2019-05-02 05:22:27	2019-05-02	12	[{"id_menu":1,"count":1}]	834	pick-up	0	12
2190	2019-05-02 05:44:52	2019-05-02	8	[{"id_menu":5,"count":1}]	1065	pick-up	0	8
2191	2019-05-02 07:22:24	2019-05-02	14	[{"id_menu":2,"count":1}]	773	delivery	5	19
2192	2019-05-02 08:01:55	2019-05-02	8	[{"id_menu":5,"count":1}]	599	pick-up	0	8
2193	2019-05-02 08:32:55	2019-05-02	12	[{"id_menu":1,"count":1}]	593	pick-up	0	12
2194	2019-05-02 10:08:18	2019-05-02	9	[{"id_menu":6,"count":1}]	964	delivery	5	14
2195	2019-05-02 12:29:29	2019-05-02	17	[{"id_menu":4,"count":1}]	287	pick-up	0	17
2196	2019-05-02 13:32:51	2019-05-02	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	1040	pick-up	0	33
2197	2019-05-02 14:32:35	2019-05-02	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	788	delivery	5	27
2198	2019-05-02 15:06:57	2019-05-02	9	[{"id_menu":7,"count":1}]	1068	pick-up	0	9
2199	2019-05-02 17:22:44	2019-05-02	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1064	pick-up	0	31
2200	2019-05-02 17:52:25	2019-05-02	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	29	delivery	5	34
2201	2019-05-02 18:21:36	2019-05-02	9	[{"id_menu":6,"count":1}]	1067	pick-up	0	9
2202	2019-05-02 18:40:18	2019-05-02	14	[{"id_menu":2,"count":1}]	1066	delivery	5	19
2203	2019-05-02 18:53:18	2019-05-02	9	[{"id_menu":6,"count":1}]	996	delivery	5	14
2204	2019-05-02 19:57:47	2019-05-02	8	[{"id_menu":5,"count":1}]	10	pick-up	0	8
2205	2019-05-02 20:29:05	2019-05-02	14	[{"id_menu":2,"count":1}]	1063	pick-up	0	14
2206	2019-05-02 20:31:39	2019-05-02	8	[{"id_menu":5,"count":2}]	997	pick-up	0	8
2207	2019-05-02 20:31:55	2019-05-02	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	950	pick-up	0	21
2208	2019-05-02 21:05:10	2019-05-02	12	[{"id_menu":3,"count":1}]	76	pick-up	0	12
2209	2019-05-02 21:14:43	2019-05-02	9	[{"id_menu":6,"count":2}]	96	delivery	5	14
2210	2019-05-02 21:28:16	2019-05-02	9	[{"id_menu":6,"count":2}]	248	delivery	5	14
2211	2019-05-02 23:34:54	2019-05-02	9	[{"id_menu":6,"count":1}]	66	delivery	5	14
2212	2019-05-03 00:15:03	2019-05-03	9	[{"id_menu":7,"count":1}]	1078	pick-up	0	9
2213	2019-05-03 02:49:46	2019-05-03	14	[{"id_menu":2,"count":1}]	778	delivery	5	19
2214	2019-05-03 03:04:14	2019-05-03	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	485	pick-up	0	29
2215	2019-05-03 03:10:22	2019-05-03	12	[{"id_menu":1,"count":1}]	1071	delivery	5	17
2216	2019-05-03 05:11:33	2019-05-03	9	[{"id_menu":6,"count":1}]	1079	delivery	5	14
2217	2019-05-03 06:17:58	2019-05-03	12	[{"id_menu":3,"count":1}]	37	pick-up	0	12
2218	2019-05-03 07:03:22	2019-05-03	9	[{"id_menu":6,"count":1}]	292	delivery	5	14
2219	2019-05-03 07:04:54	2019-05-03	9	[{"id_menu":6,"count":1}]	351	delivery	5	14
2220	2019-05-03 07:23:30	2019-05-03	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	207	pick-up	0	47
2221	2019-05-03 07:30:09	2019-05-03	17	[{"id_menu":4,"count":1}]	330	pick-up	0	17
2222	2019-05-03 08:36:10	2019-05-03	12	[{"id_menu":1,"count":1}]	1054	pick-up	0	12
2223	2019-05-03 08:56:06	2019-05-03	14	[{"id_menu":2,"count":1}]	831	delivery	5	19
2224	2019-05-03 10:16:30	2019-05-03	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	799	delivery	5	31
2225	2019-05-03 11:41:36	2019-05-03	12	[{"id_menu":3,"count":1}]	1076	delivery	5	17
2226	2019-05-03 13:52:54	2019-05-03	12	[{"id_menu":3,"count":1}]	859	pick-up	0	12
2227	2019-05-03 14:18:23	2019-05-03	9	[{"id_menu":6,"count":1}]	457	pick-up	0	9
2228	2019-05-03 14:21:13	2019-05-03	9	[{"id_menu":7,"count":1}]	1081	pick-up	0	9
2229	2019-05-03 14:45:34	2019-05-03	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	626	pick-up	0	26
2230	2019-05-03 15:19:15	2019-05-03	12	[{"id_menu":3,"count":1}]	765	pick-up	0	12
2231	2019-05-03 19:08:16	2019-05-03	14	[{"id_menu":2,"count":1}]	1072	pick-up	0	14
2232	2019-05-03 19:53:32	2019-05-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	871	delivery	5	31
2233	2019-05-03 22:47:01	2019-05-03	14	[{"id_menu":2,"count":1}]	1080	delivery	5	19
2234	2019-05-03 23:18:38	2019-05-03	9	[{"id_menu":7,"count":1}]	1075	delivery	5	14
2235	2019-05-03 23:19:10	2019-05-03	12	[{"id_menu":3,"count":1}]	1073	pick-up	0	12
2236	2019-05-03 23:35:34	2019-05-03	9	[{"id_menu":7,"count":1}]	1074	delivery	5	14
2237	2019-05-04 00:30:15	2019-05-04	12	[{"id_menu":1,"count":1}]	40	pick-up	0	12
2238	2019-05-04 00:44:11	2019-05-04	12	[{"id_menu":3,"count":1}]	530	delivery	5	17
2239	2019-05-04 00:52:39	2019-05-04	9	[{"id_menu":7,"count":1}]	611	delivery	5	14
2240	2019-05-04 01:09:01	2019-05-04	12	[{"id_menu":1,"count":1}]	764	delivery	5	17
2241	2019-05-04 01:28:22	2019-05-04	14	[{"id_menu":2,"count":1}]	436	pick-up	0	14
2242	2019-05-04 01:33:53	2019-05-04	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	839	pick-up	0	35
2243	2019-05-04 02:19:16	2019-05-04	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	630	pick-up	0	40
2244	2019-05-04 02:35:32	2019-05-04	17	[{"id_menu":4,"count":1}]	102	pick-up	0	17
2245	2019-05-04 03:39:56	2019-05-04	14	[{"id_menu":2,"count":1}]	293	pick-up	0	14
2246	2019-05-04 04:30:26	2019-05-04	12	[{"id_menu":1,"count":1}]	27	delivery	5	17
2247	2019-05-04 04:56:25	2019-05-04	9	[{"id_menu":6,"count":1}]	1090	delivery	5	14
2248	2019-05-04 05:13:55	2019-05-04	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	536	pick-up	0	35
2249	2019-05-04 05:40:11	2019-05-04	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1084	delivery	5	25
2250	2019-05-04 05:43:08	2019-05-04	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1091	delivery	5	40
2251	2019-05-04 05:50:28	2019-05-04	9	[{"id_menu":6,"count":2}]	546	delivery	5	14
2252	2019-05-04 07:23:15	2019-05-04	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	461	delivery	5	26
2253	2019-05-04 07:50:41	2019-05-04	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	958	pick-up	0	21
2254	2019-05-04 07:56:51	2019-05-04	12	[{"id_menu":3,"count":1}]	64	pick-up	0	12
2255	2019-05-04 08:27:38	2019-05-04	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	708	pick-up	0	30
2256	2019-05-04 09:09:31	2019-05-04	9	[{"id_menu":6,"count":1}]	214	pick-up	0	9
2257	2019-05-04 09:45:16	2019-05-04	17	[{"id_menu":4,"count":1}]	1082	pick-up	0	17
2258	2019-05-04 10:10:17	2019-05-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1083	pick-up	0	23
2259	2019-05-04 10:37:03	2019-05-04	12	[{"id_menu":3,"count":1}]	491	pick-up	0	12
2260	2019-05-04 11:08:10	2019-05-04	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	757	pick-up	0	26
2261	2019-05-04 12:28:59	2019-05-04	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1088	delivery	5	26
2262	2019-05-04 13:41:33	2019-05-04	12	[{"id_menu":3,"count":1}]	330	delivery	5	17
2263	2019-05-04 14:13:17	2019-05-04	17	[{"id_menu":4,"count":1}]	1085	pick-up	0	17
2264	2019-05-04 14:38:04	2019-05-04	14	[{"id_menu":2,"count":1}]	1086	pick-up	0	14
2265	2019-05-04 14:42:08	2019-05-04	17	[{"id_menu":4,"count":1}]	221	pick-up	0	17
2266	2019-05-04 14:48:00	2019-05-04	8	[{"id_menu":5,"count":1}]	1087	pick-up	0	8
2267	2019-05-04 14:53:01	2019-05-04	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	203	delivery	5	28
2268	2019-05-04 15:02:28	2019-05-04	9	[{"id_menu":7,"count":1}]	1089	delivery	5	14
2269	2019-05-04 15:22:08	2019-05-04	9	[{"id_menu":7,"count":1}]	707	delivery	5	14
2270	2019-05-04 15:43:20	2019-05-04	8	[{"id_menu":5,"count":1}]	235	pick-up	0	8
2271	2019-05-04 15:51:57	2019-05-04	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	626	delivery	5	29
2272	2019-05-04 15:52:28	2019-05-04	9	[{"id_menu":6,"count":1}]	873	delivery	5	14
2273	2019-05-04 16:42:46	2019-05-04	17	[{"id_menu":4,"count":1}]	332	pick-up	0	17
2274	2019-05-04 17:42:02	2019-05-04	14	[{"id_menu":2,"count":1}]	232	delivery	5	19
2275	2019-05-04 20:19:40	2019-05-04	17	[{"id_menu":4,"count":1}]	138	pick-up	0	17
2276	2019-05-04 21:38:26	2019-05-04	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	424	delivery	5	31
2277	2019-05-04 21:53:06	2019-05-04	12	[{"id_menu":3,"count":1}]	226	pick-up	0	12
2278	2019-05-04 22:25:56	2019-05-04	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	640	delivery	5	43
2279	2019-05-04 22:33:26	2019-05-04	9	[{"id_menu":7,"count":1}]	709	pick-up	0	9
2280	2019-05-04 23:03:25	2019-05-04	9	[{"id_menu":7,"count":1}]	295	pick-up	0	9
2281	2019-05-05 01:10:44	2019-05-05	12	[{"id_menu":3,"count":1}]	787	delivery	5	17
2282	2019-05-05 02:21:43	2019-05-05	17	[{"id_menu":4,"count":1}]	692	pick-up	0	17
2283	2019-05-05 02:39:11	2019-05-05	9	[{"id_menu":6,"count":1}]	338	pick-up	0	9
2284	2019-05-05 03:07:51	2019-05-05	12	[{"id_menu":1,"count":1}]	1095	delivery	5	17
2285	2019-05-05 03:18:44	2019-05-05	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1016	pick-up	0	21
2286	2019-05-05 05:14:50	2019-05-05	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1101	delivery	5	26
2287	2019-05-05 05:37:00	2019-05-05	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	378	pick-up	0	30
2288	2019-05-05 06:12:04	2019-05-05	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1097	pick-up	0	31
2289	2019-05-05 06:18:17	2019-05-05	17	[{"id_menu":4,"count":1}]	1096	delivery	5	22
2290	2019-05-05 06:34:58	2019-05-05	17	[{"id_menu":4,"count":1}]	232	pick-up	0	17
2291	2019-05-05 07:50:26	2019-05-05	8	[{"id_menu":5,"count":1}]	468	pick-up	0	8
2292	2019-05-05 08:06:33	2019-05-05	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	919	pick-up	0	20
2293	2019-05-05 09:17:28	2019-05-05	14	[{"id_menu":2,"count":1}]	996	pick-up	0	14
2294	2019-05-05 09:27:13	2019-05-05	14	[{"id_menu":2,"count":1}]	538	delivery	5	19
2295	2019-05-05 09:49:50	2019-05-05	9	[{"id_menu":7,"count":1}]	531	pick-up	0	9
2296	2019-05-05 09:51:49	2019-05-05	12	[{"id_menu":3,"count":1}]	1094	pick-up	0	12
2297	2019-05-05 10:26:30	2019-05-05	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	66	pick-up	0	38
2298	2019-05-05 10:32:13	2019-05-05	9	[{"id_menu":7,"count":1}]	403	pick-up	0	9
2299	2019-05-05 10:54:30	2019-05-05	9	[{"id_menu":7,"count":1}]	715	pick-up	0	9
2300	2019-05-05 10:58:01	2019-05-05	14	[{"id_menu":2,"count":2}]	135	pick-up	0	14
2301	2019-05-05 14:13:44	2019-05-05	43	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1093	delivery	5	48
2302	2019-05-05 14:45:13	2019-05-05	9	[{"id_menu":7,"count":1}]	389	pick-up	0	9
2303	2019-05-05 15:40:29	2019-05-05	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	867	pick-up	0	17
2304	2019-05-05 15:57:45	2019-05-05	8	[{"id_menu":5,"count":1}]	1102	pick-up	0	8
2305	2019-05-05 16:06:37	2019-05-05	17	[{"id_menu":4,"count":1}]	825	delivery	5	22
2306	2019-05-05 16:13:14	2019-05-05	12	[{"id_menu":3,"count":1}]	370	pick-up	0	12
2307	2019-05-05 17:00:35	2019-05-05	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	808	pick-up	0	17
2308	2019-05-05 17:00:46	2019-05-05	12	[{"id_menu":3,"count":1}]	1017	delivery	5	17
2309	2019-05-05 17:21:02	2019-05-05	9	[{"id_menu":7,"count":1}]	1092	pick-up	0	9
2310	2019-05-05 17:30:39	2019-05-05	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	586	delivery	5	31
2311	2019-05-05 18:39:00	2019-05-05	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1100	delivery	5	34
2312	2019-05-05 20:17:24	2019-05-05	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1099	pick-up	0	46
2313	2019-05-05 21:20:00	2019-05-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	1098	delivery	5	23
2314	2019-05-05 23:16:59	2019-05-05	12	[{"id_menu":3,"count":1}]	799	pick-up	0	12
2315	2019-05-05 23:29:50	2019-05-05	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	343	pick-up	0	26
2316	2019-05-06 00:39:55	2019-05-06	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1109	delivery	5	28
2317	2019-05-06 03:03:43	2019-05-06	12	[{"id_menu":1,"count":1}]	754	pick-up	0	12
2318	2019-05-06 05:57:43	2019-05-06	14	[{"id_menu":2,"count":2}]	1103	delivery	5	19
2319	2019-05-06 08:33:16	2019-05-06	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	376	delivery	5	22
2320	2019-05-06 08:58:31	2019-05-06	12	[{"id_menu":1,"count":1}]	730	pick-up	0	12
2321	2019-05-06 09:05:47	2019-05-06	9	[{"id_menu":6,"count":2}]	68	pick-up	0	9
2322	2019-05-06 11:40:16	2019-05-06	9	[{"id_menu":7,"count":1}]	180	pick-up	0	9
2323	2019-05-06 11:42:04	2019-05-06	14	[{"id_menu":2,"count":1}]	820	delivery	5	19
2324	2019-05-06 11:54:36	2019-05-06	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1104	pick-up	0	23
2325	2019-05-06 12:09:17	2019-05-06	12	[{"id_menu":3,"count":1}]	1106	delivery	5	17
2326	2019-05-06 12:20:16	2019-05-06	17	[{"id_menu":4,"count":1}]	26	pick-up	0	17
2327	2019-05-06 12:37:51	2019-05-06	12	[{"id_menu":1,"count":1}]	1110	delivery	5	17
2328	2019-05-06 12:45:36	2019-05-06	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1041	delivery	5	26
2329	2019-05-06 14:42:05	2019-05-06	9	[{"id_menu":7,"count":1}]	66	pick-up	0	9
2330	2019-05-06 16:59:49	2019-05-06	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	701	pick-up	0	40
2331	2019-05-06 19:53:34	2019-05-06	14	[{"id_menu":2,"count":1}]	1070	pick-up	0	14
2332	2019-05-06 22:27:34	2019-05-06	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	1111	delivery	5	29
2333	2019-05-07 00:15:49	2019-05-07	9	[{"id_menu":7,"count":1}]	1073	delivery	5	14
2334	2019-05-07 00:48:00	2019-05-07	9	[{"id_menu":6,"count":1}]	482	delivery	5	14
2335	2019-05-07 01:16:10	2019-05-07	9	[{"id_menu":7,"count":1}]	950	delivery	5	14
2336	2019-05-07 02:18:04	2019-05-07	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	638	pick-up	0	31
2337	2019-05-07 02:51:44	2019-05-07	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	233	pick-up	0	40
2338	2019-05-07 03:07:57	2019-05-07	17	[{"id_menu":4,"count":1}]	719	pick-up	0	17
2339	2019-05-07 06:41:08	2019-05-07	9	[{"id_menu":6,"count":1}]	1116	delivery	5	14
2340	2019-05-07 08:31:13	2019-05-07	9	[{"id_menu":7,"count":1}]	612	pick-up	0	9
2341	2019-05-07 09:56:52	2019-05-07	17	[{"id_menu":4,"count":1}]	1118	pick-up	0	17
2342	2019-05-07 10:38:42	2019-05-07	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1112	delivery	5	57
2343	2019-05-07 11:04:07	2019-05-07	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1119	pick-up	0	24
2344	2019-05-07 11:27:55	2019-05-07	9	[{"id_menu":6,"count":1}]	315	delivery	5	14
2345	2019-05-07 15:24:40	2019-05-07	17	[{"id_menu":4,"count":1}]	226	pick-up	0	17
2346	2019-05-07 15:26:39	2019-05-07	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1117	delivery	5	34
2347	2019-05-07 17:14:48	2019-05-07	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	905	pick-up	0	41
2348	2019-05-07 17:19:27	2019-05-07	14	[{"id_menu":2,"count":1}]	1114	pick-up	0	14
2349	2019-05-07 18:19:17	2019-05-07	12	[{"id_menu":1,"count":1}]	74	pick-up	0	12
2350	2019-05-07 19:30:44	2019-05-07	17	[{"id_menu":4,"count":1}]	620	delivery	5	22
2351	2019-05-07 20:00:04	2019-05-07	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	253	pick-up	0	34
2352	2019-05-07 20:26:58	2019-05-07	17	[{"id_menu":4,"count":1}]	81	pick-up	0	17
2353	2019-05-07 21:01:10	2019-05-07	9	[{"id_menu":6,"count":2}]	531	pick-up	0	9
2354	2019-05-07 21:14:10	2019-05-07	9	[{"id_menu":6,"count":1}]	227	delivery	5	14
2355	2019-05-07 23:17:32	2019-05-07	9	[{"id_menu":6,"count":1}]	169	pick-up	0	9
2356	2019-05-07 23:24:45	2019-05-07	12	[{"id_menu":3,"count":1}]	256	delivery	5	17
2357	2019-05-07 23:33:34	2019-05-07	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1021	pick-up	0	25
2358	2019-05-07 23:49:48	2019-05-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1115	pick-up	0	23
2359	2019-05-08 00:08:35	2019-05-08	9	[{"id_menu":6,"count":1}]	543	pick-up	0	9
2360	2019-05-08 00:44:58	2019-05-08	14	[{"id_menu":2,"count":1}]	1126	pick-up	0	14
2361	2019-05-08 01:08:37	2019-05-08	14	[{"id_menu":2,"count":1}]	974	pick-up	0	14
2362	2019-05-08 01:20:05	2019-05-08	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	627	delivery	5	22
2363	2019-05-08 01:20:21	2019-05-08	9	[{"id_menu":6,"count":1}]	729	pick-up	0	9
2364	2019-05-08 02:02:23	2019-05-08	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	215	pick-up	0	43
2365	2019-05-08 03:50:38	2019-05-08	14	[{"id_menu":2,"count":1}]	76	delivery	5	19
2366	2019-05-08 04:07:49	2019-05-08	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	411	pick-up	0	47
2367	2019-05-08 07:10:47	2019-05-08	17	[{"id_menu":4,"count":1}]	123	delivery	5	22
2368	2019-05-08 08:50:56	2019-05-08	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1122	delivery	5	40
2369	2019-05-08 09:03:44	2019-05-08	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1129	delivery	5	31
2370	2019-05-08 10:29:24	2019-05-08	12	[{"id_menu":3,"count":1}]	319	delivery	5	17
2371	2019-05-08 11:19:19	2019-05-08	8	[{"id_menu":5,"count":1}]	1021	pick-up	0	8
2372	2019-05-08 11:56:20	2019-05-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1121	pick-up	0	17
2373	2019-05-08 12:17:58	2019-05-08	17	[{"id_menu":4,"count":1}]	1125	pick-up	0	17
2374	2019-05-08 13:01:49	2019-05-08	9	[{"id_menu":7,"count":1}]	552	delivery	5	14
2375	2019-05-08 13:33:59	2019-05-08	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	437	delivery	5	55
2376	2019-05-08 14:13:21	2019-05-08	12	[{"id_menu":3,"count":1}]	1128	pick-up	0	12
2377	2019-05-08 14:23:37	2019-05-08	9	[{"id_menu":7,"count":1}]	144	delivery	5	14
2378	2019-05-08 16:32:38	2019-05-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	193	pick-up	0	23
2379	2019-05-08 16:38:31	2019-05-08	9	[{"id_menu":6,"count":1}]	1076	pick-up	0	9
2380	2019-05-08 16:58:44	2019-05-08	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	626	delivery	5	36
2381	2019-05-08 18:10:43	2019-05-08	17	[{"id_menu":4,"count":1}]	612	pick-up	0	17
2382	2019-05-08 19:15:15	2019-05-08	9	[{"id_menu":7,"count":1}]	66	pick-up	0	9
2383	2019-05-08 19:56:20	2019-05-08	9	[{"id_menu":6,"count":1}]	1123	pick-up	0	9
2384	2019-05-08 20:59:00	2019-05-08	17	[{"id_menu":4,"count":1}]	384	pick-up	0	17
2385	2019-05-08 21:09:35	2019-05-08	17	[{"id_menu":4,"count":1}]	1025	pick-up	0	17
2386	2019-05-08 21:39:03	2019-05-08	12	[{"id_menu":3,"count":1}]	1095	pick-up	0	12
2387	2019-05-09 01:19:29	2019-05-09	12	[{"id_menu":3,"count":1}]	61	delivery	5	17
2388	2019-05-09 03:47:08	2019-05-09	9	[{"id_menu":7,"count":1}]	477	pick-up	0	9
2389	2019-05-09 05:24:32	2019-05-09	17	[{"id_menu":4,"count":1}]	1138	pick-up	0	17
2390	2019-05-09 06:34:00	2019-05-09	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	458	pick-up	0	22
2391	2019-05-09 07:04:23	2019-05-09	12	[{"id_menu":3,"count":1}]	621	delivery	5	17
2392	2019-05-09 07:59:21	2019-05-09	12	[{"id_menu":1,"count":1}]	676	pick-up	0	12
2393	2019-05-09 08:41:51	2019-05-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	93	delivery	5	28
2394	2019-05-09 09:54:07	2019-05-09	14	[{"id_menu":2,"count":1}]	1133	pick-up	0	14
2395	2019-05-09 10:05:37	2019-05-09	33	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	41	pick-up	0	33
2396	2019-05-09 10:07:37	2019-05-09	14	[{"id_menu":2,"count":1}]	1134	pick-up	0	14
2397	2019-05-09 10:09:01	2019-05-09	14	[{"id_menu":2,"count":1}]	1070	pick-up	0	14
2398	2019-05-09 11:24:45	2019-05-09	9	[{"id_menu":6,"count":1}]	930	delivery	5	14
2399	2019-05-09 12:22:41	2019-05-09	8	[{"id_menu":5,"count":1}]	81	pick-up	0	8
2400	2019-05-09 12:37:20	2019-05-09	17	[{"id_menu":4,"count":1}]	932	delivery	5	22
2401	2019-05-09 13:09:39	2019-05-09	12	[{"id_menu":1,"count":1}]	654	pick-up	0	12
2402	2019-05-09 13:30:24	2019-05-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	591	delivery	5	23
2403	2019-05-09 13:34:58	2019-05-09	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	543	delivery	5	26
2404	2019-05-09 14:05:17	2019-05-09	14	[{"id_menu":2,"count":1}]	868	pick-up	0	14
2405	2019-05-09 14:07:19	2019-05-09	14	[{"id_menu":2,"count":1}]	232	pick-up	0	14
2406	2019-05-09 14:34:49	2019-05-09	8	[{"id_menu":5,"count":1}]	880	delivery	5	13
2407	2019-05-09 14:59:26	2019-05-09	8	[{"id_menu":5,"count":1}]	397	delivery	5	13
2408	2019-05-09 15:49:27	2019-05-09	8	[{"id_menu":5,"count":1}]	371	pick-up	0	8
2409	2019-05-09 15:51:22	2019-05-09	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	772	pick-up	0	37
2410	2019-05-09 16:29:04	2019-05-09	12	[{"id_menu":1,"count":1}]	1135	delivery	5	17
2411	2019-05-09 16:49:02	2019-05-09	14	[{"id_menu":2,"count":1}]	213	delivery	5	19
2412	2019-05-09 17:14:17	2019-05-09	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	567	delivery	5	42
2413	2019-05-09 17:33:42	2019-05-09	17	[{"id_menu":4,"count":1}]	569	pick-up	0	17
2414	2019-05-09 18:00:44	2019-05-09	14	[{"id_menu":2,"count":1}]	227	pick-up	0	14
2415	2019-05-09 18:36:54	2019-05-09	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1110	delivery	5	26
2416	2019-05-09 18:57:32	2019-05-09	14	[{"id_menu":2,"count":1}]	1131	pick-up	0	14
2417	2019-05-09 20:14:51	2019-05-09	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1137	delivery	5	26
2418	2019-05-10 00:29:11	2019-05-10	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	832	delivery	5	22
2419	2019-05-10 00:32:24	2019-05-10	12	[{"id_menu":3,"count":1}]	781	delivery	5	17
2420	2019-05-10 00:44:16	2019-05-10	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	621	delivery	5	31
2421	2019-05-10 01:15:29	2019-05-10	14	[{"id_menu":2,"count":1}]	1143	pick-up	0	14
2422	2019-05-10 02:06:27	2019-05-10	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	171	pick-up	0	20
2423	2019-05-10 03:00:24	2019-05-10	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	964	delivery	5	43
2424	2019-05-10 04:58:20	2019-05-10	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	362	delivery	5	38
2425	2019-05-10 07:11:12	2019-05-10	14	[{"id_menu":2,"count":1}]	1145	pick-up	0	14
2426	2019-05-10 07:33:17	2019-05-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1149	pick-up	0	17
2427	2019-05-10 07:45:58	2019-05-10	17	[{"id_menu":4,"count":1}]	138	delivery	5	22
2428	2019-05-10 07:54:02	2019-05-10	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	318	delivery	5	48
2429	2019-05-10 08:18:40	2019-05-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	999	pick-up	0	23
2430	2019-05-10 10:02:06	2019-05-10	9	[{"id_menu":7,"count":1}]	850	delivery	5	14
2431	2019-05-10 10:14:11	2019-05-10	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	274	pick-up	0	32
2432	2019-05-10 12:20:16	2019-05-10	55	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1139	delivery	5	60
2433	2019-05-10 13:31:27	2019-05-10	12	[{"id_menu":3,"count":1}]	730	pick-up	0	12
2434	2019-05-10 14:11:31	2019-05-10	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	563	pick-up	0	26
2435	2019-05-10 14:48:29	2019-05-10	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	557	pick-up	0	25
2436	2019-05-10 16:04:30	2019-05-10	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	630	pick-up	0	25
2437	2019-05-10 16:18:47	2019-05-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1144	delivery	5	22
2438	2019-05-10 18:14:11	2019-05-10	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	440	delivery	5	57
2439	2019-05-10 18:27:14	2019-05-10	17	[{"id_menu":4,"count":1}]	841	pick-up	0	17
2440	2019-05-10 20:17:39	2019-05-10	12	[{"id_menu":3,"count":1}]	1140	pick-up	0	12
2441	2019-05-10 21:18:42	2019-05-10	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	676	pick-up	0	26
2442	2019-05-10 23:02:13	2019-05-10	9	[{"id_menu":6,"count":1}]	452	pick-up	0	9
2443	2019-05-10 23:41:19	2019-05-10	12	[{"id_menu":1,"count":1}]	711	pick-up	0	12
2444	2019-05-11 00:29:35	2019-05-11	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1156	pick-up	0	40
2445	2019-05-11 00:47:40	2019-05-11	9	[{"id_menu":6,"count":1}]	1160	pick-up	0	9
2446	2019-05-11 00:51:21	2019-05-11	14	[{"id_menu":2,"count":1}]	787	delivery	5	19
2447	2019-05-11 00:53:25	2019-05-11	12	[{"id_menu":1,"count":1}]	950	pick-up	0	12
2448	2019-05-11 01:16:11	2019-05-11	8	[{"id_menu":5,"count":1}]	952	delivery	5	13
2449	2019-05-11 01:33:07	2019-05-11	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	481	delivery	5	34
2450	2019-05-11 01:40:36	2019-05-11	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1157	delivery	5	28
2451	2019-05-11 01:55:17	2019-05-11	9	[{"id_menu":7,"count":1}]	1155	pick-up	0	9
2452	2019-05-11 03:19:42	2019-05-11	12	[{"id_menu":1,"count":1}]	575	pick-up	0	12
2453	2019-05-11 03:41:05	2019-05-11	12	[{"id_menu":1,"count":1}]	1152	delivery	5	17
2454	2019-05-11 05:22:25	2019-05-11	14	[{"id_menu":2,"count":1}]	1158	pick-up	0	14
2455	2019-05-11 07:05:16	2019-05-11	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	653	delivery	5	52
2456	2019-05-11 08:13:50	2019-05-11	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	359	pick-up	0	34
2457	2019-05-11 09:01:16	2019-05-11	14	[{"id_menu":2,"count":1}]	228	pick-up	0	14
2458	2019-05-11 10:51:54	2019-05-11	17	[{"id_menu":4,"count":1}]	1154	delivery	5	22
2459	2019-05-11 12:55:22	2019-05-11	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	527	pick-up	0	29
2460	2019-05-11 14:00:02	2019-05-11	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	197	pick-up	0	23
2461	2019-05-11 14:28:52	2019-05-11	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1151	delivery	5	28
2462	2019-05-11 14:37:22	2019-05-11	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	154	pick-up	0	26
2463	2019-05-11 15:42:30	2019-05-11	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	41	pick-up	0	25
2464	2019-05-11 15:48:25	2019-05-11	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1159	pick-up	0	21
2465	2019-05-11 17:48:08	2019-05-11	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29	pick-up	0	17
2466	2019-05-11 18:14:09	2019-05-11	14	[{"id_menu":2,"count":1}]	1150	delivery	5	19
2467	2019-05-11 20:13:20	2019-05-11	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1153	delivery	5	40
2468	2019-05-11 21:21:39	2019-05-11	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	108	pick-up	0	47
2469	2019-05-12 00:21:00	2019-05-12	17	[{"id_menu":4,"count":1}]	682	pick-up	0	17
2470	2019-05-12 00:57:31	2019-05-12	17	[{"id_menu":4,"count":2}]	1104	pick-up	0	17
2471	2019-05-12 01:25:40	2019-05-12	14	[{"id_menu":2,"count":1}]	996	delivery	5	19
2472	2019-05-12 01:38:37	2019-05-12	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	506	delivery	5	31
2473	2019-05-12 02:26:36	2019-05-12	9	[{"id_menu":6,"count":1}]	1070	pick-up	0	9
2474	2019-05-12 02:40:30	2019-05-12	17	[{"id_menu":4,"count":1}]	204	pick-up	0	17
2475	2019-05-12 02:41:05	2019-05-12	12	[{"id_menu":1,"count":1}]	868	delivery	5	17
2476	2019-05-12 04:17:49	2019-05-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	787	delivery	5	23
2477	2019-05-12 04:18:22	2019-05-12	8	[{"id_menu":5,"count":1}]	466	delivery	5	13
2478	2019-05-12 04:48:25	2019-05-12	9	[{"id_menu":6,"count":1}]	593	pick-up	0	9
2479	2019-05-12 04:52:15	2019-05-12	9	[{"id_menu":6,"count":1}]	1161	pick-up	0	9
2480	2019-05-12 05:05:35	2019-05-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	293	pick-up	0	17
2481	2019-05-12 05:06:28	2019-05-12	12	[{"id_menu":3,"count":1}]	1007	pick-up	0	12
2482	2019-05-12 05:35:51	2019-05-12	17	[{"id_menu":4,"count":1}]	236	pick-up	0	17
2483	2019-05-12 05:37:36	2019-05-12	12	[{"id_menu":1,"count":1}]	1170	pick-up	0	12
2484	2019-05-12 07:48:02	2019-05-12	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	418	pick-up	0	29
2485	2019-05-12 07:49:51	2019-05-12	8	[{"id_menu":5,"count":1}]	193	delivery	5	13
2486	2019-05-12 08:02:16	2019-05-12	9	[{"id_menu":7,"count":1}]	1025	delivery	5	14
2487	2019-05-12 08:09:43	2019-05-12	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	669	pick-up	0	17
2488	2019-05-12 08:34:58	2019-05-12	9	[{"id_menu":6,"count":2}]	975	delivery	5	14
2489	2019-05-12 09:00:05	2019-05-12	14	[{"id_menu":2,"count":2}]	375	delivery	5	19
2490	2019-05-12 09:09:31	2019-05-12	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1163	delivery	5	45
2491	2019-05-12 09:10:10	2019-05-12	12	[{"id_menu":3,"count":1}]	228	pick-up	0	12
2492	2019-05-12 10:07:03	2019-05-12	9	[{"id_menu":7,"count":1}]	462	delivery	5	14
2493	2019-05-12 10:41:42	2019-05-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	285	pick-up	0	17
2494	2019-05-12 11:32:54	2019-05-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	677	pick-up	0	18
2495	2019-05-12 12:49:44	2019-05-12	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	688	delivery	5	27
2496	2019-05-12 12:57:23	2019-05-12	9	[{"id_menu":6,"count":1}]	678	pick-up	0	9
2497	2019-05-12 13:23:28	2019-05-12	12	[{"id_menu":1,"count":3}]	394	pick-up	0	12
2498	2019-05-12 14:38:11	2019-05-12	9	[{"id_menu":7,"count":1}]	203	pick-up	0	9
2499	2019-05-12 14:40:40	2019-05-12	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1171	pick-up	0	21
2500	2019-05-12 14:56:29	2019-05-12	14	[{"id_menu":2,"count":1}]	214	delivery	5	19
2501	2019-05-12 15:14:16	2019-05-12	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	847	pick-up	0	20
2502	2019-05-12 15:44:58	2019-05-12	9	[{"id_menu":7,"count":1}]	1169	pick-up	0	9
2503	2019-05-12 16:10:10	2019-05-12	14	[{"id_menu":2,"count":1}]	1165	pick-up	0	14
2504	2019-05-12 16:33:19	2019-05-12	12	[{"id_menu":1,"count":1}]	585	delivery	5	17
2505	2019-05-12 17:15:34	2019-05-12	9	[{"id_menu":7,"count":1}]	1162	pick-up	0	9
2506	2019-05-12 17:51:39	2019-05-12	17	[{"id_menu":4,"count":1}]	123	pick-up	0	17
2507	2019-05-12 18:56:13	2019-05-12	17	[{"id_menu":4,"count":2}]	184	delivery	5	22
2508	2019-05-12 20:34:57	2019-05-12	12	[{"id_menu":1,"count":1}]	467	delivery	5	17
2509	2019-05-12 20:41:13	2019-05-12	12	[{"id_menu":1,"count":1}]	256	pick-up	0	12
2510	2019-05-12 20:43:14	2019-05-12	17	[{"id_menu":4,"count":1}]	34	delivery	5	22
2511	2019-05-12 20:44:55	2019-05-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1166	pick-up	0	23
2512	2019-05-12 20:49:54	2019-05-12	12	[{"id_menu":1,"count":1}]	270	pick-up	0	12
2513	2019-05-12 20:51:25	2019-05-12	12	[{"id_menu":1,"count":1}]	1168	pick-up	0	12
2514	2019-05-12 21:05:17	2019-05-12	9	[{"id_menu":7,"count":1}]	145	pick-up	0	9
2515	2019-05-12 21:48:38	2019-05-12	8	[{"id_menu":5,"count":1}]	126	pick-up	0	8
2516	2019-05-12 22:14:10	2019-05-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	440	delivery	5	31
2517	2019-05-12 23:21:24	2019-05-12	12	[{"id_menu":3,"count":1}]	386	pick-up	0	12
2518	2019-05-12 23:26:51	2019-05-12	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	1167	delivery	5	26
2519	2019-05-12 23:51:10	2019-05-12	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1164	pick-up	0	29
2520	2019-05-13 02:51:53	2019-05-13	9	[{"id_menu":7,"count":1}]	222	pick-up	0	9
2521	2019-05-13 06:16:32	2019-05-13	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	78	delivery	5	34
2522	2019-05-13 06:46:54	2019-05-13	12	[{"id_menu":1,"count":1}]	1175	delivery	5	17
2523	2019-05-13 08:54:35	2019-05-13	17	[{"id_menu":4,"count":1}]	440	delivery	5	22
2524	2019-05-13 10:03:34	2019-05-13	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	41	pick-up	0	23
2525	2019-05-13 12:50:47	2019-05-13	9	[{"id_menu":7,"count":1}]	1180	delivery	5	14
2526	2019-05-13 14:43:51	2019-05-13	8	[{"id_menu":5,"count":1}]	1173	delivery	5	13
2527	2019-05-13 19:36:05	2019-05-13	12	[{"id_menu":1,"count":1}]	1178	delivery	5	17
2528	2019-05-13 22:49:02	2019-05-13	9	[{"id_menu":6,"count":1}]	171	pick-up	0	9
2529	2019-05-13 23:10:17	2019-05-13	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1176	delivery	5	30
2530	2019-05-14 00:29:24	2019-05-14	14	[{"id_menu":2,"count":1}]	1190	pick-up	0	14
2531	2019-05-14 00:40:21	2019-05-14	9	[{"id_menu":7,"count":1}]	1182	pick-up	0	9
2532	2019-05-14 01:36:15	2019-05-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	74	pick-up	0	31
2533	2019-05-14 01:40:20	2019-05-14	17	[{"id_menu":4,"count":1}]	973	pick-up	0	17
2534	2019-05-14 02:40:39	2019-05-14	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	1186	delivery	5	28
2535	2019-05-14 03:05:48	2019-05-14	9	[{"id_menu":7,"count":1}]	592	delivery	5	14
2536	2019-05-14 03:40:28	2019-05-14	12	[{"id_menu":1,"count":1}]	376	pick-up	0	12
2537	2019-05-14 03:53:21	2019-05-14	14	[{"id_menu":2,"count":1}]	1080	pick-up	0	14
2538	2019-05-14 04:11:11	2019-05-14	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	714	pick-up	0	26
2539	2019-05-14 05:56:57	2019-05-14	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1014	delivery	5	25
2540	2019-05-14 06:59:13	2019-05-14	14	[{"id_menu":2,"count":1}]	1107	pick-up	0	14
2541	2019-05-14 08:46:37	2019-05-14	12	[{"id_menu":1,"count":1}]	691	pick-up	0	12
2542	2019-05-14 08:55:47	2019-05-14	14	[{"id_menu":2,"count":1}]	99	pick-up	0	14
2543	2019-05-14 09:33:41	2019-05-14	12	[{"id_menu":3,"count":1}]	1189	pick-up	0	12
2544	2019-05-14 12:07:17	2019-05-14	17	[{"id_menu":4,"count":1}]	1183	pick-up	0	17
2545	2019-05-14 14:19:42	2019-05-14	12	[{"id_menu":1,"count":1}]	548	pick-up	0	12
2546	2019-05-14 16:11:55	2019-05-14	12	[{"id_menu":1,"count":1}]	964	delivery	5	17
2547	2019-05-14 16:32:35	2019-05-14	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	667	delivery	5	31
2548	2019-05-14 17:03:11	2019-05-14	12	[{"id_menu":1,"count":1}]	228	delivery	5	17
2549	2019-05-14 17:29:04	2019-05-14	9	[{"id_menu":6,"count":1}]	71	pick-up	0	9
2550	2019-05-14 19:58:23	2019-05-14	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1173	delivery	5	34
2551	2019-05-14 20:11:05	2019-05-14	9	[{"id_menu":6,"count":1}]	282	pick-up	0	9
2552	2019-05-14 20:58:02	2019-05-14	17	[{"id_menu":4,"count":2}]	1184	pick-up	0	17
2553	2019-05-14 21:55:05	2019-05-14	12	[{"id_menu":3,"count":1}]	749	pick-up	0	12
2554	2019-05-14 22:56:36	2019-05-14	9	[{"id_menu":6,"count":1}]	563	pick-up	0	9
2555	2019-05-15 00:01:19	2019-05-15	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1195	delivery	5	35
2556	2019-05-15 01:43:24	2019-05-15	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	527	pick-up	0	17
2557	2019-05-15 04:09:17	2019-05-15	14	[{"id_menu":2,"count":1}]	1192	delivery	5	19
2558	2019-05-15 05:18:24	2019-05-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	660	pick-up	0	18
2559	2019-05-15 06:44:10	2019-05-15	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	796	delivery	5	26
2560	2019-05-15 07:18:30	2019-05-15	9	[{"id_menu":6,"count":1}]	1113	pick-up	0	9
2561	2019-05-15 08:29:23	2019-05-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	81	delivery	5	28
2562	2019-05-15 09:03:20	2019-05-15	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	817	pick-up	0	26
2563	2019-05-15 09:26:46	2019-05-15	12	[{"id_menu":3,"count":1}]	1055	pick-up	0	12
2564	2019-05-15 09:37:16	2019-05-15	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1191	pick-up	0	26
2565	2019-05-15 09:59:20	2019-05-15	14	[{"id_menu":2,"count":1}]	934	delivery	5	19
2566	2019-05-15 11:26:39	2019-05-15	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1199	pick-up	0	26
2567	2019-05-15 11:40:46	2019-05-15	8	[{"id_menu":5,"count":1}]	1197	pick-up	0	8
2568	2019-05-15 12:06:14	2019-05-15	17	[{"id_menu":4,"count":1}]	1193	pick-up	0	17
2569	2019-05-15 12:18:50	2019-05-15	12	[{"id_menu":3,"count":1}]	462	delivery	5	17
2570	2019-05-15 12:28:42	2019-05-15	12	[{"id_menu":3,"count":2}]	1196	delivery	5	17
2571	2019-05-15 12:50:50	2019-05-15	9	[{"id_menu":6,"count":1}]	366	delivery	5	14
2572	2019-05-15 13:22:52	2019-05-15	14	[{"id_menu":2,"count":1}]	1180	pick-up	0	14
2573	2019-05-15 13:25:18	2019-05-15	14	[{"id_menu":2,"count":1}]	659	pick-up	0	14
2574	2019-05-15 14:20:56	2019-05-15	8	[{"id_menu":5,"count":1}]	1095	pick-up	0	8
2575	2019-05-15 14:34:51	2019-05-15	12	[{"id_menu":3,"count":1}]	599	pick-up	0	12
2576	2019-05-15 14:37:38	2019-05-15	14	[{"id_menu":2,"count":1}]	1194	pick-up	0	14
2577	2019-05-15 16:23:06	2019-05-15	9	[{"id_menu":6,"count":1}]	677	delivery	5	14
2578	2019-05-15 17:31:33	2019-05-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1143	delivery	5	28
2579	2019-05-15 17:31:50	2019-05-15	12	[{"id_menu":1,"count":1}]	1140	pick-up	0	12
2580	2019-05-15 18:05:16	2019-05-15	9	[{"id_menu":6,"count":1}]	416	delivery	5	14
2581	2019-05-15 18:45:11	2019-05-15	8	[{"id_menu":5,"count":1}]	1198	pick-up	0	8
2582	2019-05-15 18:46:40	2019-05-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	518	delivery	5	28
2583	2019-05-15 19:15:05	2019-05-15	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	950	pick-up	0	17
2584	2019-05-15 20:22:44	2019-05-15	9	[{"id_menu":7,"count":1}]	1138	pick-up	0	9
2585	2019-05-15 21:40:12	2019-05-15	9	[{"id_menu":7,"count":1}]	713	delivery	5	14
2586	2019-05-15 21:49:01	2019-05-15	9	[{"id_menu":6,"count":2}]	996	pick-up	0	9
2587	2019-05-15 23:40:15	2019-05-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	399	delivery	5	23
2588	2019-05-15 23:56:17	2019-05-15	12	[{"id_menu":1,"count":1}]	312	delivery	5	17
2589	2019-05-16 00:46:11	2019-05-16	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	602	delivery	5	39
2590	2019-05-16 02:29:15	2019-05-16	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	325	delivery	5	36
2591	2019-05-16 03:22:20	2019-05-16	14	[{"id_menu":2,"count":1}]	110	pick-up	0	14
2592	2019-05-16 03:31:54	2019-05-16	8	[{"id_menu":5,"count":1}]	1204	delivery	5	13
2593	2019-05-16 04:00:39	2019-05-16	17	[{"id_menu":4,"count":1}]	1208	delivery	5	22
2594	2019-05-16 04:04:40	2019-05-16	12	[{"id_menu":1,"count":1}]	291	pick-up	0	12
2595	2019-05-16 04:05:48	2019-05-16	12	[{"id_menu":3,"count":1}]	640	delivery	5	17
2596	2019-05-16 04:17:09	2019-05-16	17	[{"id_menu":4,"count":1}]	946	pick-up	0	17
2597	2019-05-16 05:01:51	2019-05-16	9	[{"id_menu":6,"count":1}]	257	pick-up	0	9
2598	2019-05-16 07:48:00	2019-05-16	17	[{"id_menu":4,"count":1}]	1206	delivery	5	22
2599	2019-05-16 08:15:15	2019-05-16	17	[{"id_menu":4,"count":1}]	1095	delivery	5	22
2600	2019-05-16 08:15:39	2019-05-16	8	[{"id_menu":5,"count":1}]	1143	pick-up	0	8
2601	2019-05-16 08:18:18	2019-05-16	9	[{"id_menu":7,"count":1}]	376	pick-up	0	9
2602	2019-05-16 08:20:21	2019-05-16	8	[{"id_menu":5,"count":1}]	1202	pick-up	0	8
2603	2019-05-16 08:23:24	2019-05-16	9	[{"id_menu":6,"count":1}]	1203	delivery	5	14
2604	2019-05-16 08:35:25	2019-05-16	8	[{"id_menu":5,"count":1}]	1088	pick-up	0	8
2605	2019-05-16 08:39:03	2019-05-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	950	pick-up	0	26
2606	2019-05-16 09:53:32	2019-05-16	12	[{"id_menu":3,"count":1}]	1205	delivery	5	17
2607	2019-05-16 14:50:30	2019-05-16	9	[{"id_menu":6,"count":1}]	1200	delivery	5	14
2608	2019-05-16 18:59:22	2019-05-16	9	[{"id_menu":7,"count":1}]	1072	delivery	5	14
2609	2019-05-16 20:01:15	2019-05-16	17	[{"id_menu":4,"count":1}]	1021	delivery	5	22
2610	2019-05-16 20:19:34	2019-05-16	8	[{"id_menu":5,"count":2}]	957	pick-up	0	8
2611	2019-05-16 20:37:46	2019-05-16	14	[{"id_menu":2,"count":1}]	926	pick-up	0	14
2612	2019-05-16 22:26:47	2019-05-16	8	[{"id_menu":5,"count":1}]	1055	pick-up	0	8
2613	2019-05-16 22:58:23	2019-05-16	8	[{"id_menu":5,"count":1}]	217	pick-up	0	8
2614	2019-05-16 23:43:19	2019-05-16	9	[{"id_menu":6,"count":1}]	1201	pick-up	0	9
2615	2019-05-17 00:14:14	2019-05-17	9	[{"id_menu":6,"count":1}]	1107	delivery	5	14
2616	2019-05-17 01:34:37	2019-05-17	8	[{"id_menu":5,"count":1}]	76	pick-up	0	8
2617	2019-05-17 02:40:23	2019-05-17	9	[{"id_menu":6,"count":1}]	661	delivery	5	14
2618	2019-05-17 03:56:41	2019-05-17	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	467	pick-up	0	31
2619	2019-05-17 04:01:24	2019-05-17	12	[{"id_menu":1,"count":1}]	1214	delivery	5	17
2620	2019-05-17 04:42:51	2019-05-17	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1212	pick-up	0	29
2621	2019-05-17 05:21:19	2019-05-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	963	pick-up	0	26
2622	2019-05-17 06:01:26	2019-05-17	14	[{"id_menu":2,"count":1}]	1216	pick-up	0	14
2623	2019-05-17 06:11:16	2019-05-17	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	371	pick-up	0	26
2624	2019-05-17 06:24:18	2019-05-17	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1115	pick-up	0	34
2625	2019-05-17 06:51:35	2019-05-17	9	[{"id_menu":7,"count":1}]	197	pick-up	0	9
2626	2019-05-17 08:01:24	2019-05-17	9	[{"id_menu":7,"count":1}]	763	pick-up	0	9
2627	2019-05-17 09:09:33	2019-05-17	9	[{"id_menu":6,"count":1}]	1217	pick-up	0	9
2628	2019-05-17 09:16:54	2019-05-17	12	[{"id_menu":3,"count":1}]	1210	pick-up	0	12
2629	2019-05-17 10:52:41	2019-05-17	9	[{"id_menu":6,"count":1}]	1211	pick-up	0	9
2630	2019-05-17 11:13:31	2019-05-17	12	[{"id_menu":1,"count":1}]	808	delivery	5	17
2631	2019-05-17 12:47:06	2019-05-17	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1213	delivery	5	36
2632	2019-05-17 14:35:08	2019-05-17	12	[{"id_menu":3,"count":1}]	41	pick-up	0	12
2633	2019-05-17 16:15:09	2019-05-17	9	[{"id_menu":6,"count":1}]	469	delivery	5	14
2634	2019-05-17 17:27:53	2019-05-17	8	[{"id_menu":5,"count":1}]	1215	pick-up	0	8
2635	2019-05-17 18:00:36	2019-05-17	12	[{"id_menu":1,"count":1}]	980	pick-up	0	12
2636	2019-05-17 18:15:03	2019-05-17	12	[{"id_menu":1,"count":1}]	1209	pick-up	0	12
2637	2019-05-17 18:32:31	2019-05-17	8	[{"id_menu":5,"count":1}]	1219	delivery	5	13
2638	2019-05-17 19:02:46	2019-05-17	14	[{"id_menu":2,"count":1}]	1208	pick-up	0	14
2639	2019-05-17 19:35:19	2019-05-17	9	[{"id_menu":6,"count":1}]	1044	pick-up	0	9
2640	2019-05-17 20:31:35	2019-05-17	9	[{"id_menu":6,"count":1}]	722	delivery	5	14
2641	2019-05-17 21:01:54	2019-05-17	14	[{"id_menu":2,"count":1}]	207	delivery	5	19
2642	2019-05-17 22:10:40	2019-05-17	8	[{"id_menu":5,"count":1}]	1148	pick-up	0	8
2643	2019-05-17 23:27:37	2019-05-17	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	333	pick-up	0	21
2644	2019-05-18 00:48:49	2019-05-18	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	171	pick-up	0	26
2645	2019-05-18 00:50:13	2019-05-18	12	[{"id_menu":3,"count":1}]	123	delivery	5	17
2646	2019-05-18 00:53:56	2019-05-18	14	[{"id_menu":2,"count":1}]	1228	delivery	5	19
2647	2019-05-18 00:58:33	2019-05-18	9	[{"id_menu":6,"count":1}]	229	delivery	5	14
2648	2019-05-18 01:04:31	2019-05-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	189	pick-up	0	23
2649	2019-05-18 01:08:18	2019-05-18	12	[{"id_menu":3,"count":1}]	36	pick-up	0	12
2650	2019-05-18 01:11:32	2019-05-18	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	443	delivery	5	48
2651	2019-05-18 01:20:44	2019-05-18	9	[{"id_menu":6,"count":1}]	511	pick-up	0	9
2652	2019-05-18 01:56:30	2019-05-18	12	[{"id_menu":3,"count":1}]	1229	pick-up	0	12
2653	2019-05-18 02:29:56	2019-05-18	12	[{"id_menu":3,"count":1}]	176	delivery	5	17
2654	2019-05-18 02:53:30	2019-05-18	9	[{"id_menu":6,"count":1}]	779	delivery	5	14
2655	2019-05-18 03:17:31	2019-05-18	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	628	delivery	5	52
2656	2019-05-18 03:55:07	2019-05-18	12	[{"id_menu":3,"count":1}]	609	delivery	5	17
2657	2019-05-18 04:34:48	2019-05-18	14	[{"id_menu":2,"count":1}]	1124	delivery	5	19
2658	2019-05-18 04:51:24	2019-05-18	14	[{"id_menu":2,"count":1}]	352	pick-up	0	14
2659	2019-05-18 05:11:02	2019-05-18	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	233	pick-up	0	34
2660	2019-05-18 06:11:31	2019-05-18	17	[{"id_menu":4,"count":1}]	1230	delivery	5	22
2661	2019-05-18 08:13:21	2019-05-18	12	[{"id_menu":1,"count":1}]	803	pick-up	0	12
2662	2019-05-18 09:00:43	2019-05-18	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	575	pick-up	0	20
2663	2019-05-18 09:26:05	2019-05-18	14	[{"id_menu":2,"count":1}]	1220	delivery	5	19
2664	2019-05-18 09:30:01	2019-05-18	17	[{"id_menu":4,"count":1}]	577	delivery	5	22
2665	2019-05-18 09:59:41	2019-05-18	17	[{"id_menu":4,"count":1}]	322	delivery	5	22
2666	2019-05-18 10:00:46	2019-05-18	17	[{"id_menu":4,"count":1}]	1225	pick-up	0	17
2667	2019-05-18 10:23:34	2019-05-18	12	[{"id_menu":3,"count":1}]	275	pick-up	0	12
2668	2019-05-18 10:52:49	2019-05-18	12	[{"id_menu":3,"count":1}]	1119	pick-up	0	12
2669	2019-05-18 11:12:33	2019-05-18	9	[{"id_menu":6,"count":1}]	1221	pick-up	0	9
2670	2019-05-18 11:13:58	2019-05-18	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	748	delivery	5	47
2671	2019-05-18 11:22:52	2019-05-18	14	[{"id_menu":2,"count":1}]	1058	pick-up	0	14
2672	2019-05-18 12:05:55	2019-05-18	9	[{"id_menu":7,"count":1}]	310	delivery	5	14
2673	2019-05-18 12:09:01	2019-05-18	9	[{"id_menu":7,"count":1}]	766	pick-up	0	9
2674	2019-05-18 13:43:47	2019-05-18	9	[{"id_menu":7,"count":1}]	1044	delivery	5	14
2675	2019-05-18 14:01:31	2019-05-18	12	[{"id_menu":3,"count":1}]	227	delivery	5	17
2676	2019-05-18 14:49:03	2019-05-18	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1211	pick-up	0	26
2677	2019-05-18 15:11:11	2019-05-18	12	[{"id_menu":1,"count":1}]	683	pick-up	0	12
2678	2019-05-18 15:26:21	2019-05-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	798	pick-up	0	17
2679	2019-05-18 15:32:41	2019-05-18	9	[{"id_menu":7,"count":1}]	304	pick-up	0	9
2680	2019-05-18 16:26:58	2019-05-18	14	[{"id_menu":2,"count":1}]	1226	pick-up	0	14
2681	2019-05-18 16:31:43	2019-05-18	12	[{"id_menu":1,"count":1}]	757	pick-up	0	12
2682	2019-05-18 18:17:45	2019-05-18	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	763	pick-up	0	37
2683	2019-05-18 18:35:34	2019-05-18	17	[{"id_menu":4,"count":1}]	360	pick-up	0	17
2684	2019-05-18 18:45:48	2019-05-18	12	[{"id_menu":1,"count":1}]	1224	delivery	5	17
2685	2019-05-18 19:37:24	2019-05-18	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	925	pick-up	0	22
2686	2019-05-18 19:52:51	2019-05-18	12	[{"id_menu":3,"count":1}]	1170	delivery	5	17
2687	2019-05-18 19:58:57	2019-05-18	8	[{"id_menu":5,"count":1}]	314	pick-up	0	8
2688	2019-05-18 20:14:47	2019-05-18	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1227	pick-up	0	40
2689	2019-05-18 20:38:31	2019-05-18	14	[{"id_menu":2,"count":1}]	1021	delivery	5	19
2690	2019-05-18 20:47:31	2019-05-18	8	[{"id_menu":5,"count":1}]	293	pick-up	0	8
2691	2019-05-18 21:10:53	2019-05-18	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1223	pick-up	0	21
2692	2019-05-18 21:38:00	2019-05-18	17	[{"id_menu":4,"count":1}]	654	pick-up	0	17
2693	2019-05-18 21:56:24	2019-05-18	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1222	pick-up	0	34
2694	2019-05-18 22:20:11	2019-05-18	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1128	delivery	5	22
2695	2019-05-18 22:48:56	2019-05-18	9	[{"id_menu":6,"count":1}]	1135	delivery	5	14
2696	2019-05-18 23:06:30	2019-05-18	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	4	pick-up	0	34
2697	2019-05-19 00:37:20	2019-05-19	17	[{"id_menu":4,"count":1}]	1232	delivery	5	22
2698	2019-05-19 01:03:02	2019-05-19	14	[{"id_menu":2,"count":1}]	591	delivery	5	19
2699	2019-05-19 01:22:34	2019-05-19	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1238	pick-up	0	21
2700	2019-05-19 01:52:38	2019-05-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	285	delivery	5	36
2701	2019-05-19 02:18:29	2019-05-19	14	[{"id_menu":2,"count":1}]	27	delivery	5	19
2702	2019-05-19 02:47:06	2019-05-19	12	[{"id_menu":1,"count":1}]	1234	delivery	5	17
2703	2019-05-19 03:10:55	2019-05-19	14	[{"id_menu":2,"count":1}]	1233	pick-up	0	14
2704	2019-05-19 03:58:59	2019-05-19	9	[{"id_menu":7,"count":1}]	154	delivery	5	14
2705	2019-05-19 04:49:11	2019-05-19	17	[{"id_menu":4,"count":1}]	1235	pick-up	0	17
2706	2019-05-19 07:50:40	2019-05-19	9	[{"id_menu":7,"count":1}]	441	delivery	5	14
2707	2019-05-19 08:11:30	2019-05-19	12	[{"id_menu":1,"count":1}]	581	delivery	5	17
2708	2019-05-19 09:00:31	2019-05-19	9	[{"id_menu":7,"count":1}]	178	pick-up	0	9
2709	2019-05-19 09:22:38	2019-05-19	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	609	pick-up	0	22
2710	2019-05-19 09:48:50	2019-05-19	9	[{"id_menu":6,"count":1}]	713	delivery	5	14
2711	2019-05-19 10:26:42	2019-05-19	17	[{"id_menu":4,"count":2}]	1237	pick-up	0	17
2712	2019-05-19 10:52:19	2019-05-19	12	[{"id_menu":1,"count":1}]	81	delivery	5	17
2713	2019-05-19 11:13:54	2019-05-19	12	[{"id_menu":1,"count":1}]	1195	delivery	5	17
2714	2019-05-19 12:18:05	2019-05-19	9	[{"id_menu":6,"count":1}]	1183	pick-up	0	9
2715	2019-05-19 13:15:40	2019-05-19	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	148	delivery	5	31
2716	2019-05-19 13:52:19	2019-05-19	17	[{"id_menu":4,"count":1}]	397	delivery	5	22
2717	2019-05-19 14:17:40	2019-05-19	14	[{"id_menu":2,"count":1}]	464	pick-up	0	14
2718	2019-05-19 15:00:22	2019-05-19	12	[{"id_menu":1,"count":1}]	379	pick-up	0	12
2719	2019-05-19 15:22:00	2019-05-19	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	466	delivery	5	31
2720	2019-05-19 15:43:02	2019-05-19	14	[{"id_menu":2,"count":1}]	228	pick-up	0	14
2721	2019-05-19 15:45:12	2019-05-19	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	754	pick-up	0	25
2722	2019-05-19 16:22:27	2019-05-19	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1239	pick-up	0	34
2723	2019-05-19 16:31:12	2019-05-19	12	[{"id_menu":3,"count":1}]	158	delivery	5	17
2724	2019-05-19 16:42:15	2019-05-19	9	[{"id_menu":6,"count":1}]	193	delivery	5	14
2725	2019-05-19 16:48:02	2019-05-19	14	[{"id_menu":2,"count":1}]	1095	delivery	5	19
2726	2019-05-19 16:50:47	2019-05-19	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	126	pick-up	0	35
2727	2019-05-19 17:53:46	2019-05-19	12	[{"id_menu":1,"count":1}]	841	pick-up	0	12
2728	2019-05-19 18:17:13	2019-05-19	8	[{"id_menu":5,"count":1}]	973	pick-up	0	8
2729	2019-05-19 19:07:43	2019-05-19	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	995	delivery	5	25
2730	2019-05-19 19:33:38	2019-05-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	832	delivery	5	23
2731	2019-05-19 19:41:33	2019-05-19	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	981	pick-up	0	24
2732	2019-05-19 20:00:26	2019-05-19	9	[{"id_menu":6,"count":1}]	840	pick-up	0	9
2733	2019-05-19 20:40:10	2019-05-19	9	[{"id_menu":6,"count":1}]	802	delivery	5	14
2734	2019-05-19 20:50:50	2019-05-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1231	pick-up	0	23
2735	2019-05-19 21:41:54	2019-05-19	17	[{"id_menu":4,"count":1}]	1109	delivery	5	22
2736	2019-05-19 21:46:21	2019-05-19	9	[{"id_menu":6,"count":1}]	1240	delivery	5	14
2737	2019-05-19 22:07:33	2019-05-19	12	[{"id_menu":1,"count":1}]	1241	pick-up	0	12
2738	2019-05-19 22:10:05	2019-05-19	12	[{"id_menu":3,"count":1}]	378	delivery	5	17
2739	2019-05-19 22:35:06	2019-05-19	12	[{"id_menu":1,"count":1}]	480	delivery	5	17
2740	2019-05-19 22:49:06	2019-05-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	970	pick-up	0	18
2741	2019-05-19 23:35:26	2019-05-19	12	[{"id_menu":3,"count":1}]	68	delivery	5	17
2742	2019-05-19 23:36:39	2019-05-19	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	519	delivery	5	34
2743	2019-05-19 23:38:29	2019-05-19	14	[{"id_menu":2,"count":1}]	953	delivery	5	19
2744	2019-05-19 23:49:41	2019-05-19	17	[{"id_menu":4,"count":1}]	1236	pick-up	0	17
2745	2019-05-20 00:19:37	2019-05-20	14	[{"id_menu":2,"count":1}]	66	pick-up	0	14
2746	2019-05-20 00:59:21	2019-05-20	9	[{"id_menu":6,"count":1}]	742	delivery	5	14
2747	2019-05-20 02:35:16	2019-05-20	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	802	pick-up	0	43
2748	2019-05-20 03:10:56	2019-05-20	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	477	pick-up	0	38
2749	2019-05-20 03:43:16	2019-05-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1155	pick-up	0	23
2750	2019-05-20 05:53:39	2019-05-20	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1092	pick-up	0	21
2751	2019-05-20 07:25:49	2019-05-20	17	[{"id_menu":4,"count":1}]	1244	pick-up	0	17
2752	2019-05-20 07:53:34	2019-05-20	8	[{"id_menu":5,"count":2}]	820	pick-up	0	8
2753	2019-05-20 08:58:42	2019-05-20	14	[{"id_menu":2,"count":1}]	627	pick-up	0	14
2754	2019-05-20 08:59:39	2019-05-20	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	901	pick-up	0	26
2755	2019-05-20 09:38:21	2019-05-20	12	[{"id_menu":1,"count":1}]	376	delivery	5	17
2756	2019-05-20 12:51:59	2019-05-20	12	[{"id_menu":3,"count":1}]	367	delivery	5	17
2757	2019-05-20 14:06:28	2019-05-20	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	322	pick-up	0	21
2758	2019-05-20 14:38:30	2019-05-20	12	[{"id_menu":1,"count":1}]	1119	delivery	5	17
2759	2019-05-20 14:54:51	2019-05-20	8	[{"id_menu":5,"count":1}]	1148	pick-up	0	8
2760	2019-05-20 16:20:39	2019-05-20	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	821	pick-up	0	17
2761	2019-05-20 17:49:11	2019-05-20	9	[{"id_menu":6,"count":1}]	781	pick-up	0	9
2762	2019-05-20 18:12:07	2019-05-20	14	[{"id_menu":2,"count":1}]	730	delivery	5	19
2763	2019-05-20 18:20:54	2019-05-20	9	[{"id_menu":6,"count":1}]	1248	pick-up	0	9
2764	2019-05-20 18:26:08	2019-05-20	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1247	delivery	5	31
2765	2019-05-20 20:56:05	2019-05-20	9	[{"id_menu":6,"count":1}]	663	delivery	5	14
2766	2019-05-20 21:27:47	2019-05-20	9	[{"id_menu":7,"count":1}]	1249	pick-up	0	9
2767	2019-05-20 22:26:27	2019-05-20	14	[{"id_menu":2,"count":1}]	1250	pick-up	0	14
2768	2019-05-20 22:35:34	2019-05-20	14	[{"id_menu":2,"count":1}]	813	pick-up	0	14
2769	2019-05-20 23:41:18	2019-05-20	9	[{"id_menu":6,"count":1}]	1245	pick-up	0	9
2770	2019-05-21 00:19:35	2019-05-21	9	[{"id_menu":6,"count":1}]	684	delivery	5	14
2771	2019-05-21 01:01:55	2019-05-21	17	[{"id_menu":4,"count":1}]	73	pick-up	0	17
2772	2019-05-21 01:06:57	2019-05-21	14	[{"id_menu":2,"count":1}]	123	pick-up	0	14
2773	2019-05-21 01:22:10	2019-05-21	14	[{"id_menu":2,"count":1}]	209	delivery	5	19
2774	2019-05-21 01:31:44	2019-05-21	9	[{"id_menu":7,"count":1}]	1154	delivery	5	14
2775	2019-05-21 02:11:00	2019-05-21	12	[{"id_menu":3,"count":1}]	1095	pick-up	0	12
2776	2019-05-21 02:13:02	2019-05-21	12	[{"id_menu":1,"count":1}]	906	pick-up	0	12
2777	2019-05-21 03:32:21	2019-05-21	8	[{"id_menu":5,"count":1}]	552	delivery	5	13
2778	2019-05-21 05:04:30	2019-05-21	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	292	delivery	5	49
2779	2019-05-21 06:29:56	2019-05-21	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	440	delivery	5	31
2780	2019-05-21 08:33:22	2019-05-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1211	pick-up	0	26
2781	2019-05-21 09:06:33	2019-05-21	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1155	delivery	5	34
2782	2019-05-21 09:22:18	2019-05-21	17	[{"id_menu":4,"count":1}]	595	pick-up	0	17
2783	2019-05-21 09:28:41	2019-05-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	895	pick-up	0	23
2784	2019-05-21 10:24:26	2019-05-21	9	[{"id_menu":7,"count":1}]	1258	pick-up	0	9
2785	2019-05-21 11:21:00	2019-05-21	9	[{"id_menu":6,"count":1}]	256	pick-up	0	9
2786	2019-05-21 11:46:21	2019-05-21	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1260	delivery	5	39
2787	2019-05-21 13:35:02	2019-05-21	17	[{"id_menu":4,"count":1}]	1118	pick-up	0	17
2788	2019-05-21 14:43:16	2019-05-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	480	delivery	5	23
2789	2019-05-21 16:01:47	2019-05-21	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	786	delivery	5	36
2790	2019-05-21 16:30:09	2019-05-21	9	[{"id_menu":7,"count":1}]	1252	pick-up	0	9
2791	2019-05-21 17:16:33	2019-05-21	12	[{"id_menu":3,"count":1}]	464	delivery	5	17
2792	2019-05-21 17:56:31	2019-05-21	8	[{"id_menu":5,"count":2}]	382	delivery	5	13
2793	2019-05-21 18:03:55	2019-05-21	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	1256	delivery	5	31
2794	2019-05-21 18:32:52	2019-05-21	12	[{"id_menu":1,"count":1}]	832	pick-up	0	12
2795	2019-05-21 21:14:20	2019-05-21	9	[{"id_menu":7,"count":1}]	1254	delivery	5	14
2796	2019-05-21 21:31:27	2019-05-21	8	[{"id_menu":5,"count":1}]	1257	delivery	5	13
2797	2019-05-21 21:45:31	2019-05-21	17	[{"id_menu":4,"count":1}]	120	delivery	5	22
2798	2019-05-21 22:02:18	2019-05-21	9	[{"id_menu":7,"count":1}]	519	pick-up	0	9
2799	2019-05-22 02:28:14	2019-05-22	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1269	pick-up	0	17
2800	2019-05-22 04:08:10	2019-05-22	8	[{"id_menu":5,"count":1}]	1092	delivery	5	13
2801	2019-05-22 04:16:38	2019-05-22	8	[{"id_menu":5,"count":1}]	1267	delivery	5	13
2802	2019-05-22 04:19:54	2019-05-22	9	[{"id_menu":7,"count":1}]	729	pick-up	0	9
2803	2019-05-22 04:22:09	2019-05-22	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	536	pick-up	0	26
2804	2019-05-22 04:47:01	2019-05-22	14	[{"id_menu":2,"count":1}]	932	delivery	5	19
2805	2019-05-22 07:25:38	2019-05-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	806	delivery	5	28
2806	2019-05-22 08:52:31	2019-05-22	12	[{"id_menu":3,"count":1}]	628	delivery	5	17
2807	2019-05-22 09:16:09	2019-05-22	9	[{"id_menu":7,"count":1}]	730	pick-up	0	9
2808	2019-05-22 09:29:45	2019-05-22	9	[{"id_menu":7,"count":1}]	1265	delivery	5	14
2809	2019-05-22 09:54:00	2019-05-22	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1253	pick-up	0	26
2810	2019-05-22 10:39:36	2019-05-22	9	[{"id_menu":6,"count":1}]	93	pick-up	0	9
2811	2019-05-22 12:13:16	2019-05-22	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	590	delivery	5	34
2812	2019-05-22 13:04:41	2019-05-22	12	[{"id_menu":1,"count":1}]	245	pick-up	0	12
2813	2019-05-22 14:10:13	2019-05-22	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	270	delivery	5	43
2814	2019-05-22 14:37:05	2019-05-22	12	[{"id_menu":1,"count":1}]	1264	delivery	5	17
2815	2019-05-22 15:47:42	2019-05-22	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1261	delivery	5	26
2816	2019-05-22 16:13:35	2019-05-22	8	[{"id_menu":5,"count":1}]	1223	pick-up	0	8
2817	2019-05-22 16:14:30	2019-05-22	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1075	pick-up	0	24
2818	2019-05-22 16:18:22	2019-05-22	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1268	delivery	5	27
2819	2019-05-22 16:58:11	2019-05-22	12	[{"id_menu":1,"count":1}]	41	delivery	5	17
2820	2019-05-22 17:32:37	2019-05-22	9	[{"id_menu":6,"count":1}]	1255	pick-up	0	9
2821	2019-05-22 18:09:06	2019-05-22	12	[{"id_menu":1,"count":1}]	73	pick-up	0	12
2822	2019-05-22 19:04:17	2019-05-22	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1266	pick-up	0	21
2823	2019-05-22 19:12:07	2019-05-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	122	delivery	5	36
2824	2019-05-22 20:12:49	2019-05-22	12	[{"id_menu":1,"count":1}]	981	delivery	5	17
2825	2019-05-22 20:19:35	2019-05-22	12	[{"id_menu":1,"count":1}]	242	delivery	5	17
2826	2019-05-22 20:41:50	2019-05-22	9	[{"id_menu":6,"count":1}]	678	pick-up	0	9
2827	2019-05-22 21:16:01	2019-05-22	12	[{"id_menu":1,"count":1}]	482	delivery	5	17
2828	2019-05-22 22:37:34	2019-05-22	12	[{"id_menu":3,"count":1}]	1263	pick-up	0	12
2829	2019-05-22 22:48:05	2019-05-22	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1137	delivery	5	31
2830	2019-05-23 00:37:42	2019-05-23	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	601	pick-up	0	17
2831	2019-05-23 00:38:30	2019-05-23	17	[{"id_menu":4,"count":1}]	360	pick-up	0	17
2832	2019-05-23 01:03:09	2019-05-23	9	[{"id_menu":6,"count":1}]	789	delivery	5	14
2833	2019-05-23 01:26:56	2019-05-23	9	[{"id_menu":6,"count":1}]	676	pick-up	0	9
2834	2019-05-23 01:55:10	2019-05-23	9	[{"id_menu":6,"count":1}]	1276	delivery	5	14
2835	2019-05-23 02:22:03	2019-05-23	14	[{"id_menu":2,"count":1}]	821	pick-up	0	14
2836	2019-05-23 04:58:54	2019-05-23	14	[{"id_menu":2,"count":1}]	660	pick-up	0	14
2837	2019-05-23 05:14:17	2019-05-23	8	[{"id_menu":5,"count":1}]	1279	pick-up	0	8
2838	2019-05-23 07:30:57	2019-05-23	9	[{"id_menu":6,"count":1}]	744	pick-up	0	9
2839	2019-05-23 07:39:19	2019-05-23	8	[{"id_menu":5,"count":1}]	1278	pick-up	0	8
2840	2019-05-23 07:51:06	2019-05-23	9	[{"id_menu":7,"count":1}]	543	pick-up	0	9
2841	2019-05-23 08:57:55	2019-05-23	8	[{"id_menu":5,"count":1}]	1272	pick-up	0	8
2842	2019-05-23 10:37:51	2019-05-23	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	239	pick-up	0	26
2843	2019-05-23 11:20:53	2019-05-23	17	[{"id_menu":4,"count":1}]	948	pick-up	0	17
2844	2019-05-23 13:08:57	2019-05-23	17	[{"id_menu":4,"count":1}]	127	delivery	5	22
2845	2019-05-23 13:40:37	2019-05-23	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1273	pick-up	0	35
2846	2019-05-23 14:32:34	2019-05-23	14	[{"id_menu":2,"count":1}]	254	pick-up	0	14
2847	2019-05-23 16:23:44	2019-05-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1023	delivery	5	23
2848	2019-05-23 18:36:44	2019-05-23	17	[{"id_menu":4,"count":1}]	319	pick-up	0	17
2849	2019-05-23 18:45:55	2019-05-23	14	[{"id_menu":2,"count":1}]	409	delivery	5	19
2850	2019-05-23 18:55:43	2019-05-23	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	748	delivery	5	36
2851	2019-05-23 18:57:12	2019-05-23	9	[{"id_menu":7,"count":1}]	1271	delivery	5	14
2852	2019-05-23 19:05:26	2019-05-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	400	pick-up	0	21
2853	2019-05-23 19:08:49	2019-05-23	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	796	delivery	5	34
2854	2019-05-23 19:29:41	2019-05-23	9	[{"id_menu":7,"count":1}]	1274	pick-up	0	9
2855	2019-05-23 21:22:29	2019-05-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	1214	delivery	5	22
2856	2019-05-23 21:23:44	2019-05-23	9	[{"id_menu":7,"count":1}]	575	pick-up	0	9
2857	2019-05-23 21:43:47	2019-05-23	8	[{"id_menu":5,"count":1}]	237	delivery	5	13
2858	2019-05-23 21:55:18	2019-05-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	83	pick-up	0	26
2859	2019-05-23 22:19:32	2019-05-23	12	[{"id_menu":1,"count":1}]	1275	delivery	5	17
2860	2019-05-23 23:59:10	2019-05-23	14	[{"id_menu":2,"count":1}]	235	pick-up	0	14
2861	2019-05-24 00:32:44	2019-05-24	9	[{"id_menu":6,"count":1}]	1286	pick-up	0	9
2862	2019-05-24 01:25:15	2019-05-24	14	[{"id_menu":2,"count":1}]	82	delivery	5	19
2863	2019-05-24 02:29:09	2019-05-24	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	1284	delivery	5	39
2864	2019-05-24 03:18:25	2019-05-24	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	381	pick-up	0	34
2865	2019-05-24 03:54:34	2019-05-24	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	997	delivery	5	36
2866	2019-05-24 03:58:25	2019-05-24	9	[{"id_menu":7,"count":1}]	690	delivery	5	14
2867	2019-05-24 05:42:44	2019-05-24	8	[{"id_menu":5,"count":1}]	975	delivery	5	13
2868	2019-05-24 06:11:25	2019-05-24	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	765	pick-up	0	33
2869	2019-05-24 06:32:00	2019-05-24	17	[{"id_menu":4,"count":1}]	274	delivery	5	22
2870	2019-05-24 08:14:23	2019-05-24	12	[{"id_menu":3,"count":1}]	1289	delivery	5	17
2871	2019-05-24 08:39:39	2019-05-24	12	[{"id_menu":3,"count":1}]	193	pick-up	0	12
2872	2019-05-24 08:51:28	2019-05-24	17	[{"id_menu":4,"count":1}]	1288	pick-up	0	17
2873	2019-05-24 10:09:01	2019-05-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	260	delivery	5	23
2874	2019-05-24 10:28:04	2019-05-24	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	832	pick-up	0	31
2875	2019-05-24 10:34:22	2019-05-24	9	[{"id_menu":6,"count":1}]	934	delivery	5	14
2876	2019-05-24 11:30:32	2019-05-24	9	[{"id_menu":7,"count":1}]	528	delivery	5	14
2877	2019-05-24 11:47:51	2019-05-24	12	[{"id_menu":1,"count":1}]	382	pick-up	0	12
2878	2019-05-24 14:08:22	2019-05-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1285	pick-up	0	17
2879	2019-05-24 14:24:26	2019-05-24	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	679	delivery	5	43
2880	2019-05-24 16:10:52	2019-05-24	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1147	delivery	5	31
2881	2019-05-24 17:20:08	2019-05-24	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	394	pick-up	0	29
2882	2019-05-24 18:34:40	2019-05-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	449	pick-up	0	26
2883	2019-05-24 19:32:08	2019-05-24	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1290	pick-up	0	32
2884	2019-05-24 20:05:52	2019-05-24	9	[{"id_menu":6,"count":1}]	1201	pick-up	0	9
2885	2019-05-24 20:34:32	2019-05-24	17	[{"id_menu":4,"count":1}]	883	delivery	5	22
2886	2019-05-24 20:49:41	2019-05-24	9	[{"id_menu":7,"count":1}]	1281	delivery	5	14
2887	2019-05-24 21:50:42	2019-05-24	9	[{"id_menu":7,"count":1}]	807	pick-up	0	9
2888	2019-05-24 23:24:49	2019-05-24	9	[{"id_menu":6,"count":1}]	1282	delivery	5	14
2889	2019-05-24 23:28:18	2019-05-24	9	[{"id_menu":6,"count":1}]	1283	delivery	5	14
2890	2019-05-25 00:31:38	2019-05-25	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1294	delivery	5	28
2891	2019-05-25 01:49:35	2019-05-25	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	1301	pick-up	0	29
2892	2019-05-25 02:11:31	2019-05-25	17	[{"id_menu":4,"count":1}]	883	pick-up	0	17
2893	2019-05-25 03:04:24	2019-05-25	17	[{"id_menu":4,"count":1}]	438	pick-up	0	17
2894	2019-05-25 03:13:53	2019-05-25	9	[{"id_menu":7,"count":1}]	1030	delivery	5	14
2895	2019-05-25 03:15:28	2019-05-25	17	[{"id_menu":4,"count":1}]	1225	pick-up	0	17
2896	2019-05-25 06:08:01	2019-05-25	17	[{"id_menu":4,"count":1}]	511	delivery	5	22
2897	2019-05-25 06:14:46	2019-05-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	233	delivery	5	31
2898	2019-05-25 07:51:41	2019-05-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	162	pick-up	0	26
2899	2019-05-25 09:59:35	2019-05-25	9	[{"id_menu":6,"count":1}]	552	pick-up	0	9
2900	2019-05-25 10:45:35	2019-05-25	17	[{"id_menu":4,"count":1}]	44	pick-up	0	17
2901	2019-05-25 11:22:34	2019-05-25	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1298	pick-up	0	38
2902	2019-05-25 11:47:34	2019-05-25	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1297	delivery	5	56
2903	2019-05-25 11:51:37	2019-05-25	9	[{"id_menu":7,"count":1}]	50	pick-up	0	9
2904	2019-05-25 12:39:15	2019-05-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	177	pick-up	0	18
2905	2019-05-25 14:14:27	2019-05-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1233	pick-up	0	23
2906	2019-05-25 14:25:11	2019-05-25	12	[{"id_menu":1,"count":1}]	749	delivery	5	17
2907	2019-05-25 14:34:04	2019-05-25	14	[{"id_menu":2,"count":1}]	947	pick-up	0	14
2908	2019-05-25 14:59:15	2019-05-25	9	[{"id_menu":6,"count":1}]	768	delivery	5	14
2909	2019-05-25 17:36:15	2019-05-25	12	[{"id_menu":3,"count":1}]	1292	pick-up	0	12
2910	2019-05-25 19:44:30	2019-05-25	9	[{"id_menu":7,"count":1}]	1299	pick-up	0	9
2911	2019-05-25 19:54:58	2019-05-25	8	[{"id_menu":5,"count":1}]	715	pick-up	0	8
2912	2019-05-25 20:12:43	2019-05-25	12	[{"id_menu":3,"count":1}]	834	pick-up	0	12
2913	2019-05-25 21:00:58	2019-05-25	17	[{"id_menu":4,"count":1}]	314	pick-up	0	17
2914	2019-05-25 21:37:11	2019-05-25	12	[{"id_menu":3,"count":1}]	1296	pick-up	0	12
2915	2019-05-25 21:52:03	2019-05-25	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1300	pick-up	0	21
2916	2019-05-25 22:17:21	2019-05-25	9	[{"id_menu":7,"count":1}]	1302	pick-up	0	9
2917	2019-05-25 22:20:24	2019-05-25	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	396	pick-up	0	21
2918	2019-05-25 22:30:35	2019-05-25	8	[{"id_menu":5,"count":1}]	352	delivery	5	13
2919	2019-05-25 22:40:03	2019-05-25	14	[{"id_menu":2,"count":1}]	1138	delivery	5	19
2920	2019-05-25 22:40:39	2019-05-25	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1291	pick-up	0	34
2921	2019-05-25 22:59:33	2019-05-25	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1293	delivery	5	26
2922	2019-05-26 00:34:51	2019-05-26	9	[{"id_menu":6,"count":1}]	1313	pick-up	0	9
2923	2019-05-26 00:59:39	2019-05-26	14	[{"id_menu":2,"count":1}]	894	pick-up	0	14
2924	2019-05-26 01:31:00	2019-05-26	17	[{"id_menu":4,"count":1}]	627	delivery	5	22
2925	2019-05-26 02:48:07	2019-05-26	14	[{"id_menu":2,"count":1}]	285	pick-up	0	14
2926	2019-05-26 04:19:45	2019-05-26	12	[{"id_menu":1,"count":1}]	1314	pick-up	0	12
2927	2019-05-26 05:11:11	2019-05-26	17	[{"id_menu":4,"count":1}]	229	pick-up	0	17
2928	2019-05-26 05:11:47	2019-05-26	9	[{"id_menu":7,"count":1}]	375	delivery	5	14
2929	2019-05-26 06:47:21	2019-05-26	17	[{"id_menu":4,"count":1}]	1312	pick-up	0	17
2930	2019-05-26 07:25:13	2019-05-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	862	pick-up	0	23
2931	2019-05-26 07:59:05	2019-05-26	12	[{"id_menu":1,"count":1}]	1097	pick-up	0	12
2932	2019-05-26 09:55:04	2019-05-26	14	[{"id_menu":2,"count":1}]	1311	pick-up	0	14
2933	2019-05-26 10:15:00	2019-05-26	14	[{"id_menu":2,"count":1}]	80	delivery	5	19
2934	2019-05-26 11:00:18	2019-05-26	14	[{"id_menu":2,"count":1}]	299	delivery	5	19
2935	2019-05-26 11:02:03	2019-05-26	17	[{"id_menu":4,"count":1}]	1306	delivery	5	22
2936	2019-05-26 11:02:37	2019-05-26	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1307	pick-up	0	21
2937	2019-05-26 11:08:46	2019-05-26	9	[{"id_menu":6,"count":1}]	1212	pick-up	0	9
2938	2019-05-26 12:07:29	2019-05-26	8	[{"id_menu":5,"count":1}]	1079	delivery	5	13
2939	2019-05-26 12:22:14	2019-05-26	14	[{"id_menu":2,"count":1}]	1072	pick-up	0	14
2940	2019-05-26 12:32:50	2019-05-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	563	pick-up	0	21
2941	2019-05-26 13:23:31	2019-05-26	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	458	pick-up	0	20
2942	2019-05-26 13:25:24	2019-05-26	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	1304	pick-up	0	35
2943	2019-05-26 13:48:40	2019-05-26	12	[{"id_menu":1,"count":1}]	1305	pick-up	0	12
2944	2019-05-26 14:27:51	2019-05-26	9	[{"id_menu":6,"count":1}]	68	pick-up	0	9
2945	2019-05-26 14:44:41	2019-05-26	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	719	pick-up	0	22
2946	2019-05-26 15:12:37	2019-05-26	8	[{"id_menu":5,"count":1}]	1303	delivery	5	13
2947	2019-05-26 15:23:57	2019-05-26	17	[{"id_menu":5,"count":3},{"id_menu":6,"count":1}]	1310	delivery	5	22
2948	2019-05-26 15:24:58	2019-05-26	12	[{"id_menu":3,"count":1}]	1289	pick-up	0	12
2949	2019-05-26 15:31:15	2019-05-26	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1075	delivery	5	52
2950	2019-05-26 15:45:30	2019-05-26	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	1315	delivery	5	36
2951	2019-05-26 16:09:30	2019-05-26	8	[{"id_menu":5,"count":1}]	1138	pick-up	0	8
2952	2019-05-26 16:25:48	2019-05-26	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	634	pick-up	0	21
2953	2019-05-26 16:51:15	2019-05-26	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1308	delivery	5	25
2954	2019-05-26 17:28:02	2019-05-26	12	[{"id_menu":1,"count":1}]	1241	pick-up	0	12
2955	2019-05-26 17:57:22	2019-05-26	14	[{"id_menu":2,"count":1}]	585	delivery	5	19
2956	2019-05-26 17:58:48	2019-05-26	9	[{"id_menu":6,"count":1}]	676	delivery	5	14
2957	2019-05-26 18:15:07	2019-05-26	12	[{"id_menu":1,"count":1}]	1070	pick-up	0	12
2958	2019-05-26 18:31:59	2019-05-26	9	[{"id_menu":6,"count":1}]	1202	pick-up	0	9
2959	2019-05-26 18:54:33	2019-05-26	14	[{"id_menu":2,"count":1}]	1309	pick-up	0	14
2960	2019-05-26 18:57:21	2019-05-26	12	[{"id_menu":3,"count":1}]	865	pick-up	0	12
2961	2019-05-26 19:25:31	2019-05-26	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	446	pick-up	0	25
2962	2019-05-26 19:27:26	2019-05-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	946	delivery	5	22
2963	2019-05-26 19:32:05	2019-05-26	9	[{"id_menu":7,"count":1}]	859	delivery	5	14
2964	2019-05-26 20:51:35	2019-05-26	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	831	delivery	5	38
2965	2019-05-26 21:25:54	2019-05-26	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	381	pick-up	0	26
2966	2019-05-26 22:39:17	2019-05-26	17	[{"id_menu":4,"count":1}]	245	pick-up	0	17
2967	2019-05-26 22:59:47	2019-05-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	639	pick-up	0	17
2968	2019-05-26 23:11:49	2019-05-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	495	delivery	5	28
2969	2019-05-27 00:32:05	2019-05-27	17	[{"id_menu":4,"count":1}]	113	pick-up	0	17
2970	2019-05-27 01:14:58	2019-05-27	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	409	delivery	5	34
2971	2019-05-27 02:52:46	2019-05-27	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	663	delivery	5	31
2972	2019-05-27 04:13:19	2019-05-27	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	654	delivery	5	31
2973	2019-05-27 04:29:34	2019-05-27	8	[{"id_menu":5,"count":1}]	964	delivery	5	13
2974	2019-05-27 04:31:25	2019-05-27	17	[{"id_menu":4,"count":1}]	932	pick-up	0	17
2975	2019-05-27 04:39:57	2019-05-27	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1324	delivery	5	38
2976	2019-05-27 06:04:37	2019-05-27	12	[{"id_menu":1,"count":1}]	169	delivery	5	17
2977	2019-05-27 06:38:50	2019-05-27	9	[{"id_menu":7,"count":1}]	1083	pick-up	0	9
2978	2019-05-27 10:11:23	2019-05-27	17	[{"id_menu":4,"count":1}]	107	delivery	5	22
2979	2019-05-27 11:53:56	2019-05-27	17	[{"id_menu":4,"count":1}]	660	pick-up	0	17
2980	2019-05-27 12:53:15	2019-05-27	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	467	pick-up	0	40
2981	2019-05-27 13:14:04	2019-05-27	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	408	pick-up	0	41
2982	2019-05-27 13:48:51	2019-05-27	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1319	delivery	5	22
2983	2019-05-27 14:34:04	2019-05-27	9	[{"id_menu":7,"count":1}]	691	delivery	5	14
2984	2019-05-27 14:40:42	2019-05-27	9	[{"id_menu":6,"count":1}]	1320	pick-up	0	9
2985	2019-05-27 15:57:50	2019-05-27	14	[{"id_menu":2,"count":1}]	777	pick-up	0	14
2986	2019-05-27 19:14:51	2019-05-27	9	[{"id_menu":6,"count":1}]	1070	pick-up	0	9
2987	2019-05-27 19:22:13	2019-05-27	8	[{"id_menu":5,"count":1}]	1223	pick-up	0	8
2988	2019-05-27 19:31:55	2019-05-27	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	730	delivery	5	26
2989	2019-05-27 19:38:33	2019-05-27	12	[{"id_menu":3,"count":1}]	1321	pick-up	0	12
2990	2019-05-27 22:25:53	2019-05-27	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1322	pick-up	0	40
2991	2019-05-27 22:42:32	2019-05-27	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	292	delivery	5	40
2992	2019-05-27 23:14:56	2019-05-27	17	[{"id_menu":4,"count":1}]	96	pick-up	0	17
2993	2019-05-28 01:07:32	2019-05-28	12	[{"id_menu":3,"count":1}]	323	pick-up	0	12
2994	2019-05-28 02:15:41	2019-05-28	17	[{"id_menu":4,"count":1}]	793	pick-up	0	17
2995	2019-05-28 02:23:19	2019-05-28	9	[{"id_menu":6,"count":1}]	665	pick-up	0	9
2996	2019-05-28 03:32:20	2019-05-28	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	591	delivery	5	43
2997	2019-05-28 05:44:57	2019-05-28	9	[{"id_menu":6,"count":1}]	1326	pick-up	0	9
2998	2019-05-28 05:54:12	2019-05-28	14	[{"id_menu":2,"count":1}]	806	pick-up	0	14
2999	2019-05-28 07:11:37	2019-05-28	14	[{"id_menu":2,"count":1}]	399	pick-up	0	14
3000	2019-05-28 09:12:52	2019-05-28	12	[{"id_menu":1,"count":1}]	654	pick-up	0	12
3001	2019-05-28 09:25:09	2019-05-28	9	[{"id_menu":7,"count":2}]	1327	pick-up	0	9
3002	2019-05-28 10:53:05	2019-05-28	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	721	delivery	5	26
3003	2019-05-28 11:14:31	2019-05-28	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1332	pick-up	0	31
3004	2019-05-28 12:40:32	2019-05-28	8	[{"id_menu":5,"count":1}]	1334	delivery	5	13
3005	2019-05-28 14:50:13	2019-05-28	9	[{"id_menu":6,"count":1}]	991	pick-up	0	9
3006	2019-05-28 15:17:51	2019-05-28	14	[{"id_menu":2,"count":1}]	609	pick-up	0	14
3007	2019-05-28 16:01:42	2019-05-28	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	228	delivery	5	31
3008	2019-05-28 17:21:45	2019-05-28	9	[{"id_menu":6,"count":1}]	443	delivery	5	14
3009	2019-05-28 19:08:44	2019-05-28	8	[{"id_menu":5,"count":1}]	359	delivery	5	13
3010	2019-05-28 19:35:09	2019-05-28	9	[{"id_menu":6,"count":1}]	1228	pick-up	0	9
3011	2019-05-28 19:39:19	2019-05-28	8	[{"id_menu":5,"count":1}]	788	pick-up	0	8
3012	2019-05-28 20:10:41	2019-05-28	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1254	delivery	5	26
3013	2019-05-28 20:47:51	2019-05-28	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1333	delivery	5	49
3014	2019-05-28 21:36:33	2019-05-28	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	678	delivery	5	36
3015	2019-05-28 21:49:57	2019-05-28	14	[{"id_menu":2,"count":1}]	41	pick-up	0	14
3016	2019-05-28 22:00:02	2019-05-28	14	[{"id_menu":2,"count":1}]	1328	pick-up	0	14
3017	2019-05-28 23:59:36	2019-05-28	12	[{"id_menu":1,"count":1}]	1325	delivery	5	17
3018	2019-05-29 01:11:55	2019-05-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	1309	pick-up	0	21
3019	2019-05-29 01:45:57	2019-05-29	9	[{"id_menu":7,"count":1}]	727	pick-up	0	9
3020	2019-05-29 02:27:50	2019-05-29	12	[{"id_menu":3,"count":1}]	1211	pick-up	0	12
3021	2019-05-29 02:57:53	2019-05-29	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	1341	pick-up	0	29
3022	2019-05-29 04:21:21	2019-05-29	17	[{"id_menu":4,"count":1}]	1344	pick-up	0	17
3023	2019-05-29 05:03:14	2019-05-29	9	[{"id_menu":6,"count":1}]	86	pick-up	0	9
3024	2019-05-29 05:05:42	2019-05-29	9	[{"id_menu":6,"count":1}]	1339	delivery	5	14
3025	2019-05-29 05:06:42	2019-05-29	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	680	pick-up	0	29
3026	2019-05-29 05:46:21	2019-05-29	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	802	pick-up	0	35
3027	2019-05-29 05:58:48	2019-05-29	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1340	delivery	5	31
3028	2019-05-29 06:15:47	2019-05-29	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	120	delivery	5	31
3029	2019-05-29 08:38:19	2019-05-29	17	[{"id_menu":4,"count":1}]	1337	pick-up	0	17
3030	2019-05-29 09:24:44	2019-05-29	8	[{"id_menu":5,"count":1}]	701	pick-up	0	8
3031	2019-05-29 09:39:15	2019-05-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1034	pick-up	0	23
3032	2019-05-29 10:33:46	2019-05-29	9	[{"id_menu":6,"count":1}]	1070	pick-up	0	9
3033	2019-05-29 10:52:41	2019-05-29	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1336	pick-up	0	29
3034	2019-05-29 10:59:38	2019-05-29	9	[{"id_menu":6,"count":1}]	833	pick-up	0	9
3035	2019-05-29 12:16:41	2019-05-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	721	pick-up	0	26
3036	2019-05-29 12:34:51	2019-05-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	134	delivery	5	26
3037	2019-05-29 12:39:46	2019-05-29	8	[{"id_menu":5,"count":1}]	1156	delivery	5	13
3038	2019-05-29 12:46:19	2019-05-29	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	996	pick-up	0	26
3039	2019-05-29 12:56:37	2019-05-29	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1343	pick-up	0	26
3040	2019-05-29 13:02:30	2019-05-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1183	pick-up	0	26
3041	2019-05-29 13:35:23	2019-05-29	8	[{"id_menu":5,"count":1}]	1335	delivery	5	13
3042	2019-05-29 14:29:29	2019-05-29	9	[{"id_menu":6,"count":1}]	88	pick-up	0	9
3043	2019-05-29 17:47:05	2019-05-29	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1302	pick-up	0	29
3044	2019-05-29 17:55:36	2019-05-29	9	[{"id_menu":6,"count":1}]	952	delivery	5	14
3045	2019-05-29 18:45:05	2019-05-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1338	pick-up	0	17
3046	2019-05-29 21:11:03	2019-05-29	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	981	delivery	5	29
3047	2019-05-29 21:42:40	2019-05-29	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1280	pick-up	0	26
3048	2019-05-29 23:14:48	2019-05-29	14	[{"id_menu":2,"count":1}]	1342	pick-up	0	14
3049	2019-05-29 23:46:49	2019-05-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	213	pick-up	0	18
3050	2019-05-30 01:26:25	2019-05-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1317	pick-up	0	21
3051	2019-05-30 01:49:26	2019-05-30	14	[{"id_menu":2,"count":1}]	1353	delivery	5	19
3052	2019-05-30 02:00:25	2019-05-30	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	935	delivery	5	31
3053	2019-05-30 02:04:26	2019-05-30	9	[{"id_menu":6,"count":1}]	826	delivery	5	14
3054	2019-05-30 02:39:25	2019-05-30	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	757	delivery	5	52
3055	2019-05-30 04:43:07	2019-05-30	17	[{"id_menu":4,"count":1}]	392	delivery	5	22
3056	2019-05-30 04:44:27	2019-05-30	12	[{"id_menu":1,"count":1}]	1349	delivery	5	17
3057	2019-05-30 05:19:31	2019-05-30	8	[{"id_menu":5,"count":1}]	1049	delivery	5	13
3058	2019-05-30 05:37:16	2019-05-30	12	[{"id_menu":3,"count":1}]	868	pick-up	0	12
3059	2019-05-30 06:10:26	2019-05-30	17	[{"id_menu":4,"count":1}]	96	pick-up	0	17
3060	2019-05-30 06:22:45	2019-05-30	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1352	pick-up	0	17
3061	2019-05-30 07:57:58	2019-05-30	17	[{"id_menu":4,"count":1}]	247	delivery	5	22
3062	2019-05-30 08:09:21	2019-05-30	8	[{"id_menu":5,"count":1}]	238	pick-up	0	8
3063	2019-05-30 08:28:09	2019-05-30	17	[{"id_menu":4,"count":1}]	1072	pick-up	0	17
3064	2019-05-30 08:39:32	2019-05-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1347	pick-up	0	26
3065	2019-05-30 08:48:47	2019-05-30	8	[{"id_menu":5,"count":1}]	1107	delivery	5	13
3066	2019-05-30 08:54:07	2019-05-30	17	[{"id_menu":4,"count":1}]	660	pick-up	0	17
3067	2019-05-30 09:47:57	2019-05-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":3}]	1293	delivery	5	23
3068	2019-05-30 10:41:03	2019-05-30	9	[{"id_menu":6,"count":1}]	838	delivery	5	14
3069	2019-05-30 12:24:32	2019-05-30	14	[{"id_menu":2,"count":1}]	376	delivery	5	19
3070	2019-05-30 13:09:56	2019-05-30	8	[{"id_menu":5,"count":1}]	1055	delivery	5	13
3071	2019-05-30 16:40:10	2019-05-30	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1346	delivery	5	31
3072	2019-05-30 16:55:08	2019-05-30	8	[{"id_menu":5,"count":1}]	1354	delivery	5	13
3073	2019-05-30 17:52:45	2019-05-30	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1348	delivery	5	40
3074	2019-05-30 18:04:36	2019-05-30	9	[{"id_menu":7,"count":1}]	986	pick-up	0	9
3075	2019-05-30 18:09:54	2019-05-30	12	[{"id_menu":3,"count":1}]	708	pick-up	0	12
3076	2019-05-30 18:26:12	2019-05-30	17	[{"id_menu":4,"count":1}]	1071	delivery	5	22
3077	2019-05-30 19:33:25	2019-05-30	14	[{"id_menu":2,"count":1}]	1309	delivery	5	19
3078	2019-05-30 19:39:09	2019-05-30	12	[{"id_menu":1,"count":1}]	359	pick-up	0	12
3079	2019-05-30 19:55:38	2019-05-30	12	[{"id_menu":1,"count":1}]	396	delivery	5	17
3080	2019-05-30 20:02:48	2019-05-30	12	[{"id_menu":1,"count":1}]	833	pick-up	0	12
3081	2019-05-30 20:30:26	2019-05-30	12	[{"id_menu":3,"count":1}]	1292	delivery	5	17
3082	2019-05-30 20:42:53	2019-05-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1085	pick-up	0	21
3083	2019-05-30 21:13:36	2019-05-30	17	[{"id_menu":4,"count":1}]	1296	pick-up	0	17
3084	2019-05-30 21:15:48	2019-05-30	9	[{"id_menu":7,"count":2}]	901	pick-up	0	9
3085	2019-05-30 22:09:47	2019-05-30	9	[{"id_menu":7,"count":1}]	678	delivery	5	14
3086	2019-05-30 22:49:40	2019-05-30	8	[{"id_menu":5,"count":1}]	184	pick-up	0	8
3087	2019-05-31 00:58:03	2019-05-31	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1358	pick-up	0	35
3088	2019-05-31 00:58:21	2019-05-31	12	[{"id_menu":1,"count":1}]	807	pick-up	0	12
3089	2019-05-31 01:53:17	2019-05-31	8	[{"id_menu":5,"count":2}]	1364	pick-up	0	8
3090	2019-05-31 03:51:47	2019-05-31	9	[{"id_menu":6,"count":1}]	1367	delivery	5	14
3091	2019-05-31 05:46:59	2019-05-31	17	[{"id_menu":4,"count":1}]	456	delivery	5	22
3092	2019-05-31 06:05:02	2019-05-31	9	[{"id_menu":6,"count":1}]	1355	delivery	5	14
3093	2019-05-31 06:09:14	2019-05-31	9	[{"id_menu":7,"count":1}]	1284	delivery	5	14
3094	2019-05-31 06:36:52	2019-05-31	17	[{"id_menu":4,"count":1}]	1366	pick-up	0	17
3095	2019-05-31 06:51:50	2019-05-31	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	721	pick-up	0	23
3096	2019-05-31 06:53:16	2019-05-31	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	676	pick-up	0	39
3097	2019-05-31 08:04:45	2019-05-31	8	[{"id_menu":5,"count":1}]	1362	delivery	5	13
3098	2019-05-31 10:48:58	2019-05-31	12	[{"id_menu":1,"count":1}]	255	delivery	5	17
3099	2019-05-31 11:21:37	2019-05-31	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	735	pick-up	0	29
3100	2019-05-31 11:26:07	2019-05-31	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1363	pick-up	0	21
3101	2019-05-31 12:38:02	2019-05-31	17	[{"id_menu":4,"count":1}]	660	pick-up	0	17
3102	2019-05-31 14:26:16	2019-05-31	9	[{"id_menu":7,"count":1}]	214	delivery	5	14
3103	2019-05-31 15:32:13	2019-05-31	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1337	delivery	5	26
3104	2019-05-31 18:04:49	2019-05-31	9	[{"id_menu":7,"count":1}]	197	pick-up	0	9
3105	2019-05-31 18:24:58	2019-05-31	9	[{"id_menu":6,"count":1}]	1365	pick-up	0	9
3106	2019-05-31 19:54:50	2019-05-31	12	[{"id_menu":1,"count":1}]	138	delivery	5	17
3107	2019-05-31 20:02:24	2019-05-31	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	226	pick-up	0	33
3108	2019-05-31 20:47:08	2019-05-31	14	[{"id_menu":2,"count":1}]	360	pick-up	0	14
3109	2019-05-31 21:39:46	2019-05-31	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	260	pick-up	0	24
3110	2019-05-31 23:13:09	2019-05-31	12	[{"id_menu":1,"count":1}]	1361	pick-up	0	12
3111	2019-05-31 23:17:49	2019-05-31	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	245	pick-up	0	23
3112	2019-05-31 23:19:42	2019-05-31	8	[{"id_menu":5,"count":1}]	954	pick-up	0	8
3113	2019-06-01 00:09:24	2019-06-01	12	[{"id_menu":1,"count":1}]	220	pick-up	0	12
3114	2019-06-01 00:37:18	2019-06-01	12	[{"id_menu":1,"count":1}]	719	pick-up	0	12
3115	2019-06-01 00:41:48	2019-06-01	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	169	pick-up	0	25
3116	2019-06-01 00:44:21	2019-06-01	9	[{"id_menu":6,"count":1}]	925	pick-up	0	9
3117	2019-06-01 01:50:22	2019-06-01	14	[{"id_menu":2,"count":1}]	189	delivery	5	19
3118	2019-06-01 03:03:09	2019-06-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1376	delivery	5	28
3119	2019-06-01 03:08:59	2019-06-01	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	101	pick-up	0	29
3120	2019-06-01 03:21:35	2019-06-01	17	[{"id_menu":4,"count":1}]	788	pick-up	0	17
3121	2019-06-01 05:08:17	2019-06-01	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	1374	delivery	5	30
3122	2019-06-01 05:17:49	2019-06-01	9	[{"id_menu":7,"count":1}]	1372	pick-up	0	9
3123	2019-06-01 05:49:15	2019-06-01	12	[{"id_menu":3,"count":1}]	1134	pick-up	0	12
3124	2019-06-01 06:26:40	2019-06-01	14	[{"id_menu":2,"count":1}]	832	delivery	5	19
3125	2019-06-01 07:37:42	2019-06-01	8	[{"id_menu":5,"count":1}]	1369	delivery	5	13
3126	2019-06-01 08:00:44	2019-06-01	9	[{"id_menu":6,"count":1}]	293	pick-up	0	9
3127	2019-06-01 08:22:44	2019-06-01	17	[{"id_menu":4,"count":1}]	1344	delivery	5	22
3128	2019-06-01 08:28:48	2019-06-01	17	[{"id_menu":4,"count":1}]	1104	pick-up	0	17
3129	2019-06-01 08:34:00	2019-06-01	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1159	pick-up	0	26
3130	2019-06-01 09:02:03	2019-06-01	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	150	pick-up	0	21
3131	2019-06-01 10:27:14	2019-06-01	17	[{"id_menu":4,"count":1}]	1368	pick-up	0	17
3132	2019-06-01 10:45:22	2019-06-01	14	[{"id_menu":2,"count":1}]	1375	delivery	5	19
3133	2019-06-01 10:51:49	2019-06-01	14	[{"id_menu":2,"count":2}]	283	pick-up	0	14
3134	2019-06-01 12:02:19	2019-06-01	8	[{"id_menu":5,"count":1}]	958	delivery	5	13
3135	2019-06-01 12:08:36	2019-06-01	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	377	delivery	5	31
3136	2019-06-01 12:17:43	2019-06-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	576	pick-up	0	21
3137	2019-06-01 12:24:04	2019-06-01	17	[{"id_menu":4,"count":1}]	495	delivery	5	22
3138	2019-06-01 13:14:30	2019-06-01	12	[{"id_menu":1,"count":1}]	1379	pick-up	0	12
3139	2019-06-01 15:01:28	2019-06-01	17	[{"id_menu":4,"count":1}]	810	delivery	5	22
3140	2019-06-01 15:38:57	2019-06-01	9	[{"id_menu":6,"count":1}]	1322	pick-up	0	9
3141	2019-06-01 16:06:29	2019-06-01	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	382	pick-up	0	29
3142	2019-06-01 16:18:16	2019-06-01	26	[{"id_menu":2,"count":3},{"id_menu":3,"count":1}]	236	pick-up	0	26
3143	2019-06-01 17:22:08	2019-06-01	12	[{"id_menu":3,"count":1}]	32	pick-up	0	12
3144	2019-06-01 17:22:32	2019-06-01	8	[{"id_menu":5,"count":1}]	1378	delivery	5	13
3145	2019-06-01 19:15:58	2019-06-01	9	[{"id_menu":6,"count":1}]	424	pick-up	0	9
3146	2019-06-01 21:28:00	2019-06-01	12	[{"id_menu":1,"count":1}]	286	pick-up	0	12
3147	2019-06-01 21:50:01	2019-06-01	8	[{"id_menu":5,"count":1}]	1373	delivery	5	13
3148	2019-06-01 22:10:31	2019-06-01	14	[{"id_menu":2,"count":1}]	1371	pick-up	0	14
3149	2019-06-01 23:11:01	2019-06-01	14	[{"id_menu":2,"count":1}]	1370	pick-up	0	14
3150	2019-06-01 23:38:28	2019-06-01	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1262	pick-up	0	26
3151	2019-06-01 23:46:59	2019-06-01	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1051	delivery	5	29
3152	2019-06-01 23:57:36	2019-06-01	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1377	delivery	5	35
3153	2019-06-02 01:10:42	2019-06-02	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	371	delivery	5	31
3154	2019-06-02 02:46:20	2019-06-02	9	[{"id_menu":6,"count":1}]	1390	delivery	5	14
3155	2019-06-02 03:23:53	2019-06-02	12	[{"id_menu":3,"count":1}]	203	delivery	5	17
3156	2019-06-02 05:25:58	2019-06-02	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1384	delivery	5	39
3157	2019-06-02 06:44:59	2019-06-02	9	[{"id_menu":6,"count":1}]	522	pick-up	0	9
3158	2019-06-02 06:46:18	2019-06-02	9	[{"id_menu":7,"count":1}]	1244	delivery	5	14
3159	2019-06-02 06:55:39	2019-06-02	9	[{"id_menu":6,"count":1}]	1167	delivery	5	14
3160	2019-06-02 07:32:07	2019-06-02	9	[{"id_menu":7,"count":1}]	1387	delivery	5	14
3161	2019-06-02 07:37:59	2019-06-02	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	1391	delivery	5	31
3162	2019-06-02 08:17:48	2019-06-02	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	172	pick-up	0	23
3163	2019-06-02 08:24:57	2019-06-02	8	[{"id_menu":5,"count":1}]	170	pick-up	0	8
3164	2019-06-02 08:44:40	2019-06-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1339	delivery	5	22
3165	2019-06-02 08:49:29	2019-06-02	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	1277	delivery	5	36
3166	2019-06-02 09:01:32	2019-06-02	9	[{"id_menu":6,"count":1}]	1236	pick-up	0	9
3167	2019-06-02 09:02:37	2019-06-02	14	[{"id_menu":2,"count":1}]	262	pick-up	0	14
3168	2019-06-02 09:49:28	2019-06-02	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	473	pick-up	0	35
3169	2019-06-02 10:03:59	2019-06-02	14	[{"id_menu":2,"count":1}]	1380	delivery	5	19
3170	2019-06-02 10:57:05	2019-06-02	8	[{"id_menu":5,"count":2}]	1086	pick-up	0	8
3171	2019-06-02 11:49:58	2019-06-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1389	pick-up	0	23
3172	2019-06-02 11:56:53	2019-06-02	9	[{"id_menu":7,"count":1}]	1382	pick-up	0	9
3173	2019-06-02 12:52:51	2019-06-02	9	[{"id_menu":7,"count":1}]	799	delivery	5	14
3174	2019-06-02 13:11:04	2019-06-02	12	[{"id_menu":3,"count":2}]	692	pick-up	0	12
3175	2019-06-02 13:35:42	2019-06-02	12	[{"id_menu":1,"count":1}]	138	pick-up	0	12
3176	2019-06-02 13:36:19	2019-06-02	12	[{"id_menu":1,"count":1}]	445	delivery	5	17
3177	2019-06-02 14:14:01	2019-06-02	9	[{"id_menu":7,"count":1}]	295	pick-up	0	9
3178	2019-06-02 14:28:47	2019-06-02	17	[{"id_menu":4,"count":1}]	1239	delivery	5	22
3179	2019-06-02 14:33:01	2019-06-02	12	[{"id_menu":3,"count":1}]	1386	pick-up	0	12
3180	2019-06-02 15:25:33	2019-06-02	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	293	pick-up	0	21
3181	2019-06-02 15:46:39	2019-06-02	14	[{"id_menu":2,"count":1}]	1383	pick-up	0	14
3182	2019-06-02 16:07:57	2019-06-02	14	[{"id_menu":2,"count":1}]	1344	delivery	5	19
3183	2019-06-02 16:26:13	2019-06-02	12	[{"id_menu":1,"count":1}]	153	pick-up	0	12
3184	2019-06-02 17:01:33	2019-06-02	9	[{"id_menu":7,"count":1}]	1381	pick-up	0	9
3185	2019-06-02 17:09:06	2019-06-02	14	[{"id_menu":2,"count":1}]	1245	pick-up	0	14
3186	2019-06-02 17:46:03	2019-06-02	14	[{"id_menu":2,"count":1}]	321	pick-up	0	14
3187	2019-06-02 17:48:59	2019-06-02	12	[{"id_menu":3,"count":1}]	336	delivery	5	17
3188	2019-06-02 18:24:42	2019-06-02	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	226	delivery	5	34
3189	2019-06-02 19:16:52	2019-06-02	17	[{"id_menu":4,"count":1}]	1	pick-up	0	17
3190	2019-06-02 19:59:32	2019-06-02	8	[{"id_menu":5,"count":1}]	1166	delivery	5	13
3191	2019-06-02 20:30:43	2019-06-02	12	[{"id_menu":1,"count":1}]	948	pick-up	0	12
3192	2019-06-02 20:58:49	2019-06-02	9	[{"id_menu":7,"count":1}]	1392	delivery	5	14
3193	2019-06-02 21:00:39	2019-06-02	9	[{"id_menu":7,"count":1}]	1385	pick-up	0	9
3194	2019-06-02 21:04:58	2019-06-02	9	[{"id_menu":6,"count":1}]	52	delivery	5	14
3195	2019-06-02 21:22:52	2019-06-02	9	[{"id_menu":6,"count":1}]	1388	pick-up	0	9
3196	2019-06-02 22:06:04	2019-06-02	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	29	pick-up	0	26
3197	2019-06-02 22:13:13	2019-06-02	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	1223	pick-up	0	31
3198	2019-06-02 22:58:16	2019-06-02	9	[{"id_menu":6,"count":1}]	27	delivery	5	14
3199	2019-06-02 23:52:34	2019-06-02	9	[{"id_menu":7,"count":1}]	1299	pick-up	0	9
3200	2019-06-02 23:58:03	2019-06-02	12	[{"id_menu":1,"count":1}]	541	pick-up	0	12
3201	2019-06-03 00:25:33	2019-06-03	12	[{"id_menu":1,"count":1}]	399	pick-up	0	12
3202	2019-06-03 01:22:06	2019-06-03	17	[{"id_menu":4,"count":1}]	1394	delivery	5	22
3203	2019-06-03 02:19:05	2019-06-03	9	[{"id_menu":6,"count":1}]	1212	pick-up	0	9
3204	2019-06-03 02:52:37	2019-06-03	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	790	delivery	5	26
3205	2019-06-03 03:15:19	2019-06-03	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1229	pick-up	0	23
3206	2019-06-03 03:42:09	2019-06-03	17	[{"id_menu":4,"count":1}]	1076	pick-up	0	17
3207	2019-06-03 04:14:10	2019-06-03	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	76	delivery	5	31
3208	2019-06-03 05:43:11	2019-06-03	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	989	pick-up	0	38
3209	2019-06-03 06:10:03	2019-06-03	9	[{"id_menu":6,"count":1}]	1258	pick-up	0	9
3210	2019-06-03 06:42:50	2019-06-03	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1399	pick-up	0	31
3211	2019-06-03 07:17:53	2019-06-03	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	1402	pick-up	0	35
3212	2019-06-03 11:40:24	2019-06-03	12	[{"id_menu":3,"count":1}]	769	delivery	5	17
3213	2019-06-03 11:48:54	2019-06-03	9	[{"id_menu":6,"count":1}]	1137	pick-up	0	9
3214	2019-06-03 13:29:19	2019-06-03	9	[{"id_menu":6,"count":1}]	172	delivery	5	14
3215	2019-06-03 15:42:58	2019-06-03	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1401	pick-up	0	17
3216	2019-06-03 16:08:30	2019-06-03	17	[{"id_menu":4,"count":2}]	1398	delivery	5	22
3217	2019-06-03 16:49:24	2019-06-03	12	[{"id_menu":3,"count":1}]	881	pick-up	0	12
3218	2019-06-03 18:15:52	2019-06-03	14	[{"id_menu":2,"count":1}]	618	pick-up	0	14
3219	2019-06-03 18:44:42	2019-06-03	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	241	pick-up	0	37
3220	2019-06-03 19:32:56	2019-06-03	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16	delivery	5	46
3221	2019-06-03 20:45:44	2019-06-03	12	[{"id_menu":1,"count":1}]	424	delivery	5	17
3222	2019-06-03 22:02:17	2019-06-03	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	582	pick-up	0	23
3223	2019-06-03 22:11:45	2019-06-03	12	[{"id_menu":1,"count":1}]	1395	delivery	5	17
3224	2019-06-03 22:40:17	2019-06-03	14	[{"id_menu":2,"count":1}]	1400	pick-up	0	14
3225	2019-06-03 22:51:38	2019-06-03	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1393	delivery	5	45
3226	2019-06-04 00:14:39	2019-06-04	8	[{"id_menu":5,"count":1}]	1228	pick-up	0	8
3227	2019-06-04 02:23:26	2019-06-04	14	[{"id_menu":2,"count":1}]	1406	delivery	5	19
3228	2019-06-04 02:45:10	2019-06-04	9	[{"id_menu":6,"count":1}]	581	delivery	5	14
3229	2019-06-04 04:48:41	2019-06-04	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	860	delivery	5	45
3230	2019-06-04 04:53:54	2019-06-04	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1411	delivery	5	38
3231	2019-06-04 06:23:08	2019-06-04	17	[{"id_menu":4,"count":1}]	351	pick-up	0	17
3232	2019-06-04 09:24:30	2019-06-04	9	[{"id_menu":6,"count":1}]	1412	delivery	5	14
3233	2019-06-04 11:12:26	2019-06-04	14	[{"id_menu":2,"count":1}]	821	pick-up	0	14
3234	2019-06-04 11:27:45	2019-06-04	12	[{"id_menu":3,"count":1}]	138	delivery	5	17
3235	2019-06-04 12:48:49	2019-06-04	14	[{"id_menu":2,"count":2}]	1409	delivery	5	19
3236	2019-06-04 14:35:44	2019-06-04	9	[{"id_menu":6,"count":1}]	1414	pick-up	0	9
3237	2019-06-04 15:35:54	2019-06-04	17	[{"id_menu":4,"count":1}]	1322	pick-up	0	17
3238	2019-06-04 15:36:24	2019-06-04	8	[{"id_menu":5,"count":1}]	1415	pick-up	0	8
3239	2019-06-04 16:06:46	2019-06-04	14	[{"id_menu":2,"count":1}]	1408	delivery	5	19
3240	2019-06-04 17:40:47	2019-06-04	8	[{"id_menu":5,"count":1}]	778	pick-up	0	8
3241	2019-06-04 21:20:44	2019-06-04	17	[{"id_menu":4,"count":1}]	1334	pick-up	0	17
3242	2019-06-04 21:28:25	2019-06-04	8	[{"id_menu":5,"count":1}]	1376	delivery	5	13
3243	2019-06-04 21:52:21	2019-06-04	12	[{"id_menu":3,"count":1}]	1407	delivery	5	17
3244	2019-06-04 21:56:58	2019-06-04	17	[{"id_menu":4,"count":1}]	684	delivery	5	22
3245	2019-06-05 00:32:29	2019-06-05	9	[{"id_menu":7,"count":1}]	1417	pick-up	0	9
3246	2019-06-05 00:42:53	2019-06-05	8	[{"id_menu":5,"count":1}]	1426	pick-up	0	8
3247	2019-06-05 02:48:33	2019-06-05	9	[{"id_menu":7,"count":1}]	768	delivery	5	14
3248	2019-06-05 03:49:36	2019-06-05	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	630	pick-up	0	38
3249	2019-06-05 03:56:24	2019-06-05	14	[{"id_menu":2,"count":1}]	627	pick-up	0	14
3250	2019-06-05 04:01:56	2019-06-05	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1269	pick-up	0	23
3251	2019-06-05 05:07:38	2019-06-05	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1416	delivery	5	31
3252	2019-06-05 05:24:54	2019-06-05	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1418	delivery	5	34
3253	2019-06-05 05:34:45	2019-06-05	9	[{"id_menu":7,"count":2}]	235	pick-up	0	9
3254	2019-06-05 06:21:45	2019-06-05	9	[{"id_menu":7,"count":1}]	1424	pick-up	0	9
3255	2019-06-05 06:32:03	2019-06-05	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1419	pick-up	0	42
3256	2019-06-05 08:28:55	2019-06-05	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1352	pick-up	0	24
3257	2019-06-05 08:59:08	2019-06-05	17	[{"id_menu":4,"count":1}]	1425	pick-up	0	17
3258	2019-06-05 09:27:32	2019-06-05	12	[{"id_menu":1,"count":2}]	1423	pick-up	0	12
3259	2019-06-05 09:44:31	2019-06-05	9	[{"id_menu":7,"count":1}]	260	pick-up	0	9
3260	2019-06-05 11:12:08	2019-06-05	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1203	pick-up	0	20
3261	2019-06-05 11:14:37	2019-06-05	12	[{"id_menu":3,"count":1}]	1421	pick-up	0	12
3262	2019-06-05 12:03:29	2019-06-05	12	[{"id_menu":1,"count":1}]	491	delivery	5	17
3263	2019-06-05 12:33:25	2019-06-05	9	[{"id_menu":6,"count":2}]	585	delivery	5	14
3264	2019-06-05 14:14:48	2019-06-05	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1056	delivery	5	26
3265	2019-06-05 15:08:23	2019-06-05	8	[{"id_menu":5,"count":1}]	466	delivery	5	13
3266	2019-06-05 15:09:13	2019-06-05	14	[{"id_menu":2,"count":1}]	136	delivery	5	19
3267	2019-06-05 15:22:20	2019-06-05	9	[{"id_menu":7,"count":1}]	241	pick-up	0	9
3268	2019-06-05 18:06:40	2019-06-05	14	[{"id_menu":2,"count":1}]	143	pick-up	0	14
3269	2019-06-05 18:13:59	2019-06-05	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	925	pick-up	0	21
3270	2019-06-05 19:28:27	2019-06-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1420	delivery	5	28
3271	2019-06-05 19:30:57	2019-06-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	479	delivery	5	31
3272	2019-06-05 19:34:53	2019-06-05	8	[{"id_menu":5,"count":1}]	957	delivery	5	13
3273	2019-06-05 20:46:30	2019-06-05	9	[{"id_menu":6,"count":1}]	193	delivery	5	14
3274	2019-06-05 21:06:15	2019-06-05	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1012	delivery	5	26
3275	2019-06-05 21:42:40	2019-06-05	12	[{"id_menu":1,"count":1}]	27	pick-up	0	12
3276	2019-06-05 22:21:17	2019-06-05	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	599	pick-up	0	20
3277	2019-06-05 23:51:31	2019-06-05	8	[{"id_menu":5,"count":1}]	259	pick-up	0	8
3278	2019-06-06 00:35:01	2019-06-06	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	424	delivery	5	34
3279	2019-06-06 00:53:11	2019-06-06	17	[{"id_menu":4,"count":1}]	1398	delivery	5	22
3280	2019-06-06 02:10:58	2019-06-06	14	[{"id_menu":2,"count":1}]	1364	delivery	5	19
3281	2019-06-06 02:50:27	2019-06-06	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1433	delivery	5	27
3282	2019-06-06 04:32:47	2019-06-06	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	260	delivery	5	51
3283	2019-06-06 05:12:13	2019-06-06	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	500	pick-up	0	20
3284	2019-06-06 05:14:08	2019-06-06	9	[{"id_menu":6,"count":1}]	528	delivery	5	14
3285	2019-06-06 05:38:14	2019-06-06	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	1079	delivery	5	30
3286	2019-06-06 06:08:55	2019-06-06	12	[{"id_menu":3,"count":1}]	245	delivery	5	17
3287	2019-06-06 06:18:26	2019-06-06	17	[{"id_menu":4,"count":1}]	730	pick-up	0	17
3288	2019-06-06 07:31:53	2019-06-06	12	[{"id_menu":1,"count":1}]	1406	pick-up	0	12
3289	2019-06-06 07:46:13	2019-06-06	14	[{"id_menu":2,"count":1}]	572	pick-up	0	14
3290	2019-06-06 08:04:03	2019-06-06	17	[{"id_menu":4,"count":1}]	742	pick-up	0	17
3291	2019-06-06 09:58:26	2019-06-06	17	[{"id_menu":4,"count":1}]	1021	pick-up	0	17
3292	2019-06-06 10:29:34	2019-06-06	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1174	pick-up	0	21
3293	2019-06-06 10:44:28	2019-06-06	12	[{"id_menu":1,"count":1}]	1427	pick-up	0	12
3294	2019-06-06 11:43:08	2019-06-06	9	[{"id_menu":7,"count":1}]	1428	delivery	5	14
3295	2019-06-06 12:01:29	2019-06-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	676	pick-up	0	23
3296	2019-06-06 12:18:20	2019-06-06	8	[{"id_menu":5,"count":1}]	1410	delivery	5	13
3297	2019-06-06 12:42:10	2019-06-06	9	[{"id_menu":7,"count":1}]	1104	delivery	5	14
3298	2019-06-06 13:14:16	2019-06-06	9	[{"id_menu":6,"count":1}]	1432	delivery	5	14
3299	2019-06-06 13:16:20	2019-06-06	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	289	pick-up	0	31
3300	2019-06-06 13:38:11	2019-06-06	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1429	pick-up	0	31
3301	2019-06-06 13:50:35	2019-06-06	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	764	delivery	5	37
3302	2019-06-06 14:44:57	2019-06-06	14	[{"id_menu":2,"count":1}]	931	pick-up	0	14
3303	2019-06-06 15:04:01	2019-06-06	8	[{"id_menu":5,"count":1}]	1138	pick-up	0	8
3304	2019-06-06 15:43:22	2019-06-06	12	[{"id_menu":3,"count":1}]	1155	delivery	5	17
3305	2019-06-06 16:04:43	2019-06-06	17	[{"id_menu":4,"count":1}]	314	pick-up	0	17
3306	2019-06-06 16:55:25	2019-06-06	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	87	delivery	5	54
3307	2019-06-06 18:41:29	2019-06-06	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1435	pick-up	0	23
3308	2019-06-06 19:02:07	2019-06-06	9	[{"id_menu":7,"count":1}]	226	delivery	5	14
3309	2019-06-06 19:16:44	2019-06-06	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	254	pick-up	0	31
3310	2019-06-06 21:28:32	2019-06-06	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	933	pick-up	0	21
3311	2019-06-06 21:32:31	2019-06-06	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	538	delivery	5	36
3312	2019-06-06 22:03:05	2019-06-06	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1255	pick-up	0	26
3313	2019-06-06 22:12:50	2019-06-06	12	[{"id_menu":3,"count":1}]	1317	pick-up	0	12
3314	2019-06-06 23:17:38	2019-06-06	17	[{"id_menu":4,"count":1}]	381	pick-up	0	17
3315	2019-06-06 23:18:50	2019-06-06	12	[{"id_menu":3,"count":1}]	1434	pick-up	0	12
3316	2019-06-07 00:29:02	2019-06-07	9	[{"id_menu":6,"count":1}]	1438	pick-up	0	9
3317	2019-06-07 00:50:49	2019-06-07	9	[{"id_menu":6,"count":1}]	1440	pick-up	0	9
3318	2019-06-07 01:01:17	2019-06-07	9	[{"id_menu":6,"count":1}]	581	delivery	5	14
3319	2019-06-07 01:12:06	2019-06-07	14	[{"id_menu":2,"count":2}]	1445	delivery	5	19
3320	2019-06-07 02:29:34	2019-06-07	9	[{"id_menu":7,"count":1}]	466	delivery	5	14
3321	2019-06-07 03:28:54	2019-06-07	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1447	pick-up	0	26
3322	2019-06-07 03:49:49	2019-06-07	14	[{"id_menu":2,"count":1}]	1184	pick-up	0	14
3323	2019-06-07 05:57:27	2019-06-07	8	[{"id_menu":5,"count":1}]	944	delivery	5	13
3324	2019-06-07 10:13:57	2019-06-07	14	[{"id_menu":2,"count":1}]	1301	pick-up	0	14
3325	2019-06-07 10:15:11	2019-06-07	17	[{"id_menu":4,"count":1}]	439	pick-up	0	17
3326	2019-06-07 10:21:33	2019-06-07	9	[{"id_menu":7,"count":1}]	270	pick-up	0	9
3327	2019-06-07 10:47:31	2019-06-07	14	[{"id_menu":2,"count":1}]	1449	pick-up	0	14
3328	2019-06-07 15:22:35	2019-06-07	8	[{"id_menu":5,"count":2}]	1444	delivery	5	13
3329	2019-06-07 15:33:33	2019-06-07	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1442	pick-up	0	34
3330	2019-06-07 15:52:03	2019-06-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	1446	pick-up	0	17
3331	2019-06-07 17:52:59	2019-06-07	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	144	pick-up	0	21
3332	2019-06-07 19:08:25	2019-06-07	17	[{"id_menu":4,"count":1}]	707	pick-up	0	17
3333	2019-06-07 19:17:54	2019-06-07	9	[{"id_menu":6,"count":1}]	487	delivery	5	14
3334	2019-06-07 21:15:39	2019-06-07	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	584	pick-up	0	20
3335	2019-06-07 21:46:51	2019-06-07	9	[{"id_menu":6,"count":1}]	1294	pick-up	0	9
3336	2019-06-07 21:49:34	2019-06-07	14	[{"id_menu":2,"count":1}]	806	pick-up	0	14
3337	2019-06-07 22:46:23	2019-06-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	628	delivery	5	22
3338	2019-06-07 23:49:11	2019-06-07	17	[{"id_menu":4,"count":1}]	1441	delivery	5	22
3339	2019-06-07 23:56:17	2019-06-07	17	[{"id_menu":4,"count":1}]	634	pick-up	0	17
3340	2019-06-08 00:33:55	2019-06-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	62	pick-up	0	23
3341	2019-06-08 00:40:03	2019-06-08	14	[{"id_menu":2,"count":1}]	268	pick-up	0	14
3342	2019-06-08 00:53:50	2019-06-08	14	[{"id_menu":2,"count":1}]	1452	pick-up	0	14
3343	2019-06-08 01:19:59	2019-06-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1302	pick-up	0	23
3344	2019-06-08 01:23:55	2019-06-08	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	821	pick-up	0	26
3345	2019-06-08 01:31:24	2019-06-08	9	[{"id_menu":7,"count":2}]	1459	delivery	5	14
3346	2019-06-08 02:39:37	2019-06-08	17	[{"id_menu":4,"count":1}]	204	delivery	5	22
3347	2019-06-08 02:41:41	2019-06-08	14	[{"id_menu":2,"count":1}]	543	pick-up	0	14
3348	2019-06-08 03:49:19	2019-06-08	12	[{"id_menu":1,"count":1}]	1460	pick-up	0	12
3349	2019-06-08 05:12:00	2019-06-08	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1209	pick-up	0	26
3350	2019-06-08 05:12:28	2019-06-08	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	1004	pick-up	0	38
3351	2019-06-08 05:46:52	2019-06-08	12	[{"id_menu":1,"count":1}]	368	pick-up	0	12
3352	2019-06-08 05:52:38	2019-06-08	9	[{"id_menu":7,"count":2}]	1176	delivery	5	14
3353	2019-06-08 07:47:15	2019-06-08	14	[{"id_menu":2,"count":1}]	449	pick-up	0	14
3354	2019-06-08 08:14:58	2019-06-08	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	593	pick-up	0	40
3355	2019-06-08 09:03:30	2019-06-08	17	[{"id_menu":4,"count":2}]	1172	pick-up	0	17
3356	2019-06-08 09:26:56	2019-06-08	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	73	pick-up	0	38
3357	2019-06-08 09:42:50	2019-06-08	12	[{"id_menu":3,"count":1}]	1454	delivery	5	17
3358	2019-06-08 09:58:42	2019-06-08	17	[{"id_menu":4,"count":1}]	1289	delivery	5	22
3359	2019-06-08 12:19:04	2019-06-08	9	[{"id_menu":7,"count":1}]	281	pick-up	0	9
3360	2019-06-08 12:21:13	2019-06-08	17	[{"id_menu":4,"count":1}]	1457	delivery	5	22
3361	2019-06-08 12:22:11	2019-06-08	8	[{"id_menu":5,"count":1}]	1458	pick-up	0	8
3362	2019-06-08 12:48:57	2019-06-08	12	[{"id_menu":1,"count":1}]	1462	delivery	5	17
3363	2019-06-08 14:14:00	2019-06-08	12	[{"id_menu":1,"count":1}]	1427	pick-up	0	12
3364	2019-06-08 15:02:07	2019-06-08	12	[{"id_menu":1,"count":1}]	1461	delivery	5	17
3365	2019-06-08 15:31:20	2019-06-08	9	[{"id_menu":6,"count":1}]	1393	delivery	5	14
3366	2019-06-08 15:47:28	2019-06-08	9	[{"id_menu":7,"count":1}]	558	delivery	5	14
3367	2019-06-08 16:00:19	2019-06-08	12	[{"id_menu":3,"count":1}]	576	pick-up	0	12
3368	2019-06-08 18:28:00	2019-06-08	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	415	delivery	5	23
3369	2019-06-08 18:38:01	2019-06-08	9	[{"id_menu":7,"count":1}]	1455	pick-up	0	9
3370	2019-06-08 19:13:41	2019-06-08	12	[{"id_menu":1,"count":1}]	1453	pick-up	0	12
3371	2019-06-08 19:37:00	2019-06-08	17	[{"id_menu":4,"count":1}]	224	pick-up	0	17
3372	2019-06-08 21:32:49	2019-06-08	9	[{"id_menu":7,"count":1}]	304	pick-up	0	9
3373	2019-06-08 21:52:24	2019-06-08	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1245	delivery	5	27
3374	2019-06-08 22:02:32	2019-06-08	12	[{"id_menu":3,"count":1}]	1456	pick-up	0	12
3375	2019-06-08 22:03:00	2019-06-08	8	[{"id_menu":5,"count":1}]	1169	pick-up	0	8
3376	2019-06-08 22:06:59	2019-06-08	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1451	delivery	5	31
3377	2019-06-08 22:20:55	2019-06-08	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1450	pick-up	0	26
3378	2019-06-08 22:59:37	2019-06-08	8	[{"id_menu":5,"count":1}]	707	delivery	5	13
3379	2019-06-08 23:45:59	2019-06-08	12	[{"id_menu":3,"count":1}]	226	pick-up	0	12
3380	2019-06-09 00:03:52	2019-06-09	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	1355	delivery	5	30
3381	2019-06-09 00:06:36	2019-06-09	9	[{"id_menu":6,"count":1}]	1471	delivery	5	14
3382	2019-06-09 00:42:21	2019-06-09	8	[{"id_menu":5,"count":1}]	1360	delivery	5	13
3383	2019-06-09 01:07:30	2019-06-09	8	[{"id_menu":5,"count":1}]	123	pick-up	0	8
3384	2019-06-09 01:33:07	2019-06-09	9	[{"id_menu":7,"count":1}]	466	delivery	5	14
3385	2019-06-09 01:37:09	2019-06-09	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1445	pick-up	0	22
3386	2019-06-09 01:47:28	2019-06-09	8	[{"id_menu":5,"count":1}]	1470	pick-up	0	8
3387	2019-06-09 03:40:00	2019-06-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	633	pick-up	0	23
3388	2019-06-09 03:51:35	2019-06-09	14	[{"id_menu":2,"count":1}]	161	delivery	5	19
3389	2019-06-09 06:05:00	2019-06-09	17	[{"id_menu":4,"count":1}]	1263	delivery	5	22
3390	2019-06-09 06:11:24	2019-06-09	12	[{"id_menu":1,"count":1}]	1387	delivery	5	17
3391	2019-06-09 06:14:27	2019-06-09	9	[{"id_menu":6,"count":1}]	477	delivery	5	14
3392	2019-06-09 06:38:16	2019-06-09	14	[{"id_menu":2,"count":1}]	1161	pick-up	0	14
3393	2019-06-09 07:34:32	2019-06-09	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	857	delivery	5	31
3394	2019-06-09 09:18:48	2019-06-09	14	[{"id_menu":2,"count":1}]	143	pick-up	0	14
3395	2019-06-09 09:58:45	2019-06-09	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	169	pick-up	0	46
3396	2019-06-09 10:10:23	2019-06-09	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1464	pick-up	0	48
3397	2019-06-09 10:15:42	2019-06-09	17	[{"id_menu":4,"count":1}]	1247	delivery	5	22
3398	2019-06-09 10:59:49	2019-06-09	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1472	pick-up	0	21
3399	2019-06-09 11:19:21	2019-06-09	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	906	pick-up	0	26
3400	2019-06-09 12:58:34	2019-06-09	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	172	delivery	5	52
3401	2019-06-09 13:27:01	2019-06-09	17	[{"id_menu":4,"count":1}]	1115	pick-up	0	17
3402	2019-06-09 13:35:40	2019-06-09	12	[{"id_menu":1,"count":1}]	397	delivery	5	17
3403	2019-06-09 14:15:44	2019-06-09	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1148	pick-up	0	33
3404	2019-06-09 14:16:34	2019-06-09	9	[{"id_menu":7,"count":1}]	1314	pick-up	0	9
3405	2019-06-09 14:17:09	2019-06-09	12	[{"id_menu":1,"count":1}]	817	pick-up	0	12
3406	2019-06-09 14:20:07	2019-06-09	14	[{"id_menu":2,"count":1}]	314	pick-up	0	14
3407	2019-06-09 14:43:34	2019-06-09	14	[{"id_menu":2,"count":1}]	1474	delivery	5	19
3408	2019-06-09 15:01:48	2019-06-09	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1090	delivery	5	43
3409	2019-06-09 15:23:08	2019-06-09	8	[{"id_menu":5,"count":1}]	643	pick-up	0	8
3410	2019-06-09 15:54:52	2019-06-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	377	delivery	5	23
3411	2019-06-09 16:04:37	2019-06-09	9	[{"id_menu":7,"count":1}]	806	delivery	5	14
3412	2019-06-09 16:13:51	2019-06-09	8	[{"id_menu":5,"count":1}]	1467	pick-up	0	8
3413	2019-06-09 16:23:28	2019-06-09	12	[{"id_menu":3,"count":1}]	1475	delivery	5	17
3414	2019-06-09 16:42:51	2019-06-09	9	[{"id_menu":7,"count":1}]	242	pick-up	0	9
3415	2019-06-09 17:27:03	2019-06-09	17	[{"id_menu":4,"count":1}]	1055	pick-up	0	17
3416	2019-06-09 17:49:10	2019-06-09	12	[{"id_menu":1,"count":1}]	1234	delivery	5	17
3417	2019-06-09 18:02:44	2019-06-09	8	[{"id_menu":5,"count":1}]	381	pick-up	0	8
3418	2019-06-09 18:16:22	2019-06-09	12	[{"id_menu":3,"count":1}]	497	pick-up	0	12
3419	2019-06-09 19:36:21	2019-06-09	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1473	pick-up	0	20
3420	2019-06-09 19:40:33	2019-06-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1258	delivery	5	28
3421	2019-06-09 19:47:45	2019-06-09	9	[{"id_menu":7,"count":1}]	1468	pick-up	0	9
3422	2019-06-09 20:06:40	2019-06-09	12	[{"id_menu":3,"count":1}]	81	delivery	5	17
3423	2019-06-09 21:11:29	2019-06-09	12	[{"id_menu":1,"count":1}]	1465	pick-up	0	12
3424	2019-06-09 21:27:51	2019-06-09	9	[{"id_menu":7,"count":1}]	862	pick-up	0	9
3425	2019-06-09 21:30:35	2019-06-09	9	[{"id_menu":7,"count":2}]	651	delivery	5	14
3426	2019-06-09 21:44:52	2019-06-09	14	[{"id_menu":2,"count":1}]	572	pick-up	0	14
3427	2019-06-09 23:06:30	2019-06-09	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	550	delivery	5	48
3428	2019-06-09 23:21:25	2019-06-09	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1466	delivery	5	29
3429	2019-06-09 23:40:24	2019-06-09	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1469	delivery	5	31
3430	2019-06-10 03:00:34	2019-06-10	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	929	pick-up	0	31
3431	2019-06-10 03:04:59	2019-06-10	12	[{"id_menu":1,"count":1}]	338	pick-up	0	12
3432	2019-06-10 03:15:40	2019-06-10	9	[{"id_menu":7,"count":1}]	1480	pick-up	0	9
3433	2019-06-10 07:08:00	2019-06-10	17	[{"id_menu":4,"count":1}]	1482	pick-up	0	17
3434	2019-06-10 07:53:26	2019-06-10	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	519	delivery	5	36
3435	2019-06-10 09:17:34	2019-06-10	9	[{"id_menu":6,"count":1}]	536	pick-up	0	9
3436	2019-06-10 10:22:03	2019-06-10	12	[{"id_menu":1,"count":1}]	101	delivery	5	17
3437	2019-06-10 10:26:52	2019-06-10	9	[{"id_menu":6,"count":1}]	171	delivery	5	14
3438	2019-06-10 10:50:47	2019-06-10	14	[{"id_menu":2,"count":2}]	223	delivery	5	19
3439	2019-06-10 11:30:24	2019-06-10	8	[{"id_menu":5,"count":1}]	260	pick-up	0	8
3440	2019-06-10 12:13:16	2019-06-10	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1212	pick-up	0	26
3441	2019-06-10 15:20:30	2019-06-10	8	[{"id_menu":5,"count":1}]	1486	pick-up	0	8
3442	2019-06-10 15:59:14	2019-06-10	8	[{"id_menu":5,"count":1}]	1065	delivery	5	13
3443	2019-06-10 17:28:48	2019-06-10	12	[{"id_menu":3,"count":1}]	203	delivery	5	17
3444	2019-06-10 17:46:40	2019-06-10	17	[{"id_menu":4,"count":1}]	882	pick-up	0	17
3445	2019-06-10 17:47:12	2019-06-10	14	[{"id_menu":2,"count":1}]	925	pick-up	0	14
3446	2019-06-10 19:01:54	2019-06-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	589	delivery	5	22
3447	2019-06-10 19:50:11	2019-06-10	14	[{"id_menu":2,"count":1}]	1253	pick-up	0	14
3448	2019-06-10 19:59:08	2019-06-10	12	[{"id_menu":1,"count":1}]	1477	pick-up	0	12
3449	2019-06-10 20:17:21	2019-06-10	8	[{"id_menu":5,"count":1}]	1172	delivery	5	13
3450	2019-06-10 20:26:30	2019-06-10	8	[{"id_menu":5,"count":1}]	709	pick-up	0	8
3451	2019-06-10 20:49:36	2019-06-10	8	[{"id_menu":5,"count":1}]	1478	pick-up	0	8
3452	2019-06-10 20:53:19	2019-06-10	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1021	pick-up	0	35
3453	2019-06-10 23:31:19	2019-06-10	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1483	delivery	5	43
3454	2019-06-11 00:19:37	2019-06-11	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	67	delivery	5	36
3455	2019-06-11 00:22:49	2019-06-11	9	[{"id_menu":7,"count":1}]	1201	delivery	5	14
3456	2019-06-11 01:11:48	2019-06-11	9	[{"id_menu":6,"count":1}]	688	delivery	5	14
3457	2019-06-11 01:27:37	2019-06-11	14	[{"id_menu":2,"count":1}]	612	delivery	5	19
3458	2019-06-11 01:48:38	2019-06-11	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1259	delivery	5	31
3459	2019-06-11 02:11:49	2019-06-11	14	[{"id_menu":2,"count":1}]	662	pick-up	0	14
3460	2019-06-11 04:10:46	2019-06-11	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	48	pick-up	0	31
3461	2019-06-11 05:04:00	2019-06-11	9	[{"id_menu":6,"count":1}]	257	delivery	5	14
3462	2019-06-11 07:09:14	2019-06-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	94	delivery	5	22
3463	2019-06-11 08:34:58	2019-06-11	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1493	pick-up	0	24
3464	2019-06-11 08:55:03	2019-06-11	9	[{"id_menu":7,"count":1}]	467	pick-up	0	9
3465	2019-06-11 10:03:48	2019-06-11	12	[{"id_menu":1,"count":1}]	1491	pick-up	0	12
3466	2019-06-11 10:09:16	2019-06-11	8	[{"id_menu":5,"count":1}]	1460	delivery	5	13
3467	2019-06-11 10:59:37	2019-06-11	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	787	pick-up	0	38
3468	2019-06-11 11:55:26	2019-06-11	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	28	pick-up	0	23
3469	2019-06-11 12:19:01	2019-06-11	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1453	pick-up	0	35
3470	2019-06-11 13:13:06	2019-06-11	14	[{"id_menu":2,"count":1}]	914	pick-up	0	14
3471	2019-06-11 13:43:19	2019-06-11	9	[{"id_menu":7,"count":1}]	1489	pick-up	0	9
3472	2019-06-11 14:01:51	2019-06-11	9	[{"id_menu":7,"count":1}]	439	pick-up	0	9
3473	2019-06-11 16:35:24	2019-06-11	9	[{"id_menu":7,"count":1}]	786	delivery	5	14
3474	2019-06-11 16:37:04	2019-06-11	8	[{"id_menu":5,"count":1}]	1487	delivery	5	13
3475	2019-06-11 17:02:00	2019-06-11	8	[{"id_menu":5,"count":1}]	1490	pick-up	0	8
3476	2019-06-11 17:28:41	2019-06-11	12	[{"id_menu":1,"count":1}]	1488	pick-up	0	12
3477	2019-06-11 18:21:27	2019-06-11	17	[{"id_menu":4,"count":1}]	68	pick-up	0	17
3478	2019-06-11 18:58:03	2019-06-11	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	1495	delivery	5	45
3479	2019-06-11 19:54:40	2019-06-11	17	[{"id_menu":4,"count":1}]	1289	pick-up	0	17
3480	2019-06-11 20:41:20	2019-06-11	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	684	pick-up	0	35
3481	2019-06-11 20:53:56	2019-06-11	17	[{"id_menu":4,"count":1}]	586	pick-up	0	17
3482	2019-06-11 21:47:55	2019-06-11	9	[{"id_menu":7,"count":1}]	1303	pick-up	0	9
3483	2019-06-12 00:11:38	2019-06-12	12	[{"id_menu":3,"count":1}]	546	delivery	5	17
3484	2019-06-12 00:44:07	2019-06-12	14	[{"id_menu":2,"count":2}]	1140	pick-up	0	14
3485	2019-06-12 01:08:43	2019-06-12	14	[{"id_menu":2,"count":1}]	445	delivery	5	19
3486	2019-06-12 02:58:19	2019-06-12	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	806	pick-up	0	20
3487	2019-06-12 03:07:57	2019-06-12	12	[{"id_menu":1,"count":1}]	1499	pick-up	0	12
3488	2019-06-12 03:46:29	2019-06-12	9	[{"id_menu":6,"count":1}]	1507	pick-up	0	9
3489	2019-06-12 03:58:49	2019-06-12	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1503	pick-up	0	38
3490	2019-06-12 04:22:28	2019-06-12	9	[{"id_menu":7,"count":1}]	1148	pick-up	0	9
3491	2019-06-12 06:11:09	2019-06-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	399	pick-up	0	17
3492	2019-06-12 06:28:43	2019-06-12	12	[{"id_menu":1,"count":1}]	226	delivery	5	17
3493	2019-06-12 07:38:40	2019-06-12	12	[{"id_menu":3,"count":1}]	376	pick-up	0	12
3494	2019-06-12 08:02:55	2019-06-12	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1505	delivery	5	30
3495	2019-06-12 10:05:16	2019-06-12	12	[{"id_menu":1,"count":1}]	1269	delivery	5	17
3496	2019-06-12 10:08:55	2019-06-12	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1500	pick-up	0	21
3497	2019-06-12 10:16:02	2019-06-12	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1501	pick-up	0	31
3498	2019-06-12 13:54:48	2019-06-12	12	[{"id_menu":3,"count":1}]	213	delivery	5	17
3499	2019-06-12 14:57:08	2019-06-12	9	[{"id_menu":7,"count":1}]	464	pick-up	0	9
3500	2019-06-12 14:59:44	2019-06-12	17	[{"id_menu":4,"count":1}]	870	delivery	5	22
3501	2019-06-12 15:17:13	2019-06-12	14	[{"id_menu":2,"count":1}]	274	delivery	5	19
3502	2019-06-12 15:52:11	2019-06-12	9	[{"id_menu":6,"count":1}]	1506	pick-up	0	9
3503	2019-06-12 17:09:29	2019-06-12	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	1498	delivery	5	31
3504	2019-06-12 18:11:53	2019-06-12	12	[{"id_menu":1,"count":1}]	29	delivery	5	17
3505	2019-06-12 18:29:31	2019-06-12	14	[{"id_menu":2,"count":1}]	1497	pick-up	0	14
3506	2019-06-12 18:32:56	2019-06-12	17	[{"id_menu":4,"count":1}]	1331	delivery	5	22
3507	2019-06-12 18:57:13	2019-06-12	8	[{"id_menu":5,"count":1}]	245	delivery	5	13
3508	2019-06-12 19:17:39	2019-06-12	14	[{"id_menu":2,"count":1}]	175	pick-up	0	14
3509	2019-06-12 21:07:27	2019-06-12	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	88	delivery	5	34
3510	2019-06-12 22:25:03	2019-06-12	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	157	pick-up	0	17
3511	2019-06-12 22:45:31	2019-06-12	12	[{"id_menu":1,"count":1}]	1289	pick-up	0	12
3512	2019-06-12 23:20:44	2019-06-12	12	[{"id_menu":1,"count":1}]	669	delivery	5	17
3513	2019-06-13 01:24:37	2019-06-13	17	[{"id_menu":4,"count":1}]	1183	pick-up	0	17
3514	2019-06-13 02:31:29	2019-06-13	9	[{"id_menu":7,"count":1}]	1324	delivery	5	14
3515	2019-06-13 02:49:01	2019-06-13	9	[{"id_menu":7,"count":1}]	1515	pick-up	0	9
3516	2019-06-13 06:51:44	2019-06-13	12	[{"id_menu":1,"count":1}]	1067	pick-up	0	12
3517	2019-06-13 07:15:46	2019-06-13	12	[{"id_menu":1,"count":1}]	1511	delivery	5	17
3518	2019-06-13 07:21:10	2019-06-13	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	708	delivery	5	34
3519	2019-06-13 07:29:25	2019-06-13	12	[{"id_menu":1,"count":1}]	1101	pick-up	0	12
3520	2019-06-13 08:09:53	2019-06-13	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1514	delivery	5	26
3521	2019-06-13 09:43:32	2019-06-13	12	[{"id_menu":1,"count":1}]	1512	delivery	5	17
3522	2019-06-13 10:15:14	2019-06-13	12	[{"id_menu":1,"count":1}]	1509	pick-up	0	12
3523	2019-06-13 10:19:38	2019-06-13	9	[{"id_menu":7,"count":1}]	1293	delivery	5	14
3524	2019-06-13 12:26:09	2019-06-13	9	[{"id_menu":7,"count":1}]	54	delivery	5	14
3525	2019-06-13 12:27:32	2019-06-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1513	delivery	5	23
3526	2019-06-13 12:42:01	2019-06-13	9	[{"id_menu":6,"count":1}]	1518	delivery	5	14
3527	2019-06-13 12:59:20	2019-06-13	9	[{"id_menu":6,"count":1}]	53	delivery	5	14
3528	2019-06-13 13:25:24	2019-06-13	9	[{"id_menu":6,"count":1}]	473	pick-up	0	9
3529	2019-06-13 15:19:18	2019-06-13	12	[{"id_menu":1,"count":1}]	877	delivery	5	17
3530	2019-06-13 15:59:10	2019-06-13	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1516	delivery	5	27
3531	2019-06-13 16:08:46	2019-06-13	17	[{"id_menu":4,"count":1}]	1354	delivery	5	22
3532	2019-06-13 16:19:51	2019-06-13	8	[{"id_menu":5,"count":1}]	1510	delivery	5	13
3533	2019-06-13 16:40:02	2019-06-13	9	[{"id_menu":7,"count":1}]	1092	delivery	5	14
3534	2019-06-13 18:17:59	2019-06-13	12	[{"id_menu":1,"count":1}]	1376	delivery	5	17
3535	2019-06-13 18:34:34	2019-06-13	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1251	delivery	5	27
3536	2019-06-13 18:34:51	2019-06-13	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1379	delivery	5	52
3537	2019-06-13 18:46:18	2019-06-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1343	pick-up	0	18
3538	2019-06-13 18:59:55	2019-06-13	17	[{"id_menu":4,"count":1}]	1432	pick-up	0	17
3539	2019-06-13 19:15:28	2019-06-13	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1064	delivery	5	25
3540	2019-06-13 19:41:32	2019-06-13	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1517	delivery	5	53
3541	2019-06-13 20:20:33	2019-06-13	9	[{"id_menu":7,"count":1}]	754	pick-up	0	9
3542	2019-06-13 21:29:01	2019-06-13	12	[{"id_menu":1,"count":1}]	1380	delivery	5	17
3543	2019-06-13 22:26:54	2019-06-13	14	[{"id_menu":2,"count":1}]	1508	delivery	5	19
3544	2019-06-13 23:30:38	2019-06-13	17	[{"id_menu":4,"count":1}]	1266	pick-up	0	17
3545	2019-06-14 01:59:30	2019-06-14	14	[{"id_menu":2,"count":1}]	382	pick-up	0	14
3546	2019-06-14 02:43:30	2019-06-14	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	1034	pick-up	0	30
3547	2019-06-14 04:36:03	2019-06-14	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1413	pick-up	0	29
3548	2019-06-14 05:24:34	2019-06-14	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1033	pick-up	0	29
3549	2019-06-14 06:24:44	2019-06-14	14	[{"id_menu":2,"count":1}]	1502	pick-up	0	14
3550	2019-06-14 06:45:31	2019-06-14	8	[{"id_menu":5,"count":1}]	122	delivery	5	13
3551	2019-06-14 06:54:52	2019-06-14	8	[{"id_menu":5,"count":1}]	1523	delivery	5	13
3552	2019-06-14 07:24:55	2019-06-14	8	[{"id_menu":5,"count":1}]	389	pick-up	0	8
3553	2019-06-14 07:43:48	2019-06-14	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	506	pick-up	0	25
3554	2019-06-14 08:00:07	2019-06-14	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1528	pick-up	0	22
3555	2019-06-14 09:09:55	2019-06-14	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	878	pick-up	0	26
3556	2019-06-14 11:02:13	2019-06-14	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	527	pick-up	0	31
3557	2019-06-14 11:24:15	2019-06-14	14	[{"id_menu":2,"count":1}]	1520	pick-up	0	14
3558	2019-06-14 12:43:40	2019-06-14	9	[{"id_menu":7,"count":1}]	1265	delivery	5	14
3559	2019-06-14 14:15:11	2019-06-14	9	[{"id_menu":7,"count":1}]	1527	pick-up	0	9
3560	2019-06-14 14:40:04	2019-06-14	9	[{"id_menu":7,"count":1}]	1524	delivery	5	14
3561	2019-06-14 15:31:47	2019-06-14	14	[{"id_menu":2,"count":1}]	547	pick-up	0	14
3562	2019-06-14 16:17:02	2019-06-14	12	[{"id_menu":1,"count":1}]	770	delivery	5	17
3563	2019-06-14 16:22:53	2019-06-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	62	pick-up	0	17
3564	2019-06-14 16:32:23	2019-06-14	14	[{"id_menu":2,"count":1}]	1481	pick-up	0	14
3565	2019-06-14 17:14:47	2019-06-14	9	[{"id_menu":7,"count":1}]	253	pick-up	0	9
3566	2019-06-14 17:42:29	2019-06-14	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	721	pick-up	0	21
3567	2019-06-14 18:18:47	2019-06-14	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	1097	pick-up	0	21
3568	2019-06-14 18:58:52	2019-06-14	12	[{"id_menu":1,"count":1}]	1387	pick-up	0	12
3569	2019-06-14 19:12:26	2019-06-14	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	1055	delivery	5	34
3570	2019-06-14 19:42:02	2019-06-14	17	[{"id_menu":4,"count":1}]	1521	pick-up	0	17
3571	2019-06-14 20:26:05	2019-06-14	8	[{"id_menu":5,"count":1}]	1208	pick-up	0	8
3572	2019-06-14 21:22:04	2019-06-14	9	[{"id_menu":6,"count":1}]	600	pick-up	0	9
3573	2019-06-14 21:35:16	2019-06-14	12	[{"id_menu":1,"count":1}]	1525	pick-up	0	12
3574	2019-06-14 22:32:19	2019-06-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	763	pick-up	0	31
3575	2019-06-14 23:02:12	2019-06-14	8	[{"id_menu":5,"count":1}]	1529	pick-up	0	8
3576	2019-06-14 23:12:50	2019-06-14	8	[{"id_menu":5,"count":1}]	1522	pick-up	0	8
3577	2019-06-15 00:16:27	2019-06-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	1533	pick-up	0	23
3578	2019-06-15 01:14:56	2019-06-15	12	[{"id_menu":1,"count":1}]	1241	pick-up	0	12
3579	2019-06-15 01:24:52	2019-06-15	12	[{"id_menu":1,"count":1}]	1235	pick-up	0	12
3580	2019-06-15 02:24:27	2019-06-15	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1263	pick-up	0	31
3581	2019-06-15 02:50:10	2019-06-15	9	[{"id_menu":7,"count":1}]	1046	delivery	5	14
3582	2019-06-15 02:51:46	2019-06-15	8	[{"id_menu":5,"count":1}]	1535	delivery	5	13
3583	2019-06-15 02:53:36	2019-06-15	9	[{"id_menu":7,"count":1}]	1375	pick-up	0	9
3584	2019-06-15 03:05:02	2019-06-15	9	[{"id_menu":6,"count":1}]	995	delivery	5	14
3585	2019-06-15 03:15:48	2019-06-15	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1536	delivery	5	30
3586	2019-06-15 03:53:09	2019-06-15	14	[{"id_menu":2,"count":1}]	1166	pick-up	0	14
3587	2019-06-15 04:30:37	2019-06-15	14	[{"id_menu":2,"count":1}]	1282	pick-up	0	14
3588	2019-06-15 05:01:24	2019-06-15	9	[{"id_menu":6,"count":1}]	813	pick-up	0	9
3589	2019-06-15 05:29:58	2019-06-15	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	310	pick-up	0	29
3590	2019-06-15 05:33:28	2019-06-15	12	[{"id_menu":1,"count":1}]	1406	delivery	5	17
3591	2019-06-15 06:45:15	2019-06-15	12	[{"id_menu":1,"count":1}]	1537	pick-up	0	12
3592	2019-06-15 08:38:15	2019-06-15	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1540	pick-up	0	20
3593	2019-06-15 08:42:58	2019-06-15	12	[{"id_menu":1,"count":1}]	1212	pick-up	0	12
3594	2019-06-15 09:37:05	2019-06-15	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1542	pick-up	0	17
3595	2019-06-15 09:40:06	2019-06-15	17	[{"id_menu":4,"count":1}]	335	delivery	5	22
3596	2019-06-15 10:12:26	2019-06-15	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	376	delivery	5	25
3597	2019-06-15 10:17:38	2019-06-15	12	[{"id_menu":1,"count":1}]	189	delivery	5	17
3598	2019-06-15 10:22:30	2019-06-15	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	498	pick-up	0	29
3599	2019-06-15 10:37:36	2019-06-15	9	[{"id_menu":7,"count":1}]	1258	pick-up	0	9
3600	2019-06-15 11:30:19	2019-06-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1076	delivery	5	28
3601	2019-06-15 11:48:15	2019-06-15	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1541	pick-up	0	25
3602	2019-06-15 11:56:52	2019-06-15	14	[{"id_menu":2,"count":1}]	1523	delivery	5	19
3603	2019-06-15 12:37:57	2019-06-15	8	[{"id_menu":5,"count":1}]	261	pick-up	0	8
3604	2019-06-15 15:31:05	2019-06-15	12	[{"id_menu":1,"count":1}]	369	pick-up	0	12
3605	2019-06-15 15:41:47	2019-06-15	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1143	pick-up	0	25
3606	2019-06-15 15:56:14	2019-06-15	9	[{"id_menu":6,"count":1}]	62	pick-up	0	9
3607	2019-06-15 16:53:02	2019-06-15	12	[{"id_menu":1,"count":1}]	1539	pick-up	0	12
3608	2019-06-15 16:53:38	2019-06-15	12	[{"id_menu":1,"count":1}]	287	pick-up	0	12
3609	2019-06-15 17:15:10	2019-06-15	8	[{"id_menu":5,"count":1}]	764	delivery	5	13
3610	2019-06-15 17:59:08	2019-06-15	17	[{"id_menu":4,"count":1}]	786	pick-up	0	17
3611	2019-06-15 18:05:36	2019-06-15	9	[{"id_menu":6,"count":3}]	949	delivery	5	14
3612	2019-06-15 18:36:19	2019-06-15	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	914	pick-up	0	31
3613	2019-06-15 19:15:25	2019-06-15	9	[{"id_menu":6,"count":1}]	1531	pick-up	0	9
3614	2019-06-15 19:28:59	2019-06-15	9	[{"id_menu":6,"count":1}]	1064	delivery	5	14
3615	2019-06-15 19:50:39	2019-06-15	9	[{"id_menu":6,"count":1}]	1532	delivery	5	14
3616	2019-06-15 19:56:30	2019-06-15	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1538	pick-up	0	48
3617	2019-06-15 20:06:06	2019-06-15	9	[{"id_menu":6,"count":1}]	1281	pick-up	0	9
3618	2019-06-15 20:10:45	2019-06-15	12	[{"id_menu":1,"count":1}]	140	pick-up	0	12
3619	2019-06-15 21:06:54	2019-06-15	12	[{"id_menu":1,"count":2}]	1313	pick-up	0	12
3620	2019-06-15 21:42:30	2019-06-15	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1534	pick-up	0	20
3621	2019-06-15 22:08:59	2019-06-15	17	[{"id_menu":4,"count":1}]	489	pick-up	0	17
3622	2019-06-15 23:52:04	2019-06-15	14	[{"id_menu":2,"count":1}]	691	delivery	5	19
3623	2019-06-16 01:14:14	2019-06-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	748	delivery	5	28
3624	2019-06-16 01:59:35	2019-06-16	8	[{"id_menu":5,"count":1}]	723	pick-up	0	8
3625	2019-06-16 02:12:57	2019-06-16	14	[{"id_menu":2,"count":1}]	1212	pick-up	0	14
3626	2019-06-16 02:50:47	2019-06-16	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	1172	delivery	5	43
3627	2019-06-16 03:47:43	2019-06-16	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1548	pick-up	0	26
3628	2019-06-16 04:01:34	2019-06-16	12	[{"id_menu":1,"count":1}]	1351	pick-up	0	12
3629	2019-06-16 04:19:46	2019-06-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1551	delivery	5	31
3630	2019-06-16 05:20:28	2019-06-16	8	[{"id_menu":5,"count":1}]	169	pick-up	0	8
3631	2019-06-16 05:26:14	2019-06-16	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	778	pick-up	0	26
3632	2019-06-16 05:46:56	2019-06-16	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	707	delivery	5	22
3633	2019-06-16 06:26:33	2019-06-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1429	pick-up	0	23
3634	2019-06-16 07:14:19	2019-06-16	17	[{"id_menu":4,"count":2}]	232	pick-up	0	17
3635	2019-06-16 07:15:26	2019-06-16	9	[{"id_menu":6,"count":1}]	1239	pick-up	0	9
3636	2019-06-16 07:16:54	2019-06-16	14	[{"id_menu":2,"count":2}]	1550	pick-up	0	14
3637	2019-06-16 07:59:41	2019-06-16	9	[{"id_menu":7,"count":1}]	1360	pick-up	0	9
3638	2019-06-16 08:02:45	2019-06-16	17	[{"id_menu":4,"count":1}]	1020	delivery	5	22
3639	2019-06-16 08:50:48	2019-06-16	14	[{"id_menu":2,"count":1}]	1549	pick-up	0	14
3640	2019-06-16 09:12:36	2019-06-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	972	delivery	5	31
3641	2019-06-16 09:22:49	2019-06-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1507	delivery	5	28
3642	2019-06-16 11:45:36	2019-06-16	8	[{"id_menu":5,"count":1}]	256	delivery	5	13
3643	2019-06-16 12:29:19	2019-06-16	17	[{"id_menu":4,"count":1}]	1552	pick-up	0	17
3644	2019-06-16 12:29:38	2019-06-16	12	[{"id_menu":3,"count":1}]	1244	delivery	5	17
3645	2019-06-16 13:16:25	2019-06-16	14	[{"id_menu":2,"count":1}]	1547	delivery	5	19
3646	2019-06-16 14:22:11	2019-06-16	14	[{"id_menu":2,"count":2}]	1432	delivery	5	19
3647	2019-06-16 14:42:08	2019-06-16	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	709	pick-up	0	46
3648	2019-06-16 15:39:57	2019-06-16	8	[{"id_menu":5,"count":1}]	1543	delivery	5	13
3649	2019-06-16 16:07:55	2019-06-16	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	946	pick-up	0	29
3650	2019-06-16 17:09:59	2019-06-16	8	[{"id_menu":5,"count":1}]	261	pick-up	0	8
3651	2019-06-16 17:31:18	2019-06-16	9	[{"id_menu":7,"count":1}]	378	pick-up	0	9
3652	2019-06-16 17:33:03	2019-06-16	9	[{"id_menu":7,"count":1}]	1459	delivery	5	14
3653	2019-06-16 17:54:10	2019-06-16	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	823	delivery	5	26
3654	2019-06-16 18:15:19	2019-06-16	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1554	delivery	5	37
3655	2019-06-16 18:28:57	2019-06-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	905	delivery	5	31
3656	2019-06-16 19:09:46	2019-06-16	14	[{"id_menu":2,"count":1}]	1553	delivery	5	19
3657	2019-06-16 20:19:10	2019-06-16	14	[{"id_menu":2,"count":2}]	1545	pick-up	0	14
3658	2019-06-16 20:26:51	2019-06-16	8	[{"id_menu":5,"count":1}]	1546	pick-up	0	8
3659	2019-06-16 22:04:53	2019-06-16	9	[{"id_menu":6,"count":1}]	26	delivery	5	14
3660	2019-06-16 23:09:14	2019-06-16	14	[{"id_menu":2,"count":1}]	1544	delivery	5	19
3661	2019-06-16 23:15:04	2019-06-16	12	[{"id_menu":3,"count":1}]	489	pick-up	0	12
3662	2019-06-16 23:57:59	2019-06-16	12	[{"id_menu":1,"count":1}]	1555	pick-up	0	12
3663	2019-06-17 00:21:13	2019-06-17	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	1564	pick-up	0	41
3664	2019-06-17 02:17:46	2019-06-17	9	[{"id_menu":7,"count":1}]	991	delivery	5	14
3665	2019-06-17 04:52:05	2019-06-17	8	[{"id_menu":5,"count":1}]	96	pick-up	0	8
3666	2019-06-17 08:23:27	2019-06-17	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1561	delivery	5	26
3667	2019-06-17 08:43:06	2019-06-17	17	[{"id_menu":4,"count":1}]	1329	pick-up	0	17
3668	2019-06-17 10:24:31	2019-06-17	17	[{"id_menu":4,"count":1}]	1539	pick-up	0	17
3669	2019-06-17 10:30:52	2019-06-17	12	[{"id_menu":3,"count":1}]	1560	delivery	5	17
3670	2019-06-17 12:46:02	2019-06-17	17	[{"id_menu":4,"count":1}]	1566	pick-up	0	17
3671	2019-06-17 12:46:52	2019-06-17	9	[{"id_menu":6,"count":1}]	541	pick-up	0	9
3672	2019-06-17 14:05:53	2019-06-17	12	[{"id_menu":1,"count":1}]	1241	pick-up	0	12
3673	2019-06-17 14:32:24	2019-06-17	12	[{"id_menu":1,"count":1}]	149	delivery	5	17
3674	2019-06-17 14:39:56	2019-06-17	14	[{"id_menu":2,"count":1}]	1559	pick-up	0	14
3675	2019-06-17 14:52:07	2019-06-17	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	270	pick-up	0	29
3676	2019-06-17 14:52:13	2019-06-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1556	pick-up	0	26
3677	2019-06-17 15:26:51	2019-06-17	17	[{"id_menu":4,"count":1}]	622	delivery	5	22
3678	2019-06-17 15:52:22	2019-06-17	14	[{"id_menu":2,"count":1}]	886	pick-up	0	14
3679	2019-06-17 16:13:46	2019-06-17	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	467	pick-up	0	21
3680	2019-06-17 16:40:44	2019-06-17	9	[{"id_menu":7,"count":1}]	1558	delivery	5	14
3681	2019-06-17 16:49:48	2019-06-17	9	[{"id_menu":6,"count":1}]	1244	pick-up	0	9
3682	2019-06-17 17:49:44	2019-06-17	9	[{"id_menu":7,"count":1}]	1562	pick-up	0	9
3683	2019-06-17 18:34:39	2019-06-17	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	381	pick-up	0	20
3684	2019-06-17 19:13:07	2019-06-17	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	274	pick-up	0	29
3685	2019-06-17 19:17:10	2019-06-17	14	[{"id_menu":2,"count":1}]	1563	pick-up	0	14
3686	2019-06-17 23:47:23	2019-06-17	9	[{"id_menu":6,"count":2}]	265	pick-up	0	9
3687	2019-06-18 00:11:38	2019-06-18	9	[{"id_menu":6,"count":1}]	1507	delivery	5	14
3688	2019-06-18 01:14:36	2019-06-18	8	[{"id_menu":5,"count":1}]	1490	delivery	5	13
3689	2019-06-18 01:45:27	2019-06-18	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1140	delivery	5	34
3690	2019-06-18 01:58:35	2019-06-18	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	1570	delivery	5	31
3691	2019-06-18 03:46:47	2019-06-18	17	[{"id_menu":4,"count":1}]	1008	delivery	5	22
3692	2019-06-18 04:22:12	2019-06-18	8	[{"id_menu":5,"count":1}]	1574	pick-up	0	8
3693	2019-06-18 04:41:20	2019-06-18	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	722	pick-up	0	21
3694	2019-06-18 05:04:56	2019-06-18	9	[{"id_menu":6,"count":1}]	1475	delivery	5	14
3695	2019-06-18 06:15:35	2019-06-18	14	[{"id_menu":2,"count":1}]	1089	pick-up	0	14
3696	2019-06-18 07:16:23	2019-06-18	9	[{"id_menu":7,"count":1}]	286	pick-up	0	9
3697	2019-06-18 08:28:03	2019-06-18	9	[{"id_menu":6,"count":1}]	1573	delivery	5	14
3698	2019-06-18 10:05:26	2019-06-18	9	[{"id_menu":7,"count":1}]	613	pick-up	0	9
3699	2019-06-18 10:13:45	2019-06-18	14	[{"id_menu":2,"count":1}]	1306	delivery	5	19
3700	2019-06-18 12:17:29	2019-06-18	17	[{"id_menu":4,"count":1}]	1562	delivery	5	22
3701	2019-06-18 13:22:43	2019-06-18	8	[{"id_menu":5,"count":1}]	213	pick-up	0	8
3702	2019-06-18 13:50:24	2019-06-18	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	197	pick-up	0	31
3703	2019-06-18 13:57:05	2019-06-18	12	[{"id_menu":3,"count":1}]	1575	delivery	5	17
3704	2019-06-18 14:56:53	2019-06-18	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	31	delivery	5	30
3705	2019-06-18 16:58:28	2019-06-18	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	982	delivery	5	40
3706	2019-06-18 17:19:06	2019-06-18	8	[{"id_menu":5,"count":2}]	1483	delivery	5	13
3707	2019-06-18 18:13:46	2019-06-18	8	[{"id_menu":5,"count":1}]	486	pick-up	0	8
3708	2019-06-18 18:27:38	2019-06-18	9	[{"id_menu":7,"count":1}]	7	delivery	5	14
3709	2019-06-18 18:49:32	2019-06-18	9	[{"id_menu":6,"count":1}]	1569	pick-up	0	9
3710	2019-06-18 18:58:29	2019-06-18	9	[{"id_menu":7,"count":1}]	139	pick-up	0	9
3711	2019-06-18 19:43:01	2019-06-18	12	[{"id_menu":1,"count":1}]	33	pick-up	0	12
3712	2019-06-18 20:53:45	2019-06-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1405	delivery	5	23
3713	2019-06-18 21:14:46	2019-06-18	9	[{"id_menu":6,"count":1}]	1576	pick-up	0	9
3714	2019-06-18 21:34:24	2019-06-18	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	310	delivery	5	26
3715	2019-06-19 00:46:10	2019-06-19	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	113	pick-up	0	21
3716	2019-06-19 00:48:30	2019-06-19	9	[{"id_menu":6,"count":1}]	397	delivery	5	14
3717	2019-06-19 00:52:57	2019-06-19	12	[{"id_menu":1,"count":1}]	44	pick-up	0	12
3718	2019-06-19 02:03:55	2019-06-19	14	[{"id_menu":2,"count":1}]	460	delivery	5	19
3719	2019-06-19 03:16:25	2019-06-19	14	[{"id_menu":2,"count":1}]	729	pick-up	0	14
3720	2019-06-19 04:33:54	2019-06-19	17	[{"id_menu":4,"count":1}]	1130	pick-up	0	17
3721	2019-06-19 04:40:44	2019-06-19	17	[{"id_menu":4,"count":1}]	613	delivery	5	22
3722	2019-06-19 04:42:31	2019-06-19	12	[{"id_menu":1,"count":1}]	271	pick-up	0	12
3723	2019-06-19 05:18:29	2019-06-19	12	[{"id_menu":1,"count":1}]	1022	pick-up	0	12
3724	2019-06-19 06:23:12	2019-06-19	9	[{"id_menu":6,"count":1}]	908	pick-up	0	9
3725	2019-06-19 08:01:05	2019-06-19	30	[{"id_menu":3,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1580	pick-up	0	30
3726	2019-06-19 08:44:32	2019-06-19	9	[{"id_menu":6,"count":1}]	468	pick-up	0	9
3727	2019-06-19 08:54:13	2019-06-19	14	[{"id_menu":2,"count":1}]	84	pick-up	0	14
3728	2019-06-19 09:16:29	2019-06-19	14	[{"id_menu":2,"count":1}]	605	pick-up	0	14
3729	2019-06-19 11:42:27	2019-06-19	12	[{"id_menu":1,"count":1}]	1399	delivery	5	17
3730	2019-06-19 11:48:52	2019-06-19	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1582	delivery	5	40
3731	2019-06-19 11:56:08	2019-06-19	14	[{"id_menu":2,"count":1}]	1586	delivery	5	19
3732	2019-06-19 12:38:43	2019-06-19	14	[{"id_menu":2,"count":1}]	62	pick-up	0	14
3733	2019-06-19 14:40:04	2019-06-19	17	[{"id_menu":4,"count":1}]	1436	delivery	5	22
3734	2019-06-19 17:12:53	2019-06-19	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	1101	delivery	5	29
3735	2019-06-19 17:50:00	2019-06-19	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1587	pick-up	0	22
3736	2019-06-19 18:15:57	2019-06-19	12	[{"id_menu":3,"count":1}]	1079	delivery	5	17
3737	2019-06-19 18:38:08	2019-06-19	9	[{"id_menu":7,"count":1}]	1581	delivery	5	14
3738	2019-06-19 18:38:31	2019-06-19	8	[{"id_menu":5,"count":1}]	1583	delivery	5	13
3739	2019-06-19 19:14:53	2019-06-19	9	[{"id_menu":6,"count":1}]	1579	delivery	5	14
3740	2019-06-19 20:21:34	2019-06-19	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1303	pick-up	0	29
3741	2019-06-19 23:03:06	2019-06-19	12	[{"id_menu":3,"count":1}]	1375	pick-up	0	12
3742	2019-06-19 23:29:38	2019-06-19	9	[{"id_menu":7,"count":1}]	1584	delivery	5	14
3743	2019-06-20 00:24:22	2019-06-20	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1534	pick-up	0	35
3744	2019-06-20 01:52:33	2019-06-20	12	[{"id_menu":1,"count":1}]	1390	pick-up	0	12
3745	2019-06-20 02:21:49	2019-06-20	8	[{"id_menu":5,"count":1}]	880	delivery	5	13
3746	2019-06-20 03:22:58	2019-06-20	17	[{"id_menu":4,"count":1}]	1148	delivery	5	22
3747	2019-06-20 03:32:31	2019-06-20	8	[{"id_menu":5,"count":1}]	1591	delivery	5	13
3748	2019-06-20 03:51:29	2019-06-20	17	[{"id_menu":4,"count":2}]	229	delivery	5	22
3749	2019-06-20 03:56:14	2019-06-20	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	1244	delivery	5	40
3750	2019-06-20 03:57:18	2019-06-20	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1598	delivery	5	31
3751	2019-06-20 04:11:14	2019-06-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	274	pick-up	0	23
3752	2019-06-20 04:14:44	2019-06-20	14	[{"id_menu":2,"count":1}]	1589	pick-up	0	14
3753	2019-06-20 04:49:02	2019-06-20	9	[{"id_menu":6,"count":1}]	76	pick-up	0	9
3754	2019-06-20 04:54:36	2019-06-20	8	[{"id_menu":5,"count":1}]	1316	delivery	5	13
3755	2019-06-20 05:14:36	2019-06-20	14	[{"id_menu":2,"count":1}]	477	delivery	5	19
3756	2019-06-20 05:16:29	2019-06-20	9	[{"id_menu":6,"count":1}]	701	pick-up	0	9
3757	2019-06-20 08:00:51	2019-06-20	9	[{"id_menu":6,"count":1}]	671	delivery	5	14
3758	2019-06-20 08:49:11	2019-06-20	9	[{"id_menu":6,"count":1}]	337	delivery	5	14
3759	2019-06-20 09:00:46	2019-06-20	8	[{"id_menu":5,"count":1}]	1257	delivery	5	13
3760	2019-06-20 09:05:39	2019-06-20	12	[{"id_menu":3,"count":1}]	161	delivery	5	17
3761	2019-06-20 09:15:34	2019-06-20	14	[{"id_menu":2,"count":2}]	623	delivery	5	19
3762	2019-06-20 10:48:54	2019-06-20	14	[{"id_menu":2,"count":1}]	932	delivery	5	19
3763	2019-06-20 11:20:25	2019-06-20	8	[{"id_menu":5,"count":1}]	1592	pick-up	0	8
3764	2019-06-20 14:16:47	2019-06-20	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1597	pick-up	0	31
3765	2019-06-20 14:20:00	2019-06-20	12	[{"id_menu":3,"count":1}]	787	pick-up	0	12
3766	2019-06-20 14:22:59	2019-06-20	12	[{"id_menu":3,"count":1}]	968	pick-up	0	12
3767	2019-06-20 15:00:31	2019-06-20	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1590	pick-up	0	41
3768	2019-06-20 15:29:20	2019-06-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1596	pick-up	0	23
3769	2019-06-20 16:44:34	2019-06-20	9	[{"id_menu":6,"count":1}]	601	pick-up	0	9
3770	2019-06-20 19:29:57	2019-06-20	9	[{"id_menu":7,"count":1}]	886	pick-up	0	9
3771	2019-06-20 19:51:18	2019-06-20	14	[{"id_menu":2,"count":1}]	122	delivery	5	19
3772	2019-06-20 19:53:38	2019-06-20	8	[{"id_menu":5,"count":1}]	1594	pick-up	0	8
3773	2019-06-20 19:59:55	2019-06-20	17	[{"id_menu":4,"count":1}]	1593	delivery	5	22
3774	2019-06-20 21:13:09	2019-06-20	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1599	pick-up	0	17
3775	2019-06-20 21:13:31	2019-06-20	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1595	delivery	5	26
3776	2019-06-20 21:16:52	2019-06-20	12	[{"id_menu":1,"count":1}]	1189	pick-up	0	12
3777	2019-06-21 04:08:59	2019-06-21	12	[{"id_menu":3,"count":1}]	1358	pick-up	0	12
3778	2019-06-21 04:28:19	2019-06-21	8	[{"id_menu":5,"count":1}]	201	pick-up	0	8
3779	2019-06-21 04:37:29	2019-06-21	8	[{"id_menu":5,"count":1}]	1563	pick-up	0	8
3780	2019-06-21 05:08:58	2019-06-21	14	[{"id_menu":2,"count":1}]	1537	pick-up	0	14
3781	2019-06-21 05:38:23	2019-06-21	12	[{"id_menu":3,"count":1}]	1054	delivery	5	17
3782	2019-06-21 08:23:11	2019-06-21	14	[{"id_menu":2,"count":1}]	113	pick-up	0	14
3783	2019-06-21 08:42:14	2019-06-21	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1602	pick-up	0	38
3784	2019-06-21 08:55:59	2019-06-21	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1352	pick-up	0	21
3785	2019-06-21 10:10:52	2019-06-21	12	[{"id_menu":1,"count":1}]	29	pick-up	0	12
3786	2019-06-21 10:29:35	2019-06-21	14	[{"id_menu":2,"count":1}]	802	delivery	5	19
3787	2019-06-21 10:52:23	2019-06-21	17	[{"id_menu":4,"count":1}]	1462	pick-up	0	17
3788	2019-06-21 10:55:45	2019-06-21	9	[{"id_menu":6,"count":1}]	1608	pick-up	0	9
3789	2019-06-21 10:56:53	2019-06-21	12	[{"id_menu":3,"count":1}]	1468	pick-up	0	12
3790	2019-06-21 11:46:42	2019-06-21	8	[{"id_menu":5,"count":1}]	545	pick-up	0	8
3791	2019-06-21 12:06:05	2019-06-21	9	[{"id_menu":7,"count":1}]	1245	pick-up	0	9
3792	2019-06-21 12:58:13	2019-06-21	17	[{"id_menu":4,"count":1}]	1601	delivery	5	22
3793	2019-06-21 13:11:01	2019-06-21	9	[{"id_menu":6,"count":1}]	720	delivery	5	14
3794	2019-06-21 13:58:56	2019-06-21	9	[{"id_menu":6,"count":1}]	536	pick-up	0	9
3795	2019-06-21 14:10:14	2019-06-21	17	[{"id_menu":4,"count":1}]	1269	pick-up	0	17
3796	2019-06-21 14:31:07	2019-06-21	8	[{"id_menu":5,"count":1}]	925	pick-up	0	8
3797	2019-06-21 15:00:56	2019-06-21	9	[{"id_menu":7,"count":2}]	1255	pick-up	0	9
3798	2019-06-21 15:01:08	2019-06-21	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1612	delivery	5	26
3799	2019-06-21 15:10:07	2019-06-21	9	[{"id_menu":6,"count":1}]	1568	pick-up	0	9
3800	2019-06-21 17:18:29	2019-06-21	8	[{"id_menu":5,"count":1}]	1085	pick-up	0	8
3801	2019-06-21 17:31:36	2019-06-21	9	[{"id_menu":7,"count":1}]	92	pick-up	0	9
3802	2019-06-21 17:48:13	2019-06-21	9	[{"id_menu":7,"count":1}]	1101	delivery	5	14
3803	2019-06-21 18:32:28	2019-06-21	8	[{"id_menu":5,"count":1}]	1609	delivery	5	13
3804	2019-06-21 19:13:36	2019-06-21	17	[{"id_menu":4,"count":1}]	1606	pick-up	0	17
3805	2019-06-21 19:54:04	2019-06-21	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1607	delivery	5	25
3806	2019-06-21 21:01:30	2019-06-21	12	[{"id_menu":3,"count":1}]	209	delivery	5	17
3807	2019-06-21 21:05:36	2019-06-21	14	[{"id_menu":2,"count":1}]	140	pick-up	0	14
3808	2019-06-21 21:44:18	2019-06-21	17	[{"id_menu":4,"count":1}]	1098	delivery	5	22
3809	2019-06-21 22:16:03	2019-06-21	12	[{"id_menu":3,"count":1}]	1600	pick-up	0	12
3810	2019-06-21 23:54:00	2019-06-21	17	[{"id_menu":4,"count":1}]	292	delivery	5	22
3811	2019-06-22 00:17:16	2019-06-22	14	[{"id_menu":2,"count":1}]	29	pick-up	0	14
3812	2019-06-22 00:19:29	2019-06-22	17	[{"id_menu":4,"count":1}]	1616	pick-up	0	17
3813	2019-06-22 02:12:02	2019-06-22	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	197	pick-up	0	24
3814	2019-06-22 02:22:23	2019-06-22	14	[{"id_menu":2,"count":1}]	1289	delivery	5	19
3815	2019-06-22 02:27:02	2019-06-22	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1619	delivery	5	34
3816	2019-06-22 03:26:32	2019-06-22	14	[{"id_menu":2,"count":2}]	541	delivery	5	19
3817	2019-06-22 03:42:08	2019-06-22	14	[{"id_menu":2,"count":1}]	1528	pick-up	0	14
3818	2019-06-22 03:50:37	2019-06-22	14	[{"id_menu":2,"count":1}]	763	pick-up	0	14
3819	2019-06-22 04:15:52	2019-06-22	14	[{"id_menu":2,"count":1}]	864	pick-up	0	14
3820	2019-06-22 04:37:53	2019-06-22	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1623	delivery	5	31
3821	2019-06-22 05:28:31	2019-06-22	17	[{"id_menu":4,"count":1}]	1621	delivery	5	22
3822	2019-06-22 06:41:30	2019-06-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	140	delivery	5	36
3823	2019-06-22 06:47:19	2019-06-22	12	[{"id_menu":1,"count":1}]	547	pick-up	0	12
3824	2019-06-22 06:50:35	2019-06-22	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1208	pick-up	0	38
3825	2019-06-22 07:19:27	2019-06-22	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1626	delivery	5	29
3826	2019-06-22 07:56:48	2019-06-22	12	[{"id_menu":1,"count":1}]	148	delivery	5	17
3827	2019-06-22 08:24:53	2019-06-22	12	[{"id_menu":1,"count":1}]	24	pick-up	0	12
3828	2019-06-22 09:01:16	2019-06-22	9	[{"id_menu":6,"count":1}]	1622	pick-up	0	9
3829	2019-06-22 09:56:09	2019-06-22	9	[{"id_menu":7,"count":1}]	1432	pick-up	0	9
3830	2019-06-22 10:19:57	2019-06-22	9	[{"id_menu":6,"count":2}]	1615	pick-up	0	9
3831	2019-06-22 10:48:28	2019-06-22	14	[{"id_menu":2,"count":1}]	352	delivery	5	19
3832	2019-06-22 11:55:54	2019-06-22	9	[{"id_menu":6,"count":1}]	1620	delivery	5	14
3833	2019-06-22 11:56:01	2019-06-22	9	[{"id_menu":6,"count":1}]	1170	pick-up	0	9
3834	2019-06-22 12:21:26	2019-06-22	14	[{"id_menu":2,"count":1}]	1147	pick-up	0	14
3835	2019-06-22 12:37:52	2019-06-22	8	[{"id_menu":5,"count":1}]	627	pick-up	0	8
3836	2019-06-22 13:44:34	2019-06-22	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	847	pick-up	0	52
3837	2019-06-22 13:53:26	2019-06-22	12	[{"id_menu":3,"count":2}]	997	pick-up	0	12
3838	2019-06-22 14:28:25	2019-06-22	14	[{"id_menu":2,"count":1}]	377	delivery	5	19
3839	2019-06-22 14:46:45	2019-06-22	14	[{"id_menu":2,"count":1}]	1376	pick-up	0	14
3840	2019-06-22 15:20:03	2019-06-22	17	[{"id_menu":4,"count":1}]	1353	pick-up	0	17
3841	2019-06-22 15:34:32	2019-06-22	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1617	pick-up	0	22
3842	2019-06-22 15:39:12	2019-06-22	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	884	pick-up	0	24
3843	2019-06-22 16:00:43	2019-06-22	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	1114	pick-up	0	20
3844	2019-06-22 18:46:14	2019-06-22	8	[{"id_menu":5,"count":1}]	1625	delivery	5	13
3845	2019-06-22 18:58:36	2019-06-22	12	[{"id_menu":3,"count":1}]	1613	pick-up	0	12
3846	2019-06-22 19:58:54	2019-06-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	1319	delivery	5	28
3847	2019-06-22 20:37:33	2019-06-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	432	pick-up	0	17
3848	2019-06-22 20:58:39	2019-06-22	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	122	pick-up	0	21
3849	2019-06-22 21:02:25	2019-06-22	9	[{"id_menu":7,"count":1}]	1549	pick-up	0	9
3850	2019-06-22 21:09:01	2019-06-22	9	[{"id_menu":6,"count":2}]	1614	pick-up	0	9
3851	2019-06-22 21:21:02	2019-06-22	9	[{"id_menu":7,"count":1}]	318	delivery	5	14
3852	2019-06-22 21:46:46	2019-06-22	12	[{"id_menu":3,"count":1}]	229	pick-up	0	12
3853	2019-06-22 21:57:38	2019-06-22	8	[{"id_menu":5,"count":1}]	626	pick-up	0	8
3854	2019-06-22 22:11:21	2019-06-22	12	[{"id_menu":1,"count":1}]	1618	pick-up	0	12
3855	2019-06-22 23:37:52	2019-06-22	12	[{"id_menu":1,"count":1}]	1624	pick-up	0	12
3856	2019-06-22 23:50:52	2019-06-22	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1021	pick-up	0	43
3857	2019-06-23 00:38:28	2019-06-23	17	[{"id_menu":4,"count":1}]	742	pick-up	0	17
3858	2019-06-23 00:51:46	2019-06-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	381	delivery	5	26
3859	2019-06-23 01:01:10	2019-06-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1257	pick-up	0	17
3860	2019-06-23 01:08:41	2019-06-23	12	[{"id_menu":1,"count":1}]	837	delivery	5	17
3861	2019-06-23 01:41:33	2019-06-23	9	[{"id_menu":6,"count":1}]	1632	pick-up	0	9
3862	2019-06-23 01:44:44	2019-06-23	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1637	pick-up	0	20
3863	2019-06-23 02:16:18	2019-06-23	9	[{"id_menu":6,"count":1}]	1484	delivery	5	14
3864	2019-06-23 02:29:26	2019-06-23	9	[{"id_menu":7,"count":1}]	1559	pick-up	0	9
3865	2019-06-23 03:38:30	2019-06-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1628	pick-up	0	17
3866	2019-06-23 03:49:57	2019-06-23	9	[{"id_menu":7,"count":1}]	1507	pick-up	0	9
3867	2019-06-23 03:56:47	2019-06-23	12	[{"id_menu":1,"count":1}]	832	pick-up	0	12
3868	2019-06-23 04:09:58	2019-06-23	8	[{"id_menu":5,"count":1}]	546	delivery	5	13
3869	2019-06-23 04:13:07	2019-06-23	12	[{"id_menu":3,"count":1}]	584	delivery	5	17
3870	2019-06-23 04:30:19	2019-06-23	12	[{"id_menu":3,"count":1}]	1432	pick-up	0	12
3871	2019-06-23 04:52:13	2019-06-23	9	[{"id_menu":6,"count":1}]	1089	pick-up	0	9
3872	2019-06-23 04:53:46	2019-06-23	12	[{"id_menu":3,"count":1}]	295	pick-up	0	12
3873	2019-06-23 04:53:53	2019-06-23	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1633	delivery	5	48
3874	2019-06-23 04:55:44	2019-06-23	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1630	delivery	5	45
3875	2019-06-23 05:10:06	2019-06-23	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1635	delivery	5	36
3876	2019-06-23 05:15:27	2019-06-23	14	[{"id_menu":2,"count":2}]	1097	pick-up	0	14
3877	2019-06-23 07:33:56	2019-06-23	17	[{"id_menu":4,"count":2}]	960	pick-up	0	17
3878	2019-06-23 08:03:18	2019-06-23	14	[{"id_menu":2,"count":1}]	229	delivery	5	19
3879	2019-06-23 08:15:54	2019-06-23	14	[{"id_menu":2,"count":1}]	1638	delivery	5	19
3880	2019-06-23 09:13:19	2019-06-23	9	[{"id_menu":7,"count":1}]	593	pick-up	0	9
3881	2019-06-23 10:36:18	2019-06-23	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	586	pick-up	0	29
3882	2019-06-23 10:52:22	2019-06-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	73	delivery	5	28
3883	2019-06-23 10:57:09	2019-06-23	9	[{"id_menu":6,"count":1}]	890	delivery	5	14
3884	2019-06-23 11:52:46	2019-06-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	37	pick-up	0	26
3885	2019-06-23 11:56:49	2019-06-23	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	440	delivery	5	34
3886	2019-06-23 12:10:04	2019-06-23	12	[{"id_menu":1,"count":2}]	925	pick-up	0	12
3887	2019-06-23 12:20:39	2019-06-23	9	[{"id_menu":6,"count":1}]	1529	pick-up	0	9
3888	2019-06-23 12:38:10	2019-06-23	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1634	delivery	5	57
3889	2019-06-23 12:52:19	2019-06-23	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1031	delivery	5	52
3890	2019-06-23 13:07:49	2019-06-23	17	[{"id_menu":4,"count":1}]	934	pick-up	0	17
3891	2019-06-23 13:42:18	2019-06-23	8	[{"id_menu":5,"count":1}]	287	pick-up	0	8
3892	2019-06-23 14:17:19	2019-06-23	17	[{"id_menu":4,"count":1}]	1415	pick-up	0	17
3893	2019-06-23 14:32:52	2019-06-23	8	[{"id_menu":5,"count":1}]	850	delivery	5	13
3894	2019-06-23 14:34:46	2019-06-23	12	[{"id_menu":1,"count":1}]	1453	pick-up	0	12
3895	2019-06-23 14:50:06	2019-06-23	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1078	delivery	5	48
3896	2019-06-23 14:56:38	2019-06-23	12	[{"id_menu":1,"count":1}]	882	pick-up	0	12
3897	2019-06-23 15:14:26	2019-06-23	9	[{"id_menu":7,"count":1}]	1325	delivery	5	14
3898	2019-06-23 15:19:49	2019-06-23	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	729	pick-up	0	21
3899	2019-06-23 15:37:20	2019-06-23	14	[{"id_menu":2,"count":2}]	62	pick-up	0	14
3900	2019-06-23 15:40:06	2019-06-23	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	535	delivery	5	57
3901	2019-06-23 16:19:00	2019-06-23	12	[{"id_menu":3,"count":1}]	1627	delivery	5	17
3902	2019-06-23 16:36:30	2019-06-23	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1487	pick-up	0	25
3903	2019-06-23 16:46:37	2019-06-23	17	[{"id_menu":4,"count":1}]	1070	pick-up	0	17
3904	2019-06-23 17:03:59	2019-06-23	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	836	delivery	5	34
3905	2019-06-23 17:52:41	2019-06-23	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	490	delivery	5	26
3906	2019-06-23 17:55:17	2019-06-23	12	[{"id_menu":1,"count":1}]	669	pick-up	0	12
3907	2019-06-23 18:35:34	2019-06-23	9	[{"id_menu":7,"count":1}]	1639	pick-up	0	9
3908	2019-06-23 18:51:47	2019-06-23	8	[{"id_menu":5,"count":1}]	460	delivery	5	13
3909	2019-06-23 19:14:35	2019-06-23	17	[{"id_menu":4,"count":1}]	122	pick-up	0	17
3910	2019-06-23 19:19:18	2019-06-23	17	[{"id_menu":4,"count":1}]	1636	pick-up	0	17
3911	2019-06-23 19:47:14	2019-06-23	14	[{"id_menu":2,"count":1}]	1629	pick-up	0	14
3912	2019-06-23 21:14:42	2019-06-23	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	137	pick-up	0	31
3913	2019-06-23 21:48:28	2019-06-23	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	265	delivery	5	25
3914	2019-06-23 21:51:07	2019-06-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1501	pick-up	0	23
3915	2019-06-23 22:26:21	2019-06-23	14	[{"id_menu":2,"count":1}]	1631	pick-up	0	14
3916	2019-06-24 00:25:25	2019-06-24	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	1647	delivery	5	31
3917	2019-06-24 01:37:45	2019-06-24	17	[{"id_menu":4,"count":1}]	1642	pick-up	0	17
3918	2019-06-24 02:58:45	2019-06-24	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	509	delivery	5	26
3919	2019-06-24 03:45:22	2019-06-24	12	[{"id_menu":1,"count":1}]	1644	pick-up	0	12
3920	2019-06-24 03:46:19	2019-06-24	14	[{"id_menu":2,"count":1}]	376	pick-up	0	14
3921	2019-06-24 03:51:02	2019-06-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	749	pick-up	0	23
3922	2019-06-24 04:03:26	2019-06-24	14	[{"id_menu":2,"count":1}]	1646	pick-up	0	14
3923	2019-06-24 06:38:07	2019-06-24	9	[{"id_menu":6,"count":1}]	639	pick-up	0	9
3924	2019-06-24 08:33:49	2019-06-24	8	[{"id_menu":5,"count":1}]	126	pick-up	0	8
3925	2019-06-24 08:56:29	2019-06-24	12	[{"id_menu":1,"count":1}]	1168	pick-up	0	12
3926	2019-06-24 09:49:54	2019-06-24	12	[{"id_menu":3,"count":1}]	477	pick-up	0	12
3927	2019-06-24 10:03:35	2019-06-24	12	[{"id_menu":1,"count":1}]	1289	pick-up	0	12
3928	2019-06-24 10:05:20	2019-06-24	9	[{"id_menu":7,"count":1}]	1010	delivery	5	14
3929	2019-06-24 10:26:20	2019-06-24	8	[{"id_menu":5,"count":1}]	1641	delivery	5	13
3930	2019-06-24 12:01:41	2019-06-24	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1645	delivery	5	34
3931	2019-06-24 12:11:47	2019-06-24	9	[{"id_menu":7,"count":1}]	1652	pick-up	0	9
3932	2019-06-24 12:50:40	2019-06-24	12	[{"id_menu":1,"count":1}]	1044	pick-up	0	12
3933	2019-06-24 13:18:16	2019-06-24	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	699	delivery	5	36
3934	2019-06-24 13:34:31	2019-06-24	17	[{"id_menu":4,"count":1}]	1512	pick-up	0	17
3935	2019-06-24 14:05:18	2019-06-24	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1072	delivery	5	36
3936	2019-06-24 14:07:26	2019-06-24	8	[{"id_menu":5,"count":1}]	925	pick-up	0	8
3937	2019-06-24 15:31:29	2019-06-24	17	[{"id_menu":4,"count":1}]	1528	pick-up	0	17
3938	2019-06-24 16:30:09	2019-06-24	12	[{"id_menu":1,"count":1}]	1343	pick-up	0	12
3939	2019-06-24 16:57:43	2019-06-24	14	[{"id_menu":2,"count":1}]	1449	delivery	5	19
3940	2019-06-24 18:20:00	2019-06-24	9	[{"id_menu":7,"count":2}]	949	delivery	5	14
3941	2019-06-24 21:22:48	2019-06-24	8	[{"id_menu":5,"count":1}]	1643	delivery	5	13
3942	2019-06-24 23:13:20	2019-06-24	8	[{"id_menu":5,"count":1}]	1344	pick-up	0	8
3943	2019-06-25 00:01:46	2019-06-25	9	[{"id_menu":6,"count":1}]	946	pick-up	0	9
3944	2019-06-25 01:17:17	2019-06-25	12	[{"id_menu":1,"count":1}]	1657	delivery	5	17
3945	2019-06-25 02:03:55	2019-06-25	17	[{"id_menu":4,"count":1}]	1414	pick-up	0	17
3946	2019-06-25 02:55:37	2019-06-25	12	[{"id_menu":1,"count":1}]	1432	pick-up	0	12
3947	2019-06-25 03:02:12	2019-06-25	17	[{"id_menu":4,"count":1}]	1454	pick-up	0	17
3948	2019-06-25 03:14:33	2019-06-25	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	1663	delivery	5	36
3949	2019-06-25 03:20:10	2019-06-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	790	delivery	5	28
3950	2019-06-25 05:06:57	2019-06-25	8	[{"id_menu":5,"count":1}]	1313	pick-up	0	8
3951	2019-06-25 05:15:00	2019-06-25	14	[{"id_menu":2,"count":1}]	1461	pick-up	0	14
3952	2019-06-25 05:40:33	2019-06-25	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1144	pick-up	0	29
3953	2019-06-25 06:19:07	2019-06-25	12	[{"id_menu":3,"count":1}]	1658	delivery	5	17
3954	2019-06-25 07:58:29	2019-06-25	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	126	delivery	5	22
3955	2019-06-25 08:10:37	2019-06-25	12	[{"id_menu":3,"count":1}]	1138	pick-up	0	12
3956	2019-06-25 08:14:04	2019-06-25	12	[{"id_menu":1,"count":1}]	313	pick-up	0	12
3957	2019-06-25 08:44:27	2019-06-25	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	389	pick-up	0	43
3958	2019-06-25 08:59:08	2019-06-25	8	[{"id_menu":5,"count":1}]	235	pick-up	0	8
3959	2019-06-25 09:12:02	2019-06-25	9	[{"id_menu":7,"count":1}]	1462	pick-up	0	9
3960	2019-06-25 09:29:21	2019-06-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	841	delivery	5	31
3961	2019-06-25 09:45:10	2019-06-25	8	[{"id_menu":5,"count":1}]	1605	delivery	5	13
3962	2019-06-25 10:14:30	2019-06-25	14	[{"id_menu":2,"count":1}]	925	pick-up	0	14
3963	2019-06-25 11:13:38	2019-06-25	9	[{"id_menu":7,"count":1}]	1654	pick-up	0	9
3964	2019-06-25 11:34:38	2019-06-25	9	[{"id_menu":6,"count":1}]	1655	delivery	5	14
3965	2019-06-25 12:14:32	2019-06-25	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	1514	delivery	5	31
3966	2019-06-25 12:30:04	2019-06-25	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1664	pick-up	0	20
3967	2019-06-25 12:31:54	2019-06-25	14	[{"id_menu":2,"count":1}]	506	pick-up	0	14
3968	2019-06-25 14:13:44	2019-06-25	12	[{"id_menu":3,"count":1}]	1322	delivery	5	17
3969	2019-06-25 15:27:28	2019-06-25	14	[{"id_menu":2,"count":1}]	1166	delivery	5	19
3970	2019-06-25 15:33:53	2019-06-25	12	[{"id_menu":3,"count":1}]	830	pick-up	0	12
3971	2019-06-25 15:47:48	2019-06-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	754	pick-up	0	18
3972	2019-06-25 17:43:54	2019-06-25	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	748	delivery	5	37
3973	2019-06-25 18:08:32	2019-06-25	9	[{"id_menu":7,"count":1}]	1429	pick-up	0	9
3974	2019-06-25 18:21:13	2019-06-25	12	[{"id_menu":1,"count":1}]	396	delivery	5	17
3975	2019-06-25 18:52:40	2019-06-25	12	[{"id_menu":1,"count":1}]	1092	delivery	5	17
3976	2019-06-25 19:36:52	2019-06-25	17	[{"id_menu":4,"count":1}]	489	delivery	5	22
3977	2019-06-25 21:41:31	2019-06-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1653	pick-up	0	17
3978	2019-06-25 21:50:41	2019-06-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1451	delivery	5	23
3979	2019-06-25 22:12:11	2019-06-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	525	delivery	5	22
3980	2019-06-25 22:56:23	2019-06-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1481	delivery	5	28
3981	2019-06-25 23:31:39	2019-06-25	12	[{"id_menu":3,"count":1}]	1656	delivery	5	17
3982	2019-06-26 00:05:47	2019-06-26	9	[{"id_menu":6,"count":1}]	1669	delivery	5	14
3983	2019-06-26 00:19:54	2019-06-26	9	[{"id_menu":7,"count":1}]	359	pick-up	0	9
3984	2019-06-26 00:37:30	2019-06-26	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1675	pick-up	0	20
3985	2019-06-26 00:59:32	2019-06-26	9	[{"id_menu":7,"count":1}]	1674	pick-up	0	9
3986	2019-06-26 01:09:40	2019-06-26	9	[{"id_menu":7,"count":1}]	424	pick-up	0	9
3987	2019-06-26 01:26:29	2019-06-26	12	[{"id_menu":1,"count":1}]	1282	pick-up	0	12
3988	2019-06-26 02:44:45	2019-06-26	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	570	pick-up	0	29
3989	2019-06-26 03:12:50	2019-06-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1188	pick-up	0	21
3990	2019-06-26 03:54:20	2019-06-26	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	1088	pick-up	0	31
3991	2019-06-26 04:38:40	2019-06-26	17	[{"id_menu":4,"count":1}]	91	pick-up	0	17
3992	2019-06-26 06:45:31	2019-06-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	925	pick-up	0	23
3993	2019-06-26 07:39:18	2019-06-26	8	[{"id_menu":5,"count":1}]	951	delivery	5	13
3994	2019-06-26 08:41:27	2019-06-26	12	[{"id_menu":1,"count":1}]	1545	pick-up	0	12
3995	2019-06-26 10:07:18	2019-06-26	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	460	delivery	5	30
3996	2019-06-26 10:42:54	2019-06-26	12	[{"id_menu":1,"count":1}]	286	pick-up	0	12
3997	2019-06-26 10:59:43	2019-06-26	8	[{"id_menu":5,"count":1}]	1676	delivery	5	13
3998	2019-06-26 11:39:14	2019-06-26	9	[{"id_menu":6,"count":1}]	1481	delivery	5	14
3999	2019-06-26 12:03:41	2019-06-26	12	[{"id_menu":1,"count":1}]	1673	pick-up	0	12
4000	2019-06-26 12:06:47	2019-06-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1581	pick-up	0	23
4001	2019-06-26 12:34:27	2019-06-26	9	[{"id_menu":7,"count":1}]	1075	delivery	5	14
4002	2019-06-26 12:46:34	2019-06-26	14	[{"id_menu":2,"count":1}]	399	pick-up	0	14
4003	2019-06-26 12:49:14	2019-06-26	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	27	pick-up	0	31
4004	2019-06-26 13:45:58	2019-06-26	9	[{"id_menu":6,"count":1}]	1670	delivery	5	14
4005	2019-06-26 15:58:35	2019-06-26	14	[{"id_menu":2,"count":1}]	829	delivery	5	19
4006	2019-06-26 16:12:47	2019-06-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	1494	delivery	5	22
4007	2019-06-26 16:32:26	2019-06-26	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	688	delivery	5	36
4008	2019-06-26 16:58:14	2019-06-26	12	[{"id_menu":3,"count":1}]	1666	pick-up	0	12
4009	2019-06-26 17:26:27	2019-06-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1667	pick-up	0	21
4010	2019-06-26 17:31:02	2019-06-26	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	1363	pick-up	0	29
4011	2019-06-26 17:48:24	2019-06-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1537	delivery	5	26
4012	2019-06-26 18:37:12	2019-06-26	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	377	delivery	5	34
4013	2019-06-26 18:51:36	2019-06-26	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1559	pick-up	0	20
4014	2019-06-26 20:29:12	2019-06-26	9	[{"id_menu":6,"count":1}]	1668	delivery	5	14
4015	2019-06-26 22:59:11	2019-06-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1490	pick-up	0	17
4016	2019-06-27 01:03:02	2019-06-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	975	delivery	5	28
4017	2019-06-27 02:22:35	2019-06-27	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1322	delivery	5	28
4018	2019-06-27 03:06:44	2019-06-27	9	[{"id_menu":6,"count":1}]	145	pick-up	0	9
4019	2019-06-27 03:41:00	2019-06-27	12	[{"id_menu":1,"count":1}]	1678	pick-up	0	12
4020	2019-06-27 05:00:15	2019-06-27	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1687	pick-up	0	20
4021	2019-06-27 05:17:06	2019-06-27	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1682	pick-up	0	43
4022	2019-06-27 05:26:49	2019-06-27	9	[{"id_menu":6,"count":1}]	158	pick-up	0	9
4023	2019-06-27 05:58:25	2019-06-27	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	543	delivery	5	26
4024	2019-06-27 07:01:46	2019-06-27	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1683	delivery	5	28
4025	2019-06-27 07:41:43	2019-06-27	9	[{"id_menu":7,"count":1}]	1685	pick-up	0	9
4026	2019-06-27 08:13:47	2019-06-27	12	[{"id_menu":3,"count":1}]	1036	pick-up	0	12
4027	2019-06-27 08:32:53	2019-06-27	9	[{"id_menu":7,"count":1}]	209	pick-up	0	9
4028	2019-06-27 09:06:45	2019-06-27	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1255	pick-up	0	26
4029	2019-06-27 09:26:26	2019-06-27	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	1562	pick-up	0	29
4030	2019-06-27 09:46:54	2019-06-27	9	[{"id_menu":6,"count":1}]	1529	pick-up	0	9
4031	2019-06-27 10:08:57	2019-06-27	8	[{"id_menu":5,"count":1}]	1677	delivery	5	13
4032	2019-06-27 10:12:48	2019-06-27	14	[{"id_menu":2,"count":1}]	1342	delivery	5	19
4033	2019-06-27 10:25:57	2019-06-27	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	906	pick-up	0	29
4034	2019-06-27 12:32:08	2019-06-27	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1313	pick-up	0	31
4035	2019-06-27 12:55:31	2019-06-27	14	[{"id_menu":2,"count":1}]	835	pick-up	0	14
4036	2019-06-27 13:03:17	2019-06-27	12	[{"id_menu":1,"count":1}]	1289	pick-up	0	12
4037	2019-06-27 13:07:32	2019-06-27	8	[{"id_menu":5,"count":1}]	640	pick-up	0	8
4038	2019-06-27 13:14:15	2019-06-27	14	[{"id_menu":2,"count":1}]	579	delivery	5	19
4039	2019-06-27 13:59:34	2019-06-27	17	[{"id_menu":4,"count":1}]	1688	delivery	5	22
4040	2019-06-27 15:28:55	2019-06-27	12	[{"id_menu":1,"count":1}]	519	delivery	5	17
4041	2019-06-27 15:45:39	2019-06-27	12	[{"id_menu":3,"count":1}]	1113	delivery	5	17
4042	2019-06-27 16:10:29	2019-06-27	17	[{"id_menu":4,"count":1}]	1092	pick-up	0	17
4043	2019-06-27 17:30:16	2019-06-27	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	1681	pick-up	0	21
4044	2019-06-27 17:33:35	2019-06-27	9	[{"id_menu":7,"count":1}]	352	pick-up	0	9
4045	2019-06-27 17:54:11	2019-06-27	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1684	pick-up	0	21
4046	2019-06-27 18:34:04	2019-06-27	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17	pick-up	0	17
4047	2019-06-27 18:53:44	2019-06-27	12	[{"id_menu":3,"count":1}]	1679	pick-up	0	12
4048	2019-06-27 19:30:38	2019-06-27	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	786	pick-up	0	43
4049	2019-06-27 21:32:48	2019-06-27	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	656	delivery	5	36
4050	2019-06-27 22:15:06	2019-06-27	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	1085	pick-up	0	26
4051	2019-06-27 23:16:31	2019-06-27	17	[{"id_menu":4,"count":2}]	192	pick-up	0	17
4052	2019-06-28 00:15:57	2019-06-28	14	[{"id_menu":2,"count":1}]	1004	delivery	5	19
4053	2019-06-28 00:44:12	2019-06-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	679	delivery	5	28
4054	2019-06-28 01:10:45	2019-06-28	12	[{"id_menu":3,"count":1}]	1367	pick-up	0	12
4055	2019-06-28 01:43:33	2019-06-28	9	[{"id_menu":6,"count":1}]	713	delivery	5	14
4056	2019-06-28 02:22:56	2019-06-28	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1657	delivery	5	34
4057	2019-06-28 02:43:01	2019-06-28	12	[{"id_menu":3,"count":1}]	1702	pick-up	0	12
4058	2019-06-28 03:58:26	2019-06-28	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	11	delivery	5	40
4059	2019-06-28 04:47:55	2019-06-28	8	[{"id_menu":5,"count":1}]	1699	pick-up	0	8
4060	2019-06-28 05:53:47	2019-06-28	17	[{"id_menu":4,"count":1}]	1690	delivery	5	22
4061	2019-06-28 06:11:29	2019-06-28	14	[{"id_menu":2,"count":1}]	1698	pick-up	0	14
4062	2019-06-28 06:12:53	2019-06-28	12	[{"id_menu":3,"count":1}]	437	delivery	5	17
4063	2019-06-28 06:41:22	2019-06-28	9	[{"id_menu":6,"count":1}]	768	pick-up	0	9
4064	2019-06-28 06:47:33	2019-06-28	12	[{"id_menu":1,"count":1}]	1270	pick-up	0	12
4065	2019-06-28 08:02:51	2019-06-28	17	[{"id_menu":4,"count":1}]	1053	delivery	5	22
4066	2019-06-28 08:32:36	2019-06-28	9	[{"id_menu":6,"count":3}]	656	delivery	5	14
4067	2019-06-28 09:45:34	2019-06-28	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	843	pick-up	0	29
4068	2019-06-28 10:38:58	2019-06-28	14	[{"id_menu":2,"count":1}]	1296	pick-up	0	14
4069	2019-06-28 11:27:04	2019-06-28	9	[{"id_menu":7,"count":1}]	1703	delivery	5	14
4070	2019-06-28 12:24:56	2019-06-28	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1310	delivery	5	26
4071	2019-06-28 13:08:42	2019-06-28	9	[{"id_menu":6,"count":1}]	377	pick-up	0	9
4072	2019-06-28 13:46:11	2019-06-28	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	1638	delivery	5	31
4073	2019-06-28 14:42:12	2019-06-28	14	[{"id_menu":2,"count":1}]	188	delivery	5	19
4074	2019-06-28 15:05:18	2019-06-28	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1691	pick-up	0	22
4075	2019-06-28 15:25:14	2019-06-28	9	[{"id_menu":7,"count":1}]	1701	pick-up	0	9
4076	2019-06-28 15:39:02	2019-06-28	9	[{"id_menu":7,"count":1}]	1696	pick-up	0	9
4077	2019-06-28 15:48:35	2019-06-28	17	[{"id_menu":4,"count":1}]	1693	pick-up	0	17
4078	2019-06-28 16:41:24	2019-06-28	12	[{"id_menu":1,"count":1}]	1279	pick-up	0	12
4079	2019-06-28 18:30:15	2019-06-28	8	[{"id_menu":5,"count":1}]	233	delivery	5	13
4080	2019-06-28 19:02:57	2019-06-28	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	194	delivery	5	26
4081	2019-06-28 19:20:48	2019-06-28	17	[{"id_menu":4,"count":1}]	1222	pick-up	0	17
4082	2019-06-28 20:11:10	2019-06-28	12	[{"id_menu":1,"count":1}]	1489	pick-up	0	12
4083	2019-06-28 20:25:14	2019-06-28	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	152	pick-up	0	26
4084	2019-06-28 20:37:29	2019-06-28	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	130	delivery	5	34
4085	2019-06-28 22:31:53	2019-06-28	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	968	delivery	5	39
4086	2019-06-28 22:43:55	2019-06-28	8	[{"id_menu":5,"count":1}]	1685	pick-up	0	8
4087	2019-06-28 22:51:25	2019-06-28	17	[{"id_menu":4,"count":1}]	382	pick-up	0	17
4088	2019-06-28 23:04:49	2019-06-28	9	[{"id_menu":6,"count":2}]	1697	delivery	5	14
4089	2019-06-28 23:38:14	2019-06-28	8	[{"id_menu":5,"count":1}]	1676	pick-up	0	8
4090	2019-06-29 00:15:48	2019-06-29	17	[{"id_menu":4,"count":1}]	10	pick-up	0	17
4091	2019-06-29 00:43:29	2019-06-29	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1088	pick-up	0	52
4092	2019-06-29 00:59:33	2019-06-29	9	[{"id_menu":7,"count":1}]	1280	delivery	5	14
4093	2019-06-29 01:14:12	2019-06-29	9	[{"id_menu":6,"count":1}]	1718	pick-up	0	9
4094	2019-06-29 01:23:55	2019-06-29	12	[{"id_menu":1,"count":2}]	1677	delivery	5	17
4095	2019-06-29 01:48:18	2019-06-29	14	[{"id_menu":2,"count":1}]	1379	pick-up	0	14
4096	2019-06-29 02:07:26	2019-06-29	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	786	delivery	5	31
4097	2019-06-29 02:12:52	2019-06-29	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1390	pick-up	0	35
4098	2019-06-29 02:30:02	2019-06-29	12	[{"id_menu":3,"count":1}]	1044	delivery	5	17
4099	2019-06-29 02:35:34	2019-06-29	12	[{"id_menu":1,"count":1}]	559	delivery	5	17
4100	2019-06-29 02:47:57	2019-06-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1705	pick-up	0	22
4101	2019-06-29 04:55:28	2019-06-29	9	[{"id_menu":6,"count":1}]	599	delivery	5	14
4102	2019-06-29 05:00:43	2019-06-29	9	[{"id_menu":7,"count":1}]	1707	pick-up	0	9
4103	2019-06-29 05:01:33	2019-06-29	9	[{"id_menu":7,"count":1}]	1716	pick-up	0	9
4104	2019-06-29 05:34:48	2019-06-29	12	[{"id_menu":1,"count":1}]	1711	delivery	5	17
4105	2019-06-29 05:40:38	2019-06-29	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1574	pick-up	0	25
4106	2019-06-29 06:10:56	2019-06-29	8	[{"id_menu":5,"count":1}]	996	pick-up	0	8
4107	2019-06-29 06:25:28	2019-06-29	17	[{"id_menu":4,"count":1}]	113	pick-up	0	17
4108	2019-06-29 08:01:27	2019-06-29	12	[{"id_menu":3,"count":1}]	286	pick-up	0	12
4109	2019-06-29 08:03:09	2019-06-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1462	pick-up	0	22
4110	2019-06-29 08:38:49	2019-06-29	17	[{"id_menu":4,"count":1}]	295	pick-up	0	17
4111	2019-06-29 09:12:02	2019-06-29	12	[{"id_menu":3,"count":1}]	1165	pick-up	0	12
4112	2019-06-29 09:54:17	2019-06-29	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1708	pick-up	0	29
4113	2019-06-29 09:57:43	2019-06-29	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1239	pick-up	0	39
4114	2019-06-29 11:16:59	2019-06-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	396	pick-up	0	21
4115	2019-06-29 12:04:30	2019-06-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1149	pick-up	0	26
4116	2019-06-29 14:05:55	2019-06-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1714	delivery	5	28
4117	2019-06-29 14:41:16	2019-06-29	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	1710	delivery	5	23
4118	2019-06-29 14:58:52	2019-06-29	12	[{"id_menu":3,"count":1}]	747	pick-up	0	12
4119	2019-06-29 15:42:47	2019-06-29	14	[{"id_menu":2,"count":1}]	1715	pick-up	0	14
4120	2019-06-29 15:46:30	2019-06-29	17	[{"id_menu":4,"count":1}]	721	pick-up	0	17
4121	2019-06-29 15:58:59	2019-06-29	8	[{"id_menu":5,"count":1}]	1289	delivery	5	13
4122	2019-06-29 16:05:27	2019-06-29	12	[{"id_menu":3,"count":1}]	1712	delivery	5	17
4123	2019-06-29 16:08:57	2019-06-29	12	[{"id_menu":1,"count":1}]	406	pick-up	0	12
4124	2019-06-29 17:13:55	2019-06-29	8	[{"id_menu":5,"count":1}]	1342	pick-up	0	8
4125	2019-06-29 19:00:45	2019-06-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	169	delivery	5	27
4126	2019-06-29 19:08:33	2019-06-29	12	[{"id_menu":3,"count":1}]	313	delivery	5	17
4127	2019-06-29 20:03:45	2019-06-29	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1704	delivery	5	37
4128	2019-06-29 20:05:36	2019-06-29	9	[{"id_menu":6,"count":1}]	1713	pick-up	0	9
4129	2019-06-29 20:51:44	2019-06-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1709	delivery	5	23
4130	2019-06-29 23:29:53	2019-06-29	14	[{"id_menu":2,"count":1}]	970	delivery	5	19
4131	2019-06-30 00:14:22	2019-06-30	17	[{"id_menu":4,"count":1}]	1263	pick-up	0	17
4132	2019-06-30 00:16:20	2019-06-30	12	[{"id_menu":1,"count":1}]	1305	pick-up	0	12
4133	2019-06-30 00:19:15	2019-06-30	12	[{"id_menu":1,"count":1}]	62	pick-up	0	12
4134	2019-06-30 01:42:30	2019-06-30	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1732	delivery	5	31
4135	2019-06-30 02:01:06	2019-06-30	9	[{"id_menu":6,"count":1}]	909	pick-up	0	9
4136	2019-06-30 02:03:53	2019-06-30	12	[{"id_menu":3,"count":1}]	158	pick-up	0	12
4137	2019-06-30 03:06:30	2019-06-30	9	[{"id_menu":7,"count":1}]	449	delivery	5	14
4138	2019-06-30 03:09:59	2019-06-30	8	[{"id_menu":5,"count":1}]	1053	pick-up	0	8
4139	2019-06-30 03:31:48	2019-06-30	9	[{"id_menu":6,"count":1}]	772	delivery	5	14
4140	2019-06-30 03:50:32	2019-06-30	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1731	pick-up	0	29
4141	2019-06-30 03:51:39	2019-06-30	12	[{"id_menu":1,"count":1}]	708	pick-up	0	12
4142	2019-06-30 04:11:25	2019-06-30	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	260	pick-up	0	21
4143	2019-06-30 04:11:45	2019-06-30	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1728	delivery	5	39
4144	2019-06-30 04:18:28	2019-06-30	9	[{"id_menu":6,"count":1}]	439	pick-up	0	9
4145	2019-06-30 04:33:27	2019-06-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	655	delivery	5	26
4146	2019-06-30 04:39:49	2019-06-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	972	delivery	5	28
4147	2019-06-30 05:34:09	2019-06-30	9	[{"id_menu":7,"count":1}]	314	pick-up	0	9
4148	2019-06-30 05:44:58	2019-06-30	9	[{"id_menu":6,"count":1}]	1206	delivery	5	14
4149	2019-06-30 06:08:02	2019-06-30	9	[{"id_menu":7,"count":1}]	481	delivery	5	14
4150	2019-06-30 06:12:51	2019-06-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	832	pick-up	0	22
4151	2019-06-30 06:18:02	2019-06-30	14	[{"id_menu":2,"count":1}]	551	delivery	5	19
4152	2019-06-30 06:42:30	2019-06-30	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	1725	delivery	5	26
4153	2019-06-30 06:43:03	2019-06-30	12	[{"id_menu":1,"count":1}]	1464	pick-up	0	12
4154	2019-06-30 06:56:55	2019-06-30	14	[{"id_menu":2,"count":1}]	179	pick-up	0	14
4155	2019-06-30 06:59:28	2019-06-30	17	[{"id_menu":4,"count":1}]	761	pick-up	0	17
4156	2019-06-30 07:00:28	2019-06-30	9	[{"id_menu":6,"count":1}]	1722	pick-up	0	9
4157	2019-06-30 07:01:22	2019-06-30	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	76	pick-up	0	43
4158	2019-06-30 07:09:26	2019-06-30	12	[{"id_menu":3,"count":1}]	176	pick-up	0	12
4159	2019-06-30 08:57:39	2019-06-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	1592	pick-up	0	18
4160	2019-06-30 09:46:04	2019-06-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	764	delivery	5	27
4161	2019-06-30 09:51:58	2019-06-30	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	437	delivery	5	25
4162	2019-06-30 10:24:45	2019-06-30	14	[{"id_menu":2,"count":1}]	868	pick-up	0	14
4163	2019-06-30 10:27:48	2019-06-30	17	[{"id_menu":4,"count":1}]	1724	delivery	5	22
4164	2019-06-30 10:27:54	2019-06-30	14	[{"id_menu":2,"count":1}]	1720	pick-up	0	14
4165	2019-06-30 10:42:42	2019-06-30	12	[{"id_menu":3,"count":2}]	1011	delivery	5	17
4166	2019-06-30 10:47:11	2019-06-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1046	delivery	5	28
4167	2019-06-30 11:44:13	2019-06-30	12	[{"id_menu":1,"count":1}]	1730	pick-up	0	12
4168	2019-06-30 11:57:56	2019-06-30	9	[{"id_menu":6,"count":1}]	719	pick-up	0	9
4169	2019-06-30 12:10:21	2019-06-30	14	[{"id_menu":2,"count":1}]	1306	pick-up	0	14
4170	2019-06-30 12:28:12	2019-06-30	17	[{"id_menu":4,"count":1}]	37	delivery	5	22
4171	2019-06-30 12:32:30	2019-06-30	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	569	pick-up	0	34
4172	2019-06-30 12:45:00	2019-06-30	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1195	delivery	5	43
4173	2019-06-30 12:50:15	2019-06-30	12	[{"id_menu":3,"count":1}]	1729	pick-up	0	12
4174	2019-06-30 12:59:25	2019-06-30	17	[{"id_menu":4,"count":1}]	1083	pick-up	0	17
4175	2019-06-30 13:23:12	2019-06-30	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1564	pick-up	0	21
4176	2019-06-30 13:41:59	2019-06-30	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1562	pick-up	0	20
4177	2019-06-30 15:18:44	2019-06-30	14	[{"id_menu":2,"count":3}]	531	pick-up	0	14
4178	2019-06-30 15:46:38	2019-06-30	9	[{"id_menu":6,"count":1}]	1144	pick-up	0	9
4179	2019-06-30 16:16:02	2019-06-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	786	pick-up	0	23
4180	2019-06-30 16:26:50	2019-06-30	17	[{"id_menu":4,"count":1}]	224	delivery	5	22
4181	2019-06-30 16:31:15	2019-06-30	9	[{"id_menu":6,"count":1}]	16	pick-up	0	9
4182	2019-06-30 16:36:06	2019-06-30	9	[{"id_menu":6,"count":1}]	1727	pick-up	0	9
4183	2019-06-30 18:39:17	2019-06-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	491	pick-up	0	21
4184	2019-06-30 19:00:36	2019-06-30	12	[{"id_menu":3,"count":1}]	788	delivery	5	17
4185	2019-06-30 19:15:24	2019-06-30	14	[{"id_menu":2,"count":1}]	931	pick-up	0	14
4186	2019-06-30 19:17:45	2019-06-30	17	[{"id_menu":4,"count":1}]	1726	pick-up	0	17
4187	2019-06-30 20:09:40	2019-06-30	12	[{"id_menu":1,"count":1}]	1687	pick-up	0	12
4188	2019-06-30 20:10:28	2019-06-30	9	[{"id_menu":7,"count":1}]	340	pick-up	0	9
4189	2019-06-30 20:48:11	2019-06-30	12	[{"id_menu":3,"count":1}]	1499	pick-up	0	12
4190	2019-06-30 20:55:03	2019-06-30	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	1721	delivery	5	31
4191	2019-06-30 21:08:59	2019-06-30	9	[{"id_menu":6,"count":1}]	1438	pick-up	0	9
4192	2019-06-30 21:15:06	2019-06-30	9	[{"id_menu":7,"count":1}]	1713	delivery	5	14
4193	2019-06-30 21:40:12	2019-06-30	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1719	pick-up	0	25
4194	2019-06-30 21:47:31	2019-06-30	14	[{"id_menu":2,"count":1}]	729	pick-up	0	14
4195	2019-06-30 22:24:46	2019-06-30	8	[{"id_menu":5,"count":1}]	1723	pick-up	0	8
4196	2019-06-30 23:14:43	2019-06-30	8	[{"id_menu":5,"count":1}]	363	pick-up	0	8
4197	2019-06-30 23:20:37	2019-06-30	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	465	delivery	5	29
4198	2019-07-01 01:19:37	2019-07-01	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	932	delivery	5	46
4199	2019-07-01 01:20:55	2019-07-01	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	1734	delivery	5	42
4200	2019-07-01 01:45:23	2019-07-01	14	[{"id_menu":2,"count":1}]	1540	pick-up	0	14
4201	2019-07-01 01:49:02	2019-07-01	8	[{"id_menu":5,"count":2}]	784	pick-up	0	8
4202	2019-07-01 02:44:21	2019-07-01	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1211	pick-up	0	26
4203	2019-07-01 02:58:07	2019-07-01	14	[{"id_menu":2,"count":1}]	1526	pick-up	0	14
4204	2019-07-01 03:16:34	2019-07-01	12	[{"id_menu":1,"count":1}]	1143	pick-up	0	12
4205	2019-07-01 04:09:05	2019-07-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1739	pick-up	0	26
4206	2019-07-01 04:33:38	2019-07-01	17	[{"id_menu":4,"count":1}]	464	pick-up	0	17
4207	2019-07-01 05:50:13	2019-07-01	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	669	delivery	5	31
4208	2019-07-01 10:03:09	2019-07-01	8	[{"id_menu":5,"count":1}]	486	pick-up	0	8
4209	2019-07-01 11:44:45	2019-07-01	12	[{"id_menu":1,"count":1}]	1481	delivery	5	17
4210	2019-07-01 13:33:11	2019-07-01	14	[{"id_menu":2,"count":1}]	1741	delivery	5	19
4211	2019-07-01 13:35:35	2019-07-01	14	[{"id_menu":2,"count":1}]	351	delivery	5	19
4212	2019-07-01 14:29:05	2019-07-01	12	[{"id_menu":3,"count":1}]	1740	delivery	5	17
4213	2019-07-01 15:04:59	2019-07-01	9	[{"id_menu":6,"count":1}]	286	pick-up	0	9
4214	2019-07-01 18:11:23	2019-07-01	12	[{"id_menu":3,"count":1}]	1305	pick-up	0	12
4215	2019-07-01 19:32:07	2019-07-01	17	[{"id_menu":4,"count":1}]	1735	pick-up	0	17
4216	2019-07-01 21:20:04	2019-07-01	14	[{"id_menu":2,"count":1}]	1664	pick-up	0	14
4217	2019-07-02 00:01:43	2019-07-02	9	[{"id_menu":7,"count":1}]	1400	delivery	5	14
4218	2019-07-02 00:06:17	2019-07-02	12	[{"id_menu":1,"count":1}]	293	pick-up	0	12
4219	2019-07-02 00:07:07	2019-07-02	9	[{"id_menu":6,"count":1}]	1379	pick-up	0	9
4220	2019-07-02 00:36:51	2019-07-02	14	[{"id_menu":2,"count":3}]	601	delivery	5	19
4221	2019-07-02 01:25:08	2019-07-02	14	[{"id_menu":2,"count":1}]	1754	delivery	5	19
4222	2019-07-02 01:59:13	2019-07-02	8	[{"id_menu":5,"count":1}]	568	delivery	5	13
4223	2019-07-02 03:26:29	2019-07-02	12	[{"id_menu":3,"count":1}]	640	pick-up	0	12
4224	2019-07-02 06:12:53	2019-07-02	14	[{"id_menu":2,"count":1}]	1745	pick-up	0	14
4225	2019-07-02 06:29:05	2019-07-02	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	1011	delivery	5	35
4226	2019-07-02 06:32:37	2019-07-02	9	[{"id_menu":7,"count":1}]	287	delivery	5	14
4227	2019-07-02 07:02:16	2019-07-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1751	pick-up	0	18
4228	2019-07-02 07:06:29	2019-07-02	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1390	pick-up	0	29
4229	2019-07-02 08:41:19	2019-07-02	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1747	pick-up	0	26
4230	2019-07-02 10:20:07	2019-07-02	8	[{"id_menu":5,"count":1}]	1088	pick-up	0	8
4231	2019-07-02 11:00:24	2019-07-02	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	1701	pick-up	0	31
4232	2019-07-02 11:00:36	2019-07-02	12	[{"id_menu":3,"count":1}]	315	pick-up	0	12
4233	2019-07-02 11:22:56	2019-07-02	8	[{"id_menu":5,"count":1}]	1749	delivery	5	13
4234	2019-07-02 12:26:30	2019-07-02	14	[{"id_menu":2,"count":1}]	609	pick-up	0	14
4235	2019-07-02 12:54:16	2019-07-02	12	[{"id_menu":1,"count":1}]	1750	pick-up	0	12
4236	2019-07-02 15:19:49	2019-07-02	17	[{"id_menu":4,"count":1}]	999	delivery	5	22
4237	2019-07-02 15:37:20	2019-07-02	12	[{"id_menu":3,"count":1}]	227	delivery	5	17
4238	2019-07-02 16:21:02	2019-07-02	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1744	delivery	5	25
4239	2019-07-02 16:48:48	2019-07-02	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1427	delivery	5	34
4240	2019-07-02 18:05:52	2019-07-02	9	[{"id_menu":6,"count":1}]	856	pick-up	0	9
4241	2019-07-02 19:56:12	2019-07-02	12	[{"id_menu":1,"count":1}]	817	pick-up	0	12
4242	2019-07-02 20:25:15	2019-07-02	17	[{"id_menu":4,"count":1}]	822	pick-up	0	17
4243	2019-07-02 20:40:09	2019-07-02	9	[{"id_menu":7,"count":1}]	1755	delivery	5	14
4244	2019-07-02 20:58:23	2019-07-02	9	[{"id_menu":6,"count":1}]	1752	delivery	5	14
4245	2019-07-02 21:08:08	2019-07-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	300	delivery	5	31
4246	2019-07-02 21:08:34	2019-07-02	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1458	delivery	5	30
4247	2019-07-02 21:22:44	2019-07-02	17	[{"id_menu":4,"count":2}]	203	pick-up	0	17
4248	2019-07-02 22:42:44	2019-07-02	12	[{"id_menu":3,"count":2}]	1753	pick-up	0	12
4249	2019-07-02 23:38:46	2019-07-02	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	313	pick-up	0	43
4250	2019-07-02 23:46:31	2019-07-02	17	[{"id_menu":4,"count":1}]	352	delivery	5	22
4251	2019-07-03 00:04:46	2019-07-03	12	[{"id_menu":1,"count":1}]	276	pick-up	0	12
4252	2019-07-03 02:00:51	2019-07-03	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	1760	pick-up	0	23
4253	2019-07-03 03:04:59	2019-07-03	14	[{"id_menu":2,"count":2}]	1370	pick-up	0	14
4254	2019-07-03 04:04:35	2019-07-03	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	318	delivery	5	39
4255	2019-07-03 04:45:42	2019-07-03	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	1310	delivery	5	42
4256	2019-07-03 04:51:59	2019-07-03	9	[{"id_menu":7,"count":1}]	1523	pick-up	0	9
4257	2019-07-03 05:00:49	2019-07-03	9	[{"id_menu":7,"count":1}]	559	delivery	5	14
4258	2019-07-03 05:18:39	2019-07-03	14	[{"id_menu":2,"count":1}]	92	delivery	5	19
4259	2019-07-03 05:42:10	2019-07-03	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1757	pick-up	0	21
4260	2019-07-03 05:48:09	2019-07-03	9	[{"id_menu":6,"count":1}]	1761	pick-up	0	9
4261	2019-07-03 08:34:41	2019-07-03	14	[{"id_menu":2,"count":1}]	519	pick-up	0	14
4262	2019-07-03 11:07:24	2019-07-03	12	[{"id_menu":3,"count":1}]	1017	pick-up	0	12
4263	2019-07-03 11:51:03	2019-07-03	9	[{"id_menu":7,"count":1}]	1092	pick-up	0	9
4264	2019-07-03 12:29:57	2019-07-03	12	[{"id_menu":1,"count":1}]	765	delivery	5	17
4265	2019-07-03 12:46:08	2019-07-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	634	delivery	5	31
4266	2019-07-03 13:27:12	2019-07-03	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	37	pick-up	0	30
4267	2019-07-03 13:29:07	2019-07-03	14	[{"id_menu":2,"count":1}]	1168	delivery	5	19
4268	2019-07-03 13:33:33	2019-07-03	12	[{"id_menu":1,"count":1}]	378	pick-up	0	12
4269	2019-07-03 14:06:04	2019-07-03	14	[{"id_menu":2,"count":1}]	575	pick-up	0	14
4270	2019-07-03 15:25:51	2019-07-03	8	[{"id_menu":5,"count":1}]	708	pick-up	0	8
4271	2019-07-03 15:40:49	2019-07-03	14	[{"id_menu":2,"count":1}]	1765	pick-up	0	14
4272	2019-07-03 15:52:51	2019-07-03	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	1762	delivery	5	23
4273	2019-07-03 16:15:27	2019-07-03	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	840	pick-up	0	25
4274	2019-07-03 17:51:14	2019-07-03	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1037	pick-up	0	23
4275	2019-07-03 18:44:56	2019-07-03	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1766	delivery	5	37
4276	2019-07-03 18:57:11	2019-07-03	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1759	pick-up	0	35
4277	2019-07-03 19:13:50	2019-07-03	9	[{"id_menu":7,"count":1}]	546	delivery	5	14
4278	2019-07-03 19:35:25	2019-07-03	9	[{"id_menu":7,"count":1}]	1529	pick-up	0	9
4279	2019-07-03 20:12:39	2019-07-03	9	[{"id_menu":6,"count":1}]	932	pick-up	0	9
4280	2019-07-03 20:52:17	2019-07-03	9	[{"id_menu":6,"count":1}]	1764	pick-up	0	9
4281	2019-07-03 21:01:50	2019-07-03	17	[{"id_menu":4,"count":1}]	44	delivery	5	22
4282	2019-07-03 21:08:55	2019-07-03	8	[{"id_menu":5,"count":1}]	1140	delivery	5	13
4283	2019-07-03 21:30:46	2019-07-03	12	[{"id_menu":3,"count":1}]	536	pick-up	0	12
4284	2019-07-03 22:19:31	2019-07-03	17	[{"id_menu":4,"count":1}]	1353	delivery	5	22
4285	2019-07-03 22:46:29	2019-07-03	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	256	pick-up	0	38
4286	2019-07-03 23:02:06	2019-07-03	9	[{"id_menu":7,"count":1}]	532	pick-up	0	9
4287	2019-07-03 23:02:09	2019-07-03	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	669	pick-up	0	31
4288	2019-07-03 23:04:31	2019-07-03	9	[{"id_menu":7,"count":1}]	1317	pick-up	0	9
4289	2019-07-03 23:32:25	2019-07-03	8	[{"id_menu":5,"count":1}]	1758	delivery	5	13
4290	2019-07-03 23:52:23	2019-07-03	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1756	pick-up	0	29
4291	2019-07-04 00:04:53	2019-07-04	8	[{"id_menu":5,"count":1}]	1774	pick-up	0	8
4292	2019-07-04 00:13:59	2019-07-04	17	[{"id_menu":4,"count":1}]	1119	pick-up	0	17
4293	2019-07-04 00:31:54	2019-07-04	9	[{"id_menu":6,"count":2}]	565	pick-up	0	9
4294	2019-07-04 01:21:15	2019-07-04	9	[{"id_menu":7,"count":1}]	1776	delivery	5	14
4295	2019-07-04 03:01:51	2019-07-04	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1768	delivery	5	23
4296	2019-07-04 03:22:49	2019-07-04	9	[{"id_menu":6,"count":1}]	1771	pick-up	0	9
4297	2019-07-04 03:47:48	2019-07-04	14	[{"id_menu":2,"count":1}]	654	delivery	5	19
4298	2019-07-04 05:35:09	2019-07-04	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	399	pick-up	0	29
4299	2019-07-04 06:38:52	2019-07-04	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1330	delivery	5	48
4300	2019-07-04 07:10:04	2019-07-04	8	[{"id_menu":5,"count":1}]	657	pick-up	0	8
4301	2019-07-04 07:52:01	2019-07-04	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1770	pick-up	0	26
4302	2019-07-04 08:09:46	2019-07-04	9	[{"id_menu":6,"count":1}]	593	pick-up	0	9
4303	2019-07-04 09:49:51	2019-07-04	17	[{"id_menu":4,"count":1}]	1373	delivery	5	22
4304	2019-07-04 10:30:18	2019-07-04	12	[{"id_menu":3,"count":1}]	639	pick-up	0	12
4305	2019-07-04 11:49:08	2019-07-04	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	338	delivery	5	31
4306	2019-07-04 12:20:15	2019-07-04	12	[{"id_menu":3,"count":1}]	778	delivery	5	17
4307	2019-07-04 13:55:15	2019-07-04	12	[{"id_menu":1,"count":1}]	925	pick-up	0	12
4308	2019-07-04 14:26:09	2019-07-04	14	[{"id_menu":2,"count":1}]	993	pick-up	0	14
4309	2019-07-04 14:35:39	2019-07-04	17	[{"id_menu":4,"count":2}]	1778	pick-up	0	17
4310	2019-07-04 14:42:17	2019-07-04	8	[{"id_menu":5,"count":2}]	1338	pick-up	0	8
4311	2019-07-04 15:25:04	2019-07-04	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	853	pick-up	0	21
4312	2019-07-04 17:41:40	2019-07-04	9	[{"id_menu":6,"count":1}]	1772	pick-up	0	9
4313	2019-07-04 17:46:10	2019-07-04	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	63	pick-up	0	22
4314	2019-07-04 17:56:05	2019-07-04	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1773	pick-up	0	31
4315	2019-07-04 18:16:10	2019-07-04	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	78	delivery	5	28
4316	2019-07-04 18:22:22	2019-07-04	8	[{"id_menu":5,"count":1}]	1559	pick-up	0	8
4317	2019-07-04 18:32:18	2019-07-04	17	[{"id_menu":4,"count":1}]	66	delivery	5	22
4318	2019-07-04 18:59:44	2019-07-04	9	[{"id_menu":7,"count":1}]	197	pick-up	0	9
4319	2019-07-04 19:00:16	2019-07-04	8	[{"id_menu":5,"count":1}]	1775	pick-up	0	8
4320	2019-07-04 21:20:46	2019-07-04	12	[{"id_menu":1,"count":1}]	1767	pick-up	0	12
4321	2019-07-04 22:00:49	2019-07-04	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1239	delivery	5	40
4322	2019-07-04 22:21:47	2019-07-04	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1746	delivery	5	25
4323	2019-07-05 00:17:09	2019-07-05	8	[{"id_menu":5,"count":1}]	312	pick-up	0	8
4324	2019-07-05 00:19:02	2019-07-05	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	310	delivery	5	43
4325	2019-07-05 01:04:31	2019-07-05	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1784	delivery	5	25
4326	2019-07-05 03:03:58	2019-07-05	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1783	pick-up	0	51
4327	2019-07-05 03:46:36	2019-07-05	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":3}]	1781	pick-up	0	26
4328	2019-07-05 04:42:58	2019-07-05	17	[{"id_menu":4,"count":1}]	1223	pick-up	0	17
4329	2019-07-05 05:08:10	2019-07-05	9	[{"id_menu":7,"count":1}]	1163	delivery	5	14
4330	2019-07-05 05:10:01	2019-07-05	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1266	pick-up	0	21
4331	2019-07-05 05:23:12	2019-07-05	9	[{"id_menu":6,"count":1}]	1787	pick-up	0	9
4332	2019-07-05 05:30:31	2019-07-05	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1092	pick-up	0	43
4333	2019-07-05 07:27:58	2019-07-05	8	[{"id_menu":5,"count":1}]	768	pick-up	0	8
4334	2019-07-05 07:28:47	2019-07-05	9	[{"id_menu":7,"count":1}]	1780	pick-up	0	9
4335	2019-07-05 07:58:29	2019-07-05	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	820	delivery	5	40
4336	2019-07-05 08:19:26	2019-07-05	8	[{"id_menu":5,"count":1}]	743	pick-up	0	8
4337	2019-07-05 08:36:24	2019-07-05	9	[{"id_menu":6,"count":1}]	1450	delivery	5	14
4338	2019-07-05 09:19:48	2019-07-05	17	[{"id_menu":4,"count":2}]	1792	delivery	5	22
4339	2019-07-05 09:51:21	2019-07-05	14	[{"id_menu":2,"count":1}]	1170	delivery	5	19
4340	2019-07-05 11:19:49	2019-07-05	9	[{"id_menu":6,"count":1}]	786	pick-up	0	9
4341	2019-07-05 13:38:38	2019-07-05	12	[{"id_menu":1,"count":1}]	623	delivery	5	17
4342	2019-07-05 13:50:50	2019-07-05	17	[{"id_menu":4,"count":1}]	1785	pick-up	0	17
4343	2019-07-05 14:48:52	2019-07-05	17	[{"id_menu":4,"count":1}]	356	pick-up	0	17
4344	2019-07-05 14:55:27	2019-07-05	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1788	delivery	5	31
4345	2019-07-05 15:06:14	2019-07-05	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1448	delivery	5	29
4346	2019-07-05 15:29:33	2019-07-05	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	1779	pick-up	0	22
4347	2019-07-05 16:39:01	2019-07-05	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	841	pick-up	0	17
4348	2019-07-05 16:52:10	2019-07-05	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	403	pick-up	0	29
4349	2019-07-05 18:29:51	2019-07-05	8	[{"id_menu":5,"count":1}]	1791	delivery	5	13
4350	2019-07-05 18:32:20	2019-07-05	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1786	pick-up	0	17
4351	2019-07-05 20:15:53	2019-07-05	9	[{"id_menu":6,"count":1}]	1282	delivery	5	14
4352	2019-07-05 21:12:12	2019-07-05	12	[{"id_menu":1,"count":1}]	808	delivery	5	17
4353	2019-07-05 21:29:34	2019-07-05	9	[{"id_menu":6,"count":1}]	1793	delivery	5	14
4354	2019-07-05 21:43:19	2019-07-05	14	[{"id_menu":2,"count":1}]	204	pick-up	0	14
4355	2019-07-05 22:00:52	2019-07-05	12	[{"id_menu":3,"count":1}]	955	delivery	5	17
4356	2019-07-05 22:49:52	2019-07-05	9	[{"id_menu":6,"count":1}]	701	pick-up	0	9
4357	2019-07-05 22:58:58	2019-07-05	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	1789	pick-up	0	23
4358	2019-07-05 23:10:32	2019-07-05	12	[{"id_menu":1,"count":1}]	1790	pick-up	0	12
4359	2019-07-05 23:18:51	2019-07-05	9	[{"id_menu":6,"count":1}]	511	pick-up	0	9
4360	2019-07-05 23:47:43	2019-07-05	8	[{"id_menu":5,"count":1}]	1273	delivery	5	13
4361	2019-07-06 00:23:39	2019-07-06	9	[{"id_menu":7,"count":1}]	1795	delivery	5	14
4362	2019-07-06 00:32:05	2019-07-06	9	[{"id_menu":6,"count":1}]	439	delivery	5	14
4363	2019-07-06 01:10:21	2019-07-06	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":3}]	1598	delivery	5	31
4364	2019-07-06 02:07:35	2019-07-06	9	[{"id_menu":6,"count":1}]	853	pick-up	0	9
4365	2019-07-06 02:34:41	2019-07-06	8	[{"id_menu":5,"count":1}]	1794	pick-up	0	8
4366	2019-07-06 03:11:10	2019-07-06	14	[{"id_menu":2,"count":1}]	833	pick-up	0	14
4367	2019-07-06 04:21:47	2019-07-06	46	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1808	delivery	5	51
4368	2019-07-06 04:54:28	2019-07-06	12	[{"id_menu":1,"count":1}]	1257	pick-up	0	12
4369	2019-07-06 05:26:28	2019-07-06	8	[{"id_menu":5,"count":1}]	567	delivery	5	13
4370	2019-07-06 05:33:10	2019-07-06	14	[{"id_menu":2,"count":1}]	1079	delivery	5	19
4371	2019-07-06 05:34:27	2019-07-06	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	986	delivery	5	36
4372	2019-07-06 05:49:22	2019-07-06	9	[{"id_menu":6,"count":1}]	1806	pick-up	0	9
4373	2019-07-06 05:57:54	2019-07-06	12	[{"id_menu":1,"count":1}]	1804	pick-up	0	12
4374	2019-07-06 06:42:35	2019-07-06	14	[{"id_menu":2,"count":1}]	1798	pick-up	0	14
4375	2019-07-06 07:22:36	2019-07-06	8	[{"id_menu":5,"count":1}]	1417	pick-up	0	8
4376	2019-07-06 07:51:51	2019-07-06	8	[{"id_menu":5,"count":1}]	1302	pick-up	0	8
4377	2019-07-06 08:02:27	2019-07-06	12	[{"id_menu":1,"count":1}]	1797	pick-up	0	12
4378	2019-07-06 09:25:22	2019-07-06	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1353	pick-up	0	29
4379	2019-07-06 09:32:52	2019-07-06	12	[{"id_menu":1,"count":1}]	1803	pick-up	0	12
4380	2019-07-06 10:06:36	2019-07-06	14	[{"id_menu":2,"count":1}]	1236	pick-up	0	14
4381	2019-07-06 10:36:50	2019-07-06	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1796	pick-up	0	21
4382	2019-07-06 11:06:39	2019-07-06	14	[{"id_menu":2,"count":1}]	1800	delivery	5	19
4383	2019-07-06 12:28:48	2019-07-06	9	[{"id_menu":7,"count":1}]	447	pick-up	0	9
4384	2019-07-06 13:40:45	2019-07-06	9	[{"id_menu":7,"count":1}]	381	pick-up	0	9
4385	2019-07-06 14:06:57	2019-07-06	14	[{"id_menu":2,"count":1}]	204	pick-up	0	14
4386	2019-07-06 14:10:06	2019-07-06	9	[{"id_menu":7,"count":1}]	1209	delivery	5	14
4387	2019-07-06 14:24:37	2019-07-06	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":3}]	703	delivery	5	25
4388	2019-07-06 15:28:32	2019-07-06	9	[{"id_menu":7,"count":1}]	1407	pick-up	0	9
4389	2019-07-06 15:36:34	2019-07-06	12	[{"id_menu":3,"count":1}]	511	pick-up	0	12
4390	2019-07-06 15:48:59	2019-07-06	17	[{"id_menu":4,"count":1}]	168	delivery	5	22
4391	2019-07-06 15:56:26	2019-07-06	14	[{"id_menu":2,"count":1}]	1802	pick-up	0	14
4392	2019-07-06 16:08:53	2019-07-06	14	[{"id_menu":2,"count":1}]	946	pick-up	0	14
4393	2019-07-06 16:14:40	2019-07-06	14	[{"id_menu":2,"count":1}]	379	delivery	5	19
4394	2019-07-06 16:21:55	2019-07-06	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	211	pick-up	0	17
4395	2019-07-06 16:23:58	2019-07-06	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1250	pick-up	0	38
4396	2019-07-06 17:18:59	2019-07-06	9	[{"id_menu":6,"count":1}]	737	pick-up	0	9
4397	2019-07-06 17:29:13	2019-07-06	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1592	pick-up	0	18
4398	2019-07-06 17:42:53	2019-07-06	17	[{"id_menu":4,"count":1}]	549	pick-up	0	17
4399	2019-07-06 18:15:51	2019-07-06	12	[{"id_menu":1,"count":1}]	35	pick-up	0	12
4400	2019-07-06 19:34:48	2019-07-06	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1807	delivery	5	36
4401	2019-07-06 19:38:45	2019-07-06	12	[{"id_menu":3,"count":1}]	1801	pick-up	0	12
4402	2019-07-06 21:16:00	2019-07-06	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	245	pick-up	0	17
4403	2019-07-06 21:41:31	2019-07-06	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1805	pick-up	0	32
4404	2019-07-06 22:55:10	2019-07-06	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	424	pick-up	0	26
4405	2019-07-06 23:49:25	2019-07-06	17	[{"id_menu":4,"count":1}]	1799	pick-up	0	17
4406	2019-07-07 00:25:34	2019-07-07	9	[{"id_menu":7,"count":1}]	609	pick-up	0	9
4407	2019-07-07 01:10:55	2019-07-07	8	[{"id_menu":5,"count":2}]	1814	delivery	5	13
4408	2019-07-07 02:30:54	2019-07-07	9	[{"id_menu":6,"count":1}]	1809	delivery	5	14
4409	2019-07-07 02:59:00	2019-07-07	9	[{"id_menu":6,"count":1}]	1822	pick-up	0	9
4410	2019-07-07 03:11:46	2019-07-07	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	482	delivery	5	43
4411	2019-07-07 03:17:08	2019-07-07	14	[{"id_menu":2,"count":1}]	260	pick-up	0	14
4412	2019-07-07 03:24:18	2019-07-07	14	[{"id_menu":2,"count":1}]	185	pick-up	0	14
4413	2019-07-07 03:24:23	2019-07-07	14	[{"id_menu":2,"count":1}]	1760	pick-up	0	14
4414	2019-07-07 03:24:59	2019-07-07	12	[{"id_menu":3,"count":1}]	423	pick-up	0	12
4415	2019-07-07 03:28:00	2019-07-07	17	[{"id_menu":4,"count":1}]	766	pick-up	0	17
4416	2019-07-07 03:53:22	2019-07-07	12	[{"id_menu":1,"count":1}]	1812	delivery	5	17
4417	2019-07-07 05:34:03	2019-07-07	9	[{"id_menu":7,"count":1}]	1244	delivery	5	14
4418	2019-07-07 06:09:00	2019-07-07	8	[{"id_menu":5,"count":1}]	1821	pick-up	0	8
4419	2019-07-07 06:12:30	2019-07-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1813	delivery	5	28
4420	2019-07-07 06:24:29	2019-07-07	14	[{"id_menu":2,"count":1}]	1709	delivery	5	19
4421	2019-07-07 06:27:19	2019-07-07	14	[{"id_menu":2,"count":1}]	1713	pick-up	0	14
4422	2019-07-07 06:49:29	2019-07-07	14	[{"id_menu":2,"count":1}]	1445	delivery	5	19
4423	2019-07-07 06:54:01	2019-07-07	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	1610	delivery	5	22
4424	2019-07-07 07:10:33	2019-07-07	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	277	delivery	5	39
4425	2019-07-07 08:10:11	2019-07-07	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	1299	delivery	5	43
4426	2019-07-07 08:23:32	2019-07-07	12	[{"id_menu":3,"count":1}]	1811	pick-up	0	12
4427	2019-07-07 08:26:28	2019-07-07	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	336	delivery	5	27
4428	2019-07-07 08:29:54	2019-07-07	14	[{"id_menu":2,"count":1}]	1685	pick-up	0	14
4429	2019-07-07 10:12:32	2019-07-07	8	[{"id_menu":5,"count":1}]	1820	pick-up	0	8
4430	2019-07-07 10:15:54	2019-07-07	14	[{"id_menu":2,"count":2}]	813	pick-up	0	14
4431	2019-07-07 10:40:00	2019-07-07	9	[{"id_menu":6,"count":1}]	786	pick-up	0	9
4432	2019-07-07 10:42:11	2019-07-07	8	[{"id_menu":5,"count":1}]	1080	pick-up	0	8
4433	2019-07-07 11:07:15	2019-07-07	14	[{"id_menu":2,"count":1}]	1343	pick-up	0	14
4434	2019-07-07 11:08:33	2019-07-07	14	[{"id_menu":2,"count":1}]	1810	pick-up	0	14
4435	2019-07-07 11:48:51	2019-07-07	9	[{"id_menu":7,"count":1}]	1819	pick-up	0	9
4436	2019-07-07 13:39:11	2019-07-07	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	1816	delivery	5	26
4437	2019-07-07 13:46:28	2019-07-07	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	523	delivery	5	22
4438	2019-07-07 14:17:23	2019-07-07	8	[{"id_menu":5,"count":1}]	1701	pick-up	0	8
4439	2019-07-07 14:45:46	2019-07-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	424	pick-up	0	21
4440	2019-07-07 14:54:12	2019-07-07	9	[{"id_menu":6,"count":1}]	1818	delivery	5	14
4441	2019-07-07 15:35:29	2019-07-07	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1659	pick-up	0	31
4442	2019-07-07 15:55:10	2019-07-07	12	[{"id_menu":1,"count":1}]	1817	pick-up	0	12
4443	2019-07-07 17:01:36	2019-07-07	9	[{"id_menu":6,"count":1}]	1030	delivery	5	14
4444	2019-07-07 17:13:02	2019-07-07	17	[{"id_menu":4,"count":1}]	1156	pick-up	0	17
4445	2019-07-07 17:24:29	2019-07-07	9	[{"id_menu":6,"count":1}]	1823	pick-up	0	9
4446	2019-07-07 17:45:26	2019-07-07	17	[{"id_menu":4,"count":1}]	1815	delivery	5	22
4447	2019-07-07 18:07:46	2019-07-07	8	[{"id_menu":5,"count":1}]	267	delivery	5	13
4448	2019-07-07 18:19:48	2019-07-07	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	525	delivery	5	45
4449	2019-07-07 18:38:14	2019-07-07	8	[{"id_menu":5,"count":1}]	1344	pick-up	0	8
4450	2019-07-07 18:50:37	2019-07-07	9	[{"id_menu":7,"count":1}]	1521	pick-up	0	9
4451	2019-07-07 19:42:22	2019-07-07	12	[{"id_menu":1,"count":1}]	856	pick-up	0	12
4452	2019-07-07 20:38:26	2019-07-07	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	847	delivery	5	26
4453	2019-07-07 21:42:52	2019-07-07	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1645	pick-up	0	21
4454	2019-07-07 22:05:59	2019-07-07	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1468	delivery	5	35
4455	2019-07-07 22:40:48	2019-07-07	9	[{"id_menu":6,"count":1}]	1034	pick-up	0	9
4456	2019-07-07 23:10:55	2019-07-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	233	pick-up	0	23
4457	2019-07-08 00:48:50	2019-07-08	17	[{"id_menu":4,"count":1}]	1421	pick-up	0	17
4458	2019-07-08 01:03:34	2019-07-08	17	[{"id_menu":4,"count":1}]	721	pick-up	0	17
4459	2019-07-08 01:05:03	2019-07-08	12	[{"id_menu":1,"count":1}]	193	delivery	5	17
4460	2019-07-08 01:24:43	2019-07-08	9	[{"id_menu":6,"count":1}]	1827	delivery	5	14
4461	2019-07-08 02:07:00	2019-07-08	14	[{"id_menu":2,"count":1}]	360	pick-up	0	14
4462	2019-07-08 02:11:33	2019-07-08	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1831	pick-up	0	26
4463	2019-07-08 02:51:55	2019-07-08	12	[{"id_menu":3,"count":1}]	281	pick-up	0	12
4464	2019-07-08 03:54:53	2019-07-08	8	[{"id_menu":5,"count":1}]	1536	pick-up	0	8
4465	2019-07-08 04:16:01	2019-07-08	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1053	pick-up	0	41
4466	2019-07-08 05:36:19	2019-07-08	9	[{"id_menu":7,"count":1}]	601	pick-up	0	9
4467	2019-07-08 05:37:29	2019-07-08	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1826	delivery	5	25
4468	2019-07-08 06:14:39	2019-07-08	17	[{"id_menu":4,"count":1}]	543	pick-up	0	17
4469	2019-07-08 06:24:16	2019-07-08	17	[{"id_menu":4,"count":1}]	788	delivery	5	22
4470	2019-07-08 06:35:20	2019-07-08	8	[{"id_menu":5,"count":1}]	1830	delivery	5	13
4471	2019-07-08 08:17:49	2019-07-08	9	[{"id_menu":7,"count":1}]	536	pick-up	0	9
4472	2019-07-08 08:33:22	2019-07-08	12	[{"id_menu":3,"count":1}]	124	pick-up	0	12
4473	2019-07-08 10:55:33	2019-07-08	8	[{"id_menu":5,"count":2}]	528	delivery	5	13
4474	2019-07-08 11:01:05	2019-07-08	9	[{"id_menu":7,"count":1}]	132	pick-up	0	9
4475	2019-07-08 11:29:06	2019-07-08	12	[{"id_menu":3,"count":1}]	423	pick-up	0	12
4476	2019-07-08 12:04:13	2019-07-08	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1514	delivery	5	40
4477	2019-07-08 12:09:45	2019-07-08	12	[{"id_menu":1,"count":1}]	1766	delivery	5	17
4478	2019-07-08 14:44:24	2019-07-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1834	delivery	5	28
4479	2019-07-08 15:27:06	2019-07-08	14	[{"id_menu":2,"count":1}]	677	pick-up	0	14
4480	2019-07-08 16:27:23	2019-07-08	12	[{"id_menu":1,"count":2}]	1832	delivery	5	17
4481	2019-07-08 16:53:51	2019-07-08	9	[{"id_menu":7,"count":1}]	433	pick-up	0	9
4482	2019-07-08 17:26:19	2019-07-08	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1117	delivery	5	40
4483	2019-07-08 17:36:55	2019-07-08	8	[{"id_menu":5,"count":1}]	1628	delivery	5	13
4484	2019-07-08 17:51:32	2019-07-08	12	[{"id_menu":3,"count":1}]	1526	pick-up	0	12
4485	2019-07-08 18:57:13	2019-07-08	12	[{"id_menu":3,"count":1}]	1679	pick-up	0	12
4486	2019-07-08 19:17:21	2019-07-08	9	[{"id_menu":7,"count":1}]	391	delivery	5	14
4487	2019-07-08 19:23:58	2019-07-08	9	[{"id_menu":7,"count":1}]	377	pick-up	0	9
4488	2019-07-08 20:17:56	2019-07-08	9	[{"id_menu":6,"count":1}]	1829	delivery	5	14
4489	2019-07-08 20:29:04	2019-07-08	14	[{"id_menu":2,"count":1}]	1228	pick-up	0	14
4490	2019-07-08 20:37:51	2019-07-08	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1824	delivery	5	37
4491	2019-07-08 20:51:13	2019-07-08	17	[{"id_menu":4,"count":1}]	997	pick-up	0	17
4492	2019-07-08 23:35:04	2019-07-08	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	329	pick-up	0	43
4493	2019-07-08 23:57:15	2019-07-08	9	[{"id_menu":6,"count":1}]	37	delivery	5	14
4494	2019-07-09 00:25:11	2019-07-09	14	[{"id_menu":2,"count":1}]	1844	pick-up	0	14
4495	2019-07-09 01:52:54	2019-07-09	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1746	pick-up	0	21
4496	2019-07-09 02:35:36	2019-07-09	12	[{"id_menu":3,"count":1}]	207	delivery	5	17
4497	2019-07-09 04:28:14	2019-07-09	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	466	delivery	5	26
4498	2019-07-09 05:18:37	2019-07-09	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	298	pick-up	0	26
4499	2019-07-09 05:20:17	2019-07-09	14	[{"id_menu":2,"count":1}]	1795	delivery	5	19
4500	2019-07-09 06:06:10	2019-07-09	9	[{"id_menu":6,"count":1}]	888	delivery	5	14
4501	2019-07-09 06:48:49	2019-07-09	12	[{"id_menu":3,"count":1}]	1445	pick-up	0	12
4502	2019-07-09 09:06:41	2019-07-09	9	[{"id_menu":7,"count":1}]	854	delivery	5	14
4503	2019-07-09 09:12:19	2019-07-09	12	[{"id_menu":3,"count":1}]	1838	pick-up	0	12
4504	2019-07-09 09:56:53	2019-07-09	9	[{"id_menu":6,"count":1}]	74	pick-up	0	9
4505	2019-07-09 10:32:28	2019-07-09	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1676	pick-up	0	21
4506	2019-07-09 11:39:43	2019-07-09	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1269	pick-up	0	43
4507	2019-07-09 12:19:13	2019-07-09	14	[{"id_menu":2,"count":1}]	1406	pick-up	0	14
4508	2019-07-09 13:20:23	2019-07-09	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1085	pick-up	0	32
4509	2019-07-09 13:31:42	2019-07-09	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1837	delivery	5	26
4510	2019-07-09 13:59:09	2019-07-09	9	[{"id_menu":6,"count":1}]	772	pick-up	0	9
4511	2019-07-09 14:01:49	2019-07-09	12	[{"id_menu":3,"count":1}]	1237	pick-up	0	12
4512	2019-07-09 14:05:25	2019-07-09	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1843	pick-up	0	37
4513	2019-07-09 16:13:08	2019-07-09	9	[{"id_menu":7,"count":1}]	837	pick-up	0	9
4514	2019-07-09 16:20:19	2019-07-09	12	[{"id_menu":1,"count":1}]	1835	pick-up	0	12
4515	2019-07-09 16:20:47	2019-07-09	17	[{"id_menu":4,"count":1}]	1839	pick-up	0	17
4516	2019-07-09 16:54:23	2019-07-09	9	[{"id_menu":6,"count":1}]	932	pick-up	0	9
4517	2019-07-09 18:00:50	2019-07-09	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	989	pick-up	0	21
4518	2019-07-09 19:12:15	2019-07-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	77	delivery	5	28
4519	2019-07-09 19:27:57	2019-07-09	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	150	pick-up	0	17
4520	2019-07-09 19:34:01	2019-07-09	14	[{"id_menu":2,"count":1}]	1451	pick-up	0	14
4521	2019-07-09 19:42:19	2019-07-09	9	[{"id_menu":6,"count":1}]	1845	pick-up	0	9
4522	2019-07-09 19:49:42	2019-07-09	8	[{"id_menu":5,"count":1}]	1669	delivery	5	13
4523	2019-07-09 19:56:42	2019-07-09	8	[{"id_menu":5,"count":1}]	581	delivery	5	13
4524	2019-07-09 21:25:09	2019-07-09	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1261	pick-up	0	25
4525	2019-07-09 22:02:33	2019-07-09	8	[{"id_menu":5,"count":1}]	1606	delivery	5	13
4526	2019-07-09 22:20:42	2019-07-09	12	[{"id_menu":3,"count":1}]	177	pick-up	0	12
4527	2019-07-09 22:21:20	2019-07-09	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	122	delivery	5	43
4528	2019-07-09 22:25:18	2019-07-09	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1836	pick-up	0	25
4529	2019-07-09 22:48:04	2019-07-09	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	1841	delivery	5	43
4530	2019-07-10 00:16:21	2019-07-10	12	[{"id_menu":3,"count":1}]	126	pick-up	0	12
4531	2019-07-10 00:21:44	2019-07-10	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	1076	pick-up	0	22
4532	2019-07-10 01:11:04	2019-07-10	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	330	pick-up	0	26
4533	2019-07-10 02:20:37	2019-07-10	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1435	pick-up	0	29
4534	2019-07-10 02:52:23	2019-07-10	14	[{"id_menu":2,"count":1}]	710	delivery	5	19
4535	2019-07-10 03:10:24	2019-07-10	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1387	delivery	5	31
4536	2019-07-10 03:28:44	2019-07-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1464	delivery	5	23
4537	2019-07-10 03:56:56	2019-07-10	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	138	delivery	5	29
4538	2019-07-10 04:01:22	2019-07-10	9	[{"id_menu":7,"count":1}]	862	pick-up	0	9
4539	2019-07-10 04:06:53	2019-07-10	12	[{"id_menu":1,"count":1}]	32	pick-up	0	12
4540	2019-07-10 04:45:42	2019-07-10	9	[{"id_menu":6,"count":1}]	1005	delivery	5	14
4541	2019-07-10 05:36:53	2019-07-10	9	[{"id_menu":7,"count":1}]	1853	pick-up	0	9
4542	2019-07-10 06:12:16	2019-07-10	17	[{"id_menu":4,"count":1}]	1679	pick-up	0	17
4543	2019-07-10 07:01:43	2019-07-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1640	pick-up	0	18
4544	2019-07-10 07:44:41	2019-07-10	8	[{"id_menu":5,"count":1}]	1851	delivery	5	13
4545	2019-07-10 08:29:42	2019-07-10	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":2}]	606	delivery	5	29
4546	2019-07-10 08:35:37	2019-07-10	9	[{"id_menu":7,"count":1}]	1104	pick-up	0	9
4547	2019-07-10 08:46:00	2019-07-10	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1390	pick-up	0	30
4548	2019-07-10 09:54:10	2019-07-10	14	[{"id_menu":2,"count":1}]	1849	delivery	5	19
4549	2019-07-10 09:57:25	2019-07-10	12	[{"id_menu":1,"count":1}]	1332	delivery	5	17
4550	2019-07-10 10:28:59	2019-07-10	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1855	pick-up	0	29
4551	2019-07-10 11:39:42	2019-07-10	14	[{"id_menu":2,"count":1}]	1317	pick-up	0	14
4552	2019-07-10 12:07:39	2019-07-10	12	[{"id_menu":3,"count":1}]	1656	pick-up	0	12
4553	2019-07-10 12:35:18	2019-07-10	17	[{"id_menu":4,"count":1}]	1858	delivery	5	22
4554	2019-07-10 12:48:43	2019-07-10	12	[{"id_menu":3,"count":1}]	1379	pick-up	0	12
4555	2019-07-10 12:55:28	2019-07-10	14	[{"id_menu":2,"count":1}]	1847	delivery	5	19
4556	2019-07-10 12:58:12	2019-07-10	9	[{"id_menu":7,"count":1}]	1269	delivery	5	14
4557	2019-07-10 12:58:54	2019-07-10	8	[{"id_menu":5,"count":1}]	1854	pick-up	0	8
4558	2019-07-10 13:43:23	2019-07-10	9	[{"id_menu":6,"count":2}]	957	pick-up	0	9
4559	2019-07-10 13:51:55	2019-07-10	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1742	pick-up	0	24
4560	2019-07-10 14:11:30	2019-07-10	9	[{"id_menu":6,"count":1}]	1850	pick-up	0	9
4561	2019-07-10 14:48:18	2019-07-10	9	[{"id_menu":6,"count":1}]	1115	delivery	5	14
4562	2019-07-10 15:25:55	2019-07-10	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1859	delivery	5	25
4563	2019-07-10 16:06:15	2019-07-10	12	[{"id_menu":1,"count":1}]	1212	pick-up	0	12
4564	2019-07-10 17:22:58	2019-07-10	12	[{"id_menu":3,"count":1}]	778	pick-up	0	12
4565	2019-07-10 17:23:46	2019-07-10	9	[{"id_menu":6,"count":1}]	81	pick-up	0	9
4566	2019-07-10 18:16:28	2019-07-10	12	[{"id_menu":3,"count":1}]	838	delivery	5	17
4567	2019-07-10 18:37:57	2019-07-10	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1376	delivery	5	30
4568	2019-07-10 18:49:06	2019-07-10	9	[{"id_menu":7,"count":1}]	1848	pick-up	0	9
4569	2019-07-10 19:13:32	2019-07-10	12	[{"id_menu":3,"count":1}]	62	pick-up	0	12
4570	2019-07-10 19:16:51	2019-07-10	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1852	pick-up	0	47
4571	2019-07-10 20:50:45	2019-07-10	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	946	pick-up	0	20
4572	2019-07-10 20:59:51	2019-07-10	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	1445	delivery	5	29
4573	2019-07-10 21:01:32	2019-07-10	8	[{"id_menu":5,"count":1}]	626	delivery	5	13
4574	2019-07-10 21:02:41	2019-07-10	8	[{"id_menu":5,"count":1}]	511	delivery	5	13
4575	2019-07-10 21:50:10	2019-07-10	17	[{"id_menu":4,"count":1}]	204	pick-up	0	17
4576	2019-07-10 23:10:35	2019-07-10	9	[{"id_menu":7,"count":1}]	1265	delivery	5	14
4577	2019-07-10 23:47:43	2019-07-10	9	[{"id_menu":7,"count":1}]	160	pick-up	0	9
4578	2019-07-11 00:19:06	2019-07-11	14	[{"id_menu":2,"count":1}]	69	pick-up	0	14
4579	2019-07-11 01:28:00	2019-07-11	9	[{"id_menu":7,"count":1}]	790	delivery	5	14
4580	2019-07-11 01:58:15	2019-07-11	14	[{"id_menu":2,"count":1}]	315	pick-up	0	14
4581	2019-07-11 03:12:06	2019-07-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1863	pick-up	0	23
4582	2019-07-11 03:35:06	2019-07-11	12	[{"id_menu":1,"count":1}]	1259	pick-up	0	12
4583	2019-07-11 03:36:51	2019-07-11	12	[{"id_menu":3,"count":1}]	1513	pick-up	0	12
4584	2019-07-11 05:50:41	2019-07-11	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1379	delivery	5	31
4585	2019-07-11 06:19:05	2019-07-11	12	[{"id_menu":3,"count":1}]	1865	pick-up	0	12
4586	2019-07-11 07:13:34	2019-07-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1869	delivery	5	23
4587	2019-07-11 07:26:17	2019-07-11	12	[{"id_menu":3,"count":1}]	49	pick-up	0	12
4588	2019-07-11 08:19:44	2019-07-11	17	[{"id_menu":4,"count":1}]	1868	pick-up	0	17
4589	2019-07-11 09:07:57	2019-07-11	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":2}]	655	pick-up	0	23
4590	2019-07-11 09:15:07	2019-07-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1871	pick-up	0	23
4591	2019-07-11 09:35:46	2019-07-11	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	946	delivery	5	22
4592	2019-07-11 09:59:42	2019-07-11	9	[{"id_menu":6,"count":1}]	1861	delivery	5	14
4593	2019-07-11 10:01:28	2019-07-11	12	[{"id_menu":3,"count":1}]	586	delivery	5	17
4594	2019-07-11 10:15:44	2019-07-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1860	delivery	5	22
4595	2019-07-11 10:53:43	2019-07-11	12	[{"id_menu":1,"count":1}]	1108	delivery	5	17
4596	2019-07-11 11:06:12	2019-07-11	9	[{"id_menu":7,"count":1}]	1857	delivery	5	14
4597	2019-07-11 12:26:50	2019-07-11	8	[{"id_menu":5,"count":1}]	1870	pick-up	0	8
4598	2019-07-11 12:30:39	2019-07-11	12	[{"id_menu":1,"count":1}]	338	delivery	5	17
4599	2019-07-11 12:46:08	2019-07-11	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1867	pick-up	0	21
4600	2019-07-11 12:57:10	2019-07-11	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	149	delivery	5	45
4601	2019-07-11 13:09:54	2019-07-11	12	[{"id_menu":1,"count":1}]	96	pick-up	0	12
4602	2019-07-11 14:03:12	2019-07-11	9	[{"id_menu":7,"count":1}]	543	delivery	5	14
4603	2019-07-11 14:17:17	2019-07-11	9	[{"id_menu":7,"count":1}]	1273	pick-up	0	9
4604	2019-07-11 15:10:19	2019-07-11	9	[{"id_menu":7,"count":1}]	38	delivery	5	14
4605	2019-07-11 16:06:07	2019-07-11	8	[{"id_menu":5,"count":1}]	267	pick-up	0	8
4606	2019-07-11 16:08:54	2019-07-11	12	[{"id_menu":1,"count":1}]	1864	pick-up	0	12
4607	2019-07-11 17:49:35	2019-07-11	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1862	pick-up	0	21
4608	2019-07-11 17:57:49	2019-07-11	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	232	pick-up	0	20
4609	2019-07-11 18:17:54	2019-07-11	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	894	pick-up	0	23
4610	2019-07-11 19:01:21	2019-07-11	8	[{"id_menu":5,"count":1}]	786	pick-up	0	8
4611	2019-07-11 20:25:38	2019-07-11	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	1176	pick-up	0	21
4612	2019-07-11 20:34:20	2019-07-11	12	[{"id_menu":3,"count":1}]	422	delivery	5	17
4613	2019-07-11 20:34:22	2019-07-11	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	213	delivery	5	34
4614	2019-07-11 20:50:19	2019-07-11	9	[{"id_menu":7,"count":1}]	1685	pick-up	0	9
4615	2019-07-11 21:28:51	2019-07-11	8	[{"id_menu":5,"count":1}]	177	pick-up	0	8
4616	2019-07-11 21:40:27	2019-07-11	9	[{"id_menu":6,"count":1}]	202	pick-up	0	9
4617	2019-07-11 23:28:25	2019-07-11	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1872	delivery	5	26
4618	2019-07-11 23:52:28	2019-07-11	8	[{"id_menu":5,"count":1}]	260	delivery	5	13
4619	2019-07-12 00:05:54	2019-07-12	8	[{"id_menu":5,"count":1}]	581	delivery	5	13
4620	2019-07-12 02:04:35	2019-07-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1881	delivery	5	23
4621	2019-07-12 03:03:04	2019-07-12	12	[{"id_menu":3,"count":1}]	1140	pick-up	0	12
4622	2019-07-12 03:11:20	2019-07-12	12	[{"id_menu":1,"count":1}]	203	pick-up	0	12
4623	2019-07-12 03:52:59	2019-07-12	12	[{"id_menu":1,"count":1}]	1834	pick-up	0	12
4624	2019-07-12 04:09:54	2019-07-12	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1880	delivery	5	25
4625	2019-07-12 04:57:41	2019-07-12	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1233	delivery	5	40
4626	2019-07-12 05:04:02	2019-07-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1886	delivery	5	23
4627	2019-07-12 05:42:06	2019-07-12	14	[{"id_menu":2,"count":1}]	286	pick-up	0	14
4628	2019-07-12 07:50:46	2019-07-12	9	[{"id_menu":7,"count":1}]	1873	pick-up	0	9
4629	2019-07-12 08:10:41	2019-07-12	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	378	pick-up	0	33
4630	2019-07-12 08:20:43	2019-07-12	9	[{"id_menu":6,"count":1}]	1889	pick-up	0	9
4631	2019-07-12 08:45:20	2019-07-12	9	[{"id_menu":7,"count":1}]	600	pick-up	0	9
4632	2019-07-12 09:01:40	2019-07-12	17	[{"id_menu":4,"count":1}]	1492	delivery	5	22
4633	2019-07-12 09:01:52	2019-07-12	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1874	delivery	5	35
4634	2019-07-12 10:00:10	2019-07-12	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	921	delivery	5	30
4635	2019-07-12 10:47:39	2019-07-12	12	[{"id_menu":1,"count":1}]	845	delivery	5	17
4636	2019-07-12 11:52:03	2019-07-12	12	[{"id_menu":1,"count":1}]	1887	delivery	5	17
4637	2019-07-12 11:55:02	2019-07-12	8	[{"id_menu":5,"count":1}]	1882	pick-up	0	8
4638	2019-07-12 12:47:17	2019-07-12	9	[{"id_menu":7,"count":1}]	1831	delivery	5	14
4639	2019-07-12 12:56:57	2019-07-12	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1885	pick-up	0	30
4640	2019-07-12 13:08:21	2019-07-12	12	[{"id_menu":3,"count":1}]	1422	delivery	5	17
4641	2019-07-12 13:20:15	2019-07-12	12	[{"id_menu":1,"count":1}]	1883	pick-up	0	12
4642	2019-07-12 13:25:54	2019-07-12	14	[{"id_menu":2,"count":1}]	1888	delivery	5	19
4643	2019-07-12 14:42:52	2019-07-12	14	[{"id_menu":2,"count":1}]	806	pick-up	0	14
4644	2019-07-12 14:51:21	2019-07-12	17	[{"id_menu":4,"count":1}]	99	delivery	5	22
4645	2019-07-12 14:56:42	2019-07-12	9	[{"id_menu":7,"count":1}]	1536	delivery	5	14
4646	2019-07-12 15:11:05	2019-07-12	12	[{"id_menu":3,"count":1}]	281	pick-up	0	12
4647	2019-07-12 15:17:37	2019-07-12	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1060	pick-up	0	26
4648	2019-07-12 15:34:55	2019-07-12	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1656	pick-up	0	43
4649	2019-07-12 16:04:01	2019-07-12	14	[{"id_menu":2,"count":1}]	1875	delivery	5	19
4650	2019-07-12 16:10:14	2019-07-12	9	[{"id_menu":6,"count":1}]	638	delivery	5	14
4651	2019-07-12 17:26:46	2019-07-12	9	[{"id_menu":6,"count":1}]	1415	delivery	5	14
4652	2019-07-12 19:01:28	2019-07-12	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1878	pick-up	0	22
4653	2019-07-12 19:19:05	2019-07-12	9	[{"id_menu":7,"count":1}]	86	pick-up	0	9
4654	2019-07-12 19:20:40	2019-07-12	12	[{"id_menu":3,"count":1}]	1761	pick-up	0	12
4655	2019-07-12 20:52:52	2019-07-12	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	599	delivery	5	45
4656	2019-07-12 21:49:41	2019-07-12	17	[{"id_menu":4,"count":1}]	1884	pick-up	0	17
4657	2019-07-12 22:11:01	2019-07-12	8	[{"id_menu":5,"count":1}]	1876	delivery	5	13
4658	2019-07-12 23:46:27	2019-07-12	14	[{"id_menu":2,"count":1}]	1877	pick-up	0	14
4659	2019-07-12 23:56:18	2019-07-12	9	[{"id_menu":7,"count":1}]	48	pick-up	0	9
4660	2019-07-13 01:55:40	2019-07-13	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1446	pick-up	0	25
4661	2019-07-13 01:58:29	2019-07-13	12	[{"id_menu":3,"count":2}]	680	delivery	5	17
4662	2019-07-13 02:55:44	2019-07-13	9	[{"id_menu":7,"count":1}]	627	pick-up	0	9
4663	2019-07-13 02:56:46	2019-07-13	9	[{"id_menu":7,"count":1}]	925	pick-up	0	9
4664	2019-07-13 03:55:15	2019-07-13	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	964	delivery	5	26
4665	2019-07-13 04:05:28	2019-07-13	14	[{"id_menu":2,"count":1}]	1174	delivery	5	19
4666	2019-07-13 04:24:53	2019-07-13	8	[{"id_menu":5,"count":1}]	1899	pick-up	0	8
4667	2019-07-13 05:14:58	2019-07-13	9	[{"id_menu":7,"count":1}]	1901	pick-up	0	9
4668	2019-07-13 05:25:59	2019-07-13	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	701	pick-up	0	23
4669	2019-07-13 05:43:41	2019-07-13	12	[{"id_menu":3,"count":1}]	1136	pick-up	0	12
4670	2019-07-13 05:46:24	2019-07-13	12	[{"id_menu":1,"count":1}]	1270	pick-up	0	12
4671	2019-07-13 06:44:59	2019-07-13	14	[{"id_menu":2,"count":1}]	1894	pick-up	0	14
4672	2019-07-13 07:17:28	2019-07-13	9	[{"id_menu":7,"count":1}]	1893	pick-up	0	9
4673	2019-07-13 07:35:09	2019-07-13	8	[{"id_menu":5,"count":1}]	340	delivery	5	13
4674	2019-07-13 08:24:45	2019-07-13	17	[{"id_menu":4,"count":1}]	332	pick-up	0	17
4675	2019-07-13 08:43:25	2019-07-13	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1247	delivery	5	39
4676	2019-07-13 08:50:13	2019-07-13	12	[{"id_menu":1,"count":1}]	482	delivery	5	17
4677	2019-07-13 09:58:27	2019-07-13	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1904	pick-up	0	38
4678	2019-07-13 11:22:13	2019-07-13	14	[{"id_menu":2,"count":1}]	1896	pick-up	0	14
4679	2019-07-13 11:23:38	2019-07-13	17	[{"id_menu":4,"count":1}]	1890	pick-up	0	17
4680	2019-07-13 12:17:34	2019-07-13	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	784	pick-up	0	52
4681	2019-07-13 12:39:03	2019-07-13	9	[{"id_menu":6,"count":1}]	707	delivery	5	14
4682	2019-07-13 12:44:41	2019-07-13	9	[{"id_menu":6,"count":1}]	538	delivery	5	14
4683	2019-07-13 13:43:35	2019-07-13	14	[{"id_menu":2,"count":1}]	1369	pick-up	0	14
4684	2019-07-13 15:46:17	2019-07-13	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	68	pick-up	0	26
4685	2019-07-13 15:59:19	2019-07-13	9	[{"id_menu":7,"count":1}]	1900	pick-up	0	9
4686	2019-07-13 16:04:28	2019-07-13	9	[{"id_menu":6,"count":1}]	880	delivery	5	14
4687	2019-07-13 16:08:16	2019-07-13	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1687	pick-up	0	34
4688	2019-07-13 16:46:56	2019-07-13	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	314	pick-up	0	26
4689	2019-07-13 17:03:13	2019-07-13	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	53	pick-up	0	23
4690	2019-07-13 17:15:59	2019-07-13	9	[{"id_menu":6,"count":2}]	1780	pick-up	0	9
4691	2019-07-13 17:21:30	2019-07-13	17	[{"id_menu":4,"count":2}]	162	pick-up	0	17
4692	2019-07-13 17:35:36	2019-07-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	506	pick-up	0	23
4693	2019-07-13 18:26:00	2019-07-13	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1774	pick-up	0	35
4694	2019-07-13 19:06:42	2019-07-13	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	531	pick-up	0	24
4695	2019-07-13 19:30:58	2019-07-13	9	[{"id_menu":6,"count":1}]	1897	delivery	5	14
4696	2019-07-13 19:31:22	2019-07-13	9	[{"id_menu":7,"count":1}]	1390	delivery	5	14
4697	2019-07-13 19:38:37	2019-07-13	9	[{"id_menu":7,"count":1}]	740	pick-up	0	9
4698	2019-07-13 19:59:40	2019-07-13	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	1674	pick-up	0	21
4699	2019-07-13 21:06:38	2019-07-13	9	[{"id_menu":6,"count":1}]	1895	pick-up	0	9
4700	2019-07-13 21:20:56	2019-07-13	12	[{"id_menu":3,"count":1}]	997	pick-up	0	12
4701	2019-07-13 21:27:23	2019-07-13	9	[{"id_menu":7,"count":2}]	226	pick-up	0	9
4702	2019-07-13 21:41:37	2019-07-13	8	[{"id_menu":5,"count":1}]	1891	pick-up	0	8
4703	2019-07-13 22:03:30	2019-07-13	12	[{"id_menu":3,"count":1}]	1639	pick-up	0	12
4704	2019-07-13 22:33:39	2019-07-13	17	[{"id_menu":4,"count":1}]	1700	pick-up	0	17
4705	2019-07-13 22:43:34	2019-07-13	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1902	pick-up	0	26
4706	2019-07-13 23:15:24	2019-07-13	17	[{"id_menu":4,"count":1}]	1609	pick-up	0	17
4707	2019-07-13 23:20:55	2019-07-13	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1789	pick-up	0	17
4708	2019-07-13 23:36:37	2019-07-13	12	[{"id_menu":1,"count":1}]	1892	delivery	5	17
4709	2019-07-13 23:37:06	2019-07-13	9	[{"id_menu":7,"count":1}]	1490	pick-up	0	9
4710	2019-07-14 00:06:47	2019-07-14	14	[{"id_menu":2,"count":1}]	943	delivery	5	19
4711	2019-07-14 00:41:05	2019-07-14	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	477	pick-up	0	26
4712	2019-07-14 01:02:55	2019-07-14	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	784	delivery	5	34
4713	2019-07-14 01:05:51	2019-07-14	17	[{"id_menu":4,"count":1}]	401	pick-up	0	17
4714	2019-07-14 01:35:52	2019-07-14	12	[{"id_menu":3,"count":1}]	547	delivery	5	17
4715	2019-07-14 01:59:32	2019-07-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	351	pick-up	0	26
4716	2019-07-14 02:08:46	2019-07-14	14	[{"id_menu":2,"count":1}]	1916	delivery	5	19
4717	2019-07-14 02:12:40	2019-07-14	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	1912	pick-up	0	26
4718	2019-07-14 02:27:58	2019-07-14	8	[{"id_menu":5,"count":1}]	1321	pick-up	0	8
4719	2019-07-14 03:57:58	2019-07-14	14	[{"id_menu":2,"count":1}]	491	pick-up	0	14
4720	2019-07-14 04:07:14	2019-07-14	12	[{"id_menu":3,"count":1}]	1184	pick-up	0	12
4721	2019-07-14 04:14:24	2019-07-14	9	[{"id_menu":7,"count":1}]	159	pick-up	0	9
4722	2019-07-14 04:15:06	2019-07-14	17	[{"id_menu":4,"count":1}]	712	delivery	5	22
4723	2019-07-14 04:42:40	2019-07-14	9	[{"id_menu":6,"count":1}]	1607	delivery	5	14
4724	2019-07-14 05:02:18	2019-07-14	14	[{"id_menu":2,"count":1}]	638	delivery	5	19
4725	2019-07-14 05:06:43	2019-07-14	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1905	pick-up	0	29
4726	2019-07-14 05:13:10	2019-07-14	12	[{"id_menu":3,"count":1}]	1917	pick-up	0	12
4727	2019-07-14 05:37:06	2019-07-14	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	74	pick-up	0	29
4728	2019-07-14 06:13:28	2019-07-14	9	[{"id_menu":6,"count":1}]	343	pick-up	0	9
4729	2019-07-14 06:18:46	2019-07-14	9	[{"id_menu":6,"count":1}]	1095	pick-up	0	9
4730	2019-07-14 06:49:10	2019-07-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1908	pick-up	0	23
4731	2019-07-14 07:08:41	2019-07-14	9	[{"id_menu":7,"count":1}]	655	pick-up	0	9
4732	2019-07-14 07:58:33	2019-07-14	17	[{"id_menu":4,"count":1}]	1106	pick-up	0	17
4733	2019-07-14 08:06:12	2019-07-14	9	[{"id_menu":6,"count":1}]	1498	delivery	5	14
4734	2019-07-14 08:15:57	2019-07-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1918	delivery	5	28
4735	2019-07-14 08:17:17	2019-07-14	12	[{"id_menu":1,"count":2}]	1636	pick-up	0	12
4736	2019-07-14 08:35:45	2019-07-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1638	delivery	5	31
4737	2019-07-14 09:04:05	2019-07-14	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1765	pick-up	0	20
4738	2019-07-14 10:30:01	2019-07-14	17	[{"id_menu":4,"count":1}]	756	pick-up	0	17
4739	2019-07-14 10:43:26	2019-07-14	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	389	delivery	5	34
4740	2019-07-14 11:00:12	2019-07-14	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1913	delivery	5	27
4741	2019-07-14 11:51:52	2019-07-14	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	972	delivery	5	46
4742	2019-07-14 11:58:22	2019-07-14	17	[{"id_menu":4,"count":1}]	1293	delivery	5	22
4743	2019-07-14 12:02:39	2019-07-14	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	274	pick-up	0	21
4744	2019-07-14 12:19:25	2019-07-14	12	[{"id_menu":1,"count":1}]	1309	delivery	5	17
4745	2019-07-14 12:23:18	2019-07-14	33	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1909	pick-up	0	33
4746	2019-07-14 12:41:34	2019-07-14	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	804	delivery	5	31
4747	2019-07-14 12:42:58	2019-07-14	8	[{"id_menu":5,"count":2}]	1914	pick-up	0	8
4748	2019-07-14 12:48:03	2019-07-14	12	[{"id_menu":3,"count":1}]	352	pick-up	0	12
4749	2019-07-14 13:14:13	2019-07-14	14	[{"id_menu":2,"count":1}]	1618	pick-up	0	14
4750	2019-07-14 13:16:34	2019-07-14	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	282	pick-up	0	26
4751	2019-07-14 14:18:38	2019-07-14	12	[{"id_menu":1,"count":1}]	1138	pick-up	0	12
4752	2019-07-14 14:30:54	2019-07-14	14	[{"id_menu":2,"count":2}]	1526	delivery	5	19
4753	2019-07-14 14:34:14	2019-07-14	9	[{"id_menu":6,"count":3}]	1911	delivery	5	14
4754	2019-07-14 14:43:07	2019-07-14	12	[{"id_menu":3,"count":1}]	833	pick-up	0	12
4755	2019-07-14 15:19:48	2019-07-14	14	[{"id_menu":2,"count":1}]	1910	delivery	5	19
4756	2019-07-14 15:36:25	2019-07-14	8	[{"id_menu":5,"count":1}]	1736	pick-up	0	8
4757	2019-07-14 15:43:26	2019-07-14	14	[{"id_menu":2,"count":1}]	1611	pick-up	0	14
4758	2019-07-14 15:50:17	2019-07-14	14	[{"id_menu":2,"count":1}]	29	delivery	5	19
4759	2019-07-14 15:57:34	2019-07-14	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	447	pick-up	0	20
4760	2019-07-14 16:55:43	2019-07-14	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	754	pick-up	0	20
4761	2019-07-14 16:55:47	2019-07-14	14	[{"id_menu":2,"count":1}]	1907	pick-up	0	14
4762	2019-07-14 17:39:28	2019-07-14	8	[{"id_menu":5,"count":1}]	1009	pick-up	0	8
4763	2019-07-14 18:13:13	2019-07-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	229	pick-up	0	26
4764	2019-07-14 19:04:19	2019-07-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1085	pick-up	0	31
4765	2019-07-14 19:20:23	2019-07-14	17	[{"id_menu":4,"count":1}]	1915	pick-up	0	17
4766	2019-07-14 19:29:58	2019-07-14	17	[{"id_menu":4,"count":1}]	37	pick-up	0	17
4767	2019-07-14 22:16:20	2019-07-14	9	[{"id_menu":7,"count":1}]	1906	delivery	5	14
4768	2019-07-14 22:25:33	2019-07-14	17	[{"id_menu":4,"count":1}]	1369	pick-up	0	17
4769	2019-07-14 23:07:40	2019-07-14	9	[{"id_menu":6,"count":1}]	1409	pick-up	0	9
4770	2019-07-14 23:25:13	2019-07-14	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	200	pick-up	0	38
4771	2019-07-14 23:43:04	2019-07-14	9	[{"id_menu":6,"count":2}]	1780	delivery	5	14
4772	2019-07-15 00:54:11	2019-07-15	9	[{"id_menu":7,"count":1}]	1865	pick-up	0	9
4773	2019-07-15 01:39:33	2019-07-15	8	[{"id_menu":5,"count":1}]	719	pick-up	0	8
4774	2019-07-15 01:56:29	2019-07-15	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	91	pick-up	0	52
4775	2019-07-15 05:37:11	2019-07-15	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	982	delivery	5	36
4776	2019-07-15 05:37:37	2019-07-15	14	[{"id_menu":2,"count":1}]	1468	delivery	5	19
4777	2019-07-15 05:42:14	2019-07-15	14	[{"id_menu":2,"count":1}]	376	pick-up	0	14
4778	2019-07-15 06:17:45	2019-07-15	14	[{"id_menu":2,"count":1}]	734	pick-up	0	14
4779	2019-07-15 07:15:16	2019-07-15	12	[{"id_menu":1,"count":2}]	974	pick-up	0	12
4780	2019-07-15 10:27:51	2019-07-15	14	[{"id_menu":2,"count":1}]	1920	delivery	5	19
4781	2019-07-15 10:53:25	2019-07-15	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	1923	delivery	5	22
4782	2019-07-15 10:54:51	2019-07-15	14	[{"id_menu":2,"count":1}]	581	delivery	5	19
4783	2019-07-15 11:05:07	2019-07-15	9	[{"id_menu":7,"count":1}]	212	delivery	5	14
4784	2019-07-15 11:11:26	2019-07-15	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	360	pick-up	0	43
4785	2019-07-15 11:25:52	2019-07-15	17	[{"id_menu":4,"count":1}]	1098	delivery	5	22
4786	2019-07-15 11:48:58	2019-07-15	8	[{"id_menu":5,"count":1}]	270	pick-up	0	8
4787	2019-07-15 12:13:24	2019-07-15	12	[{"id_menu":1,"count":1}]	1587	pick-up	0	12
4788	2019-07-15 12:13:28	2019-07-15	8	[{"id_menu":5,"count":1}]	1919	delivery	5	13
4789	2019-07-15 13:40:39	2019-07-15	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1929	pick-up	0	29
4790	2019-07-15 14:02:52	2019-07-15	9	[{"id_menu":6,"count":1}]	966	pick-up	0	9
4791	2019-07-15 14:40:49	2019-07-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1928	pick-up	0	26
4792	2019-07-15 15:21:03	2019-07-15	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1053	pick-up	0	29
4793	2019-07-15 17:02:24	2019-07-15	9	[{"id_menu":6,"count":1}]	715	pick-up	0	9
4794	2019-07-15 17:38:19	2019-07-15	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	1321	delivery	5	26
4795	2019-07-15 18:44:08	2019-07-15	9	[{"id_menu":6,"count":1}]	310	delivery	5	14
4796	2019-07-15 20:57:17	2019-07-15	8	[{"id_menu":5,"count":1}]	1183	pick-up	0	8
4797	2019-07-15 21:28:46	2019-07-15	17	[{"id_menu":4,"count":1}]	1541	delivery	5	22
4798	2019-07-15 21:29:55	2019-07-15	14	[{"id_menu":2,"count":1}]	1924	pick-up	0	14
4799	2019-07-15 22:37:07	2019-07-15	14	[{"id_menu":2,"count":1}]	190	delivery	5	19
4800	2019-07-15 22:48:39	2019-07-15	9	[{"id_menu":7,"count":1}]	1897	delivery	5	14
4801	2019-07-15 22:52:22	2019-07-15	12	[{"id_menu":1,"count":1}]	829	delivery	5	17
4802	2019-07-15 23:05:52	2019-07-15	12	[{"id_menu":1,"count":1}]	80	delivery	5	17
4803	2019-07-15 23:54:27	2019-07-15	9	[{"id_menu":7,"count":1}]	1527	pick-up	0	9
4804	2019-07-16 01:28:20	2019-07-16	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	173	pick-up	0	29
4805	2019-07-16 01:59:42	2019-07-16	9	[{"id_menu":7,"count":1}]	153	pick-up	0	9
4806	2019-07-16 02:26:28	2019-07-16	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	964	delivery	5	36
4807	2019-07-16 06:13:23	2019-07-16	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1860	pick-up	0	20
4808	2019-07-16 07:50:26	2019-07-16	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1887	pick-up	0	22
4809	2019-07-16 09:01:07	2019-07-16	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1854	pick-up	0	21
4810	2019-07-16 09:38:58	2019-07-16	17	[{"id_menu":4,"count":1}]	1239	delivery	5	22
4811	2019-07-16 09:44:59	2019-07-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1934	pick-up	0	23
4812	2019-07-16 09:47:40	2019-07-16	17	[{"id_menu":4,"count":1}]	743	pick-up	0	17
4813	2019-07-16 10:30:59	2019-07-16	14	[{"id_menu":2,"count":1}]	1189	delivery	5	19
4814	2019-07-16 12:37:43	2019-07-16	9	[{"id_menu":7,"count":1}]	849	delivery	5	14
4815	2019-07-16 13:28:35	2019-07-16	9	[{"id_menu":6,"count":1}]	1931	pick-up	0	9
4816	2019-07-16 14:13:45	2019-07-16	17	[{"id_menu":4,"count":1}]	293	pick-up	0	17
4817	2019-07-16 14:19:28	2019-07-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	972	delivery	5	31
4818	2019-07-16 14:47:57	2019-07-16	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	575	delivery	5	25
4819	2019-07-16 15:04:22	2019-07-16	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1933	pick-up	0	25
4820	2019-07-16 15:33:01	2019-07-16	9	[{"id_menu":6,"count":2}]	1786	pick-up	0	9
4821	2019-07-16 15:35:53	2019-07-16	14	[{"id_menu":2,"count":1}]	1380	delivery	5	19
4822	2019-07-16 15:54:55	2019-07-16	8	[{"id_menu":5,"count":1}]	148	delivery	5	13
4823	2019-07-16 17:17:44	2019-07-16	55	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1771	pick-up	0	55
4824	2019-07-16 18:09:47	2019-07-16	14	[{"id_menu":2,"count":1}]	1932	pick-up	0	14
4825	2019-07-16 19:01:29	2019-07-16	9	[{"id_menu":6,"count":1}]	1938	pick-up	0	9
4826	2019-07-16 19:01:47	2019-07-16	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1296	pick-up	0	46
4827	2019-07-16 19:03:29	2019-07-16	14	[{"id_menu":2,"count":1}]	1936	pick-up	0	14
4828	2019-07-16 20:14:55	2019-07-16	9	[{"id_menu":7,"count":1}]	605	pick-up	0	9
4829	2019-07-16 20:54:31	2019-07-16	14	[{"id_menu":2,"count":1}]	1289	pick-up	0	14
4830	2019-07-16 21:42:55	2019-07-16	17	[{"id_menu":4,"count":1}]	71	pick-up	0	17
4831	2019-07-16 21:55:18	2019-07-16	14	[{"id_menu":2,"count":1}]	519	pick-up	0	14
4832	2019-07-16 23:31:52	2019-07-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1941	delivery	5	28
4833	2019-07-16 23:44:46	2019-07-16	12	[{"id_menu":3,"count":1}]	981	pick-up	0	12
4834	2019-07-16 23:49:13	2019-07-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	12	pick-up	0	23
4835	2019-07-17 01:05:52	2019-07-17	12	[{"id_menu":3,"count":1}]	377	pick-up	0	12
4836	2019-07-17 01:30:28	2019-07-17	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	552	delivery	5	27
4837	2019-07-17 02:01:15	2019-07-17	8	[{"id_menu":5,"count":1}]	265	pick-up	0	8
4838	2019-07-17 02:43:41	2019-07-17	14	[{"id_menu":2,"count":1}]	1943	delivery	5	19
4839	2019-07-17 03:17:00	2019-07-17	12	[{"id_menu":3,"count":1}]	815	delivery	5	17
4840	2019-07-17 03:57:56	2019-07-17	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1550	pick-up	0	21
4841	2019-07-17 04:08:53	2019-07-17	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1461	pick-up	0	32
4842	2019-07-17 04:42:57	2019-07-17	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1076	delivery	5	27
4843	2019-07-17 05:10:29	2019-07-17	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	548	delivery	5	26
4844	2019-07-17 05:29:11	2019-07-17	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	997	pick-up	0	21
4845	2019-07-17 06:33:02	2019-07-17	9	[{"id_menu":7,"count":1}]	738	delivery	5	14
4846	2019-07-17 08:06:33	2019-07-17	9	[{"id_menu":7,"count":1}]	1955	pick-up	0	9
4847	2019-07-17 08:10:27	2019-07-17	12	[{"id_menu":1,"count":1}]	1944	pick-up	0	12
4848	2019-07-17 08:47:00	2019-07-17	9	[{"id_menu":7,"count":1}]	1194	pick-up	0	9
4849	2019-07-17 10:03:02	2019-07-17	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1950	pick-up	0	29
4850	2019-07-17 10:22:57	2019-07-17	9	[{"id_menu":6,"count":1}]	1952	pick-up	0	9
4851	2019-07-17 10:25:06	2019-07-17	17	[{"id_menu":4,"count":1}]	1902	delivery	5	22
4852	2019-07-17 10:32:31	2019-07-17	9	[{"id_menu":6,"count":1}]	456	delivery	5	14
4853	2019-07-17 11:21:25	2019-07-17	9	[{"id_menu":6,"count":1}]	1948	delivery	5	14
4854	2019-07-17 11:51:44	2019-07-17	8	[{"id_menu":5,"count":1}]	819	pick-up	0	8
4855	2019-07-17 12:13:30	2019-07-17	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1854	delivery	5	27
4856	2019-07-17 12:28:15	2019-07-17	8	[{"id_menu":5,"count":1}]	1102	pick-up	0	8
4857	2019-07-17 13:28:51	2019-07-17	9	[{"id_menu":6,"count":1}]	1435	pick-up	0	9
4858	2019-07-17 15:15:02	2019-07-17	9	[{"id_menu":6,"count":1}]	1945	pick-up	0	9
4859	2019-07-17 15:59:46	2019-07-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1951	delivery	5	23
4860	2019-07-17 16:22:25	2019-07-17	8	[{"id_menu":5,"count":1}]	1233	pick-up	0	8
4861	2019-07-17 16:47:30	2019-07-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	330	pick-up	0	18
4862	2019-07-17 17:29:28	2019-07-17	14	[{"id_menu":2,"count":2}]	1581	delivery	5	19
4863	2019-07-17 17:43:30	2019-07-17	9	[{"id_menu":7,"count":1}]	1182	pick-up	0	9
4864	2019-07-17 18:15:14	2019-07-17	12	[{"id_menu":1,"count":1}]	48	pick-up	0	12
4865	2019-07-17 18:35:06	2019-07-17	17	[{"id_menu":4,"count":1}]	1832	pick-up	0	17
4866	2019-07-17 18:55:13	2019-07-17	9	[{"id_menu":6,"count":1}]	709	delivery	5	14
4867	2019-07-17 20:47:06	2019-07-17	17	[{"id_menu":4,"count":1}]	1282	pick-up	0	17
4868	2019-07-17 20:50:26	2019-07-17	9	[{"id_menu":7,"count":1}]	207	pick-up	0	9
4869	2019-07-17 21:37:19	2019-07-17	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1889	pick-up	0	21
4870	2019-07-17 23:00:47	2019-07-17	8	[{"id_menu":5,"count":1}]	1947	pick-up	0	8
4871	2019-07-17 23:26:34	2019-07-17	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1722	delivery	5	34
4872	2019-07-17 23:48:39	2019-07-17	14	[{"id_menu":2,"count":1}]	1954	delivery	5	19
4873	2019-07-18 01:03:40	2019-07-18	12	[{"id_menu":3,"count":1}]	345	pick-up	0	12
4874	2019-07-18 01:10:42	2019-07-18	9	[{"id_menu":6,"count":1}]	1965	pick-up	0	9
4875	2019-07-18 01:27:00	2019-07-18	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1490	pick-up	0	26
4876	2019-07-18 01:52:14	2019-07-18	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1555	pick-up	0	34
4877	2019-07-18 01:54:54	2019-07-18	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1959	pick-up	0	29
4878	2019-07-18 02:04:34	2019-07-18	9	[{"id_menu":7,"count":1}]	340	delivery	5	14
4879	2019-07-18 02:29:20	2019-07-18	12	[{"id_menu":3,"count":1}]	1806	pick-up	0	12
4880	2019-07-18 02:43:08	2019-07-18	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1585	delivery	5	26
4881	2019-07-18 03:03:19	2019-07-18	8	[{"id_menu":5,"count":1}]	1956	pick-up	0	8
4882	2019-07-18 05:00:47	2019-07-18	12	[{"id_menu":1,"count":2}]	1813	pick-up	0	12
4883	2019-07-18 05:07:10	2019-07-18	12	[{"id_menu":3,"count":1}]	1527	pick-up	0	12
4884	2019-07-18 06:50:17	2019-07-18	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	1722	pick-up	0	26
4885	2019-07-18 07:01:58	2019-07-18	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1119	pick-up	0	22
4886	2019-07-18 07:10:56	2019-07-18	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1442	delivery	5	42
4887	2019-07-18 07:14:24	2019-07-18	9	[{"id_menu":7,"count":1}]	1963	delivery	5	14
4888	2019-07-18 07:17:57	2019-07-18	14	[{"id_menu":2,"count":1}]	1078	pick-up	0	14
4889	2019-07-18 07:36:23	2019-07-18	9	[{"id_menu":6,"count":1}]	1962	delivery	5	14
4890	2019-07-18 08:06:59	2019-07-18	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1445	pick-up	0	47
4891	2019-07-18 08:26:23	2019-07-18	14	[{"id_menu":2,"count":1}]	489	delivery	5	19
4892	2019-07-18 09:20:37	2019-07-18	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	173	delivery	5	31
4893	2019-07-18 09:21:46	2019-07-18	9	[{"id_menu":7,"count":1}]	820	delivery	5	14
4894	2019-07-18 11:01:16	2019-07-18	9	[{"id_menu":7,"count":1}]	203	pick-up	0	9
4895	2019-07-18 11:32:27	2019-07-18	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1967	pick-up	0	25
4896	2019-07-18 13:08:51	2019-07-18	17	[{"id_menu":4,"count":1}]	1919	pick-up	0	17
4897	2019-07-18 13:17:31	2019-07-18	14	[{"id_menu":2,"count":1}]	1964	pick-up	0	14
4898	2019-07-18 14:13:45	2019-07-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1958	delivery	5	23
4899	2019-07-18 14:49:15	2019-07-18	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	737	delivery	5	36
4900	2019-07-18 14:57:57	2019-07-18	8	[{"id_menu":5,"count":1}]	948	pick-up	0	8
4901	2019-07-18 15:29:00	2019-07-18	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1013	delivery	5	30
4902	2019-07-18 15:44:55	2019-07-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	281	pick-up	0	17
4903	2019-07-18 15:54:23	2019-07-18	17	[{"id_menu":4,"count":1}]	858	delivery	5	22
4904	2019-07-18 16:08:50	2019-07-18	14	[{"id_menu":2,"count":1}]	197	delivery	5	19
4905	2019-07-18 18:02:01	2019-07-18	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1960	pick-up	0	17
4906	2019-07-18 18:08:01	2019-07-18	8	[{"id_menu":5,"count":1}]	634	pick-up	0	8
4907	2019-07-18 18:13:28	2019-07-18	17	[{"id_menu":4,"count":1}]	228	pick-up	0	17
4908	2019-07-18 19:04:04	2019-07-18	9	[{"id_menu":7,"count":1}]	66	pick-up	0	9
4909	2019-07-18 19:05:59	2019-07-18	9	[{"id_menu":7,"count":1}]	691	pick-up	0	9
4910	2019-07-18 19:51:38	2019-07-18	17	[{"id_menu":4,"count":1}]	905	pick-up	0	17
4911	2019-07-18 20:04:43	2019-07-18	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1654	delivery	5	52
4912	2019-07-18 21:29:11	2019-07-18	14	[{"id_menu":2,"count":1}]	547	delivery	5	19
4913	2019-07-18 22:26:49	2019-07-18	12	[{"id_menu":1,"count":1}]	414	pick-up	0	12
4914	2019-07-18 22:44:40	2019-07-18	12	[{"id_menu":3,"count":1}]	655	pick-up	0	12
4915	2019-07-18 22:58:21	2019-07-18	12	[{"id_menu":1,"count":1}]	1724	delivery	5	17
4916	2019-07-18 23:15:44	2019-07-18	9	[{"id_menu":7,"count":1}]	198	pick-up	0	9
4917	2019-07-18 23:20:40	2019-07-18	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	120	delivery	5	38
4918	2019-07-19 00:43:00	2019-07-19	8	[{"id_menu":5,"count":1}]	1975	pick-up	0	8
4919	2019-07-19 00:59:52	2019-07-19	14	[{"id_menu":2,"count":1}]	1977	delivery	5	19
4920	2019-07-19 02:13:33	2019-07-19	9	[{"id_menu":6,"count":1}]	1513	pick-up	0	9
4921	2019-07-19 02:41:58	2019-07-19	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	1713	pick-up	0	29
4922	2019-07-19 03:14:13	2019-07-19	14	[{"id_menu":2,"count":1}]	1968	pick-up	0	14
4923	2019-07-19 03:22:33	2019-07-19	9	[{"id_menu":7,"count":1}]	1274	delivery	5	14
4924	2019-07-19 06:17:54	2019-07-19	9	[{"id_menu":7,"count":1}]	260	pick-up	0	9
4925	2019-07-19 06:40:05	2019-07-19	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	444	pick-up	0	26
4926	2019-07-19 07:21:00	2019-07-19	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1435	delivery	5	44
4927	2019-07-19 07:48:13	2019-07-19	8	[{"id_menu":5,"count":1}]	177	pick-up	0	8
4928	2019-07-19 08:39:57	2019-07-19	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	96	pick-up	0	26
4929	2019-07-19 08:52:12	2019-07-19	12	[{"id_menu":1,"count":1}]	1973	delivery	5	17
4930	2019-07-19 09:42:07	2019-07-19	9	[{"id_menu":6,"count":1}]	1982	pick-up	0	9
4931	2019-07-19 09:58:40	2019-07-19	9	[{"id_menu":7,"count":1}]	1706	pick-up	0	9
4932	2019-07-19 11:02:47	2019-07-19	8	[{"id_menu":5,"count":1}]	1974	delivery	5	13
4933	2019-07-19 11:15:22	2019-07-19	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	299	pick-up	0	21
4934	2019-07-19 13:17:31	2019-07-19	12	[{"id_menu":1,"count":1}]	1212	delivery	5	17
4935	2019-07-19 13:28:54	2019-07-19	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	411	pick-up	0	26
4936	2019-07-19 14:25:46	2019-07-19	17	[{"id_menu":4,"count":1}]	1241	pick-up	0	17
4937	2019-07-19 14:28:42	2019-07-19	9	[{"id_menu":7,"count":1}]	1980	pick-up	0	9
4938	2019-07-19 14:33:50	2019-07-19	14	[{"id_menu":2,"count":1}]	1979	delivery	5	19
4939	2019-07-19 14:51:07	2019-07-19	17	[{"id_menu":4,"count":1}]	1981	pick-up	0	17
4940	2019-07-19 14:51:48	2019-07-19	12	[{"id_menu":1,"count":1}]	925	delivery	5	17
4941	2019-07-19 14:54:48	2019-07-19	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1247	delivery	5	35
4942	2019-07-19 15:19:37	2019-07-19	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	697	pick-up	0	43
4943	2019-07-19 16:17:52	2019-07-19	14	[{"id_menu":2,"count":1}]	1983	delivery	5	19
4944	2019-07-19 17:01:05	2019-07-19	9	[{"id_menu":6,"count":1}]	232	pick-up	0	9
4945	2019-07-19 18:26:02	2019-07-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	274	pick-up	0	17
4946	2019-07-19 18:44:06	2019-07-19	8	[{"id_menu":5,"count":1}]	1666	delivery	5	13
4947	2019-07-19 19:37:18	2019-07-19	9	[{"id_menu":7,"count":1}]	1875	delivery	5	14
4948	2019-07-19 20:51:05	2019-07-19	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	802	pick-up	0	29
4949	2019-07-19 21:25:57	2019-07-19	8	[{"id_menu":5,"count":1}]	1969	pick-up	0	8
4950	2019-07-19 21:26:28	2019-07-19	12	[{"id_menu":3,"count":2}]	171	delivery	5	17
4951	2019-07-19 21:39:48	2019-07-19	9	[{"id_menu":7,"count":1}]	451	pick-up	0	9
4952	2019-07-19 22:23:14	2019-07-19	17	[{"id_menu":4,"count":1}]	1970	delivery	5	22
4953	2019-07-19 22:38:30	2019-07-19	9	[{"id_menu":7,"count":1}]	1897	delivery	5	14
4954	2019-07-19 23:31:09	2019-07-19	12	[{"id_menu":1,"count":2}]	287	pick-up	0	12
4955	2019-07-19 23:52:23	2019-07-19	12	[{"id_menu":1,"count":1}]	1971	delivery	5	17
4956	2019-07-20 00:16:57	2019-07-20	9	[{"id_menu":7,"count":1}]	1996	pick-up	0	9
4957	2019-07-20 00:53:18	2019-07-20	9	[{"id_menu":7,"count":1}]	1119	delivery	5	14
4958	2019-07-20 01:05:32	2019-07-20	14	[{"id_menu":2,"count":1}]	786	pick-up	0	14
4959	2019-07-20 01:27:22	2019-07-20	12	[{"id_menu":1,"count":1}]	491	pick-up	0	12
4960	2019-07-20 02:21:00	2019-07-20	8	[{"id_menu":5,"count":1}]	599	pick-up	0	8
4961	2019-07-20 02:27:19	2019-07-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1093	pick-up	0	23
4962	2019-07-20 03:54:05	2019-07-20	9	[{"id_menu":7,"count":1}]	1988	pick-up	0	9
4963	2019-07-20 05:32:45	2019-07-20	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	679	delivery	5	34
4964	2019-07-20 05:46:11	2019-07-20	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1239	pick-up	0	35
4965	2019-07-20 06:14:18	2019-07-20	17	[{"id_menu":4,"count":1}]	1684	pick-up	0	17
4966	2019-07-20 06:47:01	2019-07-20	12	[{"id_menu":3,"count":1}]	244	delivery	5	17
4967	2019-07-20 06:51:59	2019-07-20	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1986	pick-up	0	34
4968	2019-07-20 08:37:14	2019-07-20	9	[{"id_menu":6,"count":1}]	1998	delivery	5	14
4969	2019-07-20 09:40:08	2019-07-20	9	[{"id_menu":6,"count":1}]	1649	pick-up	0	9
4970	2019-07-20 09:45:03	2019-07-20	9	[{"id_menu":6,"count":1}]	1985	delivery	5	14
4971	2019-07-20 09:53:21	2019-07-20	9	[{"id_menu":7,"count":1}]	543	delivery	5	14
4972	2019-07-20 10:12:32	2019-07-20	8	[{"id_menu":5,"count":1}]	549	pick-up	0	8
4973	2019-07-20 10:18:48	2019-07-20	17	[{"id_menu":4,"count":1}]	1990	pick-up	0	17
4974	2019-07-20 10:30:13	2019-07-20	12	[{"id_menu":1,"count":1}]	1993	pick-up	0	12
4975	2019-07-20 10:54:20	2019-07-20	9	[{"id_menu":6,"count":1}]	1860	pick-up	0	9
4976	2019-07-20 10:57:00	2019-07-20	17	[{"id_menu":4,"count":1}]	954	delivery	5	22
4977	2019-07-20 11:02:58	2019-07-20	17	[{"id_menu":4,"count":1}]	626	pick-up	0	17
4978	2019-07-20 11:15:45	2019-07-20	17	[{"id_menu":4,"count":1}]	1764	pick-up	0	17
4979	2019-07-20 11:26:55	2019-07-20	9	[{"id_menu":6,"count":1}]	1994	delivery	5	14
4980	2019-07-20 11:39:26	2019-07-20	14	[{"id_menu":2,"count":1}]	1968	pick-up	0	14
4981	2019-07-20 12:23:36	2019-07-20	17	[{"id_menu":4,"count":1}]	85	pick-up	0	17
4982	2019-07-20 12:24:14	2019-07-20	14	[{"id_menu":2,"count":1}]	68	pick-up	0	14
4983	2019-07-20 13:00:06	2019-07-20	8	[{"id_menu":5,"count":1}]	1991	pick-up	0	8
4984	2019-07-20 13:05:13	2019-07-20	17	[{"id_menu":4,"count":1}]	868	pick-up	0	17
4985	2019-07-20 13:54:31	2019-07-20	8	[{"id_menu":5,"count":1}]	254	delivery	5	13
4986	2019-07-20 14:03:12	2019-07-20	9	[{"id_menu":6,"count":1}]	1989	pick-up	0	9
4987	2019-07-20 14:37:02	2019-07-20	12	[{"id_menu":3,"count":1}]	1321	delivery	5	17
4988	2019-07-20 15:35:08	2019-07-20	14	[{"id_menu":2,"count":1}]	1729	pick-up	0	14
4989	2019-07-20 15:53:05	2019-07-20	8	[{"id_menu":5,"count":1}]	78	pick-up	0	8
4990	2019-07-20 15:57:03	2019-07-20	8	[{"id_menu":5,"count":1}]	1462	pick-up	0	8
4991	2019-07-20 16:14:11	2019-07-20	8	[{"id_menu":5,"count":1}]	299	pick-up	0	8
4992	2019-07-20 16:31:37	2019-07-20	17	[{"id_menu":4,"count":1}]	905	pick-up	0	17
4993	2019-07-20 16:33:31	2019-07-20	8	[{"id_menu":5,"count":1}]	84	delivery	5	13
4994	2019-07-20 17:15:27	2019-07-20	14	[{"id_menu":2,"count":1}]	267	pick-up	0	14
4995	2019-07-20 17:29:48	2019-07-20	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1992	pick-up	0	17
4996	2019-07-20 17:41:55	2019-07-20	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	270	pick-up	0	26
4997	2019-07-20 19:02:50	2019-07-20	9	[{"id_menu":7,"count":1}]	1995	pick-up	0	9
4998	2019-07-20 19:52:03	2019-07-20	8	[{"id_menu":5,"count":1}]	807	pick-up	0	8
4999	2019-07-20 19:53:16	2019-07-20	12	[{"id_menu":3,"count":1}]	1546	delivery	5	17
5000	2019-07-20 19:57:19	2019-07-20	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1997	delivery	5	30
5001	2019-07-20 20:18:20	2019-07-20	9	[{"id_menu":7,"count":1}]	1427	pick-up	0	9
5002	2019-07-20 20:43:26	2019-07-20	9	[{"id_menu":7,"count":1}]	1481	delivery	5	14
5003	2019-07-20 21:04:36	2019-07-20	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1896	delivery	5	30
5004	2019-07-20 21:44:33	2019-07-20	12	[{"id_menu":3,"count":1}]	1984	delivery	5	17
5005	2019-07-20 21:55:23	2019-07-20	17	[{"id_menu":4,"count":1}]	421	pick-up	0	17
5006	2019-07-21 00:18:29	2019-07-21	12	[{"id_menu":1,"count":1}]	1515	pick-up	0	12
5007	2019-07-21 00:31:36	2019-07-21	17	[{"id_menu":4,"count":1}]	37	pick-up	0	17
5008	2019-07-21 00:38:10	2019-07-21	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1322	pick-up	0	21
5009	2019-07-21 01:04:15	2019-07-21	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	531	delivery	5	38
5010	2019-07-21 01:19:18	2019-07-21	9	[{"id_menu":6,"count":1}]	2013	delivery	5	14
5011	2019-07-21 01:19:25	2019-07-21	9	[{"id_menu":7,"count":1}]	2002	pick-up	0	9
5012	2019-07-21 01:33:03	2019-07-21	14	[{"id_menu":2,"count":2}]	46	delivery	5	19
5013	2019-07-21 02:13:19	2019-07-21	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	286	pick-up	0	31
5014	2019-07-21 03:12:52	2019-07-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2010	delivery	5	22
5015	2019-07-21 03:17:28	2019-07-21	9	[{"id_menu":7,"count":1}]	378	pick-up	0	9
5016	2019-07-21 03:20:36	2019-07-21	12	[{"id_menu":3,"count":1}]	1592	pick-up	0	12
5017	2019-07-21 03:28:13	2019-07-21	17	[{"id_menu":4,"count":1}]	786	delivery	5	22
5018	2019-07-21 03:32:09	2019-07-21	12	[{"id_menu":1,"count":1}]	2012	pick-up	0	12
5019	2019-07-21 03:39:48	2019-07-21	8	[{"id_menu":5,"count":1}]	1072	pick-up	0	8
5020	2019-07-21 03:57:45	2019-07-21	9	[{"id_menu":6,"count":1}]	2008	pick-up	0	9
5021	2019-07-21 04:01:42	2019-07-21	9	[{"id_menu":7,"count":1}]	358	delivery	5	14
5022	2019-07-21 05:00:27	2019-07-21	12	[{"id_menu":3,"count":1}]	1155	pick-up	0	12
5023	2019-07-21 05:08:55	2019-07-21	14	[{"id_menu":2,"count":1}]	36	delivery	5	19
5024	2019-07-21 05:48:05	2019-07-21	12	[{"id_menu":1,"count":1}]	1106	pick-up	0	12
5025	2019-07-21 06:29:24	2019-07-21	14	[{"id_menu":2,"count":1}]	506	delivery	5	19
5026	2019-07-21 06:44:22	2019-07-21	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	2006	pick-up	0	29
5027	2019-07-21 07:05:49	2019-07-21	12	[{"id_menu":1,"count":1}]	310	delivery	5	17
5028	2019-07-21 07:20:52	2019-07-21	8	[{"id_menu":5,"count":1}]	1485	pick-up	0	8
5029	2019-07-21 07:31:43	2019-07-21	9	[{"id_menu":7,"count":1}]	541	delivery	5	14
5030	2019-07-21 08:05:02	2019-07-21	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1334	pick-up	0	29
5031	2019-07-21 08:07:19	2019-07-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	219	delivery	5	31
5032	2019-07-21 08:32:51	2019-07-21	14	[{"id_menu":2,"count":1}]	1055	pick-up	0	14
5033	2019-07-21 08:43:09	2019-07-21	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	638	pick-up	0	31
5034	2019-07-21 08:49:20	2019-07-21	12	[{"id_menu":1,"count":1}]	2004	pick-up	0	12
5035	2019-07-21 09:55:13	2019-07-21	12	[{"id_menu":3,"count":1}]	223	pick-up	0	12
5036	2019-07-21 09:57:49	2019-07-21	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	2011	delivery	5	22
5037	2019-07-21 11:12:43	2019-07-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1097	delivery	5	31
5038	2019-07-21 11:50:05	2019-07-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1445	delivery	5	22
5039	2019-07-21 11:55:04	2019-07-21	12	[{"id_menu":3,"count":1}]	2007	delivery	5	17
5040	2019-07-21 11:56:06	2019-07-21	9	[{"id_menu":6,"count":1}]	1208	pick-up	0	9
5041	2019-07-21 12:19:54	2019-07-21	14	[{"id_menu":2,"count":1}]	1223	delivery	5	19
5042	2019-07-21 12:32:55	2019-07-21	9	[{"id_menu":7,"count":1}]	799	pick-up	0	9
5043	2019-07-21 12:42:10	2019-07-21	9	[{"id_menu":7,"count":1}]	1015	delivery	5	14
5044	2019-07-21 13:30:04	2019-07-21	12	[{"id_menu":1,"count":1}]	704	pick-up	0	12
5045	2019-07-21 13:30:22	2019-07-21	14	[{"id_menu":2,"count":1}]	1070	pick-up	0	14
5046	2019-07-21 13:38:26	2019-07-21	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1085	pick-up	0	38
5047	2019-07-21 13:54:53	2019-07-21	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	833	pick-up	0	29
5048	2019-07-21 14:16:16	2019-07-21	12	[{"id_menu":1,"count":2}]	993	pick-up	0	12
5049	2019-07-21 14:21:44	2019-07-21	9	[{"id_menu":6,"count":1}]	1513	pick-up	0	9
5050	2019-07-21 14:55:59	2019-07-21	17	[{"id_menu":4,"count":1}]	691	pick-up	0	17
5051	2019-07-21 15:12:24	2019-07-21	9	[{"id_menu":6,"count":1}]	61	pick-up	0	9
5052	2019-07-21 15:25:26	2019-07-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	477	pick-up	0	26
5053	2019-07-21 16:02:36	2019-07-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	942	pick-up	0	17
5054	2019-07-21 16:21:08	2019-07-21	9	[{"id_menu":7,"count":1}]	299	pick-up	0	9
5055	2019-07-21 16:33:21	2019-07-21	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	95	delivery	5	36
5056	2019-07-21 16:50:09	2019-07-21	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	584	delivery	5	31
5057	2019-07-21 16:53:22	2019-07-21	9	[{"id_menu":6,"count":1}]	2000	pick-up	0	9
5058	2019-07-21 16:57:36	2019-07-21	17	[{"id_menu":4,"count":1}]	1999	delivery	5	22
5059	2019-07-21 17:35:44	2019-07-21	17	[{"id_menu":4,"count":1}]	2003	pick-up	0	17
5060	2019-07-21 17:54:55	2019-07-21	9	[{"id_menu":6,"count":1}]	635	delivery	5	14
5061	2019-07-21 18:21:52	2019-07-21	14	[{"id_menu":2,"count":1}]	998	pick-up	0	14
5062	2019-07-21 18:22:11	2019-07-21	14	[{"id_menu":2,"count":1}]	791	delivery	5	19
5063	2019-07-21 19:41:45	2019-07-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	233	pick-up	0	23
5064	2019-07-21 19:54:39	2019-07-21	12	[{"id_menu":3,"count":1}]	847	pick-up	0	12
5065	2019-07-21 19:58:21	2019-07-21	17	[{"id_menu":4,"count":1}]	1963	pick-up	0	17
5066	2019-07-21 20:50:37	2019-07-21	12	[{"id_menu":1,"count":1}]	2009	delivery	5	17
5067	2019-07-21 21:03:54	2019-07-21	12	[{"id_menu":3,"count":1}]	573	delivery	5	17
5068	2019-07-21 21:13:10	2019-07-21	9	[{"id_menu":7,"count":1}]	1586	pick-up	0	9
5069	2019-07-21 21:48:05	2019-07-21	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	189	pick-up	0	20
5070	2019-07-21 22:54:44	2019-07-21	17	[{"id_menu":4,"count":1}]	1557	delivery	5	22
5071	2019-07-21 22:57:13	2019-07-21	12	[{"id_menu":3,"count":1}]	2001	pick-up	0	12
5072	2019-07-21 22:59:15	2019-07-21	14	[{"id_menu":2,"count":1}]	1293	delivery	5	19
5073	2019-07-21 23:12:33	2019-07-21	9	[{"id_menu":6,"count":1}]	1393	delivery	5	14
5074	2019-07-21 23:14:58	2019-07-21	14	[{"id_menu":2,"count":1}]	2005	pick-up	0	14
5075	2019-07-21 23:29:37	2019-07-21	17	[{"id_menu":4,"count":1}]	627	delivery	5	22
5076	2019-07-21 23:59:49	2019-07-21	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	826	pick-up	0	26
5077	2019-07-22 00:24:05	2019-07-22	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	439	pick-up	0	21
5078	2019-07-22 00:58:13	2019-07-22	12	[{"id_menu":3,"count":1}]	2025	pick-up	0	12
5079	2019-07-22 01:23:23	2019-07-22	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1266	pick-up	0	33
5080	2019-07-22 02:14:34	2019-07-22	14	[{"id_menu":2,"count":1}]	2021	pick-up	0	14
5081	2019-07-22 02:54:22	2019-07-22	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	519	pick-up	0	20
5082	2019-07-22 03:39:09	2019-07-22	9	[{"id_menu":6,"count":1}]	1162	pick-up	0	9
5083	2019-07-22 04:52:20	2019-07-22	14	[{"id_menu":2,"count":1}]	372	pick-up	0	14
5084	2019-07-22 05:45:46	2019-07-22	14	[{"id_menu":2,"count":1}]	1557	pick-up	0	14
5085	2019-07-22 06:04:55	2019-07-22	17	[{"id_menu":4,"count":1}]	1131	delivery	5	22
5086	2019-07-22 06:05:10	2019-07-22	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2019	pick-up	0	26
5087	2019-07-22 06:06:11	2019-07-22	17	[{"id_menu":4,"count":1}]	2023	pick-up	0	17
5088	2019-07-22 06:17:57	2019-07-22	12	[{"id_menu":1,"count":1}]	906	pick-up	0	12
5089	2019-07-22 08:48:20	2019-07-22	17	[{"id_menu":4,"count":1}]	286	delivery	5	22
5090	2019-07-22 11:07:38	2019-07-22	12	[{"id_menu":1,"count":1}]	73	pick-up	0	12
5091	2019-07-22 11:14:58	2019-07-22	8	[{"id_menu":5,"count":2}]	2017	delivery	5	13
5092	2019-07-22 11:16:47	2019-07-22	12	[{"id_menu":1,"count":1}]	2014	pick-up	0	12
5093	2019-07-22 12:05:43	2019-07-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	333	pick-up	0	31
5094	2019-07-22 12:17:11	2019-07-22	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2016	pick-up	0	46
5095	2019-07-22 13:17:18	2019-07-22	8	[{"id_menu":5,"count":1}]	1223	delivery	5	13
5096	2019-07-22 13:32:01	2019-07-22	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	826	delivery	5	27
5097	2019-07-22 13:48:36	2019-07-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	788	pick-up	0	17
5098	2019-07-22 14:44:52	2019-07-22	8	[{"id_menu":5,"count":1}]	905	pick-up	0	8
5099	2019-07-22 14:45:45	2019-07-22	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1527	pick-up	0	26
5100	2019-07-22 16:12:21	2019-07-22	14	[{"id_menu":2,"count":1}]	1810	delivery	5	19
5101	2019-07-22 16:24:08	2019-07-22	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1681	delivery	5	27
5102	2019-07-22 16:42:47	2019-07-22	9	[{"id_menu":6,"count":1}]	2018	delivery	5	14
5103	2019-07-22 16:52:59	2019-07-22	12	[{"id_menu":3,"count":1}]	257	delivery	5	17
5104	2019-07-22 17:26:04	2019-07-22	14	[{"id_menu":2,"count":1}]	31	delivery	5	19
5105	2019-07-22 21:41:05	2019-07-22	17	[{"id_menu":4,"count":1}]	1597	pick-up	0	17
5106	2019-07-22 22:12:21	2019-07-22	14	[{"id_menu":2,"count":1}]	2024	pick-up	0	14
5107	2019-07-22 22:27:04	2019-07-22	12	[{"id_menu":1,"count":1}]	1885	pick-up	0	12
5108	2019-07-23 00:04:49	2019-07-23	12	[{"id_menu":1,"count":1}]	654	pick-up	0	12
5109	2019-07-23 00:26:22	2019-07-23	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	781	pick-up	0	38
5110	2019-07-23 00:37:07	2019-07-23	9	[{"id_menu":6,"count":1}]	2035	delivery	5	14
5111	2019-07-23 01:19:13	2019-07-23	29	[{"id_menu":1,"count":3},{"id_menu":4,"count":1}]	1707	pick-up	0	29
5112	2019-07-23 01:49:48	2019-07-23	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	1819	pick-up	0	22
5113	2019-07-23 02:20:29	2019-07-23	9	[{"id_menu":7,"count":2}]	437	delivery	5	14
5114	2019-07-23 02:39:45	2019-07-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1208	pick-up	0	31
5115	2019-07-23 02:46:26	2019-07-23	17	[{"id_menu":4,"count":1}]	131	pick-up	0	17
5116	2019-07-23 03:35:53	2019-07-23	17	[{"id_menu":4,"count":1}]	640	pick-up	0	17
5117	2019-07-23 04:20:02	2019-07-23	12	[{"id_menu":1,"count":1}]	2037	pick-up	0	12
5118	2019-07-23 04:38:33	2019-07-23	17	[{"id_menu":4,"count":1}]	2029	delivery	5	22
5119	2019-07-23 04:53:26	2019-07-23	12	[{"id_menu":1,"count":1}]	573	pick-up	0	12
5120	2019-07-23 05:33:47	2019-07-23	12	[{"id_menu":3,"count":1}]	1151	delivery	5	17
5121	2019-07-23 07:17:17	2019-07-23	14	[{"id_menu":2,"count":1}]	37	pick-up	0	14
5122	2019-07-23 07:23:59	2019-07-23	12	[{"id_menu":3,"count":1}]	2032	delivery	5	17
5123	2019-07-23 07:39:54	2019-07-23	9	[{"id_menu":7,"count":1}]	1885	pick-up	0	9
5124	2019-07-23 08:02:00	2019-07-23	14	[{"id_menu":2,"count":1}]	1130	pick-up	0	14
5125	2019-07-23 08:50:36	2019-07-23	17	[{"id_menu":4,"count":1}]	840	delivery	5	22
5126	2019-07-23 09:50:35	2019-07-23	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	316	delivery	5	40
5127	2019-07-23 09:57:26	2019-07-23	12	[{"id_menu":3,"count":1}]	2030	pick-up	0	12
5128	2019-07-23 12:21:58	2019-07-23	17	[{"id_menu":4,"count":1}]	1460	pick-up	0	17
5129	2019-07-23 14:09:40	2019-07-23	12	[{"id_menu":3,"count":1}]	2034	pick-up	0	12
5130	2019-07-23 17:00:49	2019-07-23	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	444	pick-up	0	21
5131	2019-07-23 18:03:53	2019-07-23	14	[{"id_menu":2,"count":1}]	1240	delivery	5	19
5132	2019-07-23 18:05:48	2019-07-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2036	pick-up	0	23
5133	2019-07-23 18:53:34	2019-07-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1170	pick-up	0	23
5134	2019-07-23 19:14:01	2019-07-23	14	[{"id_menu":2,"count":1}]	1085	delivery	5	19
5135	2019-07-23 19:26:44	2019-07-23	9	[{"id_menu":6,"count":1}]	645	delivery	5	14
5136	2019-07-23 19:46:23	2019-07-23	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	925	delivery	5	43
5137	2019-07-23 19:56:08	2019-07-23	17	[{"id_menu":4,"count":1}]	76	pick-up	0	17
5138	2019-07-23 20:12:39	2019-07-23	14	[{"id_menu":2,"count":1}]	184	pick-up	0	14
5139	2019-07-23 20:41:10	2019-07-23	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1632	pick-up	0	20
5140	2019-07-23 21:14:08	2019-07-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	788	delivery	5	28
5141	2019-07-23 21:47:06	2019-07-23	12	[{"id_menu":3,"count":1}]	285	pick-up	0	12
5142	2019-07-23 23:08:09	2019-07-23	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	2028	pick-up	0	35
5143	2019-07-23 23:43:20	2019-07-23	8	[{"id_menu":5,"count":1}]	2031	pick-up	0	8
5144	2019-07-23 23:58:33	2019-07-23	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	832	pick-up	0	43
5145	2019-07-24 00:25:36	2019-07-24	8	[{"id_menu":5,"count":2}]	356	pick-up	0	8
5146	2019-07-24 01:22:30	2019-07-24	9	[{"id_menu":6,"count":1}]	546	delivery	5	14
5147	2019-07-24 01:32:44	2019-07-24	9	[{"id_menu":7,"count":1}]	1017	delivery	5	14
5148	2019-07-24 01:47:39	2019-07-24	9	[{"id_menu":7,"count":1}]	764	delivery	5	14
5149	2019-07-24 01:48:22	2019-07-24	17	[{"id_menu":4,"count":1}]	2043	pick-up	0	17
5150	2019-07-24 02:03:31	2019-07-24	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1224	delivery	5	39
5151	2019-07-24 02:25:40	2019-07-24	17	[{"id_menu":4,"count":1}]	1659	pick-up	0	17
5152	2019-07-24 03:30:36	2019-07-24	17	[{"id_menu":4,"count":1}]	1922	delivery	5	22
5153	2019-07-24 03:39:05	2019-07-24	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2048	delivery	5	40
5154	2019-07-24 04:32:33	2019-07-24	9	[{"id_menu":7,"count":1}]	1072	pick-up	0	9
5155	2019-07-24 04:44:55	2019-07-24	12	[{"id_menu":3,"count":1}]	213	delivery	5	17
5156	2019-07-24 04:52:37	2019-07-24	9	[{"id_menu":6,"count":1}]	719	pick-up	0	9
5157	2019-07-24 05:09:49	2019-07-24	12	[{"id_menu":1,"count":1}]	142	pick-up	0	12
5158	2019-07-24 05:46:05	2019-07-24	12	[{"id_menu":1,"count":1}]	2050	pick-up	0	12
5159	2019-07-24 06:22:16	2019-07-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2042	delivery	5	28
5160	2019-07-24 06:33:43	2019-07-24	14	[{"id_menu":2,"count":1}]	638	pick-up	0	14
5161	2019-07-24 06:36:36	2019-07-24	12	[{"id_menu":1,"count":1}]	1154	pick-up	0	12
5162	2019-07-24 06:47:03	2019-07-24	9	[{"id_menu":6,"count":1}]	1025	pick-up	0	9
5163	2019-07-24 07:00:57	2019-07-24	17	[{"id_menu":4,"count":1}]	2037	pick-up	0	17
5164	2019-07-24 07:03:26	2019-07-24	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1262	pick-up	0	25
5165	2019-07-24 07:52:23	2019-07-24	9	[{"id_menu":6,"count":1}]	2051	pick-up	0	9
5166	2019-07-24 08:09:46	2019-07-24	14	[{"id_menu":2,"count":1}]	2039	pick-up	0	14
5167	2019-07-24 08:35:53	2019-07-24	14	[{"id_menu":2,"count":1}]	679	delivery	5	19
5168	2019-07-24 09:25:00	2019-07-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1776	delivery	5	28
5169	2019-07-24 10:37:25	2019-07-24	8	[{"id_menu":5,"count":1}]	2046	pick-up	0	8
5170	2019-07-24 11:31:43	2019-07-24	9	[{"id_menu":7,"count":2}]	350	pick-up	0	9
5171	2019-07-24 11:56:17	2019-07-24	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	236	pick-up	0	21
5172	2019-07-24 12:17:03	2019-07-24	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	2040	delivery	5	43
5173	2019-07-24 12:26:00	2019-07-24	17	[{"id_menu":4,"count":1}]	1036	pick-up	0	17
5174	2019-07-24 13:16:27	2019-07-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	886	delivery	5	31
5175	2019-07-24 13:19:20	2019-07-24	9	[{"id_menu":6,"count":1}]	2047	pick-up	0	9
5176	2019-07-24 13:21:44	2019-07-24	14	[{"id_menu":2,"count":1}]	1536	delivery	5	19
5177	2019-07-24 14:15:37	2019-07-24	8	[{"id_menu":5,"count":1}]	2041	pick-up	0	8
5178	2019-07-24 15:53:40	2019-07-24	8	[{"id_menu":5,"count":1}]	2044	pick-up	0	8
5179	2019-07-24 16:02:07	2019-07-24	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2045	pick-up	0	21
5180	2019-07-24 16:31:29	2019-07-24	12	[{"id_menu":1,"count":1}]	1519	delivery	5	17
5181	2019-07-24 16:34:31	2019-07-24	14	[{"id_menu":2,"count":1}]	207	pick-up	0	14
5182	2019-07-24 18:00:21	2019-07-24	9	[{"id_menu":6,"count":1}]	1174	delivery	5	14
5183	2019-07-24 18:12:54	2019-07-24	9	[{"id_menu":7,"count":1}]	1065	pick-up	0	9
5184	2019-07-24 18:17:53	2019-07-24	9	[{"id_menu":7,"count":1}]	1480	pick-up	0	9
5185	2019-07-24 18:57:39	2019-07-24	8	[{"id_menu":5,"count":1}]	1677	pick-up	0	8
5186	2019-07-24 19:16:12	2019-07-24	9	[{"id_menu":6,"count":1}]	1463	pick-up	0	9
5187	2019-07-24 19:38:19	2019-07-24	14	[{"id_menu":2,"count":1}]	1053	pick-up	0	14
5188	2019-07-24 19:55:29	2019-07-24	17	[{"id_menu":4,"count":1}]	837	pick-up	0	17
5189	2019-07-24 20:04:12	2019-07-24	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	361	pick-up	0	25
5190	2019-07-24 20:21:31	2019-07-24	9	[{"id_menu":7,"count":1}]	660	pick-up	0	9
5191	2019-07-24 20:29:56	2019-07-24	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1900	pick-up	0	17
5192	2019-07-24 20:37:44	2019-07-24	9	[{"id_menu":6,"count":1}]	1021	delivery	5	14
5193	2019-07-24 20:54:51	2019-07-24	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1996	delivery	5	34
5194	2019-07-24 22:09:05	2019-07-24	17	[{"id_menu":4,"count":1}]	1742	pick-up	0	17
5195	2019-07-24 23:22:48	2019-07-24	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2049	delivery	5	36
5196	2019-07-25 00:33:02	2019-07-25	9	[{"id_menu":6,"count":1}]	1618	pick-up	0	9
5197	2019-07-25 00:54:09	2019-07-25	9	[{"id_menu":7,"count":1}]	528	delivery	5	14
5198	2019-07-25 00:56:57	2019-07-25	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	29	pick-up	0	23
5199	2019-07-25 01:09:16	2019-07-25	14	[{"id_menu":2,"count":1}]	2063	delivery	5	19
5200	2019-07-25 01:30:18	2019-07-25	9	[{"id_menu":7,"count":1}]	2058	pick-up	0	9
5201	2019-07-25 02:48:46	2019-07-25	9	[{"id_menu":6,"count":1}]	1192	delivery	5	14
5202	2019-07-25 03:18:58	2019-07-25	9	[{"id_menu":7,"count":1}]	511	pick-up	0	9
5203	2019-07-25 03:27:19	2019-07-25	12	[{"id_menu":1,"count":1}]	2053	pick-up	0	12
5204	2019-07-25 03:50:27	2019-07-25	17	[{"id_menu":4,"count":1}]	1463	pick-up	0	17
5205	2019-07-25 03:53:04	2019-07-25	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	2056	pick-up	0	23
5206	2019-07-25 04:07:50	2019-07-25	17	[{"id_menu":4,"count":1}]	980	delivery	5	22
5207	2019-07-25 04:27:03	2019-07-25	14	[{"id_menu":2,"count":1}]	314	pick-up	0	14
5208	2019-07-25 07:11:00	2019-07-25	9	[{"id_menu":7,"count":1}]	509	delivery	5	14
5209	2019-07-25 07:39:51	2019-07-25	12	[{"id_menu":3,"count":1}]	1241	delivery	5	17
5210	2019-07-25 07:47:11	2019-07-25	12	[{"id_menu":1,"count":1}]	136	pick-up	0	12
5211	2019-07-25 08:26:59	2019-07-25	14	[{"id_menu":2,"count":1}]	1727	pick-up	0	14
5212	2019-07-25 08:37:14	2019-07-25	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	256	pick-up	0	26
5213	2019-07-25 09:11:03	2019-07-25	17	[{"id_menu":4,"count":1}]	1592	delivery	5	22
5214	2019-07-25 09:15:06	2019-07-25	14	[{"id_menu":2,"count":1}]	1752	delivery	5	19
5215	2019-07-25 09:17:55	2019-07-25	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	2057	delivery	5	27
5216	2019-07-25 11:19:59	2019-07-25	9	[{"id_menu":6,"count":1}]	238	pick-up	0	9
5217	2019-07-25 11:23:36	2019-07-25	9	[{"id_menu":6,"count":1}]	660	pick-up	0	9
5218	2019-07-25 11:40:07	2019-07-25	8	[{"id_menu":5,"count":1}]	275	pick-up	0	8
5219	2019-07-25 11:50:11	2019-07-25	9	[{"id_menu":7,"count":1}]	964	delivery	5	14
5220	2019-07-25 12:13:59	2019-07-25	17	[{"id_menu":4,"count":1}]	486	pick-up	0	17
5221	2019-07-25 13:03:00	2019-07-25	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	88	pick-up	0	29
5222	2019-07-25 13:15:19	2019-07-25	9	[{"id_menu":6,"count":1}]	1490	pick-up	0	9
5223	2019-07-25 13:43:38	2019-07-25	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1836	delivery	5	22
5224	2019-07-25 13:54:37	2019-07-25	12	[{"id_menu":1,"count":1}]	724	delivery	5	17
5225	2019-07-25 14:02:18	2019-07-25	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	461	delivery	5	26
5226	2019-07-25 14:14:46	2019-07-25	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	1343	pick-up	0	18
5227	2019-07-25 15:31:52	2019-07-25	17	[{"id_menu":4,"count":1}]	299	delivery	5	22
5228	2019-07-25 16:27:22	2019-07-25	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	536	delivery	5	40
5229	2019-07-25 17:24:02	2019-07-25	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2003	pick-up	0	26
5230	2019-07-25 19:40:03	2019-07-25	17	[{"id_menu":4,"count":2}]	2000	pick-up	0	17
5231	2019-07-25 19:44:57	2019-07-25	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1245	delivery	5	45
5232	2019-07-25 20:10:03	2019-07-25	9	[{"id_menu":7,"count":1}]	1929	delivery	5	14
5233	2019-07-25 20:10:43	2019-07-25	9	[{"id_menu":6,"count":1}]	1889	pick-up	0	9
5234	2019-07-25 20:21:38	2019-07-25	12	[{"id_menu":3,"count":2}]	2054	pick-up	0	12
5235	2019-07-25 20:25:36	2019-07-25	9	[{"id_menu":6,"count":1}]	1208	pick-up	0	9
5236	2019-07-25 22:08:46	2019-07-25	9	[{"id_menu":6,"count":1}]	575	pick-up	0	9
5237	2019-07-25 22:11:54	2019-07-25	8	[{"id_menu":5,"count":2}]	2064	delivery	5	13
5238	2019-07-25 22:19:08	2019-07-25	14	[{"id_menu":2,"count":1}]	2055	pick-up	0	14
5239	2019-07-25 22:20:32	2019-07-25	8	[{"id_menu":5,"count":1}]	640	pick-up	0	8
5240	2019-07-25 22:39:59	2019-07-25	14	[{"id_menu":2,"count":1}]	1563	pick-up	0	14
5241	2019-07-25 22:59:47	2019-07-25	14	[{"id_menu":2,"count":1}]	2062	pick-up	0	14
5242	2019-07-25 23:11:06	2019-07-25	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1834	delivery	5	34
5243	2019-07-25 23:19:13	2019-07-25	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27	pick-up	0	32
5244	2019-07-25 23:38:16	2019-07-25	17	[{"id_menu":4,"count":1}]	2052	pick-up	0	17
5245	2019-07-26 01:30:44	2019-07-26	17	[{"id_menu":4,"count":1}]	158	pick-up	0	17
5246	2019-07-26 01:35:57	2019-07-26	12	[{"id_menu":3,"count":1}]	806	delivery	5	17
5247	2019-07-26 01:46:20	2019-07-26	9	[{"id_menu":7,"count":1}]	2068	pick-up	0	9
5248	2019-07-26 01:57:19	2019-07-26	12	[{"id_menu":1,"count":1}]	1562	delivery	5	17
5249	2019-07-26 02:04:26	2019-07-26	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2072	delivery	5	34
5250	2019-07-26 03:09:27	2019-07-26	12	[{"id_menu":1,"count":1}]	2073	delivery	5	17
5251	2019-07-26 03:16:39	2019-07-26	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	612	pick-up	0	43
5252	2019-07-26 03:35:40	2019-07-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	856	pick-up	0	21
5253	2019-07-26 03:43:57	2019-07-26	9	[{"id_menu":7,"count":1}]	2078	delivery	5	14
5254	2019-07-26 04:06:38	2019-07-26	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1732	pick-up	0	26
5255	2019-07-26 04:17:23	2019-07-26	12	[{"id_menu":1,"count":1}]	920	pick-up	0	12
5256	2019-07-26 05:18:48	2019-07-26	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1659	delivery	5	31
5257	2019-07-26 06:28:38	2019-07-26	9	[{"id_menu":6,"count":1}]	623	pick-up	0	9
5258	2019-07-26 06:37:04	2019-07-26	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	854	delivery	5	36
5259	2019-07-26 08:27:38	2019-07-26	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	2067	delivery	5	22
5260	2019-07-26 09:20:27	2019-07-26	9	[{"id_menu":7,"count":1}]	1273	pick-up	0	9
5261	2019-07-26 10:05:55	2019-07-26	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1464	delivery	5	31
5262	2019-07-26 10:10:14	2019-07-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1068	pick-up	0	23
5263	2019-07-26 11:35:26	2019-07-26	17	[{"id_menu":4,"count":1}]	1834	pick-up	0	17
5264	2019-07-26 11:37:04	2019-07-26	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	739	delivery	5	26
5265	2019-07-26 15:05:26	2019-07-26	17	[{"id_menu":4,"count":1}]	2064	pick-up	0	17
5266	2019-07-26 17:56:20	2019-07-26	9	[{"id_menu":7,"count":1}]	519	delivery	5	14
5267	2019-07-26 18:08:35	2019-07-26	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	486	pick-up	0	24
5268	2019-07-26 18:33:52	2019-07-26	9	[{"id_menu":6,"count":1}]	2079	pick-up	0	9
5269	2019-07-26 19:12:38	2019-07-26	14	[{"id_menu":2,"count":1}]	2077	delivery	5	19
5270	2019-07-26 19:13:43	2019-07-26	12	[{"id_menu":1,"count":1}]	1536	pick-up	0	12
5271	2019-07-26 19:19:33	2019-07-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2069	pick-up	0	18
5272	2019-07-26 20:49:26	2019-07-26	9	[{"id_menu":7,"count":1}]	2071	pick-up	0	9
5273	2019-07-26 21:04:32	2019-07-26	9	[{"id_menu":7,"count":1}]	546	delivery	5	14
5274	2019-07-26 21:45:48	2019-07-26	9	[{"id_menu":6,"count":1}]	2052	pick-up	0	9
5275	2019-07-26 21:54:07	2019-07-26	17	[{"id_menu":4,"count":1}]	2066	pick-up	0	17
5276	2019-07-26 22:10:24	2019-07-26	12	[{"id_menu":1,"count":1}]	1736	pick-up	0	12
5277	2019-07-27 00:24:36	2019-07-27	8	[{"id_menu":5,"count":2}]	207	pick-up	0	8
5278	2019-07-27 00:36:36	2019-07-27	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	608	pick-up	0	32
5279	2019-07-27 01:23:51	2019-07-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2080	pick-up	0	17
5280	2019-07-27 01:32:30	2019-07-27	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2092	delivery	5	26
5281	2019-07-27 02:04:05	2019-07-27	12	[{"id_menu":1,"count":1}]	581	delivery	5	17
5282	2019-07-27 02:40:29	2019-07-27	12	[{"id_menu":1,"count":1}]	1819	pick-up	0	12
5283	2019-07-27 02:45:44	2019-07-27	8	[{"id_menu":5,"count":1}]	2087	delivery	5	13
5284	2019-07-27 03:28:29	2019-07-27	14	[{"id_menu":2,"count":1}]	356	delivery	5	19
5285	2019-07-27 03:50:32	2019-07-27	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	1502	delivery	5	42
5286	2019-07-27 04:05:32	2019-07-27	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2094	pick-up	0	21
5287	2019-07-27 04:19:51	2019-07-27	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2088	delivery	5	31
5288	2019-07-27 05:18:03	2019-07-27	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1924	pick-up	0	40
5289	2019-07-27 05:23:52	2019-07-27	14	[{"id_menu":2,"count":1}]	466	delivery	5	19
5290	2019-07-27 05:29:23	2019-07-27	14	[{"id_menu":2,"count":2}]	378	pick-up	0	14
5291	2019-07-27 05:33:08	2019-07-27	17	[{"id_menu":4,"count":1}]	1597	pick-up	0	17
5292	2019-07-27 06:07:47	2019-07-27	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	797	pick-up	0	21
5293	2019-07-27 06:39:02	2019-07-27	12	[{"id_menu":3,"count":1}]	2089	delivery	5	17
5294	2019-07-27 06:43:47	2019-07-27	8	[{"id_menu":5,"count":2}]	203	delivery	5	13
5295	2019-07-27 06:50:16	2019-07-27	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1742	pick-up	0	30
5296	2019-07-27 06:50:33	2019-07-27	9	[{"id_menu":7,"count":1}]	2084	pick-up	0	9
5297	2019-07-27 07:04:15	2019-07-27	9	[{"id_menu":7,"count":1}]	729	pick-up	0	9
5298	2019-07-27 07:13:55	2019-07-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2085	pick-up	0	31
5299	2019-07-27 08:31:43	2019-07-27	17	[{"id_menu":4,"count":1}]	1809	pick-up	0	17
5300	2019-07-27 09:10:03	2019-07-27	17	[{"id_menu":4,"count":1}]	3	pick-up	0	17
5301	2019-07-27 10:53:15	2019-07-27	8	[{"id_menu":5,"count":1}]	343	pick-up	0	8
5302	2019-07-27 10:55:28	2019-07-27	17	[{"id_menu":4,"count":1}]	486	delivery	5	22
5303	2019-07-27 11:11:18	2019-07-27	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	2083	delivery	5	30
5304	2019-07-27 12:45:25	2019-07-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27	delivery	5	22
5305	2019-07-27 12:49:40	2019-07-27	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1079	delivery	5	31
5306	2019-07-27 13:01:50	2019-07-27	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	6	pick-up	0	20
5307	2019-07-27 13:30:42	2019-07-27	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	267	pick-up	0	24
5308	2019-07-27 13:32:04	2019-07-27	17	[{"id_menu":4,"count":1}]	543	pick-up	0	17
5309	2019-07-27 13:47:08	2019-07-27	9	[{"id_menu":6,"count":1}]	1766	delivery	5	14
5310	2019-07-27 14:03:29	2019-07-27	12	[{"id_menu":1,"count":1}]	170	pick-up	0	12
5311	2019-07-27 14:29:08	2019-07-27	9	[{"id_menu":6,"count":1}]	1736	delivery	5	14
5312	2019-07-27 15:01:47	2019-07-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	201	pick-up	0	31
5313	2019-07-27 15:10:32	2019-07-27	14	[{"id_menu":2,"count":1}]	2082	pick-up	0	14
5314	2019-07-27 15:27:06	2019-07-27	8	[{"id_menu":5,"count":1}]	2090	pick-up	0	8
5315	2019-07-27 16:00:31	2019-07-27	14	[{"id_menu":2,"count":1}]	799	pick-up	0	14
5316	2019-07-27 16:48:23	2019-07-27	17	[{"id_menu":4,"count":1}]	1034	delivery	5	22
5317	2019-07-27 16:54:58	2019-07-27	9	[{"id_menu":7,"count":1}]	1172	delivery	5	14
5318	2019-07-27 18:41:30	2019-07-27	8	[{"id_menu":5,"count":1}]	967	pick-up	0	8
5319	2019-07-27 20:01:31	2019-07-27	9	[{"id_menu":7,"count":1}]	189	pick-up	0	9
5320	2019-07-27 20:06:11	2019-07-27	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	482	delivery	5	31
5321	2019-07-27 20:12:48	2019-07-27	9	[{"id_menu":6,"count":1}]	74	pick-up	0	9
5322	2019-07-27 20:14:06	2019-07-27	12	[{"id_menu":1,"count":1}]	1758	delivery	5	17
5323	2019-07-27 20:24:23	2019-07-27	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2093	pick-up	0	29
5324	2019-07-27 21:04:01	2019-07-27	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1537	pick-up	0	22
5325	2019-07-27 21:08:11	2019-07-27	12	[{"id_menu":1,"count":1}]	1141	delivery	5	17
5326	2019-07-27 21:08:51	2019-07-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2081	delivery	5	22
5327	2019-07-27 21:41:02	2019-07-27	9	[{"id_menu":6,"count":1}]	242	delivery	5	14
5328	2019-07-27 22:14:10	2019-07-27	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1995	pick-up	0	20
5329	2019-07-27 22:43:02	2019-07-27	12	[{"id_menu":3,"count":1}]	1687	pick-up	0	12
5330	2019-07-27 23:04:59	2019-07-27	9	[{"id_menu":7,"count":2}]	930	delivery	5	14
5331	2019-07-27 23:05:51	2019-07-27	12	[{"id_menu":3,"count":1}]	320	pick-up	0	12
5332	2019-07-27 23:44:39	2019-07-27	9	[{"id_menu":7,"count":1}]	2086	pick-up	0	9
5333	2019-07-27 23:48:30	2019-07-27	8	[{"id_menu":5,"count":1}]	1934	delivery	5	13
5334	2019-07-28 00:24:00	2019-07-28	12	[{"id_menu":3,"count":1}]	1435	delivery	5	17
5335	2019-07-28 00:26:21	2019-07-28	9	[{"id_menu":7,"count":1}]	856	delivery	5	14
5336	2019-07-28 01:18:17	2019-07-28	12	[{"id_menu":1,"count":1}]	2098	delivery	5	17
5337	2019-07-28 01:57:42	2019-07-28	9	[{"id_menu":6,"count":1}]	103	pick-up	0	9
5338	2019-07-28 02:03:20	2019-07-28	17	[{"id_menu":4,"count":1}]	2104	delivery	5	22
5339	2019-07-28 02:15:26	2019-07-28	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	832	delivery	5	39
5340	2019-07-28 03:13:07	2019-07-28	8	[{"id_menu":5,"count":1}]	1509	delivery	5	13
5341	2019-07-28 03:21:02	2019-07-28	12	[{"id_menu":3,"count":1}]	1070	pick-up	0	12
5342	2019-07-28 03:27:52	2019-07-28	9	[{"id_menu":6,"count":1}]	844	delivery	5	14
5343	2019-07-28 03:27:52	2019-07-28	12	[{"id_menu":1,"count":1}]	2100	delivery	5	17
5344	2019-07-28 03:49:40	2019-07-28	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1667	pick-up	0	26
5345	2019-07-28 04:07:30	2019-07-28	12	[{"id_menu":1,"count":1}]	1183	delivery	5	17
5346	2019-07-28 04:21:09	2019-07-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	391	delivery	5	22
5347	2019-07-28 05:04:13	2019-07-28	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2097	pick-up	0	22
5348	2019-07-28 05:18:51	2019-07-28	9	[{"id_menu":6,"count":1}]	66	pick-up	0	9
5349	2019-07-28 05:44:19	2019-07-28	9	[{"id_menu":7,"count":1}]	708	delivery	5	14
5350	2019-07-28 05:52:20	2019-07-28	9	[{"id_menu":6,"count":1}]	462	delivery	5	14
5351	2019-07-28 06:44:21	2019-07-28	9	[{"id_menu":6,"count":2}]	586	pick-up	0	9
5352	2019-07-28 07:24:05	2019-07-28	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1233	delivery	5	34
5353	2019-07-28 07:43:47	2019-07-28	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	997	pick-up	0	30
5354	2019-07-28 07:51:20	2019-07-28	9	[{"id_menu":6,"count":1}]	850	delivery	5	14
5355	2019-07-28 08:13:23	2019-07-28	9	[{"id_menu":7,"count":1}]	61	pick-up	0	9
5356	2019-07-28 08:34:26	2019-07-28	12	[{"id_menu":3,"count":1}]	2076	pick-up	0	12
5357	2019-07-28 08:37:46	2019-07-28	9	[{"id_menu":7,"count":1}]	2095	pick-up	0	9
5358	2019-07-28 08:48:45	2019-07-28	12	[{"id_menu":1,"count":1}]	1537	pick-up	0	12
5359	2019-07-28 09:27:47	2019-07-28	9	[{"id_menu":6,"count":1}]	2102	pick-up	0	9
5360	2019-07-28 10:56:36	2019-07-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	962	delivery	5	22
5361	2019-07-28 11:51:09	2019-07-28	12	[{"id_menu":1,"count":1}]	1055	delivery	5	17
5362	2019-07-28 11:52:12	2019-07-28	14	[{"id_menu":2,"count":1}]	1054	delivery	5	19
5363	2019-07-28 14:01:57	2019-07-28	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2099	pick-up	0	20
5364	2019-07-28 14:55:56	2019-07-28	17	[{"id_menu":4,"count":1}]	525	delivery	5	22
5365	2019-07-28 15:16:59	2019-07-28	14	[{"id_menu":2,"count":1}]	886	pick-up	0	14
5366	2019-07-28 15:31:48	2019-07-28	14	[{"id_menu":2,"count":2}]	2096	delivery	5	19
5367	2019-07-28 15:44:09	2019-07-28	14	[{"id_menu":2,"count":1}]	754	pick-up	0	14
5368	2019-07-28 15:47:55	2019-07-28	12	[{"id_menu":1,"count":1}]	1380	delivery	5	17
5369	2019-07-28 16:17:57	2019-07-28	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1375	pick-up	0	24
5370	2019-07-28 16:23:59	2019-07-28	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	519	pick-up	0	21
5371	2019-07-28 17:01:28	2019-07-28	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2103	pick-up	0	35
5372	2019-07-28 17:36:43	2019-07-28	8	[{"id_menu":5,"count":1}]	135	pick-up	0	8
5373	2019-07-28 18:02:18	2019-07-28	12	[{"id_menu":1,"count":1}]	1284	delivery	5	17
5374	2019-07-28 18:35:09	2019-07-28	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2105	delivery	5	57
5375	2019-07-28 18:50:37	2019-07-28	14	[{"id_menu":2,"count":1}]	2107	pick-up	0	14
5376	2019-07-28 19:31:18	2019-07-28	12	[{"id_menu":1,"count":1}]	511	delivery	5	17
5377	2019-07-28 19:41:22	2019-07-28	9	[{"id_menu":7,"count":1}]	483	delivery	5	14
5378	2019-07-28 20:39:37	2019-07-28	12	[{"id_menu":1,"count":1}]	1700	delivery	5	17
5379	2019-07-28 20:45:13	2019-07-28	14	[{"id_menu":2,"count":1}]	2109	delivery	5	19
5380	2019-07-28 20:53:44	2019-07-28	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	612	pick-up	0	23
5381	2019-07-28 20:57:26	2019-07-28	12	[{"id_menu":3,"count":1}]	748	delivery	5	17
5382	2019-07-28 21:27:05	2019-07-28	9	[{"id_menu":6,"count":2}]	1142	delivery	5	14
5383	2019-07-28 22:05:02	2019-07-28	14	[{"id_menu":2,"count":1}]	2101	delivery	5	19
5384	2019-07-28 22:36:23	2019-07-28	9	[{"id_menu":7,"count":1}]	579	delivery	5	14
5385	2019-07-28 22:46:43	2019-07-28	12	[{"id_menu":3,"count":1}]	946	pick-up	0	12
5386	2019-07-28 22:49:06	2019-07-28	12	[{"id_menu":1,"count":1}]	2106	pick-up	0	12
5387	2019-07-28 23:02:42	2019-07-28	9	[{"id_menu":6,"count":1}]	2108	delivery	5	14
5388	2019-07-28 23:06:19	2019-07-28	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	543	delivery	5	39
5389	2019-07-28 23:18:43	2019-07-28	14	[{"id_menu":2,"count":1}]	1576	pick-up	0	14
5390	2019-07-29 00:33:11	2019-07-29	14	[{"id_menu":2,"count":1}]	2123	delivery	5	19
5391	2019-07-29 00:50:06	2019-07-29	9	[{"id_menu":7,"count":1}]	372	pick-up	0	9
5392	2019-07-29 01:26:05	2019-07-29	14	[{"id_menu":2,"count":1}]	1674	pick-up	0	14
5393	2019-07-29 01:50:43	2019-07-29	8	[{"id_menu":5,"count":1}]	228	delivery	5	13
5394	2019-07-29 06:03:29	2019-07-29	9	[{"id_menu":6,"count":1}]	2112	pick-up	0	9
5395	2019-07-29 07:33:40	2019-07-29	9	[{"id_menu":7,"count":1}]	688	delivery	5	14
5396	2019-07-29 07:41:19	2019-07-29	14	[{"id_menu":2,"count":1}]	536	delivery	5	19
5397	2019-07-29 08:45:04	2019-07-29	17	[{"id_menu":4,"count":1}]	1815	pick-up	0	17
5398	2019-07-29 08:52:31	2019-07-29	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	2118	pick-up	0	20
5399	2019-07-29 09:01:24	2019-07-29	14	[{"id_menu":2,"count":1}]	547	pick-up	0	14
5400	2019-07-29 09:12:28	2019-07-29	9	[{"id_menu":6,"count":1}]	2117	pick-up	0	9
5401	2019-07-29 10:13:34	2019-07-29	12	[{"id_menu":1,"count":1}]	1654	pick-up	0	12
5402	2019-07-29 10:56:59	2019-07-29	12	[{"id_menu":3,"count":1}]	1720	delivery	5	17
5403	2019-07-29 11:35:21	2019-07-29	17	[{"id_menu":4,"count":1}]	1429	pick-up	0	17
5404	2019-07-29 13:11:09	2019-07-29	9	[{"id_menu":7,"count":1}]	1334	delivery	5	14
5405	2019-07-29 15:58:57	2019-07-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2120	delivery	5	28
5406	2019-07-29 16:04:47	2019-07-29	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2115	pick-up	0	21
5407	2019-07-29 16:31:57	2019-07-29	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2110	pick-up	0	26
5408	2019-07-29 17:46:04	2019-07-29	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1834	pick-up	0	43
5409	2019-07-29 18:00:03	2019-07-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1800	pick-up	0	17
5410	2019-07-29 18:17:06	2019-07-29	9	[{"id_menu":6,"count":1}]	197	delivery	5	14
5411	2019-07-29 18:53:41	2019-07-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1424	delivery	5	26
5412	2019-07-29 18:54:56	2019-07-29	14	[{"id_menu":2,"count":1}]	285	pick-up	0	14
5413	2019-07-29 18:55:06	2019-07-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1557	pick-up	0	23
5414	2019-07-29 19:13:14	2019-07-29	8	[{"id_menu":5,"count":1}]	381	pick-up	0	8
5415	2019-07-29 19:29:39	2019-07-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	566	pick-up	0	26
5416	2019-07-29 19:36:49	2019-07-29	8	[{"id_menu":5,"count":1}]	2121	delivery	5	13
5417	2019-07-29 21:12:45	2019-07-29	9	[{"id_menu":6,"count":1}]	2041	pick-up	0	9
5418	2019-07-29 22:31:45	2019-07-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1988	pick-up	0	21
5419	2019-07-29 22:31:53	2019-07-29	17	[{"id_menu":4,"count":2}]	691	pick-up	0	17
5420	2019-07-29 22:49:54	2019-07-29	8	[{"id_menu":5,"count":1}]	599	delivery	5	13
5421	2019-07-29 23:18:23	2019-07-29	9	[{"id_menu":6,"count":2}]	281	pick-up	0	9
5422	2019-07-30 00:07:40	2019-07-30	9	[{"id_menu":7,"count":1}]	673	delivery	5	14
5423	2019-07-30 00:14:59	2019-07-30	9	[{"id_menu":6,"count":1}]	1170	pick-up	0	9
5424	2019-07-30 01:21:50	2019-07-30	14	[{"id_menu":2,"count":1}]	2132	delivery	5	19
5425	2019-07-30 01:31:19	2019-07-30	9	[{"id_menu":6,"count":1}]	1132	delivery	5	14
5426	2019-07-30 03:25:37	2019-07-30	9	[{"id_menu":7,"count":1}]	228	pick-up	0	9
5427	2019-07-30 03:44:27	2019-07-30	12	[{"id_menu":3,"count":1}]	778	pick-up	0	12
5428	2019-07-30 03:48:04	2019-07-30	9	[{"id_menu":7,"count":1}]	2129	delivery	5	14
5429	2019-07-30 04:58:04	2019-07-30	9	[{"id_menu":7,"count":1}]	1889	delivery	5	14
5430	2019-07-30 05:41:41	2019-07-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	360	pick-up	0	18
5431	2019-07-30 05:56:28	2019-07-30	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1638	delivery	5	53
5432	2019-07-30 06:08:04	2019-07-30	12	[{"id_menu":1,"count":1}]	1442	pick-up	0	12
5433	2019-07-30 06:16:00	2019-07-30	17	[{"id_menu":4,"count":1}]	170	pick-up	0	17
5434	2019-07-30 06:30:37	2019-07-30	9	[{"id_menu":6,"count":1}]	980	pick-up	0	9
5435	2019-07-30 08:30:43	2019-07-30	8	[{"id_menu":5,"count":1}]	171	delivery	5	13
5436	2019-07-30 08:56:04	2019-07-30	9	[{"id_menu":7,"count":1}]	1334	delivery	5	14
5437	2019-07-30 09:49:18	2019-07-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	763	pick-up	0	26
5438	2019-07-30 09:50:06	2019-07-30	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	437	delivery	5	52
5439	2019-07-30 11:20:21	2019-07-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2135	pick-up	0	17
5440	2019-07-30 11:38:57	2019-07-30	9	[{"id_menu":7,"count":1}]	1765	pick-up	0	9
5441	2019-07-30 11:58:43	2019-07-30	14	[{"id_menu":2,"count":1}]	1596	pick-up	0	14
5442	2019-07-30 12:20:03	2019-07-30	12	[{"id_menu":1,"count":1}]	820	pick-up	0	12
5443	2019-07-30 14:24:57	2019-07-30	14	[{"id_menu":2,"count":1}]	1563	pick-up	0	14
5444	2019-07-30 14:29:54	2019-07-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	2127	delivery	5	28
5445	2019-07-30 14:37:17	2019-07-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	158	delivery	5	28
5446	2019-07-30 15:52:28	2019-07-30	14	[{"id_menu":2,"count":1}]	1564	pick-up	0	14
5447	2019-07-30 16:22:57	2019-07-30	12	[{"id_menu":1,"count":1}]	1173	delivery	5	17
5448	2019-07-30 16:24:09	2019-07-30	17	[{"id_menu":4,"count":1}]	2124	pick-up	0	17
5449	2019-07-30 16:31:12	2019-07-30	9	[{"id_menu":7,"count":1}]	431	pick-up	0	9
5450	2019-07-30 17:31:58	2019-07-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2130	pick-up	0	26
5451	2019-07-30 18:16:28	2019-07-30	12	[{"id_menu":3,"count":1}]	128	pick-up	0	12
5452	2019-07-30 18:17:47	2019-07-30	9	[{"id_menu":6,"count":1}]	1631	pick-up	0	9
5453	2019-07-30 18:17:51	2019-07-30	9	[{"id_menu":7,"count":1}]	1148	pick-up	0	9
5454	2019-07-30 18:33:42	2019-07-30	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1834	pick-up	0	17
5455	2019-07-30 18:38:28	2019-07-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1108	delivery	5	31
5456	2019-07-30 18:40:55	2019-07-30	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	1344	pick-up	0	23
5457	2019-07-30 18:50:34	2019-07-30	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	708	pick-up	0	20
5458	2019-07-30 19:49:47	2019-07-30	14	[{"id_menu":2,"count":1}]	1653	pick-up	0	14
5459	2019-07-30 20:45:57	2019-07-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1025	delivery	5	28
5460	2019-07-30 21:29:36	2019-07-30	14	[{"id_menu":2,"count":1}]	2131	delivery	5	19
5461	2019-07-30 22:39:43	2019-07-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	195	delivery	5	31
5462	2019-07-30 23:42:27	2019-07-30	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	2133	delivery	5	31
5463	2019-07-31 00:14:41	2019-07-31	17	[{"id_menu":4,"count":1}]	1468	pick-up	0	17
5464	2019-07-31 00:21:09	2019-07-31	17	[{"id_menu":4,"count":1}]	396	pick-up	0	17
5465	2019-07-31 00:38:49	2019-07-31	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	440	delivery	5	34
5466	2019-07-31 00:39:24	2019-07-31	12	[{"id_menu":1,"count":1}]	1376	delivery	5	17
5467	2019-07-31 01:05:14	2019-07-31	9	[{"id_menu":6,"count":1}]	2139	pick-up	0	9
5468	2019-07-31 01:19:57	2019-07-31	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2149	pick-up	0	23
5469	2019-07-31 01:44:59	2019-07-31	9	[{"id_menu":7,"count":1}]	65	pick-up	0	9
5470	2019-07-31 01:54:47	2019-07-31	9	[{"id_menu":6,"count":1}]	1700	pick-up	0	9
5471	2019-07-31 02:05:03	2019-07-31	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	2148	delivery	5	28
5472	2019-07-31 02:09:24	2019-07-31	17	[{"id_menu":4,"count":1}]	2065	delivery	5	22
5473	2019-07-31 04:21:20	2019-07-31	12	[{"id_menu":3,"count":1}]	1759	delivery	5	17
5474	2019-07-31 04:23:50	2019-07-31	9	[{"id_menu":7,"count":1}]	2150	pick-up	0	9
5475	2019-07-31 04:33:23	2019-07-31	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1612	pick-up	0	26
5476	2019-07-31 04:50:42	2019-07-31	9	[{"id_menu":6,"count":2}]	471	delivery	5	14
5477	2019-07-31 04:53:06	2019-07-31	12	[{"id_menu":1,"count":1}]	153	pick-up	0	12
5478	2019-07-31 05:26:58	2019-07-31	12	[{"id_menu":3,"count":1}]	2146	pick-up	0	12
5479	2019-07-31 05:57:15	2019-07-31	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2143	pick-up	0	29
5480	2019-07-31 07:04:02	2019-07-31	17	[{"id_menu":4,"count":1}]	2137	delivery	5	22
5481	2019-07-31 07:06:57	2019-07-31	9	[{"id_menu":7,"count":1}]	777	delivery	5	14
5482	2019-07-31 08:10:44	2019-07-31	17	[{"id_menu":4,"count":1}]	286	pick-up	0	17
5483	2019-07-31 08:31:12	2019-07-31	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2121	delivery	5	43
5484	2019-07-31 08:34:45	2019-07-31	14	[{"id_menu":2,"count":1}]	2083	pick-up	0	14
5485	2019-07-31 08:41:22	2019-07-31	17	[{"id_menu":4,"count":1}]	626	delivery	5	22
5486	2019-07-31 09:05:17	2019-07-31	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	709	pick-up	0	17
5487	2019-07-31 09:06:49	2019-07-31	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	1460	pick-up	0	40
5488	2019-07-31 10:24:24	2019-07-31	12	[{"id_menu":1,"count":1}]	2144	pick-up	0	12
5489	2019-07-31 11:19:01	2019-07-31	8	[{"id_menu":5,"count":1}]	2077	delivery	5	13
5490	2019-07-31 11:46:47	2019-07-31	14	[{"id_menu":2,"count":1}]	2096	pick-up	0	14
5491	2019-07-31 11:59:02	2019-07-31	12	[{"id_menu":1,"count":1}]	2138	pick-up	0	12
5492	2019-07-31 12:17:31	2019-07-31	17	[{"id_menu":4,"count":1}]	1375	pick-up	0	17
5493	2019-07-31 12:31:40	2019-07-31	17	[{"id_menu":4,"count":1}]	2145	delivery	5	22
5494	2019-07-31 13:16:33	2019-07-31	14	[{"id_menu":2,"count":1}]	2142	pick-up	0	14
5495	2019-07-31 13:26:39	2019-07-31	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1804	pick-up	0	21
5496	2019-07-31 13:28:22	2019-07-31	14	[{"id_menu":2,"count":1}]	1638	delivery	5	19
5497	2019-07-31 13:35:14	2019-07-31	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1233	pick-up	0	26
5498	2019-07-31 15:47:43	2019-07-31	12	[{"id_menu":3,"count":1}]	1707	pick-up	0	12
5499	2019-07-31 15:52:23	2019-07-31	17	[{"id_menu":4,"count":1}]	52	pick-up	0	17
5500	2019-07-31 15:54:37	2019-07-31	12	[{"id_menu":1,"count":1}]	1020	delivery	5	17
5501	2019-07-31 15:59:24	2019-07-31	12	[{"id_menu":3,"count":1}]	2140	pick-up	0	12
5502	2019-07-31 16:54:03	2019-07-31	12	[{"id_menu":3,"count":1}]	669	pick-up	0	12
5503	2019-07-31 16:59:20	2019-07-31	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	1269	delivery	5	43
5504	2019-07-31 18:12:23	2019-07-31	12	[{"id_menu":3,"count":1}]	1821	delivery	5	17
5505	2019-07-31 20:16:19	2019-07-31	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1965	pick-up	0	21
5506	2019-07-31 21:06:59	2019-07-31	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	710	delivery	5	31
5507	2019-07-31 22:01:41	2019-07-31	12	[{"id_menu":1,"count":1}]	248	delivery	5	17
5508	2019-07-31 22:23:57	2019-07-31	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1457	delivery	5	40
5509	2019-07-31 23:10:33	2019-07-31	8	[{"id_menu":5,"count":2}]	2147	delivery	5	13
5510	2019-07-31 23:24:58	2019-07-31	17	[{"id_menu":4,"count":2}]	882	pick-up	0	17
5511	2019-07-31 23:51:26	2019-07-31	12	[{"id_menu":1,"count":1}]	2141	delivery	5	17
5512	2019-08-01 00:21:19	2019-08-01	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2158	pick-up	0	22
5513	2019-08-01 02:01:03	2019-08-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	223	pick-up	0	17
5514	2019-08-01 02:09:52	2019-08-01	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	40	delivery	5	26
5515	2019-08-01 02:34:22	2019-08-01	12	[{"id_menu":1,"count":1}]	295	pick-up	0	12
5516	2019-08-01 02:51:08	2019-08-01	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	1457	delivery	5	23
5517	2019-08-01 03:24:24	2019-08-01	17	[{"id_menu":4,"count":1}]	612	pick-up	0	17
5518	2019-08-01 03:43:33	2019-08-01	9	[{"id_menu":7,"count":1}]	2161	pick-up	0	9
5519	2019-08-01 03:55:33	2019-08-01	8	[{"id_menu":5,"count":1}]	215	pick-up	0	8
5520	2019-08-01 04:33:30	2019-08-01	14	[{"id_menu":2,"count":1}]	2138	delivery	5	19
5521	2019-08-01 04:51:57	2019-08-01	9	[{"id_menu":6,"count":1}]	1724	delivery	5	14
5522	2019-08-01 04:56:18	2019-08-01	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1915	pick-up	0	24
5523	2019-08-01 05:06:22	2019-08-01	9	[{"id_menu":7,"count":1}]	1654	delivery	5	14
5524	2019-08-01 05:56:05	2019-08-01	9	[{"id_menu":6,"count":1}]	1460	pick-up	0	9
5525	2019-08-01 06:05:17	2019-08-01	14	[{"id_menu":2,"count":1}]	1865	pick-up	0	14
5526	2019-08-01 06:31:44	2019-08-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	539	pick-up	0	26
5527	2019-08-01 06:33:08	2019-08-01	14	[{"id_menu":2,"count":1}]	2156	pick-up	0	14
5528	2019-08-01 07:17:00	2019-08-01	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1359	pick-up	0	43
5529	2019-08-01 07:25:33	2019-08-01	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	820	pick-up	0	43
5530	2019-08-01 08:12:12	2019-08-01	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1176	pick-up	0	21
5531	2019-08-01 08:18:00	2019-08-01	14	[{"id_menu":2,"count":1}]	1627	pick-up	0	14
5532	2019-08-01 08:29:51	2019-08-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1594	delivery	5	28
5533	2019-08-01 08:44:54	2019-08-01	9	[{"id_menu":7,"count":1}]	2122	pick-up	0	9
5534	2019-08-01 10:05:30	2019-08-01	9	[{"id_menu":7,"count":1}]	2159	pick-up	0	9
5535	2019-08-01 10:11:45	2019-08-01	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2154	delivery	5	27
5536	2019-08-01 10:15:14	2019-08-01	17	[{"id_menu":4,"count":1}]	1693	pick-up	0	17
5537	2019-08-01 10:24:03	2019-08-01	8	[{"id_menu":5,"count":1}]	2152	pick-up	0	8
5538	2019-08-01 10:45:33	2019-08-01	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2160	pick-up	0	29
5539	2019-08-01 11:33:04	2019-08-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1685	pick-up	0	31
5540	2019-08-01 11:51:31	2019-08-01	9	[{"id_menu":6,"count":1}]	1815	pick-up	0	9
5541	2019-08-01 12:46:52	2019-08-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1239	pick-up	0	17
5542	2019-08-01 13:16:15	2019-08-01	14	[{"id_menu":2,"count":1}]	2164	delivery	5	19
5543	2019-08-01 13:16:45	2019-08-01	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2157	pick-up	0	20
5544	2019-08-01 14:09:13	2019-08-01	9	[{"id_menu":7,"count":1}]	997	pick-up	0	9
5545	2019-08-01 14:16:37	2019-08-01	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	371	delivery	5	44
5546	2019-08-01 14:46:08	2019-08-01	14	[{"id_menu":2,"count":1}]	1901	pick-up	0	14
5547	2019-08-01 14:48:20	2019-08-01	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	197	pick-up	0	26
5548	2019-08-01 15:47:05	2019-08-01	17	[{"id_menu":4,"count":1}]	1013	delivery	5	22
5549	2019-08-01 15:47:11	2019-08-01	9	[{"id_menu":7,"count":1}]	506	pick-up	0	9
5550	2019-08-01 16:56:26	2019-08-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2153	delivery	5	28
5551	2019-08-01 17:00:10	2019-08-01	9	[{"id_menu":6,"count":1}]	292	delivery	5	14
5552	2019-08-01 18:02:20	2019-08-01	12	[{"id_menu":3,"count":1}]	1731	pick-up	0	12
5553	2019-08-01 18:29:16	2019-08-01	9	[{"id_menu":6,"count":1}]	230	delivery	5	14
5554	2019-08-01 18:46:32	2019-08-01	9	[{"id_menu":7,"count":1}]	2163	delivery	5	14
5555	2019-08-01 19:01:00	2019-08-01	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	455	delivery	5	40
5556	2019-08-01 19:10:11	2019-08-01	12	[{"id_menu":1,"count":1}]	722	delivery	5	17
5557	2019-08-01 21:14:33	2019-08-01	17	[{"id_menu":4,"count":1}]	2151	pick-up	0	17
5558	2019-08-01 21:31:56	2019-08-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2119	pick-up	0	23
5559	2019-08-01 21:41:31	2019-08-01	9	[{"id_menu":7,"count":1}]	1123	pick-up	0	9
5560	2019-08-01 22:01:29	2019-08-01	9	[{"id_menu":7,"count":1}]	2162	pick-up	0	9
5561	2019-08-01 22:44:59	2019-08-01	9	[{"id_menu":7,"count":1}]	926	pick-up	0	9
5562	2019-08-01 23:00:59	2019-08-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1427	pick-up	0	31
5563	2019-08-01 23:27:10	2019-08-01	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1879	delivery	5	31
5564	2019-08-01 23:46:29	2019-08-01	12	[{"id_menu":1,"count":1}]	1922	pick-up	0	12
5565	2019-08-01 23:54:31	2019-08-01	9	[{"id_menu":6,"count":1}]	2089	delivery	5	14
5566	2019-08-02 00:52:41	2019-08-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	184	pick-up	0	23
5567	2019-08-02 00:55:55	2019-08-02	12	[{"id_menu":1,"count":1}]	382	pick-up	0	12
5568	2019-08-02 01:02:31	2019-08-02	9	[{"id_menu":6,"count":1}]	678	pick-up	0	9
5569	2019-08-02 01:09:23	2019-08-02	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1269	delivery	5	28
5570	2019-08-02 01:19:58	2019-08-02	9	[{"id_menu":7,"count":1}]	721	pick-up	0	9
5571	2019-08-02 01:59:06	2019-08-02	9	[{"id_menu":6,"count":1}]	337	pick-up	0	9
5572	2019-08-02 02:33:06	2019-08-02	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1464	delivery	5	26
5573	2019-08-02 02:33:47	2019-08-02	14	[{"id_menu":2,"count":1}]	806	delivery	5	19
5574	2019-08-02 02:56:06	2019-08-02	9	[{"id_menu":6,"count":1}]	2176	pick-up	0	9
5575	2019-08-02 03:09:50	2019-08-02	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1537	pick-up	0	31
5576	2019-08-02 03:11:16	2019-08-02	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	1933	pick-up	0	29
5577	2019-08-02 03:39:18	2019-08-02	9	[{"id_menu":7,"count":1}]	467	pick-up	0	9
5578	2019-08-02 03:59:45	2019-08-02	12	[{"id_menu":1,"count":1}]	1827	pick-up	0	12
5579	2019-08-02 05:09:38	2019-08-02	17	[{"id_menu":4,"count":1}]	1380	delivery	5	22
5580	2019-08-02 06:18:41	2019-08-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1400	pick-up	0	26
5581	2019-08-02 06:58:10	2019-08-02	9	[{"id_menu":7,"count":1}]	586	delivery	5	14
5582	2019-08-02 07:01:49	2019-08-02	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	2165	pick-up	0	20
5583	2019-08-02 07:08:50	2019-08-02	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	981	pick-up	0	31
5584	2019-08-02 07:14:15	2019-08-02	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	464	delivery	5	31
5585	2019-08-02 08:16:19	2019-08-02	8	[{"id_menu":5,"count":1}]	2003	pick-up	0	8
5586	2019-08-02 08:16:35	2019-08-02	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1563	pick-up	0	29
5587	2019-08-02 08:20:42	2019-08-02	12	[{"id_menu":3,"count":1}]	1670	pick-up	0	12
5588	2019-08-02 08:37:12	2019-08-02	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2172	pick-up	0	21
5589	2019-08-02 09:01:35	2019-08-02	12	[{"id_menu":1,"count":1}]	519	pick-up	0	12
5590	2019-08-02 09:05:31	2019-08-02	17	[{"id_menu":4,"count":1}]	2173	pick-up	0	17
5591	2019-08-02 10:08:45	2019-08-02	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1685	delivery	5	25
5592	2019-08-02 10:13:03	2019-08-02	17	[{"id_menu":4,"count":1}]	2166	delivery	5	22
5593	2019-08-02 10:33:25	2019-08-02	17	[{"id_menu":4,"count":1}]	2170	pick-up	0	17
5594	2019-08-02 11:28:27	2019-08-02	17	[{"id_menu":4,"count":1}]	1988	pick-up	0	17
5595	2019-08-02 12:42:43	2019-08-02	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	653	delivery	5	26
5596	2019-08-02 12:57:57	2019-08-02	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	62	pick-up	0	21
5597	2019-08-02 14:42:11	2019-08-02	14	[{"id_menu":2,"count":1}]	1375	delivery	5	19
5598	2019-08-02 15:26:54	2019-08-02	14	[{"id_menu":2,"count":1}]	973	pick-up	0	14
5599	2019-08-02 15:35:00	2019-08-02	12	[{"id_menu":1,"count":1}]	2168	delivery	5	17
5600	2019-08-02 16:02:17	2019-08-02	17	[{"id_menu":4,"count":1}]	348	delivery	5	22
5601	2019-08-02 17:39:51	2019-08-02	9	[{"id_menu":6,"count":1}]	1987	delivery	5	14
5602	2019-08-02 20:26:56	2019-08-02	12	[{"id_menu":3,"count":1}]	1797	delivery	5	17
5603	2019-08-02 22:21:58	2019-08-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2177	pick-up	0	17
5604	2019-08-02 23:24:29	2019-08-02	9	[{"id_menu":7,"count":1}]	543	pick-up	0	9
5605	2019-08-03 00:10:01	2019-08-03	9	[{"id_menu":7,"count":1}]	1562	pick-up	0	9
5606	2019-08-03 01:02:24	2019-08-03	17	[{"id_menu":4,"count":1}]	709	pick-up	0	17
5607	2019-08-03 01:34:36	2019-08-03	14	[{"id_menu":2,"count":1}]	1385	pick-up	0	14
5608	2019-08-03 01:38:34	2019-08-03	8	[{"id_menu":5,"count":1}]	1266	pick-up	0	8
5609	2019-08-03 01:40:42	2019-08-03	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2190	pick-up	0	38
5610	2019-08-03 01:51:49	2019-08-03	9	[{"id_menu":6,"count":1}]	1607	delivery	5	14
5611	2019-08-03 01:58:28	2019-08-03	14	[{"id_menu":2,"count":1}]	671	delivery	5	19
5612	2019-08-03 02:04:34	2019-08-03	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	83	pick-up	0	25
5613	2019-08-03 03:28:46	2019-08-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1531	pick-up	0	23
5614	2019-08-03 05:01:24	2019-08-03	8	[{"id_menu":5,"count":1}]	1754	delivery	5	13
5615	2019-08-03 05:03:19	2019-08-03	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	972	delivery	5	31
5616	2019-08-03 05:52:34	2019-08-03	12	[{"id_menu":3,"count":1}]	950	pick-up	0	12
5617	2019-08-03 07:12:20	2019-08-03	9	[{"id_menu":7,"count":1}]	2180	pick-up	0	9
5618	2019-08-03 07:24:02	2019-08-03	12	[{"id_menu":3,"count":1}]	223	pick-up	0	12
5619	2019-08-03 07:52:23	2019-08-03	14	[{"id_menu":2,"count":1}]	352	pick-up	0	14
5620	2019-08-03 08:29:57	2019-08-03	17	[{"id_menu":4,"count":1}]	2194	pick-up	0	17
5621	2019-08-03 09:18:29	2019-08-03	14	[{"id_menu":2,"count":1}]	1068	pick-up	0	14
5622	2019-08-03 09:35:14	2019-08-03	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1123	delivery	5	25
5623	2019-08-03 09:37:03	2019-08-03	14	[{"id_menu":2,"count":1}]	156	pick-up	0	14
5624	2019-08-03 09:42:50	2019-08-03	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1992	pick-up	0	17
5625	2019-08-03 09:43:13	2019-08-03	9	[{"id_menu":6,"count":1}]	1352	pick-up	0	9
5626	2019-08-03 09:48:12	2019-08-03	9	[{"id_menu":6,"count":1}]	1820	delivery	5	14
5627	2019-08-03 10:21:24	2019-08-03	9	[{"id_menu":6,"count":1}]	2185	pick-up	0	9
5628	2019-08-03 10:41:50	2019-08-03	12	[{"id_menu":1,"count":1}]	1271	pick-up	0	12
5629	2019-08-03 11:18:18	2019-08-03	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2196	pick-up	0	17
5630	2019-08-03 11:22:16	2019-08-03	9	[{"id_menu":6,"count":1}]	478	delivery	5	14
5631	2019-08-03 12:17:04	2019-08-03	17	[{"id_menu":4,"count":1}]	2195	delivery	5	22
5632	2019-08-03 12:23:21	2019-08-03	14	[{"id_menu":2,"count":1}]	2192	delivery	5	19
5633	2019-08-03 13:23:19	2019-08-03	12	[{"id_menu":1,"count":1}]	1327	pick-up	0	12
5634	2019-08-03 14:09:37	2019-08-03	9	[{"id_menu":7,"count":1}]	1765	delivery	5	14
5635	2019-08-03 14:11:57	2019-08-03	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1693	delivery	5	31
5636	2019-08-03 14:15:12	2019-08-03	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1103	pick-up	0	29
5637	2019-08-03 14:35:28	2019-08-03	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	915	delivery	5	34
5638	2019-08-03 15:17:55	2019-08-03	14	[{"id_menu":2,"count":1}]	402	delivery	5	19
5639	2019-08-03 16:15:42	2019-08-03	17	[{"id_menu":4,"count":1}]	546	delivery	5	22
5640	2019-08-03 16:28:34	2019-08-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2191	delivery	5	31
5641	2019-08-03 16:36:19	2019-08-03	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	2173	pick-up	0	29
5642	2019-08-03 16:50:52	2019-08-03	12	[{"id_menu":1,"count":1}]	2184	delivery	5	17
5643	2019-08-03 17:04:09	2019-08-03	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2193	delivery	5	31
5644	2019-08-03 17:10:04	2019-08-03	17	[{"id_menu":4,"count":1}]	1241	pick-up	0	17
5645	2019-08-03 17:18:15	2019-08-03	9	[{"id_menu":7,"count":1}]	1968	pick-up	0	9
5646	2019-08-03 17:44:22	2019-08-03	14	[{"id_menu":2,"count":1}]	1115	pick-up	0	14
5647	2019-08-03 19:38:59	2019-08-03	9	[{"id_menu":7,"count":1}]	257	delivery	5	14
5648	2019-08-03 20:21:55	2019-08-03	14	[{"id_menu":2,"count":1}]	947	pick-up	0	14
5649	2019-08-03 20:22:10	2019-08-03	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1596	pick-up	0	29
5650	2019-08-03 20:36:09	2019-08-03	12	[{"id_menu":1,"count":1}]	832	pick-up	0	12
5651	2019-08-03 20:52:31	2019-08-03	14	[{"id_menu":2,"count":1}]	2105	pick-up	0	14
5652	2019-08-03 21:03:05	2019-08-03	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2182	delivery	5	37
5653	2019-08-03 21:12:03	2019-08-03	9	[{"id_menu":7,"count":1}]	2183	pick-up	0	9
5654	2019-08-03 21:17:48	2019-08-03	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2189	pick-up	0	20
5655	2019-08-03 21:21:32	2019-08-03	9	[{"id_menu":6,"count":1}]	786	pick-up	0	9
5656	2019-08-03 21:29:29	2019-08-03	14	[{"id_menu":2,"count":1}]	2186	pick-up	0	14
5657	2019-08-03 21:58:03	2019-08-03	12	[{"id_menu":1,"count":1}]	201	delivery	5	17
5658	2019-08-03 23:00:17	2019-08-03	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	461	delivery	5	31
5659	2019-08-03 23:22:07	2019-08-03	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	356	pick-up	0	20
5660	2019-08-03 23:24:31	2019-08-03	9	[{"id_menu":7,"count":1}]	37	pick-up	0	9
5661	2019-08-03 23:55:58	2019-08-03	12	[{"id_menu":1,"count":1}]	2187	delivery	5	17
5662	2019-08-04 00:04:02	2019-08-04	9	[{"id_menu":6,"count":1}]	873	delivery	5	14
5663	2019-08-04 00:16:58	2019-08-04	9	[{"id_menu":6,"count":1}]	911	pick-up	0	9
5664	2019-08-04 00:17:44	2019-08-04	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	315	pick-up	0	21
5665	2019-08-04 00:34:12	2019-08-04	14	[{"id_menu":2,"count":1}]	2212	pick-up	0	14
5666	2019-08-04 00:46:49	2019-08-04	8	[{"id_menu":5,"count":1}]	477	delivery	5	13
5667	2019-08-04 00:51:13	2019-08-04	9	[{"id_menu":6,"count":1}]	1670	pick-up	0	9
5668	2019-08-04 01:04:22	2019-08-04	12	[{"id_menu":3,"count":1}]	376	pick-up	0	12
5669	2019-08-04 01:24:39	2019-08-04	12	[{"id_menu":1,"count":1}]	2052	pick-up	0	12
5670	2019-08-04 01:37:15	2019-08-04	9	[{"id_menu":6,"count":1}]	1095	pick-up	0	9
5671	2019-08-04 01:48:47	2019-08-04	17	[{"id_menu":4,"count":1}]	2211	delivery	5	22
5672	2019-08-04 02:14:38	2019-08-04	12	[{"id_menu":1,"count":1}]	2203	pick-up	0	12
5673	2019-08-04 02:25:42	2019-08-04	17	[{"id_menu":4,"count":1}]	1596	pick-up	0	17
5674	2019-08-04 02:53:03	2019-08-04	38	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	635	delivery	5	43
5675	2019-08-04 03:02:14	2019-08-04	14	[{"id_menu":2,"count":1}]	1829	pick-up	0	14
5676	2019-08-04 03:09:47	2019-08-04	14	[{"id_menu":2,"count":1}]	111	pick-up	0	14
5677	2019-08-04 04:23:57	2019-08-04	8	[{"id_menu":5,"count":1}]	2198	delivery	5	13
5678	2019-08-04 04:30:15	2019-08-04	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1296	pick-up	0	23
5679	2019-08-04 04:54:54	2019-08-04	12	[{"id_menu":3,"count":1}]	2206	delivery	5	17
5680	2019-08-04 05:17:41	2019-08-04	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	708	pick-up	0	30
5681	2019-08-04 05:24:58	2019-08-04	12	[{"id_menu":1,"count":2}]	2197	pick-up	0	12
5682	2019-08-04 05:43:11	2019-08-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1208	pick-up	0	23
5683	2019-08-04 05:44:11	2019-08-04	12	[{"id_menu":3,"count":1}]	684	pick-up	0	12
5684	2019-08-04 07:04:05	2019-08-04	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	214	pick-up	0	24
5685	2019-08-04 07:09:19	2019-08-04	14	[{"id_menu":2,"count":1}]	584	delivery	5	19
5686	2019-08-04 08:29:04	2019-08-04	12	[{"id_menu":1,"count":1}]	993	delivery	5	17
5687	2019-08-04 08:38:19	2019-08-04	9	[{"id_menu":6,"count":2}]	126	delivery	5	14
5688	2019-08-04 08:51:46	2019-08-04	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2130	delivery	5	55
5689	2019-08-04 09:04:23	2019-08-04	9	[{"id_menu":6,"count":1}]	1280	delivery	5	14
5690	2019-08-04 09:28:38	2019-08-04	17	[{"id_menu":4,"count":1}]	2199	delivery	5	22
5691	2019-08-04 10:00:19	2019-08-04	12	[{"id_menu":1,"count":1}]	2083	pick-up	0	12
5692	2019-08-04 10:59:09	2019-08-04	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2021	pick-up	0	23
5693	2019-08-04 11:14:34	2019-08-04	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	68	pick-up	0	21
5694	2019-08-04 11:23:16	2019-08-04	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	310	pick-up	0	30
5695	2019-08-04 11:28:34	2019-08-04	8	[{"id_menu":5,"count":1}]	2202	pick-up	0	8
5696	2019-08-04 11:30:10	2019-08-04	12	[{"id_menu":1,"count":1}]	1677	pick-up	0	12
5697	2019-08-04 12:17:55	2019-08-04	17	[{"id_menu":4,"count":1}]	2209	delivery	5	22
5698	2019-08-04 12:23:55	2019-08-04	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	2123	delivery	5	25
5699	2019-08-04 12:24:11	2019-08-04	9	[{"id_menu":6,"count":1}]	2064	delivery	5	14
5700	2019-08-04 12:57:43	2019-08-04	12	[{"id_menu":1,"count":1}]	1353	delivery	5	17
5701	2019-08-04 13:33:17	2019-08-04	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	871	delivery	5	26
5702	2019-08-04 13:48:17	2019-08-04	12	[{"id_menu":3,"count":1}]	1315	delivery	5	17
5703	2019-08-04 14:06:48	2019-08-04	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	391	delivery	5	37
5704	2019-08-04 14:10:36	2019-08-04	9	[{"id_menu":7,"count":1}]	2210	delivery	5	14
5705	2019-08-04 14:22:55	2019-08-04	9	[{"id_menu":6,"count":1}]	2189	pick-up	0	9
5706	2019-08-04 14:36:34	2019-08-04	17	[{"id_menu":4,"count":1}]	1592	pick-up	0	17
5707	2019-08-04 14:44:45	2019-08-04	17	[{"id_menu":4,"count":1}]	1969	pick-up	0	17
5708	2019-08-04 15:03:58	2019-08-04	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	2208	delivery	5	28
5709	2019-08-04 15:31:53	2019-08-04	14	[{"id_menu":2,"count":1}]	799	pick-up	0	14
5710	2019-08-04 15:37:51	2019-08-04	9	[{"id_menu":7,"count":1}]	2139	pick-up	0	9
5711	2019-08-04 15:54:26	2019-08-04	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	677	pick-up	0	21
5712	2019-08-04 16:08:37	2019-08-04	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1793	delivery	5	25
5713	2019-08-04 16:42:21	2019-08-04	12	[{"id_menu":3,"count":1}]	1559	pick-up	0	12
5714	2019-08-04 16:57:14	2019-08-04	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	805	pick-up	0	26
5715	2019-08-04 17:15:17	2019-08-04	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1309	pick-up	0	32
5716	2019-08-04 17:25:35	2019-08-04	9	[{"id_menu":7,"count":1}]	474	delivery	5	14
5717	2019-08-04 17:38:20	2019-08-04	9	[{"id_menu":6,"count":1}]	1987	delivery	5	14
5718	2019-08-04 17:52:46	2019-08-04	9	[{"id_menu":6,"count":1}]	356	delivery	5	14
5719	2019-08-04 17:53:06	2019-08-04	14	[{"id_menu":2,"count":1}]	640	delivery	5	19
5720	2019-08-04 18:06:10	2019-08-04	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2201	pick-up	0	25
5721	2019-08-04 18:12:59	2019-08-04	17	[{"id_menu":4,"count":1}]	1900	pick-up	0	17
5722	2019-08-04 18:43:00	2019-08-04	17	[{"id_menu":4,"count":1}]	915	delivery	5	22
5723	2019-08-04 18:49:58	2019-08-04	9	[{"id_menu":6,"count":1}]	1795	pick-up	0	9
5724	2019-08-04 19:19:11	2019-08-04	12	[{"id_menu":1,"count":1}]	2205	pick-up	0	12
5725	2019-08-04 19:38:28	2019-08-04	14	[{"id_menu":2,"count":1}]	2204	delivery	5	19
5726	2019-08-04 19:40:50	2019-08-04	14	[{"id_menu":2,"count":1}]	482	delivery	5	19
5727	2019-08-04 19:51:36	2019-08-04	12	[{"id_menu":1,"count":1}]	1685	pick-up	0	12
5728	2019-08-04 20:39:16	2019-08-04	14	[{"id_menu":2,"count":1}]	1542	delivery	5	19
5729	2019-08-04 21:09:01	2019-08-04	12	[{"id_menu":1,"count":1}]	602	delivery	5	17
5730	2019-08-04 21:10:53	2019-08-04	9	[{"id_menu":6,"count":1}]	13	delivery	5	14
5731	2019-08-04 21:17:34	2019-08-04	17	[{"id_menu":4,"count":1}]	1344	pick-up	0	17
5732	2019-08-04 21:25:50	2019-08-04	17	[{"id_menu":4,"count":1}]	66	pick-up	0	17
5733	2019-08-04 21:27:48	2019-08-04	14	[{"id_menu":2,"count":1}]	2200	pick-up	0	14
5734	2019-08-04 21:45:32	2019-08-04	8	[{"id_menu":5,"count":1}]	1146	pick-up	0	8
5735	2019-08-04 22:20:38	2019-08-04	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1425	pick-up	0	26
5736	2019-08-04 22:34:23	2019-08-04	14	[{"id_menu":2,"count":2}]	2207	pick-up	0	14
5737	2019-08-04 22:45:17	2019-08-04	8	[{"id_menu":5,"count":1}]	690	delivery	5	13
5738	2019-08-05 02:43:50	2019-08-05	9	[{"id_menu":7,"count":1}]	934	delivery	5	14
5739	2019-08-05 03:11:08	2019-08-05	8	[{"id_menu":5,"count":1}]	850	delivery	5	13
5740	2019-08-05 03:11:39	2019-08-05	12	[{"id_menu":3,"count":1}]	1490	pick-up	0	12
5741	2019-08-05 04:06:11	2019-08-05	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2000	delivery	5	26
5742	2019-08-05 04:06:42	2019-08-05	17	[{"id_menu":4,"count":1}]	1938	pick-up	0	17
5743	2019-08-05 04:09:52	2019-08-05	12	[{"id_menu":1,"count":1}]	1481	pick-up	0	12
5744	2019-08-05 04:16:54	2019-08-05	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	1025	delivery	5	28
5745	2019-08-05 05:07:00	2019-08-05	17	[{"id_menu":4,"count":1}]	2223	pick-up	0	17
5746	2019-08-05 05:40:36	2019-08-05	9	[{"id_menu":7,"count":1}]	1670	pick-up	0	9
5747	2019-08-05 05:41:48	2019-08-05	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2069	pick-up	0	26
5748	2019-08-05 05:59:46	2019-08-05	9	[{"id_menu":7,"count":1}]	381	delivery	5	14
5749	2019-08-05 06:12:36	2019-08-05	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1033	pick-up	0	23
5750	2019-08-05 08:06:53	2019-08-05	12	[{"id_menu":3,"count":1}]	1889	pick-up	0	12
5751	2019-08-05 08:19:29	2019-08-05	9	[{"id_menu":6,"count":2}]	2193	delivery	5	14
5752	2019-08-05 08:24:49	2019-08-05	12	[{"id_menu":3,"count":1}]	2214	pick-up	0	12
5753	2019-08-05 10:01:30	2019-08-05	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	41	pick-up	0	40
5754	2019-08-05 11:10:26	2019-08-05	17	[{"id_menu":4,"count":1}]	1293	delivery	5	22
5755	2019-08-05 11:54:53	2019-08-05	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	845	pick-up	0	20
5756	2019-08-05 12:04:33	2019-08-05	9	[{"id_menu":7,"count":1}]	1858	pick-up	0	9
5757	2019-08-05 12:33:14	2019-08-05	12	[{"id_menu":3,"count":1}]	138	delivery	5	17
5758	2019-08-05 13:04:50	2019-08-05	12	[{"id_menu":1,"count":1}]	547	delivery	5	17
5759	2019-08-05 14:27:18	2019-08-05	9	[{"id_menu":6,"count":1}]	2217	pick-up	0	9
5760	2019-08-05 15:12:12	2019-08-05	9	[{"id_menu":7,"count":1}]	1832	pick-up	0	9
5761	2019-08-05 16:24:39	2019-08-05	12	[{"id_menu":3,"count":1}]	96	pick-up	0	12
5762	2019-08-05 16:38:41	2019-08-05	8	[{"id_menu":5,"count":1}]	1429	pick-up	0	8
5763	2019-08-05 16:45:52	2019-08-05	12	[{"id_menu":1,"count":1}]	788	delivery	5	17
5764	2019-08-05 17:38:47	2019-08-05	17	[{"id_menu":4,"count":1}]	2224	pick-up	0	17
5765	2019-08-05 17:46:17	2019-08-05	17	[{"id_menu":4,"count":1}]	218	pick-up	0	17
5766	2019-08-05 18:17:19	2019-08-05	9	[{"id_menu":6,"count":1}]	1654	delivery	5	14
5767	2019-08-05 18:29:48	2019-08-05	17	[{"id_menu":4,"count":1}]	44	pick-up	0	17
5768	2019-08-05 19:28:01	2019-08-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1021	delivery	5	28
5769	2019-08-05 19:44:57	2019-08-05	12	[{"id_menu":3,"count":1}]	2215	delivery	5	17
5770	2019-08-05 21:32:17	2019-08-05	17	[{"id_menu":4,"count":1}]	649	pick-up	0	17
5771	2019-08-05 21:38:40	2019-08-05	34	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	2101	delivery	5	39
5772	2019-08-05 22:00:46	2019-08-05	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	980	pick-up	0	26
5773	2019-08-05 23:02:43	2019-08-05	12	[{"id_menu":1,"count":1}]	170	delivery	5	17
5774	2019-08-06 00:15:20	2019-08-06	12	[{"id_menu":1,"count":1}]	2056	pick-up	0	12
5775	2019-08-06 01:34:44	2019-08-06	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	216	pick-up	0	24
5776	2019-08-06 02:13:53	2019-08-06	14	[{"id_menu":2,"count":1}]	1230	delivery	5	19
5777	2019-08-06 03:30:04	2019-08-06	9	[{"id_menu":7,"count":1}]	2237	pick-up	0	9
5778	2019-08-06 03:47:52	2019-08-06	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	362	delivery	5	26
5779	2019-08-06 03:53:50	2019-08-06	12	[{"id_menu":1,"count":1}]	1902	pick-up	0	12
5780	2019-08-06 04:16:15	2019-08-06	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1402	pick-up	0	40
5781	2019-08-06 04:27:43	2019-08-06	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	2231	pick-up	0	29
5782	2019-08-06 05:07:11	2019-08-06	14	[{"id_menu":2,"count":1}]	1468	pick-up	0	14
5783	2019-08-06 05:34:47	2019-08-06	12	[{"id_menu":1,"count":1}]	2238	pick-up	0	12
5784	2019-08-06 05:35:27	2019-08-06	8	[{"id_menu":5,"count":1}]	1948	delivery	5	13
5785	2019-08-06 06:29:06	2019-08-06	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2197	delivery	5	26
5786	2019-08-06 06:43:48	2019-08-06	8	[{"id_menu":5,"count":1}]	1510	pick-up	0	8
5787	2019-08-06 08:01:19	2019-08-06	12	[{"id_menu":1,"count":1}]	15	pick-up	0	12
5788	2019-08-06 08:20:15	2019-08-06	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2229	pick-up	0	21
5789	2019-08-06 08:25:10	2019-08-06	9	[{"id_menu":7,"count":1}]	245	pick-up	0	9
5790	2019-08-06 09:17:26	2019-08-06	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2230	pick-up	0	22
5791	2019-08-06 09:40:04	2019-08-06	9	[{"id_menu":6,"count":1}]	1333	delivery	5	14
5792	2019-08-06 10:14:45	2019-08-06	12	[{"id_menu":3,"count":1}]	2207	delivery	5	17
5793	2019-08-06 11:09:29	2019-08-06	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":3}]	2240	delivery	5	31
5794	2019-08-06 11:25:04	2019-08-06	9	[{"id_menu":6,"count":1}]	1090	pick-up	0	9
5795	2019-08-06 11:57:10	2019-08-06	12	[{"id_menu":3,"count":1}]	2228	delivery	5	17
5796	2019-08-06 12:15:34	2019-08-06	9	[{"id_menu":6,"count":1}]	1502	pick-up	0	9
5797	2019-08-06 12:23:22	2019-08-06	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1679	pick-up	0	26
5798	2019-08-06 13:16:50	2019-08-06	14	[{"id_menu":2,"count":1}]	92	delivery	5	19
5799	2019-08-06 13:28:13	2019-08-06	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1264	pick-up	0	43
5800	2019-08-06 13:31:42	2019-08-06	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1014	pick-up	0	50
5801	2019-08-06 14:16:22	2019-08-06	9	[{"id_menu":7,"count":1}]	921	delivery	5	14
5802	2019-08-06 14:42:17	2019-08-06	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1998	pick-up	0	22
5803	2019-08-06 14:44:19	2019-08-06	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	506	pick-up	0	26
5804	2019-08-06 15:34:23	2019-08-06	9	[{"id_menu":6,"count":1}]	1325	delivery	5	14
5805	2019-08-06 15:55:13	2019-08-06	12	[{"id_menu":3,"count":1}]	1537	pick-up	0	12
5806	2019-08-06 19:10:12	2019-08-06	12	[{"id_menu":1,"count":1}]	1963	pick-up	0	12
5807	2019-08-06 19:43:17	2019-08-06	9	[{"id_menu":6,"count":1}]	676	pick-up	0	9
5808	2019-08-06 20:03:19	2019-08-06	12	[{"id_menu":1,"count":1}]	2235	pick-up	0	12
5809	2019-08-06 20:09:36	2019-08-06	9	[{"id_menu":7,"count":1}]	1331	pick-up	0	9
5810	2019-08-06 20:24:12	2019-08-06	9	[{"id_menu":6,"count":1}]	1639	pick-up	0	9
5811	2019-08-06 20:44:32	2019-08-06	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	150	pick-up	0	17
5812	2019-08-06 21:31:59	2019-08-06	9	[{"id_menu":7,"count":1}]	2232	pick-up	0	9
5813	2019-08-06 21:58:27	2019-08-06	12	[{"id_menu":1,"count":1}]	683	pick-up	0	12
5814	2019-08-06 22:12:00	2019-08-06	12	[{"id_menu":3,"count":1}]	722	pick-up	0	12
5815	2019-08-06 22:12:39	2019-08-06	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	972	delivery	5	28
5816	2019-08-06 23:03:58	2019-08-06	12	[{"id_menu":1,"count":1}]	1314	pick-up	0	12
5817	2019-08-06 23:21:36	2019-08-06	12	[{"id_menu":3,"count":2}]	1233	pick-up	0	12
5818	2019-08-06 23:57:02	2019-08-06	17	[{"id_menu":4,"count":2}]	2227	pick-up	0	17
5819	2019-08-07 00:01:34	2019-08-07	14	[{"id_menu":2,"count":1}]	483	delivery	5	19
5820	2019-08-07 00:14:13	2019-08-07	14	[{"id_menu":2,"count":1}]	659	delivery	5	19
5821	2019-08-07 00:42:31	2019-08-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	823	delivery	5	28
5822	2019-08-07 00:54:57	2019-08-07	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	479	delivery	5	31
5823	2019-08-07 01:30:14	2019-08-07	12	[{"id_menu":3,"count":1}]	2248	pick-up	0	12
5824	2019-08-07 01:36:20	2019-08-07	9	[{"id_menu":7,"count":1}]	189	pick-up	0	9
5825	2019-08-07 02:10:11	2019-08-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2253	pick-up	0	18
5826	2019-08-07 02:53:53	2019-08-07	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	963	pick-up	0	26
5827	2019-08-07 03:27:07	2019-08-07	14	[{"id_menu":2,"count":1}]	2245	delivery	5	19
5828	2019-08-07 04:00:34	2019-08-07	17	[{"id_menu":4,"count":1}]	2241	delivery	5	22
5829	2019-08-07 04:54:40	2019-08-07	9	[{"id_menu":7,"count":1}]	540	delivery	5	14
5830	2019-08-07 05:03:37	2019-08-07	12	[{"id_menu":1,"count":1}]	466	delivery	5	17
5831	2019-08-07 05:09:09	2019-08-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2	pick-up	0	23
5832	2019-08-07 05:28:43	2019-08-07	12	[{"id_menu":1,"count":1}]	2251	pick-up	0	12
5833	2019-08-07 06:48:09	2019-08-07	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	1530	delivery	5	45
5834	2019-08-07 06:53:01	2019-08-07	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	233	delivery	5	30
5835	2019-08-07 07:03:48	2019-08-07	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2250	pick-up	0	26
5836	2019-08-07 07:05:08	2019-08-07	8	[{"id_menu":5,"count":1}]	2013	pick-up	0	8
5837	2019-08-07 07:52:28	2019-08-07	8	[{"id_menu":5,"count":1}]	2243	pick-up	0	8
5838	2019-08-07 07:55:57	2019-08-07	9	[{"id_menu":7,"count":1}]	1236	delivery	5	14
5839	2019-08-07 08:08:20	2019-08-07	9	[{"id_menu":7,"count":1}]	820	delivery	5	14
5840	2019-08-07 09:09:08	2019-08-07	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	338	pick-up	0	31
5841	2019-08-07 09:21:52	2019-08-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2201	pick-up	0	18
5842	2019-08-07 09:40:27	2019-08-07	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2254	delivery	5	22
5843	2019-08-07 10:32:25	2019-08-07	9	[{"id_menu":6,"count":1}]	2252	delivery	5	14
5844	2019-08-07 10:58:12	2019-08-07	17	[{"id_menu":4,"count":1}]	177	pick-up	0	17
5845	2019-08-07 11:21:02	2019-08-07	12	[{"id_menu":3,"count":1}]	9	pick-up	0	12
5846	2019-08-07 11:24:51	2019-08-07	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1627	pick-up	0	22
5847	2019-08-07 11:28:50	2019-08-07	8	[{"id_menu":5,"count":1}]	1718	pick-up	0	8
5848	2019-08-07 11:39:20	2019-08-07	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	418	pick-up	0	26
5849	2019-08-07 12:11:32	2019-08-07	17	[{"id_menu":4,"count":1}]	1583	delivery	5	22
5850	2019-08-07 13:06:23	2019-08-07	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1896	pick-up	0	47
5851	2019-08-07 13:37:45	2019-08-07	8	[{"id_menu":5,"count":1}]	2193	delivery	5	13
5852	2019-08-07 13:39:20	2019-08-07	17	[{"id_menu":4,"count":1}]	292	delivery	5	22
5853	2019-08-07 13:43:06	2019-08-07	9	[{"id_menu":7,"count":1}]	1122	delivery	5	14
5854	2019-08-07 14:43:58	2019-08-07	9	[{"id_menu":7,"count":1}]	1167	delivery	5	14
5855	2019-08-07 15:38:16	2019-08-07	12	[{"id_menu":3,"count":1}]	2242	pick-up	0	12
5856	2019-08-07 16:33:52	2019-08-07	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1687	delivery	5	35
5857	2019-08-07 17:08:26	2019-08-07	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":3}]	2249	pick-up	0	25
5858	2019-08-07 17:12:58	2019-08-07	12	[{"id_menu":1,"count":1}]	123	pick-up	0	12
5859	2019-08-07 18:03:09	2019-08-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	512	pick-up	0	23
5860	2019-08-07 18:24:15	2019-08-07	12	[{"id_menu":1,"count":1}]	308	pick-up	0	12
5861	2019-08-07 18:32:01	2019-08-07	8	[{"id_menu":5,"count":2}]	847	delivery	5	13
5862	2019-08-07 18:47:39	2019-08-07	17	[{"id_menu":4,"count":1}]	2078	delivery	5	22
5863	2019-08-07 19:19:42	2019-08-07	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	809	delivery	5	30
5864	2019-08-07 19:20:58	2019-08-07	14	[{"id_menu":2,"count":1}]	980	pick-up	0	14
5865	2019-08-07 19:29:19	2019-08-07	14	[{"id_menu":2,"count":2}]	1059	delivery	5	19
5866	2019-08-07 19:47:23	2019-08-07	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1816	pick-up	0	25
5867	2019-08-07 19:55:44	2019-08-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1992	delivery	5	28
5868	2019-08-07 20:28:43	2019-08-07	12	[{"id_menu":1,"count":1}]	1650	pick-up	0	12
5869	2019-08-07 21:02:02	2019-08-07	9	[{"id_menu":7,"count":1}]	2246	pick-up	0	9
5870	2019-08-07 21:05:08	2019-08-07	12	[{"id_menu":1,"count":1}]	82	delivery	5	17
5871	2019-08-07 21:37:36	2019-08-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2244	pick-up	0	21
5872	2019-08-08 01:12:23	2019-08-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1885	pick-up	0	23
5873	2019-08-08 01:22:24	2019-08-08	9	[{"id_menu":6,"count":1}]	519	pick-up	0	9
5874	2019-08-08 01:42:08	2019-08-08	14	[{"id_menu":2,"count":1}]	2021	delivery	5	19
5875	2019-08-08 02:13:35	2019-08-08	9	[{"id_menu":6,"count":1}]	1380	delivery	5	14
5876	2019-08-08 02:36:20	2019-08-08	12	[{"id_menu":1,"count":1}]	2006	pick-up	0	12
5877	2019-08-08 02:38:11	2019-08-08	14	[{"id_menu":2,"count":1}]	352	delivery	5	19
5878	2019-08-08 02:42:48	2019-08-08	9	[{"id_menu":6,"count":1}]	1677	pick-up	0	9
5879	2019-08-08 03:00:45	2019-08-08	9	[{"id_menu":7,"count":1}]	73	delivery	5	14
5880	2019-08-08 03:28:36	2019-08-08	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	550	delivery	5	37
5881	2019-08-08 04:24:21	2019-08-08	8	[{"id_menu":5,"count":1}]	2258	pick-up	0	8
5882	2019-08-08 04:27:50	2019-08-08	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1104	pick-up	0	21
5883	2019-08-08 05:56:45	2019-08-08	17	[{"id_menu":4,"count":1}]	1575	pick-up	0	17
5884	2019-08-08 06:18:42	2019-08-08	8	[{"id_menu":5,"count":1}]	2257	pick-up	0	8
5885	2019-08-08 07:10:11	2019-08-08	9	[{"id_menu":6,"count":1}]	388	delivery	5	14
5886	2019-08-08 07:24:27	2019-08-08	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	298	pick-up	0	38
5887	2019-08-08 09:41:22	2019-08-08	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	367	delivery	5	31
5888	2019-08-08 09:49:07	2019-08-08	17	[{"id_menu":4,"count":1}]	1058	pick-up	0	17
5889	2019-08-08 09:55:15	2019-08-08	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2262	delivery	5	31
5890	2019-08-08 10:15:46	2019-08-08	8	[{"id_menu":5,"count":1}]	1142	delivery	5	13
5891	2019-08-08 10:30:48	2019-08-08	9	[{"id_menu":7,"count":1}]	2259	delivery	5	14
5892	2019-08-08 10:41:34	2019-08-08	12	[{"id_menu":1,"count":1}]	1427	pick-up	0	12
5893	2019-08-08 11:06:57	2019-08-08	17	[{"id_menu":4,"count":1}]	2263	delivery	5	22
5894	2019-08-08 11:19:58	2019-08-08	9	[{"id_menu":6,"count":1}]	833	pick-up	0	9
5895	2019-08-08 11:53:12	2019-08-08	17	[{"id_menu":4,"count":1}]	2265	delivery	5	22
5896	2019-08-08 11:57:07	2019-08-08	9	[{"id_menu":6,"count":1}]	1693	delivery	5	14
5897	2019-08-08 11:59:48	2019-08-08	12	[{"id_menu":3,"count":1}]	1526	delivery	5	17
5898	2019-08-08 12:10:36	2019-08-08	14	[{"id_menu":2,"count":1}]	2261	pick-up	0	14
5899	2019-08-08 13:14:43	2019-08-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11	pick-up	0	17
5900	2019-08-08 13:39:43	2019-08-08	14	[{"id_menu":2,"count":1}]	2080	pick-up	0	14
5901	2019-08-08 13:45:11	2019-08-08	12	[{"id_menu":1,"count":1}]	708	pick-up	0	12
5902	2019-08-08 14:27:56	2019-08-08	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	821	pick-up	0	26
5903	2019-08-08 15:07:42	2019-08-08	8	[{"id_menu":5,"count":1}]	2268	pick-up	0	8
5904	2019-08-08 15:25:00	2019-08-08	9	[{"id_menu":7,"count":1}]	1078	delivery	5	14
5905	2019-08-08 15:51:02	2019-08-08	8	[{"id_menu":5,"count":1}]	892	pick-up	0	8
5906	2019-08-08 16:15:27	2019-08-08	9	[{"id_menu":6,"count":1}]	1160	delivery	5	14
5907	2019-08-08 16:16:33	2019-08-08	9	[{"id_menu":6,"count":1}]	2266	pick-up	0	9
5908	2019-08-08 17:25:43	2019-08-08	12	[{"id_menu":3,"count":1}]	127	pick-up	0	12
5909	2019-08-08 17:26:44	2019-08-08	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1922	pick-up	0	26
5910	2019-08-08 17:29:24	2019-08-08	9	[{"id_menu":7,"count":1}]	2255	delivery	5	14
5911	2019-08-08 17:32:45	2019-08-08	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	482	delivery	5	31
5912	2019-08-08 18:39:51	2019-08-08	8	[{"id_menu":5,"count":1}]	1314	pick-up	0	8
5913	2019-08-08 19:05:02	2019-08-08	9	[{"id_menu":7,"count":1}]	2260	pick-up	0	9
5914	2019-08-08 19:18:43	2019-08-08	12	[{"id_menu":1,"count":1}]	2256	delivery	5	17
5915	2019-08-08 20:01:49	2019-08-08	41	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2264	pick-up	0	41
5916	2019-08-08 20:09:04	2019-08-08	8	[{"id_menu":5,"count":1}]	1343	delivery	5	13
5917	2019-08-08 20:17:08	2019-08-08	14	[{"id_menu":2,"count":1}]	1355	delivery	5	19
5918	2019-08-08 21:00:58	2019-08-08	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	436	pick-up	0	47
5919	2019-08-08 21:22:38	2019-08-08	9	[{"id_menu":6,"count":1}]	638	delivery	5	14
5920	2019-08-08 21:55:59	2019-08-08	9	[{"id_menu":6,"count":1}]	423	pick-up	0	9
5921	2019-08-08 21:58:19	2019-08-08	17	[{"id_menu":4,"count":1}]	1832	pick-up	0	17
5922	2019-08-08 22:44:31	2019-08-08	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2188	delivery	5	31
5923	2019-08-08 22:59:41	2019-08-08	12	[{"id_menu":1,"count":2}]	1097	pick-up	0	12
5924	2019-08-08 23:39:27	2019-08-08	9	[{"id_menu":7,"count":1}]	1461	pick-up	0	9
5925	2019-08-08 23:49:07	2019-08-08	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	1228	pick-up	0	25
5926	2019-08-09 00:04:23	2019-08-09	9	[{"id_menu":6,"count":1}]	1136	pick-up	0	9
5927	2019-08-09 00:04:52	2019-08-09	12	[{"id_menu":3,"count":1}]	1887	delivery	5	17
5928	2019-08-09 01:43:08	2019-08-09	12	[{"id_menu":3,"count":1}]	1268	delivery	5	17
5929	2019-08-09 02:32:49	2019-08-09	17	[{"id_menu":4,"count":1}]	1820	delivery	5	22
5930	2019-08-09 02:41:33	2019-08-09	8	[{"id_menu":5,"count":1}]	183	pick-up	0	8
5931	2019-08-09 02:55:28	2019-08-09	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1110	pick-up	0	31
5932	2019-08-09 03:17:42	2019-08-09	14	[{"id_menu":2,"count":1}]	2272	pick-up	0	14
5933	2019-08-09 03:26:14	2019-08-09	17	[{"id_menu":4,"count":1}]	2277	delivery	5	22
5934	2019-08-09 04:02:48	2019-08-09	17	[{"id_menu":4,"count":1}]	883	pick-up	0	17
5935	2019-08-09 04:21:04	2019-08-09	17	[{"id_menu":4,"count":1}]	1486	delivery	5	22
5936	2019-08-09 06:27:42	2019-08-09	12	[{"id_menu":3,"count":1}]	2281	delivery	5	17
5937	2019-08-09 06:37:51	2019-08-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1193	delivery	5	28
5938	2019-08-09 06:45:42	2019-08-09	12	[{"id_menu":1,"count":1}]	126	delivery	5	17
5939	2019-08-09 06:53:06	2019-08-09	12	[{"id_menu":3,"count":1}]	787	delivery	5	17
5940	2019-08-09 07:53:53	2019-08-09	17	[{"id_menu":4,"count":1}]	503	delivery	5	22
5941	2019-08-09 07:59:49	2019-08-09	9	[{"id_menu":6,"count":1}]	2284	pick-up	0	9
5942	2019-08-09 08:05:11	2019-08-09	8	[{"id_menu":5,"count":1}]	213	pick-up	0	8
5943	2019-08-09 08:08:24	2019-08-09	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2217	pick-up	0	26
5944	2019-08-09 08:36:47	2019-08-09	9	[{"id_menu":6,"count":1}]	1682	pick-up	0	9
5945	2019-08-09 09:43:04	2019-08-09	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	95	pick-up	0	31
5946	2019-08-09 09:43:48	2019-08-09	17	[{"id_menu":4,"count":1}]	1145	pick-up	0	17
5947	2019-08-09 09:50:07	2019-08-09	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2072	delivery	5	22
5948	2019-08-09 10:34:24	2019-08-09	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2137	pick-up	0	38
5949	2019-08-09 11:03:31	2019-08-09	12	[{"id_menu":1,"count":1}]	2117	pick-up	0	12
5950	2019-08-09 11:25:15	2019-08-09	17	[{"id_menu":4,"count":1}]	2278	delivery	5	22
5951	2019-08-09 11:42:20	2019-08-09	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2282	delivery	5	27
5952	2019-08-09 12:19:56	2019-08-09	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2283	delivery	5	31
5953	2019-08-09 13:22:50	2019-08-09	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	527	delivery	5	38
5954	2019-08-09 13:49:50	2019-08-09	14	[{"id_menu":2,"count":1}]	2271	pick-up	0	14
5955	2019-08-09 13:51:56	2019-08-09	12	[{"id_menu":3,"count":1}]	243	delivery	5	17
5956	2019-08-09 15:30:40	2019-08-09	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1455	pick-up	0	29
5957	2019-08-09 15:30:43	2019-08-09	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1765	pick-up	0	31
5958	2019-08-09 15:48:18	2019-08-09	9	[{"id_menu":6,"count":1}]	763	pick-up	0	9
5959	2019-08-09 16:21:54	2019-08-09	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	506	pick-up	0	21
5960	2019-08-09 16:36:21	2019-08-09	17	[{"id_menu":4,"count":2}]	743	delivery	5	22
5961	2019-08-09 17:20:13	2019-08-09	9	[{"id_menu":7,"count":1}]	2279	pick-up	0	9
5962	2019-08-09 17:20:48	2019-08-09	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1456	pick-up	0	26
5963	2019-08-09 18:04:19	2019-08-09	12	[{"id_menu":3,"count":1}]	1306	delivery	5	17
5964	2019-08-09 18:27:15	2019-08-09	9	[{"id_menu":6,"count":1}]	508	delivery	5	14
5965	2019-08-09 18:29:00	2019-08-09	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	2000	delivery	5	25
5966	2019-08-09 18:31:00	2019-08-09	14	[{"id_menu":2,"count":2}]	2276	pick-up	0	14
5967	2019-08-09 18:59:29	2019-08-09	8	[{"id_menu":5,"count":1}]	1529	pick-up	0	8
5968	2019-08-09 19:16:09	2019-08-09	8	[{"id_menu":5,"count":1}]	1098	delivery	5	13
5969	2019-08-09 19:47:22	2019-08-09	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2270	delivery	5	31
5970	2019-08-09 20:23:09	2019-08-09	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1258	delivery	5	29
5971	2019-08-09 20:27:43	2019-08-09	9	[{"id_menu":6,"count":1}]	1988	delivery	5	14
5972	2019-08-09 21:01:38	2019-08-09	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	105	delivery	5	27
5973	2019-08-09 21:26:09	2019-08-09	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1514	delivery	5	31
5974	2019-08-09 21:59:05	2019-08-09	9	[{"id_menu":7,"count":1}]	83	pick-up	0	9
5975	2019-08-09 22:09:31	2019-08-09	17	[{"id_menu":4,"count":1}]	1126	delivery	5	22
5976	2019-08-09 23:13:14	2019-08-09	14	[{"id_menu":2,"count":1}]	853	pick-up	0	14
5977	2019-08-09 23:39:12	2019-08-09	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2168	delivery	5	26
5978	2019-08-09 23:40:36	2019-08-09	17	[{"id_menu":4,"count":1}]	590	delivery	5	22
5979	2019-08-09 23:47:17	2019-08-09	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1331	delivery	5	45
5980	2019-08-09 23:48:12	2019-08-09	8	[{"id_menu":5,"count":1}]	1385	pick-up	0	8
5981	2019-08-10 00:29:36	2019-08-10	9	[{"id_menu":6,"count":1}]	2293	pick-up	0	9
5982	2019-08-10 00:34:55	2019-08-10	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2287	pick-up	0	31
5983	2019-08-10 00:59:26	2019-08-10	9	[{"id_menu":7,"count":1}]	498	pick-up	0	9
5984	2019-08-10 02:02:58	2019-08-10	9	[{"id_menu":6,"count":1}]	1406	pick-up	0	9
5985	2019-08-10 02:19:00	2019-08-10	17	[{"id_menu":4,"count":1}]	719	delivery	5	22
5986	2019-08-10 02:41:48	2019-08-10	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	2297	delivery	5	34
5987	2019-08-10 02:57:17	2019-08-10	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1400	pick-up	0	29
5988	2019-08-10 03:15:34	2019-08-10	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2291	pick-up	0	20
5989	2019-08-10 03:17:03	2019-08-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1956	pick-up	0	23
5990	2019-08-10 03:33:06	2019-08-10	14	[{"id_menu":2,"count":1}]	1416	delivery	5	19
5991	2019-08-10 03:39:22	2019-08-10	9	[{"id_menu":7,"count":1}]	226	pick-up	0	9
5992	2019-08-10 03:41:38	2019-08-10	14	[{"id_menu":2,"count":1}]	2140	pick-up	0	14
5993	2019-08-10 04:27:19	2019-08-10	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	701	pick-up	0	21
5994	2019-08-10 04:37:18	2019-08-10	12	[{"id_menu":1,"count":1}]	2294	pick-up	0	12
5995	2019-08-10 05:34:44	2019-08-10	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	2026	pick-up	0	26
5996	2019-08-10 06:38:07	2019-08-10	14	[{"id_menu":2,"count":2}]	1999	pick-up	0	14
5997	2019-08-10 07:26:18	2019-08-10	14	[{"id_menu":2,"count":1}]	906	pick-up	0	14
5998	2019-08-10 07:30:48	2019-08-10	14	[{"id_menu":2,"count":1}]	371	delivery	5	19
5999	2019-08-10 07:53:02	2019-08-10	12	[{"id_menu":1,"count":1}]	2290	pick-up	0	12
6000	2019-08-10 08:04:13	2019-08-10	14	[{"id_menu":2,"count":1}]	743	delivery	5	19
6001	2019-08-10 08:19:11	2019-08-10	17	[{"id_menu":4,"count":1}]	1847	pick-up	0	17
6002	2019-08-10 09:09:34	2019-08-10	9	[{"id_menu":6,"count":1}]	972	delivery	5	14
6003	2019-08-10 09:28:17	2019-08-10	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2300	pick-up	0	26
6004	2019-08-10 09:51:19	2019-08-10	9	[{"id_menu":6,"count":1}]	1448	delivery	5	14
6005	2019-08-10 10:33:43	2019-08-10	9	[{"id_menu":6,"count":1}]	1810	pick-up	0	9
6006	2019-08-10 10:49:56	2019-08-10	12	[{"id_menu":1,"count":2}]	531	pick-up	0	12
6007	2019-08-10 11:18:50	2019-08-10	8	[{"id_menu":5,"count":1}]	2227	pick-up	0	8
6008	2019-08-10 11:34:02	2019-08-10	8	[{"id_menu":5,"count":2}]	1258	delivery	5	13
6009	2019-08-10 11:46:17	2019-08-10	17	[{"id_menu":4,"count":1}]	2286	delivery	5	22
6010	2019-08-10 12:13:00	2019-08-10	17	[{"id_menu":4,"count":1}]	1433	delivery	5	22
6011	2019-08-10 12:44:38	2019-08-10	9	[{"id_menu":6,"count":1}]	527	delivery	5	14
6012	2019-08-10 13:14:34	2019-08-10	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1545	pick-up	0	32
6013	2019-08-10 13:17:37	2019-08-10	14	[{"id_menu":2,"count":1}]	1115	pick-up	0	14
6014	2019-08-10 14:06:35	2019-08-10	17	[{"id_menu":4,"count":1}]	2292	pick-up	0	17
6015	2019-08-10 14:06:56	2019-08-10	17	[{"id_menu":4,"count":1}]	547	delivery	5	22
6016	2019-08-10 14:23:15	2019-08-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1685	pick-up	0	23
6017	2019-08-10 15:03:13	2019-08-10	17	[{"id_menu":4,"count":1}]	841	pick-up	0	17
6018	2019-08-10 15:11:21	2019-08-10	9	[{"id_menu":7,"count":1}]	377	delivery	5	14
6019	2019-08-10 15:20:54	2019-08-10	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2296	delivery	5	42
6020	2019-08-10 15:37:21	2019-08-10	8	[{"id_menu":5,"count":1}]	415	delivery	5	13
6021	2019-08-10 16:05:00	2019-08-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	66	pick-up	0	23
6022	2019-08-10 16:22:47	2019-08-10	9	[{"id_menu":6,"count":1}]	2295	pick-up	0	9
6023	2019-08-10 17:14:40	2019-08-10	12	[{"id_menu":3,"count":1}]	1988	pick-up	0	12
6024	2019-08-10 18:36:15	2019-08-10	9	[{"id_menu":7,"count":1}]	1507	pick-up	0	9
6025	2019-08-10 18:59:17	2019-08-10	12	[{"id_menu":3,"count":2}]	1080	pick-up	0	12
6026	2019-08-10 19:18:28	2019-08-10	14	[{"id_menu":2,"count":1}]	2289	pick-up	0	14
6027	2019-08-10 19:41:49	2019-08-10	14	[{"id_menu":2,"count":1}]	1737	pick-up	0	14
6028	2019-08-10 20:04:00	2019-08-10	9	[{"id_menu":7,"count":1}]	1713	pick-up	0	9
6029	2019-08-10 20:06:17	2019-08-10	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	1846	delivery	5	31
6030	2019-08-10 21:32:59	2019-08-10	12	[{"id_menu":3,"count":1}]	290	pick-up	0	12
6031	2019-08-10 21:34:59	2019-08-10	9	[{"id_menu":6,"count":1}]	2298	delivery	5	14
6032	2019-08-10 21:41:11	2019-08-10	12	[{"id_menu":3,"count":1}]	1177	pick-up	0	12
6033	2019-08-10 22:30:51	2019-08-10	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1792	pick-up	0	26
6034	2019-08-10 23:00:07	2019-08-10	8	[{"id_menu":5,"count":1}]	2288	pick-up	0	8
6035	2019-08-10 23:31:39	2019-08-10	9	[{"id_menu":7,"count":1}]	1813	pick-up	0	9
6036	2019-08-10 23:49:31	2019-08-10	17	[{"id_menu":4,"count":1}]	2285	pick-up	0	17
6037	2019-08-11 00:46:14	2019-08-11	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	372	pick-up	0	29
6038	2019-08-11 01:01:58	2019-08-11	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	62	delivery	5	26
6039	2019-08-11 01:07:15	2019-08-11	12	[{"id_menu":3,"count":1}]	1578	pick-up	0	12
6040	2019-08-11 01:23:37	2019-08-11	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1239	pick-up	0	39
6041	2019-08-11 02:12:20	2019-08-11	14	[{"id_menu":2,"count":1}]	1095	delivery	5	19
6042	2019-08-11 02:27:47	2019-08-11	12	[{"id_menu":3,"count":1}]	2301	pick-up	0	12
6043	2019-08-11 02:50:13	2019-08-11	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2316	pick-up	0	26
6044	2019-08-11 03:05:18	2019-08-11	12	[{"id_menu":3,"count":1}]	1097	pick-up	0	12
6045	2019-08-11 03:40:19	2019-08-11	14	[{"id_menu":2,"count":1}]	2315	pick-up	0	14
6046	2019-08-11 03:42:52	2019-08-11	14	[{"id_menu":2,"count":1}]	883	delivery	5	19
6047	2019-08-11 03:52:08	2019-08-11	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	431	delivery	5	22
6048	2019-08-11 03:58:58	2019-08-11	12	[{"id_menu":3,"count":1}]	360	pick-up	0	12
6049	2019-08-11 04:42:27	2019-08-11	17	[{"id_menu":4,"count":1}]	764	delivery	5	22
6050	2019-08-11 04:45:35	2019-08-11	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1905	pick-up	0	26
6051	2019-08-11 04:57:19	2019-08-11	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	787	pick-up	0	26
6052	2019-08-11 04:58:58	2019-08-11	8	[{"id_menu":5,"count":1}]	2305	delivery	5	13
6053	2019-08-11 06:45:04	2019-08-11	9	[{"id_menu":7,"count":1}]	1656	delivery	5	14
6054	2019-08-11 08:01:38	2019-08-11	8	[{"id_menu":5,"count":1}]	1385	pick-up	0	8
6055	2019-08-11 08:45:21	2019-08-11	8	[{"id_menu":5,"count":1}]	1765	delivery	5	13
6056	2019-08-11 09:12:25	2019-08-11	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	338	delivery	5	25
6057	2019-08-11 09:37:41	2019-08-11	17	[{"id_menu":4,"count":1}]	574	pick-up	0	17
6058	2019-08-11 10:03:10	2019-08-11	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1648	pick-up	0	23
6059	2019-08-11 10:51:05	2019-08-11	9	[{"id_menu":7,"count":1}]	2234	pick-up	0	9
6060	2019-08-11 11:02:57	2019-08-11	14	[{"id_menu":2,"count":1}]	593	pick-up	0	14
6061	2019-08-11 11:05:29	2019-08-11	17	[{"id_menu":4,"count":1}]	2312	delivery	5	22
6062	2019-08-11 11:10:11	2019-08-11	8	[{"id_menu":5,"count":1}]	1596	delivery	5	13
6063	2019-08-11 12:16:54	2019-08-11	9	[{"id_menu":7,"count":1}]	2061	pick-up	0	9
6064	2019-08-11 12:30:04	2019-08-11	14	[{"id_menu":2,"count":1}]	213	pick-up	0	14
6065	2019-08-11 12:31:32	2019-08-11	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2307	pick-up	0	21
6066	2019-08-11 12:36:02	2019-08-11	9	[{"id_menu":7,"count":1}]	1245	pick-up	0	9
6067	2019-08-11 13:11:03	2019-08-11	17	[{"id_menu":4,"count":1}]	1377	delivery	5	22
6068	2019-08-11 13:38:15	2019-08-11	9	[{"id_menu":7,"count":1}]	639	pick-up	0	9
6069	2019-08-11 13:42:41	2019-08-11	14	[{"id_menu":2,"count":1}]	2052	delivery	5	19
6070	2019-08-11 13:53:28	2019-08-11	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	2308	delivery	5	29
6071	2019-08-11 14:17:21	2019-08-11	9	[{"id_menu":6,"count":1}]	997	pick-up	0	9
6072	2019-08-11 15:01:48	2019-08-11	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1583	pick-up	0	43
6073	2019-08-11 15:07:12	2019-08-11	9	[{"id_menu":6,"count":1}]	2082	pick-up	0	9
6074	2019-08-11 15:22:31	2019-08-11	17	[{"id_menu":4,"count":1}]	1172	pick-up	0	17
6075	2019-08-11 15:43:57	2019-08-11	12	[{"id_menu":1,"count":1}]	2302	delivery	5	17
6076	2019-08-11 15:46:37	2019-08-11	9	[{"id_menu":6,"count":1}]	635	delivery	5	14
6077	2019-08-11 15:51:25	2019-08-11	8	[{"id_menu":5,"count":1}]	1657	pick-up	0	8
6078	2019-08-11 16:03:02	2019-08-11	12	[{"id_menu":1,"count":1}]	2310	delivery	5	17
6079	2019-08-11 16:07:05	2019-08-11	14	[{"id_menu":2,"count":2}]	541	pick-up	0	14
6080	2019-08-11 16:18:02	2019-08-11	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1653	pick-up	0	17
6081	2019-08-11 16:25:33	2019-08-11	9	[{"id_menu":7,"count":1}]	119	pick-up	0	9
6082	2019-08-11 16:39:37	2019-08-11	14	[{"id_menu":2,"count":1}]	267	pick-up	0	14
6083	2019-08-11 16:42:13	2019-08-11	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	799	pick-up	0	17
6084	2019-08-11 16:45:19	2019-08-11	14	[{"id_menu":2,"count":1}]	2304	delivery	5	19
6085	2019-08-11 17:18:35	2019-08-11	9	[{"id_menu":7,"count":1}]	2211	pick-up	0	9
6086	2019-08-11 18:11:32	2019-08-11	12	[{"id_menu":3,"count":1}]	2306	delivery	5	17
6087	2019-08-11 18:36:09	2019-08-11	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	807	pick-up	0	33
6088	2019-08-11 19:51:09	2019-08-11	9	[{"id_menu":6,"count":1}]	996	pick-up	0	9
6089	2019-08-11 20:04:03	2019-08-11	8	[{"id_menu":5,"count":1}]	2056	pick-up	0	8
6090	2019-08-11 20:20:02	2019-08-11	9	[{"id_menu":6,"count":2}]	2311	pick-up	0	9
6091	2019-08-11 20:43:34	2019-08-11	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	399	pick-up	0	20
6092	2019-08-11 21:41:13	2019-08-11	9	[{"id_menu":7,"count":1}]	735	pick-up	0	9
6093	2019-08-11 22:08:26	2019-08-11	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	2303	delivery	5	26
6094	2019-08-11 22:22:50	2019-08-11	9	[{"id_menu":7,"count":1}]	2313	pick-up	0	9
6095	2019-08-11 22:34:56	2019-08-11	8	[{"id_menu":5,"count":1}]	2309	pick-up	0	8
6096	2019-08-11 22:42:34	2019-08-11	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	27	pick-up	0	26
6097	2019-08-11 22:52:55	2019-08-11	12	[{"id_menu":3,"count":1}]	1183	pick-up	0	12
6098	2019-08-11 23:02:56	2019-08-11	9	[{"id_menu":7,"count":1}]	2314	pick-up	0	9
6099	2019-08-11 23:22:58	2019-08-11	9	[{"id_menu":7,"count":1}]	1569	pick-up	0	9
6100	2019-08-11 23:26:05	2019-08-11	8	[{"id_menu":5,"count":1}]	1800	delivery	5	13
6101	2019-08-11 23:50:47	2019-08-11	17	[{"id_menu":4,"count":1}]	2186	delivery	5	22
6102	2019-08-12 02:03:46	2019-08-12	14	[{"id_menu":2,"count":1}]	1373	delivery	5	19
6103	2019-08-12 02:10:04	2019-08-12	9	[{"id_menu":7,"count":1}]	2325	pick-up	0	9
6104	2019-08-12 02:20:22	2019-08-12	17	[{"id_menu":4,"count":1}]	2324	pick-up	0	17
6105	2019-08-12 02:53:24	2019-08-12	9	[{"id_menu":7,"count":1}]	340	pick-up	0	9
6106	2019-08-12 04:55:50	2019-08-12	9	[{"id_menu":6,"count":1}]	2319	pick-up	0	9
6107	2019-08-12 05:20:11	2019-08-12	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	1647	delivery	5	37
6108	2019-08-12 05:22:34	2019-08-12	14	[{"id_menu":2,"count":2}]	2331	pick-up	0	14
6109	2019-08-12 06:38:35	2019-08-12	12	[{"id_menu":1,"count":1}]	2187	delivery	5	17
6110	2019-08-12 07:25:56	2019-08-12	14	[{"id_menu":2,"count":1}]	2330	delivery	5	19
6111	2019-08-12 07:43:01	2019-08-12	9	[{"id_menu":6,"count":1}]	78	pick-up	0	9
6112	2019-08-12 08:09:13	2019-08-12	9	[{"id_menu":6,"count":2}]	489	delivery	5	14
6113	2019-08-12 09:10:40	2019-08-12	8	[{"id_menu":5,"count":1}]	1258	pick-up	0	8
6114	2019-08-12 09:47:17	2019-08-12	12	[{"id_menu":3,"count":1}]	1092	delivery	5	17
6115	2019-08-12 10:27:21	2019-08-12	12	[{"id_menu":3,"count":1}]	381	pick-up	0	12
6116	2019-08-12 10:51:12	2019-08-12	17	[{"id_menu":4,"count":1}]	1115	pick-up	0	17
6117	2019-08-12 11:48:35	2019-08-12	9	[{"id_menu":7,"count":1}]	1320	pick-up	0	9
6118	2019-08-12 11:56:42	2019-08-12	14	[{"id_menu":2,"count":1}]	1269	pick-up	0	14
6119	2019-08-12 12:00:57	2019-08-12	8	[{"id_menu":5,"count":1}]	628	delivery	5	13
6120	2019-08-12 13:06:21	2019-08-12	14	[{"id_menu":2,"count":1}]	808	pick-up	0	14
6121	2019-08-12 13:24:59	2019-08-12	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	1176	delivery	5	39
6122	2019-08-12 14:56:59	2019-08-12	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	837	pick-up	0	43
6123	2019-08-12 15:39:03	2019-08-12	12	[{"id_menu":3,"count":1}]	189	pick-up	0	12
6124	2019-08-12 16:59:37	2019-08-12	9	[{"id_menu":6,"count":1}]	2321	pick-up	0	9
6125	2019-08-12 17:11:00	2019-08-12	12	[{"id_menu":1,"count":1}]	431	delivery	5	17
6126	2019-08-12 17:27:27	2019-08-12	14	[{"id_menu":2,"count":1}]	2326	pick-up	0	14
6127	2019-08-12 17:42:25	2019-08-12	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	1537	pick-up	0	37
6128	2019-08-12 18:05:19	2019-08-12	12	[{"id_menu":3,"count":1}]	1053	pick-up	0	12
6129	2019-08-12 18:49:33	2019-08-12	8	[{"id_menu":5,"count":1}]	1951	delivery	5	13
6130	2019-08-12 22:14:28	2019-08-12	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	552	delivery	5	45
6131	2019-08-12 22:18:37	2019-08-12	12	[{"id_menu":1,"count":1}]	1654	pick-up	0	12
6132	2019-08-12 22:27:54	2019-08-12	8	[{"id_menu":5,"count":1}]	1462	delivery	5	13
6133	2019-08-12 22:35:48	2019-08-12	12	[{"id_menu":3,"count":1}]	360	pick-up	0	12
6134	2019-08-12 23:13:45	2019-08-12	8	[{"id_menu":5,"count":1}]	995	delivery	5	13
6135	2019-08-12 23:58:20	2019-08-12	9	[{"id_menu":6,"count":1}]	2317	delivery	5	14
6136	2019-08-13 00:29:29	2019-08-13	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2335	delivery	5	31
6137	2019-08-13 00:39:24	2019-08-13	12	[{"id_menu":1,"count":1}]	41	pick-up	0	12
6138	2019-08-13 00:48:53	2019-08-13	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	806	delivery	5	26
6139	2019-08-13 01:18:06	2019-08-13	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1572	delivery	5	25
6140	2019-08-13 03:17:02	2019-08-13	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	2336	pick-up	0	26
6141	2019-08-13 04:09:38	2019-08-13	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	395	delivery	5	26
6142	2019-08-13 04:53:09	2019-08-13	12	[{"id_menu":3,"count":1}]	2338	delivery	5	17
6143	2019-08-13 04:53:19	2019-08-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	970	pick-up	0	31
6144	2019-08-13 05:08:42	2019-08-13	8	[{"id_menu":5,"count":1}]	2173	delivery	5	13
6145	2019-08-13 05:41:27	2019-08-13	12	[{"id_menu":3,"count":1}]	1921	pick-up	0	12
6146	2019-08-13 07:05:16	2019-08-13	17	[{"id_menu":4,"count":1}]	1170	pick-up	0	17
6147	2019-08-13 07:26:27	2019-08-13	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	684	pick-up	0	17
6148	2019-08-13 07:33:28	2019-08-13	17	[{"id_menu":4,"count":1}]	1292	pick-up	0	17
6149	2019-08-13 08:57:24	2019-08-13	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	104	pick-up	0	17
6150	2019-08-13 10:07:38	2019-08-13	9	[{"id_menu":7,"count":1}]	1307	pick-up	0	9
6151	2019-08-13 10:33:03	2019-08-13	17	[{"id_menu":4,"count":1}]	1460	delivery	5	22
6152	2019-08-13 10:42:57	2019-08-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1226	delivery	5	36
6153	2019-08-13 11:50:37	2019-08-13	17	[{"id_menu":4,"count":1}]	1314	pick-up	0	17
6154	2019-08-13 12:22:21	2019-08-13	12	[{"id_menu":3,"count":1}]	2344	pick-up	0	12
6155	2019-08-13 12:25:42	2019-08-13	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2008	pick-up	0	21
6156	2019-08-13 12:34:06	2019-08-13	12	[{"id_menu":3,"count":1}]	997	pick-up	0	12
6157	2019-08-13 12:46:45	2019-08-13	17	[{"id_menu":4,"count":1}]	760	pick-up	0	17
6158	2019-08-13 12:57:45	2019-08-13	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1693	pick-up	0	26
6159	2019-08-13 13:17:06	2019-08-13	17	[{"id_menu":4,"count":1}]	2333	pick-up	0	17
6160	2019-08-13 14:09:30	2019-08-13	9	[{"id_menu":7,"count":1}]	2332	delivery	5	14
6161	2019-08-13 15:44:55	2019-08-13	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	945	pick-up	0	26
6162	2019-08-13 15:51:15	2019-08-13	12	[{"id_menu":3,"count":1}]	1393	delivery	5	17
6163	2019-08-13 17:21:08	2019-08-13	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	1780	pick-up	0	25
6164	2019-08-13 18:30:19	2019-08-13	9	[{"id_menu":6,"count":1}]	2337	pick-up	0	9
6165	2019-08-13 19:50:16	2019-08-13	9	[{"id_menu":7,"count":1}]	688	pick-up	0	9
6166	2019-08-13 20:12:06	2019-08-13	8	[{"id_menu":5,"count":1}]	2334	pick-up	0	8
6167	2019-08-13 20:32:50	2019-08-13	12	[{"id_menu":1,"count":1}]	1155	pick-up	0	12
6168	2019-08-13 21:25:52	2019-08-13	12	[{"id_menu":3,"count":1}]	1781	delivery	5	17
6169	2019-08-13 22:39:10	2019-08-13	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	292	delivery	5	31
6170	2019-08-13 22:42:12	2019-08-13	12	[{"id_menu":3,"count":1}]	1905	delivery	5	17
6171	2019-08-13 23:02:10	2019-08-13	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2340	pick-up	0	23
6172	2019-08-14 01:49:40	2019-08-14	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	599	delivery	5	25
6173	2019-08-14 01:51:46	2019-08-14	17	[{"id_menu":4,"count":1}]	2119	delivery	5	22
6174	2019-08-14 03:00:44	2019-08-14	17	[{"id_menu":4,"count":1}]	1720	pick-up	0	17
6175	2019-08-14 03:09:58	2019-08-14	14	[{"id_menu":2,"count":1}]	2346	pick-up	0	14
6176	2019-08-14 03:48:11	2019-08-14	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	781	pick-up	0	29
6177	2019-08-14 05:35:45	2019-08-14	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	104	pick-up	0	21
6178	2019-08-14 05:41:30	2019-08-14	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1679	pick-up	0	26
6179	2019-08-14 06:08:47	2019-08-14	9	[{"id_menu":6,"count":1}]	2356	pick-up	0	9
6180	2019-08-14 07:11:42	2019-08-14	12	[{"id_menu":1,"count":1}]	2357	delivery	5	17
6181	2019-08-14 07:51:47	2019-08-14	9	[{"id_menu":7,"count":2}]	806	delivery	5	14
6182	2019-08-14 08:07:31	2019-08-14	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2355	delivery	5	40
6183	2019-08-14 08:31:08	2019-08-14	12	[{"id_menu":1,"count":1}]	76	delivery	5	17
6184	2019-08-14 08:32:06	2019-08-14	14	[{"id_menu":2,"count":1}]	310	pick-up	0	14
6185	2019-08-14 09:21:49	2019-08-14	14	[{"id_menu":2,"count":1}]	2359	pick-up	0	14
6186	2019-08-14 09:35:11	2019-08-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2353	pick-up	0	31
6187	2019-08-14 10:06:59	2019-08-14	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1888	delivery	5	48
6188	2019-08-14 10:21:21	2019-08-14	9	[{"id_menu":6,"count":1}]	2275	delivery	5	14
6189	2019-08-14 10:30:13	2019-08-14	14	[{"id_menu":2,"count":1}]	1393	delivery	5	19
6190	2019-08-14 10:39:47	2019-08-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2349	pick-up	0	26
6191	2019-08-14 11:46:20	2019-08-14	17	[{"id_menu":4,"count":1}]	2086	delivery	5	22
6192	2019-08-14 13:04:53	2019-08-14	17	[{"id_menu":4,"count":1}]	989	pick-up	0	17
6193	2019-08-14 13:32:32	2019-08-14	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	593	pick-up	0	29
6194	2019-08-14 13:38:27	2019-08-14	12	[{"id_menu":1,"count":1}]	2347	pick-up	0	12
6195	2019-08-14 13:52:20	2019-08-14	12	[{"id_menu":3,"count":1}]	660	pick-up	0	12
6196	2019-08-14 13:55:11	2019-08-14	9	[{"id_menu":6,"count":1}]	2351	pick-up	0	9
6197	2019-08-14 16:28:09	2019-08-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	2350	pick-up	0	23
6198	2019-08-14 17:21:48	2019-08-14	9	[{"id_menu":7,"count":2}]	826	pick-up	0	9
6199	2019-08-14 17:27:58	2019-08-14	14	[{"id_menu":2,"count":1}]	2354	pick-up	0	14
6200	2019-08-14 18:05:02	2019-08-14	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1043	delivery	5	34
6201	2019-08-14 18:08:35	2019-08-14	17	[{"id_menu":4,"count":1}]	2352	delivery	5	22
6202	2019-08-14 18:57:20	2019-08-14	9	[{"id_menu":6,"count":1}]	1794	delivery	5	14
6203	2019-08-14 19:32:15	2019-08-14	14	[{"id_menu":2,"count":1}]	932	pick-up	0	14
6204	2019-08-14 19:47:30	2019-08-14	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1241	delivery	5	39
6205	2019-08-14 19:58:05	2019-08-14	9	[{"id_menu":6,"count":1}]	29	pick-up	0	9
6206	2019-08-14 20:03:19	2019-08-14	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	2358	pick-up	0	24
6207	2019-08-14 21:17:01	2019-08-14	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1375	pick-up	0	25
6208	2019-08-14 22:17:10	2019-08-14	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1862	pick-up	0	17
6209	2019-08-14 22:35:11	2019-08-14	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1736	delivery	5	26
6210	2019-08-14 22:36:10	2019-08-14	17	[{"id_menu":4,"count":1}]	386	delivery	5	22
6211	2019-08-14 22:36:22	2019-08-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1458	delivery	5	36
6212	2019-08-14 23:01:45	2019-08-14	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2348	pick-up	0	40
6213	2019-08-14 23:14:24	2019-08-14	14	[{"id_menu":2,"count":1}]	2	pick-up	0	14
6214	2019-08-14 23:26:51	2019-08-14	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2082	pick-up	0	20
6215	2019-08-14 23:40:47	2019-08-14	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2213	pick-up	0	25
6216	2019-08-15 00:00:38	2019-08-15	17	[{"id_menu":4,"count":1}]	2360	delivery	5	22
6217	2019-08-15 00:26:14	2019-08-15	12	[{"id_menu":1,"count":1}]	1536	delivery	5	17
6218	2019-08-15 00:34:55	2019-08-15	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	216	pick-up	0	17
6219	2019-08-15 01:05:16	2019-08-15	17	[{"id_menu":4,"count":1}]	2207	delivery	5	22
6220	2019-08-15 01:25:00	2019-08-15	14	[{"id_menu":2,"count":1}]	2371	pick-up	0	14
6221	2019-08-15 01:28:08	2019-08-15	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":3}]	1380	delivery	5	26
6222	2019-08-15 02:14:57	2019-08-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1387	delivery	5	23
6223	2019-08-15 04:27:28	2019-08-15	9	[{"id_menu":7,"count":1}]	1979	pick-up	0	9
6224	2019-08-15 04:34:42	2019-08-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2124	delivery	5	31
6225	2019-08-15 04:41:24	2019-08-15	17	[{"id_menu":4,"count":1}]	982	delivery	5	22
6226	2019-08-15 04:59:04	2019-08-15	9	[{"id_menu":7,"count":1}]	395	pick-up	0	9
6227	2019-08-15 05:09:14	2019-08-15	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1857	delivery	5	37
6228	2019-08-15 05:55:39	2019-08-15	9	[{"id_menu":6,"count":1}]	2244	pick-up	0	9
6229	2019-08-15 06:53:29	2019-08-15	17	[{"id_menu":4,"count":1}]	1555	pick-up	0	17
6230	2019-08-15 07:00:25	2019-08-15	9	[{"id_menu":7,"count":1}]	2367	pick-up	0	9
6231	2019-08-15 07:23:53	2019-08-15	9	[{"id_menu":6,"count":1}]	140	pick-up	0	9
6232	2019-08-15 07:26:55	2019-08-15	12	[{"id_menu":1,"count":1}]	764	delivery	5	17
6233	2019-08-15 07:39:05	2019-08-15	17	[{"id_menu":4,"count":1}]	1537	pick-up	0	17
6234	2019-08-15 07:51:52	2019-08-15	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	669	pick-up	0	21
6235	2019-08-15 08:01:26	2019-08-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	412	delivery	5	28
6236	2019-08-15 08:18:12	2019-08-15	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	482	delivery	5	45
6237	2019-08-15 09:00:32	2019-08-15	9	[{"id_menu":6,"count":1}]	150	pick-up	0	9
6238	2019-08-15 10:50:22	2019-08-15	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1523	pick-up	0	25
6239	2019-08-15 10:52:31	2019-08-15	17	[{"id_menu":4,"count":1}]	2364	pick-up	0	17
6240	2019-08-15 11:05:33	2019-08-15	9	[{"id_menu":6,"count":1}]	790	pick-up	0	9
6241	2019-08-15 11:23:47	2019-08-15	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2373	delivery	5	39
6242	2019-08-15 12:20:39	2019-08-15	14	[{"id_menu":2,"count":1}]	1349	delivery	5	19
6243	2019-08-15 12:27:51	2019-08-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1143	delivery	5	28
6244	2019-08-15 13:14:57	2019-08-15	14	[{"id_menu":2,"count":1}]	2361	pick-up	0	14
6245	2019-08-15 13:18:34	2019-08-15	9	[{"id_menu":6,"count":1}]	1293	delivery	5	14
6246	2019-08-15 13:30:08	2019-08-15	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1393	delivery	5	40
6247	2019-08-15 14:31:44	2019-08-15	9	[{"id_menu":6,"count":1}]	2365	pick-up	0	9
6248	2019-08-15 14:41:48	2019-08-15	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	758	delivery	5	30
6249	2019-08-15 15:11:19	2019-08-15	14	[{"id_menu":2,"count":1}]	2370	pick-up	0	14
6250	2019-08-15 15:11:29	2019-08-15	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1675	pick-up	0	21
6251	2019-08-15 15:17:43	2019-08-15	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	232	pick-up	0	22
6252	2019-08-15 15:29:29	2019-08-15	14	[{"id_menu":2,"count":1}]	743	pick-up	0	14
6253	2019-08-15 15:33:13	2019-08-15	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	135	pick-up	0	31
6254	2019-08-15 15:33:41	2019-08-15	17	[{"id_menu":4,"count":1}]	37	pick-up	0	17
6255	2019-08-15 16:16:47	2019-08-15	9	[{"id_menu":6,"count":1}]	2368	pick-up	0	9
6256	2019-08-15 16:31:06	2019-08-15	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	467	pick-up	0	26
6257	2019-08-15 16:33:07	2019-08-15	12	[{"id_menu":1,"count":1}]	404	pick-up	0	12
6258	2019-08-15 17:16:08	2019-08-15	12	[{"id_menu":3,"count":1}]	1051	pick-up	0	12
6259	2019-08-15 17:21:06	2019-08-15	9	[{"id_menu":6,"count":1}]	2363	pick-up	0	9
6260	2019-08-15 17:30:48	2019-08-15	14	[{"id_menu":2,"count":1}]	934	pick-up	0	14
6261	2019-08-15 17:36:37	2019-08-15	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1376	delivery	5	25
6262	2019-08-15 17:38:16	2019-08-15	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	941	pick-up	0	31
6263	2019-08-15 18:29:00	2019-08-15	17	[{"id_menu":4,"count":1}]	1212	pick-up	0	17
6264	2019-08-15 20:47:03	2019-08-15	9	[{"id_menu":7,"count":1}]	1944	delivery	5	14
6265	2019-08-15 21:00:05	2019-08-15	12	[{"id_menu":3,"count":1}]	1096	pick-up	0	12
6266	2019-08-15 21:12:17	2019-08-15	8	[{"id_menu":5,"count":1}]	49	pick-up	0	8
6267	2019-08-15 22:00:24	2019-08-15	14	[{"id_menu":2,"count":1}]	2366	pick-up	0	14
6268	2019-08-15 23:14:39	2019-08-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1970	pick-up	0	23
6269	2019-08-15 23:28:07	2019-08-15	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2362	delivery	5	36
6270	2019-08-15 23:42:39	2019-08-15	9	[{"id_menu":7,"count":1}]	2339	delivery	5	14
6271	2019-08-15 23:57:43	2019-08-15	9	[{"id_menu":7,"count":1}]	1377	delivery	5	14
6272	2019-08-16 01:35:31	2019-08-16	12	[{"id_menu":1,"count":1}]	2358	delivery	5	17
6273	2019-08-16 02:38:17	2019-08-16	8	[{"id_menu":5,"count":1}]	2388	pick-up	0	8
6274	2019-08-16 03:11:54	2019-08-16	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2389	pick-up	0	21
6275	2019-08-16 03:20:30	2019-08-16	12	[{"id_menu":3,"count":1}]	1627	pick-up	0	12
6276	2019-08-16 04:35:14	2019-08-16	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1228	pick-up	0	21
6277	2019-08-16 04:47:28	2019-08-16	17	[{"id_menu":4,"count":1}]	2028	pick-up	0	17
6278	2019-08-16 05:12:29	2019-08-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	547	delivery	5	23
6279	2019-08-16 05:39:07	2019-08-16	14	[{"id_menu":2,"count":1}]	2380	delivery	5	19
6280	2019-08-16 06:22:05	2019-08-16	12	[{"id_menu":1,"count":1}]	2374	pick-up	0	12
6281	2019-08-16 06:25:02	2019-08-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2	delivery	5	23
6282	2019-08-16 07:24:32	2019-08-16	14	[{"id_menu":2,"count":1}]	2282	pick-up	0	14
6283	2019-08-16 07:34:42	2019-08-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	1325	delivery	5	22
6284	2019-08-16 07:37:51	2019-08-16	17	[{"id_menu":4,"count":1}]	1780	pick-up	0	17
6285	2019-08-16 07:50:20	2019-08-16	14	[{"id_menu":2,"count":1}]	482	delivery	5	19
6286	2019-08-16 08:14:43	2019-08-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	669	pick-up	0	17
6287	2019-08-16 08:56:24	2019-08-16	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	2354	pick-up	0	17
6288	2019-08-16 09:11:14	2019-08-16	17	[{"id_menu":4,"count":1}]	2385	pick-up	0	17
6289	2019-08-16 09:11:28	2019-08-16	14	[{"id_menu":2,"count":1}]	1343	pick-up	0	14
6290	2019-08-16 09:21:30	2019-08-16	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1303	delivery	5	27
6291	2019-08-16 09:37:07	2019-08-16	14	[{"id_menu":2,"count":1}]	447	delivery	5	19
6292	2019-08-16 09:37:28	2019-08-16	9	[{"id_menu":6,"count":1}]	92	pick-up	0	9
6293	2019-08-16 10:12:13	2019-08-16	9	[{"id_menu":6,"count":1}]	1044	pick-up	0	9
6294	2019-08-16 12:04:16	2019-08-16	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2375	pick-up	0	21
6295	2019-08-16 12:31:21	2019-08-16	12	[{"id_menu":3,"count":1}]	2390	delivery	5	17
6296	2019-08-16 14:03:28	2019-08-16	12	[{"id_menu":1,"count":1}]	980	pick-up	0	12
6297	2019-08-16 15:16:55	2019-08-16	17	[{"id_menu":4,"count":1}]	171	delivery	5	22
6298	2019-08-16 15:26:18	2019-08-16	9	[{"id_menu":6,"count":1}]	90	pick-up	0	9
6299	2019-08-16 15:40:14	2019-08-16	9	[{"id_menu":6,"count":1}]	2378	delivery	5	14
6300	2019-08-16 15:45:57	2019-08-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	676	pick-up	0	21
6301	2019-08-16 16:20:09	2019-08-16	9	[{"id_menu":6,"count":1}]	2377	delivery	5	14
6302	2019-08-16 16:46:24	2019-08-16	8	[{"id_menu":5,"count":1}]	2384	delivery	5	13
6303	2019-08-16 16:58:32	2019-08-16	9	[{"id_menu":7,"count":1}]	2383	delivery	5	14
6304	2019-08-16 17:16:25	2019-08-16	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	1374	pick-up	0	38
6305	2019-08-16 17:37:36	2019-08-16	14	[{"id_menu":2,"count":1}]	1682	pick-up	0	14
6306	2019-08-16 17:40:03	2019-08-16	12	[{"id_menu":1,"count":1}]	32	pick-up	0	12
6307	2019-08-16 17:45:03	2019-08-16	12	[{"id_menu":1,"count":1}]	2381	pick-up	0	12
6308	2019-08-16 19:16:53	2019-08-16	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1937	delivery	5	54
6309	2019-08-16 19:28:11	2019-08-16	17	[{"id_menu":4,"count":1}]	372	pick-up	0	17
6310	2019-08-16 19:59:52	2019-08-16	14	[{"id_menu":2,"count":1}]	244	delivery	5	19
6311	2019-08-16 20:09:45	2019-08-16	17	[{"id_menu":4,"count":1}]	236	pick-up	0	17
6312	2019-08-16 21:04:12	2019-08-16	9	[{"id_menu":6,"count":1}]	2387	pick-up	0	9
6313	2019-08-16 21:13:52	2019-08-16	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2382	pick-up	0	26
6314	2019-08-16 22:03:00	2019-08-16	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2252	pick-up	0	20
6315	2019-08-16 22:09:00	2019-08-16	12	[{"id_menu":3,"count":1}]	1101	pick-up	0	12
6316	2019-08-16 23:56:12	2019-08-16	12	[{"id_menu":1,"count":1}]	1536	pick-up	0	12
6317	2019-08-17 00:01:18	2019-08-17	9	[{"id_menu":7,"count":1}]	2072	delivery	5	14
6318	2019-08-17 00:01:34	2019-08-17	9	[{"id_menu":6,"count":1}]	529	pick-up	0	9
6319	2019-08-17 00:09:54	2019-08-17	9	[{"id_menu":6,"count":1}]	932	delivery	5	14
6320	2019-08-17 00:14:45	2019-08-17	9	[{"id_menu":6,"count":1}]	1334	pick-up	0	9
6321	2019-08-17 00:22:27	2019-08-17	14	[{"id_menu":2,"count":1}]	1257	delivery	5	19
6322	2019-08-17 00:51:00	2019-08-17	17	[{"id_menu":4,"count":1}]	1449	pick-up	0	17
6323	2019-08-17 01:02:41	2019-08-17	12	[{"id_menu":1,"count":1}]	376	pick-up	0	12
6324	2019-08-17 02:00:50	2019-08-17	17	[{"id_menu":4,"count":1}]	1469	delivery	5	22
6325	2019-08-17 02:06:28	2019-08-17	17	[{"id_menu":4,"count":2}]	2391	delivery	5	22
6326	2019-08-17 02:37:11	2019-08-17	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	71	pick-up	0	31
6327	2019-08-17 02:41:43	2019-08-17	9	[{"id_menu":7,"count":1}]	299	pick-up	0	9
6328	2019-08-17 03:00:05	2019-08-17	17	[{"id_menu":4,"count":1}]	2401	pick-up	0	17
6329	2019-08-17 03:24:23	2019-08-17	12	[{"id_menu":1,"count":1}]	966	pick-up	0	12
6330	2019-08-17 03:31:06	2019-08-17	17	[{"id_menu":4,"count":1}]	1754	delivery	5	22
6331	2019-08-17 03:40:35	2019-08-17	12	[{"id_menu":1,"count":1}]	142	pick-up	0	12
6332	2019-08-17 03:58:44	2019-08-17	9	[{"id_menu":6,"count":1}]	1536	pick-up	0	9
6333	2019-08-17 05:35:50	2019-08-17	17	[{"id_menu":4,"count":1}]	2397	pick-up	0	17
6334	2019-08-17 07:42:33	2019-08-17	9	[{"id_menu":6,"count":1}]	221	pick-up	0	9
6335	2019-08-17 08:01:16	2019-08-17	9	[{"id_menu":7,"count":1}]	1686	delivery	5	14
6336	2019-08-17 08:09:25	2019-08-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	784	pick-up	0	23
6337	2019-08-17 08:11:46	2019-08-17	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	271	pick-up	0	17
6338	2019-08-17 08:17:39	2019-08-17	14	[{"id_menu":2,"count":1}]	1008	delivery	5	19
6339	2019-08-17 08:25:37	2019-08-17	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2404	pick-up	0	17
6340	2019-08-17 08:33:43	2019-08-17	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1094	pick-up	0	26
6341	2019-08-17 09:15:42	2019-08-17	9	[{"id_menu":7,"count":1}]	2149	pick-up	0	9
6342	2019-08-17 09:25:52	2019-08-17	9	[{"id_menu":6,"count":1}]	1258	pick-up	0	9
6343	2019-08-17 09:34:22	2019-08-17	14	[{"id_menu":2,"count":1}]	543	delivery	5	19
6344	2019-08-17 10:19:37	2019-08-17	14	[{"id_menu":2,"count":1}]	1825	delivery	5	19
6345	2019-08-17 10:45:33	2019-08-17	12	[{"id_menu":1,"count":1}]	1393	delivery	5	17
6346	2019-08-17 11:07:33	2019-08-17	12	[{"id_menu":1,"count":1}]	2197	delivery	5	17
6347	2019-08-17 11:19:04	2019-08-17	9	[{"id_menu":7,"count":2}]	2406	delivery	5	14
6348	2019-08-17 11:32:46	2019-08-17	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	2405	pick-up	0	39
6349	2019-08-17 11:36:51	2019-08-17	17	[{"id_menu":4,"count":1}]	158	delivery	5	22
6350	2019-08-17 11:54:27	2019-08-17	17	[{"id_menu":4,"count":1}]	477	pick-up	0	17
6351	2019-08-17 12:07:48	2019-08-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2403	pick-up	0	23
6352	2019-08-17 13:12:28	2019-08-17	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1525	delivery	5	26
6353	2019-08-17 13:52:26	2019-08-17	9	[{"id_menu":6,"count":1}]	310	delivery	5	14
6354	2019-08-17 13:54:02	2019-08-17	12	[{"id_menu":1,"count":1}]	187	pick-up	0	12
6355	2019-08-17 14:25:39	2019-08-17	12	[{"id_menu":3,"count":1}]	1839	pick-up	0	12
6356	2019-08-17 14:26:02	2019-08-17	12	[{"id_menu":3,"count":1}]	371	delivery	5	17
6357	2019-08-17 15:24:26	2019-08-17	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	2076	pick-up	0	38
6358	2019-08-17 15:27:36	2019-08-17	12	[{"id_menu":3,"count":1}]	1640	pick-up	0	12
6359	2019-08-17 16:04:36	2019-08-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	397	delivery	5	23
6360	2019-08-17 16:11:49	2019-08-17	12	[{"id_menu":1,"count":1}]	2392	pick-up	0	12
6361	2019-08-17 16:24:01	2019-08-17	14	[{"id_menu":2,"count":1}]	2399	pick-up	0	14
6362	2019-08-17 16:51:30	2019-08-17	14	[{"id_menu":2,"count":2}]	2400	pick-up	0	14
6363	2019-08-17 17:22:46	2019-08-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1861	pick-up	0	26
6364	2019-08-17 17:58:20	2019-08-17	12	[{"id_menu":1,"count":1}]	870	delivery	5	17
6365	2019-08-17 18:22:07	2019-08-17	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2408	delivery	5	31
6366	2019-08-17 18:25:38	2019-08-17	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	707	delivery	5	40
6367	2019-08-17 19:06:34	2019-08-17	12	[{"id_menu":1,"count":1}]	1296	pick-up	0	12
6368	2019-08-17 19:14:51	2019-08-17	9	[{"id_menu":6,"count":1}]	2393	delivery	5	14
6369	2019-08-17 20:15:11	2019-08-17	14	[{"id_menu":2,"count":1}]	925	delivery	5	19
6370	2019-08-17 20:19:44	2019-08-17	9	[{"id_menu":6,"count":1}]	1453	delivery	5	14
6371	2019-08-17 21:10:17	2019-08-17	9	[{"id_menu":6,"count":1}]	2289	pick-up	0	9
6372	2019-08-17 21:20:36	2019-08-17	12	[{"id_menu":3,"count":1}]	2025	pick-up	0	12
6373	2019-08-17 21:32:31	2019-08-17	14	[{"id_menu":2,"count":1}]	1663	delivery	5	19
6374	2019-08-17 21:50:40	2019-08-17	12	[{"id_menu":3,"count":1}]	806	delivery	5	17
6375	2019-08-17 21:56:16	2019-08-17	12	[{"id_menu":3,"count":1}]	2293	pick-up	0	12
6376	2019-08-17 22:37:51	2019-08-17	14	[{"id_menu":2,"count":2}]	2396	delivery	5	19
6377	2019-08-17 22:43:54	2019-08-17	17	[{"id_menu":4,"count":2}]	2398	delivery	5	22
6378	2019-08-17 23:07:45	2019-08-17	14	[{"id_menu":2,"count":1}]	2402	pick-up	0	14
6379	2019-08-17 23:15:29	2019-08-17	17	[{"id_menu":4,"count":1}]	381	pick-up	0	17
6380	2019-08-17 23:23:03	2019-08-17	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2407	pick-up	0	17
6381	2019-08-17 23:31:30	2019-08-17	14	[{"id_menu":2,"count":1}]	802	delivery	5	19
6382	2019-08-17 23:34:40	2019-08-17	8	[{"id_menu":5,"count":1}]	2394	pick-up	0	8
6383	2019-08-17 23:49:28	2019-08-17	9	[{"id_menu":6,"count":1}]	1397	pick-up	0	9
6384	2019-08-18 00:01:50	2019-08-18	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	195	pick-up	0	38
6385	2019-08-18 00:08:18	2019-08-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2179	pick-up	0	17
6386	2019-08-18 00:12:15	2019-08-18	12	[{"id_menu":1,"count":1}]	506	delivery	5	17
6387	2019-08-18 00:14:26	2019-08-18	9	[{"id_menu":7,"count":2}]	1781	pick-up	0	9
6388	2019-08-18 00:52:03	2019-08-18	9	[{"id_menu":6,"count":1}]	743	pick-up	0	9
6389	2019-08-18 00:53:04	2019-08-18	17	[{"id_menu":4,"count":1}]	2217	pick-up	0	17
6390	2019-08-18 01:10:34	2019-08-18	17	[{"id_menu":4,"count":2}]	2413	pick-up	0	17
6391	2019-08-18 01:35:36	2019-08-18	9	[{"id_menu":6,"count":1}]	1025	pick-up	0	9
6392	2019-08-18 02:06:32	2019-08-18	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	2422	delivery	5	34
6393	2019-08-18 02:49:58	2019-08-18	9	[{"id_menu":6,"count":1}]	1910	pick-up	0	9
6394	2019-08-18 02:58:24	2019-08-18	12	[{"id_menu":3,"count":1}]	2410	pick-up	0	12
6395	2019-08-18 03:18:32	2019-08-18	14	[{"id_menu":2,"count":1}]	709	pick-up	0	14
6396	2019-08-18 03:22:26	2019-08-18	9	[{"id_menu":6,"count":1}]	319	pick-up	0	9
6397	2019-08-18 03:26:19	2019-08-18	9	[{"id_menu":6,"count":1}]	2055	pick-up	0	9
6398	2019-08-18 03:28:18	2019-08-18	12	[{"id_menu":1,"count":1}]	382	pick-up	0	12
6399	2019-08-18 03:35:08	2019-08-18	14	[{"id_menu":2,"count":1}]	2252	pick-up	0	14
6400	2019-08-18 03:36:09	2019-08-18	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2425	pick-up	0	34
6401	2019-08-18 03:37:04	2019-08-18	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2189	pick-up	0	29
6402	2019-08-18 03:41:17	2019-08-18	14	[{"id_menu":2,"count":1}]	2358	delivery	5	19
6403	2019-08-18 04:26:30	2019-08-18	9	[{"id_menu":7,"count":1}]	269	pick-up	0	9
6404	2019-08-18 04:27:49	2019-08-18	14	[{"id_menu":2,"count":1}]	389	pick-up	0	14
6405	2019-08-18 05:28:00	2019-08-18	9	[{"id_menu":7,"count":1}]	242	delivery	5	14
6406	2019-08-18 06:12:16	2019-08-18	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1854	pick-up	0	26
6407	2019-08-18 06:35:42	2019-08-18	17	[{"id_menu":4,"count":1}]	2417	delivery	5	22
6408	2019-08-18 06:52:24	2019-08-18	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1272	delivery	5	52
6409	2019-08-18 07:14:58	2019-08-18	9	[{"id_menu":6,"count":1}]	1337	pick-up	0	9
6410	2019-08-18 07:34:47	2019-08-18	12	[{"id_menu":1,"count":1}]	1269	pick-up	0	12
6411	2019-08-18 07:52:09	2019-08-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	378	delivery	5	28
6412	2019-08-18 09:51:34	2019-08-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2409	delivery	5	28
6413	2019-08-18 10:04:30	2019-08-18	8	[{"id_menu":5,"count":1}]	1532	delivery	5	13
6414	2019-08-18 10:12:47	2019-08-18	14	[{"id_menu":2,"count":1}]	2418	pick-up	0	14
6415	2019-08-18 10:14:05	2019-08-18	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	36	pick-up	0	52
6416	2019-08-18 10:19:53	2019-08-18	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	857	delivery	5	43
6417	2019-08-18 10:44:22	2019-08-18	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2369	delivery	5	30
6418	2019-08-18 11:22:01	2019-08-18	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	2420	delivery	5	29
6419	2019-08-18 11:26:11	2019-08-18	9	[{"id_menu":7,"count":1}]	1674	pick-up	0	9
6420	2019-08-18 11:43:20	2019-08-18	12	[{"id_menu":1,"count":1}]	1164	delivery	5	17
6421	2019-08-18 11:58:16	2019-08-18	9	[{"id_menu":7,"count":1}]	1761	delivery	5	14
6422	2019-08-18 12:27:52	2019-08-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2004	pick-up	0	23
6423	2019-08-18 12:34:09	2019-08-18	17	[{"id_menu":4,"count":1}]	279	delivery	5	22
6424	2019-08-18 13:00:04	2019-08-18	17	[{"id_menu":4,"count":1}]	2415	pick-up	0	17
6425	2019-08-18 13:24:50	2019-08-18	9	[{"id_menu":7,"count":1}]	2226	delivery	5	14
6426	2019-08-18 13:40:36	2019-08-18	8	[{"id_menu":5,"count":1}]	433	pick-up	0	8
6427	2019-08-18 14:39:34	2019-08-18	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2416	pick-up	0	20
6428	2019-08-18 14:40:20	2019-08-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1390	pick-up	0	23
6429	2019-08-18 14:58:19	2019-08-18	8	[{"id_menu":5,"count":1}]	2426	pick-up	0	8
6430	2019-08-18 15:06:24	2019-08-18	12	[{"id_menu":1,"count":1}]	176	delivery	5	17
6431	2019-08-18 15:25:37	2019-08-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2419	delivery	5	22
6432	2019-08-18 15:44:37	2019-08-18	14	[{"id_menu":2,"count":1}]	1370	pick-up	0	14
6433	2019-08-18 15:48:12	2019-08-18	8	[{"id_menu":5,"count":1}]	1314	delivery	5	13
6434	2019-08-18 16:16:40	2019-08-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2412	pick-up	0	18
6435	2019-08-18 16:28:40	2019-08-18	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	362	delivery	5	22
6436	2019-08-18 16:35:11	2019-08-18	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1200	delivery	5	31
6437	2019-08-18 16:37:38	2019-08-18	14	[{"id_menu":2,"count":1}]	2424	delivery	5	19
6438	2019-08-18 17:00:18	2019-08-18	17	[{"id_menu":4,"count":1}]	838	delivery	5	22
6439	2019-08-18 17:10:53	2019-08-18	17	[{"id_menu":4,"count":1}]	2421	pick-up	0	17
6440	2019-08-18 17:22:51	2019-08-18	17	[{"id_menu":4,"count":1}]	1196	pick-up	0	17
6441	2019-08-18 17:29:04	2019-08-18	14	[{"id_menu":2,"count":1}]	1103	pick-up	0	14
6442	2019-08-18 18:23:53	2019-08-18	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	826	pick-up	0	40
6443	2019-08-18 18:36:41	2019-08-18	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2199	delivery	5	45
6444	2019-08-18 18:39:08	2019-08-18	9	[{"id_menu":7,"count":1}]	2095	delivery	5	14
6445	2019-08-18 18:49:41	2019-08-18	9	[{"id_menu":7,"count":1}]	2041	delivery	5	14
6446	2019-08-18 19:31:04	2019-08-18	9	[{"id_menu":7,"count":1}]	323	delivery	5	14
6447	2019-08-18 19:39:43	2019-08-18	12	[{"id_menu":3,"count":1}]	1303	pick-up	0	12
6448	2019-08-18 19:42:20	2019-08-18	17	[{"id_menu":4,"count":1}]	2277	pick-up	0	17
6449	2019-08-18 19:48:22	2019-08-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	359	pick-up	0	23
6450	2019-08-18 20:01:36	2019-08-18	12	[{"id_menu":1,"count":1}]	314	pick-up	0	12
6451	2019-08-18 20:11:36	2019-08-18	9	[{"id_menu":6,"count":1}]	1239	pick-up	0	9
6452	2019-08-18 20:21:28	2019-08-18	12	[{"id_menu":3,"count":1}]	740	pick-up	0	12
6453	2019-08-18 20:21:58	2019-08-18	9	[{"id_menu":6,"count":1}]	730	delivery	5	14
6454	2019-08-18 21:08:35	2019-08-18	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	536	pick-up	0	31
6455	2019-08-18 21:11:11	2019-08-18	14	[{"id_menu":2,"count":1}]	2246	pick-up	0	14
6456	2019-08-18 21:28:59	2019-08-18	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	287	pick-up	0	26
6457	2019-08-18 21:31:13	2019-08-18	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	581	delivery	5	40
6458	2019-08-18 21:40:29	2019-08-18	17	[{"id_menu":4,"count":1}]	778	delivery	5	22
6459	2019-08-18 21:45:47	2019-08-18	12	[{"id_menu":3,"count":1}]	2085	pick-up	0	12
6460	2019-08-18 22:31:49	2019-08-18	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2411	delivery	5	30
6461	2019-08-18 22:50:46	2019-08-18	12	[{"id_menu":3,"count":1}]	699	delivery	5	17
6462	2019-08-18 22:52:48	2019-08-18	12	[{"id_menu":1,"count":1}]	2423	pick-up	0	12
6463	2019-08-18 23:08:29	2019-08-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	840	delivery	5	23
6464	2019-08-18 23:32:17	2019-08-18	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1902	pick-up	0	29
6465	2019-08-18 23:41:59	2019-08-18	9	[{"id_menu":7,"count":1}]	47	pick-up	0	9
6466	2019-08-18 23:44:16	2019-08-18	14	[{"id_menu":2,"count":1}]	2414	delivery	5	19
6467	2019-08-19 00:04:04	2019-08-19	9	[{"id_menu":6,"count":1}]	1610	delivery	5	14
6468	2019-08-19 00:04:30	2019-08-19	14	[{"id_menu":2,"count":2}]	2439	pick-up	0	14
6469	2019-08-19 00:06:20	2019-08-19	17	[{"id_menu":4,"count":1}]	1322	delivery	5	22
6470	2019-08-19 01:38:13	2019-08-19	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1207	delivery	5	43
6471	2019-08-19 02:42:04	2019-08-19	12	[{"id_menu":1,"count":1}]	2441	pick-up	0	12
6472	2019-08-19 04:39:11	2019-08-19	12	[{"id_menu":1,"count":1}]	2437	pick-up	0	12
6473	2019-08-19 04:40:57	2019-08-19	14	[{"id_menu":2,"count":1}]	1435	delivery	5	19
6474	2019-08-19 04:41:22	2019-08-19	14	[{"id_menu":2,"count":1}]	352	delivery	5	19
6475	2019-08-19 04:53:05	2019-08-19	8	[{"id_menu":5,"count":1}]	766	pick-up	0	8
6476	2019-08-19 06:03:12	2019-08-19	12	[{"id_menu":3,"count":1}]	1104	pick-up	0	12
6477	2019-08-19 06:05:34	2019-08-19	17	[{"id_menu":4,"count":2}]	1677	delivery	5	22
6478	2019-08-19 07:28:12	2019-08-19	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	2015	pick-up	0	20
6479	2019-08-19 07:35:47	2019-08-19	17	[{"id_menu":4,"count":1}]	1212	pick-up	0	17
6480	2019-08-19 07:42:32	2019-08-19	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	362	delivery	5	34
6481	2019-08-19 08:00:20	2019-08-19	9	[{"id_menu":6,"count":1}]	2428	delivery	5	14
6482	2019-08-19 08:08:07	2019-08-19	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2440	delivery	5	35
6483	2019-08-19 08:38:58	2019-08-19	17	[{"id_menu":4,"count":1}]	1778	pick-up	0	17
6484	2019-08-19 09:13:01	2019-08-19	17	[{"id_menu":4,"count":1}]	397	delivery	5	22
6485	2019-08-19 10:12:30	2019-08-19	14	[{"id_menu":2,"count":1}]	1115	pick-up	0	14
6486	2019-08-19 10:58:44	2019-08-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2425	delivery	5	28
6487	2019-08-19 11:26:23	2019-08-19	14	[{"id_menu":2,"count":1}]	2436	pick-up	0	14
6488	2019-08-19 12:01:41	2019-08-19	17	[{"id_menu":4,"count":1}]	76	pick-up	0	17
6489	2019-08-19 12:05:07	2019-08-19	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	1800	pick-up	0	26
6490	2019-08-19 13:12:29	2019-08-19	8	[{"id_menu":5,"count":1}]	315	pick-up	0	8
6491	2019-08-19 14:52:11	2019-08-19	17	[{"id_menu":4,"count":1}]	2438	pick-up	0	17
6492	2019-08-19 17:04:31	2019-08-19	9	[{"id_menu":7,"count":1}]	328	delivery	5	14
6493	2019-08-19 17:19:48	2019-08-19	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2429	pick-up	0	21
6494	2019-08-19 17:20:13	2019-08-19	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2367	pick-up	0	22
6495	2019-08-19 17:52:13	2019-08-19	17	[{"id_menu":4,"count":1}]	120	pick-up	0	17
6496	2019-08-19 18:17:06	2019-08-19	14	[{"id_menu":2,"count":1}]	627	delivery	5	19
6497	2019-08-19 18:35:48	2019-08-19	14	[{"id_menu":2,"count":1}]	2041	pick-up	0	14
6498	2019-08-19 20:22:46	2019-08-19	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2433	pick-up	0	26
6499	2019-08-19 20:56:33	2019-08-19	17	[{"id_menu":4,"count":1}]	1266	pick-up	0	17
6500	2019-08-19 23:19:44	2019-08-19	8	[{"id_menu":5,"count":1}]	286	pick-up	0	8
6501	2019-08-19 23:27:56	2019-08-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2110	pick-up	0	18
6502	2019-08-19 23:49:56	2019-08-19	17	[{"id_menu":4,"count":1}]	826	delivery	5	22
6503	2019-08-20 00:23:31	2019-08-20	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	66	delivery	5	31
6504	2019-08-20 00:24:42	2019-08-20	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2000	pick-up	0	21
6505	2019-08-20 01:01:46	2019-08-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	528	delivery	5	28
6506	2019-08-20 02:06:40	2019-08-20	12	[{"id_menu":1,"count":1}]	1424	pick-up	0	12
6507	2019-08-20 02:37:44	2019-08-20	12	[{"id_menu":3,"count":1}]	1072	delivery	5	17
6508	2019-08-20 03:10:32	2019-08-20	9	[{"id_menu":7,"count":1}]	2334	delivery	5	14
6509	2019-08-20 03:30:42	2019-08-20	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1679	pick-up	0	26
6510	2019-08-20 03:42:46	2019-08-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2447	pick-up	0	18
6511	2019-08-20 04:00:22	2019-08-20	9	[{"id_menu":6,"count":1}]	1085	pick-up	0	9
6512	2019-08-20 04:01:34	2019-08-20	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2454	pick-up	0	29
6583	2019-08-21 12:38:50	2019-08-21	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	2192	delivery	5	28
6513	2019-08-20 04:35:50	2019-08-20	34	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	2442	pick-up	0	34
6514	2019-08-20 04:44:30	2019-08-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1173	delivery	5	28
6515	2019-08-20 04:53:31	2019-08-20	17	[{"id_menu":4,"count":1}]	299	pick-up	0	17
6516	2019-08-20 06:14:37	2019-08-20	14	[{"id_menu":2,"count":2}]	1168	delivery	5	19
6517	2019-08-20 06:40:03	2019-08-20	14	[{"id_menu":2,"count":1}]	1273	pick-up	0	14
6518	2019-08-20 07:03:26	2019-08-20	12	[{"id_menu":3,"count":1}]	2384	delivery	5	17
6519	2019-08-20 07:04:34	2019-08-20	12	[{"id_menu":1,"count":1}]	1811	pick-up	0	12
6520	2019-08-20 08:17:47	2019-08-20	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2449	pick-up	0	21
6521	2019-08-20 08:40:51	2019-08-20	9	[{"id_menu":7,"count":1}]	2444	delivery	5	14
6522	2019-08-20 09:06:17	2019-08-20	17	[{"id_menu":4,"count":1}]	1119	delivery	5	22
6523	2019-08-20 10:27:12	2019-08-20	9	[{"id_menu":6,"count":1}]	2366	pick-up	0	9
6524	2019-08-20 10:57:53	2019-08-20	12	[{"id_menu":1,"count":2}]	1618	pick-up	0	12
6525	2019-08-20 12:10:17	2019-08-20	12	[{"id_menu":1,"count":2}]	183	pick-up	0	12
6526	2019-08-20 13:07:49	2019-08-20	8	[{"id_menu":5,"count":1}]	1677	delivery	5	13
6527	2019-08-20 13:22:25	2019-08-20	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	787	pick-up	0	25
6528	2019-08-20 14:38:58	2019-08-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2445	delivery	5	28
6529	2019-08-20 14:49:16	2019-08-20	14	[{"id_menu":2,"count":1}]	709	pick-up	0	14
6530	2019-08-20 14:54:22	2019-08-20	14	[{"id_menu":2,"count":1}]	400	pick-up	0	14
6531	2019-08-20 14:54:27	2019-08-20	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2452	delivery	5	34
6532	2019-08-20 14:56:09	2019-08-20	9	[{"id_menu":7,"count":1}]	172	pick-up	0	9
6533	2019-08-20 16:05:35	2019-08-20	9	[{"id_menu":6,"count":1}]	1276	pick-up	0	9
6534	2019-08-20 16:25:57	2019-08-20	12	[{"id_menu":3,"count":1}]	1095	delivery	5	17
6535	2019-08-20 16:27:27	2019-08-20	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2443	pick-up	0	26
6536	2019-08-20 16:33:36	2019-08-20	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1070	pick-up	0	20
6537	2019-08-20 17:39:29	2019-08-20	17	[{"id_menu":4,"count":1}]	396	pick-up	0	17
6538	2019-08-20 18:17:45	2019-08-20	9	[{"id_menu":6,"count":1}]	1678	delivery	5	14
6539	2019-08-20 18:47:25	2019-08-20	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	314	pick-up	0	34
6540	2019-08-20 19:23:58	2019-08-20	12	[{"id_menu":3,"count":1}]	2446	pick-up	0	12
6541	2019-08-20 21:23:53	2019-08-20	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2451	delivery	5	31
6542	2019-08-20 21:54:52	2019-08-20	12	[{"id_menu":1,"count":1}]	2070	pick-up	0	12
6543	2019-08-20 21:57:31	2019-08-20	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2450	pick-up	0	26
6544	2019-08-20 22:04:38	2019-08-20	17	[{"id_menu":4,"count":1}]	1317	pick-up	0	17
6545	2019-08-20 22:09:11	2019-08-20	8	[{"id_menu":5,"count":1}]	393	delivery	5	13
6546	2019-08-20 22:27:43	2019-08-20	17	[{"id_menu":4,"count":1}]	246	pick-up	0	17
6547	2019-08-20 22:45:52	2019-08-20	14	[{"id_menu":2,"count":1}]	1900	pick-up	0	14
6548	2019-08-20 23:20:52	2019-08-20	9	[{"id_menu":6,"count":1}]	228	pick-up	0	9
6549	2019-08-21 01:24:07	2019-08-21	9	[{"id_menu":7,"count":1}]	1485	delivery	5	14
6550	2019-08-21 01:47:12	2019-08-21	8	[{"id_menu":5,"count":1}]	2207	pick-up	0	8
6551	2019-08-21 02:00:03	2019-08-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2466	delivery	5	28
6552	2019-08-21 02:18:21	2019-08-21	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	2465	delivery	5	25
6553	2019-08-21 02:34:24	2019-08-21	12	[{"id_menu":1,"count":1}]	377	pick-up	0	12
6554	2019-08-21 02:44:01	2019-08-21	17	[{"id_menu":4,"count":1}]	2253	delivery	5	22
6555	2019-08-21 02:48:38	2019-08-21	8	[{"id_menu":5,"count":1}]	1424	pick-up	0	8
6556	2019-08-21 02:55:43	2019-08-21	14	[{"id_menu":2,"count":1}]	2101	delivery	5	19
6557	2019-08-21 02:59:25	2019-08-21	9	[{"id_menu":6,"count":1}]	1614	pick-up	0	9
6558	2019-08-21 03:04:06	2019-08-21	12	[{"id_menu":1,"count":1}]	158	pick-up	0	12
6559	2019-08-21 03:29:43	2019-08-21	14	[{"id_menu":2,"count":1}]	2467	delivery	5	19
6560	2019-08-21 03:37:56	2019-08-21	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2317	pick-up	0	21
6561	2019-08-21 03:54:57	2019-08-21	17	[{"id_menu":4,"count":1}]	1116	delivery	5	22
6562	2019-08-21 03:58:03	2019-08-21	12	[{"id_menu":1,"count":1}]	2397	delivery	5	17
6563	2019-08-21 05:38:51	2019-08-21	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2404	delivery	5	27
6564	2019-08-21 05:42:55	2019-08-21	12	[{"id_menu":1,"count":1}]	777	pick-up	0	12
6565	2019-08-21 06:57:08	2019-08-21	9	[{"id_menu":6,"count":1}]	2310	delivery	5	14
6566	2019-08-21 07:02:11	2019-08-21	9	[{"id_menu":7,"count":1}]	2460	pick-up	0	9
6567	2019-08-21 07:02:53	2019-08-21	12	[{"id_menu":1,"count":1}]	1819	pick-up	0	12
6568	2019-08-21 08:09:22	2019-08-21	9	[{"id_menu":7,"count":1}]	784	pick-up	0	9
6569	2019-08-21 08:48:09	2019-08-21	14	[{"id_menu":2,"count":1}]	1344	delivery	5	19
6570	2019-08-21 08:50:20	2019-08-21	17	[{"id_menu":4,"count":1}]	1659	pick-up	0	17
6571	2019-08-21 08:52:33	2019-08-21	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	2468	pick-up	0	29
6572	2019-08-21 08:55:56	2019-08-21	12	[{"id_menu":3,"count":1}]	2398	pick-up	0	12
6573	2019-08-21 09:01:48	2019-08-21	8	[{"id_menu":5,"count":1}]	932	pick-up	0	8
6574	2019-08-21 09:02:21	2019-08-21	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1665	delivery	5	31
6575	2019-08-21 09:05:00	2019-08-21	9	[{"id_menu":6,"count":1}]	2463	pick-up	0	9
6576	2019-08-21 09:49:30	2019-08-21	12	[{"id_menu":1,"count":1}]	1860	pick-up	0	12
6577	2019-08-21 10:23:52	2019-08-21	12	[{"id_menu":3,"count":1}]	1631	pick-up	0	12
6578	2019-08-21 10:28:10	2019-08-21	9	[{"id_menu":7,"count":1}]	203	pick-up	0	9
6579	2019-08-21 10:44:33	2019-08-21	17	[{"id_menu":4,"count":1}]	511	pick-up	0	17
6580	2019-08-21 11:19:59	2019-08-21	12	[{"id_menu":1,"count":1}]	2459	delivery	5	17
6581	2019-08-21 12:29:25	2019-08-21	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	1072	delivery	5	36
6582	2019-08-21 12:36:08	2019-08-21	9	[{"id_menu":6,"count":1}]	2374	delivery	5	14
6584	2019-08-21 12:46:30	2019-08-21	9	[{"id_menu":6,"count":1}]	716	pick-up	0	9
6585	2019-08-21 13:08:31	2019-08-21	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2458	pick-up	0	43
6586	2019-08-21 13:25:15	2019-08-21	9	[{"id_menu":6,"count":1}]	76	pick-up	0	9
6587	2019-08-21 13:30:29	2019-08-21	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	2469	pick-up	0	24
6588	2019-08-21 13:32:07	2019-08-21	14	[{"id_menu":2,"count":1}]	1586	pick-up	0	14
6589	2019-08-21 14:18:05	2019-08-21	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1164	pick-up	0	26
6590	2019-08-21 15:05:41	2019-08-21	12	[{"id_menu":3,"count":1}]	993	pick-up	0	12
6591	2019-08-21 15:51:07	2019-08-21	14	[{"id_menu":2,"count":1}]	679	delivery	5	19
6592	2019-08-21 16:19:15	2019-08-21	9	[{"id_menu":6,"count":1}]	2333	pick-up	0	9
6593	2019-08-21 17:20:30	2019-08-21	9	[{"id_menu":7,"count":1}]	655	pick-up	0	9
6594	2019-08-21 18:30:01	2019-08-21	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1969	pick-up	0	22
6595	2019-08-21 19:00:56	2019-08-21	9	[{"id_menu":7,"count":1}]	2464	pick-up	0	9
6596	2019-08-21 19:17:27	2019-08-21	8	[{"id_menu":5,"count":1}]	111	delivery	5	13
6597	2019-08-21 19:20:30	2019-08-21	12	[{"id_menu":3,"count":1}]	1448	delivery	5	17
6598	2019-08-21 19:40:21	2019-08-21	8	[{"id_menu":5,"count":1}]	2461	pick-up	0	8
6599	2019-08-21 19:48:23	2019-08-21	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	2415	pick-up	0	20
6600	2019-08-21 20:29:33	2019-08-21	12	[{"id_menu":3,"count":1}]	1280	delivery	5	17
6601	2019-08-21 22:03:46	2019-08-21	9	[{"id_menu":7,"count":1}]	1244	pick-up	0	9
6602	2019-08-21 22:04:18	2019-08-21	8	[{"id_menu":5,"count":1}]	2068	delivery	5	13
6603	2019-08-21 22:14:14	2019-08-21	9	[{"id_menu":7,"count":1}]	1754	pick-up	0	9
6604	2019-08-22 00:15:55	2019-08-22	14	[{"id_menu":2,"count":1}]	899	pick-up	0	14
6605	2019-08-22 00:33:04	2019-08-22	14	[{"id_menu":2,"count":1}]	1674	pick-up	0	14
6606	2019-08-22 00:47:58	2019-08-22	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	2480	pick-up	0	24
6607	2019-08-22 02:16:10	2019-08-22	14	[{"id_menu":2,"count":1}]	2200	pick-up	0	14
6608	2019-08-22 02:19:58	2019-08-22	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1148	delivery	5	25
6609	2019-08-22 02:44:46	2019-08-22	9	[{"id_menu":6,"count":1}]	790	pick-up	0	9
6610	2019-08-22 02:52:24	2019-08-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2472	pick-up	0	23
6611	2019-08-22 02:54:14	2019-08-22	14	[{"id_menu":2,"count":1}]	1523	delivery	5	19
6612	2019-08-22 03:13:06	2019-08-22	12	[{"id_menu":3,"count":1}]	227	delivery	5	17
6613	2019-08-22 03:47:31	2019-08-22	17	[{"id_menu":4,"count":1}]	2477	pick-up	0	17
6614	2019-08-22 04:07:18	2019-08-22	12	[{"id_menu":3,"count":1}]	1231	delivery	5	17
6615	2019-08-22 04:22:58	2019-08-22	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2474	pick-up	0	26
6616	2019-08-22 06:08:00	2019-08-22	9	[{"id_menu":7,"count":1}]	173	pick-up	0	9
6617	2019-08-22 06:11:05	2019-08-22	14	[{"id_menu":2,"count":1}]	1433	delivery	5	19
6618	2019-08-22 06:13:32	2019-08-22	12	[{"id_menu":1,"count":1}]	895	pick-up	0	12
6619	2019-08-22 06:22:47	2019-08-22	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1677	delivery	5	31
6620	2019-08-22 06:29:45	2019-08-22	12	[{"id_menu":1,"count":1}]	2471	pick-up	0	12
6621	2019-08-22 07:04:58	2019-08-22	14	[{"id_menu":2,"count":1}]	2430	pick-up	0	14
6622	2019-08-22 08:46:42	2019-08-22	12	[{"id_menu":1,"count":1}]	2481	pick-up	0	12
6623	2019-08-22 08:47:10	2019-08-22	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	336	delivery	5	25
6624	2019-08-22 09:25:22	2019-08-22	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	509	pick-up	0	21
6625	2019-08-22 09:41:57	2019-08-22	17	[{"id_menu":4,"count":1}]	876	delivery	5	22
6626	2019-08-22 10:06:24	2019-08-22	14	[{"id_menu":2,"count":2}]	1967	delivery	5	19
6627	2019-08-22 10:10:27	2019-08-22	12	[{"id_menu":1,"count":2}]	1461	pick-up	0	12
6628	2019-08-22 11:51:42	2019-08-22	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	74	pick-up	0	26
6629	2019-08-22 12:04:37	2019-08-22	9	[{"id_menu":6,"count":1}]	308	pick-up	0	9
6630	2019-08-22 12:21:55	2019-08-22	8	[{"id_menu":5,"count":2}]	1715	pick-up	0	8
6631	2019-08-22 13:44:14	2019-08-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2476	pick-up	0	23
6632	2019-08-22 14:10:12	2019-08-22	12	[{"id_menu":3,"count":1}]	649	pick-up	0	12
6633	2019-08-22 14:16:30	2019-08-22	12	[{"id_menu":3,"count":1}]	1208	pick-up	0	12
6634	2019-08-22 14:31:28	2019-08-22	14	[{"id_menu":2,"count":1}]	1563	pick-up	0	14
6635	2019-08-22 14:45:48	2019-08-22	33	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1112	delivery	5	38
6636	2019-08-22 16:25:37	2019-08-22	9	[{"id_menu":7,"count":2}]	2475	delivery	5	14
6637	2019-08-22 17:15:54	2019-08-22	8	[{"id_menu":5,"count":1}]	1215	pick-up	0	8
6638	2019-08-22 17:28:49	2019-08-22	14	[{"id_menu":2,"count":1}]	612	delivery	5	19
6639	2019-08-22 18:53:24	2019-08-22	9	[{"id_menu":6,"count":1}]	1598	delivery	5	14
6640	2019-08-22 19:30:03	2019-08-22	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	627	pick-up	0	31
6641	2019-08-22 19:39:10	2019-08-22	14	[{"id_menu":2,"count":1}]	2478	pick-up	0	14
6642	2019-08-22 19:44:32	2019-08-22	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1278	pick-up	0	29
6643	2019-08-22 19:57:59	2019-08-22	14	[{"id_menu":2,"count":1}]	292	delivery	5	19
6644	2019-08-22 20:03:49	2019-08-22	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	303	pick-up	0	39
6645	2019-08-22 20:05:33	2019-08-22	12	[{"id_menu":1,"count":1}]	654	pick-up	0	12
6646	2019-08-22 20:37:44	2019-08-22	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	669	pick-up	0	31
6647	2019-08-22 20:49:29	2019-08-22	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2087	pick-up	0	21
6648	2019-08-22 20:50:50	2019-08-22	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	2434	pick-up	0	29
6649	2019-08-22 20:56:08	2019-08-22	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2473	delivery	5	30
6650	2019-08-22 21:28:47	2019-08-22	12	[{"id_menu":1,"count":1}]	2470	pick-up	0	12
6651	2019-08-22 23:05:38	2019-08-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	184	pick-up	0	23
6652	2019-08-22 23:10:29	2019-08-22	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	528	delivery	5	31
6653	2019-08-22 23:25:38	2019-08-22	17	[{"id_menu":4,"count":1}]	1464	pick-up	0	17
6654	2019-08-23 00:45:40	2019-08-23	8	[{"id_menu":5,"count":1}]	1545	delivery	5	13
6655	2019-08-23 01:26:22	2019-08-23	9	[{"id_menu":6,"count":1}]	2264	pick-up	0	9
6656	2019-08-23 01:39:17	2019-08-23	14	[{"id_menu":2,"count":1}]	1895	pick-up	0	14
6657	2019-08-23 02:10:41	2019-08-23	14	[{"id_menu":2,"count":2}]	2178	pick-up	0	14
6658	2019-08-23 02:45:08	2019-08-23	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":2}]	1521	delivery	5	31
6659	2019-08-23 03:30:43	2019-08-23	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2487	pick-up	0	43
6660	2019-08-23 03:56:21	2019-08-23	14	[{"id_menu":2,"count":1}]	2488	pick-up	0	14
6661	2019-08-23 04:15:57	2019-08-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2497	pick-up	0	23
6662	2019-08-23 04:35:13	2019-08-23	17	[{"id_menu":4,"count":1}]	313	pick-up	0	17
6663	2019-08-23 05:17:36	2019-08-23	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1679	delivery	5	34
6664	2019-08-23 05:56:48	2019-08-23	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":2}]	1009	pick-up	0	20
6665	2019-08-23 06:11:11	2019-08-23	17	[{"id_menu":4,"count":2}]	103	pick-up	0	17
6666	2019-08-23 06:28:34	2019-08-23	17	[{"id_menu":4,"count":1}]	1681	delivery	5	22
6667	2019-08-23 06:39:30	2019-08-23	12	[{"id_menu":1,"count":1}]	2134	pick-up	0	12
6668	2019-08-23 07:03:07	2019-08-23	12	[{"id_menu":3,"count":1}]	2486	pick-up	0	12
6669	2019-08-23 07:07:12	2019-08-23	9	[{"id_menu":6,"count":1}]	2483	delivery	5	14
6670	2019-08-23 07:32:15	2019-08-23	17	[{"id_menu":4,"count":1}]	1253	delivery	5	22
6671	2019-08-23 08:16:08	2019-08-23	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1712	delivery	5	37
6672	2019-08-23 08:28:11	2019-08-23	14	[{"id_menu":2,"count":1}]	1295	delivery	5	19
6673	2019-08-23 08:30:56	2019-08-23	9	[{"id_menu":6,"count":1}]	126	pick-up	0	9
6674	2019-08-23 10:07:32	2019-08-23	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1461	pick-up	0	26
6675	2019-08-23 10:49:30	2019-08-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1377	delivery	5	26
6676	2019-08-23 11:33:37	2019-08-23	17	[{"id_menu":4,"count":1}]	2130	pick-up	0	17
6677	2019-08-23 12:02:11	2019-08-23	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	2418	pick-up	0	37
6678	2019-08-23 12:05:11	2019-08-23	12	[{"id_menu":1,"count":1}]	2498	pick-up	0	12
6679	2019-08-23 13:11:53	2019-08-23	12	[{"id_menu":3,"count":1}]	1093	delivery	5	17
6680	2019-08-23 13:29:42	2019-08-23	14	[{"id_menu":2,"count":1}]	2496	delivery	5	19
6681	2019-08-23 13:37:40	2019-08-23	8	[{"id_menu":5,"count":1}]	184	pick-up	0	8
6682	2019-08-23 13:41:50	2019-08-23	12	[{"id_menu":1,"count":1}]	170	pick-up	0	12
6683	2019-08-23 15:01:45	2019-08-23	9	[{"id_menu":6,"count":1}]	634	delivery	5	14
6684	2019-08-23 15:43:55	2019-08-23	9	[{"id_menu":7,"count":1}]	329	pick-up	0	9
6685	2019-08-23 16:40:34	2019-08-23	17	[{"id_menu":4,"count":1}]	1311	pick-up	0	17
6686	2019-08-23 16:56:41	2019-08-23	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1427	pick-up	0	35
6687	2019-08-23 17:47:15	2019-08-23	9	[{"id_menu":7,"count":1}]	2485	delivery	5	14
6688	2019-08-23 18:34:12	2019-08-23	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2491	delivery	5	31
6689	2019-08-23 20:24:17	2019-08-23	8	[{"id_menu":5,"count":2}]	2394	pick-up	0	8
6690	2019-08-23 20:59:59	2019-08-23	17	[{"id_menu":4,"count":1}]	2484	delivery	5	22
6691	2019-08-23 21:00:55	2019-08-23	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1963	pick-up	0	40
6692	2019-08-23 21:21:19	2019-08-23	17	[{"id_menu":4,"count":1}]	169	delivery	5	22
6693	2019-08-23 22:13:16	2019-08-23	14	[{"id_menu":2,"count":2}]	830	pick-up	0	14
6694	2019-08-23 22:16:55	2019-08-23	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	1053	pick-up	0	29
6695	2019-08-23 22:38:56	2019-08-23	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	624	pick-up	0	31
6696	2019-08-23 23:29:32	2019-08-23	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1713	delivery	5	22
6697	2019-08-23 23:32:04	2019-08-23	9	[{"id_menu":6,"count":1}]	2156	delivery	5	14
6698	2019-08-24 00:11:22	2019-08-24	9	[{"id_menu":7,"count":1}]	1528	pick-up	0	9
6699	2019-08-24 00:20:49	2019-08-24	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	631	delivery	5	26
6700	2019-08-24 00:27:45	2019-08-24	12	[{"id_menu":1,"count":1}]	114	pick-up	0	12
6701	2019-08-24 01:05:00	2019-08-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1541	delivery	5	22
6702	2019-08-24 01:21:51	2019-08-24	9	[{"id_menu":6,"count":1}]	1253	pick-up	0	9
6703	2019-08-24 01:43:54	2019-08-24	12	[{"id_menu":3,"count":1}]	1092	pick-up	0	12
6704	2019-08-24 01:44:31	2019-08-24	8	[{"id_menu":5,"count":1}]	2193	pick-up	0	8
6705	2019-08-24 01:44:31	2019-08-24	14	[{"id_menu":2,"count":1}]	1280	pick-up	0	14
6706	2019-08-24 01:48:23	2019-08-24	9	[{"id_menu":7,"count":1}]	2504	pick-up	0	9
6707	2019-08-24 02:07:27	2019-08-24	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1257	pick-up	0	42
6708	2019-08-24 02:25:48	2019-08-24	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2351	pick-up	0	20
6709	2019-08-24 02:29:57	2019-08-24	12	[{"id_menu":1,"count":1}]	62	pick-up	0	12
6710	2019-08-24 02:33:17	2019-08-24	12	[{"id_menu":3,"count":1}]	678	pick-up	0	12
6711	2019-08-24 02:35:26	2019-08-24	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2480	pick-up	0	41
6712	2019-08-24 02:42:01	2019-08-24	14	[{"id_menu":2,"count":2}]	1245	pick-up	0	14
6713	2019-08-24 02:55:15	2019-08-24	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1114	pick-up	0	35
6714	2019-08-24 03:01:23	2019-08-24	8	[{"id_menu":5,"count":1}]	1093	pick-up	0	8
6715	2019-08-24 03:25:58	2019-08-24	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2508	pick-up	0	29
6716	2019-08-24 04:15:59	2019-08-24	17	[{"id_menu":4,"count":1}]	1956	pick-up	0	17
6717	2019-08-24 04:32:20	2019-08-24	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	356	pick-up	0	35
6718	2019-08-24 05:04:58	2019-08-24	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	477	delivery	5	30
6719	2019-08-24 05:28:44	2019-08-24	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2516	pick-up	0	26
6720	2019-08-24 05:45:10	2019-08-24	9	[{"id_menu":6,"count":1}]	856	pick-up	0	9
6721	2019-08-24 05:55:41	2019-08-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	2514	pick-up	0	26
6722	2019-08-24 06:17:23	2019-08-24	14	[{"id_menu":2,"count":1}]	2501	pick-up	0	14
6723	2019-08-24 06:23:45	2019-08-24	14	[{"id_menu":2,"count":1}]	2506	delivery	5	19
6724	2019-08-24 06:33:42	2019-08-24	9	[{"id_menu":6,"count":1}]	1896	pick-up	0	9
6725	2019-08-24 06:34:12	2019-08-24	9	[{"id_menu":7,"count":1}]	742	delivery	5	14
6726	2019-08-24 06:41:56	2019-08-24	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	2191	pick-up	0	29
6727	2019-08-24 06:55:02	2019-08-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2505	pick-up	0	23
6728	2019-08-24 07:05:24	2019-08-24	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2502	pick-up	0	21
6729	2019-08-24 07:17:59	2019-08-24	12	[{"id_menu":1,"count":1}]	472	delivery	5	17
6730	2019-08-24 07:52:50	2019-08-24	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2339	delivery	5	30
6731	2019-08-24 08:07:06	2019-08-24	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2173	delivery	5	31
6732	2019-08-24 08:59:21	2019-08-24	14	[{"id_menu":2,"count":1}]	2515	pick-up	0	14
6733	2019-08-24 09:23:46	2019-08-24	17	[{"id_menu":4,"count":1}]	2090	pick-up	0	17
6734	2019-08-24 09:28:55	2019-08-24	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2512	delivery	5	31
6735	2019-08-24 09:53:10	2019-08-24	17	[{"id_menu":4,"count":1}]	1582	pick-up	0	17
6736	2019-08-24 11:02:57	2019-08-24	9	[{"id_menu":6,"count":1}]	294	delivery	5	14
6737	2019-08-24 11:08:58	2019-08-24	14	[{"id_menu":2,"count":1}]	1877	pick-up	0	14
6738	2019-08-24 11:19:54	2019-08-24	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	58	pick-up	0	31
6739	2019-08-24 11:33:24	2019-08-24	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2041	pick-up	0	21
6740	2019-08-24 12:27:32	2019-08-24	9	[{"id_menu":7,"count":1}]	908	delivery	5	14
6741	2019-08-24 12:51:44	2019-08-24	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	2500	pick-up	0	40
6742	2019-08-24 13:14:03	2019-08-24	17	[{"id_menu":4,"count":1}]	2510	pick-up	0	17
6743	2019-08-24 13:14:33	2019-08-24	12	[{"id_menu":3,"count":1}]	2509	pick-up	0	12
6744	2019-08-24 13:58:43	2019-08-24	12	[{"id_menu":1,"count":1}]	861	delivery	5	17
6745	2019-08-24 14:19:38	2019-08-24	14	[{"id_menu":2,"count":2}]	1513	delivery	5	19
6746	2019-08-24 15:02:14	2019-08-24	14	[{"id_menu":2,"count":1}]	171	pick-up	0	14
6747	2019-08-24 15:42:59	2019-08-24	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	149	pick-up	0	21
6748	2019-08-24 15:43:45	2019-08-24	12	[{"id_menu":1,"count":1}]	1429	delivery	5	17
6749	2019-08-24 16:31:07	2019-08-24	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	2290	pick-up	0	37
6750	2019-08-24 16:42:47	2019-08-24	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1119	pick-up	0	35
6751	2019-08-24 17:01:57	2019-08-24	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2511	pick-up	0	21
6752	2019-08-24 17:57:04	2019-08-24	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2503	delivery	5	51
6753	2019-08-24 18:16:09	2019-08-24	12	[{"id_menu":1,"count":1}]	2513	pick-up	0	12
6754	2019-08-24 18:38:47	2019-08-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2507	delivery	5	22
6755	2019-08-24 18:53:48	2019-08-24	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	48	pick-up	0	21
6756	2019-08-24 19:30:35	2019-08-24	9	[{"id_menu":7,"count":1}]	2499	delivery	5	14
6757	2019-08-24 19:45:49	2019-08-24	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	573	pick-up	0	38
6758	2019-08-24 19:51:42	2019-08-24	9	[{"id_menu":7,"count":1}]	2282	pick-up	0	9
6759	2019-08-24 20:11:05	2019-08-24	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	1173	delivery	5	22
6760	2019-08-24 21:10:54	2019-08-24	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	291	delivery	5	22
6761	2019-08-24 21:34:42	2019-08-24	8	[{"id_menu":5,"count":1}]	189	pick-up	0	8
6762	2019-08-24 22:42:36	2019-08-24	8	[{"id_menu":5,"count":1}]	235	delivery	5	13
6763	2019-08-24 23:15:46	2019-08-24	12	[{"id_menu":3,"count":1}]	1223	pick-up	0	12
6764	2019-08-24 23:22:02	2019-08-24	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1948	delivery	5	43
6765	2019-08-24 23:23:36	2019-08-24	12	[{"id_menu":3,"count":1}]	1376	pick-up	0	12
6766	2019-08-24 23:28:03	2019-08-24	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1244	pick-up	0	35
6767	2019-08-24 23:30:26	2019-08-24	55	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1888	pick-up	0	55
6768	2019-08-25 00:31:00	2019-08-25	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2527	pick-up	0	26
6769	2019-08-25 01:51:56	2019-08-25	17	[{"id_menu":4,"count":1}]	2519	pick-up	0	17
6770	2019-08-25 02:00:39	2019-08-25	8	[{"id_menu":5,"count":1}]	1684	pick-up	0	8
6771	2019-08-25 02:19:26	2019-08-25	14	[{"id_menu":2,"count":1}]	2089	pick-up	0	14
6772	2019-08-25 02:33:46	2019-08-25	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	962	delivery	5	26
6773	2019-08-25 02:41:29	2019-08-25	14	[{"id_menu":2,"count":1}]	1120	delivery	5	19
6774	2019-08-25 02:42:21	2019-08-25	8	[{"id_menu":5,"count":1}]	193	delivery	5	13
6775	2019-08-25 02:42:30	2019-08-25	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	740	pick-up	0	26
6776	2019-08-25 03:09:48	2019-08-25	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	627	pick-up	0	23
6777	2019-08-25 03:24:37	2019-08-25	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	1155	pick-up	0	26
6778	2019-08-25 03:52:11	2019-08-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2521	pick-up	0	18
6779	2019-08-25 04:22:45	2019-08-25	14	[{"id_menu":2,"count":1}]	1627	delivery	5	19
6780	2019-08-25 04:40:30	2019-08-25	12	[{"id_menu":3,"count":1}]	2384	pick-up	0	12
6781	2019-08-25 04:52:55	2019-08-25	12	[{"id_menu":3,"count":1}]	2525	delivery	5	17
6782	2019-08-25 05:51:26	2019-08-25	17	[{"id_menu":4,"count":2}]	1490	delivery	5	22
6783	2019-08-25 05:51:31	2019-08-25	37	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2533	delivery	5	42
6784	2019-08-25 05:59:09	2019-08-25	12	[{"id_menu":3,"count":1}]	655	pick-up	0	12
6785	2019-08-25 06:24:32	2019-08-25	17	[{"id_menu":4,"count":2}]	2366	pick-up	0	17
6786	2019-08-25 06:35:49	2019-08-25	8	[{"id_menu":5,"count":2}]	1707	pick-up	0	8
6787	2019-08-25 06:36:31	2019-08-25	9	[{"id_menu":7,"count":1}]	2522	pick-up	0	9
6788	2019-08-25 06:50:27	2019-08-25	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	712	delivery	5	39
6789	2019-08-25 06:52:59	2019-08-25	14	[{"id_menu":2,"count":1}]	1638	delivery	5	19
6790	2019-08-25 07:03:18	2019-08-25	12	[{"id_menu":3,"count":1}]	2316	delivery	5	17
6791	2019-08-25 07:43:56	2019-08-25	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1934	delivery	5	40
6792	2019-08-25 07:45:27	2019-08-25	12	[{"id_menu":3,"count":2}]	638	pick-up	0	12
6793	2019-08-25 07:47:15	2019-08-25	12	[{"id_menu":1,"count":1}]	575	delivery	5	17
6794	2019-08-25 07:47:51	2019-08-25	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2523	pick-up	0	38
6795	2019-08-25 07:57:22	2019-08-25	8	[{"id_menu":5,"count":1}]	660	delivery	5	13
6796	2019-08-25 08:44:37	2019-08-25	8	[{"id_menu":5,"count":1}]	1409	pick-up	0	8
6797	2019-08-25 08:53:01	2019-08-25	14	[{"id_menu":2,"count":1}]	2517	pick-up	0	14
6798	2019-08-25 09:08:42	2019-08-25	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2178	delivery	5	31
6799	2019-08-25 09:16:48	2019-08-25	14	[{"id_menu":2,"count":1}]	2520	pick-up	0	14
6800	2019-08-25 09:22:16	2019-08-25	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1813	pick-up	0	25
6801	2019-08-25 09:25:34	2019-08-25	17	[{"id_menu":4,"count":1}]	855	pick-up	0	17
6802	2019-08-25 09:28:07	2019-08-25	12	[{"id_menu":3,"count":1}]	440	delivery	5	17
6803	2019-08-25 09:29:34	2019-08-25	12	[{"id_menu":1,"count":1}]	227	pick-up	0	12
6804	2019-08-25 10:25:28	2019-08-25	17	[{"id_menu":4,"count":1}]	2526	delivery	5	22
6805	2019-08-25 11:30:31	2019-08-25	14	[{"id_menu":2,"count":1}]	2518	delivery	5	19
6806	2019-08-25 11:31:05	2019-08-25	12	[{"id_menu":3,"count":1}]	2086	delivery	5	17
6807	2019-08-25 11:42:39	2019-08-25	9	[{"id_menu":6,"count":1}]	1592	pick-up	0	9
6808	2019-08-25 12:18:33	2019-08-25	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	491	pick-up	0	21
6809	2019-08-25 12:21:12	2019-08-25	17	[{"id_menu":4,"count":1}]	1509	pick-up	0	17
6810	2019-08-25 12:27:53	2019-08-25	12	[{"id_menu":1,"count":1}]	561	pick-up	0	12
6811	2019-08-25 12:41:05	2019-08-25	12	[{"id_menu":1,"count":1}]	2398	delivery	5	17
6812	2019-08-25 12:52:07	2019-08-25	12	[{"id_menu":3,"count":1}]	676	delivery	5	17
6813	2019-08-25 13:48:27	2019-08-25	8	[{"id_menu":5,"count":1}]	1769	pick-up	0	8
6814	2019-08-25 15:04:06	2019-08-25	12	[{"id_menu":1,"count":1}]	1353	delivery	5	17
6815	2019-08-25 15:15:26	2019-08-25	9	[{"id_menu":6,"count":1}]	1710	delivery	5	14
6816	2019-08-25 15:59:24	2019-08-25	8	[{"id_menu":5,"count":1}]	2426	delivery	5	13
6817	2019-08-25 16:20:04	2019-08-25	9	[{"id_menu":7,"count":1}]	2240	delivery	5	14
6818	2019-08-25 16:20:14	2019-08-25	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1732	delivery	5	26
6819	2019-08-25 16:33:49	2019-08-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2524	delivery	5	28
6820	2019-08-25 16:42:17	2019-08-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	547	pick-up	0	26
6821	2019-08-25 16:50:00	2019-08-25	12	[{"id_menu":3,"count":1}]	2214	pick-up	0	12
6822	2019-08-25 17:24:16	2019-08-25	12	[{"id_menu":3,"count":1}]	1902	pick-up	0	12
6823	2019-08-25 18:35:46	2019-08-25	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1263	pick-up	0	21
6824	2019-08-25 18:43:36	2019-08-25	8	[{"id_menu":5,"count":1}]	2532	pick-up	0	8
6825	2019-08-25 19:16:55	2019-08-25	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	853	pick-up	0	23
6826	2019-08-25 19:22:17	2019-08-25	9	[{"id_menu":6,"count":1}]	1505	pick-up	0	9
6827	2019-08-25 19:26:35	2019-08-25	14	[{"id_menu":2,"count":1}]	2190	delivery	5	19
6828	2019-08-25 20:04:07	2019-08-25	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":3}]	21	pick-up	0	29
6829	2019-08-25 20:06:44	2019-08-25	12	[{"id_menu":1,"count":1}]	981	delivery	5	17
6830	2019-08-25 20:26:31	2019-08-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	240	pick-up	0	23
6831	2019-08-25 21:06:44	2019-08-25	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	376	delivery	5	26
6832	2019-08-25 21:18:57	2019-08-25	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2531	delivery	5	31
6833	2019-08-25 21:46:46	2019-08-25	14	[{"id_menu":2,"count":1}]	2528	pick-up	0	14
6834	2019-08-25 21:53:57	2019-08-25	14	[{"id_menu":2,"count":1}]	2529	pick-up	0	14
6835	2019-08-25 21:57:42	2019-08-25	9	[{"id_menu":6,"count":1}]	1296	delivery	5	14
6836	2019-08-25 22:25:13	2019-08-25	9	[{"id_menu":6,"count":1}]	1654	pick-up	0	9
6837	2019-08-25 22:31:36	2019-08-25	12	[{"id_menu":3,"count":2}]	2085	pick-up	0	12
6838	2019-08-25 22:57:36	2019-08-25	12	[{"id_menu":3,"count":1}]	1335	pick-up	0	12
6839	2019-08-25 23:17:26	2019-08-25	14	[{"id_menu":2,"count":1}]	150	pick-up	0	14
6840	2019-08-25 23:18:54	2019-08-25	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2530	pick-up	0	29
6841	2019-08-25 23:19:07	2019-08-25	14	[{"id_menu":2,"count":1}]	1223	delivery	5	19
6842	2019-08-25 23:36:03	2019-08-25	14	[{"id_menu":2,"count":1}]	53	pick-up	0	14
6843	2019-08-26 01:37:54	2019-08-26	17	[{"id_menu":4,"count":1}]	2409	pick-up	0	17
6844	2019-08-26 02:55:17	2019-08-26	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2367	delivery	5	34
6845	2019-08-26 03:04:44	2019-08-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1443	delivery	5	31
6846	2019-08-26 03:24:01	2019-08-26	8	[{"id_menu":5,"count":1}]	2540	pick-up	0	8
6847	2019-08-26 05:34:20	2019-08-26	9	[{"id_menu":7,"count":1}]	2474	delivery	5	14
6848	2019-08-26 08:38:38	2019-08-26	12	[{"id_menu":1,"count":1}]	2289	pick-up	0	12
6849	2019-08-26 09:45:17	2019-08-26	8	[{"id_menu":5,"count":1}]	2541	delivery	5	13
6850	2019-08-26 09:56:43	2019-08-26	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	666	delivery	5	39
6851	2019-08-26 10:10:47	2019-08-26	9	[{"id_menu":7,"count":1}]	1242	pick-up	0	9
6852	2019-08-26 10:19:01	2019-08-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	950	pick-up	0	23
6853	2019-08-26 11:54:56	2019-08-26	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	807	delivery	5	29
6854	2019-08-26 12:19:19	2019-08-26	17	[{"id_menu":4,"count":1}]	575	pick-up	0	17
6855	2019-08-26 12:20:45	2019-08-26	9	[{"id_menu":6,"count":1}]	2535	delivery	5	14
6856	2019-08-26 13:00:00	2019-08-26	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	293	pick-up	0	22
6857	2019-08-26 14:21:56	2019-08-26	12	[{"id_menu":1,"count":1}]	2381	pick-up	0	12
6858	2019-08-26 14:55:57	2019-08-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2544	pick-up	0	17
6859	2019-08-26 15:46:19	2019-08-26	9	[{"id_menu":7,"count":1}]	328	delivery	5	14
6860	2019-08-26 15:50:58	2019-08-26	17	[{"id_menu":4,"count":1}]	140	pick-up	0	17
6861	2019-08-26 16:43:46	2019-08-26	8	[{"id_menu":5,"count":1}]	2189	delivery	5	13
6862	2019-08-26 17:33:36	2019-08-26	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	107	delivery	5	27
6863	2019-08-26 18:32:03	2019-08-26	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	676	pick-up	0	29
6864	2019-08-26 19:12:13	2019-08-26	9	[{"id_menu":6,"count":2}]	586	pick-up	0	9
6865	2019-08-26 19:19:05	2019-08-26	9	[{"id_menu":6,"count":1}]	925	pick-up	0	9
6866	2019-08-26 19:48:25	2019-08-26	55	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1235	pick-up	0	55
6867	2019-08-26 20:05:17	2019-08-26	12	[{"id_menu":3,"count":1}]	833	pick-up	0	12
6868	2019-08-26 20:54:30	2019-08-26	12	[{"id_menu":3,"count":1}]	1123	pick-up	0	12
6869	2019-08-26 20:57:48	2019-08-26	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	506	pick-up	0	35
6870	2019-08-26 21:29:56	2019-08-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1374	pick-up	0	18
6871	2019-08-26 22:55:26	2019-08-26	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	887	delivery	5	26
6872	2019-08-26 23:20:30	2019-08-26	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	612	pick-up	0	29
6873	2019-08-26 23:30:30	2019-08-26	8	[{"id_menu":5,"count":1}]	379	pick-up	0	8
6874	2019-08-26 23:33:58	2019-08-26	17	[{"id_menu":4,"count":1}]	2548	pick-up	0	17
6875	2019-08-26 23:33:58	2019-08-26	14	[{"id_menu":2,"count":1}]	1426	delivery	5	19
6876	2019-08-26 23:40:08	2019-08-26	12	[{"id_menu":3,"count":1}]	2523	delivery	5	17
6877	2019-08-26 23:55:16	2019-08-26	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	763	pick-up	0	26
6878	2019-08-27 00:03:39	2019-08-27	12	[{"id_menu":1,"count":1}]	72	delivery	5	17
6879	2019-08-27 00:08:57	2019-08-27	8	[{"id_menu":5,"count":1}]	2255	delivery	5	13
6880	2019-08-27 00:24:32	2019-08-27	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1376	pick-up	0	34
6881	2019-08-27 00:49:19	2019-08-27	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2550	pick-up	0	21
6882	2019-08-27 00:59:16	2019-08-27	9	[{"id_menu":6,"count":1}]	1835	pick-up	0	9
6883	2019-08-27 01:10:12	2019-08-27	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	189	pick-up	0	35
6884	2019-08-27 01:56:57	2019-08-27	9	[{"id_menu":6,"count":1}]	2546	delivery	5	14
6885	2019-08-27 02:51:12	2019-08-27	9	[{"id_menu":7,"count":1}]	745	pick-up	0	9
6886	2019-08-27 04:10:49	2019-08-27	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1215	pick-up	0	26
6887	2019-08-27 05:10:12	2019-08-27	17	[{"id_menu":4,"count":1}]	2556	delivery	5	22
6888	2019-08-27 06:42:05	2019-08-27	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1659	pick-up	0	31
6889	2019-08-27 07:04:37	2019-08-27	12	[{"id_menu":3,"count":1}]	1245	delivery	5	17
6890	2019-08-27 07:26:22	2019-08-27	9	[{"id_menu":7,"count":1}]	2153	pick-up	0	9
6891	2019-08-27 07:27:32	2019-08-27	8	[{"id_menu":5,"count":1}]	1925	delivery	5	13
6892	2019-08-27 08:47:22	2019-08-27	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1455	pick-up	0	21
6893	2019-08-27 09:23:42	2019-08-27	9	[{"id_menu":6,"count":1}]	1377	delivery	5	14
6894	2019-08-27 09:27:03	2019-08-27	8	[{"id_menu":5,"count":1}]	1582	delivery	5	13
6895	2019-08-27 09:41:19	2019-08-27	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	1209	pick-up	0	26
6896	2019-08-27 10:01:14	2019-08-27	17	[{"id_menu":4,"count":1}]	100	delivery	5	22
6897	2019-08-27 11:12:49	2019-08-27	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1464	pick-up	0	32
6898	2019-08-27 11:38:55	2019-08-27	12	[{"id_menu":1,"count":1}]	2552	delivery	5	17
6899	2019-08-27 13:02:08	2019-08-27	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	2555	delivery	5	40
6900	2019-08-27 13:32:35	2019-08-27	12	[{"id_menu":1,"count":1}]	2561	delivery	5	17
6901	2019-08-27 13:46:25	2019-08-27	17	[{"id_menu":4,"count":1}]	748	delivery	5	22
6902	2019-08-27 13:47:02	2019-08-27	12	[{"id_menu":3,"count":1}]	922	delivery	5	17
6903	2019-08-27 14:14:03	2019-08-27	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1422	pick-up	0	22
6904	2019-08-27 14:25:22	2019-08-27	9	[{"id_menu":7,"count":1}]	2076	pick-up	0	9
6905	2019-08-27 14:40:40	2019-08-27	14	[{"id_menu":2,"count":1}]	2298	delivery	5	19
6906	2019-08-27 14:57:42	2019-08-27	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1161	delivery	5	36
6907	2019-08-27 15:37:09	2019-08-27	17	[{"id_menu":4,"count":1}]	2551	pick-up	0	17
6908	2019-08-27 15:55:28	2019-08-27	12	[{"id_menu":1,"count":1}]	338	delivery	5	17
6909	2019-08-27 16:06:53	2019-08-27	12	[{"id_menu":3,"count":1}]	2562	pick-up	0	12
6910	2019-08-27 16:40:17	2019-08-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	712	delivery	5	23
6911	2019-08-27 16:41:47	2019-08-27	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2262	delivery	5	25
6912	2019-08-27 17:01:24	2019-08-27	8	[{"id_menu":5,"count":1}]	899	pick-up	0	8
6913	2019-08-27 17:16:16	2019-08-27	9	[{"id_menu":6,"count":1}]	2272	pick-up	0	9
6914	2019-08-27 17:23:38	2019-08-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	1410	delivery	5	22
6915	2019-08-27 18:01:47	2019-08-27	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	610	pick-up	0	34
6916	2019-08-27 18:25:51	2019-08-27	9	[{"id_menu":7,"count":1}]	138	pick-up	0	9
6917	2019-08-27 19:43:50	2019-08-27	9	[{"id_menu":7,"count":1}]	74	pick-up	0	9
6918	2019-08-27 19:52:31	2019-08-27	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2557	delivery	5	37
6919	2019-08-27 19:56:43	2019-08-27	8	[{"id_menu":5,"count":1}]	2228	pick-up	0	8
6920	2019-08-27 20:24:36	2019-08-27	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1729	delivery	5	26
6921	2019-08-27 20:53:57	2019-08-27	9	[{"id_menu":6,"count":1}]	2558	delivery	5	14
6922	2019-08-27 21:50:16	2019-08-27	17	[{"id_menu":4,"count":1}]	2050	pick-up	0	17
6923	2019-08-27 22:21:42	2019-08-27	12	[{"id_menu":1,"count":1}]	281	delivery	5	17
6924	2019-08-27 22:29:06	2019-08-27	14	[{"id_menu":2,"count":1}]	1352	delivery	5	19
6925	2019-08-27 22:36:00	2019-08-27	17	[{"id_menu":4,"count":1}]	207	pick-up	0	17
6926	2019-08-27 23:04:35	2019-08-27	14	[{"id_menu":2,"count":1}]	270	pick-up	0	14
6927	2019-08-27 23:05:12	2019-08-27	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1860	delivery	5	27
6928	2019-08-27 23:11:36	2019-08-27	12	[{"id_menu":1,"count":1}]	486	delivery	5	17
6929	2019-08-27 23:12:18	2019-08-27	17	[{"id_menu":4,"count":1}]	2242	pick-up	0	17
6930	2019-08-27 23:16:52	2019-08-27	17	[{"id_menu":4,"count":2}]	177	pick-up	0	17
6931	2019-08-27 23:20:43	2019-08-27	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1053	pick-up	0	21
6932	2019-08-27 23:55:40	2019-08-27	12	[{"id_menu":3,"count":1}]	2559	pick-up	0	12
6933	2019-08-28 00:16:30	2019-08-28	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1427	pick-up	0	26
6934	2019-08-28 00:26:20	2019-08-28	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	2571	delivery	5	25
6935	2019-08-28 00:47:51	2019-08-28	14	[{"id_menu":2,"count":1}]	2570	pick-up	0	14
6936	2019-08-28 01:43:21	2019-08-28	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2231	pick-up	0	26
6937	2019-08-28 01:48:07	2019-08-28	14	[{"id_menu":2,"count":2}]	1754	delivery	5	19
6938	2019-08-28 02:42:32	2019-08-28	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2478	pick-up	0	21
6939	2019-08-28 03:11:40	2019-08-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1055	pick-up	0	23
6940	2019-08-28 03:18:56	2019-08-28	14	[{"id_menu":2,"count":1}]	2574	pick-up	0	14
6941	2019-08-28 04:41:15	2019-08-28	9	[{"id_menu":7,"count":1}]	1337	pick-up	0	9
6942	2019-08-28 05:27:17	2019-08-28	9	[{"id_menu":7,"count":1}]	44	delivery	5	14
6943	2019-08-28 05:29:42	2019-08-28	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	490	delivery	5	34
6944	2019-08-28 06:01:58	2019-08-28	8	[{"id_menu":5,"count":1}]	688	delivery	5	13
6945	2019-08-28 06:05:39	2019-08-28	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	964	delivery	5	35
6946	2019-08-28 06:16:54	2019-08-28	9	[{"id_menu":6,"count":1}]	2577	pick-up	0	9
6947	2019-08-28 06:36:57	2019-08-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	907	delivery	5	31
6948	2019-08-28 06:38:30	2019-08-28	12	[{"id_menu":1,"count":1}]	1676	delivery	5	17
6949	2019-08-28 06:43:44	2019-08-28	9	[{"id_menu":7,"count":1}]	2546	pick-up	0	9
6950	2019-08-28 06:45:49	2019-08-28	14	[{"id_menu":2,"count":1}]	2569	pick-up	0	14
6951	2019-08-28 06:59:46	2019-08-28	12	[{"id_menu":3,"count":1}]	2455	pick-up	0	12
6952	2019-08-28 07:01:12	2019-08-28	12	[{"id_menu":1,"count":1}]	1531	delivery	5	17
6953	2019-08-28 07:06:02	2019-08-28	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1314	delivery	5	30
6954	2019-08-28 07:25:01	2019-08-28	12	[{"id_menu":3,"count":1}]	1223	pick-up	0	12
6955	2019-08-28 07:32:08	2019-08-28	9	[{"id_menu":6,"count":1}]	1145	pick-up	0	9
6956	2019-08-28 08:55:30	2019-08-28	9	[{"id_menu":7,"count":1}]	2568	delivery	5	14
6957	2019-08-28 09:13:09	2019-08-28	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	399	pick-up	0	21
6958	2019-08-28 09:17:44	2019-08-28	14	[{"id_menu":2,"count":2}]	1525	pick-up	0	14
6959	2019-08-28 09:36:31	2019-08-28	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2010	delivery	5	34
6960	2019-08-28 10:15:15	2019-08-28	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	5	pick-up	0	21
6961	2019-08-28 10:15:50	2019-08-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	208	pick-up	0	17
6962	2019-08-28 10:55:19	2019-08-28	17	[{"id_menu":4,"count":1}]	1650	pick-up	0	17
6963	2019-08-28 11:27:30	2019-08-28	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	2567	pick-up	0	20
6964	2019-08-28 12:54:33	2019-08-28	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1681	delivery	5	34
6965	2019-08-28 13:01:06	2019-08-28	9	[{"id_menu":7,"count":1}]	168	pick-up	0	9
6966	2019-08-28 13:07:23	2019-08-28	14	[{"id_menu":2,"count":1}]	203	pick-up	0	14
6967	2019-08-28 13:10:13	2019-08-28	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	66	pick-up	0	21
6968	2019-08-28 14:38:44	2019-08-28	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1832	delivery	5	39
6969	2019-08-28 14:54:53	2019-08-28	17	[{"id_menu":4,"count":2}]	2566	pick-up	0	17
6970	2019-08-28 15:15:08	2019-08-28	12	[{"id_menu":1,"count":1}]	972	delivery	5	17
6971	2019-08-28 15:21:22	2019-08-28	12	[{"id_menu":1,"count":1}]	2565	delivery	5	17
6972	2019-08-28 15:29:05	2019-08-28	17	[{"id_menu":4,"count":1}]	1784	delivery	5	22
6973	2019-08-28 15:38:00	2019-08-28	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2287	delivery	5	35
6974	2019-08-28 15:38:09	2019-08-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	286	pick-up	0	18
6975	2019-08-28 16:01:30	2019-08-28	12	[{"id_menu":1,"count":1}]	2572	delivery	5	17
6976	2019-08-28 16:05:55	2019-08-28	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1674	delivery	5	26
6977	2019-08-28 16:14:12	2019-08-28	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1321	pick-up	0	23
6978	2019-08-28 16:15:11	2019-08-28	17	[{"id_menu":4,"count":1}]	2573	pick-up	0	17
6979	2019-08-28 16:18:43	2019-08-28	8	[{"id_menu":5,"count":1}]	2541	delivery	5	13
6980	2019-08-28 16:47:14	2019-08-28	12	[{"id_menu":1,"count":2}]	2523	pick-up	0	12
6981	2019-08-28 16:53:06	2019-08-28	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1104	pick-up	0	21
6982	2019-08-28 17:32:28	2019-08-28	14	[{"id_menu":2,"count":1}]	397	delivery	5	19
6983	2019-08-28 18:15:08	2019-08-28	9	[{"id_menu":7,"count":1}]	793	delivery	5	14
6984	2019-08-28 18:48:24	2019-08-28	14	[{"id_menu":2,"count":1}]	2313	pick-up	0	14
6985	2019-08-28 19:19:20	2019-08-28	8	[{"id_menu":5,"count":1}]	2564	pick-up	0	8
6986	2019-08-28 19:29:13	2019-08-28	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":3}]	2466	delivery	5	31
6987	2019-08-28 19:40:59	2019-08-28	8	[{"id_menu":5,"count":1}]	456	delivery	5	13
6988	2019-08-28 19:43:27	2019-08-28	8	[{"id_menu":5,"count":1}]	1509	delivery	5	13
6989	2019-08-28 20:29:25	2019-08-28	9	[{"id_menu":6,"count":1}]	1424	pick-up	0	9
6990	2019-08-28 20:33:21	2019-08-28	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1185	delivery	5	30
6991	2019-08-28 20:53:12	2019-08-28	14	[{"id_menu":2,"count":1}]	2034	pick-up	0	14
6992	2019-08-28 20:53:54	2019-08-28	14	[{"id_menu":2,"count":1}]	1233	delivery	5	19
6993	2019-08-28 21:21:12	2019-08-28	12	[{"id_menu":3,"count":1}]	2563	delivery	5	17
6994	2019-08-28 22:13:30	2019-08-28	12	[{"id_menu":1,"count":1}]	1630	delivery	5	17
6995	2019-08-28 22:41:18	2019-08-28	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	708	pick-up	0	29
6996	2019-08-28 22:58:57	2019-08-28	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	2575	pick-up	0	26
6997	2019-08-28 23:21:14	2019-08-28	17	[{"id_menu":4,"count":1}]	1817	pick-up	0	17
6998	2019-08-28 23:43:26	2019-08-28	8	[{"id_menu":5,"count":1}]	71	pick-up	0	8
6999	2019-08-29 01:17:21	2019-08-29	12	[{"id_menu":1,"count":1}]	660	pick-up	0	12
7000	2019-08-29 01:28:53	2019-08-29	8	[{"id_menu":5,"count":1}]	1700	pick-up	0	8
7001	2019-08-29 01:43:31	2019-08-29	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1166	pick-up	0	43
7002	2019-08-29 02:06:13	2019-08-29	14	[{"id_menu":2,"count":1}]	1184	pick-up	0	14
7003	2019-08-29 02:53:19	2019-08-29	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	2581	pick-up	0	24
7004	2019-08-29 03:11:35	2019-08-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	2578	delivery	5	31
7005	2019-08-29 03:22:45	2019-08-29	8	[{"id_menu":5,"count":2}]	826	pick-up	0	8
7006	2019-08-29 03:55:42	2019-08-29	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1929	delivery	5	25
7007	2019-08-29 03:58:24	2019-08-29	8	[{"id_menu":5,"count":1}]	2586	delivery	5	13
7008	2019-08-29 04:01:35	2019-08-29	8	[{"id_menu":5,"count":1}]	363	pick-up	0	8
7009	2019-08-29 04:10:48	2019-08-29	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2592	pick-up	0	25
7010	2019-08-29 04:23:28	2019-08-29	9	[{"id_menu":6,"count":1}]	2590	delivery	5	14
7011	2019-08-29 04:27:25	2019-08-29	9	[{"id_menu":6,"count":1}]	1885	pick-up	0	9
7012	2019-08-29 04:28:32	2019-08-29	14	[{"id_menu":2,"count":1}]	1223	pick-up	0	14
7013	2019-08-29 05:02:08	2019-08-29	14	[{"id_menu":2,"count":1}]	2588	pick-up	0	14
7014	2019-08-29 05:34:03	2019-08-29	8	[{"id_menu":5,"count":1}]	1911	delivery	5	13
7015	2019-08-29 05:59:48	2019-08-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2584	pick-up	0	23
7016	2019-08-29 06:52:01	2019-08-29	9	[{"id_menu":7,"count":1}]	1961	pick-up	0	9
7017	2019-08-29 06:57:58	2019-08-29	9	[{"id_menu":6,"count":1}]	669	delivery	5	14
7018	2019-08-29 07:13:14	2019-08-29	12	[{"id_menu":1,"count":1}]	1117	delivery	5	17
7019	2019-08-29 07:52:40	2019-08-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2287	pick-up	0	31
7020	2019-08-29 07:56:22	2019-08-29	9	[{"id_menu":7,"count":1}]	1143	pick-up	0	9
7021	2019-08-29 08:55:20	2019-08-29	14	[{"id_menu":2,"count":1}]	822	pick-up	0	14
7022	2019-08-29 09:31:45	2019-08-29	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2029	delivery	5	31
7023	2019-08-29 10:01:24	2019-08-29	9	[{"id_menu":7,"count":1}]	1963	pick-up	0	9
7024	2019-08-29 10:13:07	2019-08-29	12	[{"id_menu":3,"count":1}]	638	pick-up	0	12
7025	2019-08-29 10:35:35	2019-08-29	12	[{"id_menu":3,"count":1}]	356	pick-up	0	12
7026	2019-08-29 10:57:58	2019-08-29	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2582	pick-up	0	21
7027	2019-08-29 11:25:54	2019-08-29	8	[{"id_menu":5,"count":1}]	284	delivery	5	13
7028	2019-08-29 12:06:58	2019-08-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2107	pick-up	0	23
7029	2019-08-29 12:38:00	2019-08-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	806	pick-up	0	18
7030	2019-08-29 13:23:11	2019-08-29	9	[{"id_menu":6,"count":1}]	2185	pick-up	0	9
7031	2019-08-29 13:23:43	2019-08-29	9	[{"id_menu":7,"count":1}]	2579	delivery	5	14
7032	2019-08-29 13:35:34	2019-08-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1182	pick-up	0	17
7033	2019-08-29 14:08:43	2019-08-29	8	[{"id_menu":5,"count":1}]	2110	pick-up	0	8
7034	2019-08-29 14:12:47	2019-08-29	9	[{"id_menu":7,"count":1}]	2583	delivery	5	14
7035	2019-08-29 14:27:47	2019-08-29	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	2591	delivery	5	31
7036	2019-08-29 15:00:35	2019-08-29	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	2143	pick-up	0	40
7037	2019-08-29 15:07:13	2019-08-29	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1808	delivery	5	39
7038	2019-08-29 16:26:31	2019-08-29	17	[{"id_menu":4,"count":1}]	2585	pick-up	0	17
7039	2019-08-29 17:17:41	2019-08-29	12	[{"id_menu":3,"count":1}]	1713	delivery	5	17
7040	2019-08-29 18:40:09	2019-08-29	9	[{"id_menu":7,"count":1}]	1556	delivery	5	14
7041	2019-08-29 19:02:43	2019-08-29	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2440	delivery	5	47
7042	2019-08-29 19:03:52	2019-08-29	8	[{"id_menu":5,"count":1}]	1729	delivery	5	13
7043	2019-08-29 19:47:10	2019-08-29	8	[{"id_menu":5,"count":1}]	2589	pick-up	0	8
7044	2019-08-29 19:49:16	2019-08-29	14	[{"id_menu":2,"count":1}]	646	pick-up	0	14
7045	2019-08-29 20:14:29	2019-08-29	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	2587	pick-up	0	25
7046	2019-08-29 20:33:47	2019-08-29	9	[{"id_menu":6,"count":1}]	315	delivery	5	14
7047	2019-08-29 20:51:39	2019-08-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	133	pick-up	0	21
7048	2019-08-29 20:56:14	2019-08-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	417	pick-up	0	21
7049	2019-08-29 21:54:59	2019-08-29	14	[{"id_menu":2,"count":1}]	830	pick-up	0	14
7050	2019-08-29 23:09:24	2019-08-29	9	[{"id_menu":7,"count":1}]	1970	pick-up	0	9
7051	2019-08-29 23:44:06	2019-08-29	9	[{"id_menu":7,"count":1}]	1457	delivery	5	14
7052	2019-08-30 00:22:51	2019-08-30	8	[{"id_menu":5,"count":1}]	1533	delivery	5	13
7053	2019-08-30 00:32:04	2019-08-30	17	[{"id_menu":4,"count":1}]	2598	pick-up	0	17
7054	2019-08-30 00:55:31	2019-08-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	929	pick-up	0	18
7055	2019-08-30 01:42:36	2019-08-30	8	[{"id_menu":5,"count":1}]	1729	delivery	5	13
7056	2019-08-30 04:02:19	2019-08-30	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	285	pick-up	0	21
7057	2019-08-30 04:04:39	2019-08-30	9	[{"id_menu":6,"count":1}]	2596	delivery	5	14
7058	2019-08-30 04:25:31	2019-08-30	14	[{"id_menu":2,"count":2}]	1263	delivery	5	19
7059	2019-08-30 04:32:40	2019-08-30	12	[{"id_menu":1,"count":1}]	204	pick-up	0	12
7060	2019-08-30 05:08:41	2019-08-30	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2189	delivery	5	45
7061	2019-08-30 05:20:24	2019-08-30	8	[{"id_menu":5,"count":1}]	1642	pick-up	0	8
7062	2019-08-30 05:38:17	2019-08-30	8	[{"id_menu":5,"count":1}]	826	pick-up	0	8
7063	2019-08-30 05:56:54	2019-08-30	17	[{"id_menu":4,"count":1}]	2605	delivery	5	22
7064	2019-08-30 07:24:02	2019-08-30	8	[{"id_menu":5,"count":1}]	830	delivery	5	13
7065	2019-08-30 07:40:56	2019-08-30	12	[{"id_menu":3,"count":1}]	1528	pick-up	0	12
7066	2019-08-30 08:01:13	2019-08-30	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2611	pick-up	0	29
7067	2019-08-30 08:06:43	2019-08-30	8	[{"id_menu":5,"count":1}]	2594	pick-up	0	8
7068	2019-08-30 08:12:58	2019-08-30	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2608	delivery	5	22
7069	2019-08-30 08:20:35	2019-08-30	8	[{"id_menu":5,"count":1}]	1415	pick-up	0	8
7070	2019-08-30 08:33:34	2019-08-30	14	[{"id_menu":2,"count":1}]	2597	pick-up	0	14
7071	2019-08-30 08:54:43	2019-08-30	37	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	172	pick-up	0	37
7072	2019-08-30 09:25:15	2019-08-30	17	[{"id_menu":4,"count":1}]	2609	pick-up	0	17
7073	2019-08-30 09:27:17	2019-08-30	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	2604	pick-up	0	23
7074	2019-08-30 09:37:29	2019-08-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2492	pick-up	0	22
7075	2019-08-30 10:49:56	2019-08-30	12	[{"id_menu":3,"count":1}]	1731	pick-up	0	12
7076	2019-08-30 10:54:31	2019-08-30	8	[{"id_menu":5,"count":1}]	2606	pick-up	0	8
7077	2019-08-30 11:19:15	2019-08-30	14	[{"id_menu":2,"count":1}]	2309	pick-up	0	14
7078	2019-08-30 11:38:56	2019-08-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	880	delivery	5	22
7079	2019-08-30 12:18:33	2019-08-30	14	[{"id_menu":2,"count":1}]	2603	pick-up	0	14
7080	2019-08-30 12:32:48	2019-08-30	9	[{"id_menu":6,"count":1}]	1610	delivery	5	14
7081	2019-08-30 12:44:46	2019-08-30	12	[{"id_menu":3,"count":1}]	1354	pick-up	0	12
7082	2019-08-30 13:11:54	2019-08-30	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	669	pick-up	0	29
7083	2019-08-30 13:17:34	2019-08-30	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	2330	delivery	5	29
7084	2019-08-30 13:44:52	2019-08-30	14	[{"id_menu":2,"count":1}]	2602	delivery	5	19
7085	2019-08-30 13:58:53	2019-08-30	8	[{"id_menu":5,"count":1}]	531	pick-up	0	8
7086	2019-08-30 14:06:00	2019-08-30	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2575	pick-up	0	26
7087	2019-08-30 14:24:12	2019-08-30	14	[{"id_menu":2,"count":2}]	2600	delivery	5	19
7088	2019-08-30 15:28:04	2019-08-30	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	1181	pick-up	0	38
7089	2019-08-30 15:47:24	2019-08-30	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2115	pick-up	0	29
7090	2019-08-30 16:00:32	2019-08-30	12	[{"id_menu":1,"count":1}]	2599	delivery	5	17
7091	2019-08-30 16:28:57	2019-08-30	12	[{"id_menu":3,"count":1}]	2216	delivery	5	17
7092	2019-08-30 16:40:38	2019-08-30	14	[{"id_menu":2,"count":1}]	2607	pick-up	0	14
7093	2019-08-30 17:31:23	2019-08-30	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2442	pick-up	0	35
7094	2019-08-30 17:32:08	2019-08-30	9	[{"id_menu":6,"count":1}]	970	pick-up	0	9
7095	2019-08-30 17:55:16	2019-08-30	9	[{"id_menu":6,"count":1}]	2237	pick-up	0	9
7096	2019-08-30 19:36:06	2019-08-30	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1968	pick-up	0	21
7097	2019-08-30 20:30:26	2019-08-30	17	[{"id_menu":4,"count":1}]	2595	pick-up	0	17
7098	2019-08-30 20:37:05	2019-08-30	9	[{"id_menu":7,"count":1}]	2610	pick-up	0	9
7099	2019-08-30 20:53:55	2019-08-30	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	511	pick-up	0	26
7100	2019-08-30 22:13:18	2019-08-30	17	[{"id_menu":4,"count":1}]	2601	pick-up	0	17
7101	2019-08-30 22:16:37	2019-08-30	38	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	787	pick-up	0	38
7102	2019-08-30 22:41:18	2019-08-30	14	[{"id_menu":2,"count":1}]	1831	delivery	5	19
7103	2019-08-30 22:44:21	2019-08-30	12	[{"id_menu":1,"count":1}]	27	pick-up	0	12
7104	2019-08-30 22:45:36	2019-08-30	14	[{"id_menu":2,"count":1}]	73	pick-up	0	14
7105	2019-08-30 23:50:25	2019-08-30	9	[{"id_menu":7,"count":1}]	1279	pick-up	0	9
7106	2019-08-30 23:59:27	2019-08-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2546	delivery	5	28
7107	2019-08-31 00:01:46	2019-08-31	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	799	pick-up	0	17
7108	2019-08-31 00:14:50	2019-08-31	12	[{"id_menu":3,"count":1}]	1053	pick-up	0	12
7109	2019-08-31 00:51:36	2019-08-31	14	[{"id_menu":2,"count":1}]	1432	delivery	5	19
7110	2019-08-31 01:11:42	2019-08-31	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1692	pick-up	0	35
7111	2019-08-31 01:36:38	2019-08-31	9	[{"id_menu":6,"count":1}]	378	delivery	5	14
7112	2019-08-31 01:39:10	2019-08-31	17	[{"id_menu":4,"count":1}]	29	pick-up	0	17
7113	2019-08-31 02:27:55	2019-08-31	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2062	delivery	5	26
7114	2019-08-31 02:28:31	2019-08-31	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2068	delivery	5	34
7115	2019-08-31 03:17:27	2019-08-31	17	[{"id_menu":4,"count":1}]	340	pick-up	0	17
7116	2019-08-31 03:55:35	2019-08-31	12	[{"id_menu":1,"count":1}]	2619	pick-up	0	12
7117	2019-08-31 04:27:58	2019-08-31	8	[{"id_menu":5,"count":1}]	2627	pick-up	0	8
7118	2019-08-31 04:38:11	2019-08-31	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	708	pick-up	0	21
7119	2019-08-31 04:50:07	2019-08-31	9	[{"id_menu":7,"count":1}]	184	pick-up	0	9
7120	2019-08-31 06:28:41	2019-08-31	9	[{"id_menu":7,"count":1}]	2618	delivery	5	14
7121	2019-08-31 06:29:25	2019-08-31	12	[{"id_menu":3,"count":1}]	1166	pick-up	0	12
7122	2019-08-31 06:55:18	2019-08-31	12	[{"id_menu":3,"count":1}]	2624	pick-up	0	12
7123	2019-08-31 06:59:05	2019-08-31	12	[{"id_menu":1,"count":1}]	1121	pick-up	0	12
7124	2019-08-31 07:08:29	2019-08-31	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1163	delivery	5	43
7125	2019-08-31 07:43:07	2019-08-31	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	2615	delivery	5	27
7126	2019-08-31 08:19:47	2019-08-31	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	915	pick-up	0	20
7127	2019-08-31 08:25:31	2019-08-31	9	[{"id_menu":6,"count":1}]	1839	pick-up	0	9
7128	2019-08-31 08:39:19	2019-08-31	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1406	pick-up	0	49
7129	2019-08-31 08:45:53	2019-08-31	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	865	pick-up	0	18
7130	2019-08-31 08:48:59	2019-08-31	14	[{"id_menu":2,"count":1}]	558	pick-up	0	14
7131	2019-08-31 08:49:07	2019-08-31	9	[{"id_menu":6,"count":1}]	1746	pick-up	0	9
7132	2019-08-31 08:55:34	2019-08-31	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1255	delivery	5	31
7133	2019-08-31 08:56:21	2019-08-31	8	[{"id_menu":5,"count":1}]	2374	pick-up	0	8
7134	2019-08-31 09:02:17	2019-08-31	14	[{"id_menu":2,"count":1}]	773	pick-up	0	14
7135	2019-08-31 09:15:42	2019-08-31	12	[{"id_menu":1,"count":1}]	518	delivery	5	17
7136	2019-08-31 09:16:48	2019-08-31	12	[{"id_menu":1,"count":1}]	2613	delivery	5	17
7137	2019-08-31 09:43:09	2019-08-31	14	[{"id_menu":2,"count":1}]	1641	pick-up	0	14
7138	2019-08-31 10:02:16	2019-08-31	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2272	pick-up	0	23
7139	2019-08-31 10:23:08	2019-08-31	9	[{"id_menu":7,"count":1}]	22	pick-up	0	9
7140	2019-08-31 10:36:38	2019-08-31	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2616	pick-up	0	21
7141	2019-08-31 10:58:29	2019-08-31	17	[{"id_menu":4,"count":1}]	486	pick-up	0	17
7142	2019-08-31 11:04:35	2019-08-31	9	[{"id_menu":6,"count":1}]	1848	pick-up	0	9
7143	2019-08-31 11:05:00	2019-08-31	14	[{"id_menu":2,"count":1}]	2612	delivery	5	19
7144	2019-08-31 11:18:31	2019-08-31	9	[{"id_menu":6,"count":1}]	1344	pick-up	0	9
7145	2019-08-31 12:26:23	2019-08-31	9	[{"id_menu":6,"count":1}]	1992	pick-up	0	9
7146	2019-08-31 12:26:55	2019-08-31	12	[{"id_menu":1,"count":1}]	2141	delivery	5	17
7147	2019-08-31 12:32:01	2019-08-31	12	[{"id_menu":3,"count":1}]	753	delivery	5	17
7148	2019-08-31 12:36:28	2019-08-31	8	[{"id_menu":5,"count":2}]	2614	delivery	5	13
7149	2019-08-31 13:06:40	2019-08-31	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1106	delivery	5	40
7150	2019-08-31 13:29:32	2019-08-31	9	[{"id_menu":7,"count":1}]	2621	delivery	5	14
7151	2019-08-31 13:33:03	2019-08-31	9	[{"id_menu":7,"count":1}]	609	delivery	5	14
7152	2019-08-31 13:45:45	2019-08-31	17	[{"id_menu":4,"count":1}]	1563	pick-up	0	17
7153	2019-08-31 14:06:37	2019-08-31	9	[{"id_menu":7,"count":1}]	1783	pick-up	0	9
7154	2019-08-31 14:14:23	2019-08-31	12	[{"id_menu":3,"count":2}]	666	pick-up	0	12
7155	2019-08-31 14:18:31	2019-08-31	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	2575	pick-up	0	29
7156	2019-08-31 14:46:10	2019-08-31	8	[{"id_menu":5,"count":1}]	1153	delivery	5	13
7157	2019-08-31 15:03:20	2019-08-31	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1950	pick-up	0	30
7158	2019-08-31 15:32:47	2019-08-31	9	[{"id_menu":6,"count":1}]	903	pick-up	0	9
7159	2019-08-31 15:38:25	2019-08-31	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	158	pick-up	0	31
7160	2019-08-31 15:40:24	2019-08-31	12	[{"id_menu":3,"count":1}]	2232	pick-up	0	12
7161	2019-08-31 15:45:31	2019-08-31	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	351	delivery	5	29
7162	2019-08-31 16:09:08	2019-08-31	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	394	pick-up	0	23
7163	2019-08-31 16:27:49	2019-08-31	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	642	delivery	5	36
7164	2019-08-31 16:47:01	2019-08-31	9	[{"id_menu":7,"count":1}]	2557	pick-up	0	9
7165	2019-08-31 17:17:36	2019-08-31	17	[{"id_menu":4,"count":1}]	2626	pick-up	0	17
7166	2019-08-31 17:19:00	2019-08-31	9	[{"id_menu":6,"count":1}]	778	pick-up	0	9
7167	2019-08-31 18:05:37	2019-08-31	14	[{"id_menu":2,"count":1}]	2617	pick-up	0	14
7168	2019-08-31 18:19:05	2019-08-31	17	[{"id_menu":4,"count":1}]	2628	pick-up	0	17
7169	2019-08-31 18:26:49	2019-08-31	17	[{"id_menu":4,"count":1}]	2625	pick-up	0	17
7170	2019-08-31 18:30:10	2019-08-31	43	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1900	delivery	5	48
7171	2019-08-31 21:08:41	2019-08-31	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	466	delivery	5	40
7172	2019-08-31 21:20:32	2019-08-31	8	[{"id_menu":5,"count":1}]	2622	delivery	5	13
7173	2019-08-31 21:24:52	2019-08-31	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1301	pick-up	0	17
7174	2019-08-31 21:48:08	2019-08-31	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	2629	pick-up	0	20
7175	2019-08-31 21:52:21	2019-08-31	12	[{"id_menu":3,"count":1}]	2577	pick-up	0	12
7176	2019-08-31 22:03:15	2019-08-31	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2623	pick-up	0	29
7177	2019-08-31 22:15:11	2019-08-31	9	[{"id_menu":6,"count":1}]	612	delivery	5	14
7178	2019-08-31 22:17:19	2019-08-31	9	[{"id_menu":6,"count":1}]	2440	delivery	5	14
7179	2019-08-31 22:18:25	2019-08-31	17	[{"id_menu":4,"count":2}]	2630	pick-up	0	17
7180	2019-08-31 23:59:54	2019-08-31	9	[{"id_menu":7,"count":1}]	2620	delivery	5	14
7181	2019-09-01 00:25:32	2019-09-01	9	[{"id_menu":7,"count":1}]	226	delivery	5	14
7182	2019-09-01 00:29:20	2019-09-01	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2551	pick-up	0	21
7183	2019-09-01 00:38:05	2019-09-01	9	[{"id_menu":6,"count":1}]	2638	delivery	5	14
7184	2019-09-01 00:41:48	2019-09-01	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1289	pick-up	0	26
7185	2019-09-01 00:42:04	2019-09-01	8	[{"id_menu":5,"count":1}]	2655	delivery	5	13
7186	2019-09-01 01:21:23	2019-09-01	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	203	pick-up	0	29
7187	2019-09-01 01:23:20	2019-09-01	14	[{"id_menu":2,"count":1}]	2573	pick-up	0	14
7188	2019-09-01 01:46:22	2019-09-01	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1324	delivery	5	36
7189	2019-09-01 01:46:25	2019-09-01	14	[{"id_menu":2,"count":1}]	376	pick-up	0	14
7190	2019-09-01 01:51:02	2019-09-01	12	[{"id_menu":1,"count":1}]	531	pick-up	0	12
7191	2019-09-01 02:32:36	2019-09-01	9	[{"id_menu":6,"count":1}]	2228	delivery	5	14
7192	2019-09-01 02:51:24	2019-09-01	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2635	delivery	5	52
7193	2019-09-01 02:52:43	2019-09-01	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	832	delivery	5	29
7194	2019-09-01 03:15:38	2019-09-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	754	pick-up	0	17
7195	2019-09-01 03:26:06	2019-09-01	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1712	pick-up	0	20
7196	2019-09-01 03:37:03	2019-09-01	9	[{"id_menu":7,"count":1}]	2631	pick-up	0	9
7197	2019-09-01 03:43:37	2019-09-01	8	[{"id_menu":5,"count":1}]	2358	delivery	5	13
7198	2019-09-01 03:51:11	2019-09-01	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	575	pick-up	0	31
7199	2019-09-01 03:57:21	2019-09-01	12	[{"id_menu":1,"count":1}]	396	pick-up	0	12
7200	2019-09-01 04:31:24	2019-09-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1441	pick-up	0	17
7201	2019-09-01 04:48:35	2019-09-01	12	[{"id_menu":3,"count":1}]	2633	delivery	5	17
7202	2019-09-01 04:51:33	2019-09-01	9	[{"id_menu":6,"count":1}]	82	pick-up	0	9
7203	2019-09-01 05:19:36	2019-09-01	8	[{"id_menu":5,"count":1}]	135	pick-up	0	8
7204	2019-09-01 05:19:42	2019-09-01	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	382	pick-up	0	26
7205	2019-09-01 05:36:45	2019-09-01	12	[{"id_menu":3,"count":1}]	2634	pick-up	0	12
7206	2019-09-01 05:39:39	2019-09-01	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	654	delivery	5	45
7207	2019-09-01 05:47:19	2019-09-01	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	66	delivery	5	26
7208	2019-09-01 06:29:17	2019-09-01	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2653	pick-up	0	26
7209	2019-09-01 06:55:52	2019-09-01	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	337	pick-up	0	20
7210	2019-09-01 06:59:08	2019-09-01	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1679	delivery	5	40
7211	2019-09-01 07:12:18	2019-09-01	17	[{"id_menu":4,"count":1}]	743	delivery	5	22
7212	2019-09-01 07:39:52	2019-09-01	17	[{"id_menu":4,"count":1}]	2637	delivery	5	22
7213	2019-09-01 07:58:46	2019-09-01	12	[{"id_menu":1,"count":1}]	2513	delivery	5	17
7214	2019-09-01 08:08:56	2019-09-01	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	475	delivery	5	37
7215	2019-09-01 08:11:21	2019-09-01	8	[{"id_menu":5,"count":1}]	332	delivery	5	13
7216	2019-09-01 08:15:08	2019-09-01	12	[{"id_menu":1,"count":1}]	247	delivery	5	17
7217	2019-09-01 08:57:56	2019-09-01	12	[{"id_menu":3,"count":1}]	2276	pick-up	0	12
7218	2019-09-01 09:16:37	2019-09-01	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	749	pick-up	0	31
7219	2019-09-01 09:29:59	2019-09-01	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2649	delivery	5	37
7220	2019-09-01 09:42:03	2019-09-01	12	[{"id_menu":1,"count":1}]	2267	delivery	5	17
7221	2019-09-01 10:11:23	2019-09-01	8	[{"id_menu":5,"count":1}]	2437	delivery	5	13
7222	2019-09-01 10:13:29	2019-09-01	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1316	pick-up	0	24
7223	2019-09-01 10:15:27	2019-09-01	14	[{"id_menu":2,"count":1}]	2233	delivery	5	19
7224	2019-09-01 10:38:43	2019-09-01	8	[{"id_menu":5,"count":1}]	2548	delivery	5	13
7225	2019-09-01 10:42:39	2019-09-01	17	[{"id_menu":4,"count":1}]	934	pick-up	0	17
7226	2019-09-01 11:08:42	2019-09-01	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1530	delivery	5	42
7227	2019-09-01 11:24:46	2019-09-01	14	[{"id_menu":2,"count":1}]	1610	delivery	5	19
7228	2019-09-01 11:27:52	2019-09-01	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	886	pick-up	0	29
7229	2019-09-01 11:49:59	2019-09-01	9	[{"id_menu":7,"count":1}]	1257	pick-up	0	9
7230	2019-09-01 11:52:55	2019-09-01	12	[{"id_menu":1,"count":1}]	2636	delivery	5	17
7231	2019-09-01 12:04:10	2019-09-01	17	[{"id_menu":4,"count":1}]	2632	delivery	5	22
7232	2019-09-01 12:11:20	2019-09-01	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2619	delivery	5	26
7233	2019-09-01 12:12:43	2019-09-01	9	[{"id_menu":7,"count":1}]	185	pick-up	0	9
7234	2019-09-01 12:12:45	2019-09-01	17	[{"id_menu":4,"count":1}]	1104	pick-up	0	17
7235	2019-09-01 12:39:23	2019-09-01	9	[{"id_menu":7,"count":2}]	2657	delivery	5	14
7236	2019-09-01 13:27:09	2019-09-01	9	[{"id_menu":6,"count":1}]	2644	pick-up	0	9
7237	2019-09-01 13:34:01	2019-09-01	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	285	pick-up	0	20
7238	2019-09-01 14:06:24	2019-09-01	9	[{"id_menu":7,"count":1}]	93	pick-up	0	9
7239	2019-09-01 14:15:36	2019-09-01	9	[{"id_menu":6,"count":1}]	5	pick-up	0	9
7240	2019-09-01 14:31:27	2019-09-01	12	[{"id_menu":1,"count":1}]	2646	delivery	5	17
7241	2019-09-01 14:33:13	2019-09-01	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":3}]	701	pick-up	0	29
7242	2019-09-01 15:17:29	2019-09-01	12	[{"id_menu":1,"count":1}]	1935	pick-up	0	12
7243	2019-09-01 15:47:47	2019-09-01	9	[{"id_menu":6,"count":1}]	1512	pick-up	0	9
7244	2019-09-01 15:55:10	2019-09-01	12	[{"id_menu":1,"count":1}]	2641	pick-up	0	12
7245	2019-09-01 16:01:43	2019-09-01	14	[{"id_menu":2,"count":1}]	643	delivery	5	19
7246	2019-09-01 16:02:53	2019-09-01	12	[{"id_menu":1,"count":1}]	213	pick-up	0	12
7247	2019-09-01 16:04:34	2019-09-01	9	[{"id_menu":6,"count":2}]	2648	delivery	5	14
7248	2019-09-01 16:05:35	2019-09-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2647	delivery	5	28
7249	2019-09-01 16:15:58	2019-09-01	9	[{"id_menu":7,"count":1}]	2366	pick-up	0	9
7250	2019-09-01 16:38:19	2019-09-01	14	[{"id_menu":2,"count":1}]	2642	pick-up	0	14
7251	2019-09-01 16:54:56	2019-09-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	958	pick-up	0	17
7252	2019-09-01 17:08:56	2019-09-01	8	[{"id_menu":5,"count":1}]	2253	pick-up	0	8
7253	2019-09-01 17:17:23	2019-09-01	12	[{"id_menu":3,"count":1}]	2546	pick-up	0	12
7254	2019-09-01 17:18:14	2019-09-01	17	[{"id_menu":4,"count":1}]	2508	pick-up	0	17
7255	2019-09-01 17:18:14	2019-09-01	8	[{"id_menu":5,"count":1}]	1942	delivery	5	13
7256	2019-09-01 17:26:07	2019-09-01	14	[{"id_menu":2,"count":2}]	880	delivery	5	19
7257	2019-09-01 17:26:45	2019-09-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1273	pick-up	0	23
7258	2019-09-01 17:42:12	2019-09-01	9	[{"id_menu":7,"count":1}]	2652	delivery	5	14
7259	2019-09-01 18:21:25	2019-09-01	43	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	489	delivery	5	48
7260	2019-09-01 18:22:28	2019-09-01	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2651	pick-up	0	26
7261	2019-09-01 18:25:44	2019-09-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2640	delivery	5	26
7262	2019-09-01 18:29:31	2019-09-01	12	[{"id_menu":3,"count":1}]	2492	pick-up	0	12
7263	2019-09-01 18:30:42	2019-09-01	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	29	pick-up	0	43
7264	2019-09-01 18:32:53	2019-09-01	9	[{"id_menu":6,"count":1}]	173	pick-up	0	9
7265	2019-09-01 18:44:10	2019-09-01	9	[{"id_menu":6,"count":1}]	2562	delivery	5	14
7266	2019-09-01 18:44:20	2019-09-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2538	delivery	5	28
7267	2019-09-01 18:56:54	2019-09-01	14	[{"id_menu":2,"count":1}]	2262	pick-up	0	14
7268	2019-09-01 19:00:19	2019-09-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	466	delivery	5	22
7269	2019-09-01 19:07:35	2019-09-01	9	[{"id_menu":7,"count":1}]	1095	pick-up	0	9
7270	2019-09-01 19:19:17	2019-09-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1772	pick-up	0	31
7271	2019-09-01 19:25:02	2019-09-01	12	[{"id_menu":1,"count":1}]	136	pick-up	0	12
7272	2019-09-01 19:30:14	2019-09-01	12	[{"id_menu":1,"count":1}]	2656	delivery	5	17
7273	2019-09-01 19:43:04	2019-09-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":3}]	1710	delivery	5	22
7274	2019-09-01 19:49:17	2019-09-01	12	[{"id_menu":1,"count":1}]	1217	pick-up	0	12
7275	2019-09-01 20:14:53	2019-09-01	9	[{"id_menu":6,"count":1}]	2650	delivery	5	14
7276	2019-09-01 21:45:30	2019-09-01	9	[{"id_menu":6,"count":1}]	204	pick-up	0	9
7277	2019-09-01 22:06:15	2019-09-01	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	821	delivery	5	36
7278	2019-09-01 22:09:58	2019-09-01	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	2227	pick-up	0	26
7279	2019-09-01 22:27:31	2019-09-01	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1750	pick-up	0	21
7280	2019-09-01 22:34:48	2019-09-01	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2643	delivery	5	35
7281	2019-09-01 22:37:09	2019-09-01	9	[{"id_menu":7,"count":1}]	955	pick-up	0	9
7282	2019-09-01 22:50:08	2019-09-01	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2645	delivery	5	48
7283	2019-09-01 23:42:10	2019-09-01	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1016	pick-up	0	21
7284	2019-09-01 23:43:37	2019-09-01	14	[{"id_menu":2,"count":1}]	972	delivery	5	19
7285	2019-09-01 23:45:25	2019-09-01	8	[{"id_menu":5,"count":1}]	2639	delivery	5	13
7286	2019-09-01 23:59:11	2019-09-01	8	[{"id_menu":5,"count":1}]	2654	pick-up	0	8
7287	2019-09-02 00:11:59	2019-09-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2310	pick-up	0	26
7288	2019-09-02 00:21:24	2019-09-02	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2511	pick-up	0	31
7289	2019-09-02 00:51:53	2019-09-02	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2226	delivery	5	26
7290	2019-09-02 01:10:55	2019-09-02	12	[{"id_menu":3,"count":1}]	638	delivery	5	17
7291	2019-09-02 01:32:14	2019-09-02	14	[{"id_menu":2,"count":1}]	2217	pick-up	0	14
7292	2019-09-02 01:39:24	2019-09-02	17	[{"id_menu":4,"count":1}]	1893	pick-up	0	17
7293	2019-09-02 02:32:29	2019-09-02	14	[{"id_menu":2,"count":1}]	2674	pick-up	0	14
7294	2019-09-02 02:53:55	2019-09-02	9	[{"id_menu":6,"count":1}]	527	delivery	5	14
7295	2019-09-02 04:12:08	2019-09-02	9	[{"id_menu":6,"count":1}]	2680	pick-up	0	9
7296	2019-09-02 04:22:27	2019-09-02	9	[{"id_menu":6,"count":1}]	2672	delivery	5	14
7297	2019-09-02 05:05:35	2019-09-02	14	[{"id_menu":2,"count":1}]	2661	delivery	5	19
7298	2019-09-02 05:42:35	2019-09-02	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2623	pick-up	0	21
7299	2019-09-02 05:57:21	2019-09-02	12	[{"id_menu":3,"count":1}]	2663	delivery	5	17
7300	2019-09-02 06:34:20	2019-09-02	9	[{"id_menu":6,"count":1}]	2664	delivery	5	14
7301	2019-09-02 07:43:54	2019-09-02	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	1238	pick-up	0	29
7302	2019-09-02 08:38:11	2019-09-02	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2633	delivery	5	26
7303	2019-09-02 09:00:22	2019-09-02	17	[{"id_menu":4,"count":1}]	802	delivery	5	22
7304	2019-09-02 09:22:02	2019-09-02	17	[{"id_menu":4,"count":1}]	2353	pick-up	0	17
7305	2019-09-02 09:58:36	2019-09-02	14	[{"id_menu":2,"count":1}]	711	delivery	5	19
7306	2019-09-02 10:47:28	2019-09-02	17	[{"id_menu":4,"count":1}]	2443	delivery	5	22
7307	2019-09-02 11:50:21	2019-09-02	9	[{"id_menu":7,"count":1}]	2665	delivery	5	14
7308	2019-09-02 13:39:30	2019-09-02	12	[{"id_menu":1,"count":1}]	806	pick-up	0	12
7309	2019-09-02 13:46:52	2019-09-02	14	[{"id_menu":2,"count":1}]	2679	delivery	5	19
7310	2019-09-02 14:04:36	2019-09-02	9	[{"id_menu":6,"count":1}]	593	delivery	5	14
7311	2019-09-02 14:05:32	2019-09-02	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2287	delivery	5	49
7312	2019-09-02 14:29:43	2019-09-02	17	[{"id_menu":4,"count":1}]	1847	pick-up	0	17
7313	2019-09-02 15:11:28	2019-09-02	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	743	delivery	5	31
7314	2019-09-02 15:58:27	2019-09-02	17	[{"id_menu":4,"count":1}]	1520	pick-up	0	17
7315	2019-09-02 17:03:05	2019-09-02	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	2540	pick-up	0	20
7316	2019-09-02 17:41:40	2019-09-02	9	[{"id_menu":6,"count":1}]	2230	pick-up	0	9
7317	2019-09-02 17:46:57	2019-09-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2660	delivery	5	31
7318	2019-09-02 18:28:11	2019-09-02	14	[{"id_menu":2,"count":1}]	2669	delivery	5	19
7319	2019-09-02 18:36:30	2019-09-02	14	[{"id_menu":2,"count":1}]	822	delivery	5	19
7320	2019-09-02 19:03:28	2019-09-02	14	[{"id_menu":2,"count":1}]	2670	delivery	5	19
7321	2019-09-02 19:06:32	2019-09-02	9	[{"id_menu":6,"count":1}]	2658	delivery	5	14
7322	2019-09-02 19:24:16	2019-09-02	9	[{"id_menu":6,"count":1}]	2668	pick-up	0	9
7323	2019-09-02 19:56:03	2019-09-02	8	[{"id_menu":5,"count":1}]	2677	delivery	5	13
7324	2019-09-02 20:03:47	2019-09-02	9	[{"id_menu":7,"count":1}]	2366	pick-up	0	9
7325	2019-09-02 20:07:00	2019-09-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	166	pick-up	0	23
7326	2019-09-02 20:21:09	2019-09-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	2681	delivery	5	22
7327	2019-09-02 20:30:16	2019-09-02	9	[{"id_menu":6,"count":1}]	2676	pick-up	0	9
7328	2019-09-02 21:00:14	2019-09-02	14	[{"id_menu":2,"count":1}]	1563	delivery	5	19
7329	2019-09-02 22:03:45	2019-09-02	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2092	delivery	5	34
7330	2019-09-02 22:07:51	2019-09-02	9	[{"id_menu":6,"count":1}]	2675	delivery	5	14
7331	2019-09-02 22:15:44	2019-09-02	8	[{"id_menu":5,"count":1}]	1293	delivery	5	13
7332	2019-09-02 22:20:12	2019-09-02	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1860	delivery	5	27
7333	2019-09-02 22:48:56	2019-09-02	9	[{"id_menu":6,"count":1}]	720	delivery	5	14
7334	2019-09-02 23:06:08	2019-09-02	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	228	pick-up	0	21
7335	2019-09-02 23:11:45	2019-09-02	9	[{"id_menu":6,"count":1}]	2659	pick-up	0	9
7336	2019-09-03 00:08:48	2019-09-03	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1215	pick-up	0	17
7337	2019-09-03 00:33:25	2019-09-03	12	[{"id_menu":3,"count":1}]	1582	pick-up	0	12
7338	2019-09-03 00:54:42	2019-09-03	8	[{"id_menu":5,"count":1}]	306	delivery	5	13
7339	2019-09-03 01:15:20	2019-09-03	9	[{"id_menu":6,"count":2}]	1592	pick-up	0	9
7340	2019-09-03 01:17:23	2019-09-03	9	[{"id_menu":7,"count":1}]	2689	delivery	5	14
7341	2019-09-03 01:44:51	2019-09-03	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	357	delivery	5	42
7342	2019-09-03 01:57:16	2019-09-03	12	[{"id_menu":1,"count":1}]	361	pick-up	0	12
7343	2019-09-03 02:20:27	2019-09-03	12	[{"id_menu":3,"count":1}]	1107	delivery	5	17
7344	2019-09-03 02:21:24	2019-09-03	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2682	pick-up	0	21
7345	2019-09-03 02:52:27	2019-09-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2050	delivery	5	28
7346	2019-09-03 02:54:52	2019-09-03	12	[{"id_menu":1,"count":1}]	2697	pick-up	0	12
7347	2019-09-03 03:15:37	2019-09-03	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1889	delivery	5	36
7348	2019-09-03 03:22:18	2019-09-03	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	2687	delivery	5	22
7349	2019-09-03 03:36:52	2019-09-03	12	[{"id_menu":1,"count":1}]	2701	delivery	5	17
7350	2019-09-03 05:36:28	2019-09-03	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2702	pick-up	0	21
7351	2019-09-03 05:40:41	2019-09-03	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	270	pick-up	0	17
7352	2019-09-03 05:42:44	2019-09-03	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1423	pick-up	0	25
7353	2019-09-03 06:12:23	2019-09-03	14	[{"id_menu":2,"count":1}]	2602	delivery	5	19
7354	2019-09-03 06:24:29	2019-09-03	9	[{"id_menu":7,"count":1}]	283	pick-up	0	9
7355	2019-09-03 07:00:28	2019-09-03	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2691	delivery	5	26
7356	2019-09-03 07:14:43	2019-09-03	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1963	pick-up	0	32
7357	2019-09-03 07:51:26	2019-09-03	14	[{"id_menu":2,"count":1}]	1049	delivery	5	19
7358	2019-09-03 08:06:24	2019-09-03	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	49	delivery	5	30
7359	2019-09-03 08:39:59	2019-09-03	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	2683	delivery	5	36
7360	2019-09-03 08:42:06	2019-09-03	8	[{"id_menu":5,"count":1}]	1729	pick-up	0	8
7361	2019-09-03 08:53:14	2019-09-03	14	[{"id_menu":2,"count":1}]	2185	pick-up	0	14
7362	2019-09-03 09:09:50	2019-09-03	9	[{"id_menu":6,"count":1}]	602	delivery	5	14
7363	2019-09-03 09:14:56	2019-09-03	8	[{"id_menu":5,"count":1}]	981	pick-up	0	8
7364	2019-09-03 09:19:31	2019-09-03	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2627	delivery	5	28
7365	2019-09-03 09:32:13	2019-09-03	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1854	pick-up	0	31
7366	2019-09-03 09:45:19	2019-09-03	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2692	pick-up	0	22
7367	2019-09-03 09:51:03	2019-09-03	12	[{"id_menu":3,"count":1}]	397	delivery	5	17
7368	2019-09-03 10:03:15	2019-09-03	9	[{"id_menu":7,"count":1}]	1576	pick-up	0	9
7369	2019-09-03 10:51:01	2019-09-03	9	[{"id_menu":6,"count":1}]	833	pick-up	0	9
7370	2019-09-03 11:41:16	2019-09-03	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2236	pick-up	0	25
7371	2019-09-03 11:43:07	2019-09-03	9	[{"id_menu":7,"count":1}]	2266	delivery	5	14
7372	2019-09-03 11:43:54	2019-09-03	8	[{"id_menu":5,"count":1}]	871	delivery	5	13
7373	2019-09-03 12:25:35	2019-09-03	8	[{"id_menu":5,"count":1}]	931	pick-up	0	8
7374	2019-09-03 12:43:02	2019-09-03	9	[{"id_menu":6,"count":1}]	964	delivery	5	14
7375	2019-09-03 12:55:42	2019-09-03	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2332	delivery	5	48
7376	2019-09-03 13:14:30	2019-09-03	14	[{"id_menu":2,"count":1}]	1651	delivery	5	19
7377	2019-09-03 14:03:15	2019-09-03	9	[{"id_menu":6,"count":1}]	2703	pick-up	0	9
7378	2019-09-03 14:15:01	2019-09-03	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2704	delivery	5	25
7379	2019-09-03 14:16:17	2019-09-03	12	[{"id_menu":3,"count":1}]	2616	pick-up	0	12
7380	2019-09-03 15:08:11	2019-09-03	9	[{"id_menu":7,"count":1}]	1316	pick-up	0	9
7381	2019-09-03 15:24:15	2019-09-03	8	[{"id_menu":5,"count":1}]	2367	delivery	5	13
7382	2019-09-03 16:08:14	2019-09-03	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2695	delivery	5	27
7383	2019-09-03 16:54:08	2019-09-03	9	[{"id_menu":7,"count":1}]	918	delivery	5	14
7384	2019-09-03 18:18:21	2019-09-03	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2698	pick-up	0	35
7385	2019-09-03 18:41:29	2019-09-03	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	642	delivery	5	25
7386	2019-09-03 18:44:29	2019-09-03	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	413	pick-up	0	40
7387	2019-09-03 20:10:51	2019-09-03	17	[{"id_menu":4,"count":1}]	2690	delivery	5	22
7388	2019-09-03 20:16:34	2019-09-03	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	2520	delivery	5	26
7389	2019-09-03 20:45:56	2019-09-03	17	[{"id_menu":4,"count":1}]	2283	pick-up	0	17
7390	2019-09-03 21:10:56	2019-09-03	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2700	delivery	5	30
7391	2019-09-03 22:04:33	2019-09-03	12	[{"id_menu":1,"count":1}]	1055	pick-up	0	12
7392	2019-09-03 22:18:11	2019-09-03	14	[{"id_menu":2,"count":1}]	2587	pick-up	0	14
7393	2019-09-03 22:43:52	2019-09-03	17	[{"id_menu":4,"count":1}]	1048	delivery	5	22
7394	2019-09-03 22:55:03	2019-09-03	17	[{"id_menu":4,"count":1}]	1821	delivery	5	22
7395	2019-09-03 23:51:54	2019-09-03	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1700	pick-up	0	21
7396	2019-09-04 00:22:25	2019-09-04	12	[{"id_menu":3,"count":1}]	1797	pick-up	0	12
7397	2019-09-04 00:54:06	2019-09-04	14	[{"id_menu":2,"count":1}]	21	pick-up	0	14
7398	2019-09-04 01:02:30	2019-09-04	12	[{"id_menu":1,"count":1}]	2056	pick-up	0	12
7399	2019-09-04 02:17:12	2019-09-04	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2217	pick-up	0	17
7400	2019-09-04 02:17:24	2019-09-04	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	2724	delivery	5	22
7401	2019-09-04 02:34:34	2019-09-04	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2716	pick-up	0	29
7402	2019-09-04 02:41:08	2019-09-04	17	[{"id_menu":4,"count":2}]	2474	pick-up	0	17
7403	2019-09-04 02:49:41	2019-09-04	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	1680	delivery	5	36
7404	2019-09-04 03:05:28	2019-09-04	8	[{"id_menu":5,"count":1}]	972	delivery	5	13
7405	2019-09-04 03:16:36	2019-09-04	9	[{"id_menu":7,"count":1}]	1985	delivery	5	14
7406	2019-09-04 03:20:14	2019-09-04	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	2712	delivery	5	25
7407	2019-09-04 04:09:09	2019-09-04	12	[{"id_menu":3,"count":1}]	78	pick-up	0	12
7408	2019-09-04 04:41:31	2019-09-04	17	[{"id_menu":4,"count":2}]	1685	pick-up	0	17
7409	2019-09-04 05:11:48	2019-09-04	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	1104	pick-up	0	29
7410	2019-09-04 05:23:40	2019-09-04	9	[{"id_menu":7,"count":1}]	2283	delivery	5	14
7411	2019-09-04 05:35:58	2019-09-04	12	[{"id_menu":1,"count":1}]	777	delivery	5	17
7412	2019-09-04 05:43:34	2019-09-04	12	[{"id_menu":3,"count":1}]	1944	pick-up	0	12
7413	2019-09-04 05:44:02	2019-09-04	17	[{"id_menu":4,"count":1}]	2575	pick-up	0	17
7414	2019-09-04 06:15:16	2019-09-04	17	[{"id_menu":4,"count":2}]	2197	pick-up	0	17
7415	2019-09-04 06:33:56	2019-09-04	12	[{"id_menu":3,"count":1}]	2276	delivery	5	17
7416	2019-09-04 06:52:43	2019-09-04	14	[{"id_menu":2,"count":1}]	351	delivery	5	19
7417	2019-09-04 07:05:17	2019-09-04	12	[{"id_menu":1,"count":1}]	1713	pick-up	0	12
7418	2019-09-04 07:29:56	2019-09-04	12	[{"id_menu":1,"count":1}]	2720	delivery	5	17
7419	2019-09-04 07:41:29	2019-09-04	9	[{"id_menu":6,"count":1}]	2710	delivery	5	14
7420	2019-09-04 08:09:19	2019-09-04	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2706	pick-up	0	26
7421	2019-09-04 08:58:41	2019-09-04	12	[{"id_menu":1,"count":1}]	2714	delivery	5	17
7422	2019-09-04 09:17:10	2019-09-04	14	[{"id_menu":2,"count":1}]	1118	pick-up	0	14
7423	2019-09-04 09:37:01	2019-09-04	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2715	pick-up	0	31
7424	2019-09-04 09:38:09	2019-09-04	9	[{"id_menu":6,"count":1}]	2477	pick-up	0	9
7425	2019-09-04 10:33:03	2019-09-04	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	506	pick-up	0	31
7426	2019-09-04 11:32:54	2019-09-04	12	[{"id_menu":1,"count":1}]	2659	delivery	5	17
7427	2019-09-04 11:55:46	2019-09-04	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2105	delivery	5	55
7428	2019-09-04 12:09:20	2019-09-04	8	[{"id_menu":5,"count":1}]	2721	delivery	5	13
7429	2019-09-04 12:21:55	2019-09-04	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	247	pick-up	0	34
7430	2019-09-04 12:26:31	2019-09-04	8	[{"id_menu":5,"count":1}]	1841	pick-up	0	8
7431	2019-09-04 12:54:04	2019-09-04	14	[{"id_menu":2,"count":1}]	2708	delivery	5	19
7432	2019-09-04 13:10:13	2019-09-04	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	44	delivery	5	31
7433	2019-09-04 14:03:31	2019-09-04	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	143	pick-up	0	20
7434	2019-09-04 15:24:33	2019-09-04	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1677	pick-up	0	31
7435	2019-09-04 15:31:06	2019-09-04	8	[{"id_menu":5,"count":1}]	2726	pick-up	0	8
7436	2019-09-04 15:51:40	2019-09-04	9	[{"id_menu":6,"count":1}]	2725	pick-up	0	9
7437	2019-09-04 16:01:17	2019-09-04	12	[{"id_menu":1,"count":1}]	20	delivery	5	17
7438	2019-09-04 16:08:41	2019-09-04	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	2705	delivery	5	25
7439	2019-09-04 17:15:56	2019-09-04	12	[{"id_menu":3,"count":1}]	97	pick-up	0	12
7440	2019-09-04 17:49:50	2019-09-04	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1075	delivery	5	31
7441	2019-09-04 18:14:32	2019-09-04	14	[{"id_menu":2,"count":1}]	1424	delivery	5	19
7442	2019-09-04 18:16:09	2019-09-04	14	[{"id_menu":2,"count":1}]	1176	pick-up	0	14
7443	2019-09-04 18:56:33	2019-09-04	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2573	pick-up	0	34
7444	2019-09-04 19:10:37	2019-09-04	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1266	pick-up	0	21
7445	2019-09-04 19:18:46	2019-09-04	12	[{"id_menu":3,"count":1}]	2717	delivery	5	17
7446	2019-09-04 19:50:10	2019-09-04	8	[{"id_menu":5,"count":1}]	763	pick-up	0	8
7447	2019-09-04 20:43:05	2019-09-04	9	[{"id_menu":6,"count":1}]	2231	pick-up	0	9
7448	2019-09-04 20:47:09	2019-09-04	9	[{"id_menu":6,"count":1}]	2707	delivery	5	14
7449	2019-09-04 21:08:50	2019-09-04	12	[{"id_menu":1,"count":1}]	2572	pick-up	0	12
7450	2019-09-04 21:17:19	2019-09-04	12	[{"id_menu":3,"count":1}]	820	pick-up	0	12
7451	2019-09-04 21:29:52	2019-09-04	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2392	delivery	5	48
7452	2019-09-04 21:31:40	2019-09-04	17	[{"id_menu":4,"count":1}]	2723	delivery	5	22
7453	2019-09-04 21:34:38	2019-09-04	14	[{"id_menu":2,"count":1}]	749	pick-up	0	14
7454	2019-09-04 21:56:36	2019-09-04	14	[{"id_menu":2,"count":1}]	235	pick-up	0	14
7455	2019-09-04 21:58:30	2019-09-04	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2631	pick-up	0	21
7456	2019-09-04 22:05:04	2019-09-04	8	[{"id_menu":5,"count":1}]	254	delivery	5	13
7457	2019-09-04 22:22:07	2019-09-04	14	[{"id_menu":2,"count":1}]	2727	delivery	5	19
7458	2019-09-04 22:23:07	2019-09-04	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	528	delivery	5	31
7459	2019-09-04 22:37:43	2019-09-04	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	476	delivery	5	22
7460	2019-09-04 22:41:56	2019-09-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	743	pick-up	0	23
7461	2019-09-04 23:35:23	2019-09-04	8	[{"id_menu":5,"count":1}]	37	pick-up	0	8
7462	2019-09-04 23:44:08	2019-09-04	8	[{"id_menu":5,"count":1}]	209	pick-up	0	8
7463	2019-09-05 00:12:48	2019-09-05	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1017	pick-up	0	26
7464	2019-09-05 00:42:32	2019-09-05	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2231	pick-up	0	49
7465	2019-09-05 01:14:31	2019-09-05	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2729	delivery	5	25
7466	2019-09-05 01:18:46	2019-09-05	14	[{"id_menu":2,"count":1}]	872	pick-up	0	14
7467	2019-09-05 01:27:22	2019-09-05	12	[{"id_menu":1,"count":1}]	1545	pick-up	0	12
7468	2019-09-05 01:41:10	2019-09-05	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	295	pick-up	0	25
7469	2019-09-05 03:05:45	2019-09-05	9	[{"id_menu":6,"count":1}]	2561	delivery	5	14
7470	2019-09-05 03:10:02	2019-09-05	12	[{"id_menu":3,"count":1}]	2037	pick-up	0	12
7471	2019-09-05 03:19:59	2019-09-05	9	[{"id_menu":7,"count":1}]	389	pick-up	0	9
7472	2019-09-05 03:35:45	2019-09-05	9	[{"id_menu":6,"count":1}]	1690	delivery	5	14
7473	2019-09-05 03:36:03	2019-09-05	8	[{"id_menu":5,"count":1}]	227	pick-up	0	8
7474	2019-09-05 03:41:56	2019-09-05	14	[{"id_menu":2,"count":1}]	229	pick-up	0	14
7475	2019-09-05 04:25:46	2019-09-05	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1215	pick-up	0	31
7476	2019-09-05 05:33:13	2019-09-05	14	[{"id_menu":2,"count":1}]	351	pick-up	0	14
7477	2019-09-05 05:34:03	2019-09-05	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	48	pick-up	0	21
7478	2019-09-05 06:02:36	2019-09-05	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2733	delivery	5	31
7479	2019-09-05 06:09:09	2019-09-05	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2741	delivery	5	26
7480	2019-09-05 06:23:12	2019-09-05	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	94	delivery	5	39
7481	2019-09-05 06:46:23	2019-09-05	9	[{"id_menu":7,"count":1}]	1344	pick-up	0	9
7482	2019-09-05 06:50:57	2019-09-05	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1674	pick-up	0	17
7483	2019-09-05 07:26:47	2019-09-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2738	delivery	5	28
7484	2019-09-05 08:21:18	2019-09-05	9	[{"id_menu":6,"count":2}]	1934	pick-up	0	9
7485	2019-09-05 08:52:45	2019-09-05	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2734	delivery	5	31
7486	2019-09-05 09:35:26	2019-09-05	9	[{"id_menu":6,"count":1}]	1304	delivery	5	14
7487	2019-09-05 10:02:38	2019-09-05	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2731	delivery	5	40
7488	2019-09-05 10:28:24	2019-09-05	17	[{"id_menu":4,"count":1}]	2590	pick-up	0	17
7489	2019-09-05 10:57:45	2019-09-05	12	[{"id_menu":1,"count":1}]	1367	delivery	5	17
7490	2019-09-05 10:57:57	2019-09-05	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1414	pick-up	0	23
7491	2019-09-05 11:00:07	2019-09-05	17	[{"id_menu":4,"count":2}]	2735	pick-up	0	17
7492	2019-09-05 11:04:36	2019-09-05	12	[{"id_menu":3,"count":1}]	1209	pick-up	0	12
7493	2019-09-05 11:56:50	2019-09-05	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	143	pick-up	0	52
7494	2019-09-05 12:08:45	2019-09-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	2745	delivery	5	31
7495	2019-09-05 12:21:54	2019-09-05	14	[{"id_menu":2,"count":2}]	2752	pick-up	0	14
7496	2019-09-05 14:13:02	2019-09-05	8	[{"id_menu":5,"count":1}]	2732	pick-up	0	8
7497	2019-09-05 14:28:32	2019-09-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2541	delivery	5	31
7498	2019-09-05 14:40:21	2019-09-05	9	[{"id_menu":7,"count":1}]	287	delivery	5	14
7499	2019-09-05 14:44:49	2019-09-05	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2747	pick-up	0	50
7500	2019-09-05 15:07:04	2019-09-05	14	[{"id_menu":2,"count":2}]	2730	delivery	5	19
7501	2019-09-05 15:15:31	2019-09-05	14	[{"id_menu":2,"count":1}]	696	pick-up	0	14
7502	2019-09-05 15:23:27	2019-09-05	14	[{"id_menu":2,"count":2}]	189	pick-up	0	14
7503	2019-09-05 15:23:28	2019-09-05	17	[{"id_menu":4,"count":1}]	757	pick-up	0	17
7504	2019-09-05 15:25:34	2019-09-05	12	[{"id_menu":1,"count":1}]	1282	delivery	5	17
7505	2019-09-05 15:27:57	2019-09-05	8	[{"id_menu":5,"count":1}]	315	pick-up	0	8
7506	2019-09-05 15:39:52	2019-09-05	12	[{"id_menu":3,"count":1}]	399	pick-up	0	12
7507	2019-09-05 15:41:00	2019-09-05	9	[{"id_menu":7,"count":1}]	2736	pick-up	0	9
7508	2019-09-05 15:44:32	2019-09-05	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2750	pick-up	0	48
7509	2019-09-05 16:08:35	2019-09-05	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1021	pick-up	0	29
7510	2019-09-05 16:10:39	2019-09-05	12	[{"id_menu":1,"count":1}]	2360	pick-up	0	12
7511	2019-09-05 16:54:16	2019-09-05	12	[{"id_menu":1,"count":1}]	2748	delivery	5	17
7512	2019-09-05 17:07:58	2019-09-05	12	[{"id_menu":1,"count":1}]	1269	pick-up	0	12
7513	2019-09-05 17:10:22	2019-09-05	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	2672	delivery	5	29
7514	2019-09-05 17:26:56	2019-09-05	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	265	pick-up	0	21
7515	2019-09-05 17:42:34	2019-09-05	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2753	delivery	5	31
7516	2019-09-05 17:55:37	2019-09-05	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2749	delivery	5	56
7517	2019-09-05 18:08:05	2019-09-05	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1736	pick-up	0	21
7518	2019-09-05 18:08:48	2019-09-05	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2740	delivery	5	43
7519	2019-09-05 18:13:22	2019-09-05	14	[{"id_menu":2,"count":1}]	2742	delivery	5	19
7520	2019-09-05 18:13:37	2019-09-05	12	[{"id_menu":3,"count":1}]	1723	pick-up	0	12
7521	2019-09-05 18:19:20	2019-09-05	8	[{"id_menu":5,"count":1}]	2746	delivery	5	13
7522	2019-09-05 18:35:49	2019-09-05	9	[{"id_menu":6,"count":1}]	1956	pick-up	0	9
7523	2019-09-05 18:49:01	2019-09-05	17	[{"id_menu":4,"count":1}]	2134	pick-up	0	17
7524	2019-09-05 19:16:20	2019-09-05	9	[{"id_menu":6,"count":1}]	1933	pick-up	0	9
7525	2019-09-05 19:18:25	2019-09-05	8	[{"id_menu":5,"count":1}]	379	delivery	5	13
7526	2019-09-05 19:41:30	2019-09-05	12	[{"id_menu":3,"count":1}]	1079	delivery	5	17
7527	2019-09-05 19:55:12	2019-09-05	9	[{"id_menu":6,"count":1}]	1126	delivery	5	14
7528	2019-09-05 20:00:51	2019-09-05	9	[{"id_menu":6,"count":1}]	2526	pick-up	0	9
7529	2019-09-05 20:26:26	2019-09-05	14	[{"id_menu":2,"count":1}]	203	pick-up	0	14
7530	2019-09-05 20:28:54	2019-09-05	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1651	delivery	5	39
7531	2019-09-05 21:09:33	2019-09-05	9	[{"id_menu":7,"count":1}]	2739	delivery	5	14
7532	2019-09-05 21:22:54	2019-09-05	12	[{"id_menu":1,"count":1}]	2140	pick-up	0	12
7533	2019-09-05 21:29:04	2019-09-05	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2021	delivery	5	45
7534	2019-09-05 21:34:04	2019-09-05	14	[{"id_menu":2,"count":1}]	2594	pick-up	0	14
7535	2019-09-05 21:47:16	2019-09-05	8	[{"id_menu":5,"count":1}]	1291	pick-up	0	8
7536	2019-09-05 22:24:18	2019-09-05	8	[{"id_menu":5,"count":1}]	625	delivery	5	13
7537	2019-09-05 22:28:31	2019-09-05	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	381	pick-up	0	29
7538	2019-09-05 22:57:16	2019-09-05	14	[{"id_menu":2,"count":1}]	2737	pick-up	0	14
7539	2019-09-05 23:23:38	2019-09-05	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1442	delivery	5	31
7540	2019-09-05 23:54:31	2019-09-05	12	[{"id_menu":3,"count":1}]	2083	pick-up	0	12
7541	2019-09-06 01:31:50	2019-09-06	12	[{"id_menu":1,"count":1}]	1093	delivery	5	17
7542	2019-09-06 01:48:16	2019-09-06	12	[{"id_menu":3,"count":1}]	2446	pick-up	0	12
7543	2019-09-06 01:49:54	2019-09-06	9	[{"id_menu":6,"count":1}]	29	delivery	5	14
7544	2019-09-06 02:40:42	2019-09-06	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2754	delivery	5	36
7545	2019-09-06 03:12:50	2019-09-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1080	pick-up	0	23
7546	2019-09-06 04:06:13	2019-09-06	12	[{"id_menu":3,"count":1}]	2572	delivery	5	17
7547	2019-09-06 04:24:16	2019-09-06	12	[{"id_menu":3,"count":1}]	2777	pick-up	0	12
7548	2019-09-06 04:43:23	2019-09-06	12	[{"id_menu":3,"count":1}]	1257	pick-up	0	12
7549	2019-09-06 05:02:12	2019-09-06	9	[{"id_menu":7,"count":1}]	807	pick-up	0	9
7550	2019-09-06 05:29:14	2019-09-06	12	[{"id_menu":1,"count":1}]	2197	pick-up	0	12
7551	2019-09-06 05:35:47	2019-09-06	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2781	pick-up	0	26
7552	2019-09-06 05:56:08	2019-09-06	12	[{"id_menu":1,"count":1}]	59	pick-up	0	12
7553	2019-09-06 05:58:47	2019-09-06	12	[{"id_menu":3,"count":1}]	269	delivery	5	17
7554	2019-09-06 05:58:50	2019-09-06	14	[{"id_menu":2,"count":1}]	2765	delivery	5	19
7555	2019-09-06 06:15:33	2019-09-06	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2053	pick-up	0	37
7556	2019-09-06 06:26:49	2019-09-06	9	[{"id_menu":7,"count":1}]	2769	delivery	5	14
7557	2019-09-06 06:27:48	2019-09-06	14	[{"id_menu":2,"count":1}]	1473	pick-up	0	14
7558	2019-09-06 06:37:05	2019-09-06	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	2763	delivery	5	31
7559	2019-09-06 07:32:42	2019-09-06	12	[{"id_menu":3,"count":1}]	2776	delivery	5	17
7560	2019-09-06 07:41:28	2019-09-06	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2775	delivery	5	30
7561	2019-09-06 07:52:21	2019-09-06	8	[{"id_menu":5,"count":2}]	598	delivery	5	13
7562	2019-09-06 07:58:42	2019-09-06	14	[{"id_menu":2,"count":1}]	2761	delivery	5	19
7563	2019-09-06 09:02:04	2019-09-06	12	[{"id_menu":3,"count":2}]	2779	delivery	5	17
7564	2019-09-06 09:05:42	2019-09-06	12	[{"id_menu":3,"count":1}]	1627	delivery	5	17
7565	2019-09-06 09:08:54	2019-09-06	12	[{"id_menu":1,"count":1}]	1188	pick-up	0	12
7566	2019-09-06 09:28:59	2019-09-06	9	[{"id_menu":6,"count":1}]	2124	delivery	5	14
7567	2019-09-06 10:45:59	2019-09-06	12	[{"id_menu":3,"count":1}]	2099	pick-up	0	12
7568	2019-09-06 10:53:42	2019-09-06	17	[{"id_menu":4,"count":1}]	314	pick-up	0	17
7569	2019-09-06 11:25:44	2019-09-06	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	2770	pick-up	0	31
7570	2019-09-06 11:40:45	2019-09-06	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2778	delivery	5	28
7571	2019-09-06 12:27:05	2019-09-06	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	96	delivery	5	31
7572	2019-09-06 13:08:40	2019-09-06	8	[{"id_menu":5,"count":1}]	1196	pick-up	0	8
7573	2019-09-06 13:09:28	2019-09-06	14	[{"id_menu":2,"count":1}]	1618	delivery	5	19
7574	2019-09-06 13:39:19	2019-09-06	17	[{"id_menu":4,"count":1}]	1390	delivery	5	22
7575	2019-09-06 13:56:54	2019-09-06	12	[{"id_menu":3,"count":1}]	2767	pick-up	0	12
7576	2019-09-06 14:13:39	2019-09-06	9	[{"id_menu":7,"count":1}]	1263	pick-up	0	9
7577	2019-09-06 14:16:39	2019-09-06	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2771	pick-up	0	21
7578	2019-09-06 14:21:11	2019-09-06	9	[{"id_menu":6,"count":1}]	87	delivery	5	14
7579	2019-09-06 14:34:57	2019-09-06	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2766	delivery	5	45
7580	2019-09-06 15:15:33	2019-09-06	8	[{"id_menu":5,"count":1}]	1462	delivery	5	13
7581	2019-09-06 15:32:54	2019-09-06	8	[{"id_menu":5,"count":1}]	2768	pick-up	0	8
7582	2019-09-06 16:03:58	2019-09-06	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	285	pick-up	0	29
7583	2019-09-06 16:04:43	2019-09-06	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1009	pick-up	0	24
7584	2019-09-06 16:34:44	2019-09-06	9	[{"id_menu":6,"count":1}]	639	pick-up	0	9
7585	2019-09-06 17:06:28	2019-09-06	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	2774	delivery	5	22
7586	2019-09-06 17:28:12	2019-09-06	12	[{"id_menu":3,"count":1}]	1747	delivery	5	17
7587	2019-09-06 18:15:12	2019-09-06	9	[{"id_menu":6,"count":1}]	778	pick-up	0	9
7588	2019-09-06 19:09:57	2019-09-06	14	[{"id_menu":2,"count":1}]	906	delivery	5	19
7589	2019-09-06 19:20:38	2019-09-06	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2772	delivery	5	30
7590	2019-09-06 20:08:18	2019-09-06	9	[{"id_menu":7,"count":1}]	2561	delivery	5	14
7591	2019-09-06 20:15:41	2019-09-06	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2780	delivery	5	31
7592	2019-09-06 20:41:25	2019-09-06	9	[{"id_menu":7,"count":1}]	2764	pick-up	0	9
7593	2019-09-06 21:18:40	2019-09-06	8	[{"id_menu":5,"count":1}]	2556	delivery	5	13
7594	2019-09-06 21:44:36	2019-09-06	9	[{"id_menu":7,"count":1}]	2762	delivery	5	14
7595	2019-09-06 21:52:50	2019-09-06	9	[{"id_menu":7,"count":1}]	440	delivery	5	14
7596	2019-09-06 22:59:32	2019-09-06	12	[{"id_menu":3,"count":1}]	2227	pick-up	0	12
7597	2019-09-06 23:29:28	2019-09-06	12	[{"id_menu":1,"count":1}]	2759	pick-up	0	12
7598	2019-09-07 00:05:11	2019-09-07	9	[{"id_menu":7,"count":1}]	2799	pick-up	0	9
7599	2019-09-07 00:18:05	2019-09-07	12	[{"id_menu":1,"count":1}]	906	pick-up	0	12
7600	2019-09-07 01:12:09	2019-09-07	14	[{"id_menu":2,"count":1}]	707	pick-up	0	14
7601	2019-09-07 01:21:54	2019-09-07	8	[{"id_menu":5,"count":1}]	444	pick-up	0	8
7602	2019-09-07 01:31:46	2019-09-07	9	[{"id_menu":6,"count":1}]	1303	pick-up	0	9
7603	2019-09-07 01:47:29	2019-09-07	12	[{"id_menu":1,"count":1}]	2784	delivery	5	17
7604	2019-09-07 02:14:42	2019-09-07	9	[{"id_menu":7,"count":1}]	1677	pick-up	0	9
7605	2019-09-07 02:20:42	2019-09-07	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2795	pick-up	0	29
7606	2019-09-07 02:27:48	2019-09-07	17	[{"id_menu":4,"count":1}]	2801	pick-up	0	17
7607	2019-09-07 02:33:12	2019-09-07	12	[{"id_menu":1,"count":1}]	2785	delivery	5	17
7608	2019-09-07 02:51:36	2019-09-07	9	[{"id_menu":7,"count":1}]	2333	delivery	5	14
7609	2019-09-07 02:53:30	2019-09-07	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2657	delivery	5	26
7610	2019-09-07 03:22:30	2019-09-07	8	[{"id_menu":5,"count":1}]	2789	delivery	5	13
7611	2019-09-07 03:22:47	2019-09-07	12	[{"id_menu":1,"count":1}]	2787	delivery	5	17
7612	2019-09-07 03:25:39	2019-09-07	8	[{"id_menu":5,"count":1}]	2225	pick-up	0	8
7613	2019-09-07 03:30:14	2019-09-07	12	[{"id_menu":3,"count":1}]	2806	delivery	5	17
7614	2019-09-07 03:58:13	2019-09-07	17	[{"id_menu":4,"count":1}]	2796	delivery	5	22
7615	2019-09-07 04:26:46	2019-09-07	9	[{"id_menu":6,"count":1}]	1789	pick-up	0	9
7616	2019-09-07 04:33:27	2019-09-07	8	[{"id_menu":5,"count":1}]	597	delivery	5	13
7617	2019-09-07 04:35:59	2019-09-07	8	[{"id_menu":5,"count":2}]	2797	pick-up	0	8
7618	2019-09-07 04:40:34	2019-09-07	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2691	pick-up	0	25
7619	2019-09-07 06:10:34	2019-09-07	9	[{"id_menu":7,"count":1}]	1438	pick-up	0	9
7620	2019-09-07 06:23:01	2019-09-07	12	[{"id_menu":1,"count":1}]	126	delivery	5	17
7621	2019-09-07 06:29:30	2019-09-07	12	[{"id_menu":1,"count":1}]	2078	delivery	5	17
7622	2019-09-07 06:52:30	2019-09-07	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":3}]	2673	delivery	5	25
7623	2019-09-07 07:43:39	2019-09-07	12	[{"id_menu":3,"count":1}]	177	pick-up	0	12
7624	2019-09-07 07:59:58	2019-09-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2793	delivery	5	22
7625	2019-09-07 08:07:07	2019-09-07	14	[{"id_menu":2,"count":1}]	447	pick-up	0	14
7626	2019-09-07 08:21:05	2019-09-07	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1118	delivery	5	27
7627	2019-09-07 08:27:28	2019-09-07	8	[{"id_menu":5,"count":1}]	2056	pick-up	0	8
7628	2019-09-07 08:59:49	2019-09-07	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	2474	pick-up	0	21
7629	2019-09-07 09:12:15	2019-09-07	9	[{"id_menu":7,"count":1}]	215	delivery	5	14
7630	2019-09-07 09:15:05	2019-09-07	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	928	pick-up	0	39
7631	2019-09-07 09:55:47	2019-09-07	55	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2272	delivery	5	60
7632	2019-09-07 09:57:07	2019-09-07	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	206	delivery	5	40
7633	2019-09-07 10:09:23	2019-09-07	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2803	delivery	5	22
7634	2019-09-07 10:22:13	2019-09-07	8	[{"id_menu":5,"count":1}]	2788	pick-up	0	8
7635	2019-09-07 10:34:50	2019-09-07	14	[{"id_menu":2,"count":1}]	1168	pick-up	0	14
7636	2019-09-07 10:41:06	2019-09-07	8	[{"id_menu":5,"count":1}]	2804	pick-up	0	8
7637	2019-09-07 11:22:54	2019-09-07	14	[{"id_menu":2,"count":1}]	111	delivery	5	19
7638	2019-09-07 12:19:16	2019-09-07	12	[{"id_menu":3,"count":1}]	2792	pick-up	0	12
7639	2019-09-07 12:19:19	2019-09-07	9	[{"id_menu":6,"count":2}]	948	pick-up	0	9
7640	2019-09-07 12:31:23	2019-09-07	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	634	pick-up	0	26
7641	2019-09-07 12:31:51	2019-09-07	9	[{"id_menu":7,"count":1}]	740	pick-up	0	9
7642	2019-09-07 13:31:07	2019-09-07	17	[{"id_menu":4,"count":1}]	2783	pick-up	0	17
7643	2019-09-07 16:08:37	2019-09-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1306	delivery	5	28
7644	2019-09-07 16:40:23	2019-09-07	9	[{"id_menu":6,"count":1}]	29	delivery	5	14
7645	2019-09-07 17:02:44	2019-09-07	14	[{"id_menu":2,"count":1}]	2130	delivery	5	19
7646	2019-09-07 17:27:20	2019-09-07	14	[{"id_menu":2,"count":1}]	2697	delivery	5	19
7647	2019-09-07 17:39:46	2019-09-07	12	[{"id_menu":3,"count":1}]	2782	pick-up	0	12
7648	2019-09-07 18:05:24	2019-09-07	9	[{"id_menu":7,"count":1}]	2800	delivery	5	14
7649	2019-09-07 18:23:12	2019-09-07	17	[{"id_menu":4,"count":1}]	2798	pick-up	0	17
7650	2019-09-07 18:51:08	2019-09-07	12	[{"id_menu":3,"count":1}]	2807	pick-up	0	12
7651	2019-09-07 19:17:12	2019-09-07	14	[{"id_menu":2,"count":1}]	2808	pick-up	0	14
7652	2019-09-07 19:26:45	2019-09-07	14	[{"id_menu":2,"count":1}]	536	pick-up	0	14
7653	2019-09-07 19:31:40	2019-09-07	14	[{"id_menu":2,"count":3}]	638	pick-up	0	14
7654	2019-09-07 19:44:53	2019-09-07	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2794	pick-up	0	29
7655	2019-09-07 20:10:49	2019-09-07	14	[{"id_menu":2,"count":1}]	1406	pick-up	0	14
7656	2019-09-07 20:11:01	2019-09-07	14	[{"id_menu":2,"count":1}]	2108	pick-up	0	14
7657	2019-09-07 20:32:18	2019-09-07	12	[{"id_menu":3,"count":1}]	2802	pick-up	0	12
7658	2019-09-07 20:32:20	2019-09-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	2791	delivery	5	23
7659	2019-09-07 20:38:40	2019-09-07	14	[{"id_menu":2,"count":1}]	359	delivery	5	19
7660	2019-09-07 21:07:19	2019-09-07	14	[{"id_menu":2,"count":1}]	271	pick-up	0	14
7661	2019-09-07 21:08:05	2019-09-07	14	[{"id_menu":2,"count":1}]	269	delivery	5	19
7662	2019-09-07 21:39:22	2019-09-07	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	932	delivery	5	25
7663	2019-09-07 22:04:34	2019-09-07	9	[{"id_menu":7,"count":1}]	2805	delivery	5	14
7664	2019-09-07 22:37:29	2019-09-07	12	[{"id_menu":3,"count":1}]	2170	delivery	5	17
7665	2019-09-07 22:43:19	2019-09-07	17	[{"id_menu":4,"count":1}]	2809	delivery	5	22
7666	2019-09-07 22:49:19	2019-09-07	9	[{"id_menu":6,"count":1}]	1618	pick-up	0	9
7667	2019-09-07 23:14:15	2019-09-07	12	[{"id_menu":3,"count":1}]	2415	pick-up	0	12
7668	2019-09-07 23:26:19	2019-09-07	17	[{"id_menu":4,"count":1}]	1536	pick-up	0	17
7669	2019-09-07 23:33:55	2019-09-07	14	[{"id_menu":2,"count":1}]	2786	delivery	5	19
7670	2019-09-07 23:35:55	2019-09-07	8	[{"id_menu":5,"count":1}]	2790	delivery	5	13
7671	2019-09-07 23:50:50	2019-09-07	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2140	pick-up	0	20
7672	2019-09-08 00:12:35	2019-09-08	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1582	pick-up	0	17
7673	2019-09-08 00:29:45	2019-09-08	9	[{"id_menu":7,"count":1}]	1897	delivery	5	14
7674	2019-09-08 00:40:33	2019-09-08	12	[{"id_menu":3,"count":1}]	1356	pick-up	0	12
7675	2019-09-08 00:58:18	2019-09-08	14	[{"id_menu":2,"count":1}]	2214	pick-up	0	14
7676	2019-09-08 01:07:16	2019-09-08	12	[{"id_menu":3,"count":1}]	660	pick-up	0	12
7677	2019-09-08 01:08:12	2019-09-08	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	2837	delivery	5	37
7678	2019-09-08 01:27:50	2019-09-08	9	[{"id_menu":7,"count":1}]	1486	pick-up	0	9
7679	2019-09-08 01:32:35	2019-09-08	9	[{"id_menu":6,"count":1}]	2810	pick-up	0	9
7680	2019-09-08 01:57:29	2019-09-08	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2821	pick-up	0	21
7681	2019-09-08 02:13:56	2019-09-08	12	[{"id_menu":3,"count":1}]	1549	pick-up	0	12
7682	2019-09-08 02:16:12	2019-09-08	9	[{"id_menu":6,"count":1}]	919	pick-up	0	9
7683	2019-09-08 02:53:57	2019-09-08	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1569	pick-up	0	26
7684	2019-09-08 03:24:28	2019-09-08	14	[{"id_menu":2,"count":1}]	1720	pick-up	0	14
7685	2019-09-08 03:33:05	2019-09-08	9	[{"id_menu":6,"count":1}]	678	pick-up	0	9
7686	2019-09-08 04:46:49	2019-09-08	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	2579	pick-up	0	23
7687	2019-09-08 04:54:50	2019-09-08	14	[{"id_menu":2,"count":2}]	2824	delivery	5	19
7688	2019-09-08 04:58:40	2019-09-08	12	[{"id_menu":1,"count":1}]	2389	delivery	5	17
7689	2019-09-08 05:05:44	2019-09-08	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1212	pick-up	0	22
7690	2019-09-08 05:08:23	2019-09-08	12	[{"id_menu":3,"count":1}]	2169	pick-up	0	12
7691	2019-09-08 05:30:04	2019-09-08	17	[{"id_menu":4,"count":1}]	2699	pick-up	0	17
7692	2019-09-08 05:32:18	2019-09-08	9	[{"id_menu":6,"count":1}]	2076	pick-up	0	9
7693	2019-09-08 05:33:59	2019-09-08	9	[{"id_menu":7,"count":1}]	1220	delivery	5	14
7694	2019-09-08 06:28:18	2019-09-08	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	2317	pick-up	0	20
7695	2019-09-08 06:28:27	2019-09-08	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	2320	pick-up	0	40
7696	2019-09-08 06:29:32	2019-09-08	8	[{"id_menu":5,"count":1}]	2835	pick-up	0	8
7697	2019-09-08 06:29:43	2019-09-08	14	[{"id_menu":2,"count":1}]	146	pick-up	0	14
7698	2019-09-08 06:31:48	2019-09-08	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1888	delivery	5	43
7699	2019-09-08 06:50:31	2019-09-08	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2078	pick-up	0	48
7700	2019-09-08 06:56:40	2019-09-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1601	delivery	5	22
7701	2019-09-08 07:08:46	2019-09-08	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2401	delivery	5	43
7702	2019-09-08 07:12:19	2019-09-08	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	684	pick-up	0	26
7703	2019-09-08 07:18:58	2019-09-08	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2237	pick-up	0	31
7704	2019-09-08 07:26:02	2019-09-08	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1134	pick-up	0	21
7705	2019-09-08 07:52:28	2019-09-08	12	[{"id_menu":1,"count":1}]	1322	delivery	5	17
7706	2019-09-08 07:57:19	2019-09-08	12	[{"id_menu":3,"count":1}]	950	pick-up	0	12
7707	2019-09-08 08:03:54	2019-09-08	9	[{"id_menu":6,"count":2}]	1885	pick-up	0	9
7708	2019-09-08 08:15:00	2019-09-08	9	[{"id_menu":6,"count":1}]	1041	delivery	5	14
7709	2019-09-08 08:24:59	2019-09-08	17	[{"id_menu":4,"count":1}]	1113	pick-up	0	17
7710	2019-09-08 08:27:47	2019-09-08	9	[{"id_menu":7,"count":1}]	233	pick-up	0	9
7711	2019-09-08 09:07:06	2019-09-08	9	[{"id_menu":6,"count":1}]	2555	delivery	5	14
7712	2019-09-08 09:22:43	2019-09-08	14	[{"id_menu":2,"count":1}]	1566	pick-up	0	14
7713	2019-09-08 09:28:08	2019-09-08	8	[{"id_menu":5,"count":1}]	2604	pick-up	0	8
7714	2019-09-08 09:59:37	2019-09-08	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1929	delivery	5	27
7715	2019-09-08 10:10:52	2019-09-08	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2819	delivery	5	36
7716	2019-09-08 10:12:15	2019-09-08	9	[{"id_menu":6,"count":1}]	2814	delivery	5	14
7717	2019-09-08 10:48:17	2019-09-08	9	[{"id_menu":6,"count":1}]	2816	pick-up	0	9
7718	2019-09-08 10:53:09	2019-09-08	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2827	pick-up	0	26
7719	2019-09-08 10:59:32	2019-09-08	9	[{"id_menu":7,"count":1}]	2828	pick-up	0	9
7720	2019-09-08 11:39:30	2019-09-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2293	pick-up	0	17
7721	2019-09-08 11:58:57	2019-09-08	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2833	delivery	5	56
7722	2019-09-08 12:06:31	2019-09-08	12	[{"id_menu":1,"count":1}]	533	delivery	5	17
7723	2019-09-08 12:36:08	2019-09-08	17	[{"id_menu":4,"count":1}]	378	delivery	5	22
7724	2019-09-08 12:50:37	2019-09-08	12	[{"id_menu":1,"count":1}]	2822	delivery	5	17
7725	2019-09-08 13:02:12	2019-09-08	12	[{"id_menu":1,"count":1}]	655	pick-up	0	12
7726	2019-09-08 13:14:31	2019-09-08	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	2829	pick-up	0	23
7727	2019-09-08 13:23:47	2019-09-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	974	delivery	5	22
7728	2019-09-08 13:27:29	2019-09-08	9	[{"id_menu":7,"count":1}]	2475	delivery	5	14
7729	2019-09-08 13:38:52	2019-09-08	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1099	pick-up	0	26
7730	2019-09-08 13:57:33	2019-09-08	12	[{"id_menu":3,"count":1}]	2693	pick-up	0	12
7731	2019-09-08 14:37:11	2019-09-08	17	[{"id_menu":4,"count":1}]	1375	pick-up	0	17
7732	2019-09-08 15:24:57	2019-09-08	14	[{"id_menu":2,"count":1}]	2575	pick-up	0	14
7733	2019-09-08 16:09:17	2019-09-08	8	[{"id_menu":5,"count":1}]	799	delivery	5	13
7734	2019-09-08 16:21:49	2019-09-08	9	[{"id_menu":7,"count":1}]	1774	pick-up	0	9
7735	2019-09-08 17:19:34	2019-09-08	14	[{"id_menu":2,"count":1}]	575	pick-up	0	14
7736	2019-09-08 17:24:34	2019-09-08	14	[{"id_menu":2,"count":1}]	925	pick-up	0	14
7737	2019-09-08 17:36:49	2019-09-08	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2812	delivery	5	34
7738	2019-09-08 17:48:24	2019-09-08	8	[{"id_menu":5,"count":2}]	2830	pick-up	0	8
7739	2019-09-08 18:21:54	2019-09-08	17	[{"id_menu":4,"count":1}]	2834	delivery	5	22
7740	2019-09-08 18:24:31	2019-09-08	14	[{"id_menu":2,"count":1}]	2176	delivery	5	19
7741	2019-09-08 18:41:48	2019-09-08	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	2811	delivery	5	22
7742	2019-09-08 18:50:56	2019-09-08	9	[{"id_menu":7,"count":1}]	356	pick-up	0	9
7743	2019-09-08 19:15:58	2019-09-08	12	[{"id_menu":1,"count":1}]	2741	delivery	5	17
7744	2019-09-08 19:25:06	2019-09-08	8	[{"id_menu":5,"count":1}]	1681	pick-up	0	8
7745	2019-09-08 19:56:14	2019-09-08	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1208	pick-up	0	26
7746	2019-09-08 20:06:45	2019-09-08	14	[{"id_menu":2,"count":1}]	999	delivery	5	19
7747	2019-09-08 20:15:52	2019-09-08	14	[{"id_menu":2,"count":1}]	996	pick-up	0	14
7748	2019-09-08 20:25:09	2019-09-08	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2813	pick-up	0	26
7749	2019-09-08 20:52:05	2019-09-08	8	[{"id_menu":5,"count":1}]	2818	delivery	5	13
7750	2019-09-08 21:16:34	2019-09-08	14	[{"id_menu":2,"count":1}]	2826	pick-up	0	14
7751	2019-09-08 21:47:23	2019-09-08	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2820	pick-up	0	25
7752	2019-09-08 22:14:17	2019-09-08	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2836	delivery	5	25
7753	2019-09-08 22:23:30	2019-09-08	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2817	delivery	5	31
7754	2019-09-08 22:25:53	2019-09-08	9	[{"id_menu":6,"count":1}]	1070	pick-up	0	9
7755	2019-09-08 22:51:15	2019-09-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	2831	delivery	5	28
7756	2019-09-08 22:54:57	2019-09-08	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2825	delivery	5	31
7757	2019-09-08 23:10:15	2019-09-08	8	[{"id_menu":5,"count":1}]	2055	pick-up	0	8
7758	2019-09-08 23:19:17	2019-09-08	14	[{"id_menu":2,"count":1}]	2823	delivery	5	19
7759	2019-09-08 23:21:21	2019-09-08	17	[{"id_menu":4,"count":1}]	2832	delivery	5	22
7760	2019-09-08 23:27:51	2019-09-08	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2815	pick-up	0	51
7761	2019-09-08 23:56:01	2019-09-08	12	[{"id_menu":3,"count":1}]	707	pick-up	0	12
7762	2019-09-09 00:25:42	2019-09-09	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1282	pick-up	0	29
7763	2019-09-09 00:50:12	2019-09-09	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	764	delivery	5	42
7764	2019-09-09 02:01:10	2019-09-09	12	[{"id_menu":3,"count":1}]	939	delivery	5	17
7765	2019-09-09 02:15:44	2019-09-09	8	[{"id_menu":5,"count":1}]	53	pick-up	0	8
7766	2019-09-09 02:57:57	2019-09-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	2845	delivery	5	23
7767	2019-09-09 03:11:08	2019-09-09	17	[{"id_menu":4,"count":1}]	2523	pick-up	0	17
7768	2019-09-09 03:12:57	2019-09-09	9	[{"id_menu":6,"count":1}]	1795	pick-up	0	9
7769	2019-09-09 03:30:22	2019-09-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2854	delivery	5	28
7770	2019-09-09 03:46:53	2019-09-09	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	2848	delivery	5	23
7771	2019-09-09 04:20:15	2019-09-09	9	[{"id_menu":7,"count":1}]	1444	delivery	5	14
7772	2019-09-09 05:55:44	2019-09-09	12	[{"id_menu":3,"count":1}]	2397	pick-up	0	12
7773	2019-09-09 06:21:37	2019-09-09	12	[{"id_menu":1,"count":1}]	2855	pick-up	0	12
7774	2019-09-09 06:29:01	2019-09-09	12	[{"id_menu":1,"count":1}]	2230	delivery	5	17
7775	2019-09-09 07:05:16	2019-09-09	14	[{"id_menu":2,"count":1}]	1306	pick-up	0	14
7776	2019-09-09 08:37:04	2019-09-09	17	[{"id_menu":4,"count":1}]	1317	pick-up	0	17
7777	2019-09-09 09:26:04	2019-09-09	14	[{"id_menu":2,"count":1}]	2857	pick-up	0	14
7778	2019-09-09 09:38:57	2019-09-09	17	[{"id_menu":4,"count":1}]	2840	pick-up	0	17
7779	2019-09-09 09:49:33	2019-09-09	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2846	delivery	5	35
7780	2019-09-09 10:38:57	2019-09-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1373	pick-up	0	23
7781	2019-09-09 10:55:12	2019-09-09	17	[{"id_menu":4,"count":1}]	1567	delivery	5	22
7782	2019-09-09 12:17:12	2019-09-09	8	[{"id_menu":5,"count":1}]	2859	pick-up	0	8
7783	2019-09-09 12:39:16	2019-09-09	12	[{"id_menu":1,"count":1}]	2089	delivery	5	17
7784	2019-09-09 13:11:47	2019-09-09	17	[{"id_menu":4,"count":1}]	2856	pick-up	0	17
7785	2019-09-09 13:33:37	2019-09-09	12	[{"id_menu":3,"count":1}]	1445	pick-up	0	12
7786	2019-09-09 13:37:52	2019-09-09	12	[{"id_menu":3,"count":1}]	1620	delivery	5	17
7787	2019-09-09 13:57:28	2019-09-09	9	[{"id_menu":7,"count":1}]	2847	delivery	5	14
7788	2019-09-09 13:58:03	2019-09-09	12	[{"id_menu":3,"count":1}]	527	pick-up	0	12
7789	2019-09-09 15:06:43	2019-09-09	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2849	delivery	5	31
7790	2019-09-09 15:18:06	2019-09-09	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2774	delivery	5	27
7791	2019-09-09 16:36:58	2019-09-09	14	[{"id_menu":2,"count":1}]	2851	pick-up	0	14
7792	2019-09-09 18:26:38	2019-09-09	12	[{"id_menu":1,"count":1}]	2843	delivery	5	17
7793	2019-09-09 19:56:30	2019-09-09	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	136	delivery	5	37
7794	2019-09-09 20:42:18	2019-09-09	12	[{"id_menu":3,"count":1}]	1237	delivery	5	17
7795	2019-09-09 20:50:21	2019-09-09	14	[{"id_menu":2,"count":1}]	628	delivery	5	19
7796	2019-09-09 21:42:11	2019-09-09	9	[{"id_menu":6,"count":1}]	2244	pick-up	0	9
7797	2019-09-09 21:52:36	2019-09-09	9	[{"id_menu":6,"count":1}]	2842	delivery	5	14
7798	2019-09-09 22:21:06	2019-09-09	14	[{"id_menu":2,"count":1}]	408	delivery	5	19
7799	2019-09-09 23:26:17	2019-09-09	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	529	pick-up	0	26
7800	2019-09-09 23:42:17	2019-09-09	12	[{"id_menu":1,"count":2}]	2806	delivery	5	17
7801	2019-09-10 01:14:44	2019-09-10	12	[{"id_menu":1,"count":1}]	2878	delivery	5	17
7802	2019-09-10 02:00:05	2019-09-10	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2770	delivery	5	37
7803	2019-09-10 02:20:52	2019-09-10	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2864	delivery	5	26
7804	2019-09-10 02:30:24	2019-09-10	12	[{"id_menu":1,"count":1}]	1025	pick-up	0	12
7805	2019-09-10 02:57:42	2019-09-10	12	[{"id_menu":1,"count":1}]	777	pick-up	0	12
7806	2019-09-10 03:00:17	2019-09-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2417	delivery	5	23
7807	2019-09-10 03:08:10	2019-09-10	9	[{"id_menu":6,"count":1}]	997	delivery	5	14
7808	2019-09-10 03:08:58	2019-09-10	17	[{"id_menu":4,"count":1}]	1462	delivery	5	22
7809	2019-09-10 03:48:32	2019-09-10	12	[{"id_menu":3,"count":1}]	2546	delivery	5	17
7810	2019-09-10 03:51:15	2019-09-10	17	[{"id_menu":4,"count":1}]	1490	pick-up	0	17
7811	2019-09-10 03:56:52	2019-09-10	12	[{"id_menu":1,"count":2}]	1581	pick-up	0	12
7812	2019-09-10 04:08:57	2019-09-10	9	[{"id_menu":7,"count":1}]	2662	pick-up	0	9
7813	2019-09-10 04:50:46	2019-09-10	12	[{"id_menu":1,"count":1}]	138	pick-up	0	12
7814	2019-09-10 04:53:17	2019-09-10	17	[{"id_menu":4,"count":1}]	2863	delivery	5	22
7815	2019-09-10 05:34:01	2019-09-10	9	[{"id_menu":7,"count":1}]	2855	pick-up	0	9
7816	2019-09-10 05:38:31	2019-09-10	14	[{"id_menu":2,"count":1}]	2884	delivery	5	19
7817	2019-09-10 06:02:54	2019-09-10	9	[{"id_menu":6,"count":1}]	2871	delivery	5	14
7818	2019-09-10 06:13:04	2019-09-10	12	[{"id_menu":1,"count":1}]	1364	pick-up	0	12
7819	2019-09-10 06:15:17	2019-09-10	12	[{"id_menu":3,"count":1}]	2667	pick-up	0	12
7820	2019-09-10 06:48:37	2019-09-10	9	[{"id_menu":7,"count":1}]	1727	pick-up	0	9
7821	2019-09-10 07:27:31	2019-09-10	12	[{"id_menu":1,"count":1}]	2868	delivery	5	17
7822	2019-09-10 07:34:34	2019-09-10	14	[{"id_menu":2,"count":1}]	2877	delivery	5	19
7823	2019-09-10 07:57:31	2019-09-10	12	[{"id_menu":3,"count":1}]	1468	pick-up	0	12
7824	2019-09-10 08:24:39	2019-09-10	14	[{"id_menu":2,"count":1}]	925	pick-up	0	14
7825	2019-09-10 09:16:50	2019-09-10	9	[{"id_menu":6,"count":1}]	992	delivery	5	14
7826	2019-09-10 10:50:55	2019-09-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	2391	delivery	5	22
7827	2019-09-10 10:58:46	2019-09-10	9	[{"id_menu":6,"count":1}]	1068	pick-up	0	9
7828	2019-09-10 11:15:51	2019-09-10	9	[{"id_menu":7,"count":1}]	1980	delivery	5	14
7829	2019-09-10 13:12:57	2019-09-10	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2882	delivery	5	37
7830	2019-09-10 14:39:29	2019-09-10	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	2551	pick-up	0	20
7831	2019-09-10 14:54:01	2019-09-10	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2869	pick-up	0	21
7832	2019-09-10 14:58:32	2019-09-10	12	[{"id_menu":3,"count":1}]	1085	pick-up	0	12
7833	2019-09-10 16:10:19	2019-09-10	9	[{"id_menu":6,"count":1}]	299	pick-up	0	9
7834	2019-09-10 17:32:18	2019-09-10	8	[{"id_menu":5,"count":1}]	2874	pick-up	0	8
7835	2019-09-10 18:04:35	2019-09-10	17	[{"id_menu":4,"count":1}]	2881	pick-up	0	17
7836	2019-09-10 18:13:26	2019-09-10	14	[{"id_menu":2,"count":1}]	1557	pick-up	0	14
7837	2019-09-10 19:14:14	2019-09-10	12	[{"id_menu":3,"count":1}]	2873	pick-up	0	12
7838	2019-09-10 19:24:16	2019-09-10	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2885	delivery	5	27
7839	2019-09-10 19:28:29	2019-09-10	14	[{"id_menu":2,"count":1}]	2880	pick-up	0	14
7840	2019-09-10 19:47:55	2019-09-10	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	2872	pick-up	0	29
7841	2019-09-10 20:12:15	2019-09-10	14	[{"id_menu":2,"count":1}]	128	pick-up	0	14
7842	2019-09-10 20:37:43	2019-09-10	8	[{"id_menu":5,"count":2}]	2862	pick-up	0	8
7843	2019-09-10 20:44:38	2019-09-10	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2875	delivery	5	46
7844	2019-09-10 21:02:08	2019-09-10	17	[{"id_menu":4,"count":1}]	265	delivery	5	22
7845	2019-09-10 21:23:22	2019-09-10	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2870	pick-up	0	26
7846	2019-09-10 23:08:04	2019-09-10	12	[{"id_menu":3,"count":1}]	2333	pick-up	0	12
7847	2019-09-10 23:32:18	2019-09-10	9	[{"id_menu":6,"count":1}]	304	pick-up	0	9
7848	2019-09-10 23:56:50	2019-09-10	17	[{"id_menu":4,"count":1}]	468	delivery	5	22
7849	2019-09-11 00:09:07	2019-09-11	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2181	pick-up	0	26
7850	2019-09-11 00:37:16	2019-09-11	17	[{"id_menu":4,"count":1}]	122	pick-up	0	17
7851	2019-09-11 00:48:49	2019-09-11	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	382	pick-up	0	21
7852	2019-09-11 01:08:51	2019-09-11	37	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2895	delivery	5	42
7853	2019-09-11 01:13:52	2019-09-11	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	356	delivery	5	29
7854	2019-09-11 02:39:15	2019-09-11	17	[{"id_menu":4,"count":1}]	2901	pick-up	0	17
7855	2019-09-11 03:16:55	2019-09-11	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	41	pick-up	0	52
7856	2019-09-11 03:52:51	2019-09-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2887	delivery	5	22
7857	2019-09-11 03:55:32	2019-09-11	8	[{"id_menu":5,"count":1}]	2910	delivery	5	13
7858	2019-09-11 04:58:36	2019-09-11	14	[{"id_menu":2,"count":1}]	1101	pick-up	0	14
7859	2019-09-11 05:18:29	2019-09-11	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	886	pick-up	0	26
7860	2019-09-11 05:23:17	2019-09-11	12	[{"id_menu":3,"count":1}]	2891	pick-up	0	12
7861	2019-09-11 05:48:07	2019-09-11	17	[{"id_menu":4,"count":1}]	2892	pick-up	0	17
7862	2019-09-11 06:01:37	2019-09-11	14	[{"id_menu":2,"count":1}]	1250	delivery	5	19
7863	2019-09-11 06:51:38	2019-09-11	14	[{"id_menu":2,"count":1}]	1266	delivery	5	19
7864	2019-09-11 06:59:09	2019-09-11	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2897	delivery	5	40
7865	2019-09-11 07:01:24	2019-09-11	14	[{"id_menu":2,"count":1}]	287	pick-up	0	14
7866	2019-09-11 07:23:38	2019-09-11	14	[{"id_menu":2,"count":1}]	2282	pick-up	0	14
7867	2019-09-11 07:23:52	2019-09-11	9	[{"id_menu":6,"count":1}]	2207	pick-up	0	9
7868	2019-09-11 07:56:49	2019-09-11	12	[{"id_menu":3,"count":1}]	2904	delivery	5	17
7869	2019-09-11 08:02:22	2019-09-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2907	pick-up	0	23
7870	2019-09-11 08:05:15	2019-09-11	12	[{"id_menu":1,"count":1}]	123	pick-up	0	12
7871	2019-09-11 08:12:22	2019-09-11	9	[{"id_menu":7,"count":1}]	2888	delivery	5	14
7872	2019-09-11 08:12:38	2019-09-11	9	[{"id_menu":6,"count":1}]	2909	delivery	5	14
7873	2019-09-11 08:13:02	2019-09-11	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	1535	delivery	5	26
7874	2019-09-11 08:24:13	2019-09-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1212	delivery	5	28
7875	2019-09-11 09:10:03	2019-09-11	14	[{"id_menu":2,"count":1}]	551	pick-up	0	14
7876	2019-09-11 09:48:34	2019-09-11	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2886	delivery	5	27
7877	2019-09-11 10:34:15	2019-09-11	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	2077	pick-up	0	23
7878	2019-09-11 10:50:45	2019-09-11	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	348	pick-up	0	31
7879	2019-09-11 12:59:11	2019-09-11	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	950	pick-up	0	26
7880	2019-09-11 13:09:16	2019-09-11	9	[{"id_menu":6,"count":1}]	2083	pick-up	0	9
7881	2019-09-11 13:45:06	2019-09-11	12	[{"id_menu":1,"count":1}]	2061	delivery	5	17
7882	2019-09-11 15:04:27	2019-09-11	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2899	delivery	5	48
7883	2019-09-11 15:09:14	2019-09-11	9	[{"id_menu":7,"count":1}]	1001	pick-up	0	9
7884	2019-09-11 15:45:56	2019-09-11	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2582	delivery	5	31
7885	2019-09-11 15:58:00	2019-09-11	17	[{"id_menu":4,"count":1}]	2398	delivery	5	22
7886	2019-09-11 15:58:41	2019-09-11	14	[{"id_menu":2,"count":1}]	2890	pick-up	0	14
7887	2019-09-11 16:04:12	2019-09-11	8	[{"id_menu":5,"count":1}]	135	pick-up	0	8
7888	2019-09-11 16:42:23	2019-09-11	8	[{"id_menu":5,"count":1}]	1657	pick-up	0	8
7889	2019-09-11 17:07:34	2019-09-11	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2905	delivery	5	36
7890	2019-09-11 17:53:11	2019-09-11	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	236	pick-up	0	21
7891	2019-09-11 17:53:40	2019-09-11	12	[{"id_menu":1,"count":1}]	2889	pick-up	0	12
7892	2019-09-11 18:11:03	2019-09-11	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	2906	delivery	5	22
7893	2019-09-11 18:13:49	2019-09-11	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1432	delivery	5	44
7894	2019-09-11 18:24:29	2019-09-11	12	[{"id_menu":1,"count":1}]	376	pick-up	0	12
7895	2019-09-11 18:29:57	2019-09-11	9	[{"id_menu":7,"count":1}]	2894	delivery	5	14
7896	2019-09-11 18:44:55	2019-09-11	12	[{"id_menu":3,"count":1}]	154	delivery	5	17
7897	2019-09-11 18:47:30	2019-09-11	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	658	delivery	5	36
7898	2019-09-11 19:11:09	2019-09-11	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	29	delivery	5	45
7899	2019-09-11 19:26:53	2019-09-11	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	1900	pick-up	0	26
7900	2019-09-11 19:45:08	2019-09-11	17	[{"id_menu":4,"count":1}]	2893	delivery	5	22
7901	2019-09-11 20:29:46	2019-09-11	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1263	delivery	5	31
7902	2019-09-11 20:43:49	2019-09-11	8	[{"id_menu":5,"count":1}]	2898	pick-up	0	8
7903	2019-09-11 21:06:00	2019-09-11	17	[{"id_menu":4,"count":1}]	1485	delivery	5	22
7904	2019-09-11 21:09:25	2019-09-11	9	[{"id_menu":6,"count":1}]	2868	delivery	5	14
7905	2019-09-11 21:26:09	2019-09-11	12	[{"id_menu":3,"count":1}]	1944	delivery	5	17
7906	2019-09-11 21:54:33	2019-09-11	14	[{"id_menu":2,"count":1}]	2902	pick-up	0	14
7907	2019-09-11 22:25:17	2019-09-11	8	[{"id_menu":5,"count":1}]	2908	delivery	5	13
7908	2019-09-11 22:39:55	2019-09-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1369	pick-up	0	23
7909	2019-09-11 23:16:35	2019-09-11	8	[{"id_menu":5,"count":1}]	2774	delivery	5	13
7910	2019-09-11 23:27:55	2019-09-11	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	2562	delivery	5	39
7911	2019-09-11 23:46:30	2019-09-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2434	delivery	5	23
7912	2019-09-11 23:49:49	2019-09-11	9	[{"id_menu":6,"count":1}]	2447	pick-up	0	9
7913	2019-09-12 00:50:15	2019-09-12	9	[{"id_menu":7,"count":1}]	626	pick-up	0	9
7914	2019-09-12 01:52:31	2019-09-12	9	[{"id_menu":7,"count":1}]	2124	pick-up	0	9
7915	2019-09-12 02:00:42	2019-09-12	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	510	pick-up	0	26
7916	2019-09-12 02:23:57	2019-09-12	12	[{"id_menu":1,"count":1}]	2922	delivery	5	17
7917	2019-09-12 02:59:13	2019-09-12	8	[{"id_menu":5,"count":1}]	2513	delivery	5	13
7918	2019-09-12 03:59:25	2019-09-12	8	[{"id_menu":5,"count":1}]	1922	delivery	5	13
7919	2019-09-12 04:05:11	2019-09-12	12	[{"id_menu":1,"count":1}]	2134	pick-up	0	12
7920	2019-09-12 04:10:12	2019-09-12	9	[{"id_menu":7,"count":1}]	1263	delivery	5	14
7921	2019-09-12 04:22:43	2019-09-12	14	[{"id_menu":2,"count":1}]	1071	pick-up	0	14
7922	2019-09-12 04:27:12	2019-09-12	9	[{"id_menu":7,"count":1}]	21	pick-up	0	9
7923	2019-09-12 04:29:04	2019-09-12	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1760	delivery	5	31
7924	2019-09-12 04:34:40	2019-09-12	12	[{"id_menu":1,"count":1}]	2932	pick-up	0	12
7925	2019-09-12 04:37:39	2019-09-12	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2927	delivery	5	31
7926	2019-09-12 04:58:39	2019-09-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2575	pick-up	0	18
7927	2019-09-12 05:45:54	2019-09-12	9	[{"id_menu":7,"count":1}]	2296	delivery	5	14
7928	2019-09-12 06:00:30	2019-09-12	14	[{"id_menu":2,"count":1}]	2228	delivery	5	19
7929	2019-09-12 06:10:21	2019-09-12	12	[{"id_menu":1,"count":1}]	1442	pick-up	0	12
7930	2019-09-12 06:14:09	2019-09-12	9	[{"id_menu":6,"count":1}]	250	pick-up	0	9
7931	2019-09-12 06:25:57	2019-09-12	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	138	delivery	5	26
7932	2019-09-12 06:26:21	2019-09-12	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2352	pick-up	0	29
7933	2019-09-12 07:34:20	2019-09-12	17	[{"id_menu":4,"count":1}]	309	pick-up	0	17
7934	2019-09-12 07:35:53	2019-09-12	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2929	delivery	5	26
7935	2019-09-12 07:57:39	2019-09-12	14	[{"id_menu":2,"count":1}]	806	pick-up	0	14
7936	2019-09-12 08:07:44	2019-09-12	12	[{"id_menu":1,"count":1}]	2913	delivery	5	17
7937	2019-09-12 08:10:59	2019-09-12	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1312	pick-up	0	21
7938	2019-09-12 08:11:25	2019-09-12	17	[{"id_menu":4,"count":1}]	1119	pick-up	0	17
7939	2019-09-12 08:16:25	2019-09-12	17	[{"id_menu":4,"count":1}]	1889	delivery	5	22
7940	2019-09-12 08:17:35	2019-09-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2926	pick-up	0	17
7941	2019-09-12 09:23:18	2019-09-12	17	[{"id_menu":4,"count":1}]	1303	pick-up	0	17
7942	2019-09-12 09:41:04	2019-09-12	9	[{"id_menu":6,"count":1}]	2426	delivery	5	14
7943	2019-09-12 09:43:59	2019-09-12	12	[{"id_menu":1,"count":1}]	2064	delivery	5	17
7944	2019-09-12 10:26:22	2019-09-12	9	[{"id_menu":6,"count":1}]	64	pick-up	0	9
7945	2019-09-12 10:56:06	2019-09-12	9	[{"id_menu":6,"count":1}]	1248	pick-up	0	9
7946	2019-09-12 11:03:21	2019-09-12	9	[{"id_menu":6,"count":1}]	764	delivery	5	14
7947	2019-09-12 11:52:36	2019-09-12	14	[{"id_menu":2,"count":1}]	1285	pick-up	0	14
7948	2019-09-12 12:06:51	2019-09-12	12	[{"id_menu":3,"count":1}]	2752	pick-up	0	12
7949	2019-09-12 12:14:28	2019-09-12	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1391	delivery	5	43
7950	2019-09-12 12:29:15	2019-09-12	12	[{"id_menu":3,"count":1}]	2455	delivery	5	17
7951	2019-09-12 12:43:09	2019-09-12	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2924	delivery	5	34
7952	2019-09-12 13:01:46	2019-09-12	17	[{"id_menu":4,"count":1}]	359	pick-up	0	17
7953	2019-09-12 13:02:23	2019-09-12	8	[{"id_menu":5,"count":1}]	2449	pick-up	0	8
7954	2019-09-12 14:04:17	2019-09-12	8	[{"id_menu":5,"count":1}]	2918	delivery	5	13
7955	2019-09-12 14:21:02	2019-09-12	9	[{"id_menu":6,"count":1}]	2920	pick-up	0	9
7956	2019-09-12 15:41:42	2019-09-12	17	[{"id_menu":4,"count":1}]	655	pick-up	0	17
7957	2019-09-12 15:54:39	2019-09-12	8	[{"id_menu":5,"count":1}]	2214	pick-up	0	8
7958	2019-09-12 16:14:29	2019-09-12	14	[{"id_menu":2,"count":1}]	2309	delivery	5	19
7959	2019-09-12 16:41:04	2019-09-12	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1529	delivery	5	25
7960	2019-09-12 16:55:46	2019-09-12	17	[{"id_menu":4,"count":1}]	2916	pick-up	0	17
7961	2019-09-12 17:14:59	2019-09-12	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2919	delivery	5	31
7962	2019-09-12 17:46:25	2019-09-12	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2662	pick-up	0	20
7963	2019-09-12 17:59:50	2019-09-12	17	[{"id_menu":4,"count":1}]	281	pick-up	0	17
7964	2019-09-12 18:05:39	2019-09-12	8	[{"id_menu":5,"count":1}]	2048	pick-up	0	8
7965	2019-09-12 18:24:15	2019-09-12	14	[{"id_menu":2,"count":1}]	2928	pick-up	0	14
7966	2019-09-12 18:44:00	2019-09-12	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	74	pick-up	0	26
7967	2019-09-12 18:53:38	2019-09-12	8	[{"id_menu":5,"count":1}]	2605	delivery	5	13
7968	2019-09-12 19:14:21	2019-09-12	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2004	pick-up	0	26
7969	2019-09-12 19:17:21	2019-09-12	8	[{"id_menu":5,"count":1}]	547	delivery	5	13
7970	2019-09-12 20:00:19	2019-09-12	14	[{"id_menu":2,"count":1}]	919	delivery	5	19
7971	2019-09-12 20:39:58	2019-09-12	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	154	delivery	5	46
7972	2019-09-12 21:48:45	2019-09-12	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	156	delivery	5	26
7973	2019-09-12 22:07:17	2019-09-12	12	[{"id_menu":1,"count":1}]	2833	delivery	5	17
7974	2019-09-12 22:26:09	2019-09-12	14	[{"id_menu":2,"count":1}]	2021	delivery	5	19
7975	2019-09-12 22:26:55	2019-09-12	9	[{"id_menu":7,"count":1}]	2921	delivery	5	14
7976	2019-09-12 22:38:48	2019-09-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2931	delivery	5	22
7977	2019-09-12 22:49:52	2019-09-12	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2914	pick-up	0	26
7978	2019-09-12 23:07:37	2019-09-12	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	910	pick-up	0	29
7979	2019-09-12 23:22:26	2019-09-12	14	[{"id_menu":2,"count":1}]	2041	delivery	5	19
7980	2019-09-12 23:38:06	2019-09-12	8	[{"id_menu":5,"count":1}]	2276	pick-up	0	8
7981	2019-09-13 00:08:32	2019-09-13	9	[{"id_menu":7,"count":1}]	27	delivery	5	14
7982	2019-09-13 00:23:14	2019-09-13	12	[{"id_menu":1,"count":1}]	2939	delivery	5	17
7983	2019-09-13 00:27:21	2019-09-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1019	pick-up	0	31
7984	2019-09-13 00:32:58	2019-09-13	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	315	pick-up	0	32
7985	2019-09-13 01:24:18	2019-09-13	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	2954	delivery	5	45
7986	2019-09-13 01:31:27	2019-09-13	17	[{"id_menu":4,"count":1}]	531	delivery	5	22
7987	2019-09-13 01:35:59	2019-09-13	9	[{"id_menu":7,"count":1}]	947	pick-up	0	9
7988	2019-09-13 01:49:31	2019-09-13	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1754	pick-up	0	43
7989	2019-09-13 02:05:26	2019-09-13	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2936	delivery	5	22
7990	2019-09-13 02:15:03	2019-09-13	17	[{"id_menu":4,"count":1}]	1963	delivery	5	22
7991	2019-09-13 02:18:33	2019-09-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2934	delivery	5	23
7992	2019-09-13 02:55:29	2019-09-13	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1166	pick-up	0	20
7993	2019-09-13 03:26:51	2019-09-13	14	[{"id_menu":2,"count":1}]	126	pick-up	0	14
7994	2019-09-13 03:44:45	2019-09-13	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2945	delivery	5	43
7995	2019-09-13 03:48:02	2019-09-13	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	442	delivery	5	40
7996	2019-09-13 04:03:01	2019-09-13	9	[{"id_menu":7,"count":2}]	66	delivery	5	14
7997	2019-09-13 04:42:52	2019-09-13	9	[{"id_menu":6,"count":2}]	2955	delivery	5	14
7998	2019-09-13 05:09:51	2019-09-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	585	delivery	5	23
7999	2019-09-13 05:28:35	2019-09-13	12	[{"id_menu":1,"count":1}]	2953	pick-up	0	12
8000	2019-09-13 05:37:38	2019-09-13	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1715	pick-up	0	21
8001	2019-09-13 06:15:22	2019-09-13	12	[{"id_menu":3,"count":1}]	2950	delivery	5	17
8002	2019-09-13 06:28:29	2019-09-13	9	[{"id_menu":6,"count":1}]	1215	pick-up	0	9
8003	2019-09-13 07:48:44	2019-09-13	12	[{"id_menu":1,"count":1}]	1104	pick-up	0	12
8004	2019-09-13 08:13:01	2019-09-13	14	[{"id_menu":2,"count":2}]	384	pick-up	0	14
8005	2019-09-13 08:40:16	2019-09-13	17	[{"id_menu":4,"count":1}]	489	pick-up	0	17
8006	2019-09-13 09:09:36	2019-09-13	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2000	pick-up	0	32
8007	2019-09-13 09:40:50	2019-09-13	14	[{"id_menu":2,"count":1}]	2948	delivery	5	19
8008	2019-09-13 09:55:08	2019-09-13	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2960	pick-up	0	35
8009	2019-09-13 10:16:29	2019-09-13	9	[{"id_menu":6,"count":1}]	2956	delivery	5	14
8010	2019-09-13 10:42:10	2019-09-13	12	[{"id_menu":1,"count":1}]	2943	pick-up	0	12
8011	2019-09-13 10:45:22	2019-09-13	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1950	pick-up	0	17
8012	2019-09-13 11:05:14	2019-09-13	9	[{"id_menu":6,"count":1}]	2947	delivery	5	14
8013	2019-09-13 11:43:56	2019-09-13	14	[{"id_menu":2,"count":1}]	2952	delivery	5	19
8014	2019-09-13 12:23:49	2019-09-13	17	[{"id_menu":4,"count":2}]	2941	pick-up	0	17
8015	2019-09-13 12:36:07	2019-09-13	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1733	pick-up	0	26
8016	2019-09-13 12:49:52	2019-09-13	17	[{"id_menu":4,"count":1}]	2949	delivery	5	22
8017	2019-09-13 13:49:11	2019-09-13	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1834	delivery	5	30
8018	2019-09-13 13:56:31	2019-09-13	17	[{"id_menu":4,"count":2}]	2590	pick-up	0	17
8019	2019-09-13 15:06:26	2019-09-13	14	[{"id_menu":2,"count":1}]	2443	delivery	5	19
8020	2019-09-13 15:40:43	2019-09-13	12	[{"id_menu":3,"count":1}]	71	pick-up	0	12
8021	2019-09-13 15:41:30	2019-09-13	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	2942	delivery	5	39
8022	2019-09-13 16:18:47	2019-09-13	8	[{"id_menu":5,"count":1}]	261	pick-up	0	8
8023	2019-09-13 16:33:07	2019-09-13	9	[{"id_menu":7,"count":1}]	2959	pick-up	0	9
8024	2019-09-13 16:36:01	2019-09-13	12	[{"id_menu":3,"count":1}]	260	delivery	5	17
8025	2019-09-13 16:55:20	2019-09-13	14	[{"id_menu":2,"count":1}]	787	delivery	5	19
8026	2019-09-13 16:58:21	2019-09-13	12	[{"id_menu":3,"count":1}]	498	pick-up	0	12
8027	2019-09-13 17:02:34	2019-09-13	12	[{"id_menu":3,"count":1}]	2935	delivery	5	17
8028	2019-09-13 17:03:35	2019-09-13	14	[{"id_menu":2,"count":1}]	491	pick-up	0	14
8029	2019-09-13 17:16:00	2019-09-13	14	[{"id_menu":2,"count":1}]	2933	pick-up	0	14
8030	2019-09-13 17:22:02	2019-09-13	9	[{"id_menu":7,"count":1}]	2806	delivery	5	14
8031	2019-09-13 17:38:55	2019-09-13	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	138	pick-up	0	23
8032	2019-09-13 17:53:51	2019-09-13	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2937	pick-up	0	38
8033	2019-09-13 18:15:02	2019-09-13	14	[{"id_menu":2,"count":1}]	1717	pick-up	0	14
8034	2019-09-13 18:20:09	2019-09-13	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1015	delivery	5	22
8035	2019-09-13 19:32:28	2019-09-13	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1972	delivery	5	34
8036	2019-09-13 20:31:16	2019-09-13	17	[{"id_menu":4,"count":1}]	184	delivery	5	22
8037	2019-09-13 20:41:53	2019-09-13	8	[{"id_menu":5,"count":1}]	1563	pick-up	0	8
8038	2019-09-13 21:01:45	2019-09-13	12	[{"id_menu":3,"count":1}]	708	pick-up	0	12
8039	2019-09-13 21:12:13	2019-09-13	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	1457	delivery	5	28
8040	2019-09-13 23:00:26	2019-09-13	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	541	pick-up	0	31
8041	2019-09-13 23:08:43	2019-09-13	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1537	delivery	5	22
8042	2019-09-13 23:09:47	2019-09-13	9	[{"id_menu":7,"count":1}]	2797	pick-up	0	9
8043	2019-09-13 23:17:23	2019-09-13	9	[{"id_menu":6,"count":1}]	207	pick-up	0	9
8044	2019-09-14 00:40:58	2019-09-14	17	[{"id_menu":4,"count":1}]	964	delivery	5	22
8045	2019-09-14 00:57:12	2019-09-14	17	[{"id_menu":4,"count":1}]	1640	delivery	5	22
8046	2019-09-14 01:03:53	2019-09-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1118	delivery	5	36
8047	2019-09-14 01:08:30	2019-09-14	9	[{"id_menu":6,"count":1}]	2964	pick-up	0	9
8048	2019-09-14 01:09:00	2019-09-14	12	[{"id_menu":3,"count":1}]	786	delivery	5	17
8049	2019-09-14 01:21:58	2019-09-14	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	2974	delivery	5	23
8050	2019-09-14 01:34:02	2019-09-14	9	[{"id_menu":7,"count":1}]	207	pick-up	0	9
8051	2019-09-14 01:42:27	2019-09-14	14	[{"id_menu":2,"count":1}]	2985	delivery	5	19
8052	2019-09-14 02:02:15	2019-09-14	14	[{"id_menu":2,"count":1}]	2562	delivery	5	19
8053	2019-09-14 02:12:23	2019-09-14	9	[{"id_menu":6,"count":1}]	639	delivery	5	14
8054	2019-09-14 02:26:07	2019-09-14	8	[{"id_menu":5,"count":1}]	308	delivery	5	13
8055	2019-09-14 02:38:09	2019-09-14	14	[{"id_menu":2,"count":2}]	744	pick-up	0	14
8056	2019-09-14 02:41:57	2019-09-14	12	[{"id_menu":3,"count":1}]	1922	pick-up	0	12
8057	2019-09-14 02:53:12	2019-09-14	12	[{"id_menu":3,"count":1}]	2517	delivery	5	17
8058	2019-09-14 02:55:36	2019-09-14	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2971	delivery	5	30
8059	2019-09-14 03:40:58	2019-09-14	9	[{"id_menu":6,"count":1}]	2253	pick-up	0	9
8060	2019-09-14 03:58:37	2019-09-14	12	[{"id_menu":3,"count":1}]	654	pick-up	0	12
8061	2019-09-14 04:33:17	2019-09-14	9	[{"id_menu":7,"count":1}]	2447	delivery	5	14
8062	2019-09-14 04:55:28	2019-09-14	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	1376	pick-up	0	21
8063	2019-09-14 04:59:28	2019-09-14	14	[{"id_menu":2,"count":1}]	2275	pick-up	0	14
8064	2019-09-14 05:12:14	2019-09-14	12	[{"id_menu":3,"count":1}]	739	pick-up	0	12
8065	2019-09-14 05:40:15	2019-09-14	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2573	pick-up	0	49
8066	2019-09-14 06:02:34	2019-09-14	12	[{"id_menu":1,"count":1}]	913	delivery	5	17
8067	2019-09-14 06:50:41	2019-09-14	17	[{"id_menu":4,"count":1}]	44	pick-up	0	17
8068	2019-09-14 07:36:38	2019-09-14	12	[{"id_menu":1,"count":1}]	2981	pick-up	0	12
8069	2019-09-14 08:07:57	2019-09-14	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2982	delivery	5	27
8070	2019-09-14 08:15:15	2019-09-14	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1818	delivery	5	38
8071	2019-09-14 09:24:03	2019-09-14	12	[{"id_menu":1,"count":1}]	821	pick-up	0	12
8072	2019-09-14 09:33:50	2019-09-14	12	[{"id_menu":1,"count":1}]	379	pick-up	0	12
8073	2019-09-14 09:50:37	2019-09-14	9	[{"id_menu":6,"count":1}]	2978	delivery	5	14
8074	2019-09-14 09:51:43	2019-09-14	9	[{"id_menu":7,"count":1}]	2659	pick-up	0	9
8075	2019-09-14 09:59:24	2019-09-14	8	[{"id_menu":5,"count":1}]	2986	delivery	5	13
8076	2019-09-14 10:07:55	2019-09-14	9	[{"id_menu":6,"count":1}]	1931	pick-up	0	9
8077	2019-09-14 10:08:40	2019-09-14	14	[{"id_menu":2,"count":1}]	2543	delivery	5	19
8078	2019-09-14 10:15:02	2019-09-14	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2843	delivery	5	31
8079	2019-09-14 10:52:07	2019-09-14	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2966	pick-up	0	26
8080	2019-09-14 11:00:23	2019-09-14	17	[{"id_menu":4,"count":1}]	1729	delivery	5	22
8081	2019-09-14 11:01:04	2019-09-14	12	[{"id_menu":1,"count":1}]	1562	delivery	5	17
8082	2019-09-14 11:02:14	2019-09-14	14	[{"id_menu":2,"count":1}]	2076	pick-up	0	14
8083	2019-09-14 11:09:26	2019-09-14	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2139	pick-up	0	32
8084	2019-09-14 11:36:46	2019-09-14	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2980	pick-up	0	29
8085	2019-09-14 11:39:04	2019-09-14	17	[{"id_menu":4,"count":1}]	1379	pick-up	0	17
8086	2019-09-14 11:48:20	2019-09-14	17	[{"id_menu":4,"count":1}]	340	pick-up	0	17
8087	2019-09-14 11:53:18	2019-09-14	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2116	delivery	5	31
8088	2019-09-14 11:53:32	2019-09-14	14	[{"id_menu":2,"count":1}]	1813	pick-up	0	14
8089	2019-09-14 12:13:34	2019-09-14	9	[{"id_menu":7,"count":1}]	2413	pick-up	0	9
8090	2019-09-14 12:13:36	2019-09-14	17	[{"id_menu":4,"count":2}]	408	pick-up	0	17
8091	2019-09-14 12:39:23	2019-09-14	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1680	delivery	5	45
8092	2019-09-14 12:46:19	2019-09-14	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2984	delivery	5	26
8093	2019-09-14 12:48:57	2019-09-14	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1687	delivery	5	22
8094	2019-09-14 13:24:58	2019-09-14	17	[{"id_menu":4,"count":1}]	2358	pick-up	0	17
8095	2019-09-14 13:31:54	2019-09-14	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	1979	delivery	5	26
8096	2019-09-14 13:38:42	2019-09-14	8	[{"id_menu":5,"count":1}]	1715	pick-up	0	8
8097	2019-09-14 13:49:59	2019-09-14	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2282	pick-up	0	21
8098	2019-09-14 13:54:35	2019-09-14	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	708	pick-up	0	21
8099	2019-09-14 14:00:05	2019-09-14	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2979	delivery	5	26
8100	2019-09-14 14:08:22	2019-09-14	9	[{"id_menu":7,"count":1}]	638	delivery	5	14
8101	2019-09-14 14:08:33	2019-09-14	8	[{"id_menu":5,"count":1}]	2973	pick-up	0	8
8102	2019-09-14 14:12:00	2019-09-14	14	[{"id_menu":2,"count":1}]	2623	delivery	5	19
8103	2019-09-14 14:32:43	2019-09-14	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2798	pick-up	0	22
8104	2019-09-14 14:39:27	2019-09-14	14	[{"id_menu":2,"count":1}]	1296	delivery	5	19
8105	2019-09-14 14:50:44	2019-09-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2007	delivery	5	22
8106	2019-09-14 15:52:12	2019-09-14	17	[{"id_menu":4,"count":1}]	968	pick-up	0	17
8107	2019-09-14 15:56:54	2019-09-14	8	[{"id_menu":5,"count":1}]	2505	pick-up	0	8
8108	2019-09-14 17:12:59	2019-09-14	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2972	pick-up	0	37
8109	2019-09-14 17:15:44	2019-09-14	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1304	delivery	5	26
8110	2019-09-14 17:27:42	2019-09-14	9	[{"id_menu":6,"count":1}]	74	pick-up	0	9
8111	2019-09-14 17:48:45	2019-09-14	12	[{"id_menu":3,"count":1}]	634	pick-up	0	12
8112	2019-09-14 17:52:47	2019-09-14	17	[{"id_menu":4,"count":2}]	2969	pick-up	0	17
8113	2019-09-14 18:25:09	2019-09-14	9	[{"id_menu":7,"count":1}]	1528	delivery	5	14
8114	2019-09-14 18:45:20	2019-09-14	9	[{"id_menu":6,"count":1}]	2761	delivery	5	14
8115	2019-09-14 19:13:14	2019-09-14	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2672	delivery	5	27
8116	2019-09-14 19:19:36	2019-09-14	12	[{"id_menu":3,"count":1}]	1218	pick-up	0	12
8117	2019-09-14 19:28:57	2019-09-14	9	[{"id_menu":7,"count":1}]	2776	pick-up	0	9
8118	2019-09-14 19:36:15	2019-09-14	8	[{"id_menu":5,"count":1}]	2983	pick-up	0	8
8119	2019-09-14 19:48:05	2019-09-14	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2977	pick-up	0	23
8120	2019-09-14 19:52:53	2019-09-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2975	delivery	5	22
8121	2019-09-14 20:23:18	2019-09-14	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2976	delivery	5	31
8122	2019-09-14 21:03:51	2019-09-14	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2965	delivery	5	31
8123	2019-09-14 21:17:38	2019-09-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1289	pick-up	0	17
8124	2019-09-14 21:44:04	2019-09-14	9	[{"id_menu":6,"count":1}]	2970	delivery	5	14
8125	2019-09-14 21:48:43	2019-09-14	9	[{"id_menu":6,"count":1}]	2967	pick-up	0	9
8126	2019-09-14 21:51:28	2019-09-14	8	[{"id_menu":5,"count":1}]	2187	delivery	5	13
8127	2019-09-14 21:56:30	2019-09-14	9	[{"id_menu":6,"count":1}]	2894	pick-up	0	9
8128	2019-09-14 22:10:41	2019-09-14	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	1295	pick-up	0	21
8129	2019-09-14 22:20:29	2019-09-14	9	[{"id_menu":7,"count":1}]	1228	delivery	5	14
8130	2019-09-14 22:29:42	2019-09-14	17	[{"id_menu":4,"count":1}]	2961	pick-up	0	17
8131	2019-09-14 23:00:39	2019-09-14	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	601	pick-up	0	23
8132	2019-09-14 23:14:32	2019-09-14	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	2119	pick-up	0	21
8133	2019-09-14 23:56:40	2019-09-14	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	723	pick-up	0	26
8134	2019-09-14 23:59:18	2019-09-14	12	[{"id_menu":1,"count":1}]	2962	pick-up	0	12
8135	2019-09-15 00:05:01	2019-09-15	14	[{"id_menu":2,"count":1}]	1405	pick-up	0	14
8136	2019-09-15 00:24:53	2019-09-15	9	[{"id_menu":6,"count":1}]	2699	pick-up	0	9
8137	2019-09-15 00:28:44	2019-09-15	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	203	pick-up	0	25
8138	2019-09-15 01:12:06	2019-09-15	9	[{"id_menu":6,"count":1}]	314	pick-up	0	9
8139	2019-09-15 01:17:19	2019-09-15	12	[{"id_menu":1,"count":1}]	2987	delivery	5	17
8140	2019-09-15 01:32:27	2019-09-15	12	[{"id_menu":3,"count":1}]	429	pick-up	0	12
8141	2019-09-15 01:38:42	2019-09-15	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2237	pick-up	0	35
8142	2019-09-15 01:42:45	2019-09-15	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3009	pick-up	0	17
8143	2019-09-15 01:43:29	2019-09-15	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2105	pick-up	0	26
8144	2019-09-15 02:00:01	2019-09-15	9	[{"id_menu":6,"count":1}]	2994	delivery	5	14
8145	2019-09-15 02:43:16	2019-09-15	9	[{"id_menu":7,"count":1}]	806	delivery	5	14
8146	2019-09-15 03:08:31	2019-09-15	12	[{"id_menu":3,"count":1}]	2561	delivery	5	17
8147	2019-09-15 03:48:45	2019-09-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3007	pick-up	0	23
8215	2019-09-15 17:22:28	2019-09-15	12	[{"id_menu":1,"count":1}]	976	pick-up	0	12
8148	2019-09-15 04:02:39	2019-09-15	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	232	pick-up	0	38
8149	2019-09-15 04:06:16	2019-09-15	8	[{"id_menu":5,"count":1}]	1485	pick-up	0	8
8150	2019-09-15 04:28:09	2019-09-15	12	[{"id_menu":3,"count":1}]	1627	pick-up	0	12
8151	2019-09-15 04:34:15	2019-09-15	9	[{"id_menu":6,"count":1}]	1445	pick-up	0	9
8152	2019-09-15 04:50:54	2019-09-15	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	3011	delivery	5	40
8153	2019-09-15 05:04:20	2019-09-15	14	[{"id_menu":2,"count":2}]	2317	pick-up	0	14
8154	2019-09-15 05:07:17	2019-09-15	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2989	pick-up	0	29
8155	2019-09-15 05:21:19	2019-09-15	14	[{"id_menu":2,"count":1}]	511	pick-up	0	14
8156	2019-09-15 06:00:39	2019-09-15	12	[{"id_menu":3,"count":1}]	2536	delivery	5	17
8157	2019-09-15 06:03:19	2019-09-15	12	[{"id_menu":1,"count":1}]	3010	pick-up	0	12
8158	2019-09-15 06:03:34	2019-09-15	9	[{"id_menu":7,"count":1}]	3004	delivery	5	14
8159	2019-09-15 06:05:29	2019-09-15	12	[{"id_menu":1,"count":1}]	1545	delivery	5	17
8160	2019-09-15 06:09:16	2019-09-15	12	[{"id_menu":3,"count":1}]	96	pick-up	0	12
8161	2019-09-15 06:30:08	2019-09-15	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2453	pick-up	0	31
8162	2019-09-15 06:32:16	2019-09-15	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2762	pick-up	0	21
8163	2019-09-15 06:37:13	2019-09-15	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	691	pick-up	0	35
8164	2019-09-15 06:39:45	2019-09-15	14	[{"id_menu":2,"count":1}]	3005	delivery	5	19
8165	2019-09-15 06:46:10	2019-09-15	9	[{"id_menu":6,"count":1}]	1908	delivery	5	14
8166	2019-09-15 06:48:20	2019-09-15	9	[{"id_menu":6,"count":1}]	2780	pick-up	0	9
8167	2019-09-15 07:03:18	2019-09-15	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2855	pick-up	0	17
8168	2019-09-15 07:06:02	2019-09-15	9	[{"id_menu":6,"count":1}]	1618	pick-up	0	9
8169	2019-09-15 07:06:06	2019-09-15	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3013	delivery	5	40
8170	2019-09-15 07:20:44	2019-09-15	9	[{"id_menu":7,"count":1}]	2998	delivery	5	14
8171	2019-09-15 07:29:20	2019-09-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1760	delivery	5	28
8172	2019-09-15 08:25:30	2019-09-15	12	[{"id_menu":3,"count":1}]	2421	pick-up	0	12
8173	2019-09-15 08:57:40	2019-09-15	8	[{"id_menu":5,"count":1}]	2992	delivery	5	13
8174	2019-09-15 09:07:01	2019-09-15	17	[{"id_menu":4,"count":1}]	21	pick-up	0	17
8175	2019-09-15 09:10:22	2019-09-15	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2313	pick-up	0	40
8176	2019-09-15 09:46:02	2019-09-15	17	[{"id_menu":4,"count":1}]	2303	pick-up	0	17
8177	2019-09-15 09:47:40	2019-09-15	12	[{"id_menu":3,"count":1}]	1854	pick-up	0	12
8178	2019-09-15 09:56:04	2019-09-15	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	654	delivery	5	22
8179	2019-09-15 10:10:40	2019-09-15	9	[{"id_menu":6,"count":1}]	930	pick-up	0	9
8180	2019-09-15 10:11:13	2019-09-15	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1424	pick-up	0	35
8181	2019-09-15 10:12:40	2019-09-15	9	[{"id_menu":6,"count":1}]	1481	pick-up	0	9
8182	2019-09-15 10:18:11	2019-09-15	12	[{"id_menu":3,"count":1}]	3006	delivery	5	17
8183	2019-09-15 10:22:17	2019-09-15	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	466	delivery	5	45
8184	2019-09-15 10:50:16	2019-09-15	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2991	delivery	5	39
8185	2019-09-15 10:51:02	2019-09-15	14	[{"id_menu":2,"count":1}]	2988	delivery	5	19
8186	2019-09-15 10:52:08	2019-09-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1640	pick-up	0	26
8187	2019-09-15 11:12:10	2019-09-15	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	138	pick-up	0	26
8188	2019-09-15 11:13:23	2019-09-15	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	2834	delivery	5	26
8189	2019-09-15 11:13:58	2019-09-15	17	[{"id_menu":4,"count":1}]	395	pick-up	0	17
8190	2019-09-15 11:42:05	2019-09-15	12	[{"id_menu":3,"count":1}]	3003	pick-up	0	12
8191	2019-09-15 11:52:42	2019-09-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2710	delivery	5	28
8192	2019-09-15 12:08:20	2019-09-15	12	[{"id_menu":1,"count":1}]	2999	delivery	5	17
8193	2019-09-15 12:10:04	2019-09-15	9	[{"id_menu":7,"count":1}]	2477	pick-up	0	9
8194	2019-09-15 12:10:08	2019-09-15	12	[{"id_menu":1,"count":1}]	2520	delivery	5	17
8195	2019-09-15 12:41:37	2019-09-15	12	[{"id_menu":3,"count":1}]	2172	pick-up	0	12
8196	2019-09-15 12:47:56	2019-09-15	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1261	pick-up	0	21
8197	2019-09-15 12:59:09	2019-09-15	17	[{"id_menu":4,"count":1}]	478	pick-up	0	17
8198	2019-09-15 13:34:16	2019-09-15	12	[{"id_menu":1,"count":1}]	1110	pick-up	0	12
8199	2019-09-15 13:55:37	2019-09-15	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1363	pick-up	0	22
8200	2019-09-15 13:58:25	2019-09-15	12	[{"id_menu":1,"count":1}]	1820	pick-up	0	12
8201	2019-09-15 14:11:21	2019-09-15	9	[{"id_menu":6,"count":1}]	993	pick-up	0	9
8202	2019-09-15 14:18:46	2019-09-15	14	[{"id_menu":2,"count":1}]	2552	pick-up	0	14
8203	2019-09-15 14:21:11	2019-09-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2996	pick-up	0	23
8204	2019-09-15 14:37:36	2019-09-15	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2997	delivery	5	48
8205	2019-09-15 14:54:02	2019-09-15	12	[{"id_menu":1,"count":1}]	648	pick-up	0	12
8206	2019-09-15 15:01:54	2019-09-15	12	[{"id_menu":3,"count":1}]	2472	pick-up	0	12
8207	2019-09-15 15:06:17	2019-09-15	8	[{"id_menu":5,"count":1}]	1987	delivery	5	13
8208	2019-09-15 15:14:19	2019-09-15	9	[{"id_menu":6,"count":1}]	59	delivery	5	14
8209	2019-09-15 15:43:10	2019-09-15	9	[{"id_menu":6,"count":1}]	1815	delivery	5	14
8210	2019-09-15 16:18:58	2019-09-15	12	[{"id_menu":3,"count":1}]	153	pick-up	0	12
8211	2019-09-15 16:28:37	2019-09-15	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	917	delivery	5	40
8212	2019-09-15 16:30:01	2019-09-15	17	[{"id_menu":4,"count":1}]	688	pick-up	0	17
8213	2019-09-15 17:14:18	2019-09-15	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2982	delivery	5	30
8214	2019-09-15 17:15:23	2019-09-15	9	[{"id_menu":6,"count":1}]	2420	delivery	5	14
8216	2019-09-15 17:51:26	2019-09-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	684	delivery	5	31
8217	2019-09-15 17:55:11	2019-09-15	12	[{"id_menu":3,"count":1}]	3012	pick-up	0	12
8218	2019-09-15 18:10:42	2019-09-15	9	[{"id_menu":6,"count":1}]	1727	pick-up	0	9
8219	2019-09-15 18:13:43	2019-09-15	9	[{"id_menu":6,"count":1}]	3014	delivery	5	14
8220	2019-09-15 18:19:01	2019-09-15	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2664	delivery	5	31
8221	2019-09-15 18:53:16	2019-09-15	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	119	pick-up	0	21
8222	2019-09-15 19:14:01	2019-09-15	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2956	pick-up	0	25
8223	2019-09-15 19:14:58	2019-09-15	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3000	pick-up	0	26
8224	2019-09-15 19:39:30	2019-09-15	9	[{"id_menu":6,"count":1}]	1862	pick-up	0	9
8225	2019-09-15 19:46:56	2019-09-15	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	3001	pick-up	0	20
8226	2019-09-15 19:54:39	2019-09-15	9	[{"id_menu":6,"count":1}]	2272	pick-up	0	9
8227	2019-09-15 21:25:31	2019-09-15	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	3008	delivery	5	22
8228	2019-09-15 21:29:39	2019-09-15	17	[{"id_menu":4,"count":1}]	170	pick-up	0	17
8229	2019-09-15 21:53:42	2019-09-15	12	[{"id_menu":1,"count":1}]	2618	delivery	5	17
8230	2019-09-15 21:54:09	2019-09-15	14	[{"id_menu":2,"count":1}]	2993	pick-up	0	14
8231	2019-09-15 22:01:47	2019-09-15	17	[{"id_menu":4,"count":1}]	1409	delivery	5	22
8232	2019-09-15 22:08:31	2019-09-15	12	[{"id_menu":1,"count":1}]	1095	delivery	5	17
8233	2019-09-15 22:09:55	2019-09-15	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1266	pick-up	0	35
8234	2019-09-15 22:17:32	2019-09-15	8	[{"id_menu":5,"count":1}]	204	pick-up	0	8
8235	2019-09-15 22:20:31	2019-09-15	17	[{"id_menu":4,"count":1}]	3002	pick-up	0	17
8236	2019-09-15 22:30:11	2019-09-15	9	[{"id_menu":7,"count":1}]	3015	pick-up	0	9
8237	2019-09-15 22:31:01	2019-09-15	12	[{"id_menu":1,"count":1}]	2123	pick-up	0	12
8238	2019-09-15 22:41:51	2019-09-15	17	[{"id_menu":4,"count":1}]	2926	pick-up	0	17
8239	2019-09-15 22:43:13	2019-09-15	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	2922	pick-up	0	24
8240	2019-09-15 22:46:33	2019-09-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	2995	delivery	5	31
8241	2019-09-15 23:18:13	2019-09-15	9	[{"id_menu":7,"count":1}]	2990	delivery	5	14
8242	2019-09-15 23:24:01	2019-09-15	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1223	pick-up	0	29
8243	2019-09-15 23:54:59	2019-09-15	9	[{"id_menu":6,"count":1}]	217	pick-up	0	9
8244	2019-09-16 00:33:44	2019-09-16	8	[{"id_menu":5,"count":1}]	172	delivery	5	13
8245	2019-09-16 00:48:37	2019-09-16	9	[{"id_menu":6,"count":1}]	2556	delivery	5	14
8246	2019-09-16 03:26:52	2019-09-16	8	[{"id_menu":5,"count":1}]	1970	delivery	5	13
8247	2019-09-16 03:27:02	2019-09-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	831	delivery	5	31
8248	2019-09-16 04:06:16	2019-09-16	9	[{"id_menu":7,"count":2}]	2939	delivery	5	14
8249	2019-09-16 04:33:56	2019-09-16	8	[{"id_menu":5,"count":1}]	2472	delivery	5	13
8250	2019-09-16 06:35:26	2019-09-16	9	[{"id_menu":7,"count":1}]	1813	pick-up	0	9
8251	2019-09-16 06:59:25	2019-09-16	9	[{"id_menu":7,"count":1}]	2551	pick-up	0	9
8252	2019-09-16 07:29:38	2019-09-16	12	[{"id_menu":3,"count":1}]	941	pick-up	0	12
8253	2019-09-16 07:45:00	2019-09-16	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	3024	pick-up	0	32
8254	2019-09-16 07:57:54	2019-09-16	14	[{"id_menu":2,"count":1}]	2943	pick-up	0	14
8255	2019-09-16 08:19:13	2019-09-16	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	1656	pick-up	0	20
8256	2019-09-16 09:18:53	2019-09-16	12	[{"id_menu":3,"count":1}]	1393	delivery	5	17
8257	2019-09-16 09:36:50	2019-09-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2332	delivery	5	28
8258	2019-09-16 10:32:28	2019-09-16	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3030	delivery	5	52
8259	2019-09-16 10:38:06	2019-09-16	8	[{"id_menu":5,"count":1}]	131	pick-up	0	8
8260	2019-09-16 11:03:48	2019-09-16	9	[{"id_menu":6,"count":1}]	800	delivery	5	14
8261	2019-09-16 11:12:42	2019-09-16	17	[{"id_menu":4,"count":1}]	563	delivery	5	22
8262	2019-09-16 12:36:35	2019-09-16	17	[{"id_menu":4,"count":1}]	1155	delivery	5	22
8263	2019-09-16 12:58:49	2019-09-16	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	567	delivery	5	27
8264	2019-09-16 14:05:28	2019-09-16	14	[{"id_menu":2,"count":1}]	2189	pick-up	0	14
8265	2019-09-16 15:58:43	2019-09-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1690	delivery	5	28
8266	2019-09-16 16:07:18	2019-09-16	12	[{"id_menu":1,"count":1}]	684	delivery	5	17
8267	2019-09-16 16:17:08	2019-09-16	12	[{"id_menu":3,"count":1}]	3036	delivery	5	17
8268	2019-09-16 16:50:01	2019-09-16	14	[{"id_menu":2,"count":1}]	3018	delivery	5	19
8269	2019-09-16 17:33:15	2019-09-16	17	[{"id_menu":4,"count":1}]	930	pick-up	0	17
8270	2019-09-16 17:40:39	2019-09-16	9	[{"id_menu":6,"count":1}]	3016	delivery	5	14
8271	2019-09-16 18:18:08	2019-09-16	8	[{"id_menu":5,"count":1}]	3041	delivery	5	13
8272	2019-09-16 18:41:46	2019-09-16	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1279	pick-up	0	21
8273	2019-09-16 18:44:35	2019-09-16	12	[{"id_menu":3,"count":1}]	2538	delivery	5	17
8274	2019-09-16 19:28:43	2019-09-16	8	[{"id_menu":5,"count":1}]	933	pick-up	0	8
8275	2019-09-16 19:46:15	2019-09-16	14	[{"id_menu":2,"count":1}]	2052	delivery	5	19
8276	2019-09-16 21:14:02	2019-09-16	14	[{"id_menu":2,"count":1}]	2237	pick-up	0	14
8277	2019-09-16 21:19:28	2019-09-16	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	2401	pick-up	0	24
8278	2019-09-16 21:59:42	2019-09-16	9	[{"id_menu":6,"count":1}]	3031	pick-up	0	9
8279	2019-09-16 23:37:36	2019-09-16	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2845	delivery	5	37
8280	2019-09-17 00:06:07	2019-09-17	14	[{"id_menu":2,"count":1}]	2217	pick-up	0	14
8281	2019-09-17 00:11:25	2019-09-17	17	[{"id_menu":4,"count":1}]	3069	delivery	5	22
8282	2019-09-17 00:11:31	2019-09-17	8	[{"id_menu":5,"count":1}]	289	delivery	5	13
8283	2019-09-17 00:14:49	2019-09-17	12	[{"id_menu":1,"count":1}]	1813	delivery	5	17
8284	2019-09-17 01:20:00	2019-09-17	9	[{"id_menu":6,"count":1}]	3058	delivery	5	14
8285	2019-09-17 01:30:05	2019-09-17	17	[{"id_menu":4,"count":1}]	3052	delivery	5	22
8286	2019-09-17 02:29:07	2019-09-17	17	[{"id_menu":4,"count":1}]	3064	delivery	5	22
8287	2019-09-17 02:45:44	2019-09-17	17	[{"id_menu":4,"count":1}]	2771	delivery	5	22
8288	2019-09-17 02:56:14	2019-09-17	9	[{"id_menu":7,"count":1}]	2938	pick-up	0	9
8289	2019-09-17 03:07:24	2019-09-17	9	[{"id_menu":6,"count":1}]	1736	pick-up	0	9
8290	2019-09-17 03:47:34	2019-09-17	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":2}]	3049	delivery	5	22
8291	2019-09-17 04:00:52	2019-09-17	12	[{"id_menu":3,"count":2}]	2956	delivery	5	17
8292	2019-09-17 05:36:36	2019-09-17	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	3065	pick-up	0	21
8293	2019-09-17 05:39:00	2019-09-17	14	[{"id_menu":2,"count":1}]	177	delivery	5	19
8294	2019-09-17 06:17:21	2019-09-17	14	[{"id_menu":2,"count":1}]	3051	pick-up	0	14
8295	2019-09-17 06:20:49	2019-09-17	9	[{"id_menu":7,"count":1}]	3053	delivery	5	14
8296	2019-09-17 07:39:35	2019-09-17	14	[{"id_menu":2,"count":1}]	3059	delivery	5	19
8297	2019-09-17 07:41:47	2019-09-17	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":2}]	25	pick-up	0	23
8298	2019-09-17 08:59:39	2019-09-17	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2954	delivery	5	31
8299	2019-09-17 09:55:16	2019-09-17	12	[{"id_menu":1,"count":1}]	1592	delivery	5	17
8300	2019-09-17 10:03:31	2019-09-17	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	80	delivery	5	31
8301	2019-09-17 11:08:32	2019-09-17	9	[{"id_menu":7,"count":1}]	719	pick-up	0	9
8302	2019-09-17 11:39:48	2019-09-17	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	1233	pick-up	0	21
8303	2019-09-17 12:27:06	2019-09-17	17	[{"id_menu":4,"count":1}]	378	pick-up	0	17
8304	2019-09-17 12:36:30	2019-09-17	17	[{"id_menu":4,"count":1}]	2600	delivery	5	22
8305	2019-09-17 14:11:36	2019-09-17	17	[{"id_menu":4,"count":1}]	997	pick-up	0	17
8306	2019-09-17 14:15:00	2019-09-17	17	[{"id_menu":4,"count":1}]	3054	delivery	5	22
8307	2019-09-17 14:48:07	2019-09-17	17	[{"id_menu":4,"count":1}]	3050	pick-up	0	17
8308	2019-09-17 15:05:44	2019-09-17	12	[{"id_menu":1,"count":1}]	2950	pick-up	0	12
8309	2019-09-17 15:29:46	2019-09-17	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2185	delivery	5	31
8310	2019-09-17 16:22:41	2019-09-17	14	[{"id_menu":2,"count":2}]	1606	delivery	5	19
8311	2019-09-17 16:59:05	2019-09-17	12	[{"id_menu":3,"count":1}]	2295	pick-up	0	12
8312	2019-09-17 17:12:03	2019-09-17	17	[{"id_menu":4,"count":1}]	1490	delivery	5	22
8313	2019-09-17 17:13:01	2019-09-17	12	[{"id_menu":1,"count":1}]	3063	delivery	5	17
8314	2019-09-17 17:41:30	2019-09-17	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	3056	pick-up	0	21
8315	2019-09-17 17:55:47	2019-09-17	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	74	pick-up	0	43
8316	2019-09-17 18:16:36	2019-09-17	9	[{"id_menu":7,"count":2}]	1727	pick-up	0	9
8317	2019-09-17 18:58:16	2019-09-17	14	[{"id_menu":2,"count":1}]	182	pick-up	0	14
8318	2019-09-17 19:15:18	2019-09-17	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3044	delivery	5	46
8319	2019-09-17 19:52:02	2019-09-17	8	[{"id_menu":5,"count":1}]	3048	delivery	5	13
8320	2019-09-17 20:01:06	2019-09-17	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	3061	delivery	5	27
8321	2019-09-17 20:24:40	2019-09-17	17	[{"id_menu":4,"count":1}]	2523	pick-up	0	17
8322	2019-09-17 20:53:38	2019-09-17	9	[{"id_menu":6,"count":1}]	2610	pick-up	0	9
8323	2019-09-17 20:59:12	2019-09-17	12	[{"id_menu":1,"count":1}]	2728	pick-up	0	12
8324	2019-09-17 21:00:05	2019-09-17	9	[{"id_menu":7,"count":1}]	301	delivery	5	14
8325	2019-09-17 21:20:37	2019-09-17	17	[{"id_menu":4,"count":1}]	1597	delivery	5	22
8326	2019-09-17 21:37:19	2019-09-17	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1457	delivery	5	22
8327	2019-09-17 21:49:09	2019-09-17	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	993	pick-up	0	29
8328	2019-09-17 21:53:01	2019-09-17	8	[{"id_menu":5,"count":1}]	3066	pick-up	0	8
8329	2019-09-17 21:54:07	2019-09-17	9	[{"id_menu":6,"count":3}]	778	delivery	5	14
8330	2019-09-17 22:41:03	2019-09-17	8	[{"id_menu":5,"count":1}]	2431	delivery	5	13
8331	2019-09-17 22:43:11	2019-09-17	9	[{"id_menu":7,"count":1}]	807	pick-up	0	9
8332	2019-09-17 23:06:54	2019-09-17	9	[{"id_menu":7,"count":1}]	821	pick-up	0	9
8333	2019-09-17 23:40:26	2019-09-17	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	788	pick-up	0	26
8334	2019-09-17 23:48:12	2019-09-17	14	[{"id_menu":2,"count":1}]	226	delivery	5	19
8335	2019-09-18 00:34:02	2019-09-18	9	[{"id_menu":7,"count":1}]	2952	delivery	5	14
8336	2019-09-18 01:49:18	2019-09-18	9	[{"id_menu":6,"count":2}]	3099	delivery	5	14
8337	2019-09-18 01:56:18	2019-09-18	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	292	delivery	5	38
8338	2019-09-18 01:59:16	2019-09-18	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1803	pick-up	0	31
8339	2019-09-18 02:16:44	2019-09-18	17	[{"id_menu":4,"count":1}]	3094	delivery	5	22
8340	2019-09-18 02:52:34	2019-09-18	12	[{"id_menu":1,"count":1}]	1435	pick-up	0	12
8341	2019-09-18 03:35:21	2019-09-18	9	[{"id_menu":7,"count":2}]	3078	delivery	5	14
8342	2019-09-18 03:45:55	2019-09-18	9	[{"id_menu":7,"count":1}]	3091	delivery	5	14
8343	2019-09-18 03:52:38	2019-09-18	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1932	delivery	5	35
8344	2019-09-18 04:00:58	2019-09-18	12	[{"id_menu":3,"count":1}]	2960	pick-up	0	12
8345	2019-09-18 04:20:43	2019-09-18	14	[{"id_menu":2,"count":1}]	3075	delivery	5	19
8346	2019-09-18 04:37:14	2019-09-18	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	3071	pick-up	0	26
8347	2019-09-18 04:38:14	2019-09-18	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1170	pick-up	0	31
8348	2019-09-18 04:47:12	2019-09-18	9	[{"id_menu":7,"count":1}]	3085	pick-up	0	9
8349	2019-09-18 04:48:36	2019-09-18	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	790	pick-up	0	37
8350	2019-09-18 05:05:14	2019-09-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	868	pick-up	0	18
8351	2019-09-18 05:25:59	2019-09-18	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2068	pick-up	0	20
8352	2019-09-18 05:46:44	2019-09-18	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2443	pick-up	0	41
8353	2019-09-18 06:05:01	2019-09-18	12	[{"id_menu":3,"count":1}]	2594	pick-up	0	12
8354	2019-09-18 06:19:29	2019-09-18	14	[{"id_menu":2,"count":1}]	3073	pick-up	0	14
8355	2019-09-18 06:22:12	2019-09-18	9	[{"id_menu":7,"count":1}]	3086	delivery	5	14
8356	2019-09-18 06:32:46	2019-09-18	17	[{"id_menu":4,"count":1}]	1711	pick-up	0	17
8357	2019-09-18 06:47:57	2019-09-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3093	delivery	5	28
8358	2019-09-18 06:55:02	2019-09-18	9	[{"id_menu":7,"count":1}]	2491	delivery	5	14
8359	2019-09-18 07:01:13	2019-09-18	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2861	delivery	5	26
8360	2019-09-18 07:13:56	2019-09-18	14	[{"id_menu":2,"count":1}]	609	pick-up	0	14
8361	2019-09-18 08:02:23	2019-09-18	9	[{"id_menu":7,"count":1}]	1862	pick-up	0	9
8362	2019-09-18 08:03:44	2019-09-18	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	810	delivery	5	25
8363	2019-09-18 08:13:17	2019-09-18	9	[{"id_menu":6,"count":1}]	1742	pick-up	0	9
8364	2019-09-18 09:43:33	2019-09-18	8	[{"id_menu":5,"count":1}]	135	pick-up	0	8
8365	2019-09-18 10:42:17	2019-09-18	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1266	delivery	5	55
8366	2019-09-18 11:08:19	2019-09-18	14	[{"id_menu":2,"count":1}]	3096	delivery	5	19
8367	2019-09-18 11:13:09	2019-09-18	12	[{"id_menu":1,"count":1}]	2107	pick-up	0	12
8368	2019-09-18 11:30:20	2019-09-18	9	[{"id_menu":7,"count":1}]	3082	delivery	5	14
8369	2019-09-18 12:02:31	2019-09-18	17	[{"id_menu":4,"count":1}]	3074	delivery	5	22
8370	2019-09-18 12:32:26	2019-09-18	14	[{"id_menu":2,"count":1}]	2404	pick-up	0	14
8371	2019-09-18 12:47:35	2019-09-18	12	[{"id_menu":1,"count":1}]	2572	pick-up	0	12
8372	2019-09-18 13:11:47	2019-09-18	8	[{"id_menu":5,"count":1}]	2520	pick-up	0	8
8373	2019-09-18 13:25:56	2019-09-18	8	[{"id_menu":5,"count":1}]	1645	pick-up	0	8
8374	2019-09-18 13:30:00	2019-09-18	14	[{"id_menu":2,"count":1}]	274	pick-up	0	14
8375	2019-09-18 14:31:43	2019-09-18	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1409	pick-up	0	47
8376	2019-09-18 14:44:55	2019-09-18	9	[{"id_menu":7,"count":1}]	2570	pick-up	0	9
8377	2019-09-18 14:48:19	2019-09-18	12	[{"id_menu":1,"count":1}]	2659	delivery	5	17
8378	2019-09-18 15:07:14	2019-09-18	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3072	pick-up	0	21
8379	2019-09-18 15:40:11	2019-09-18	17	[{"id_menu":4,"count":1}]	1269	pick-up	0	17
8380	2019-09-18 16:00:41	2019-09-18	9	[{"id_menu":6,"count":1}]	1996	pick-up	0	9
8381	2019-09-18 16:15:25	2019-09-18	9	[{"id_menu":6,"count":1}]	2937	pick-up	0	9
8382	2019-09-18 16:24:30	2019-09-18	9	[{"id_menu":6,"count":1}]	1604	delivery	5	14
8383	2019-09-18 16:26:04	2019-09-18	8	[{"id_menu":5,"count":1}]	2062	delivery	5	13
8384	2019-09-18 17:19:37	2019-09-18	9	[{"id_menu":7,"count":1}]	3079	delivery	5	14
8385	2019-09-18 17:25:44	2019-09-18	9	[{"id_menu":7,"count":1}]	2319	delivery	5	14
8386	2019-09-18 17:34:52	2019-09-18	17	[{"id_menu":4,"count":1}]	1088	pick-up	0	17
8387	2019-09-18 17:37:19	2019-09-18	9	[{"id_menu":7,"count":1}]	822	delivery	5	14
8388	2019-09-18 18:06:18	2019-09-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	784	pick-up	0	23
8389	2019-09-18 18:10:17	2019-09-18	8	[{"id_menu":5,"count":1}]	832	pick-up	0	8
8390	2019-09-18 18:11:06	2019-09-18	14	[{"id_menu":2,"count":1}]	933	pick-up	0	14
8391	2019-09-18 18:18:07	2019-09-18	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	71	pick-up	0	29
8392	2019-09-18 18:27:05	2019-09-18	17	[{"id_menu":4,"count":1}]	3095	pick-up	0	17
8393	2019-09-18 18:28:15	2019-09-18	14	[{"id_menu":2,"count":1}]	3070	pick-up	0	14
8394	2019-09-18 18:28:25	2019-09-18	17	[{"id_menu":4,"count":2}]	3097	delivery	5	22
8395	2019-09-18 18:28:55	2019-09-18	14	[{"id_menu":2,"count":1}]	1183	delivery	5	19
8396	2019-09-18 19:01:43	2019-09-18	9	[{"id_menu":7,"count":1}]	3087	delivery	5	14
8397	2019-09-18 19:06:06	2019-09-18	17	[{"id_menu":4,"count":1}]	3092	pick-up	0	17
8398	2019-09-18 19:36:33	2019-09-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3077	pick-up	0	23
8399	2019-09-18 20:00:50	2019-09-18	12	[{"id_menu":1,"count":1}]	1526	pick-up	0	12
8400	2019-09-18 20:33:18	2019-09-18	14	[{"id_menu":2,"count":1}]	506	delivery	5	19
8401	2019-09-18 20:35:43	2019-09-18	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	2916	pick-up	0	22
8402	2019-09-18 20:42:18	2019-09-18	14	[{"id_menu":2,"count":1}]	743	delivery	5	19
8403	2019-09-18 20:50:06	2019-09-18	8	[{"id_menu":5,"count":1}]	3088	pick-up	0	8
8404	2019-09-18 21:00:48	2019-09-18	8	[{"id_menu":5,"count":1}]	3080	pick-up	0	8
8405	2019-09-18 21:01:46	2019-09-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	160	pick-up	0	23
8406	2019-09-18 21:19:04	2019-09-18	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2100	pick-up	0	26
8407	2019-09-18 21:32:31	2019-09-18	8	[{"id_menu":5,"count":1}]	1541	pick-up	0	8
8408	2019-09-18 22:09:06	2019-09-18	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	1839	pick-up	0	24
8409	2019-09-18 22:16:27	2019-09-18	12	[{"id_menu":3,"count":1}]	1686	delivery	5	17
8410	2019-09-18 22:38:09	2019-09-18	14	[{"id_menu":2,"count":1}]	1085	pick-up	0	14
8411	2019-09-18 22:45:44	2019-09-18	9	[{"id_menu":6,"count":1}]	1936	pick-up	0	9
8412	2019-09-19 00:34:07	2019-09-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3123	delivery	5	31
8413	2019-09-19 00:55:24	2019-09-19	9	[{"id_menu":6,"count":1}]	1343	pick-up	0	9
8414	2019-09-19 01:13:31	2019-09-19	9	[{"id_menu":6,"count":1}]	3114	delivery	5	14
8415	2019-09-19 01:29:28	2019-09-19	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1481	pick-up	0	29
8416	2019-09-19 01:49:48	2019-09-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	573	pick-up	0	17
8417	2019-09-19 02:04:16	2019-09-19	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3127	delivery	5	40
8418	2019-09-19 02:12:31	2019-09-19	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1889	delivery	5	29
8419	2019-09-19 02:13:29	2019-09-19	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	3117	delivery	5	38
8420	2019-09-19 02:14:49	2019-09-19	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1843	delivery	5	35
8421	2019-09-19 02:26:12	2019-09-19	12	[{"id_menu":3,"count":2}]	3113	pick-up	0	12
8422	2019-09-19 02:33:18	2019-09-19	17	[{"id_menu":4,"count":1}]	3126	pick-up	0	17
8423	2019-09-19 02:44:02	2019-09-19	9	[{"id_menu":6,"count":1}]	1075	pick-up	0	9
8424	2019-09-19 02:48:38	2019-09-19	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1223	delivery	5	27
8425	2019-09-19 03:01:38	2019-09-19	14	[{"id_menu":2,"count":1}]	1860	delivery	5	19
8426	2019-09-19 03:19:03	2019-09-19	9	[{"id_menu":6,"count":2}]	1782	delivery	5	14
8427	2019-09-19 03:24:37	2019-09-19	12	[{"id_menu":3,"count":1}]	424	delivery	5	17
8428	2019-09-19 03:28:08	2019-09-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2519	delivery	5	23
8429	2019-09-19 03:57:22	2019-09-19	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3100	delivery	5	42
8430	2019-09-19 04:21:48	2019-09-19	12	[{"id_menu":3,"count":1}]	1507	pick-up	0	12
8431	2019-09-19 04:57:27	2019-09-19	12	[{"id_menu":1,"count":1}]	334	delivery	5	17
8432	2019-09-19 06:15:26	2019-09-19	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3118	pick-up	0	21
8433	2019-09-19 06:30:39	2019-09-19	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2796	pick-up	0	33
8434	2019-09-19 06:41:32	2019-09-19	8	[{"id_menu":5,"count":1}]	3119	delivery	5	13
8435	2019-09-19 07:07:13	2019-09-19	9	[{"id_menu":7,"count":1}]	786	pick-up	0	9
8436	2019-09-19 07:11:16	2019-09-19	8	[{"id_menu":5,"count":1}]	1380	delivery	5	13
8437	2019-09-19 07:22:15	2019-09-19	14	[{"id_menu":2,"count":1}]	2538	pick-up	0	14
8438	2019-09-19 07:46:36	2019-09-19	9	[{"id_menu":7,"count":1}]	735	delivery	5	14
8439	2019-09-19 08:02:51	2019-09-19	8	[{"id_menu":5,"count":1}]	1710	delivery	5	13
8440	2019-09-19 08:11:21	2019-09-19	17	[{"id_menu":4,"count":1}]	693	delivery	5	22
8441	2019-09-19 08:20:16	2019-09-19	9	[{"id_menu":6,"count":1}]	3108	delivery	5	14
8442	2019-09-19 08:53:15	2019-09-19	9	[{"id_menu":6,"count":1}]	2558	delivery	5	14
8443	2019-09-19 09:13:02	2019-09-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	74	delivery	5	36
8444	2019-09-19 09:20:45	2019-09-19	17	[{"id_menu":4,"count":1}]	2185	pick-up	0	17
8445	2019-09-19 09:28:03	2019-09-19	8	[{"id_menu":5,"count":1}]	1442	pick-up	0	8
8446	2019-09-19 09:49:25	2019-09-19	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2845	delivery	5	35
8447	2019-09-19 09:55:55	2019-09-19	9	[{"id_menu":7,"count":1}]	2172	pick-up	0	9
8448	2019-09-19 09:58:21	2019-09-19	12	[{"id_menu":1,"count":1}]	2760	delivery	5	17
8449	2019-09-19 10:03:19	2019-09-19	9	[{"id_menu":6,"count":1}]	171	delivery	5	14
8450	2019-09-19 10:13:07	2019-09-19	12	[{"id_menu":3,"count":1}]	2594	pick-up	0	12
8451	2019-09-19 10:39:48	2019-09-19	8	[{"id_menu":5,"count":1}]	906	delivery	5	13
8452	2019-09-19 11:40:15	2019-09-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3111	pick-up	0	31
8453	2019-09-19 11:42:13	2019-09-19	12	[{"id_menu":1,"count":1}]	356	pick-up	0	12
8454	2019-09-19 11:53:48	2019-09-19	17	[{"id_menu":4,"count":1}]	450	delivery	5	22
8455	2019-09-19 12:30:36	2019-09-19	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3105	pick-up	0	26
8456	2019-09-19 12:44:41	2019-09-19	12	[{"id_menu":1,"count":1}]	1010	delivery	5	17
8457	2019-09-19 13:31:40	2019-09-19	17	[{"id_menu":4,"count":1}]	2361	pick-up	0	17
8458	2019-09-19 13:37:20	2019-09-19	9	[{"id_menu":7,"count":1}]	3102	pick-up	0	9
8459	2019-09-19 14:09:43	2019-09-19	14	[{"id_menu":2,"count":1}]	3115	delivery	5	19
8460	2019-09-19 14:24:11	2019-09-19	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	3121	delivery	5	25
8461	2019-09-19 14:35:59	2019-09-19	9	[{"id_menu":6,"count":2}]	3120	pick-up	0	9
8462	2019-09-19 14:42:27	2019-09-19	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	487	delivery	5	40
8463	2019-09-19 14:54:23	2019-09-19	8	[{"id_menu":5,"count":1}]	3122	delivery	5	13
8464	2019-09-19 15:01:43	2019-09-19	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3106	delivery	5	34
8465	2019-09-19 15:33:58	2019-09-19	9	[{"id_menu":6,"count":1}]	3109	pick-up	0	9
8466	2019-09-19 16:10:11	2019-09-19	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2079	pick-up	0	22
8467	2019-09-19 16:55:35	2019-09-19	17	[{"id_menu":4,"count":2}]	2392	pick-up	0	17
8468	2019-09-19 17:17:39	2019-09-19	9	[{"id_menu":6,"count":1}]	1127	pick-up	0	9
8469	2019-09-19 17:24:25	2019-09-19	17	[{"id_menu":4,"count":1}]	708	delivery	5	22
8470	2019-09-19 17:27:50	2019-09-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3103	delivery	5	23
8471	2019-09-19 18:00:16	2019-09-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	372	pick-up	0	23
8472	2019-09-19 18:00:45	2019-09-19	14	[{"id_menu":2,"count":1}]	584	delivery	5	19
8473	2019-09-19 18:13:18	2019-09-19	12	[{"id_menu":1,"count":1}]	1020	pick-up	0	12
8474	2019-09-19 18:22:57	2019-09-19	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1640	pick-up	0	20
8475	2019-09-19 19:21:05	2019-09-19	8	[{"id_menu":5,"count":1}]	1557	pick-up	0	8
8476	2019-09-19 19:44:11	2019-09-19	17	[{"id_menu":4,"count":1}]	1796	pick-up	0	17
8477	2019-09-19 19:53:47	2019-09-19	8	[{"id_menu":5,"count":1}]	2709	pick-up	0	8
8478	2019-09-19 20:17:00	2019-09-19	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	425	delivery	5	45
8479	2019-09-19 20:37:56	2019-09-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	536	pick-up	0	23
8480	2019-09-19 20:53:09	2019-09-19	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1924	delivery	5	26
8481	2019-09-19 20:57:33	2019-09-19	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	931	pick-up	0	29
8482	2019-09-19 21:14:10	2019-09-19	9	[{"id_menu":6,"count":1}]	746	pick-up	0	9
8483	2019-09-19 21:24:16	2019-09-19	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	1044	pick-up	0	23
8484	2019-09-19 21:36:54	2019-09-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1445	delivery	5	23
8485	2019-09-19 21:46:44	2019-09-19	17	[{"id_menu":4,"count":1}]	3125	delivery	5	22
8486	2019-09-19 21:48:29	2019-09-19	14	[{"id_menu":2,"count":1}]	3110	delivery	5	19
8487	2019-09-19 22:09:13	2019-09-19	12	[{"id_menu":3,"count":1}]	3104	pick-up	0	12
8488	2019-09-19 22:32:09	2019-09-19	46	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	2349	delivery	5	51
8489	2019-09-19 22:43:24	2019-09-19	20	[{"id_menu":1,"count":3},{"id_menu":5,"count":1}]	2816	delivery	5	25
8490	2019-09-19 22:48:28	2019-09-19	9	[{"id_menu":6,"count":1}]	2608	pick-up	0	9
8491	2019-09-19 23:34:23	2019-09-19	14	[{"id_menu":2,"count":1}]	2668	pick-up	0	14
8492	2019-09-19 23:40:51	2019-09-19	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2126	pick-up	0	26
8493	2019-09-19 23:45:29	2019-09-19	9	[{"id_menu":6,"count":1}]	3116	delivery	5	14
8494	2019-09-20 00:35:49	2019-09-20	9	[{"id_menu":7,"count":1}]	2384	delivery	5	14
8495	2019-09-20 00:37:36	2019-09-20	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2875	pick-up	0	42
8496	2019-09-20 00:42:40	2019-09-20	8	[{"id_menu":5,"count":1}]	3128	pick-up	0	8
8497	2019-09-20 00:56:47	2019-09-20	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	148	pick-up	0	26
8498	2019-09-20 01:14:59	2019-09-20	9	[{"id_menu":6,"count":1}]	449	delivery	5	14
8499	2019-09-20 01:16:08	2019-09-20	9	[{"id_menu":6,"count":1}]	2713	pick-up	0	9
8500	2019-09-20 01:50:04	2019-09-20	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1101	pick-up	0	31
8501	2019-09-20 03:13:07	2019-09-20	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3136	delivery	5	40
8502	2019-09-20 03:19:42	2019-09-20	12	[{"id_menu":1,"count":1}]	2209	pick-up	0	12
8503	2019-09-20 04:56:20	2019-09-20	8	[{"id_menu":5,"count":1}]	3130	pick-up	0	8
8504	2019-09-20 05:30:14	2019-09-20	9	[{"id_menu":6,"count":1}]	2752	pick-up	0	9
8505	2019-09-20 05:41:40	2019-09-20	14	[{"id_menu":2,"count":1}]	2210	delivery	5	19
8506	2019-09-20 05:49:06	2019-09-20	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	3143	delivery	5	26
8507	2019-09-20 06:07:03	2019-09-20	8	[{"id_menu":5,"count":1}]	981	pick-up	0	8
8508	2019-09-20 06:19:05	2019-09-20	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2975	delivery	5	43
8509	2019-09-20 06:41:46	2019-09-20	14	[{"id_menu":2,"count":1}]	3155	pick-up	0	14
8510	2019-09-20 06:57:06	2019-09-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	351	pick-up	0	18
8511	2019-09-20 07:00:13	2019-09-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1780	pick-up	0	23
8512	2019-09-20 07:01:47	2019-09-20	17	[{"id_menu":4,"count":1}]	2272	pick-up	0	17
8513	2019-09-20 07:05:37	2019-09-20	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	135	delivery	5	35
8514	2019-09-20 07:11:11	2019-09-20	9	[{"id_menu":7,"count":1}]	722	delivery	5	14
8515	2019-09-20 07:33:51	2019-09-20	8	[{"id_menu":5,"count":1}]	117	pick-up	0	8
8516	2019-09-20 08:03:18	2019-09-20	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1731	pick-up	0	26
8517	2019-09-20 08:27:12	2019-09-20	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	466	delivery	5	31
8518	2019-09-20 08:44:44	2019-09-20	8	[{"id_menu":5,"count":1}]	3150	delivery	5	13
8519	2019-09-20 09:01:46	2019-09-20	9	[{"id_menu":7,"count":1}]	891	delivery	5	14
8520	2019-09-20 09:12:10	2019-09-20	9	[{"id_menu":6,"count":1}]	3139	delivery	5	14
8521	2019-09-20 09:28:49	2019-09-20	12	[{"id_menu":3,"count":1}]	193	delivery	5	17
8522	2019-09-20 10:15:10	2019-09-20	9	[{"id_menu":7,"count":1}]	2007	pick-up	0	9
8523	2019-09-20 10:16:16	2019-09-20	12	[{"id_menu":3,"count":1}]	1839	pick-up	0	12
8524	2019-09-20 11:26:02	2019-09-20	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1273	pick-up	0	25
8525	2019-09-20 11:41:33	2019-09-20	8	[{"id_menu":5,"count":2}]	3144	pick-up	0	8
8526	2019-09-20 12:02:07	2019-09-20	17	[{"id_menu":4,"count":1}]	3159	delivery	5	22
8527	2019-09-20 12:03:12	2019-09-20	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	2060	delivery	5	45
8528	2019-09-20 12:15:44	2019-09-20	8	[{"id_menu":5,"count":1}]	3054	pick-up	0	8
8529	2019-09-20 12:27:33	2019-09-20	12	[{"id_menu":1,"count":2}]	3160	pick-up	0	12
8530	2019-09-20 12:37:18	2019-09-20	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	3132	pick-up	0	21
8531	2019-09-20 12:59:03	2019-09-20	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	3035	pick-up	0	35
8532	2019-09-20 13:27:53	2019-09-20	12	[{"id_menu":3,"count":1}]	1813	delivery	5	17
8533	2019-09-20 13:30:29	2019-09-20	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	532	pick-up	0	38
8534	2019-09-20 13:37:22	2019-09-20	9	[{"id_menu":7,"count":1}]	3148	delivery	5	14
8535	2019-09-20 13:38:49	2019-09-20	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	3149	delivery	5	31
8536	2019-09-20 13:41:03	2019-09-20	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	2189	pick-up	0	26
8537	2019-09-20 13:47:35	2019-09-20	9	[{"id_menu":6,"count":1}]	3138	pick-up	0	9
8538	2019-09-20 14:32:13	2019-09-20	9	[{"id_menu":7,"count":1}]	1490	delivery	5	14
8539	2019-09-20 14:32:18	2019-09-20	14	[{"id_menu":2,"count":1}]	3140	delivery	5	19
8540	2019-09-20 14:37:05	2019-09-20	12	[{"id_menu":1,"count":1}]	2310	delivery	5	17
8541	2019-09-20 14:43:28	2019-09-20	14	[{"id_menu":2,"count":1}]	1531	pick-up	0	14
8542	2019-09-20 15:22:09	2019-09-20	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	2064	delivery	5	31
8543	2019-09-20 15:45:16	2019-09-20	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3133	delivery	5	27
8544	2019-09-20 15:50:48	2019-09-20	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1845	pick-up	0	26
8545	2019-09-20 16:20:42	2019-09-20	8	[{"id_menu":5,"count":1}]	3157	pick-up	0	8
8546	2019-09-20 16:49:22	2019-09-20	9	[{"id_menu":7,"count":1}]	2498	delivery	5	14
8547	2019-09-20 16:59:09	2019-09-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3131	delivery	5	23
8548	2019-09-20 17:04:30	2019-09-20	14	[{"id_menu":2,"count":1}]	1810	delivery	5	19
8549	2019-09-20 17:09:03	2019-09-20	9	[{"id_menu":7,"count":1}]	3135	pick-up	0	9
8550	2019-09-20 17:18:11	2019-09-20	12	[{"id_menu":3,"count":1}]	1241	pick-up	0	12
8551	2019-09-20 17:41:41	2019-09-20	8	[{"id_menu":5,"count":1}]	2680	pick-up	0	8
8552	2019-09-20 18:06:38	2019-09-20	9	[{"id_menu":6,"count":1}]	837	pick-up	0	9
8553	2019-09-20 19:07:57	2019-09-20	49	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1132	delivery	5	54
8554	2019-09-20 19:33:47	2019-09-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3101	delivery	5	28
8555	2019-09-20 19:49:45	2019-09-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	560	delivery	5	28
8556	2019-09-20 20:00:24	2019-09-20	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	609	pick-up	0	25
8557	2019-09-20 20:03:00	2019-09-20	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	228	pick-up	0	21
8558	2019-09-20 20:23:25	2019-09-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1250	pick-up	0	23
8559	2019-09-20 20:35:06	2019-09-20	8	[{"id_menu":5,"count":1}]	2928	pick-up	0	8
8560	2019-09-20 20:39:38	2019-09-20	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	1557	pick-up	0	38
8561	2019-09-20 20:52:38	2019-09-20	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	2793	delivery	5	26
8562	2019-09-20 21:09:14	2019-09-20	12	[{"id_menu":1,"count":1}]	1595	delivery	5	17
8563	2019-09-20 21:11:09	2019-09-20	14	[{"id_menu":2,"count":1}]	2623	pick-up	0	14
8564	2019-09-20 21:30:20	2019-09-20	17	[{"id_menu":4,"count":1}]	3152	pick-up	0	17
8565	2019-09-20 21:51:15	2019-09-20	17	[{"id_menu":4,"count":2}]	2021	pick-up	0	17
8566	2019-09-20 21:57:46	2019-09-20	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	980	pick-up	0	21
8567	2019-09-20 22:08:01	2019-09-20	12	[{"id_menu":3,"count":1}]	2351	pick-up	0	12
8568	2019-09-20 22:46:08	2019-09-20	9	[{"id_menu":7,"count":1}]	3156	delivery	5	14
8569	2019-09-20 22:54:04	2019-09-20	14	[{"id_menu":2,"count":1}]	3147	pick-up	0	14
8570	2019-09-20 22:59:11	2019-09-20	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1816	delivery	5	31
8571	2019-09-20 23:25:51	2019-09-20	9	[{"id_menu":7,"count":1}]	3145	delivery	5	14
8572	2019-09-21 00:10:13	2019-09-21	8	[{"id_menu":5,"count":1}]	3174	delivery	5	13
8573	2019-09-21 00:13:14	2019-09-21	9	[{"id_menu":7,"count":1}]	3077	pick-up	0	9
8574	2019-09-21 00:28:25	2019-09-21	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	293	pick-up	0	20
8575	2019-09-21 01:44:08	2019-09-21	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	126	pick-up	0	25
8576	2019-09-21 03:24:38	2019-09-21	14	[{"id_menu":2,"count":1}]	3173	delivery	5	19
8577	2019-09-21 03:26:02	2019-09-21	14	[{"id_menu":2,"count":1}]	3178	delivery	5	19
8578	2019-09-21 03:30:50	2019-09-21	8	[{"id_menu":5,"count":1}]	2501	pick-up	0	8
8579	2019-09-21 03:31:11	2019-09-21	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1272	delivery	5	25
8580	2019-09-21 03:42:14	2019-09-21	12	[{"id_menu":1,"count":1}]	3181	delivery	5	17
8581	2019-09-21 03:43:06	2019-09-21	8	[{"id_menu":5,"count":2}]	2050	pick-up	0	8
8582	2019-09-21 04:16:10	2019-09-21	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	292	delivery	5	25
8583	2019-09-21 05:23:22	2019-09-21	17	[{"id_menu":4,"count":1}]	291	pick-up	0	17
8584	2019-09-21 05:24:22	2019-09-21	9	[{"id_menu":7,"count":1}]	820	pick-up	0	9
8585	2019-09-21 05:42:06	2019-09-21	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	3176	pick-up	0	31
8586	2019-09-21 05:57:01	2019-09-21	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3188	delivery	5	36
8587	2019-09-21 06:04:39	2019-09-21	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	2457	delivery	5	25
8588	2019-09-21 06:14:53	2019-09-21	9	[{"id_menu":7,"count":1}]	308	pick-up	0	9
8589	2019-09-21 06:18:47	2019-09-21	14	[{"id_menu":2,"count":1}]	972	delivery	5	19
8590	2019-09-21 06:29:01	2019-09-21	17	[{"id_menu":4,"count":1}]	3170	delivery	5	22
8591	2019-09-21 06:30:38	2019-09-21	8	[{"id_menu":5,"count":1}]	270	pick-up	0	8
8592	2019-09-21 06:37:50	2019-09-21	9	[{"id_menu":6,"count":1}]	1742	pick-up	0	9
8593	2019-09-21 06:40:54	2019-09-21	12	[{"id_menu":1,"count":1}]	2594	pick-up	0	12
8594	2019-09-21 06:59:54	2019-09-21	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	2111	delivery	5	23
8595	2019-09-21 07:09:03	2019-09-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1137	pick-up	0	23
8596	2019-09-21 07:31:51	2019-09-21	12	[{"id_menu":3,"count":2}]	211	pick-up	0	12
8597	2019-09-21 07:47:12	2019-09-21	9	[{"id_menu":6,"count":1}]	1669	delivery	5	14
8598	2019-09-21 07:54:20	2019-09-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	1820	pick-up	0	23
8599	2019-09-21 07:55:31	2019-09-21	9	[{"id_menu":7,"count":2}]	3166	delivery	5	14
8600	2019-09-21 07:56:51	2019-09-21	12	[{"id_menu":3,"count":1}]	3051	pick-up	0	12
8601	2019-09-21 08:00:28	2019-09-21	12	[{"id_menu":1,"count":1}]	1529	pick-up	0	12
8602	2019-09-21 08:02:03	2019-09-21	14	[{"id_menu":2,"count":2}]	1484	pick-up	0	14
8603	2019-09-21 08:13:12	2019-09-21	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1358	pick-up	0	21
8604	2019-09-21 08:16:08	2019-09-21	12	[{"id_menu":3,"count":1}]	2572	pick-up	0	12
8605	2019-09-21 08:28:18	2019-09-21	17	[{"id_menu":4,"count":1}]	3185	delivery	5	22
8606	2019-09-21 08:40:46	2019-09-21	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	3163	pick-up	0	20
8607	2019-09-21 08:50:21	2019-09-21	9	[{"id_menu":7,"count":1}]	70	delivery	5	14
8608	2019-09-21 09:05:57	2019-09-21	14	[{"id_menu":2,"count":1}]	1309	pick-up	0	14
8609	2019-09-21 09:19:18	2019-09-21	17	[{"id_menu":4,"count":1}]	3169	delivery	5	22
8610	2019-09-21 09:39:56	2019-09-21	17	[{"id_menu":4,"count":1}]	1693	delivery	5	22
8611	2019-09-21 10:03:32	2019-09-21	14	[{"id_menu":2,"count":1}]	323	delivery	5	19
8612	2019-09-21 10:47:05	2019-09-21	17	[{"id_menu":4,"count":1}]	659	pick-up	0	17
8613	2019-09-21 10:48:55	2019-09-21	14	[{"id_menu":2,"count":1}]	2636	pick-up	0	14
8614	2019-09-21 11:02:31	2019-09-21	12	[{"id_menu":3,"count":1}]	3179	pick-up	0	12
8615	2019-09-21 11:17:32	2019-09-21	14	[{"id_menu":2,"count":1}]	2628	pick-up	0	14
8616	2019-09-21 11:35:49	2019-09-21	17	[{"id_menu":4,"count":1}]	2193	pick-up	0	17
8617	2019-09-21 11:50:26	2019-09-21	12	[{"id_menu":1,"count":1}]	3184	delivery	5	17
8618	2019-09-21 11:55:12	2019-09-21	14	[{"id_menu":2,"count":1}]	371	delivery	5	19
8619	2019-09-21 12:09:32	2019-09-21	17	[{"id_menu":4,"count":1}]	1772	pick-up	0	17
8620	2019-09-21 12:14:17	2019-09-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2933	delivery	5	22
8621	2019-09-21 12:39:23	2019-09-21	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	3187	delivery	5	23
8622	2019-09-21 12:51:08	2019-09-21	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	547	pick-up	0	29
8623	2019-09-21 13:11:59	2019-09-21	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1453	delivery	5	29
8624	2019-09-21 13:32:19	2019-09-21	17	[{"id_menu":4,"count":1}]	766	pick-up	0	17
8625	2019-09-21 13:41:46	2019-09-21	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2217	pick-up	0	26
8626	2019-09-21 14:03:54	2019-09-21	9	[{"id_menu":7,"count":2}]	3189	pick-up	0	9
8627	2019-09-21 14:07:52	2019-09-21	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	3165	delivery	5	34
8628	2019-09-21 14:10:47	2019-09-21	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	342	delivery	5	26
8629	2019-09-21 14:24:38	2019-09-21	17	[{"id_menu":4,"count":1}]	2161	pick-up	0	17
8630	2019-09-21 14:32:52	2019-09-21	12	[{"id_menu":1,"count":1}]	313	delivery	5	17
8631	2019-09-21 14:43:53	2019-09-21	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3182	delivery	5	34
8632	2019-09-21 14:53:08	2019-09-21	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	634	pick-up	0	22
8633	2019-09-21 15:05:19	2019-09-21	12	[{"id_menu":1,"count":2}]	1019	pick-up	0	12
8634	2019-09-21 15:26:53	2019-09-21	17	[{"id_menu":4,"count":1}]	1155	delivery	5	22
8635	2019-09-21 15:45:19	2019-09-21	12	[{"id_menu":1,"count":1}]	158	pick-up	0	12
8636	2019-09-21 16:10:12	2019-09-21	12	[{"id_menu":1,"count":1}]	847	pick-up	0	12
8637	2019-09-21 16:11:46	2019-09-21	9	[{"id_menu":7,"count":1}]	3180	pick-up	0	9
8638	2019-09-21 16:12:20	2019-09-21	12	[{"id_menu":3,"count":1}]	3162	delivery	5	17
8639	2019-09-21 16:16:40	2019-09-21	14	[{"id_menu":2,"count":1}]	310	delivery	5	19
8640	2019-09-21 16:57:18	2019-09-21	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	665	pick-up	0	22
8641	2019-09-21 17:14:27	2019-09-21	14	[{"id_menu":2,"count":1}]	1280	pick-up	0	14
8642	2019-09-21 17:34:12	2019-09-21	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	3168	pick-up	0	21
8643	2019-09-21 17:53:42	2019-09-21	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1938	pick-up	0	41
8644	2019-09-21 18:03:10	2019-09-21	14	[{"id_menu":2,"count":1}]	1687	delivery	5	19
8645	2019-09-21 18:09:55	2019-09-21	9	[{"id_menu":6,"count":1}]	2824	pick-up	0	9
8646	2019-09-21 18:12:18	2019-09-21	14	[{"id_menu":2,"count":1}]	2357	delivery	5	19
8647	2019-09-21 18:30:41	2019-09-21	8	[{"id_menu":5,"count":2}]	3186	pick-up	0	8
8648	2019-09-21 19:37:26	2019-09-21	14	[{"id_menu":2,"count":2}]	1760	delivery	5	19
8649	2019-09-21 19:43:03	2019-09-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1563	pick-up	0	23
8650	2019-09-21 20:31:26	2019-09-21	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	3190	pick-up	0	20
8651	2019-09-21 20:33:49	2019-09-21	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	3183	delivery	5	26
8652	2019-09-21 20:39:52	2019-09-21	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	3175	delivery	5	31
8653	2019-09-21 20:49:36	2019-09-21	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3172	pick-up	0	31
8654	2019-09-21 21:43:27	2019-09-21	12	[{"id_menu":1,"count":1}]	233	pick-up	0	12
8655	2019-09-21 21:58:15	2019-09-21	9	[{"id_menu":6,"count":1}]	3119	delivery	5	14
8656	2019-09-21 22:02:13	2019-09-21	9	[{"id_menu":7,"count":1}]	719	pick-up	0	9
8657	2019-09-21 22:20:40	2019-09-21	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	557	delivery	5	34
8658	2019-09-21 22:28:44	2019-09-21	14	[{"id_menu":2,"count":1}]	1025	pick-up	0	14
8659	2019-09-21 22:37:59	2019-09-21	8	[{"id_menu":5,"count":1}]	1222	pick-up	0	8
8660	2019-09-21 22:43:01	2019-09-21	14	[{"id_menu":2,"count":1}]	3167	pick-up	0	14
8661	2019-09-21 22:54:32	2019-09-21	9	[{"id_menu":7,"count":1}]	2052	pick-up	0	9
8662	2019-09-21 22:56:06	2019-09-21	9	[{"id_menu":7,"count":1}]	709	pick-up	0	9
8663	2019-09-21 23:30:57	2019-09-21	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	1281	delivery	5	27
8664	2019-09-21 23:36:43	2019-09-21	9	[{"id_menu":6,"count":1}]	1514	delivery	5	14
8665	2019-09-21 23:50:58	2019-09-21	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	304	pick-up	0	26
8666	2019-09-21 23:58:57	2019-09-21	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3171	delivery	5	34
8667	2019-09-22 01:01:34	2019-09-22	14	[{"id_menu":2,"count":1}]	3217	delivery	5	19
8668	2019-09-22 01:09:41	2019-09-22	8	[{"id_menu":5,"count":1}]	2752	pick-up	0	8
8669	2019-09-22 01:22:01	2019-09-22	9	[{"id_menu":7,"count":1}]	3193	delivery	5	14
8670	2019-09-22 01:22:19	2019-09-22	8	[{"id_menu":5,"count":1}]	3192	pick-up	0	8
8671	2019-09-22 01:37:32	2019-09-22	9	[{"id_menu":6,"count":1}]	2897	pick-up	0	9
8672	2019-09-22 01:45:42	2019-09-22	12	[{"id_menu":3,"count":1}]	78	pick-up	0	12
8673	2019-09-22 01:54:36	2019-09-22	14	[{"id_menu":2,"count":1}]	1106	pick-up	0	14
8674	2019-09-22 01:57:46	2019-09-22	8	[{"id_menu":5,"count":1}]	3204	delivery	5	13
8675	2019-09-22 02:12:37	2019-09-22	17	[{"id_menu":4,"count":1}]	3194	delivery	5	22
8676	2019-09-22 02:14:09	2019-09-22	14	[{"id_menu":2,"count":1}]	1581	pick-up	0	14
8677	2019-09-22 02:24:35	2019-09-22	12	[{"id_menu":3,"count":1}]	1314	pick-up	0	12
8678	2019-09-22 02:29:35	2019-09-22	12	[{"id_menu":1,"count":2}]	3215	pick-up	0	12
8679	2019-09-22 02:34:13	2019-09-22	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1797	pick-up	0	20
8680	2019-09-22 03:04:05	2019-09-22	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1072	pick-up	0	38
8681	2019-09-22 03:50:52	2019-09-22	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3220	delivery	5	53
8682	2019-09-22 03:51:40	2019-09-22	14	[{"id_menu":2,"count":1}]	171	pick-up	0	14
8683	2019-09-22 04:03:00	2019-09-22	14	[{"id_menu":2,"count":1}]	3057	delivery	5	19
8684	2019-09-22 04:24:31	2019-09-22	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	695	pick-up	0	26
8685	2019-09-22 04:49:08	2019-09-22	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3212	delivery	5	44
8686	2019-09-22 04:51:25	2019-09-22	9	[{"id_menu":6,"count":1}]	3195	delivery	5	14
8687	2019-09-22 04:52:48	2019-09-22	9	[{"id_menu":7,"count":1}]	3199	delivery	5	14
8688	2019-09-22 05:27:58	2019-09-22	9	[{"id_menu":6,"count":1}]	92	delivery	5	14
8689	2019-09-22 05:38:35	2019-09-22	8	[{"id_menu":5,"count":1}]	2392	pick-up	0	8
8690	2019-09-22 05:42:47	2019-09-22	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	3198	pick-up	0	26
8691	2019-09-22 06:06:39	2019-09-22	8	[{"id_menu":5,"count":1}]	1956	pick-up	0	8
8692	2019-09-22 06:07:26	2019-09-22	17	[{"id_menu":4,"count":1}]	456	pick-up	0	17
8693	2019-09-22 06:08:09	2019-09-22	9	[{"id_menu":6,"count":1}]	3207	pick-up	0	9
8694	2019-09-22 06:18:00	2019-09-22	12	[{"id_menu":1,"count":1}]	489	pick-up	0	12
8695	2019-09-22 06:22:06	2019-09-22	14	[{"id_menu":2,"count":1}]	1670	delivery	5	19
8696	2019-09-22 06:26:07	2019-09-22	14	[{"id_menu":2,"count":1}]	2621	delivery	5	19
8697	2019-09-22 06:26:25	2019-09-22	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3213	delivery	5	27
8698	2019-09-22 06:35:29	2019-09-22	8	[{"id_menu":5,"count":2}]	2630	delivery	5	13
8699	2019-09-22 06:47:01	2019-09-22	14	[{"id_menu":2,"count":1}]	3219	pick-up	0	14
8700	2019-09-22 06:51:57	2019-09-22	9	[{"id_menu":6,"count":1}]	3202	delivery	5	14
8701	2019-09-22 07:01:24	2019-09-22	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3197	delivery	5	45
8702	2019-09-22 07:03:36	2019-09-22	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3146	pick-up	0	33
8703	2019-09-22 07:22:00	2019-09-22	9	[{"id_menu":6,"count":1}]	2078	pick-up	0	9
8704	2019-09-22 07:24:06	2019-09-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2134	delivery	5	36
8705	2019-09-22 07:35:09	2019-09-22	14	[{"id_menu":2,"count":2}]	2189	delivery	5	19
8706	2019-09-22 07:45:14	2019-09-22	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	91	delivery	5	25
8707	2019-09-22 07:50:30	2019-09-22	12	[{"id_menu":3,"count":1}]	2224	pick-up	0	12
8708	2019-09-22 08:03:24	2019-09-22	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3223	delivery	5	34
8709	2019-09-22 08:05:11	2019-09-22	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	1742	pick-up	0	29
8710	2019-09-22 08:38:05	2019-09-22	9	[{"id_menu":7,"count":1}]	721	pick-up	0	9
8711	2019-09-22 08:46:06	2019-09-22	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	806	delivery	5	34
8712	2019-09-22 09:16:19	2019-09-22	9	[{"id_menu":7,"count":1}]	3206	pick-up	0	9
8713	2019-09-22 09:24:35	2019-09-22	14	[{"id_menu":2,"count":1}]	981	delivery	5	19
8714	2019-09-22 09:27:26	2019-09-22	9	[{"id_menu":6,"count":1}]	763	pick-up	0	9
8715	2019-09-22 09:36:40	2019-09-22	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2618	pick-up	0	20
8716	2019-09-22 09:40:10	2019-09-22	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	2025	pick-up	0	21
8717	2019-09-22 09:41:06	2019-09-22	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1160	delivery	5	31
8718	2019-09-22 09:52:09	2019-09-22	8	[{"id_menu":5,"count":1}]	2715	delivery	5	13
8719	2019-09-22 10:09:01	2019-09-22	12	[{"id_menu":1,"count":1}]	3191	pick-up	0	12
8720	2019-09-22 10:18:05	2019-09-22	9	[{"id_menu":7,"count":1}]	3210	delivery	5	14
8721	2019-09-22 10:29:06	2019-09-22	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1053	pick-up	0	24
8722	2019-09-22 10:31:16	2019-09-22	12	[{"id_menu":1,"count":1}]	1015	pick-up	0	12
8723	2019-09-22 10:33:24	2019-09-22	17	[{"id_menu":4,"count":1}]	1023	delivery	5	22
8724	2019-09-22 10:37:54	2019-09-22	17	[{"id_menu":4,"count":1}]	2711	delivery	5	22
8725	2019-09-22 10:58:31	2019-09-22	8	[{"id_menu":5,"count":1}]	1896	pick-up	0	8
8726	2019-09-22 11:04:19	2019-09-22	9	[{"id_menu":7,"count":1}]	778	pick-up	0	9
8727	2019-09-22 11:15:11	2019-09-22	9	[{"id_menu":7,"count":1}]	3218	delivery	5	14
8728	2019-09-22 11:34:36	2019-09-22	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	3224	pick-up	0	26
8729	2019-09-22 11:43:14	2019-09-22	9	[{"id_menu":7,"count":1}]	856	pick-up	0	9
8730	2019-09-22 11:46:48	2019-09-22	14	[{"id_menu":2,"count":1}]	2082	delivery	5	19
8731	2019-09-22 11:48:41	2019-09-22	17	[{"id_menu":4,"count":1}]	2464	pick-up	0	17
8732	2019-09-22 12:16:07	2019-09-22	12	[{"id_menu":3,"count":1}]	76	pick-up	0	12
8733	2019-09-22 12:28:49	2019-09-22	8	[{"id_menu":5,"count":1}]	3203	delivery	5	13
8734	2019-09-22 12:31:36	2019-09-22	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3200	delivery	5	22
8735	2019-09-22 12:32:07	2019-09-22	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	964	delivery	5	22
8736	2019-09-22 12:38:29	2019-09-22	17	[{"id_menu":4,"count":1}]	729	pick-up	0	17
8737	2019-09-22 13:24:57	2019-09-22	17	[{"id_menu":4,"count":1}]	304	pick-up	0	17
8738	2019-09-22 13:30:06	2019-09-22	14	[{"id_menu":2,"count":1}]	2602	pick-up	0	14
8739	2019-09-22 13:31:44	2019-09-22	17	[{"id_menu":4,"count":1}]	490	delivery	5	22
8740	2019-09-22 13:36:49	2019-09-22	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	631	delivery	5	40
8741	2019-09-22 13:38:57	2019-09-22	14	[{"id_menu":2,"count":1}]	3225	pick-up	0	14
8742	2019-09-22 13:40:01	2019-09-22	8	[{"id_menu":5,"count":1}]	786	pick-up	0	8
8743	2019-09-22 14:02:25	2019-09-22	9	[{"id_menu":6,"count":1}]	1998	pick-up	0	9
8744	2019-09-22 14:03:56	2019-09-22	17	[{"id_menu":4,"count":1}]	1228	pick-up	0	17
8745	2019-09-22 14:19:31	2019-09-22	8	[{"id_menu":5,"count":1}]	1421	pick-up	0	8
8746	2019-09-22 14:26:43	2019-09-22	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2420	pick-up	0	52
8747	2019-09-22 15:07:09	2019-09-22	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1390	pick-up	0	34
8748	2019-09-22 15:30:25	2019-09-22	12	[{"id_menu":3,"count":1}]	2407	delivery	5	17
8749	2019-09-22 15:50:33	2019-09-22	9	[{"id_menu":7,"count":1}]	371	pick-up	0	9
8750	2019-09-22 15:58:03	2019-09-22	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3221	delivery	5	22
8751	2019-09-22 16:06:04	2019-09-22	17	[{"id_menu":4,"count":1}]	825	delivery	5	22
8752	2019-09-22 16:11:07	2019-09-22	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1767	pick-up	0	29
8753	2019-09-22 16:16:30	2019-09-22	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	382	pick-up	0	35
8754	2019-09-22 17:03:06	2019-09-22	34	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3211	delivery	5	39
8755	2019-09-22 17:10:44	2019-09-22	17	[{"id_menu":4,"count":1}]	2419	pick-up	0	17
8756	2019-09-22 17:10:51	2019-09-22	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	583	delivery	5	31
8757	2019-09-22 17:24:58	2019-09-22	9	[{"id_menu":7,"count":1}]	581	delivery	5	14
8758	2019-09-22 17:49:28	2019-09-22	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	818	pick-up	0	49
8759	2019-09-22 18:18:44	2019-09-22	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1679	pick-up	0	21
8760	2019-09-22 18:27:20	2019-09-22	9	[{"id_menu":7,"count":1}]	909	delivery	5	14
8761	2019-09-22 18:31:58	2019-09-22	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	229	pick-up	0	21
8762	2019-09-22 18:46:01	2019-09-22	17	[{"id_menu":4,"count":2}]	3214	pick-up	0	17
8763	2019-09-22 18:46:22	2019-09-22	9	[{"id_menu":7,"count":1}]	2627	pick-up	0	9
8764	2019-09-22 19:00:13	2019-09-22	14	[{"id_menu":2,"count":1}]	3216	delivery	5	19
8765	2019-09-22 19:06:47	2019-09-22	8	[{"id_menu":5,"count":1}]	2845	delivery	5	13
8766	2019-09-22 19:13:56	2019-09-22	12	[{"id_menu":3,"count":1}]	3201	pick-up	0	12
8767	2019-09-22 19:33:24	2019-09-22	14	[{"id_menu":2,"count":1}]	271	pick-up	0	14
8768	2019-09-22 19:50:38	2019-09-22	12	[{"id_menu":1,"count":1}]	2564	pick-up	0	12
8769	2019-09-22 20:03:59	2019-09-22	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3209	delivery	5	22
8770	2019-09-22 20:29:51	2019-09-22	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	3208	delivery	5	39
8771	2019-09-22 21:21:41	2019-09-22	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	3205	delivery	5	25
8772	2019-09-22 21:25:35	2019-09-22	14	[{"id_menu":2,"count":1}]	3222	pick-up	0	14
8773	2019-09-22 21:41:09	2019-09-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1522	pick-up	0	23
8774	2019-09-22 21:54:11	2019-09-22	12	[{"id_menu":1,"count":1}]	482	delivery	5	17
8775	2019-09-22 22:38:35	2019-09-22	9	[{"id_menu":7,"count":2}]	3196	pick-up	0	9
8776	2019-09-22 22:48:41	2019-09-22	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	1638	delivery	5	42
8777	2019-09-22 23:29:04	2019-09-22	9	[{"id_menu":6,"count":2}]	1761	pick-up	0	9
8778	2019-09-22 23:41:12	2019-09-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1293	delivery	5	22
8779	2019-09-23 00:06:47	2019-09-23	17	[{"id_menu":4,"count":1}]	2190	pick-up	0	17
8780	2019-09-23 00:23:58	2019-09-23	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1492	pick-up	0	17
8781	2019-09-23 01:29:07	2019-09-23	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	3240	delivery	5	40
8782	2019-09-23 01:56:25	2019-09-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3231	delivery	5	23
8783	2019-09-23 02:50:32	2019-09-23	14	[{"id_menu":2,"count":2}]	3249	delivery	5	19
8784	2019-09-23 03:37:50	2019-09-23	9	[{"id_menu":7,"count":1}]	1165	pick-up	0	9
8785	2019-09-23 04:38:59	2019-09-23	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	534	pick-up	0	37
8786	2019-09-23 05:00:53	2019-09-23	9	[{"id_menu":6,"count":1}]	229	delivery	5	14
8787	2019-09-23 05:05:21	2019-09-23	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	2799	pick-up	0	20
8788	2019-09-23 05:29:21	2019-09-23	9	[{"id_menu":7,"count":1}]	3073	delivery	5	14
8789	2019-09-23 06:25:20	2019-09-23	14	[{"id_menu":2,"count":1}]	3234	delivery	5	19
8790	2019-09-23 06:36:36	2019-09-23	17	[{"id_menu":4,"count":1}]	3052	pick-up	0	17
8791	2019-09-23 07:08:15	2019-09-23	14	[{"id_menu":2,"count":1}]	3245	delivery	5	19
8792	2019-09-23 07:19:59	2019-09-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1970	pick-up	0	26
8793	2019-09-23 07:26:15	2019-09-23	9	[{"id_menu":7,"count":1}]	1919	delivery	5	14
8794	2019-09-23 07:32:00	2019-09-23	12	[{"id_menu":3,"count":1}]	541	pick-up	0	12
8795	2019-09-23 07:54:23	2019-09-23	9	[{"id_menu":7,"count":1}]	655	pick-up	0	9
8796	2019-09-23 08:42:03	2019-09-23	14	[{"id_menu":2,"count":1}]	639	delivery	5	19
8797	2019-09-23 08:47:13	2019-09-23	17	[{"id_menu":4,"count":1}]	169	pick-up	0	17
8798	2019-09-23 09:47:32	2019-09-23	9	[{"id_menu":7,"count":1}]	826	pick-up	0	9
8799	2019-09-23 10:49:47	2019-09-23	12	[{"id_menu":3,"count":1}]	71	delivery	5	17
8800	2019-09-23 11:24:11	2019-09-23	9	[{"id_menu":6,"count":1}]	1037	delivery	5	14
8801	2019-09-23 11:38:27	2019-09-23	12	[{"id_menu":3,"count":1}]	1367	pick-up	0	12
8802	2019-09-23 11:57:26	2019-09-23	17	[{"id_menu":4,"count":1}]	2776	pick-up	0	17
8803	2019-09-23 12:14:03	2019-09-23	14	[{"id_menu":2,"count":1}]	2367	pick-up	0	14
8804	2019-09-23 12:36:10	2019-09-23	9	[{"id_menu":6,"count":1}]	27	pick-up	0	9
8805	2019-09-23 13:13:12	2019-09-23	12	[{"id_menu":3,"count":1}]	3226	delivery	5	17
8806	2019-09-23 14:16:14	2019-09-23	14	[{"id_menu":2,"count":1}]	2673	delivery	5	19
8807	2019-09-23 14:25:32	2019-09-23	12	[{"id_menu":1,"count":1}]	906	pick-up	0	12
8808	2019-09-23 14:51:23	2019-09-23	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	2277	pick-up	0	21
8809	2019-09-23 14:57:39	2019-09-23	9	[{"id_menu":7,"count":1}]	2537	delivery	5	14
8810	2019-09-23 15:09:26	2019-09-23	14	[{"id_menu":2,"count":1}]	2530	delivery	5	19
8811	2019-09-23 15:30:42	2019-09-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3238	delivery	5	23
8812	2019-09-23 15:38:33	2019-09-23	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	1942	delivery	5	43
8813	2019-09-23 15:53:33	2019-09-23	9	[{"id_menu":6,"count":1}]	749	pick-up	0	9
8814	2019-09-23 16:21:20	2019-09-23	9	[{"id_menu":6,"count":1}]	3242	pick-up	0	9
8815	2019-09-23 17:02:03	2019-09-23	9	[{"id_menu":6,"count":1}]	1244	delivery	5	14
8816	2019-09-23 17:04:45	2019-09-23	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3227	pick-up	0	35
8817	2019-09-23 17:09:25	2019-09-23	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1700	pick-up	0	26
8818	2019-09-23 17:41:18	2019-09-23	9	[{"id_menu":7,"count":1}]	2897	delivery	5	14
8819	2019-09-23 17:57:03	2019-09-23	9	[{"id_menu":7,"count":1}]	2352	pick-up	0	9
8820	2019-09-23 18:05:00	2019-09-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1625	delivery	5	28
8821	2019-09-23 18:06:52	2019-09-23	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	575	pick-up	0	35
8822	2019-09-23 18:29:06	2019-09-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3235	delivery	5	23
8823	2019-09-23 19:34:22	2019-09-23	9	[{"id_menu":7,"count":1}]	3237	delivery	5	14
8824	2019-09-23 19:48:51	2019-09-23	9	[{"id_menu":6,"count":1}]	1344	delivery	5	14
8825	2019-09-23 19:49:32	2019-09-23	17	[{"id_menu":4,"count":1}]	3239	delivery	5	22
8826	2019-09-23 19:50:32	2019-09-23	9	[{"id_menu":7,"count":1}]	1080	delivery	5	14
8827	2019-09-23 20:59:50	2019-09-23	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2694	delivery	5	51
8828	2019-09-23 21:36:17	2019-09-23	9	[{"id_menu":7,"count":1}]	2345	pick-up	0	9
8829	2019-09-23 22:00:01	2019-09-23	14	[{"id_menu":2,"count":1}]	3232	delivery	5	19
8830	2019-09-23 22:00:46	2019-09-23	17	[{"id_menu":4,"count":1}]	628	delivery	5	22
8831	2019-09-23 22:03:49	2019-09-23	12	[{"id_menu":3,"count":1}]	3251	pick-up	0	12
8832	2019-09-23 22:35:32	2019-09-23	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	19	pick-up	0	26
8833	2019-09-23 23:11:15	2019-09-23	17	[{"id_menu":4,"count":1}]	1496	pick-up	0	17
8834	2019-09-23 23:13:35	2019-09-23	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2731	pick-up	0	26
8835	2019-09-24 00:25:43	2019-09-24	12	[{"id_menu":3,"count":1}]	660	pick-up	0	12
8836	2019-09-24 00:52:57	2019-09-24	8	[{"id_menu":5,"count":1}]	788	pick-up	0	8
8837	2019-09-24 02:40:42	2019-09-24	17	[{"id_menu":4,"count":1}]	2256	pick-up	0	17
8838	2019-09-24 02:42:40	2019-09-24	12	[{"id_menu":1,"count":1}]	2630	pick-up	0	12
8839	2019-09-24 02:48:05	2019-09-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	431	pick-up	0	23
8840	2019-09-24 02:54:13	2019-09-24	17	[{"id_menu":4,"count":1}]	3278	delivery	5	22
8841	2019-09-24 03:19:20	2019-09-24	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":2}]	32	pick-up	0	26
8842	2019-09-24 03:39:38	2019-09-24	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	318	delivery	5	43
8843	2019-09-24 03:42:48	2019-09-24	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1570	delivery	5	40
8844	2019-09-24 05:09:34	2019-09-24	17	[{"id_menu":4,"count":1}]	3268	pick-up	0	17
8845	2019-09-24 05:18:51	2019-09-24	8	[{"id_menu":5,"count":1}]	3263	pick-up	0	8
8846	2019-09-24 05:22:45	2019-09-24	14	[{"id_menu":2,"count":1}]	3255	pick-up	0	14
8847	2019-09-24 05:33:59	2019-09-24	9	[{"id_menu":6,"count":1}]	2384	delivery	5	14
8848	2019-09-24 06:15:38	2019-09-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3254	delivery	5	31
8849	2019-09-24 06:23:53	2019-09-24	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	3256	delivery	5	31
8850	2019-09-24 06:57:29	2019-09-24	9	[{"id_menu":7,"count":2}]	1526	delivery	5	14
8851	2019-09-24 07:01:32	2019-09-24	14	[{"id_menu":2,"count":1}]	3273	pick-up	0	14
8852	2019-09-24 07:03:32	2019-09-24	14	[{"id_menu":2,"count":1}]	3262	delivery	5	19
8853	2019-09-24 07:04:56	2019-09-24	12	[{"id_menu":3,"count":1}]	1929	pick-up	0	12
8854	2019-09-24 08:10:30	2019-09-24	9	[{"id_menu":6,"count":2}]	813	delivery	5	14
8855	2019-09-24 08:52:14	2019-09-24	14	[{"id_menu":2,"count":1}]	21	pick-up	0	14
8856	2019-09-24 08:53:35	2019-09-24	17	[{"id_menu":4,"count":1}]	1435	pick-up	0	17
8857	2019-09-24 09:23:30	2019-09-24	9	[{"id_menu":7,"count":2}]	2272	pick-up	0	9
8858	2019-09-24 10:04:57	2019-09-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1140	pick-up	0	23
8859	2019-09-24 10:17:25	2019-09-24	9	[{"id_menu":6,"count":1}]	2608	pick-up	0	9
8860	2019-09-24 10:21:23	2019-09-24	12	[{"id_menu":1,"count":1}]	2435	pick-up	0	12
8861	2019-09-24 10:26:10	2019-09-24	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	3272	delivery	5	26
8862	2019-09-24 10:50:33	2019-09-24	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1819	pick-up	0	40
8863	2019-09-24 11:59:31	2019-09-24	9	[{"id_menu":7,"count":1}]	2386	delivery	5	14
8864	2019-09-24 12:28:08	2019-09-24	14	[{"id_menu":2,"count":1}]	2310	delivery	5	19
8865	2019-09-24 12:43:57	2019-09-24	17	[{"id_menu":4,"count":1}]	67	delivery	5	22
8866	2019-09-24 12:54:30	2019-09-24	9	[{"id_menu":6,"count":1}]	2373	pick-up	0	9
8867	2019-09-24 14:20:02	2019-09-24	14	[{"id_menu":2,"count":1}]	2007	delivery	5	19
8868	2019-09-24 15:07:57	2019-09-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2734	delivery	5	22
8869	2019-09-24 15:19:00	2019-09-24	17	[{"id_menu":4,"count":1}]	3274	pick-up	0	17
8870	2019-09-24 15:21:09	2019-09-24	12	[{"id_menu":1,"count":1}]	3275	pick-up	0	12
8871	2019-09-24 15:24:11	2019-09-24	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	2868	delivery	5	22
8872	2019-09-24 16:03:27	2019-09-24	9	[{"id_menu":7,"count":1}]	734	pick-up	0	9
8873	2019-09-24 16:38:52	2019-09-24	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2662	delivery	5	34
8874	2019-09-24 16:44:38	2019-09-24	17	[{"id_menu":4,"count":1}]	1302	pick-up	0	17
8875	2019-09-24 16:55:06	2019-09-24	12	[{"id_menu":1,"count":1}]	2107	pick-up	0	12
8876	2019-09-24 17:46:04	2019-09-24	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3270	pick-up	0	31
8877	2019-09-24 17:56:51	2019-09-24	17	[{"id_menu":4,"count":1}]	2683	delivery	5	22
8878	2019-09-24 18:00:33	2019-09-24	9	[{"id_menu":7,"count":1}]	3267	delivery	5	14
8879	2019-09-24 18:31:10	2019-09-24	12	[{"id_menu":1,"count":1}]	1513	pick-up	0	12
8880	2019-09-24 18:45:09	2019-09-24	12	[{"id_menu":3,"count":1}]	2056	delivery	5	17
8881	2019-09-24 18:57:03	2019-09-24	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1310	delivery	5	43
8882	2019-09-24 19:56:08	2019-09-24	14	[{"id_menu":2,"count":1}]	3069	delivery	5	19
8883	2019-09-24 20:01:12	2019-09-24	12	[{"id_menu":1,"count":1}]	235	pick-up	0	12
8884	2019-09-24 20:03:01	2019-09-24	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3266	delivery	5	30
8885	2019-09-24 20:04:43	2019-09-24	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3265	pick-up	0	17
8886	2019-09-24 20:09:40	2019-09-24	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	2197	delivery	5	28
8887	2019-09-24 21:21:02	2019-09-24	9	[{"id_menu":6,"count":1}]	3271	delivery	5	14
8888	2019-09-24 21:27:44	2019-09-24	9	[{"id_menu":6,"count":1}]	2416	pick-up	0	9
8889	2019-09-24 21:35:39	2019-09-24	12	[{"id_menu":1,"count":1}]	3258	delivery	5	17
8890	2019-09-24 21:36:22	2019-09-24	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1289	pick-up	0	21
8891	2019-09-24 21:52:44	2019-09-24	9	[{"id_menu":6,"count":1}]	3261	delivery	5	14
8892	2019-09-24 21:54:49	2019-09-24	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	3037	delivery	5	25
8893	2019-09-24 21:57:19	2019-09-24	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	171	pick-up	0	29
8894	2019-09-24 21:59:24	2019-09-24	17	[{"id_menu":4,"count":1}]	2752	pick-up	0	17
8895	2019-09-24 22:11:45	2019-09-24	9	[{"id_menu":6,"count":1}]	3259	delivery	5	14
8896	2019-09-24 22:18:56	2019-09-24	14	[{"id_menu":2,"count":1}]	68	pick-up	0	14
8897	2019-09-24 22:25:20	2019-09-24	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	1670	delivery	5	25
8898	2019-09-24 23:19:31	2019-09-24	17	[{"id_menu":4,"count":1}]	281	pick-up	0	17
8899	2019-09-25 00:28:01	2019-09-25	14	[{"id_menu":2,"count":1}]	2556	delivery	5	19
8900	2019-09-25 00:50:40	2019-09-25	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	3293	delivery	5	31
8901	2019-09-25 01:08:32	2019-09-25	12	[{"id_menu":3,"count":1}]	3291	pick-up	0	12
8902	2019-09-25 01:20:51	2019-09-25	12	[{"id_menu":1,"count":1}]	3282	pick-up	0	12
8903	2019-09-25 01:31:01	2019-09-25	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2653	delivery	5	26
8904	2019-09-25 01:49:17	2019-09-25	14	[{"id_menu":2,"count":1}]	1795	pick-up	0	14
8905	2019-09-25 03:21:43	2019-09-25	9	[{"id_menu":7,"count":1}]	3308	delivery	5	14
8906	2019-09-25 03:50:16	2019-09-25	9	[{"id_menu":7,"count":1}]	2197	pick-up	0	9
8907	2019-09-25 04:08:10	2019-09-25	12	[{"id_menu":1,"count":1}]	3172	pick-up	0	12
8908	2019-09-25 04:08:23	2019-09-25	9	[{"id_menu":6,"count":1}]	2110	delivery	5	14
8909	2019-09-25 04:22:35	2019-09-25	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	378	pick-up	0	26
8910	2019-09-25 04:33:33	2019-09-25	9	[{"id_menu":6,"count":1}]	3298	delivery	5	14
8911	2019-09-25 04:56:04	2019-09-25	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3297	delivery	5	39
8912	2019-09-25 05:08:58	2019-09-25	9	[{"id_menu":6,"count":1}]	781	pick-up	0	9
8913	2019-09-25 05:18:46	2019-09-25	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	8	pick-up	0	20
8914	2019-09-25 05:27:52	2019-09-25	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3292	delivery	5	40
8915	2019-09-25 06:04:17	2019-09-25	9	[{"id_menu":6,"count":3}]	1362	delivery	5	14
8916	2019-09-25 07:51:06	2019-09-25	9	[{"id_menu":6,"count":1}]	1781	pick-up	0	9
8917	2019-09-25 08:12:23	2019-09-25	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2933	pick-up	0	21
8918	2019-09-25 08:33:22	2019-09-25	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1528	pick-up	0	21
8919	2019-09-25 08:33:58	2019-09-25	8	[{"id_menu":5,"count":1}]	3280	delivery	5	13
8920	2019-09-25 08:50:29	2019-09-25	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3102	pick-up	0	44
8921	2019-09-25 08:54:55	2019-09-25	9	[{"id_menu":7,"count":1}]	2007	pick-up	0	9
8922	2019-09-25 09:01:55	2019-09-25	9	[{"id_menu":6,"count":1}]	3306	delivery	5	14
8923	2019-09-25 09:24:35	2019-09-25	12	[{"id_menu":3,"count":1}]	1014	pick-up	0	12
8924	2019-09-25 09:24:45	2019-09-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	3294	delivery	5	28
8925	2019-09-25 09:30:27	2019-09-25	14	[{"id_menu":2,"count":2}]	3289	delivery	5	19
8926	2019-09-25 09:36:12	2019-09-25	30	[{"id_menu":3,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3285	pick-up	0	30
8927	2019-09-25 09:41:39	2019-09-25	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3299	delivery	5	22
8928	2019-09-25 10:04:43	2019-09-25	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	327	pick-up	0	24
8929	2019-09-25 10:07:24	2019-09-25	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2783	delivery	5	27
8930	2019-09-25 10:34:37	2019-09-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	786	pick-up	0	26
8931	2019-09-25 10:49:01	2019-09-25	8	[{"id_menu":5,"count":1}]	3160	pick-up	0	8
8932	2019-09-25 11:09:40	2019-09-25	9	[{"id_menu":6,"count":1}]	3279	delivery	5	14
8933	2019-09-25 11:24:11	2019-09-25	17	[{"id_menu":4,"count":1}]	1490	pick-up	0	17
8934	2019-09-25 11:30:30	2019-09-25	9	[{"id_menu":6,"count":1}]	1369	delivery	5	14
8935	2019-09-25 11:46:19	2019-09-25	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2605	delivery	5	39
8936	2019-09-25 11:51:33	2019-09-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3300	delivery	5	23
8937	2019-09-25 12:01:06	2019-09-25	14	[{"id_menu":2,"count":1}]	822	pick-up	0	14
8938	2019-09-25 12:15:39	2019-09-25	9	[{"id_menu":7,"count":1}]	3304	pick-up	0	9
8939	2019-09-25 12:18:53	2019-09-25	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3159	delivery	5	40
8940	2019-09-25 13:18:11	2019-09-25	12	[{"id_menu":1,"count":1}]	1259	pick-up	0	12
8941	2019-09-25 13:28:33	2019-09-25	8	[{"id_menu":5,"count":1}]	1900	pick-up	0	8
8942	2019-09-25 13:31:24	2019-09-25	9	[{"id_menu":7,"count":1}]	586	delivery	5	14
8943	2019-09-25 14:33:32	2019-09-25	8	[{"id_menu":5,"count":1}]	3284	delivery	5	13
8944	2019-09-25 14:37:56	2019-09-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	351	delivery	5	31
8945	2019-09-25 15:36:51	2019-09-25	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	628	delivery	5	49
8946	2019-09-25 15:37:57	2019-09-25	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3296	pick-up	0	22
8947	2019-09-25 16:00:14	2019-09-25	12	[{"id_menu":3,"count":1}]	2398	pick-up	0	12
8948	2019-09-25 17:26:05	2019-09-25	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	151	delivery	5	48
8949	2019-09-25 17:49:42	2019-09-25	14	[{"id_menu":2,"count":1}]	2916	pick-up	0	14
8950	2019-09-25 19:03:50	2019-09-25	9	[{"id_menu":6,"count":1}]	550	delivery	5	14
8951	2019-09-25 19:12:45	2019-09-25	14	[{"id_menu":2,"count":1}]	229	pick-up	0	14
8952	2019-09-25 19:51:00	2019-09-25	9	[{"id_menu":7,"count":1}]	765	pick-up	0	9
8953	2019-09-25 19:58:19	2019-09-25	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3288	pick-up	0	31
8954	2019-09-25 21:12:21	2019-09-25	17	[{"id_menu":4,"count":1}]	820	delivery	5	22
8955	2019-09-25 21:20:50	2019-09-25	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3281	delivery	5	22
8956	2019-09-25 21:23:45	2019-09-25	14	[{"id_menu":2,"count":1}]	3283	pick-up	0	14
8957	2019-09-25 21:36:02	2019-09-25	12	[{"id_menu":1,"count":1}]	2730	delivery	5	17
8958	2019-09-25 21:48:40	2019-09-25	17	[{"id_menu":4,"count":1}]	1127	delivery	5	22
8959	2019-09-25 22:46:13	2019-09-25	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3286	delivery	5	34
8960	2019-09-25 23:25:23	2019-09-25	17	[{"id_menu":4,"count":1}]	1546	pick-up	0	17
8961	2019-09-25 23:33:08	2019-09-25	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":2}]	564	pick-up	0	26
8962	2019-09-25 23:56:47	2019-09-25	8	[{"id_menu":5,"count":2}]	2386	delivery	5	13
8963	2019-09-25 23:57:22	2019-09-25	17	[{"id_menu":4,"count":1}]	1115	pick-up	0	17
8964	2019-09-26 00:09:16	2019-09-26	12	[{"id_menu":3,"count":1}]	3172	pick-up	0	12
8965	2019-09-26 00:23:17	2019-09-26	12	[{"id_menu":1,"count":1}]	511	delivery	5	17
8966	2019-09-26 00:25:12	2019-09-26	9	[{"id_menu":6,"count":1}]	3319	delivery	5	14
8967	2019-09-26 00:42:24	2019-09-26	9	[{"id_menu":7,"count":1}]	3333	delivery	5	14
8968	2019-09-26 00:54:51	2019-09-26	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1729	pick-up	0	26
8969	2019-09-26 01:24:12	2019-09-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3330	pick-up	0	23
8970	2019-09-26 01:52:51	2019-09-26	8	[{"id_menu":5,"count":1}]	996	pick-up	0	8
8971	2019-09-26 03:56:44	2019-09-26	9	[{"id_menu":6,"count":1}]	1208	pick-up	0	9
8972	2019-09-26 03:58:04	2019-09-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3323	delivery	5	22
8973	2019-09-26 04:05:17	2019-09-26	17	[{"id_menu":4,"count":1}]	719	delivery	5	22
8974	2019-09-26 04:14:43	2019-09-26	12	[{"id_menu":3,"count":1}]	707	pick-up	0	12
8975	2019-09-26 04:26:32	2019-09-26	12	[{"id_menu":3,"count":2}]	743	pick-up	0	12
8976	2019-09-26 04:46:20	2019-09-26	9	[{"id_menu":6,"count":1}]	3327	pick-up	0	9
8977	2019-09-26 04:51:18	2019-09-26	17	[{"id_menu":4,"count":1}]	3336	delivery	5	22
8978	2019-09-26 05:01:35	2019-09-26	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	763	pick-up	0	51
8979	2019-09-26 05:13:17	2019-09-26	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	709	delivery	5	34
8980	2019-09-26 05:24:13	2019-09-26	14	[{"id_menu":2,"count":1}]	1995	pick-up	0	14
8981	2019-09-26 05:25:16	2019-09-26	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2254	delivery	5	45
8982	2019-09-26 05:36:16	2019-09-26	14	[{"id_menu":2,"count":1}]	2153	delivery	5	19
8983	2019-09-26 06:29:17	2019-09-26	12	[{"id_menu":3,"count":1}]	2332	delivery	5	17
8984	2019-09-26 06:44:14	2019-09-26	9	[{"id_menu":6,"count":1}]	670	pick-up	0	9
8985	2019-09-26 07:01:54	2019-09-26	9	[{"id_menu":6,"count":1}]	1322	pick-up	0	9
8986	2019-09-26 07:04:18	2019-09-26	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	3326	delivery	5	29
8987	2019-09-26 07:19:21	2019-09-26	17	[{"id_menu":4,"count":1}]	221	pick-up	0	17
8988	2019-09-26 07:48:26	2019-09-26	14	[{"id_menu":2,"count":1}]	2168	pick-up	0	14
8989	2019-09-26 08:02:26	2019-09-26	14	[{"id_menu":2,"count":1}]	3322	delivery	5	19
8990	2019-09-26 08:24:13	2019-09-26	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2619	delivery	5	44
8991	2019-09-26 08:33:32	2019-09-26	9	[{"id_menu":7,"count":1}]	3312	delivery	5	14
8992	2019-09-26 08:45:17	2019-09-26	9	[{"id_menu":7,"count":1}]	2296	delivery	5	14
8993	2019-09-26 08:53:03	2019-09-26	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1968	pick-up	0	32
8994	2019-09-26 09:03:26	2019-09-26	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	1282	delivery	5	35
8995	2019-09-26 09:34:53	2019-09-26	12	[{"id_menu":1,"count":1}]	3313	delivery	5	17
8996	2019-09-26 10:05:39	2019-09-26	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3329	pick-up	0	52
8997	2019-09-26 10:31:03	2019-09-26	14	[{"id_menu":2,"count":1}]	3332	pick-up	0	14
8998	2019-09-26 11:03:13	2019-09-26	17	[{"id_menu":4,"count":1}]	1548	pick-up	0	17
8999	2019-09-26 11:07:50	2019-09-26	12	[{"id_menu":1,"count":1}]	1457	delivery	5	17
9000	2019-09-26 11:21:07	2019-09-26	9	[{"id_menu":6,"count":1}]	642	delivery	5	14
9001	2019-09-26 11:23:35	2019-09-26	12	[{"id_menu":1,"count":1}]	3316	delivery	5	17
9002	2019-09-26 12:07:11	2019-09-26	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3309	pick-up	0	22
9003	2019-09-26 12:18:13	2019-09-26	8	[{"id_menu":5,"count":1}]	2680	pick-up	0	8
9004	2019-09-26 12:23:43	2019-09-26	12	[{"id_menu":1,"count":2}]	274	pick-up	0	12
9005	2019-09-26 12:55:01	2019-09-26	12	[{"id_menu":3,"count":1}]	1531	pick-up	0	12
9006	2019-09-26 13:02:48	2019-09-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2653	pick-up	0	17
9007	2019-09-26 13:16:20	2019-09-26	9	[{"id_menu":7,"count":1}]	1896	pick-up	0	9
9008	2019-09-26 13:24:53	2019-09-26	14	[{"id_menu":2,"count":1}]	2855	delivery	5	19
9009	2019-09-26 13:29:22	2019-09-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3176	pick-up	0	17
9010	2019-09-26 13:37:08	2019-09-26	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	3331	delivery	5	37
9011	2019-09-26 13:47:23	2019-09-26	9	[{"id_menu":7,"count":1}]	213	pick-up	0	9
9012	2019-09-26 13:57:02	2019-09-26	8	[{"id_menu":5,"count":1}]	3321	delivery	5	13
9013	2019-09-26 14:57:43	2019-09-26	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	970	pick-up	0	38
9014	2019-09-26 15:09:25	2019-09-26	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	975	delivery	5	43
9015	2019-09-26 15:13:38	2019-09-26	9	[{"id_menu":6,"count":1}]	3317	delivery	5	14
9016	2019-09-26 15:27:38	2019-09-26	9	[{"id_menu":6,"count":1}]	2386	delivery	5	14
9017	2019-09-26 15:47:09	2019-09-26	8	[{"id_menu":5,"count":1}]	1618	pick-up	0	8
9018	2019-09-26 15:53:59	2019-09-26	14	[{"id_menu":2,"count":1}]	3320	delivery	5	19
9019	2019-09-26 16:04:10	2019-09-26	9	[{"id_menu":6,"count":1}]	3311	delivery	5	14
9020	2019-09-26 16:19:50	2019-09-26	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	439	pick-up	0	43
9021	2019-09-26 16:24:22	2019-09-26	9	[{"id_menu":7,"count":1}]	3314	pick-up	0	9
9022	2019-09-26 16:29:41	2019-09-26	12	[{"id_menu":3,"count":1}]	2464	pick-up	0	12
9023	2019-09-26 16:49:32	2019-09-26	9	[{"id_menu":7,"count":1}]	3334	delivery	5	14
9024	2019-09-26 17:25:07	2019-09-26	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2894	pick-up	0	38
9025	2019-09-26 18:06:21	2019-09-26	17	[{"id_menu":4,"count":1}]	3310	delivery	5	22
9026	2019-09-26 18:14:35	2019-09-26	14	[{"id_menu":2,"count":1}]	3315	delivery	5	19
9027	2019-09-26 19:22:16	2019-09-26	9	[{"id_menu":7,"count":1}]	3328	delivery	5	14
9028	2019-09-26 19:25:06	2019-09-26	9	[{"id_menu":6,"count":1}]	1453	pick-up	0	9
9029	2019-09-26 19:48:09	2019-09-26	9	[{"id_menu":7,"count":1}]	2783	delivery	5	14
9030	2019-09-26 20:02:52	2019-09-26	9	[{"id_menu":6,"count":1}]	2146	delivery	5	14
9031	2019-09-26 20:18:39	2019-09-26	9	[{"id_menu":6,"count":1}]	3318	delivery	5	14
9032	2019-09-26 20:19:04	2019-09-26	12	[{"id_menu":1,"count":1}]	757	pick-up	0	12
9033	2019-09-26 20:44:15	2019-09-26	12	[{"id_menu":1,"count":1}]	2414	delivery	5	17
9034	2019-09-26 20:56:03	2019-09-26	17	[{"id_menu":4,"count":1}]	527	delivery	5	22
9035	2019-09-26 21:39:11	2019-09-26	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1780	delivery	5	48
9036	2019-09-26 21:40:50	2019-09-26	12	[{"id_menu":1,"count":1}]	245	pick-up	0	12
9037	2019-09-26 22:28:12	2019-09-26	14	[{"id_menu":2,"count":1}]	2501	pick-up	0	14
9038	2019-09-26 22:45:39	2019-09-26	8	[{"id_menu":5,"count":1}]	3113	pick-up	0	8
9039	2019-09-26 22:46:30	2019-09-26	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	544	delivery	5	28
9040	2019-09-26 23:11:31	2019-09-26	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3324	delivery	5	34
9041	2019-09-26 23:54:58	2019-09-26	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	799	pick-up	0	29
9042	2019-09-27 00:01:57	2019-09-27	17	[{"id_menu":4,"count":1}]	2551	delivery	5	22
9043	2019-09-27 00:06:38	2019-09-27	17	[{"id_menu":4,"count":1}]	3341	delivery	5	22
9044	2019-09-27 00:10:09	2019-09-27	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3363	pick-up	0	25
9045	2019-09-27 00:10:28	2019-09-27	12	[{"id_menu":3,"count":1}]	2855	delivery	5	17
9046	2019-09-27 00:16:20	2019-09-27	17	[{"id_menu":4,"count":1}]	1696	pick-up	0	17
9047	2019-09-27 00:30:15	2019-09-27	12	[{"id_menu":3,"count":1}]	1931	delivery	5	17
9048	2019-09-27 00:34:05	2019-09-27	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3348	delivery	5	35
9049	2019-09-27 00:42:33	2019-09-27	12	[{"id_menu":1,"count":1}]	1273	pick-up	0	12
9050	2019-09-27 01:26:26	2019-09-27	8	[{"id_menu":5,"count":1}]	3353	pick-up	0	8
9051	2019-09-27 01:41:10	2019-09-27	17	[{"id_menu":4,"count":1}]	1756	pick-up	0	17
9052	2019-09-27 01:49:08	2019-09-27	12	[{"id_menu":3,"count":1}]	3366	pick-up	0	12
9053	2019-09-27 02:17:44	2019-09-27	12	[{"id_menu":1,"count":2}]	3190	delivery	5	17
9054	2019-09-27 02:51:47	2019-09-27	12	[{"id_menu":3,"count":1}]	3356	pick-up	0	12
9055	2019-09-27 03:11:13	2019-09-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1747	pick-up	0	23
9056	2019-09-27 03:23:17	2019-09-27	12	[{"id_menu":3,"count":1}]	1592	delivery	5	17
9057	2019-09-27 04:13:56	2019-09-27	12	[{"id_menu":1,"count":1}]	2347	pick-up	0	12
9058	2019-09-27 04:23:32	2019-09-27	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	3338	pick-up	0	26
9059	2019-09-27 04:31:54	2019-09-27	9	[{"id_menu":7,"count":1}]	3362	delivery	5	14
9060	2019-09-27 04:50:10	2019-09-27	12	[{"id_menu":3,"count":2}]	3370	pick-up	0	12
9061	2019-09-27 05:37:02	2019-09-27	12	[{"id_menu":3,"count":1}]	2370	delivery	5	17
9062	2019-09-27 05:37:51	2019-09-27	9	[{"id_menu":6,"count":1}]	418	pick-up	0	9
9063	2019-09-27 07:02:13	2019-09-27	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3360	delivery	5	37
9064	2019-09-27 07:14:16	2019-09-27	17	[{"id_menu":4,"count":1}]	3359	delivery	5	22
9065	2019-09-27 07:38:16	2019-09-27	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1059	delivery	5	26
9066	2019-09-27 07:42:48	2019-09-27	9	[{"id_menu":6,"count":1}]	2127	delivery	5	14
9067	2019-09-27 07:50:18	2019-09-27	17	[{"id_menu":4,"count":1}]	3351	delivery	5	22
9068	2019-09-27 08:12:56	2019-09-27	9	[{"id_menu":6,"count":1}]	3330	pick-up	0	9
9069	2019-09-27 08:21:44	2019-09-27	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	3102	delivery	5	43
9070	2019-09-27 08:31:24	2019-09-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	140	delivery	5	23
9071	2019-09-27 09:26:22	2019-09-27	9	[{"id_menu":6,"count":1}]	2796	pick-up	0	9
9072	2019-09-27 09:27:36	2019-09-27	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3364	delivery	5	40
9073	2019-09-27 09:46:59	2019-09-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3342	delivery	5	28
9074	2019-09-27 10:19:13	2019-09-27	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3153	pick-up	0	49
9075	2019-09-27 10:31:34	2019-09-27	17	[{"id_menu":4,"count":1}]	2564	pick-up	0	17
9076	2019-09-27 10:36:02	2019-09-27	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	3346	pick-up	0	29
9077	2019-09-27 10:45:01	2019-09-27	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3349	delivery	5	34
9078	2019-09-27 10:46:41	2019-09-27	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	122	pick-up	0	26
9079	2019-09-27 10:55:09	2019-09-27	14	[{"id_menu":2,"count":1}]	3367	delivery	5	19
9080	2019-09-27 11:11:20	2019-09-27	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3361	delivery	5	48
9081	2019-09-27 11:19:15	2019-09-27	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	3371	delivery	5	31
9082	2019-09-27 11:36:23	2019-09-27	9	[{"id_menu":6,"count":1}]	1682	pick-up	0	9
9083	2019-09-27 11:49:55	2019-09-27	9	[{"id_menu":6,"count":1}]	2627	pick-up	0	9
9084	2019-09-27 12:05:26	2019-09-27	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	3339	delivery	5	26
9085	2019-09-27 12:24:24	2019-09-27	8	[{"id_menu":5,"count":1}]	3158	delivery	5	13
9086	2019-09-27 12:37:23	2019-09-27	17	[{"id_menu":4,"count":1}]	1924	pick-up	0	17
9087	2019-09-27 12:52:01	2019-09-27	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	465	pick-up	0	23
9088	2019-09-27 13:44:45	2019-09-27	14	[{"id_menu":2,"count":1}]	3368	delivery	5	19
9089	2019-09-27 14:20:55	2019-09-27	12	[{"id_menu":3,"count":1}]	1992	pick-up	0	12
9090	2019-09-27 14:44:56	2019-09-27	12	[{"id_menu":3,"count":1}]	1722	delivery	5	17
9091	2019-09-27 15:04:51	2019-09-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3340	delivery	5	22
9092	2019-09-27 15:10:47	2019-09-27	17	[{"id_menu":4,"count":1}]	86	delivery	5	22
9093	2019-09-27 15:18:27	2019-09-27	9	[{"id_menu":6,"count":1}]	2150	delivery	5	14
9094	2019-09-27 15:46:04	2019-09-27	17	[{"id_menu":4,"count":1}]	1453	pick-up	0	17
9095	2019-09-27 16:04:21	2019-09-27	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3354	pick-up	0	25
9096	2019-09-27 16:17:49	2019-09-27	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	590	delivery	5	37
9097	2019-09-27 16:29:53	2019-09-27	9	[{"id_menu":7,"count":1}]	3369	delivery	5	14
9098	2019-09-27 17:13:42	2019-09-27	12	[{"id_menu":3,"count":1}]	886	pick-up	0	12
9099	2019-09-27 17:56:29	2019-09-27	12	[{"id_menu":3,"count":1}]	3358	delivery	5	17
9100	2019-09-27 18:02:34	2019-09-27	12	[{"id_menu":3,"count":1}]	2227	delivery	5	17
9101	2019-09-27 18:03:45	2019-09-27	14	[{"id_menu":2,"count":1}]	2581	pick-up	0	14
9102	2019-09-27 19:39:43	2019-09-27	17	[{"id_menu":4,"count":1}]	813	delivery	5	22
9103	2019-09-27 19:41:13	2019-09-27	8	[{"id_menu":5,"count":1}]	2961	pick-up	0	8
9104	2019-09-27 19:44:59	2019-09-27	12	[{"id_menu":1,"count":1}]	2083	pick-up	0	12
9105	2019-09-27 19:48:31	2019-09-27	9	[{"id_menu":6,"count":1}]	1135	delivery	5	14
9106	2019-09-27 20:00:24	2019-09-27	9	[{"id_menu":6,"count":2}]	3343	delivery	5	14
9107	2019-09-27 20:04:50	2019-09-27	14	[{"id_menu":2,"count":1}]	2145	delivery	5	19
9108	2019-09-27 20:29:33	2019-09-27	17	[{"id_menu":4,"count":1}]	240	delivery	5	22
9109	2019-09-27 21:33:35	2019-09-27	14	[{"id_menu":2,"count":1}]	3357	pick-up	0	14
9110	2019-09-27 21:37:28	2019-09-27	8	[{"id_menu":5,"count":1}]	3345	delivery	5	13
9111	2019-09-27 21:51:21	2019-09-27	9	[{"id_menu":7,"count":1}]	883	pick-up	0	9
9112	2019-09-27 22:19:22	2019-09-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3352	pick-up	0	17
9113	2019-09-27 22:26:00	2019-09-27	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	3126	delivery	5	26
9114	2019-09-27 22:29:11	2019-09-27	17	[{"id_menu":4,"count":1}]	2064	delivery	5	22
9115	2019-09-27 22:51:37	2019-09-27	12	[{"id_menu":3,"count":1}]	49	pick-up	0	12
9116	2019-09-27 23:18:39	2019-09-27	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	173	pick-up	0	46
9117	2019-09-27 23:20:26	2019-09-27	12	[{"id_menu":1,"count":1}]	2798	delivery	5	17
9118	2019-09-27 23:27:00	2019-09-27	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3365	delivery	5	49
9119	2019-09-27 23:28:24	2019-09-27	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	372	pick-up	0	20
9120	2019-09-27 23:54:41	2019-09-27	17	[{"id_menu":4,"count":1}]	389	pick-up	0	17
9121	2019-09-28 00:13:12	2019-09-28	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	1289	delivery	5	40
9122	2019-09-28 00:18:28	2019-09-28	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1085	pick-up	0	37
9123	2019-09-28 00:19:45	2019-09-28	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	135	pick-up	0	22
9124	2019-09-28 00:29:05	2019-09-28	14	[{"id_menu":2,"count":1}]	3361	pick-up	0	14
9125	2019-09-28 00:53:37	2019-09-28	9	[{"id_menu":6,"count":1}]	3372	pick-up	0	9
9126	2019-09-28 01:17:52	2019-09-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3394	pick-up	0	17
9127	2019-09-28 01:34:18	2019-09-28	8	[{"id_menu":5,"count":1}]	2809	pick-up	0	8
9128	2019-09-28 01:45:00	2019-09-28	9	[{"id_menu":6,"count":1}]	1364	pick-up	0	9
9129	2019-09-28 01:47:58	2019-09-28	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	580	pick-up	0	35
9130	2019-09-28 02:09:23	2019-09-28	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1194	pick-up	0	33
9131	2019-09-28 02:17:54	2019-09-28	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2858	delivery	5	31
9132	2019-09-28 02:31:42	2019-09-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	960	delivery	5	31
9133	2019-09-28 02:43:05	2019-09-28	12	[{"id_menu":3,"count":1}]	1283	delivery	5	17
9134	2019-09-28 02:51:38	2019-09-28	14	[{"id_menu":2,"count":1}]	140	pick-up	0	14
9135	2019-09-28 03:19:46	2019-09-28	14	[{"id_menu":2,"count":1}]	965	delivery	5	19
9136	2019-09-28 03:36:46	2019-09-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2354	pick-up	0	17
9137	2019-09-28 03:46:37	2019-09-28	14	[{"id_menu":2,"count":1}]	2735	pick-up	0	14
9138	2019-09-28 03:47:03	2019-09-28	9	[{"id_menu":7,"count":1}]	531	pick-up	0	9
9139	2019-09-28 03:50:36	2019-09-28	14	[{"id_menu":2,"count":1}]	209	pick-up	0	14
9140	2019-09-28 04:27:30	2019-09-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2723	delivery	5	31
9141	2019-09-28 04:31:21	2019-09-28	17	[{"id_menu":4,"count":1}]	3381	delivery	5	22
9142	2019-09-28 04:34:55	2019-09-28	9	[{"id_menu":7,"count":1}]	1453	delivery	5	14
9143	2019-09-28 04:35:23	2019-09-28	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3395	pick-up	0	23
9144	2019-09-28 04:51:00	2019-09-28	9	[{"id_menu":7,"count":1}]	3379	delivery	5	14
9145	2019-09-28 05:15:05	2019-09-28	8	[{"id_menu":5,"count":1}]	1241	pick-up	0	8
9146	2019-09-28 05:15:25	2019-09-28	14	[{"id_menu":2,"count":1}]	3393	delivery	5	19
9147	2019-09-28 05:45:45	2019-09-28	8	[{"id_menu":5,"count":1}]	765	pick-up	0	8
9148	2019-09-28 06:32:49	2019-09-28	14	[{"id_menu":2,"count":2}]	3389	pick-up	0	14
9149	2019-09-28 07:04:37	2019-09-28	17	[{"id_menu":4,"count":1}]	2980	pick-up	0	17
9150	2019-09-28 07:24:25	2019-09-28	12	[{"id_menu":3,"count":1}]	2137	pick-up	0	12
9151	2019-09-28 07:31:58	2019-09-28	12	[{"id_menu":3,"count":1}]	2611	pick-up	0	12
9152	2019-09-28 07:50:22	2019-09-28	9	[{"id_menu":6,"count":1}]	2570	pick-up	0	9
9153	2019-09-28 08:03:38	2019-09-28	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3402	delivery	5	49
9154	2019-09-28 08:10:35	2019-09-28	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	3382	pick-up	0	26
9155	2019-09-28 08:19:01	2019-09-28	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	2659	pick-up	0	32
9156	2019-09-28 08:19:33	2019-09-28	8	[{"id_menu":5,"count":1}]	1118	pick-up	0	8
9157	2019-09-28 08:39:33	2019-09-28	12	[{"id_menu":1,"count":1}]	3380	delivery	5	17
9158	2019-09-28 09:13:22	2019-09-28	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	3397	delivery	5	25
9159	2019-09-28 09:45:39	2019-09-28	8	[{"id_menu":5,"count":1}]	612	pick-up	0	8
9160	2019-09-28 10:00:01	2019-09-28	8	[{"id_menu":5,"count":1}]	3386	delivery	5	13
9161	2019-09-28 10:39:20	2019-09-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	560	delivery	5	31
9162	2019-09-28 10:50:57	2019-09-28	12	[{"id_menu":1,"count":1}]	3384	delivery	5	17
9163	2019-09-28 11:01:17	2019-09-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	3406	delivery	5	23
9164	2019-09-28 11:05:11	2019-09-28	9	[{"id_menu":6,"count":1}]	2160	delivery	5	14
9165	2019-09-28 11:17:07	2019-09-28	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1972	delivery	5	34
9166	2019-09-28 11:17:12	2019-09-28	17	[{"id_menu":4,"count":1}]	1108	delivery	5	22
9167	2019-09-28 11:29:42	2019-09-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3387	delivery	5	22
9168	2019-09-28 12:17:48	2019-09-28	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3392	delivery	5	35
9169	2019-09-28 12:19:21	2019-09-28	17	[{"id_menu":4,"count":1}]	1259	pick-up	0	17
9170	2019-09-28 12:31:20	2019-09-28	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	3403	delivery	5	26
9171	2019-09-28 12:37:18	2019-09-28	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	175	pick-up	0	21
9172	2019-09-28 12:46:25	2019-09-28	12	[{"id_menu":3,"count":1}]	3391	pick-up	0	12
9173	2019-09-28 12:47:11	2019-09-28	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2573	pick-up	0	20
9174	2019-09-28 13:14:57	2019-09-28	14	[{"id_menu":2,"count":1}]	3398	delivery	5	19
9175	2019-09-28 13:28:35	2019-09-28	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3400	delivery	5	26
9176	2019-09-28 13:34:13	2019-09-28	9	[{"id_menu":6,"count":1}]	2396	pick-up	0	9
9177	2019-09-28 13:35:32	2019-09-28	8	[{"id_menu":5,"count":1}]	822	delivery	5	13
9178	2019-09-28 13:45:03	2019-09-28	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	3388	delivery	5	26
9179	2019-09-28 13:46:33	2019-09-28	9	[{"id_menu":7,"count":1}]	471	delivery	5	14
9180	2019-09-28 13:50:20	2019-09-28	17	[{"id_menu":4,"count":1}]	2000	pick-up	0	17
9181	2019-09-28 13:52:39	2019-09-28	9	[{"id_menu":7,"count":1}]	1676	pick-up	0	9
9182	2019-09-28 14:07:45	2019-09-28	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3396	delivery	5	36
9183	2019-09-28 14:35:23	2019-09-28	9	[{"id_menu":7,"count":1}]	2652	pick-up	0	9
9184	2019-09-28 14:59:52	2019-09-28	12	[{"id_menu":1,"count":1}]	1871	pick-up	0	12
9185	2019-09-28 15:20:25	2019-09-28	8	[{"id_menu":5,"count":1}]	68	pick-up	0	8
9186	2019-09-28 15:40:50	2019-09-28	34	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	826	pick-up	0	34
9187	2019-09-28 15:52:14	2019-09-28	12	[{"id_menu":1,"count":1}]	2799	pick-up	0	12
9188	2019-09-28 15:58:40	2019-09-28	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2546	pick-up	0	21
9189	2019-09-28 16:08:31	2019-09-28	12	[{"id_menu":1,"count":1}]	2827	pick-up	0	12
9190	2019-09-28 16:25:15	2019-09-28	17	[{"id_menu":4,"count":1}]	634	pick-up	0	17
9191	2019-09-28 16:30:20	2019-09-28	8	[{"id_menu":5,"count":1}]	2440	delivery	5	13
9192	2019-09-28 16:42:55	2019-09-28	12	[{"id_menu":3,"count":1}]	3401	pick-up	0	12
9193	2019-09-28 16:54:25	2019-09-28	9	[{"id_menu":7,"count":1}]	1387	delivery	5	14
9194	2019-09-28 17:28:06	2019-09-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3374	delivery	5	31
9195	2019-09-28 17:58:20	2019-09-28	17	[{"id_menu":4,"count":1}]	136	delivery	5	22
9196	2019-09-28 18:51:19	2019-09-28	9	[{"id_menu":6,"count":1}]	3373	delivery	5	14
9197	2019-09-28 19:04:19	2019-09-28	9	[{"id_menu":6,"count":1}]	2888	delivery	5	14
9198	2019-09-28 19:06:58	2019-09-28	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1914	delivery	5	29
9199	2019-09-28 19:27:11	2019-09-28	8	[{"id_menu":5,"count":1}]	999	pick-up	0	8
9200	2019-09-28 19:27:16	2019-09-28	12	[{"id_menu":1,"count":1}]	2007	pick-up	0	12
9201	2019-09-28 19:36:43	2019-09-28	8	[{"id_menu":5,"count":1}]	1816	pick-up	0	8
9202	2019-09-28 19:48:21	2019-09-28	12	[{"id_menu":1,"count":1}]	632	pick-up	0	12
9203	2019-09-28 19:57:40	2019-09-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3385	pick-up	0	23
9204	2019-09-28 20:07:41	2019-09-28	9	[{"id_menu":6,"count":1}]	1670	pick-up	0	9
9205	2019-09-28 20:12:56	2019-09-28	17	[{"id_menu":4,"count":1}]	1854	delivery	5	22
9206	2019-09-28 20:47:15	2019-09-28	9	[{"id_menu":6,"count":1}]	835	pick-up	0	9
9207	2019-09-28 20:53:28	2019-09-28	9	[{"id_menu":7,"count":1}]	593	delivery	5	14
9208	2019-09-28 21:59:53	2019-09-28	12	[{"id_menu":1,"count":1}]	3377	delivery	5	17
9209	2019-09-28 22:02:59	2019-09-28	9	[{"id_menu":7,"count":1}]	3383	delivery	5	14
9210	2019-09-28 22:22:45	2019-09-28	12	[{"id_menu":3,"count":1}]	3052	pick-up	0	12
9211	2019-09-28 22:28:06	2019-09-28	8	[{"id_menu":5,"count":1}]	3404	delivery	5	13
9212	2019-09-28 22:36:46	2019-09-28	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1087	pick-up	0	22
9213	2019-09-28 22:54:24	2019-09-28	17	[{"id_menu":4,"count":2}]	3399	pick-up	0	17
9214	2019-09-28 22:56:39	2019-09-28	17	[{"id_menu":4,"count":1}]	3375	pick-up	0	17
9215	2019-09-28 23:01:17	2019-09-28	9	[{"id_menu":6,"count":1}]	2828	pick-up	0	9
9216	2019-09-28 23:33:08	2019-09-28	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	3378	delivery	5	45
9217	2019-09-28 23:47:14	2019-09-28	14	[{"id_menu":2,"count":1}]	3376	pick-up	0	14
9218	2019-09-28 23:59:35	2019-09-28	14	[{"id_menu":2,"count":1}]	2630	delivery	5	19
9219	2019-09-29 00:01:18	2019-09-29	9	[{"id_menu":6,"count":1}]	1832	pick-up	0	9
9220	2019-09-29 00:01:34	2019-09-29	9	[{"id_menu":6,"count":1}]	2997	delivery	5	14
9221	2019-09-29 00:02:44	2019-09-29	9	[{"id_menu":7,"count":2}]	709	pick-up	0	9
9222	2019-09-29 00:07:04	2019-09-29	22	[{"id_menu":2,"count":3},{"id_menu":5,"count":1}]	3258	pick-up	0	22
9223	2019-09-29 00:12:22	2019-09-29	9	[{"id_menu":6,"count":1}]	3423	delivery	5	14
9224	2019-09-29 00:13:43	2019-09-29	23	[{"id_menu":2,"count":3},{"id_menu":7,"count":1}]	3443	delivery	5	28
9225	2019-09-29 00:31:40	2019-09-29	8	[{"id_menu":5,"count":1}]	1863	pick-up	0	8
9226	2019-09-29 00:35:34	2019-09-29	9	[{"id_menu":6,"count":2}]	1183	delivery	5	14
9227	2019-09-29 00:37:04	2019-09-29	17	[{"id_menu":4,"count":1}]	489	delivery	5	22
9228	2019-09-29 00:41:49	2019-09-29	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	886	delivery	5	26
9229	2019-09-29 00:42:25	2019-09-29	9	[{"id_menu":7,"count":1}]	1814	delivery	5	14
9230	2019-09-29 00:55:19	2019-09-29	12	[{"id_menu":3,"count":1}]	2110	delivery	5	17
9231	2019-09-29 00:56:12	2019-09-29	14	[{"id_menu":2,"count":1}]	3409	delivery	5	19
9232	2019-09-29 01:00:34	2019-09-29	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	3440	pick-up	0	29
9233	2019-09-29 01:15:48	2019-09-29	14	[{"id_menu":2,"count":1}]	3228	pick-up	0	14
9234	2019-09-29 01:30:16	2019-09-29	9	[{"id_menu":6,"count":1}]	3437	delivery	5	14
9235	2019-09-29 01:41:35	2019-09-29	14	[{"id_menu":2,"count":1}]	3335	delivery	5	19
9236	2019-09-29 02:01:42	2019-09-29	8	[{"id_menu":5,"count":1}]	440	delivery	5	13
9237	2019-09-29 02:29:31	2019-09-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	3407	delivery	5	26
9238	2019-09-29 02:29:35	2019-09-29	9	[{"id_menu":6,"count":1}]	1811	pick-up	0	9
9239	2019-09-29 02:38:56	2019-09-29	17	[{"id_menu":4,"count":1}]	1582	pick-up	0	17
9240	2019-09-29 02:40:38	2019-09-29	12	[{"id_menu":3,"count":1}]	52	pick-up	0	12
9241	2019-09-29 03:02:43	2019-09-29	9	[{"id_menu":6,"count":1}]	3436	delivery	5	14
9242	2019-09-29 03:07:43	2019-09-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	3107	delivery	5	28
9243	2019-09-29 03:09:49	2019-09-29	17	[{"id_menu":4,"count":1}]	1484	pick-up	0	17
9244	2019-09-29 03:12:36	2019-09-29	8	[{"id_menu":5,"count":1}]	1021	pick-up	0	8
9245	2019-09-29 03:17:26	2019-09-29	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3277	delivery	5	34
9246	2019-09-29 03:26:33	2019-09-29	9	[{"id_menu":7,"count":1}]	2963	pick-up	0	9
9247	2019-09-29 03:29:58	2019-09-29	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2283	pick-up	0	21
9248	2019-09-29 03:42:16	2019-09-29	14	[{"id_menu":2,"count":1}]	3422	delivery	5	19
9249	2019-09-29 04:25:29	2019-09-29	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	2977	delivery	5	34
9250	2019-09-29 04:36:06	2019-09-29	12	[{"id_menu":1,"count":1}]	1343	delivery	5	17
9251	2019-09-29 04:59:09	2019-09-29	14	[{"id_menu":2,"count":1}]	1924	pick-up	0	14
9252	2019-09-29 05:09:05	2019-09-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1760	pick-up	0	26
9253	2019-09-29 05:15:57	2019-09-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2550	delivery	5	26
9254	2019-09-29 05:50:45	2019-09-29	9	[{"id_menu":7,"count":1}]	2496	pick-up	0	9
9255	2019-09-29 05:51:07	2019-09-29	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	3438	delivery	5	37
9256	2019-09-29 05:51:34	2019-09-29	9	[{"id_menu":7,"count":1}]	3417	delivery	5	14
9257	2019-09-29 06:35:45	2019-09-29	9	[{"id_menu":7,"count":1}]	81	delivery	5	14
9258	2019-09-29 06:39:50	2019-09-29	8	[{"id_menu":5,"count":1}]	1155	pick-up	0	8
9259	2019-09-29 06:50:36	2019-09-29	9	[{"id_menu":6,"count":1}]	15	pick-up	0	9
9260	2019-09-29 06:53:59	2019-09-29	9	[{"id_menu":6,"count":1}]	3432	pick-up	0	9
9261	2019-09-29 06:54:31	2019-09-29	12	[{"id_menu":3,"count":1}]	2053	delivery	5	17
9262	2019-09-29 07:00:33	2019-09-29	9	[{"id_menu":6,"count":1}]	913	delivery	5	14
9263	2019-09-29 07:01:47	2019-09-29	9	[{"id_menu":6,"count":1}]	3442	pick-up	0	9
9264	2019-09-29 07:15:06	2019-09-29	12	[{"id_menu":1,"count":1}]	150	pick-up	0	12
9265	2019-09-29 07:27:10	2019-09-29	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	837	pick-up	0	34
9266	2019-09-29 07:31:00	2019-09-29	14	[{"id_menu":2,"count":1}]	3420	pick-up	0	14
9267	2019-09-29 07:38:18	2019-09-29	14	[{"id_menu":2,"count":1}]	519	pick-up	0	14
9268	2019-09-29 07:49:25	2019-09-29	17	[{"id_menu":4,"count":1}]	1785	pick-up	0	17
9269	2019-09-29 07:52:46	2019-09-29	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3427	delivery	5	43
9270	2019-09-29 08:11:08	2019-09-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2882	delivery	5	22
9271	2019-09-29 08:14:46	2019-09-29	17	[{"id_menu":4,"count":1}]	1659	delivery	5	22
9272	2019-09-29 08:19:16	2019-09-29	17	[{"id_menu":4,"count":1}]	238	pick-up	0	17
9273	2019-09-29 08:26:59	2019-09-29	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	279	pick-up	0	21
9274	2019-09-29 08:32:07	2019-09-29	12	[{"id_menu":1,"count":1}]	1914	pick-up	0	12
9275	2019-09-29 08:38:51	2019-09-29	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	190	pick-up	0	21
9276	2019-09-29 08:49:44	2019-09-29	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1860	delivery	5	34
9277	2019-09-29 08:51:11	2019-09-29	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1147	pick-up	0	31
9278	2019-09-29 08:56:58	2019-09-29	14	[{"id_menu":2,"count":1}]	2291	pick-up	0	14
9279	2019-09-29 09:07:55	2019-09-29	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1134	delivery	5	34
9280	2019-09-29 09:21:24	2019-09-29	12	[{"id_menu":1,"count":1}]	3410	delivery	5	17
9281	2019-09-29 09:26:05	2019-09-29	8	[{"id_menu":5,"count":1}]	527	pick-up	0	8
9282	2019-09-29 09:28:06	2019-09-29	12	[{"id_menu":1,"count":1}]	856	pick-up	0	12
9283	2019-09-29 09:39:57	2019-09-29	9	[{"id_menu":7,"count":1}]	2074	delivery	5	14
9284	2019-09-29 09:48:46	2019-09-29	12	[{"id_menu":1,"count":1}]	2076	pick-up	0	12
9285	2019-09-29 09:52:15	2019-09-29	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	552	pick-up	0	43
9286	2019-09-29 09:58:37	2019-09-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":3}]	2812	delivery	5	28
9287	2019-09-29 10:00:58	2019-09-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3429	delivery	5	28
9288	2019-09-29 10:01:18	2019-09-29	17	[{"id_menu":4,"count":1}]	931	delivery	5	22
9289	2019-09-29 10:08:53	2019-09-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1150	delivery	5	22
9290	2019-09-29 10:21:31	2019-09-29	14	[{"id_menu":2,"count":1}]	3426	delivery	5	19
9291	2019-09-29 10:24:56	2019-09-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2845	delivery	5	22
9292	2019-09-29 10:26:26	2019-09-29	14	[{"id_menu":2,"count":1}]	719	delivery	5	19
9293	2019-09-29 10:29:13	2019-09-29	14	[{"id_menu":2,"count":1}]	1085	pick-up	0	14
9294	2019-09-29 10:45:01	2019-09-29	17	[{"id_menu":4,"count":1}]	1314	delivery	5	22
9295	2019-09-29 10:50:40	2019-09-29	9	[{"id_menu":6,"count":1}]	3418	delivery	5	14
9296	2019-09-29 10:59:37	2019-09-29	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	3434	delivery	5	25
9297	2019-09-29 11:15:58	2019-09-29	12	[{"id_menu":3,"count":1}]	2065	pick-up	0	12
9298	2019-09-29 11:42:16	2019-09-29	14	[{"id_menu":2,"count":1}]	3414	pick-up	0	14
9299	2019-09-29 11:44:26	2019-09-29	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	676	pick-up	0	43
9300	2019-09-29 11:48:46	2019-09-29	9	[{"id_menu":7,"count":1}]	1059	delivery	5	14
9301	2019-09-29 11:49:59	2019-09-29	8	[{"id_menu":5,"count":1}]	2735	pick-up	0	8
9302	2019-09-29 11:54:52	2019-09-29	12	[{"id_menu":3,"count":1}]	2630	pick-up	0	12
9303	2019-09-29 12:04:36	2019-09-29	12	[{"id_menu":3,"count":1}]	1263	pick-up	0	12
9304	2019-09-29 12:14:16	2019-09-29	8	[{"id_menu":5,"count":1}]	2582	pick-up	0	8
9305	2019-09-29 12:16:25	2019-09-29	9	[{"id_menu":7,"count":1}]	3040	delivery	5	14
9306	2019-09-29 12:26:36	2019-09-29	12	[{"id_menu":1,"count":1}]	376	pick-up	0	12
9307	2019-09-29 12:32:38	2019-09-29	9	[{"id_menu":6,"count":1}]	925	pick-up	0	9
9308	2019-09-29 12:33:13	2019-09-29	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	2303	delivery	5	28
9309	2019-09-29 12:44:16	2019-09-29	9	[{"id_menu":6,"count":1}]	3444	pick-up	0	9
9310	2019-09-29 13:25:19	2019-09-29	12	[{"id_menu":3,"count":1}]	3413	delivery	5	17
9311	2019-09-29 13:38:24	2019-09-29	14	[{"id_menu":2,"count":1}]	1720	pick-up	0	14
9312	2019-09-29 13:41:46	2019-09-29	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	3111	pick-up	0	26
9313	2019-09-29 13:59:14	2019-09-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	337	pick-up	0	23
9314	2019-09-29 13:59:40	2019-09-29	14	[{"id_menu":2,"count":2}]	1996	pick-up	0	14
9315	2019-09-29 14:01:47	2019-09-29	8	[{"id_menu":5,"count":1}]	2935	pick-up	0	8
9316	2019-09-29 14:05:54	2019-09-29	8	[{"id_menu":5,"count":1}]	3425	delivery	5	13
9317	2019-09-29 14:32:10	2019-09-29	8	[{"id_menu":5,"count":1}]	3416	pick-up	0	8
9318	2019-09-29 15:10:18	2019-09-29	17	[{"id_menu":4,"count":1}]	626	pick-up	0	17
9319	2019-09-29 15:12:08	2019-09-29	12	[{"id_menu":3,"count":1}]	2228	delivery	5	17
9320	2019-09-29 15:16:56	2019-09-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3428	delivery	5	36
9321	2019-09-29 15:25:24	2019-09-29	9	[{"id_menu":6,"count":1}]	841	delivery	5	14
9322	2019-09-29 15:29:00	2019-09-29	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	3419	pick-up	0	29
9323	2019-09-29 15:45:01	2019-09-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	972	delivery	5	31
9324	2019-09-29 16:11:03	2019-09-29	14	[{"id_menu":2,"count":1}]	3433	delivery	5	19
9325	2019-09-29 16:16:37	2019-09-29	17	[{"id_menu":4,"count":1}]	3412	delivery	5	22
9326	2019-09-29 16:28:11	2019-09-29	9	[{"id_menu":7,"count":1}]	1289	pick-up	0	9
9327	2019-09-29 16:38:22	2019-09-29	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1810	delivery	5	38
9328	2019-09-29 16:47:27	2019-09-29	9	[{"id_menu":6,"count":1}]	3430	pick-up	0	9
9329	2019-09-29 17:14:35	2019-09-29	14	[{"id_menu":2,"count":1}]	175	delivery	5	19
9330	2019-09-29 17:24:09	2019-09-29	9	[{"id_menu":7,"count":1}]	3424	delivery	5	14
9331	2019-09-29 17:29:05	2019-09-29	12	[{"id_menu":1,"count":1}]	2055	delivery	5	17
9332	2019-09-29 17:45:33	2019-09-29	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1514	delivery	5	36
9333	2019-09-29 17:48:53	2019-09-29	9	[{"id_menu":7,"count":1}]	1752	pick-up	0	9
9334	2019-09-29 18:00:47	2019-09-29	12	[{"id_menu":3,"count":1}]	3411	delivery	5	17
9335	2019-09-29 18:17:23	2019-09-29	9	[{"id_menu":6,"count":1}]	1956	pick-up	0	9
9336	2019-09-29 18:35:11	2019-09-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3036	delivery	5	22
9337	2019-09-29 18:43:27	2019-09-29	17	[{"id_menu":4,"count":1}]	1349	pick-up	0	17
9338	2019-09-29 19:41:26	2019-09-29	12	[{"id_menu":1,"count":1}]	3439	pick-up	0	12
9339	2019-09-29 20:02:20	2019-09-29	12	[{"id_menu":3,"count":1}]	1170	pick-up	0	12
9340	2019-09-29 20:02:40	2019-09-29	8	[{"id_menu":5,"count":1}]	2894	pick-up	0	8
9341	2019-09-29 20:03:01	2019-09-29	12	[{"id_menu":3,"count":1}]	3415	delivery	5	17
9342	2019-09-29 20:40:32	2019-09-29	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	2517	pick-up	0	26
9343	2019-09-29 20:48:02	2019-09-29	12	[{"id_menu":1,"count":1}]	2739	pick-up	0	12
9344	2019-09-29 20:54:35	2019-09-29	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	802	pick-up	0	26
9345	2019-09-29 20:54:59	2019-09-29	12	[{"id_menu":1,"count":1}]	772	delivery	5	17
9346	2019-09-29 21:03:18	2019-09-29	17	[{"id_menu":4,"count":1}]	73	pick-up	0	17
9347	2019-09-29 21:12:20	2019-09-29	17	[{"id_menu":4,"count":1}]	1072	pick-up	0	17
9348	2019-09-29 21:24:27	2019-09-29	17	[{"id_menu":4,"count":1}]	2189	pick-up	0	17
9349	2019-09-29 21:50:37	2019-09-29	14	[{"id_menu":2,"count":1}]	3168	pick-up	0	14
9350	2019-09-29 22:01:13	2019-09-29	9	[{"id_menu":7,"count":1}]	3408	delivery	5	14
9351	2019-09-29 22:06:22	2019-09-29	8	[{"id_menu":5,"count":1}]	754	pick-up	0	8
9352	2019-09-29 22:15:20	2019-09-29	9	[{"id_menu":7,"count":1}]	3431	delivery	5	14
9353	2019-09-29 22:20:24	2019-09-29	9	[{"id_menu":6,"count":1}]	2599	pick-up	0	9
9354	2019-09-29 22:32:25	2019-09-29	12	[{"id_menu":1,"count":1}]	2740	delivery	5	17
9355	2019-09-29 23:00:41	2019-09-29	14	[{"id_menu":2,"count":1}]	1803	delivery	5	19
9356	2019-09-29 23:01:00	2019-09-29	17	[{"id_menu":4,"count":1}]	1445	pick-up	0	17
9357	2019-09-29 23:04:00	2019-09-29	12	[{"id_menu":1,"count":1}]	799	pick-up	0	12
9358	2019-09-29 23:15:22	2019-09-29	12	[{"id_menu":3,"count":1}]	2292	pick-up	0	12
9359	2019-09-29 23:29:44	2019-09-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3435	pick-up	0	26
9360	2019-09-29 23:33:07	2019-09-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3441	pick-up	0	22
9361	2019-09-29 23:33:46	2019-09-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3421	pick-up	0	18
9362	2019-09-30 00:04:07	2019-09-30	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3450	delivery	5	22
9363	2019-09-30 00:50:16	2019-09-30	12	[{"id_menu":1,"count":1}]	2855	pick-up	0	12
9364	2019-09-30 01:21:34	2019-09-30	17	[{"id_menu":4,"count":1}]	3452	delivery	5	22
9365	2019-09-30 01:22:50	2019-09-30	12	[{"id_menu":1,"count":2}]	223	pick-up	0	12
9366	2019-09-30 01:40:27	2019-09-30	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	3459	pick-up	0	22
9367	2019-09-30 01:58:27	2019-09-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3461	delivery	5	28
9368	2019-09-30 02:17:48	2019-09-30	9	[{"id_menu":7,"count":1}]	2993	pick-up	0	9
9369	2019-09-30 03:10:40	2019-09-30	14	[{"id_menu":2,"count":1}]	2867	delivery	5	19
9370	2019-09-30 04:15:30	2019-09-30	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1905	delivery	5	34
9371	2019-09-30 05:41:13	2019-09-30	17	[{"id_menu":4,"count":1}]	868	pick-up	0	17
9372	2019-09-30 06:26:18	2019-09-30	12	[{"id_menu":1,"count":1}]	3468	delivery	5	17
9373	2019-09-30 06:29:11	2019-09-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	3411	pick-up	0	23
9374	2019-09-30 07:56:37	2019-09-30	12	[{"id_menu":1,"count":1}]	757	delivery	5	17
9375	2019-09-30 08:32:43	2019-09-30	14	[{"id_menu":2,"count":1}]	467	delivery	5	19
9376	2019-09-30 09:03:32	2019-09-30	12	[{"id_menu":1,"count":1}]	1674	pick-up	0	12
9377	2019-09-30 10:21:48	2019-09-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3451	delivery	5	28
9378	2019-09-30 11:00:47	2019-09-30	9	[{"id_menu":7,"count":1}]	3463	delivery	5	14
9379	2019-09-30 11:01:07	2019-09-30	17	[{"id_menu":4,"count":1}]	1676	pick-up	0	17
9380	2019-09-30 11:25:12	2019-09-30	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3464	pick-up	0	40
9381	2019-09-30 11:31:59	2019-09-30	9	[{"id_menu":6,"count":2}]	3472	delivery	5	14
9382	2019-09-30 11:36:48	2019-09-30	17	[{"id_menu":4,"count":1}]	543	delivery	5	22
9383	2019-09-30 11:58:00	2019-09-30	17	[{"id_menu":4,"count":1}]	60	pick-up	0	17
9384	2019-09-30 12:12:53	2019-09-30	9	[{"id_menu":6,"count":1}]	2237	delivery	5	14
9385	2019-09-30 13:08:57	2019-09-30	12	[{"id_menu":1,"count":1}]	418	pick-up	0	12
9386	2019-09-30 13:24:59	2019-09-30	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	1369	delivery	5	28
9387	2019-09-30 14:00:21	2019-09-30	17	[{"id_menu":4,"count":1}]	3193	pick-up	0	17
9388	2019-09-30 14:12:43	2019-09-30	12	[{"id_menu":1,"count":1}]	2523	pick-up	0	12
9389	2019-09-30 14:51:18	2019-09-30	17	[{"id_menu":4,"count":1}]	3403	pick-up	0	17
9390	2019-09-30 14:56:41	2019-09-30	17	[{"id_menu":4,"count":1}]	1462	pick-up	0	17
9391	2019-09-30 15:29:49	2019-09-30	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3419	pick-up	0	48
9392	2019-09-30 17:16:28	2019-09-30	9	[{"id_menu":7,"count":1}]	3466	delivery	5	14
9393	2019-09-30 17:23:40	2019-09-30	14	[{"id_menu":2,"count":1}]	310	delivery	5	19
9394	2019-09-30 18:05:02	2019-09-30	12	[{"id_menu":3,"count":1}]	2536	pick-up	0	12
9395	2019-09-30 18:18:20	2019-09-30	17	[{"id_menu":4,"count":1}]	1568	pick-up	0	17
9396	2019-09-30 18:18:48	2019-09-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	826	delivery	5	31
9397	2019-09-30 18:49:40	2019-09-30	14	[{"id_menu":2,"count":1}]	3467	delivery	5	19
9398	2019-09-30 18:52:16	2019-09-30	14	[{"id_menu":2,"count":1}]	2022	pick-up	0	14
9399	2019-09-30 18:58:07	2019-09-30	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	3469	delivery	5	36
9400	2019-09-30 20:21:35	2019-09-30	9	[{"id_menu":6,"count":1}]	3462	delivery	5	14
9401	2019-09-30 20:51:07	2019-09-30	14	[{"id_menu":2,"count":1}]	3102	pick-up	0	14
9402	2019-09-30 20:55:46	2019-09-30	9	[{"id_menu":6,"count":1}]	184	delivery	5	14
9403	2019-09-30 20:56:26	2019-09-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1703	delivery	5	28
9404	2019-09-30 22:00:19	2019-09-30	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3457	pick-up	0	49
9405	2019-09-30 22:11:50	2019-09-30	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	2071	delivery	5	25
9406	2019-09-30 22:34:17	2019-09-30	14	[{"id_menu":2,"count":1}]	1981	pick-up	0	14
9407	2019-09-30 22:42:20	2019-09-30	9	[{"id_menu":6,"count":1}]	2420	pick-up	0	9
9408	2019-09-30 22:56:07	2019-09-30	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3471	delivery	5	48
9409	2019-09-30 22:59:59	2019-09-30	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	213	pick-up	0	26
9410	2019-09-30 23:33:09	2019-09-30	14	[{"id_menu":2,"count":1}]	2091	pick-up	0	14
9411	2019-09-30 23:42:07	2019-09-30	9	[{"id_menu":7,"count":1}]	80	pick-up	0	9
9412	2019-09-30 23:52:11	2019-09-30	9	[{"id_menu":6,"count":2}]	3458	delivery	5	14
9413	2019-10-01 00:03:38	2019-10-01	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	3494	delivery	5	25
9414	2019-10-01 00:07:37	2019-10-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1046	delivery	5	23
9415	2019-10-01 00:56:57	2019-10-01	12	[{"id_menu":3,"count":1}]	2875	pick-up	0	12
9416	2019-10-01 01:40:44	2019-10-01	14	[{"id_menu":2,"count":1}]	3493	delivery	5	19
9417	2019-10-01 02:27:51	2019-10-01	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3477	pick-up	0	35
9418	2019-10-01 02:45:57	2019-10-01	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	3500	delivery	5	39
9419	2019-10-01 03:35:50	2019-10-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3119	delivery	5	28
9420	2019-10-01 04:25:30	2019-10-01	43	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3484	delivery	5	48
9421	2019-10-01 04:26:02	2019-10-01	9	[{"id_menu":7,"count":1}]	670	pick-up	0	9
9422	2019-10-01 04:36:50	2019-10-01	9	[{"id_menu":7,"count":1}]	3447	pick-up	0	9
9423	2019-10-01 04:55:40	2019-10-01	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1382	pick-up	0	47
9424	2019-10-01 05:08:41	2019-10-01	12	[{"id_menu":1,"count":1}]	2516	delivery	5	17
9425	2019-10-01 05:50:25	2019-10-01	12	[{"id_menu":1,"count":1}]	153	pick-up	0	12
9426	2019-10-01 06:10:52	2019-10-01	14	[{"id_menu":2,"count":1}]	293	pick-up	0	14
9427	2019-10-01 06:28:55	2019-10-01	8	[{"id_menu":5,"count":1}]	2891	delivery	5	13
9428	2019-10-01 06:30:16	2019-10-01	9	[{"id_menu":7,"count":1}]	19	delivery	5	14
9429	2019-10-01 07:07:06	2019-10-01	12	[{"id_menu":1,"count":1}]	3389	pick-up	0	12
9430	2019-10-01 07:33:00	2019-10-01	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3490	delivery	5	45
9431	2019-10-01 07:38:38	2019-10-01	14	[{"id_menu":2,"count":1}]	3496	pick-up	0	14
9432	2019-10-01 08:04:32	2019-10-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2230	pick-up	0	31
9433	2019-10-01 08:06:44	2019-10-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3480	pick-up	0	23
9434	2019-10-01 08:17:24	2019-10-01	17	[{"id_menu":4,"count":1}]	1481	delivery	5	22
9435	2019-10-01 08:28:00	2019-10-01	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	2065	pick-up	0	23
9436	2019-10-01 08:50:37	2019-10-01	17	[{"id_menu":4,"count":1}]	2418	delivery	5	22
9437	2019-10-01 09:00:41	2019-10-01	14	[{"id_menu":2,"count":1}]	3478	delivery	5	19
9438	2019-10-01 09:16:33	2019-10-01	9	[{"id_menu":6,"count":1}]	3487	pick-up	0	9
9439	2019-10-01 09:46:44	2019-10-01	14	[{"id_menu":2,"count":1}]	3476	pick-up	0	14
9440	2019-10-01 09:48:53	2019-10-01	14	[{"id_menu":2,"count":1}]	3504	pick-up	0	14
9441	2019-10-01 09:50:13	2019-10-01	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3489	delivery	5	57
9442	2019-10-01 10:24:45	2019-10-01	14	[{"id_menu":2,"count":1}]	2916	delivery	5	19
9443	2019-10-01 10:35:43	2019-10-01	17	[{"id_menu":4,"count":1}]	3474	delivery	5	22
9444	2019-10-01 11:01:22	2019-10-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3486	delivery	5	28
9445	2019-10-01 11:19:15	2019-10-01	8	[{"id_menu":5,"count":1}]	691	pick-up	0	8
9446	2019-10-01 11:57:25	2019-10-01	9	[{"id_menu":6,"count":1}]	3499	delivery	5	14
9447	2019-10-01 12:00:10	2019-10-01	12	[{"id_menu":1,"count":1}]	3483	delivery	5	17
9448	2019-10-01 12:26:29	2019-10-01	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	964	delivery	5	45
9449	2019-10-01 12:34:51	2019-10-01	12	[{"id_menu":1,"count":1}]	2551	pick-up	0	12
9450	2019-10-01 13:08:03	2019-10-01	14	[{"id_menu":2,"count":1}]	556	pick-up	0	14
9451	2019-10-01 13:20:09	2019-10-01	9	[{"id_menu":6,"count":2}]	2946	pick-up	0	9
9452	2019-10-01 14:08:41	2019-10-01	12	[{"id_menu":1,"count":1}]	3449	pick-up	0	12
9453	2019-10-01 14:38:39	2019-10-01	14	[{"id_menu":2,"count":1}]	2477	pick-up	0	14
9454	2019-10-01 14:59:03	2019-10-01	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	274	pick-up	0	21
9455	2019-10-01 15:08:04	2019-10-01	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2761	delivery	5	52
9456	2019-10-01 15:30:43	2019-10-01	9	[{"id_menu":7,"count":1}]	502	delivery	5	14
9457	2019-10-01 16:08:12	2019-10-01	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2936	delivery	5	40
9458	2019-10-01 16:16:27	2019-10-01	12	[{"id_menu":3,"count":1}]	2604	delivery	5	17
9459	2019-10-01 16:25:10	2019-10-01	14	[{"id_menu":2,"count":1}]	3498	pick-up	0	14
9460	2019-10-01 16:34:56	2019-10-01	9	[{"id_menu":6,"count":1}]	3481	delivery	5	14
9461	2019-10-01 17:29:14	2019-10-01	9	[{"id_menu":7,"count":1}]	2962	delivery	5	14
9462	2019-10-01 17:41:30	2019-10-01	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2078	pick-up	0	26
9463	2019-10-01 18:04:28	2019-10-01	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2332	delivery	5	39
9464	2019-10-01 18:06:16	2019-10-01	12	[{"id_menu":1,"count":1}]	240	pick-up	0	12
9465	2019-10-01 18:15:13	2019-10-01	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2001	delivery	5	45
9466	2019-10-01 18:44:23	2019-10-01	8	[{"id_menu":5,"count":1}]	3485	delivery	5	13
9467	2019-10-01 19:10:01	2019-10-01	9	[{"id_menu":7,"count":1}]	405	pick-up	0	9
9468	2019-10-01 19:28:24	2019-10-01	9	[{"id_menu":6,"count":1}]	3502	delivery	5	14
9469	2019-10-01 19:41:06	2019-10-01	17	[{"id_menu":4,"count":1}]	1659	pick-up	0	17
9470	2019-10-01 19:57:01	2019-10-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	3136	delivery	5	22
9471	2019-10-01 20:52:41	2019-10-01	12	[{"id_menu":1,"count":1}]	3450	delivery	5	17
9472	2019-10-01 20:54:59	2019-10-01	9	[{"id_menu":6,"count":1}]	1742	pick-up	0	9
9473	2019-10-01 21:39:07	2019-10-01	12	[{"id_menu":1,"count":1}]	3482	delivery	5	17
9474	2019-10-01 21:44:21	2019-10-01	14	[{"id_menu":2,"count":1}]	3475	delivery	5	19
9475	2019-10-01 22:22:33	2019-10-01	12	[{"id_menu":1,"count":1}]	3497	delivery	5	17
9476	2019-10-01 22:48:19	2019-10-01	12	[{"id_menu":3,"count":1}]	2195	pick-up	0	12
9477	2019-10-01 23:03:05	2019-10-01	8	[{"id_menu":5,"count":1}]	2691	delivery	5	13
9478	2019-10-02 00:05:10	2019-10-02	17	[{"id_menu":4,"count":1}]	707	delivery	5	22
9479	2019-10-02 00:20:53	2019-10-02	14	[{"id_menu":2,"count":1}]	1531	pick-up	0	14
9480	2019-10-02 00:32:28	2019-10-02	9	[{"id_menu":7,"count":1}]	3523	delivery	5	14
9481	2019-10-02 00:33:22	2019-10-02	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	880	delivery	5	39
9482	2019-10-02 00:40:51	2019-10-02	14	[{"id_menu":2,"count":1}]	2517	pick-up	0	14
9483	2019-10-02 00:44:26	2019-10-02	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3040	delivery	5	34
9484	2019-10-02 01:36:51	2019-10-02	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2367	pick-up	0	21
9485	2019-10-02 01:37:04	2019-10-02	14	[{"id_menu":2,"count":2}]	2983	pick-up	0	14
9486	2019-10-02 01:58:19	2019-10-02	12	[{"id_menu":3,"count":1}]	2575	pick-up	0	12
9487	2019-10-02 01:58:59	2019-10-02	12	[{"id_menu":1,"count":1}]	62	delivery	5	17
9488	2019-10-02 02:36:18	2019-10-02	14	[{"id_menu":2,"count":1}]	284	delivery	5	19
9489	2019-10-02 02:54:16	2019-10-02	14	[{"id_menu":2,"count":1}]	3399	delivery	5	19
9490	2019-10-02 03:22:29	2019-10-02	12	[{"id_menu":1,"count":1}]	3530	delivery	5	17
9491	2019-10-02 03:42:12	2019-10-02	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":3}]	3052	delivery	5	31
9492	2019-10-02 04:22:14	2019-10-02	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2065	pick-up	0	31
9493	2019-10-02 05:05:39	2019-10-02	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	3529	pick-up	0	24
9494	2019-10-02 05:28:31	2019-10-02	14	[{"id_menu":2,"count":1}]	883	pick-up	0	14
9495	2019-10-02 07:03:21	2019-10-02	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2485	delivery	5	31
9496	2019-10-02 07:18:15	2019-10-02	9	[{"id_menu":6,"count":1}]	3511	pick-up	0	9
9497	2019-10-02 07:23:51	2019-10-02	12	[{"id_menu":1,"count":1}]	3507	pick-up	0	12
9498	2019-10-02 07:37:18	2019-10-02	9	[{"id_menu":7,"count":1}]	722	pick-up	0	9
9499	2019-10-02 07:43:58	2019-10-02	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	626	pick-up	0	21
9500	2019-10-02 07:52:24	2019-10-02	17	[{"id_menu":4,"count":1}]	703	delivery	5	22
9501	2019-10-02 07:56:34	2019-10-02	12	[{"id_menu":1,"count":1}]	2807	pick-up	0	12
9502	2019-10-02 08:00:49	2019-10-02	9	[{"id_menu":7,"count":1}]	3135	pick-up	0	9
9503	2019-10-02 08:04:54	2019-10-02	8	[{"id_menu":5,"count":1}]	2172	delivery	5	13
9504	2019-10-02 08:15:57	2019-10-02	12	[{"id_menu":1,"count":2}]	3534	delivery	5	17
9505	2019-10-02 08:41:12	2019-10-02	9	[{"id_menu":6,"count":1}]	1243	pick-up	0	9
9506	2019-10-02 08:49:12	2019-10-02	14	[{"id_menu":2,"count":1}]	527	pick-up	0	14
9507	2019-10-02 09:27:39	2019-10-02	14	[{"id_menu":2,"count":1}]	440	delivery	5	19
9508	2019-10-02 10:30:54	2019-10-02	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2902	pick-up	0	29
9509	2019-10-02 11:02:32	2019-10-02	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2870	pick-up	0	31
9510	2019-10-02 11:04:01	2019-10-02	9	[{"id_menu":6,"count":1}]	3513	pick-up	0	9
9511	2019-10-02 11:05:36	2019-10-02	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	3083	delivery	5	26
9512	2019-10-02 11:11:50	2019-10-02	9	[{"id_menu":7,"count":1}]	1679	pick-up	0	9
9513	2019-10-02 11:18:46	2019-10-02	14	[{"id_menu":2,"count":1}]	3532	pick-up	0	14
9514	2019-10-02 11:24:08	2019-10-02	9	[{"id_menu":6,"count":1}]	3525	delivery	5	14
9515	2019-10-02 11:29:56	2019-10-02	8	[{"id_menu":5,"count":1}]	1363	pick-up	0	8
9516	2019-10-02 12:03:37	2019-10-02	9	[{"id_menu":7,"count":1}]	2472	pick-up	0	9
9517	2019-10-02 12:14:07	2019-10-02	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	2181	delivery	5	29
9518	2019-10-02 12:20:03	2019-10-02	14	[{"id_menu":2,"count":1}]	2183	delivery	5	19
9519	2019-10-02 12:23:27	2019-10-02	14	[{"id_menu":2,"count":1}]	3514	pick-up	0	14
9520	2019-10-02 12:27:40	2019-10-02	12	[{"id_menu":3,"count":1}]	3361	delivery	5	17
9521	2019-10-02 12:42:55	2019-10-02	8	[{"id_menu":5,"count":1}]	2630	pick-up	0	8
9522	2019-10-02 12:50:53	2019-10-02	14	[{"id_menu":2,"count":1}]	3505	delivery	5	19
9523	2019-10-02 12:51:05	2019-10-02	12	[{"id_menu":3,"count":1}]	381	pick-up	0	12
9524	2019-10-02 12:53:33	2019-10-02	9	[{"id_menu":6,"count":1}]	1693	pick-up	0	9
9525	2019-10-02 14:02:20	2019-10-02	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1715	delivery	5	30
9526	2019-10-02 14:03:22	2019-10-02	12	[{"id_menu":3,"count":1}]	1055	pick-up	0	12
9527	2019-10-02 14:12:36	2019-10-02	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2128	pick-up	0	37
9528	2019-10-02 14:14:04	2019-10-02	12	[{"id_menu":3,"count":1}]	3510	pick-up	0	12
9529	2019-10-02 14:34:02	2019-10-02	17	[{"id_menu":4,"count":1}]	3173	delivery	5	22
9530	2019-10-02 14:46:06	2019-10-02	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	3524	pick-up	0	22
9531	2019-10-02 15:02:46	2019-10-02	9	[{"id_menu":6,"count":1}]	2272	pick-up	0	9
9532	2019-10-02 15:02:52	2019-10-02	14	[{"id_menu":2,"count":1}]	3527	pick-up	0	14
9533	2019-10-02 15:10:32	2019-10-02	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2920	delivery	5	27
9534	2019-10-02 15:32:04	2019-10-02	33	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	413	delivery	5	38
9535	2019-10-02 15:51:14	2019-10-02	9	[{"id_menu":6,"count":1}]	1979	pick-up	0	9
9536	2019-10-02 16:21:39	2019-10-02	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2477	pick-up	0	21
9537	2019-10-02 16:36:17	2019-10-02	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1765	pick-up	0	40
9538	2019-10-02 16:36:43	2019-10-02	14	[{"id_menu":2,"count":1}]	3509	pick-up	0	14
9539	2019-10-02 16:38:39	2019-10-02	14	[{"id_menu":2,"count":1}]	1076	delivery	5	19
9540	2019-10-02 16:45:37	2019-10-02	9	[{"id_menu":7,"count":1}]	3444	delivery	5	14
9541	2019-10-02 17:04:07	2019-10-02	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	820	pick-up	0	20
9542	2019-10-02 17:24:56	2019-10-02	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	265	delivery	5	31
9543	2019-10-02 17:46:23	2019-10-02	9	[{"id_menu":7,"count":1}]	3506	delivery	5	14
9544	2019-10-02 17:47:12	2019-10-02	17	[{"id_menu":4,"count":1}]	799	pick-up	0	17
9545	2019-10-02 17:51:09	2019-10-02	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3526	pick-up	0	25
9546	2019-10-02 18:27:42	2019-10-02	8	[{"id_menu":5,"count":1}]	2728	pick-up	0	8
9547	2019-10-02 18:46:10	2019-10-02	9	[{"id_menu":6,"count":2}]	3522	delivery	5	14
9548	2019-10-02 19:02:09	2019-10-02	12	[{"id_menu":1,"count":1}]	1455	pick-up	0	12
9549	2019-10-02 19:11:44	2019-10-02	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	2691	pick-up	0	29
9550	2019-10-02 19:15:17	2019-10-02	14	[{"id_menu":2,"count":2}]	2119	pick-up	0	14
9551	2019-10-02 19:19:27	2019-10-02	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3517	delivery	5	51
9552	2019-10-02 20:05:46	2019-10-02	12	[{"id_menu":1,"count":1}]	1008	delivery	5	17
9553	2019-10-02 20:41:00	2019-10-02	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1041	pick-up	0	30
9554	2019-10-02 20:59:49	2019-10-02	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2237	pick-up	0	32
9555	2019-10-02 21:10:21	2019-10-02	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	2127	delivery	5	40
9556	2019-10-02 21:16:06	2019-10-02	9	[{"id_menu":6,"count":1}]	314	pick-up	0	9
9557	2019-10-02 21:17:27	2019-10-02	9	[{"id_menu":7,"count":1}]	3508	delivery	5	14
9558	2019-10-02 21:22:27	2019-10-02	9	[{"id_menu":6,"count":1}]	982	delivery	5	14
9559	2019-10-02 21:26:02	2019-10-02	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	400	pick-up	0	21
9560	2019-10-02 21:30:29	2019-10-02	14	[{"id_menu":2,"count":1}]	2633	pick-up	0	14
9561	2019-10-02 21:40:03	2019-10-02	9	[{"id_menu":7,"count":1}]	2613	pick-up	0	9
9562	2019-10-02 21:59:47	2019-10-02	9	[{"id_menu":6,"count":1}]	3519	delivery	5	14
9563	2019-10-02 22:07:13	2019-10-02	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3520	delivery	5	27
9564	2019-10-02 22:08:39	2019-10-02	9	[{"id_menu":7,"count":1}]	3516	delivery	5	14
9565	2019-10-02 22:45:38	2019-10-02	12	[{"id_menu":3,"count":1}]	2798	delivery	5	17
9566	2019-10-02 22:51:49	2019-10-02	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	270	delivery	5	27
9567	2019-10-02 22:52:33	2019-10-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	719	pick-up	0	18
9568	2019-10-02 23:02:31	2019-10-02	12	[{"id_menu":3,"count":1}]	643	delivery	5	17
9569	2019-10-02 23:38:45	2019-10-02	9	[{"id_menu":6,"count":1}]	2101	pick-up	0	9
9570	2019-10-02 23:49:40	2019-10-02	17	[{"id_menu":4,"count":1}]	1334	pick-up	0	17
9571	2019-10-02 23:55:21	2019-10-02	12	[{"id_menu":3,"count":1}]	3533	pick-up	0	12
9572	2019-10-02 23:56:17	2019-10-02	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2252	delivery	5	34
9573	2019-10-03 00:03:20	2019-10-03	14	[{"id_menu":2,"count":1}]	3560	pick-up	0	14
9574	2019-10-03 00:27:12	2019-10-03	17	[{"id_menu":4,"count":1}]	3538	delivery	5	22
9575	2019-10-03 00:51:25	2019-10-03	8	[{"id_menu":5,"count":1}]	29	pick-up	0	8
9576	2019-10-03 00:56:19	2019-10-03	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2418	pick-up	0	35
9577	2019-10-03 01:08:28	2019-10-03	17	[{"id_menu":4,"count":1}]	3540	delivery	5	22
9578	2019-10-03 01:13:56	2019-10-03	14	[{"id_menu":2,"count":1}]	1528	pick-up	0	14
9579	2019-10-03 01:54:50	2019-10-03	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	654	delivery	5	31
9580	2019-10-03 02:09:06	2019-10-03	9	[{"id_menu":6,"count":1}]	1442	delivery	5	14
9581	2019-10-03 02:12:48	2019-10-03	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2466	delivery	5	45
9582	2019-10-03 02:24:18	2019-10-03	8	[{"id_menu":5,"count":1}]	710	delivery	5	13
9583	2019-10-03 03:15:05	2019-10-03	14	[{"id_menu":2,"count":1}]	707	delivery	5	19
9584	2019-10-03 04:06:15	2019-10-03	9	[{"id_menu":7,"count":1}]	3129	delivery	5	14
9585	2019-10-03 04:13:47	2019-10-03	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	946	pick-up	0	26
9586	2019-10-03 04:19:13	2019-10-03	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	3543	delivery	5	35
9587	2019-10-03 05:05:33	2019-10-03	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3563	delivery	5	45
9588	2019-10-03 05:14:56	2019-10-03	12	[{"id_menu":3,"count":1}]	401	pick-up	0	12
9589	2019-10-03 05:26:50	2019-10-03	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	169	delivery	5	31
9590	2019-10-03 05:31:14	2019-10-03	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2010	delivery	5	25
9591	2019-10-03 05:56:25	2019-10-03	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	1369	delivery	5	26
9592	2019-10-03 06:03:47	2019-10-03	9	[{"id_menu":6,"count":1}]	1481	pick-up	0	9
9593	2019-10-03 06:08:18	2019-10-03	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1071	pick-up	0	32
9594	2019-10-03 06:12:37	2019-10-03	9	[{"id_menu":6,"count":1}]	2107	pick-up	0	9
9595	2019-10-03 06:26:08	2019-10-03	14	[{"id_menu":2,"count":1}]	3541	delivery	5	19
9596	2019-10-03 06:32:42	2019-10-03	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3550	pick-up	0	22
9597	2019-10-03 06:40:26	2019-10-03	17	[{"id_menu":4,"count":1}]	1018	delivery	5	22
9598	2019-10-03 07:14:01	2019-10-03	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	3330	pick-up	0	21
9599	2019-10-03 07:55:13	2019-10-03	14	[{"id_menu":2,"count":1}]	123	delivery	5	19
9600	2019-10-03 08:06:46	2019-10-03	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2282	pick-up	0	25
9601	2019-10-03 08:07:03	2019-10-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	3572	delivery	5	31
9602	2019-10-03 08:16:38	2019-10-03	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1531	pick-up	0	24
9603	2019-10-03 08:31:15	2019-10-03	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	1468	delivery	5	48
9604	2019-10-03 08:56:10	2019-10-03	12	[{"id_menu":3,"count":1}]	3549	delivery	5	17
9605	2019-10-03 09:13:42	2019-10-03	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	37	pick-up	0	33
9606	2019-10-03 09:52:54	2019-10-03	9	[{"id_menu":7,"count":1}]	3565	delivery	5	14
9607	2019-10-03 09:53:05	2019-10-03	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	110	pick-up	0	29
9608	2019-10-03 10:06:40	2019-10-03	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3569	delivery	5	34
9609	2019-10-03 10:18:11	2019-10-03	9	[{"id_menu":6,"count":1}]	3545	delivery	5	14
9610	2019-10-03 10:31:09	2019-10-03	55	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3568	delivery	5	60
9611	2019-10-03 10:39:46	2019-10-03	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	1742	delivery	5	28
9612	2019-10-03 10:48:38	2019-10-03	8	[{"id_menu":5,"count":2}]	3462	delivery	5	13
9613	2019-10-03 10:51:45	2019-10-03	12	[{"id_menu":1,"count":1}]	2403	pick-up	0	12
9614	2019-10-03 11:54:43	2019-10-03	9	[{"id_menu":6,"count":1}]	3555	delivery	5	14
9615	2019-10-03 12:05:19	2019-10-03	9	[{"id_menu":7,"count":1}]	3566	delivery	5	14
9616	2019-10-03 12:07:43	2019-10-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1831	delivery	5	31
9617	2019-10-03 12:12:11	2019-10-03	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	656	delivery	5	28
9618	2019-10-03 12:12:21	2019-10-03	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	3551	delivery	5	25
9619	2019-10-03 12:14:06	2019-10-03	9	[{"id_menu":7,"count":2}]	1025	pick-up	0	9
9620	2019-10-03 12:19:06	2019-10-03	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	3554	delivery	5	40
9621	2019-10-03 12:39:13	2019-10-03	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	529	pick-up	0	26
9622	2019-10-03 12:40:08	2019-10-03	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1337	pick-up	0	34
9623	2019-10-03 13:21:40	2019-10-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3224	delivery	5	31
9624	2019-10-03 13:29:11	2019-10-03	9	[{"id_menu":6,"count":1}]	2042	delivery	5	14
9625	2019-10-03 13:33:23	2019-10-03	12	[{"id_menu":1,"count":1}]	376	pick-up	0	12
9626	2019-10-03 13:35:06	2019-10-03	14	[{"id_menu":2,"count":1}]	2606	pick-up	0	14
9627	2019-10-03 13:38:27	2019-10-03	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3552	delivery	5	34
9628	2019-10-03 14:03:03	2019-10-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2116	pick-up	0	23
9629	2019-10-03 14:20:57	2019-10-03	17	[{"id_menu":4,"count":1}]	1106	delivery	5	22
9630	2019-10-03 14:35:17	2019-10-03	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	970	pick-up	0	23
9631	2019-10-03 14:37:51	2019-10-03	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	729	pick-up	0	29
9632	2019-10-03 14:48:51	2019-10-03	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	3571	delivery	5	40
9633	2019-10-03 15:48:55	2019-10-03	12	[{"id_menu":3,"count":1}]	374	pick-up	0	12
9634	2019-10-03 15:49:52	2019-10-03	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1840	pick-up	0	26
9635	2019-10-03 16:42:07	2019-10-03	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3558	delivery	5	36
9636	2019-10-03 17:01:22	2019-10-03	12	[{"id_menu":1,"count":1}]	1239	pick-up	0	12
9637	2019-10-03 17:01:27	2019-10-03	14	[{"id_menu":2,"count":1}]	2101	pick-up	0	14
9638	2019-10-03 17:12:22	2019-10-03	17	[{"id_menu":4,"count":1}]	1462	pick-up	0	17
9639	2019-10-03 17:23:30	2019-10-03	12	[{"id_menu":3,"count":1}]	3535	pick-up	0	12
9640	2019-10-03 17:29:26	2019-10-03	9	[{"id_menu":6,"count":1}]	3537	delivery	5	14
9641	2019-10-03 17:58:47	2019-10-03	8	[{"id_menu":5,"count":1}]	3536	delivery	5	13
9642	2019-10-03 18:18:32	2019-10-03	12	[{"id_menu":3,"count":1}]	2228	pick-up	0	12
9643	2019-10-03 18:29:38	2019-10-03	12	[{"id_menu":1,"count":1}]	153	pick-up	0	12
9644	2019-10-03 18:38:20	2019-10-03	9	[{"id_menu":6,"count":1}]	3548	delivery	5	14
9645	2019-10-03 19:13:51	2019-10-03	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	2868	delivery	5	22
9646	2019-10-03 19:22:25	2019-10-03	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3556	delivery	5	22
9647	2019-10-03 19:48:50	2019-10-03	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2555	delivery	5	55
9648	2019-10-03 19:51:09	2019-10-03	9	[{"id_menu":7,"count":1}]	3542	delivery	5	14
9649	2019-10-03 19:56:17	2019-10-03	12	[{"id_menu":3,"count":1}]	2310	pick-up	0	12
9650	2019-10-03 20:02:22	2019-10-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	3546	delivery	5	31
9651	2019-10-03 20:38:28	2019-10-03	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3539	pick-up	0	17
9652	2019-10-03 20:41:10	2019-10-03	17	[{"id_menu":4,"count":1}]	640	pick-up	0	17
9653	2019-10-03 21:07:28	2019-10-03	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	3559	pick-up	0	26
9654	2019-10-03 21:09:44	2019-10-03	12	[{"id_menu":1,"count":1}]	213	pick-up	0	12
9655	2019-10-03 21:25:17	2019-10-03	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2374	delivery	5	36
9656	2019-10-03 21:25:53	2019-10-03	17	[{"id_menu":4,"count":1}]	3491	pick-up	0	17
9657	2019-10-03 21:45:14	2019-10-03	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3553	pick-up	0	26
9658	2019-10-03 21:47:40	2019-10-03	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3562	delivery	5	37
9659	2019-10-03 21:47:51	2019-10-03	12	[{"id_menu":1,"count":1}]	1434	pick-up	0	12
9660	2019-10-03 22:00:59	2019-10-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3564	delivery	5	28
9661	2019-10-03 22:04:07	2019-10-03	9	[{"id_menu":7,"count":1}]	3567	delivery	5	14
9662	2019-10-03 22:30:53	2019-10-03	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3380	delivery	5	26
9663	2019-10-03 22:35:49	2019-10-03	9	[{"id_menu":7,"count":1}]	1581	pick-up	0	9
9664	2019-10-03 22:48:21	2019-10-03	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	3570	pick-up	0	21
9665	2019-10-03 22:52:59	2019-10-03	17	[{"id_menu":4,"count":1}]	3544	delivery	5	22
9666	2019-10-03 22:58:30	2019-10-03	9	[{"id_menu":6,"count":1}]	3511	pick-up	0	9
9667	2019-10-04 00:10:45	2019-10-04	12	[{"id_menu":1,"count":1}]	3591	delivery	5	17
9668	2019-10-04 00:26:32	2019-10-04	9	[{"id_menu":7,"count":1}]	3582	delivery	5	14
9669	2019-10-04 00:50:44	2019-10-04	8	[{"id_menu":5,"count":2}]	3598	delivery	5	13
9670	2019-10-04 01:05:44	2019-10-04	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3602	delivery	5	36
9671	2019-10-04 01:08:29	2019-10-04	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	2446	pick-up	0	43
9672	2019-10-04 01:35:12	2019-10-04	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3587	delivery	5	43
9673	2019-10-04 01:52:26	2019-10-04	17	[{"id_menu":4,"count":1}]	2289	delivery	5	22
9674	2019-10-04 02:15:23	2019-10-04	14	[{"id_menu":2,"count":1}]	439	delivery	5	19
9675	2019-10-04 02:46:31	2019-10-04	9	[{"id_menu":6,"count":1}]	2004	delivery	5	14
9676	2019-10-04 03:25:23	2019-10-04	14	[{"id_menu":2,"count":1}]	3168	pick-up	0	14
9677	2019-10-04 03:32:44	2019-10-04	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	3583	delivery	5	28
9678	2019-10-04 04:30:49	2019-10-04	9	[{"id_menu":6,"count":1}]	1194	pick-up	0	9
9679	2019-10-04 05:36:53	2019-10-04	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3599	delivery	5	43
9680	2019-10-04 06:04:03	2019-10-04	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	92	pick-up	0	35
9681	2019-10-04 06:59:50	2019-10-04	17	[{"id_menu":4,"count":1}]	71	pick-up	0	17
9682	2019-10-04 07:08:48	2019-10-04	8	[{"id_menu":5,"count":1}]	980	delivery	5	13
9683	2019-10-04 07:10:44	2019-10-04	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3586	delivery	5	28
9684	2019-10-04 07:13:26	2019-10-04	12	[{"id_menu":3,"count":1}]	2937	delivery	5	17
9685	2019-10-04 07:24:45	2019-10-04	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":3}]	391	delivery	5	25
9686	2019-10-04 07:47:24	2019-10-04	9	[{"id_menu":6,"count":1}]	1988	delivery	5	14
9687	2019-10-04 07:56:54	2019-10-04	9	[{"id_menu":6,"count":1}]	3577	pick-up	0	9
9688	2019-10-04 08:06:04	2019-10-04	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	3574	delivery	5	27
9689	2019-10-04 08:13:17	2019-10-04	9	[{"id_menu":7,"count":1}]	1415	pick-up	0	9
9690	2019-10-04 08:39:21	2019-10-04	9	[{"id_menu":6,"count":1}]	3604	pick-up	0	9
9691	2019-10-04 08:52:15	2019-10-04	14	[{"id_menu":2,"count":1}]	3603	delivery	5	19
9692	2019-10-04 08:55:45	2019-10-04	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1245	pick-up	0	29
9693	2019-10-04 08:57:20	2019-10-04	9	[{"id_menu":7,"count":1}]	3589	delivery	5	14
9694	2019-10-04 09:18:33	2019-10-04	8	[{"id_menu":5,"count":1}]	2398	pick-up	0	8
9695	2019-10-04 09:27:27	2019-10-04	12	[{"id_menu":3,"count":1}]	3573	delivery	5	17
9696	2019-10-04 09:54:20	2019-10-04	14	[{"id_menu":2,"count":1}]	1481	pick-up	0	14
9697	2019-10-04 09:54:27	2019-10-04	8	[{"id_menu":5,"count":1}]	3592	delivery	5	13
9698	2019-10-04 10:11:12	2019-10-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	821	pick-up	0	23
9699	2019-10-04 10:27:45	2019-10-04	12	[{"id_menu":3,"count":1}]	2177	pick-up	0	12
9700	2019-10-04 10:32:47	2019-10-04	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	341	pick-up	0	22
9701	2019-10-04 11:06:27	2019-10-04	9	[{"id_menu":7,"count":1}]	2932	pick-up	0	9
9702	2019-10-04 11:07:24	2019-10-04	9	[{"id_menu":6,"count":1}]	315	pick-up	0	9
9703	2019-10-04 11:08:39	2019-10-04	8	[{"id_menu":5,"count":1}]	3579	delivery	5	13
9704	2019-10-04 11:09:01	2019-10-04	12	[{"id_menu":1,"count":1}]	3588	delivery	5	17
9705	2019-10-04 11:13:54	2019-10-04	17	[{"id_menu":4,"count":1}]	3607	pick-up	0	17
9706	2019-10-04 12:05:10	2019-10-04	8	[{"id_menu":5,"count":1}]	3595	delivery	5	13
9707	2019-10-04 12:10:58	2019-10-04	17	[{"id_menu":4,"count":1}]	2776	pick-up	0	17
9708	2019-10-04 12:23:56	2019-10-04	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3509	delivery	5	31
9709	2019-10-04 13:32:27	2019-10-04	17	[{"id_menu":4,"count":1}]	3576	delivery	5	22
9710	2019-10-04 13:38:49	2019-10-04	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	735	pick-up	0	21
9711	2019-10-04 13:44:18	2019-10-04	17	[{"id_menu":4,"count":1}]	1097	delivery	5	22
9712	2019-10-04 13:44:29	2019-10-04	12	[{"id_menu":1,"count":1}]	3593	pick-up	0	12
9713	2019-10-04 13:54:43	2019-10-04	9	[{"id_menu":6,"count":1}]	3597	delivery	5	14
9714	2019-10-04 14:25:40	2019-10-04	17	[{"id_menu":4,"count":1}]	209	pick-up	0	17
9715	2019-10-04 14:34:27	2019-10-04	8	[{"id_menu":5,"count":1}]	74	pick-up	0	8
9716	2019-10-04 14:42:51	2019-10-04	14	[{"id_menu":2,"count":1}]	3584	delivery	5	19
9717	2019-10-04 15:12:41	2019-10-04	14	[{"id_menu":2,"count":1}]	3461	delivery	5	19
9718	2019-10-04 15:46:26	2019-10-04	17	[{"id_menu":4,"count":1}]	274	pick-up	0	17
9719	2019-10-04 15:47:39	2019-10-04	17	[{"id_menu":4,"count":2}]	1929	pick-up	0	17
9720	2019-10-04 16:00:21	2019-10-04	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2695	delivery	5	22
9721	2019-10-04 16:11:38	2019-10-04	14	[{"id_menu":2,"count":1}]	3390	pick-up	0	14
9722	2019-10-04 16:36:58	2019-10-04	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	489	pick-up	0	29
9723	2019-10-04 17:23:52	2019-10-04	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	203	delivery	5	29
9724	2019-10-04 17:55:44	2019-10-04	14	[{"id_menu":2,"count":1}]	1189	pick-up	0	14
9725	2019-10-04 17:57:07	2019-10-04	14	[{"id_menu":2,"count":1}]	3263	pick-up	0	14
9726	2019-10-04 18:05:31	2019-10-04	9	[{"id_menu":6,"count":1}]	2123	delivery	5	14
9727	2019-10-04 18:40:05	2019-10-04	17	[{"id_menu":4,"count":1}]	3347	pick-up	0	17
9728	2019-10-04 19:05:57	2019-10-04	12	[{"id_menu":3,"count":1}]	3578	pick-up	0	12
9729	2019-10-04 19:06:56	2019-10-04	14	[{"id_menu":2,"count":1}]	3594	pick-up	0	14
9730	2019-10-04 19:24:08	2019-10-04	17	[{"id_menu":4,"count":1}]	2715	pick-up	0	17
9731	2019-10-04 19:34:46	2019-10-04	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3585	delivery	5	52
9732	2019-10-04 19:55:53	2019-10-04	9	[{"id_menu":7,"count":1}]	2748	pick-up	0	9
9733	2019-10-04 19:57:15	2019-10-04	17	[{"id_menu":4,"count":1}]	3580	delivery	5	22
9734	2019-10-04 20:05:01	2019-10-04	9	[{"id_menu":7,"count":1}]	1217	pick-up	0	9
9735	2019-10-04 20:16:58	2019-10-04	9	[{"id_menu":7,"count":1}]	3224	delivery	5	14
9736	2019-10-04 20:18:59	2019-10-04	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	731	delivery	5	46
9737	2019-10-04 20:35:49	2019-10-04	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3173	delivery	5	44
9738	2019-10-04 20:39:00	2019-10-04	17	[{"id_menu":4,"count":1}]	3601	delivery	5	22
9739	2019-10-04 20:39:13	2019-10-04	12	[{"id_menu":1,"count":1}]	2623	pick-up	0	12
9740	2019-10-04 21:21:36	2019-10-04	17	[{"id_menu":4,"count":1}]	304	delivery	5	22
9741	2019-10-04 21:57:28	2019-10-04	12	[{"id_menu":3,"count":1}]	3575	delivery	5	17
9742	2019-10-04 22:14:08	2019-10-04	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	3605	delivery	5	31
9743	2019-10-04 22:17:06	2019-10-04	12	[{"id_menu":1,"count":1}]	3600	pick-up	0	12
9744	2019-10-04 22:34:47	2019-10-04	9	[{"id_menu":6,"count":1}]	626	pick-up	0	9
9745	2019-10-04 22:38:09	2019-10-04	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2000	pick-up	0	21
9746	2019-10-04 22:39:00	2019-10-04	14	[{"id_menu":2,"count":1}]	202	pick-up	0	14
9747	2019-10-04 22:59:54	2019-10-04	9	[{"id_menu":7,"count":2}]	1627	delivery	5	14
9748	2019-10-04 23:05:54	2019-10-04	12	[{"id_menu":1,"count":1}]	1055	delivery	5	17
9749	2019-10-04 23:42:13	2019-10-04	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3059	delivery	5	35
9750	2019-10-05 00:05:56	2019-10-05	9	[{"id_menu":7,"count":1}]	227	pick-up	0	9
9751	2019-10-05 00:25:16	2019-10-05	14	[{"id_menu":2,"count":1}]	2539	pick-up	0	14
9752	2019-10-05 00:35:02	2019-10-05	17	[{"id_menu":4,"count":2}]	2592	pick-up	0	17
9753	2019-10-05 01:25:29	2019-10-05	9	[{"id_menu":6,"count":1}]	1559	pick-up	0	9
9754	2019-10-05 01:39:17	2019-10-05	17	[{"id_menu":4,"count":1}]	3642	delivery	5	22
9755	2019-10-05 01:39:30	2019-10-05	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2134	pick-up	0	38
9756	2019-10-05 01:49:14	2019-10-05	9	[{"id_menu":6,"count":1}]	3617	pick-up	0	9
9757	2019-10-05 02:09:23	2019-10-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3638	delivery	5	28
9758	2019-10-05 02:26:09	2019-10-05	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	931	pick-up	0	17
9759	2019-10-05 03:09:19	2019-10-05	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3640	pick-up	0	23
9760	2019-10-05 03:10:30	2019-10-05	12	[{"id_menu":1,"count":2}]	3627	pick-up	0	12
9761	2019-10-05 03:12:15	2019-10-05	12	[{"id_menu":1,"count":1}]	1140	delivery	5	17
9762	2019-10-05 03:33:44	2019-10-05	9	[{"id_menu":7,"count":1}]	3308	delivery	5	14
9763	2019-10-05 03:35:46	2019-10-05	17	[{"id_menu":4,"count":1}]	3403	pick-up	0	17
9764	2019-10-05 04:10:25	2019-10-05	14	[{"id_menu":2,"count":1}]	2442	pick-up	0	14
9765	2019-10-05 04:16:34	2019-10-05	9	[{"id_menu":6,"count":1}]	3613	delivery	5	14
9766	2019-10-05 04:30:18	2019-10-05	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2715	pick-up	0	33
9767	2019-10-05 04:39:30	2019-10-05	9	[{"id_menu":7,"count":1}]	3224	pick-up	0	9
9768	2019-10-05 04:42:06	2019-10-05	8	[{"id_menu":5,"count":1}]	3427	delivery	5	13
9769	2019-10-05 05:28:32	2019-10-05	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2736	pick-up	0	29
9770	2019-10-05 05:31:15	2019-10-05	14	[{"id_menu":2,"count":1}]	669	pick-up	0	14
9771	2019-10-05 05:44:46	2019-10-05	12	[{"id_menu":1,"count":1}]	3628	pick-up	0	12
9772	2019-10-05 05:52:47	2019-10-05	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3634	delivery	5	53
9773	2019-10-05 06:00:42	2019-10-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3643	pick-up	0	26
9774	2019-10-05 06:00:55	2019-10-05	12	[{"id_menu":1,"count":1}]	619	delivery	5	17
9775	2019-10-05 06:03:27	2019-10-05	14	[{"id_menu":2,"count":2}]	3488	delivery	5	19
9776	2019-10-05 06:05:37	2019-10-05	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	3623	pick-up	0	29
9777	2019-10-05 06:43:18	2019-10-05	8	[{"id_menu":5,"count":1}]	3610	delivery	5	13
9778	2019-10-05 07:21:58	2019-10-05	9	[{"id_menu":6,"count":1}]	2472	pick-up	0	9
9779	2019-10-05 07:49:33	2019-10-05	12	[{"id_menu":3,"count":1}]	2085	pick-up	0	12
9780	2019-10-05 07:50:04	2019-10-05	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3604	pick-up	0	25
9781	2019-10-05 08:38:17	2019-10-05	9	[{"id_menu":6,"count":1}]	2606	pick-up	0	9
9782	2019-10-05 08:42:21	2019-10-05	9	[{"id_menu":6,"count":1}]	111	pick-up	0	9
9783	2019-10-05 09:04:35	2019-10-05	12	[{"id_menu":1,"count":1}]	2616	pick-up	0	12
9784	2019-10-05 09:17:46	2019-10-05	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2513	delivery	5	31
9785	2019-10-05 09:24:41	2019-10-05	17	[{"id_menu":4,"count":1}]	826	pick-up	0	17
9786	2019-10-05 09:44:46	2019-10-05	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	3612	delivery	5	39
9787	2019-10-05 09:59:25	2019-10-05	9	[{"id_menu":7,"count":1}]	2162	pick-up	0	9
9788	2019-10-05 10:08:08	2019-10-05	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	2263	delivery	5	31
9789	2019-10-05 10:13:31	2019-10-05	12	[{"id_menu":1,"count":1}]	2228	pick-up	0	12
9790	2019-10-05 10:48:33	2019-10-05	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	2507	delivery	5	26
9791	2019-10-05 10:54:30	2019-10-05	8	[{"id_menu":5,"count":1}]	3631	delivery	5	13
9792	2019-10-05 11:29:47	2019-10-05	9	[{"id_menu":6,"count":1}]	2887	delivery	5	14
9793	2019-10-05 11:52:14	2019-10-05	12	[{"id_menu":3,"count":1}]	1819	pick-up	0	12
9794	2019-10-05 11:58:33	2019-10-05	9	[{"id_menu":7,"count":1}]	2375	delivery	5	14
9795	2019-10-05 12:05:05	2019-10-05	12	[{"id_menu":1,"count":1}]	256	pick-up	0	12
9796	2019-10-05 12:10:32	2019-10-05	17	[{"id_menu":4,"count":3}]	462	delivery	5	22
9797	2019-10-05 12:12:08	2019-10-05	9	[{"id_menu":6,"count":1}]	3611	delivery	5	14
9798	2019-10-05 12:16:30	2019-10-05	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	3335	pick-up	0	21
9799	2019-10-05 12:35:03	2019-10-05	8	[{"id_menu":5,"count":1}]	1840	delivery	5	13
9800	2019-10-05 12:43:17	2019-10-05	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2699	delivery	5	26
9801	2019-10-05 12:46:55	2019-10-05	8	[{"id_menu":5,"count":1}]	3629	delivery	5	13
9802	2019-10-05 13:18:16	2019-10-05	8	[{"id_menu":5,"count":1}]	3637	pick-up	0	8
9803	2019-10-05 13:23:49	2019-10-05	9	[{"id_menu":7,"count":1}]	2688	pick-up	0	9
9804	2019-10-05 13:28:21	2019-10-05	17	[{"id_menu":4,"count":1}]	3632	pick-up	0	17
9805	2019-10-05 13:36:58	2019-10-05	9	[{"id_menu":6,"count":1}]	3639	delivery	5	14
9806	2019-10-05 13:40:10	2019-10-05	9	[{"id_menu":6,"count":1}]	3618	pick-up	0	9
9807	2019-10-05 13:40:29	2019-10-05	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3646	delivery	5	37
9808	2019-10-05 13:43:42	2019-10-05	9	[{"id_menu":7,"count":1}]	946	pick-up	0	9
9809	2019-10-05 13:46:38	2019-10-05	9	[{"id_menu":7,"count":1}]	3624	pick-up	0	9
9810	2019-10-05 14:15:12	2019-10-05	9	[{"id_menu":6,"count":1}]	3615	delivery	5	14
9811	2019-10-05 14:20:29	2019-10-05	9	[{"id_menu":7,"count":2}]	2462	pick-up	0	9
9812	2019-10-05 14:26:55	2019-10-05	38	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1810	pick-up	0	38
9813	2019-10-05 14:50:26	2019-10-05	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3059	delivery	5	30
9814	2019-10-05 15:00:34	2019-10-05	9	[{"id_menu":6,"count":1}]	3630	delivery	5	14
9815	2019-10-05 15:29:13	2019-10-05	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1306	pick-up	0	24
9816	2019-10-05 15:35:01	2019-10-05	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	941	pick-up	0	31
9817	2019-10-05 15:50:12	2019-10-05	17	[{"id_menu":4,"count":1}]	2200	pick-up	0	17
9818	2019-10-05 15:53:23	2019-10-05	12	[{"id_menu":1,"count":1}]	3635	pick-up	0	12
9819	2019-10-05 15:58:23	2019-10-05	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2232	delivery	5	34
9820	2019-10-05 16:12:07	2019-10-05	9	[{"id_menu":7,"count":3}]	3238	delivery	5	14
9821	2019-10-05 16:45:12	2019-10-05	12	[{"id_menu":3,"count":1}]	3609	pick-up	0	12
9822	2019-10-05 16:46:00	2019-10-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3622	pick-up	0	18
9823	2019-10-05 16:46:27	2019-10-05	9	[{"id_menu":7,"count":1}]	2623	delivery	5	14
9824	2019-10-05 16:55:06	2019-10-05	9	[{"id_menu":7,"count":1}]	1924	delivery	5	14
9825	2019-10-05 16:59:15	2019-10-05	14	[{"id_menu":2,"count":1}]	2807	pick-up	0	14
9826	2019-10-05 17:24:25	2019-10-05	8	[{"id_menu":5,"count":1}]	640	pick-up	0	8
9827	2019-10-05 17:27:59	2019-10-05	12	[{"id_menu":3,"count":1}]	889	delivery	5	17
9828	2019-10-05 17:29:44	2019-10-05	12	[{"id_menu":3,"count":1}]	172	pick-up	0	12
9829	2019-10-05 17:37:02	2019-10-05	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	832	delivery	5	28
9830	2019-10-05 17:51:22	2019-10-05	17	[{"id_menu":4,"count":1}]	3619	delivery	5	22
9831	2019-10-05 17:56:04	2019-10-05	17	[{"id_menu":4,"count":2}]	3645	delivery	5	22
9832	2019-10-05 17:56:05	2019-10-05	14	[{"id_menu":2,"count":1}]	1356	pick-up	0	14
9833	2019-10-05 17:59:59	2019-10-05	14	[{"id_menu":2,"count":1}]	3616	delivery	5	19
9834	2019-10-05 18:03:57	2019-10-05	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	3321	delivery	5	45
9835	2019-10-05 18:04:24	2019-10-05	12	[{"id_menu":3,"count":1}]	2965	delivery	5	17
9836	2019-10-05 18:24:07	2019-10-05	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	3626	delivery	5	26
9837	2019-10-05 18:55:55	2019-10-05	8	[{"id_menu":5,"count":1}]	1467	delivery	5	13
9838	2019-10-05 19:04:00	2019-10-05	14	[{"id_menu":2,"count":1}]	2770	delivery	5	19
9839	2019-10-05 19:04:48	2019-10-05	9	[{"id_menu":6,"count":1}]	2729	delivery	5	14
9840	2019-10-05 19:12:22	2019-10-05	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3633	delivery	5	31
9841	2019-10-05 19:54:07	2019-10-05	9	[{"id_menu":6,"count":1}]	3380	pick-up	0	9
9842	2019-10-05 20:09:39	2019-10-05	9	[{"id_menu":6,"count":1}]	203	pick-up	0	9
9843	2019-10-05 20:10:24	2019-10-05	17	[{"id_menu":4,"count":1}]	599	delivery	5	22
9844	2019-10-05 20:10:27	2019-10-05	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3625	delivery	5	31
9845	2019-10-05 20:13:13	2019-10-05	9	[{"id_menu":7,"count":1}]	3641	delivery	5	14
9846	2019-10-05 20:20:06	2019-10-05	12	[{"id_menu":1,"count":1}]	3620	delivery	5	17
9847	2019-10-05 20:21:50	2019-10-05	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3614	pick-up	0	22
9848	2019-10-05 20:45:59	2019-10-05	12	[{"id_menu":3,"count":1}]	707	delivery	5	17
9849	2019-10-05 21:08:41	2019-10-05	8	[{"id_menu":5,"count":1}]	3636	pick-up	0	8
9850	2019-10-05 21:18:26	2019-10-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2132	pick-up	0	18
9851	2019-10-05 21:25:38	2019-10-05	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2470	pick-up	0	25
9852	2019-10-05 21:56:03	2019-10-05	17	[{"id_menu":4,"count":1}]	3324	pick-up	0	17
9853	2019-10-05 21:56:39	2019-10-05	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	3644	delivery	5	39
9854	2019-10-05 21:58:09	2019-10-05	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	3621	delivery	5	31
9855	2019-10-05 22:13:52	2019-10-05	8	[{"id_menu":5,"count":1}]	678	pick-up	0	8
9856	2019-10-05 22:54:23	2019-10-05	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2114	pick-up	0	21
9857	2019-10-05 23:31:09	2019-10-05	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1993	delivery	5	25
9858	2019-10-06 00:03:16	2019-10-06	12	[{"id_menu":1,"count":1}]	160	pick-up	0	12
9859	2019-10-06 00:08:19	2019-10-06	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	3658	delivery	5	34
9860	2019-10-06 00:21:46	2019-10-06	9	[{"id_menu":6,"count":2}]	2488	pick-up	0	9
9861	2019-10-06 00:25:23	2019-10-06	9	[{"id_menu":7,"count":1}]	3659	pick-up	0	9
9862	2019-10-06 01:27:27	2019-10-06	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1289	delivery	5	26
9863	2019-10-06 01:38:21	2019-10-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3653	delivery	5	28
9864	2019-10-06 01:50:05	2019-10-06	12	[{"id_menu":1,"count":1}]	2276	pick-up	0	12
9865	2019-10-06 01:56:39	2019-10-06	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1914	pick-up	0	31
9866	2019-10-06 01:58:03	2019-10-06	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	577	delivery	5	22
9867	2019-10-06 02:11:17	2019-10-06	14	[{"id_menu":2,"count":1}]	2954	pick-up	0	14
9868	2019-10-06 02:37:30	2019-10-06	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	2956	pick-up	0	21
9869	2019-10-06 02:49:06	2019-10-06	8	[{"id_menu":5,"count":1}]	1727	pick-up	0	8
9870	2019-10-06 02:56:33	2019-10-06	9	[{"id_menu":7,"count":1}]	2367	delivery	5	14
9871	2019-10-06 02:58:24	2019-10-06	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1070	pick-up	0	31
9872	2019-10-06 03:19:55	2019-10-06	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3130	pick-up	0	26
9873	2019-10-06 03:23:15	2019-10-06	9	[{"id_menu":6,"count":1}]	2890	delivery	5	14
9874	2019-10-06 03:27:22	2019-10-06	9	[{"id_menu":6,"count":2}]	3683	delivery	5	14
9875	2019-10-06 03:54:24	2019-10-06	9	[{"id_menu":6,"count":1}]	3662	delivery	5	14
9876	2019-10-06 04:07:20	2019-10-06	43	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3668	delivery	5	48
9877	2019-10-06 04:09:09	2019-10-06	30	[{"id_menu":3,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	956	pick-up	0	30
9878	2019-10-06 04:09:22	2019-10-06	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1373	pick-up	0	31
9879	2019-10-06 04:24:14	2019-10-06	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2562	pick-up	0	20
9880	2019-10-06 04:39:34	2019-10-06	38	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3661	delivery	5	43
9881	2019-10-06 05:00:06	2019-10-06	14	[{"id_menu":2,"count":4}]	3629	delivery	5	19
9882	2019-10-06 05:46:35	2019-10-06	8	[{"id_menu":5,"count":1}]	1380	delivery	5	13
9883	2019-10-06 06:07:57	2019-10-06	12	[{"id_menu":1,"count":1}]	3648	delivery	5	17
9884	2019-10-06 06:25:22	2019-10-06	9	[{"id_menu":6,"count":1}]	3680	pick-up	0	9
9885	2019-10-06 06:38:22	2019-10-06	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2583	delivery	5	56
9886	2019-10-06 06:45:26	2019-10-06	17	[{"id_menu":4,"count":1}]	346	pick-up	0	17
9887	2019-10-06 07:04:34	2019-10-06	14	[{"id_menu":2,"count":1}]	338	pick-up	0	14
9888	2019-10-06 07:07:15	2019-10-06	17	[{"id_menu":4,"count":1}]	2622	pick-up	0	17
9889	2019-10-06 07:30:53	2019-10-06	14	[{"id_menu":2,"count":1}]	1595	delivery	5	19
9890	2019-10-06 07:49:54	2019-10-06	12	[{"id_menu":3,"count":1}]	3318	pick-up	0	12
9891	2019-10-06 07:55:12	2019-10-06	12	[{"id_menu":3,"count":1}]	3603	delivery	5	17
9892	2019-10-06 08:18:18	2019-10-06	12	[{"id_menu":1,"count":2}]	3660	pick-up	0	12
9893	2019-10-06 08:21:31	2019-10-06	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	311	delivery	5	31
9894	2019-10-06 08:30:57	2019-10-06	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	650	delivery	5	45
9895	2019-10-06 08:34:08	2019-10-06	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1412	delivery	5	26
9896	2019-10-06 08:39:43	2019-10-06	9	[{"id_menu":6,"count":1}]	3673	delivery	5	14
9897	2019-10-06 08:40:56	2019-10-06	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1754	delivery	5	42
9898	2019-10-06 08:53:52	2019-10-06	12	[{"id_menu":1,"count":1}]	2277	pick-up	0	12
9899	2019-10-06 08:57:43	2019-10-06	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	2358	delivery	5	25
9900	2019-10-06 09:00:35	2019-10-06	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3647	delivery	5	26
9901	2019-10-06 09:05:14	2019-10-06	14	[{"id_menu":2,"count":1}]	728	delivery	5	19
9902	2019-10-06 09:10:24	2019-10-06	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1924	pick-up	0	38
9903	2019-10-06 09:10:26	2019-10-06	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	654	pick-up	0	26
9904	2019-10-06 09:30:16	2019-10-06	8	[{"id_menu":5,"count":1}]	3678	pick-up	0	8
9905	2019-10-06 09:30:20	2019-10-06	9	[{"id_menu":6,"count":1}]	2477	pick-up	0	9
9906	2019-10-06 09:35:20	2019-10-06	9	[{"id_menu":6,"count":1}]	1568	pick-up	0	9
9907	2019-10-06 09:43:36	2019-10-06	14	[{"id_menu":2,"count":2}]	330	pick-up	0	14
9908	2019-10-06 09:48:40	2019-10-06	14	[{"id_menu":2,"count":1}]	3652	pick-up	0	14
9909	2019-10-06 09:50:10	2019-10-06	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2445	delivery	5	31
9910	2019-10-06 09:56:29	2019-10-06	9	[{"id_menu":6,"count":1}]	3665	delivery	5	14
9911	2019-10-06 09:58:32	2019-10-06	9	[{"id_menu":7,"count":1}]	3666	delivery	5	14
9912	2019-10-06 09:59:42	2019-10-06	12	[{"id_menu":1,"count":1}]	1678	pick-up	0	12
9913	2019-10-06 10:14:09	2019-10-06	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3579	delivery	5	26
9914	2019-10-06 10:19:17	2019-10-06	17	[{"id_menu":4,"count":1}]	511	pick-up	0	17
9915	2019-10-06 10:41:01	2019-10-06	8	[{"id_menu":5,"count":1}]	376	pick-up	0	8
9916	2019-10-06 10:44:08	2019-10-06	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	3671	delivery	5	26
9917	2019-10-06 11:00:19	2019-10-06	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3670	pick-up	0	29
9918	2019-10-06 11:15:43	2019-10-06	8	[{"id_menu":5,"count":1}]	3649	delivery	5	13
9919	2019-10-06 11:16:30	2019-10-06	14	[{"id_menu":2,"count":1}]	2368	delivery	5	19
9920	2019-10-06 11:20:41	2019-10-06	8	[{"id_menu":5,"count":1}]	3225	pick-up	0	8
9921	2019-10-06 11:27:13	2019-10-06	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":2}]	3667	delivery	5	26
9922	2019-10-06 11:55:29	2019-10-06	14	[{"id_menu":2,"count":1}]	1633	pick-up	0	14
9923	2019-10-06 11:59:24	2019-10-06	14	[{"id_menu":2,"count":2}]	3672	pick-up	0	14
9924	2019-10-06 12:22:34	2019-10-06	9	[{"id_menu":7,"count":1}]	3682	delivery	5	14
9925	2019-10-06 12:33:24	2019-10-06	9	[{"id_menu":6,"count":2}]	3679	delivery	5	14
9926	2019-10-06 12:39:09	2019-10-06	9	[{"id_menu":6,"count":2}]	3676	delivery	5	14
9927	2019-10-06 12:41:31	2019-10-06	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	1963	pick-up	0	29
9928	2019-10-06 12:48:37	2019-10-06	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	41	delivery	5	36
9929	2019-10-06 12:51:19	2019-10-06	12	[{"id_menu":1,"count":1}]	3675	delivery	5	17
9930	2019-10-06 12:55:57	2019-10-06	12	[{"id_menu":3,"count":1}]	315	pick-up	0	12
9931	2019-10-06 13:04:42	2019-10-06	17	[{"id_menu":4,"count":2}]	1932	pick-up	0	17
9932	2019-10-06 13:14:04	2019-10-06	9	[{"id_menu":7,"count":1}]	2153	pick-up	0	9
9933	2019-10-06 14:10:22	2019-10-06	9	[{"id_menu":6,"count":1}]	3459	delivery	5	14
9934	2019-10-06 14:11:58	2019-10-06	8	[{"id_menu":5,"count":1}]	3677	delivery	5	13
9935	2019-10-06 14:21:42	2019-10-06	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	3651	delivery	5	25
9936	2019-10-06 14:26:44	2019-10-06	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	816	delivery	5	31
9937	2019-10-06 14:38:21	2019-10-06	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	172	pick-up	0	18
9938	2019-10-06 14:46:06	2019-10-06	14	[{"id_menu":2,"count":1}]	1563	pick-up	0	14
9939	2019-10-06 15:25:58	2019-10-06	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3655	pick-up	0	25
9940	2019-10-06 15:35:18	2019-10-06	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2243	pick-up	0	23
9941	2019-10-06 15:39:03	2019-10-06	17	[{"id_menu":4,"count":1}]	2197	delivery	5	22
9942	2019-10-06 15:44:13	2019-10-06	12	[{"id_menu":1,"count":1}]	3674	pick-up	0	12
9943	2019-10-06 15:53:09	2019-10-06	12	[{"id_menu":3,"count":1}]	1435	pick-up	0	12
9944	2019-10-06 15:53:30	2019-10-06	12	[{"id_menu":3,"count":1}]	78	delivery	5	17
9945	2019-10-06 15:57:44	2019-10-06	17	[{"id_menu":4,"count":1}]	3069	pick-up	0	17
9946	2019-10-06 16:44:27	2019-10-06	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3654	delivery	5	40
9947	2019-10-06 17:08:22	2019-10-06	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1161	pick-up	0	17
9948	2019-10-06 17:26:01	2019-10-06	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1569	delivery	5	36
9949	2019-10-06 17:27:27	2019-10-06	17	[{"id_menu":4,"count":1}]	2815	delivery	5	22
9950	2019-10-06 17:42:07	2019-10-06	9	[{"id_menu":7,"count":1}]	3211	delivery	5	14
9951	2019-10-06 17:47:42	2019-10-06	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3681	delivery	5	43
9952	2019-10-06 17:52:36	2019-10-06	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	232	pick-up	0	26
9953	2019-10-06 17:56:07	2019-10-06	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	236	pick-up	0	26
9954	2019-10-06 18:06:56	2019-10-06	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2283	pick-up	0	29
9955	2019-10-06 18:24:55	2019-10-06	12	[{"id_menu":3,"count":1}]	3657	pick-up	0	12
9956	2019-10-06 18:25:49	2019-10-06	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2781	delivery	5	25
9957	2019-10-06 18:29:14	2019-10-06	12	[{"id_menu":3,"count":1}]	1303	pick-up	0	12
9958	2019-10-06 18:30:47	2019-10-06	9	[{"id_menu":7,"count":1}]	683	pick-up	0	9
9959	2019-10-06 18:50:08	2019-10-06	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3343	delivery	5	31
9960	2019-10-06 18:55:16	2019-10-06	9	[{"id_menu":7,"count":2}]	3663	pick-up	0	9
9961	2019-10-06 18:58:58	2019-10-06	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2706	delivery	5	31
9962	2019-10-06 19:06:33	2019-10-06	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2143	delivery	5	26
9963	2019-10-06 19:18:02	2019-10-06	9	[{"id_menu":7,"count":1}]	469	delivery	5	14
9964	2019-10-06 19:22:29	2019-10-06	12	[{"id_menu":1,"count":1}]	290	delivery	5	17
9965	2019-10-06 19:35:32	2019-10-06	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3664	delivery	5	48
9966	2019-10-06 20:10:11	2019-10-06	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1311	pick-up	0	23
9967	2019-10-06 20:17:21	2019-10-06	17	[{"id_menu":4,"count":2}]	2742	pick-up	0	17
9968	2019-10-06 20:22:30	2019-10-06	12	[{"id_menu":1,"count":1}]	1245	pick-up	0	12
9969	2019-10-06 20:23:34	2019-10-06	9	[{"id_menu":7,"count":1}]	3335	pick-up	0	9
9970	2019-10-06 20:55:16	2019-10-06	9	[{"id_menu":6,"count":1}]	1523	pick-up	0	9
9971	2019-10-06 21:06:40	2019-10-06	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3669	pick-up	0	41
9972	2019-10-06 21:10:03	2019-10-06	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	136	pick-up	0	31
9973	2019-10-06 21:25:11	2019-10-06	14	[{"id_menu":2,"count":1}]	3102	pick-up	0	14
9974	2019-10-06 21:56:49	2019-10-06	14	[{"id_menu":2,"count":1}]	1457	delivery	5	19
9975	2019-10-06 22:13:46	2019-10-06	14	[{"id_menu":2,"count":1}]	2041	delivery	5	19
9976	2019-10-06 22:29:46	2019-10-06	12	[{"id_menu":1,"count":1}]	2257	pick-up	0	12
9977	2019-10-06 22:40:09	2019-10-06	14	[{"id_menu":2,"count":1}]	3650	delivery	5	19
9978	2019-10-06 22:58:51	2019-10-06	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	2868	delivery	5	26
9979	2019-10-06 23:04:27	2019-10-06	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2070	pick-up	0	29
9980	2019-10-06 23:05:47	2019-10-06	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2960	pick-up	0	38
9981	2019-10-06 23:08:13	2019-10-06	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	3656	delivery	5	25
9982	2019-10-06 23:10:10	2019-10-06	9	[{"id_menu":7,"count":1}]	3116	pick-up	0	9
9983	2019-10-06 23:10:53	2019-10-06	14	[{"id_menu":2,"count":1}]	3148	pick-up	0	14
9984	2019-10-06 23:15:45	2019-10-06	9	[{"id_menu":7,"count":1}]	1417	pick-up	0	9
9985	2019-10-06 23:25:11	2019-10-06	12	[{"id_menu":1,"count":1}]	193	pick-up	0	12
9986	2019-10-06 23:28:31	2019-10-06	9	[{"id_menu":6,"count":1}]	1781	delivery	5	14
9987	2019-10-06 23:42:11	2019-10-06	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	2386	delivery	5	31
9988	2019-10-07 00:00:34	2019-10-07	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2125	pick-up	0	32
9989	2019-10-07 00:19:03	2019-10-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3708	delivery	5	28
9990	2019-10-07 00:27:48	2019-10-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3688	delivery	5	23
9991	2019-10-07 00:28:18	2019-10-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1107	pick-up	0	23
9992	2019-10-07 02:03:46	2019-10-07	9	[{"id_menu":7,"count":1}]	655	pick-up	0	9
9993	2019-10-07 02:37:23	2019-10-07	9	[{"id_menu":6,"count":1}]	3710	pick-up	0	9
9994	2019-10-07 02:40:19	2019-10-07	9	[{"id_menu":7,"count":1}]	3696	pick-up	0	9
9995	2019-10-07 02:55:13	2019-10-07	12	[{"id_menu":1,"count":1}]	3686	pick-up	0	12
9996	2019-10-07 02:57:03	2019-10-07	17	[{"id_menu":4,"count":1}]	2149	pick-up	0	17
9997	2019-10-07 03:36:08	2019-10-07	9	[{"id_menu":7,"count":1}]	262	pick-up	0	9
9998	2019-10-07 03:59:50	2019-10-07	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3043	delivery	5	31
9999	2019-10-07 04:06:33	2019-10-07	9	[{"id_menu":6,"count":1}]	2567	delivery	5	14
10000	2019-10-07 04:10:57	2019-10-07	9	[{"id_menu":6,"count":1}]	3694	delivery	5	14
10001	2019-10-07 04:19:06	2019-10-07	9	[{"id_menu":7,"count":1}]	3690	delivery	5	14
10002	2019-10-07 05:20:02	2019-10-07	17	[{"id_menu":4,"count":1}]	73	pick-up	0	17
10003	2019-10-07 05:40:51	2019-10-07	9	[{"id_menu":6,"count":1}]	3691	delivery	5	14
10004	2019-10-07 05:41:39	2019-10-07	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	3692	delivery	5	22
10005	2019-10-07 05:59:35	2019-10-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1968	delivery	5	28
10006	2019-10-07 06:26:59	2019-10-07	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	3684	delivery	5	27
10007	2019-10-07 06:41:19	2019-10-07	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1699	pick-up	0	32
10008	2019-10-07 07:44:09	2019-10-07	8	[{"id_menu":5,"count":1}]	1776	delivery	5	13
10009	2019-10-07 09:41:31	2019-10-07	8	[{"id_menu":5,"count":1}]	3697	delivery	5	13
10010	2019-10-07 09:51:06	2019-10-07	8	[{"id_menu":5,"count":1}]	1233	pick-up	0	8
10011	2019-10-07 09:54:32	2019-10-07	9	[{"id_menu":6,"count":1}]	3689	delivery	5	14
10012	2019-10-07 10:09:08	2019-10-07	9	[{"id_menu":6,"count":1}]	602	delivery	5	14
10013	2019-10-07 10:21:58	2019-10-07	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3713	pick-up	0	40
10014	2019-10-07 10:47:24	2019-10-07	14	[{"id_menu":2,"count":1}]	2633	pick-up	0	14
10015	2019-10-07 11:07:16	2019-10-07	12	[{"id_menu":3,"count":1}]	2456	delivery	5	17
10016	2019-10-07 11:20:07	2019-10-07	14	[{"id_menu":2,"count":1}]	1403	pick-up	0	14
10017	2019-10-07 11:51:41	2019-10-07	8	[{"id_menu":5,"count":1}]	2927	delivery	5	13
10018	2019-10-07 12:41:50	2019-10-07	9	[{"id_menu":6,"count":1}]	3243	delivery	5	14
10019	2019-10-07 13:51:03	2019-10-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	379	pick-up	0	17
10020	2019-10-07 13:52:02	2019-10-07	17	[{"id_menu":4,"count":1}]	1037	pick-up	0	17
10021	2019-10-07 13:57:28	2019-10-07	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2832	delivery	5	31
10022	2019-10-07 13:58:06	2019-10-07	14	[{"id_menu":2,"count":1}]	1523	delivery	5	19
10023	2019-10-07 14:06:17	2019-10-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2570	pick-up	0	21
10024	2019-10-07 14:25:42	2019-10-07	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	3460	delivery	5	40
10025	2019-10-07 14:55:50	2019-10-07	9	[{"id_menu":7,"count":1}]	1681	pick-up	0	9
10026	2019-10-07 15:10:00	2019-10-07	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	1481	pick-up	0	21
10027	2019-10-07 16:04:04	2019-10-07	9	[{"id_menu":6,"count":1}]	3709	pick-up	0	9
10028	2019-10-07 16:10:29	2019-10-07	17	[{"id_menu":4,"count":1}]	3714	delivery	5	22
10029	2019-10-07 16:19:43	2019-10-07	9	[{"id_menu":7,"count":1}]	1092	delivery	5	14
10030	2019-10-07 16:20:16	2019-10-07	9	[{"id_menu":7,"count":1}]	2217	delivery	5	14
10031	2019-10-07 16:58:08	2019-10-07	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	180	delivery	5	34
10032	2019-10-07 17:06:29	2019-10-07	9	[{"id_menu":7,"count":1}]	3706	delivery	5	14
10033	2019-10-07 17:16:47	2019-10-07	17	[{"id_menu":4,"count":1}]	270	pick-up	0	17
10034	2019-10-07 17:22:35	2019-10-07	12	[{"id_menu":1,"count":1}]	990	pick-up	0	12
10035	2019-10-07 18:47:12	2019-10-07	9	[{"id_menu":7,"count":1}]	516	delivery	5	14
10036	2019-10-07 18:49:48	2019-10-07	9	[{"id_menu":6,"count":1}]	3378	delivery	5	14
10037	2019-10-07 19:44:56	2019-10-07	14	[{"id_menu":2,"count":1}]	1357	pick-up	0	14
10038	2019-10-07 20:06:08	2019-10-07	9	[{"id_menu":7,"count":1}]	351	delivery	5	14
10039	2019-10-07 21:08:10	2019-10-07	17	[{"id_menu":4,"count":1}]	2309	pick-up	0	17
10040	2019-10-07 21:32:20	2019-10-07	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3699	delivery	5	40
10041	2019-10-07 22:30:46	2019-10-07	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2728	pick-up	0	35
10042	2019-10-07 22:37:23	2019-10-07	17	[{"id_menu":4,"count":1}]	3170	delivery	5	22
10043	2019-10-07 22:55:05	2019-10-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3700	delivery	5	28
10044	2019-10-07 23:23:42	2019-10-07	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1448	delivery	5	45
10045	2019-10-08 00:16:12	2019-10-08	14	[{"id_menu":2,"count":1}]	3298	delivery	5	19
10046	2019-10-08 00:42:21	2019-10-08	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	3739	delivery	5	31
10047	2019-10-08 00:56:07	2019-10-08	8	[{"id_menu":5,"count":1}]	18	pick-up	0	8
10048	2019-10-08 01:25:01	2019-10-08	8	[{"id_menu":5,"count":1}]	3737	pick-up	0	8
10049	2019-10-08 01:32:47	2019-10-08	8	[{"id_menu":5,"count":1}]	1460	pick-up	0	8
10050	2019-10-08 01:47:20	2019-10-08	12	[{"id_menu":1,"count":1}]	2993	pick-up	0	12
10051	2019-10-08 01:56:10	2019-10-08	9	[{"id_menu":7,"count":1}]	3155	pick-up	0	9
10052	2019-10-08 02:17:14	2019-10-08	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1344	pick-up	0	26
10053	2019-10-08 02:22:26	2019-10-08	9	[{"id_menu":7,"count":1}]	3744	delivery	5	14
10054	2019-10-08 02:31:44	2019-10-08	9	[{"id_menu":6,"count":1}]	3446	delivery	5	14
10055	2019-10-08 03:08:23	2019-10-08	14	[{"id_menu":2,"count":1}]	684	pick-up	0	14
10056	2019-10-08 04:12:23	2019-10-08	9	[{"id_menu":7,"count":1}]	3717	delivery	5	14
10057	2019-10-08 05:00:09	2019-10-08	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	3740	delivery	5	31
10058	2019-10-08 05:03:34	2019-10-08	9	[{"id_menu":7,"count":1}]	3723	delivery	5	14
10059	2019-10-08 05:04:53	2019-10-08	9	[{"id_menu":7,"count":1}]	3176	pick-up	0	9
10060	2019-10-08 05:09:51	2019-10-08	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3343	delivery	5	34
10061	2019-10-08 05:11:54	2019-10-08	12	[{"id_menu":1,"count":1}]	3732	delivery	5	17
10062	2019-10-08 05:29:53	2019-10-08	8	[{"id_menu":5,"count":1}]	1979	delivery	5	13
10063	2019-10-08 05:36:07	2019-10-08	9	[{"id_menu":6,"count":1}]	2228	delivery	5	14
10064	2019-10-08 05:53:26	2019-10-08	12	[{"id_menu":3,"count":1}]	21	delivery	5	17
10065	2019-10-08 06:01:34	2019-10-08	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3733	delivery	5	26
10066	2019-10-08 06:19:18	2019-10-08	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3746	delivery	5	31
10067	2019-10-08 06:23:28	2019-10-08	12	[{"id_menu":1,"count":1}]	3741	pick-up	0	12
10068	2019-10-08 06:43:46	2019-10-08	9	[{"id_menu":6,"count":1}]	1053	delivery	5	14
10069	2019-10-08 06:46:35	2019-10-08	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2083	pick-up	0	25
10070	2019-10-08 07:01:18	2019-10-08	14	[{"id_menu":2,"count":1}]	754	pick-up	0	14
10071	2019-10-08 07:38:38	2019-10-08	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1375	pick-up	0	21
10072	2019-10-08 07:49:38	2019-10-08	9	[{"id_menu":6,"count":1}]	839	pick-up	0	9
10073	2019-10-08 07:58:38	2019-10-08	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2398	pick-up	0	34
10074	2019-10-08 08:02:25	2019-10-08	9	[{"id_menu":7,"count":1}]	3705	delivery	5	14
10075	2019-10-08 08:40:32	2019-10-08	8	[{"id_menu":5,"count":1}]	3721	delivery	5	13
10076	2019-10-08 08:41:03	2019-10-08	9	[{"id_menu":6,"count":1}]	3670	pick-up	0	9
10077	2019-10-08 09:01:01	2019-10-08	9	[{"id_menu":7,"count":1}]	3731	delivery	5	14
10078	2019-10-08 09:27:25	2019-10-08	8	[{"id_menu":5,"count":1}]	2633	pick-up	0	8
10079	2019-10-08 09:40:05	2019-10-08	8	[{"id_menu":5,"count":1}]	3716	pick-up	0	8
10080	2019-10-08 10:02:48	2019-10-08	8	[{"id_menu":5,"count":1}]	3747	delivery	5	13
10081	2019-10-08 10:03:54	2019-10-08	8	[{"id_menu":5,"count":1}]	1765	delivery	5	13
10082	2019-10-08 10:06:04	2019-10-08	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	3734	pick-up	0	20
10083	2019-10-08 10:11:04	2019-10-08	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2599	pick-up	0	26
10084	2019-10-08 10:29:34	2019-10-08	9	[{"id_menu":7,"count":2}]	1263	delivery	5	14
10085	2019-10-08 10:42:31	2019-10-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3719	pick-up	0	23
10086	2019-10-08 10:46:35	2019-10-08	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	695	pick-up	0	26
10087	2019-10-08 11:10:51	2019-10-08	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	3211	delivery	5	22
10088	2019-10-08 11:16:16	2019-10-08	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	153	pick-up	0	20
10089	2019-10-08 11:53:13	2019-10-08	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	973	pick-up	0	43
10090	2019-10-08 12:00:43	2019-10-08	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":3}]	3742	delivery	5	31
10091	2019-10-08 12:06:54	2019-10-08	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1834	pick-up	0	39
10092	2019-10-08 12:19:36	2019-10-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2733	delivery	5	23
10093	2019-10-08 12:25:05	2019-10-08	9	[{"id_menu":6,"count":1}]	3745	delivery	5	14
10094	2019-10-08 12:53:33	2019-10-08	17	[{"id_menu":4,"count":1}]	3725	pick-up	0	17
10095	2019-10-08 13:04:37	2019-10-08	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	310	pick-up	0	20
10096	2019-10-08 13:48:05	2019-10-08	12	[{"id_menu":1,"count":1}]	1214	delivery	5	17
10097	2019-10-08 14:28:36	2019-10-08	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	3379	delivery	5	25
10098	2019-10-08 14:28:40	2019-10-08	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	946	pick-up	0	21
10099	2019-10-08 15:02:51	2019-10-08	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	3363	pick-up	0	21
10100	2019-10-08 15:26:44	2019-10-08	8	[{"id_menu":5,"count":1}]	3728	pick-up	0	8
10101	2019-10-08 15:36:37	2019-10-08	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1131	pick-up	0	38
10102	2019-10-08 15:38:26	2019-10-08	9	[{"id_menu":7,"count":1}]	702	pick-up	0	9
10103	2019-10-08 15:48:20	2019-10-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3052	pick-up	0	23
10104	2019-10-08 15:52:08	2019-10-08	12	[{"id_menu":3,"count":1}]	3722	delivery	5	17
10105	2019-10-08 16:35:40	2019-10-08	9	[{"id_menu":6,"count":1}]	3729	pick-up	0	9
10106	2019-10-08 17:33:14	2019-10-08	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3139	pick-up	0	31
10107	2019-10-08 17:36:05	2019-10-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	612	delivery	5	28
10108	2019-10-08 18:23:56	2019-10-08	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2851	delivery	5	26
10109	2019-10-08 18:51:56	2019-10-08	17	[{"id_menu":4,"count":1}]	488	delivery	5	22
10110	2019-10-08 19:00:08	2019-10-08	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	669	pick-up	0	25
10111	2019-10-08 19:41:29	2019-10-08	14	[{"id_menu":2,"count":1}]	3215	pick-up	0	14
10112	2019-10-08 19:46:05	2019-10-08	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	2956	pick-up	0	38
10113	2019-10-08 20:06:21	2019-10-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	2507	delivery	5	23
10114	2019-10-08 20:13:38	2019-10-08	12	[{"id_menu":3,"count":1}]	2602	pick-up	0	12
10115	2019-10-08 20:21:58	2019-10-08	9	[{"id_menu":7,"count":1}]	868	pick-up	0	9
10116	2019-10-08 20:25:16	2019-10-08	14	[{"id_menu":2,"count":1}]	3727	delivery	5	19
10117	2019-10-08 20:41:02	2019-10-08	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2193	pick-up	0	21
10118	2019-10-08 21:07:46	2019-10-08	9	[{"id_menu":7,"count":1}]	440	delivery	5	14
10119	2019-10-08 21:08:24	2019-10-08	12	[{"id_menu":1,"count":1}]	1457	delivery	5	17
10120	2019-10-08 21:28:03	2019-10-08	12	[{"id_menu":3,"count":1}]	3726	delivery	5	17
10121	2019-10-08 21:40:14	2019-10-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1309	pick-up	0	23
10122	2019-10-08 21:45:59	2019-10-08	9	[{"id_menu":7,"count":1}]	264	pick-up	0	9
10123	2019-10-08 21:49:16	2019-10-08	9	[{"id_menu":6,"count":1}]	2860	pick-up	0	9
10124	2019-10-08 22:00:11	2019-10-08	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	63	pick-up	0	21
10125	2019-10-08 22:10:07	2019-10-08	14	[{"id_menu":2,"count":1}]	882	pick-up	0	14
10126	2019-10-08 22:38:30	2019-10-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1172	pick-up	0	17
10127	2019-10-08 22:50:26	2019-10-08	17	[{"id_menu":4,"count":1}]	3730	delivery	5	22
10128	2019-10-08 22:58:22	2019-10-08	9	[{"id_menu":7,"count":4}]	2386	delivery	5	14
10129	2019-10-09 00:11:58	2019-10-09	14	[{"id_menu":2,"count":1}]	265	delivery	5	19
10130	2019-10-09 00:13:07	2019-10-09	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	2139	delivery	5	36
10131	2019-10-09 00:19:56	2019-10-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3780	pick-up	0	18
10132	2019-10-09 00:22:10	2019-10-09	9	[{"id_menu":7,"count":1}]	3001	pick-up	0	9
10133	2019-10-09 01:18:43	2019-10-09	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3252	delivery	5	34
10134	2019-10-09 01:20:52	2019-10-09	14	[{"id_menu":2,"count":2}]	647	delivery	5	19
10135	2019-10-09 01:37:10	2019-10-09	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	122	pick-up	0	37
10136	2019-10-09 02:59:17	2019-10-09	9	[{"id_menu":6,"count":2}]	235	pick-up	0	9
10137	2019-10-09 03:11:35	2019-10-09	12	[{"id_menu":1,"count":1}]	701	pick-up	0	12
10138	2019-10-09 03:26:37	2019-10-09	9	[{"id_menu":7,"count":1}]	58	pick-up	0	9
10139	2019-10-09 03:34:22	2019-10-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	475	delivery	5	28
10140	2019-10-09 03:52:55	2019-10-09	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	3765	pick-up	0	26
10141	2019-10-09 04:13:51	2019-10-09	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1103	pick-up	0	31
10142	2019-10-09 04:49:00	2019-10-09	9	[{"id_menu":6,"count":1}]	68	delivery	5	14
10143	2019-10-09 05:02:00	2019-10-09	12	[{"id_menu":1,"count":1}]	3727	delivery	5	17
10144	2019-10-09 05:10:40	2019-10-09	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	3764	delivery	5	25
10145	2019-10-09 05:16:56	2019-10-09	17	[{"id_menu":4,"count":1}]	655	pick-up	0	17
10146	2019-10-09 05:40:28	2019-10-09	12	[{"id_menu":1,"count":1}]	1791	pick-up	0	12
10147	2019-10-09 05:55:50	2019-10-09	9	[{"id_menu":7,"count":1}]	3778	delivery	5	14
10148	2019-10-09 05:57:15	2019-10-09	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	389	pick-up	0	21
10149	2019-10-09 06:10:05	2019-10-09	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	3228	pick-up	0	37
10150	2019-10-09 06:11:41	2019-10-09	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	2619	delivery	5	29
10151	2019-10-09 06:40:00	2019-10-09	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3776	delivery	5	35
10152	2019-10-09 06:44:37	2019-10-09	12	[{"id_menu":1,"count":1}]	2327	pick-up	0	12
10153	2019-10-09 06:46:19	2019-10-09	12	[{"id_menu":3,"count":1}]	3768	delivery	5	17
10154	2019-10-09 07:22:54	2019-10-09	17	[{"id_menu":4,"count":1}]	1841	delivery	5	22
10155	2019-10-09 07:24:26	2019-10-09	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3766	pick-up	0	35
10156	2019-10-09 07:42:25	2019-10-09	14	[{"id_menu":2,"count":1}]	3771	delivery	5	19
10157	2019-10-09 07:45:25	2019-10-09	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2025	delivery	5	36
10158	2019-10-09 07:48:51	2019-10-09	12	[{"id_menu":3,"count":1}]	3283	pick-up	0	12
10159	2019-10-09 08:18:16	2019-10-09	12	[{"id_menu":3,"count":1}]	3774	delivery	5	17
10160	2019-10-09 08:26:12	2019-10-09	9	[{"id_menu":7,"count":1}]	1344	pick-up	0	9
10161	2019-10-09 08:35:39	2019-10-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1166	pick-up	0	23
10162	2019-10-09 09:43:05	2019-10-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	3289	pick-up	0	18
10163	2019-10-09 09:43:26	2019-10-09	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3757	delivery	5	31
10164	2019-10-09 09:44:42	2019-10-09	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3754	delivery	5	36
10165	2019-10-09 09:50:18	2019-10-09	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1323	pick-up	0	26
10166	2019-10-09 09:52:41	2019-10-09	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	3753	delivery	5	23
10167	2019-10-09 10:00:29	2019-10-09	9	[{"id_menu":7,"count":1}]	980	pick-up	0	9
10168	2019-10-09 10:05:15	2019-10-09	12	[{"id_menu":1,"count":1}]	1380	delivery	5	17
10169	2019-10-09 10:08:02	2019-10-09	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	3779	delivery	5	31
10170	2019-10-09 10:37:50	2019-10-09	8	[{"id_menu":5,"count":1}]	3043	delivery	5	13
10171	2019-10-09 11:32:18	2019-10-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1465	pick-up	0	23
10172	2019-10-09 11:33:16	2019-10-09	9	[{"id_menu":7,"count":1}]	1413	pick-up	0	9
10173	2019-10-09 11:37:25	2019-10-09	9	[{"id_menu":6,"count":1}]	1313	pick-up	0	9
10174	2019-10-09 11:53:02	2019-10-09	17	[{"id_menu":4,"count":1}]	3767	delivery	5	22
10175	2019-10-09 12:18:56	2019-10-09	17	[{"id_menu":4,"count":1}]	2552	pick-up	0	17
10176	2019-10-09 12:20:33	2019-10-09	17	[{"id_menu":4,"count":1}]	1453	delivery	5	22
10177	2019-10-09 12:23:11	2019-10-09	12	[{"id_menu":3,"count":1}]	1909	pick-up	0	12
10178	2019-10-09 12:23:25	2019-10-09	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1796	pick-up	0	39
10179	2019-10-09 12:42:59	2019-10-09	9	[{"id_menu":6,"count":1}]	2193	pick-up	0	9
10180	2019-10-09 12:44:20	2019-10-09	9	[{"id_menu":7,"count":1}]	2729	delivery	5	14
10181	2019-10-09 13:11:29	2019-10-09	9	[{"id_menu":6,"count":1}]	1549	delivery	5	14
10182	2019-10-09 13:13:26	2019-10-09	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	78	pick-up	0	21
10183	2019-10-09 13:16:35	2019-10-09	14	[{"id_menu":2,"count":1}]	2153	pick-up	0	14
10184	2019-10-09 13:21:19	2019-10-09	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	765	pick-up	0	22
10185	2019-10-09 13:34:55	2019-10-09	9	[{"id_menu":6,"count":1}]	437	delivery	5	14
10186	2019-10-09 14:23:54	2019-10-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3172	pick-up	0	18
10187	2019-10-09 14:59:20	2019-10-09	9	[{"id_menu":6,"count":1}]	3770	pick-up	0	9
10188	2019-10-09 15:40:44	2019-10-09	17	[{"id_menu":4,"count":1}]	590	delivery	5	22
10189	2019-10-09 15:52:26	2019-10-09	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	636	pick-up	0	26
10190	2019-10-09 16:14:15	2019-10-09	8	[{"id_menu":5,"count":2}]	925	delivery	5	13
10191	2019-10-09 16:16:56	2019-10-09	12	[{"id_menu":1,"count":1}]	3769	pick-up	0	12
10192	2019-10-09 16:21:49	2019-10-09	12	[{"id_menu":3,"count":1}]	3772	pick-up	0	12
10193	2019-10-09 16:51:25	2019-10-09	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3748	delivery	5	31
10194	2019-10-09 16:57:46	2019-10-09	12	[{"id_menu":3,"count":1}]	2004	delivery	5	17
10195	2019-10-09 17:17:47	2019-10-09	12	[{"id_menu":3,"count":1}]	3756	delivery	5	17
10196	2019-10-09 17:19:40	2019-10-09	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	3751	delivery	5	26
10197	2019-10-09 17:59:13	2019-10-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3755	delivery	5	22
10198	2019-10-09 18:02:14	2019-10-09	14	[{"id_menu":2,"count":1}]	113	pick-up	0	14
10199	2019-10-09 19:16:17	2019-10-09	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	2081	delivery	5	30
10200	2019-10-09 19:49:41	2019-10-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1842	delivery	5	28
10201	2019-10-09 19:54:03	2019-10-09	12	[{"id_menu":1,"count":1}]	2304	pick-up	0	12
10202	2019-10-09 20:51:46	2019-10-09	17	[{"id_menu":4,"count":2}]	1854	delivery	5	22
10203	2019-10-09 21:07:40	2019-10-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3761	delivery	5	23
10204	2019-10-09 21:38:49	2019-10-09	9	[{"id_menu":7,"count":1}]	2838	delivery	5	14
10205	2019-10-09 22:21:15	2019-10-09	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3190	pick-up	0	26
10206	2019-10-09 22:47:25	2019-10-09	12	[{"id_menu":3,"count":1}]	3762	pick-up	0	12
10207	2019-10-09 22:54:59	2019-10-09	12	[{"id_menu":3,"count":1}]	2523	delivery	5	17
10208	2019-10-09 23:07:08	2019-10-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	3775	delivery	5	23
10209	2019-10-09 23:14:59	2019-10-09	14	[{"id_menu":2,"count":1}]	626	pick-up	0	14
10210	2019-10-09 23:33:10	2019-10-09	12	[{"id_menu":3,"count":1}]	3752	pick-up	0	12
10211	2019-10-09 23:33:11	2019-10-09	9	[{"id_menu":6,"count":1}]	1800	pick-up	0	9
10212	2019-10-09 23:39:28	2019-10-09	9	[{"id_menu":6,"count":2}]	3760	delivery	5	14
10213	2019-10-10 00:14:59	2019-10-10	9	[{"id_menu":6,"count":2}]	3783	delivery	5	14
10214	2019-10-10 00:31:38	2019-10-10	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2291	pick-up	0	20
10215	2019-10-10 00:33:36	2019-10-10	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3789	delivery	5	36
10216	2019-10-10 00:34:45	2019-10-10	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2088	pick-up	0	31
10217	2019-10-10 00:37:34	2019-10-10	9	[{"id_menu":6,"count":1}]	1322	pick-up	0	9
10218	2019-10-10 01:50:52	2019-10-10	12	[{"id_menu":3,"count":1}]	743	pick-up	0	12
10219	2019-10-10 02:06:36	2019-10-10	14	[{"id_menu":2,"count":1}]	3567	delivery	5	19
10220	2019-10-10 02:22:28	2019-10-10	9	[{"id_menu":7,"count":1}]	330	delivery	5	14
10221	2019-10-10 02:24:57	2019-10-10	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	318	delivery	5	25
10222	2019-10-10 03:12:16	2019-10-10	14	[{"id_menu":2,"count":1}]	236	pick-up	0	14
10223	2019-10-10 03:25:23	2019-10-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	3793	delivery	5	28
10224	2019-10-10 03:35:37	2019-10-10	12	[{"id_menu":3,"count":1}]	945	pick-up	0	12
10225	2019-10-10 03:37:18	2019-10-10	9	[{"id_menu":6,"count":1}]	835	pick-up	0	9
10226	2019-10-10 03:53:27	2019-10-10	12	[{"id_menu":1,"count":1}]	392	pick-up	0	12
10227	2019-10-10 04:04:03	2019-10-10	8	[{"id_menu":5,"count":1}]	3781	delivery	5	13
10228	2019-10-10 04:10:36	2019-10-10	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2309	pick-up	0	50
10229	2019-10-10 04:34:51	2019-10-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	708	delivery	5	28
10230	2019-10-10 05:05:44	2019-10-10	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	977	delivery	5	34
10231	2019-10-10 05:08:50	2019-10-10	8	[{"id_menu":5,"count":1}]	931	pick-up	0	8
10232	2019-10-10 05:10:58	2019-10-10	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2000	pick-up	0	50
10233	2019-10-10 05:23:16	2019-10-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3480	pick-up	0	23
10234	2019-10-10 05:40:20	2019-10-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3790	pick-up	0	23
10235	2019-10-10 05:46:51	2019-10-10	14	[{"id_menu":2,"count":1}]	3814	pick-up	0	14
10236	2019-10-10 05:53:04	2019-10-10	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2901	pick-up	0	29
10237	2019-10-10 06:02:29	2019-10-10	12	[{"id_menu":1,"count":2}]	3002	delivery	5	17
10238	2019-10-10 06:08:04	2019-10-10	8	[{"id_menu":5,"count":1}]	722	pick-up	0	8
10239	2019-10-10 06:11:30	2019-10-10	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3794	delivery	5	44
10240	2019-10-10 06:28:36	2019-10-10	17	[{"id_menu":4,"count":1}]	3785	pick-up	0	17
10241	2019-10-10 06:49:28	2019-10-10	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3784	delivery	5	48
10242	2019-10-10 07:05:39	2019-10-10	9	[{"id_menu":7,"count":2}]	3812	pick-up	0	9
10243	2019-10-10 07:18:09	2019-10-10	9	[{"id_menu":7,"count":1}]	3807	delivery	5	14
10244	2019-10-10 07:24:56	2019-10-10	14	[{"id_menu":2,"count":1}]	1462	delivery	5	19
10245	2019-10-10 07:52:24	2019-10-10	8	[{"id_menu":5,"count":1}]	1293	delivery	5	13
10246	2019-10-10 08:03:03	2019-10-10	9	[{"id_menu":6,"count":1}]	1679	pick-up	0	9
10247	2019-10-10 08:13:20	2019-10-10	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	44	pick-up	0	26
10248	2019-10-10 08:18:53	2019-10-10	14	[{"id_menu":2,"count":1}]	3806	delivery	5	19
10249	2019-10-10 08:26:11	2019-10-10	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	269	pick-up	0	29
10250	2019-10-10 08:53:33	2019-10-10	14	[{"id_menu":2,"count":1}]	2498	delivery	5	19
10251	2019-10-10 09:09:06	2019-10-10	9	[{"id_menu":6,"count":1}]	2252	pick-up	0	9
10252	2019-10-10 09:14:28	2019-10-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2538	pick-up	0	17
10253	2019-10-10 09:27:35	2019-10-10	9	[{"id_menu":7,"count":1}]	2479	delivery	5	14
10254	2019-10-10 09:47:18	2019-10-10	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	3811	delivery	5	34
10255	2019-10-10 10:02:38	2019-10-10	8	[{"id_menu":5,"count":1}]	1153	delivery	5	13
10256	2019-10-10 10:13:51	2019-10-10	9	[{"id_menu":7,"count":1}]	2025	pick-up	0	9
10257	2019-10-10 10:15:34	2019-10-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3815	delivery	5	28
10258	2019-10-10 10:40:46	2019-10-10	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3804	delivery	5	27
10259	2019-10-10 10:45:28	2019-10-10	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3797	delivery	5	43
10260	2019-10-10 10:52:07	2019-10-10	17	[{"id_menu":4,"count":1}]	1497	pick-up	0	17
10261	2019-10-10 11:59:54	2019-10-10	9	[{"id_menu":7,"count":1}]	3800	delivery	5	14
10262	2019-10-10 12:06:41	2019-10-10	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	3059	delivery	5	26
10263	2019-10-10 12:26:47	2019-10-10	12	[{"id_menu":3,"count":1}]	1836	pick-up	0	12
10264	2019-10-10 13:02:06	2019-10-10	17	[{"id_menu":4,"count":1}]	2116	pick-up	0	17
10265	2019-10-10 13:14:23	2019-10-10	8	[{"id_menu":5,"count":1}]	1376	pick-up	0	8
10266	2019-10-10 13:20:25	2019-10-10	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	783	delivery	5	31
10267	2019-10-10 13:39:35	2019-10-10	9	[{"id_menu":7,"count":1}]	1818	delivery	5	14
10268	2019-10-10 14:21:26	2019-10-10	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	3786	delivery	5	39
10269	2019-10-10 14:23:59	2019-10-10	14	[{"id_menu":2,"count":1}]	3808	delivery	5	19
10270	2019-10-10 14:42:23	2019-10-10	12	[{"id_menu":3,"count":1}]	3796	delivery	5	17
10271	2019-10-10 15:31:33	2019-10-10	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3662	delivery	5	51
10272	2019-10-10 16:25:37	2019-10-10	17	[{"id_menu":4,"count":2}]	204	pick-up	0	17
10273	2019-10-10 16:25:53	2019-10-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2938	delivery	5	23
10274	2019-10-10 16:33:43	2019-10-10	17	[{"id_menu":4,"count":1}]	3521	delivery	5	22
10275	2019-10-10 17:12:33	2019-10-10	14	[{"id_menu":2,"count":1}]	2204	pick-up	0	14
10276	2019-10-10 17:20:41	2019-10-10	17	[{"id_menu":4,"count":1}]	2777	pick-up	0	17
10277	2019-10-10 17:21:05	2019-10-10	17	[{"id_menu":4,"count":1}]	3111	pick-up	0	17
10278	2019-10-10 17:23:40	2019-10-10	17	[{"id_menu":4,"count":1}]	3802	pick-up	0	17
10279	2019-10-10 17:28:33	2019-10-10	12	[{"id_menu":3,"count":1}]	1839	pick-up	0	12
10280	2019-10-10 17:31:14	2019-10-10	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	3553	pick-up	0	26
10281	2019-10-10 17:43:23	2019-10-10	12	[{"id_menu":1,"count":1}]	3148	pick-up	0	12
10282	2019-10-10 18:13:19	2019-10-10	9	[{"id_menu":7,"count":1}]	530	pick-up	0	9
10283	2019-10-10 18:27:25	2019-10-10	9	[{"id_menu":6,"count":1}]	96	pick-up	0	9
10284	2019-10-10 18:35:36	2019-10-10	9	[{"id_menu":6,"count":2}]	3578	pick-up	0	9
10285	2019-10-10 18:47:06	2019-10-10	9	[{"id_menu":6,"count":1}]	3792	delivery	5	14
10286	2019-10-10 18:48:29	2019-10-10	14	[{"id_menu":2,"count":1}]	1929	pick-up	0	14
10287	2019-10-10 19:13:21	2019-10-10	17	[{"id_menu":4,"count":1}]	2477	pick-up	0	17
10288	2019-10-10 19:22:11	2019-10-10	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	3048	pick-up	0	20
10289	2019-10-10 20:00:21	2019-10-10	9	[{"id_menu":6,"count":1}]	197	delivery	5	14
10290	2019-10-10 20:06:24	2019-10-10	17	[{"id_menu":4,"count":1}]	3801	pick-up	0	17
10291	2019-10-10 20:11:33	2019-10-10	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3805	delivery	5	43
10292	2019-10-10 20:39:21	2019-10-10	8	[{"id_menu":5,"count":1}]	3795	delivery	5	13
10293	2019-10-10 21:06:45	2019-10-10	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1120	delivery	5	39
10294	2019-10-10 21:19:12	2019-10-10	9	[{"id_menu":6,"count":1}]	1460	delivery	5	14
10295	2019-10-10 21:41:29	2019-10-10	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	3782	pick-up	0	20
10296	2019-10-10 22:40:50	2019-10-10	9	[{"id_menu":6,"count":1}]	3788	pick-up	0	9
10297	2019-10-10 22:45:16	2019-10-10	12	[{"id_menu":1,"count":1}]	1970	pick-up	0	12
10298	2019-10-10 22:47:02	2019-10-10	8	[{"id_menu":5,"count":1}]	136	pick-up	0	8
10299	2019-10-10 22:55:30	2019-10-10	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	3787	pick-up	0	26
10300	2019-10-10 23:12:19	2019-10-10	8	[{"id_menu":5,"count":1}]	2546	pick-up	0	8
10301	2019-10-10 23:17:39	2019-10-10	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	1574	pick-up	0	23
10302	2019-10-10 23:34:15	2019-10-10	14	[{"id_menu":2,"count":1}]	108	pick-up	0	14
10303	2019-10-10 23:49:49	2019-10-10	14	[{"id_menu":2,"count":1}]	111	pick-up	0	14
10304	2019-10-11 00:14:17	2019-10-11	9	[{"id_menu":6,"count":1}]	3843	delivery	5	14
10305	2019-10-11 01:26:25	2019-10-11	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3821	delivery	5	36
10306	2019-10-11 01:56:38	2019-10-11	14	[{"id_menu":2,"count":1}]	3826	pick-up	0	14
10307	2019-10-11 02:15:39	2019-10-11	9	[{"id_menu":7,"count":1}]	1922	pick-up	0	9
10308	2019-10-11 02:23:33	2019-10-11	9	[{"id_menu":7,"count":1}]	880	delivery	5	14
10309	2019-10-11 02:24:39	2019-10-11	12	[{"id_menu":1,"count":1}]	3848	delivery	5	17
10310	2019-10-11 02:25:38	2019-10-11	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1698	delivery	5	26
10311	2019-10-11 02:33:42	2019-10-11	12	[{"id_menu":3,"count":1}]	1303	delivery	5	17
10312	2019-10-11 02:43:02	2019-10-11	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3019	delivery	5	43
10313	2019-10-11 03:07:29	2019-10-11	17	[{"id_menu":4,"count":1}]	507	delivery	5	22
10314	2019-10-11 04:07:35	2019-10-11	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	415	delivery	5	39
10315	2019-10-11 04:13:14	2019-10-11	9	[{"id_menu":6,"count":1}]	987	pick-up	0	9
10316	2019-10-11 04:13:51	2019-10-11	14	[{"id_menu":2,"count":1}]	3840	pick-up	0	14
10317	2019-10-11 04:33:44	2019-10-11	17	[{"id_menu":4,"count":2}]	2819	delivery	5	22
10318	2019-10-11 04:35:31	2019-10-11	9	[{"id_menu":7,"count":1}]	3823	delivery	5	14
10319	2019-10-11 05:40:28	2019-10-11	17	[{"id_menu":4,"count":1}]	2434	pick-up	0	17
10320	2019-10-11 06:59:12	2019-10-11	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3841	pick-up	0	26
10321	2019-10-11 07:10:50	2019-10-11	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3831	delivery	5	26
10322	2019-10-11 07:24:06	2019-10-11	17	[{"id_menu":4,"count":1}]	3314	pick-up	0	17
10323	2019-10-11 07:27:49	2019-10-11	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3233	delivery	5	31
10324	2019-10-11 07:35:04	2019-10-11	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1115	pick-up	0	23
10325	2019-10-11 07:58:14	2019-10-11	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	790	pick-up	0	26
10326	2019-10-11 08:01:18	2019-10-11	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	3853	delivery	5	34
10327	2019-10-11 08:30:01	2019-10-11	17	[{"id_menu":4,"count":1}]	269	pick-up	0	17
10328	2019-10-11 08:39:46	2019-10-11	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1184	delivery	5	26
10329	2019-10-11 08:55:22	2019-10-11	12	[{"id_menu":3,"count":1}]	3835	delivery	5	17
10330	2019-10-11 09:34:42	2019-10-11	9	[{"id_menu":7,"count":1}]	3844	delivery	5	14
10331	2019-10-11 09:35:04	2019-10-11	12	[{"id_menu":1,"count":1}]	76	delivery	5	17
10332	2019-10-11 09:45:55	2019-10-11	12	[{"id_menu":3,"count":1}]	2358	delivery	5	17
10333	2019-10-11 10:09:32	2019-10-11	9	[{"id_menu":7,"count":1}]	3787	pick-up	0	9
10334	2019-10-11 10:27:32	2019-10-11	9	[{"id_menu":6,"count":1}]	258	delivery	5	14
10335	2019-10-11 10:28:24	2019-10-11	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	2101	pick-up	0	38
10336	2019-10-11 10:33:25	2019-10-11	9	[{"id_menu":6,"count":1}]	188	pick-up	0	9
10337	2019-10-11 10:37:10	2019-10-11	17	[{"id_menu":4,"count":1}]	3854	delivery	5	22
10338	2019-10-11 10:49:10	2019-10-11	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	3851	pick-up	0	26
10339	2019-10-11 10:56:58	2019-10-11	12	[{"id_menu":1,"count":1}]	2831	delivery	5	17
10340	2019-10-11 11:22:40	2019-10-11	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2275	pick-up	0	43
10341	2019-10-11 11:33:03	2019-10-11	14	[{"id_menu":2,"count":1}]	1708	pick-up	0	14
10342	2019-10-11 11:34:05	2019-10-11	12	[{"id_menu":3,"count":1}]	654	pick-up	0	12
10343	2019-10-11 11:51:34	2019-10-11	9	[{"id_menu":7,"count":1}]	3836	delivery	5	14
10344	2019-10-11 13:08:46	2019-10-11	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	3827	pick-up	0	29
10345	2019-10-11 13:32:28	2019-10-11	17	[{"id_menu":4,"count":1}]	3174	pick-up	0	17
10346	2019-10-11 13:39:08	2019-10-11	12	[{"id_menu":1,"count":1}]	3822	pick-up	0	12
10347	2019-10-11 13:44:19	2019-10-11	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3845	delivery	5	26
10348	2019-10-11 14:14:18	2019-10-11	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	227	pick-up	0	26
10349	2019-10-11 14:37:52	2019-10-11	12	[{"id_menu":3,"count":1}]	531	pick-up	0	12
10350	2019-10-11 14:52:05	2019-10-11	9	[{"id_menu":6,"count":2}]	3838	delivery	5	14
10351	2019-10-11 15:09:33	2019-10-11	12	[{"id_menu":3,"count":1}]	81	pick-up	0	12
10352	2019-10-11 15:09:37	2019-10-11	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3816	delivery	5	49
10353	2019-10-11 15:12:34	2019-10-11	17	[{"id_menu":4,"count":1}]	2993	pick-up	0	17
10354	2019-10-11 15:14:30	2019-10-11	14	[{"id_menu":2,"count":1}]	3849	delivery	5	19
10355	2019-10-11 15:20:43	2019-10-11	12	[{"id_menu":3,"count":1}]	3817	delivery	5	17
10356	2019-10-11 15:26:58	2019-10-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2000	pick-up	0	23
10357	2019-10-11 15:28:40	2019-10-11	8	[{"id_menu":5,"count":1}]	408	delivery	5	13
10358	2019-10-11 15:39:24	2019-10-11	14	[{"id_menu":2,"count":1}]	432	pick-up	0	14
10359	2019-10-11 15:39:54	2019-10-11	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	3837	delivery	5	23
10360	2019-10-11 15:43:49	2019-10-11	12	[{"id_menu":3,"count":2}]	650	delivery	5	17
10361	2019-10-11 16:11:28	2019-10-11	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1025	delivery	5	36
10362	2019-10-11 16:36:37	2019-10-11	8	[{"id_menu":5,"count":1}]	256	pick-up	0	8
10363	2019-10-11 16:37:32	2019-10-11	17	[{"id_menu":4,"count":1}]	1569	pick-up	0	17
10364	2019-10-11 16:39:59	2019-10-11	9	[{"id_menu":6,"count":1}]	1656	pick-up	0	9
10365	2019-10-11 16:41:13	2019-10-11	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3829	delivery	5	36
10366	2019-10-11 17:01:37	2019-10-11	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	2277	pick-up	0	32
10367	2019-10-11 17:04:25	2019-10-11	9	[{"id_menu":6,"count":1}]	2870	pick-up	0	9
10368	2019-10-11 17:21:52	2019-10-11	9	[{"id_menu":6,"count":1}]	2511	pick-up	0	9
10369	2019-10-11 17:23:32	2019-10-11	8	[{"id_menu":5,"count":1}]	1148	delivery	5	13
10370	2019-10-11 17:41:27	2019-10-11	9	[{"id_menu":7,"count":1}]	980	pick-up	0	9
10371	2019-10-11 17:54:44	2019-10-11	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	454	delivery	5	26
10372	2019-10-11 19:16:50	2019-10-11	8	[{"id_menu":5,"count":1}]	3614	pick-up	0	8
10373	2019-10-11 19:27:54	2019-10-11	14	[{"id_menu":2,"count":1}]	78	delivery	5	19
10374	2019-10-11 19:52:20	2019-10-11	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	3855	delivery	5	38
10375	2019-10-11 20:24:17	2019-10-11	14	[{"id_menu":2,"count":1}]	678	delivery	5	19
10376	2019-10-11 20:37:34	2019-10-11	12	[{"id_menu":1,"count":1}]	3834	delivery	5	17
10377	2019-10-11 20:48:19	2019-10-11	9	[{"id_menu":6,"count":1}]	3077	delivery	5	14
10378	2019-10-11 21:12:13	2019-10-11	17	[{"id_menu":4,"count":1}]	2392	pick-up	0	17
10379	2019-10-11 21:17:49	2019-10-11	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1055	delivery	5	42
10380	2019-10-11 21:43:02	2019-10-11	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	3852	pick-up	0	26
10381	2019-10-11 21:48:25	2019-10-11	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3830	pick-up	0	26
10382	2019-10-11 22:32:45	2019-10-11	14	[{"id_menu":2,"count":1}]	2653	delivery	5	19
10383	2019-10-11 22:47:08	2019-10-11	8	[{"id_menu":5,"count":1}]	3828	delivery	5	13
10384	2019-10-11 23:22:47	2019-10-11	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2811	delivery	5	44
10385	2019-10-11 23:22:55	2019-10-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1713	delivery	5	22
10386	2019-10-11 23:55:00	2019-10-11	9	[{"id_menu":6,"count":1}]	3825	pick-up	0	9
10387	2019-10-12 00:05:33	2019-10-12	9	[{"id_menu":6,"count":1}]	2659	pick-up	0	9
10388	2019-10-12 00:12:58	2019-10-12	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3882	delivery	5	31
10389	2019-10-12 00:21:00	2019-10-12	14	[{"id_menu":2,"count":1}]	3619	pick-up	0	14
10390	2019-10-12 00:32:56	2019-10-12	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3884	pick-up	0	29
10391	2019-10-12 00:48:55	2019-10-12	14	[{"id_menu":2,"count":1}]	3155	pick-up	0	14
10392	2019-10-12 01:02:08	2019-10-12	14	[{"id_menu":2,"count":1}]	1439	delivery	5	19
10393	2019-10-12 01:04:44	2019-10-12	9	[{"id_menu":6,"count":1}]	286	pick-up	0	9
10394	2019-10-12 01:13:46	2019-10-12	14	[{"id_menu":2,"count":1}]	1114	pick-up	0	14
10395	2019-10-12 01:16:15	2019-10-12	12	[{"id_menu":3,"count":1}]	3147	pick-up	0	12
10396	2019-10-12 01:33:04	2019-10-12	12	[{"id_menu":3,"count":1}]	2123	delivery	5	17
10397	2019-10-12 01:50:07	2019-10-12	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1276	pick-up	0	17
10398	2019-10-12 02:08:58	2019-10-12	8	[{"id_menu":5,"count":1}]	1557	pick-up	0	8
10399	2019-10-12 02:10:13	2019-10-12	12	[{"id_menu":3,"count":1}]	2176	pick-up	0	12
10400	2019-10-12 02:49:03	2019-10-12	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2268	pick-up	0	26
10401	2019-10-12 03:03:26	2019-10-12	12	[{"id_menu":3,"count":1}]	669	delivery	5	17
10402	2019-10-12 03:07:49	2019-10-12	17	[{"id_menu":4,"count":1}]	464	pick-up	0	17
10403	2019-10-12 03:10:40	2019-10-12	14	[{"id_menu":2,"count":1}]	3861	pick-up	0	14
10404	2019-10-12 03:20:09	2019-10-12	8	[{"id_menu":5,"count":1}]	3230	pick-up	0	8
10405	2019-10-12 03:21:14	2019-10-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2386	delivery	5	22
10406	2019-10-12 03:30:36	2019-10-12	12	[{"id_menu":3,"count":1}]	2513	delivery	5	17
10407	2019-10-12 03:41:04	2019-10-12	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3870	pick-up	0	22
10408	2019-10-12 04:32:51	2019-10-12	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	171	delivery	5	36
10409	2019-10-12 05:06:24	2019-10-12	9	[{"id_menu":7,"count":1}]	1106	delivery	5	14
10410	2019-10-12 05:06:50	2019-10-12	12	[{"id_menu":1,"count":1}]	2287	pick-up	0	12
10411	2019-10-12 05:08:46	2019-10-12	9	[{"id_menu":7,"count":1}]	2849	delivery	5	14
10412	2019-10-12 05:09:17	2019-10-12	17	[{"id_menu":4,"count":1}]	1726	pick-up	0	17
10413	2019-10-12 05:11:13	2019-10-12	12	[{"id_menu":1,"count":1}]	3118	delivery	5	17
10414	2019-10-12 05:34:33	2019-10-12	8	[{"id_menu":5,"count":1}]	3868	delivery	5	13
10415	2019-10-12 05:58:03	2019-10-12	8	[{"id_menu":5,"count":2}]	3878	delivery	5	13
10416	2019-10-12 06:04:32	2019-10-12	17	[{"id_menu":4,"count":1}]	3678	pick-up	0	17
10417	2019-10-12 06:34:54	2019-10-12	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3863	pick-up	0	23
10418	2019-10-12 06:42:36	2019-10-12	8	[{"id_menu":5,"count":1}]	2744	delivery	5	13
10419	2019-10-12 06:44:53	2019-10-12	14	[{"id_menu":2,"count":2}]	2893	delivery	5	19
10420	2019-10-12 07:20:48	2019-10-12	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2776	pick-up	0	17
10421	2019-10-12 07:25:23	2019-10-12	8	[{"id_menu":5,"count":1}]	3875	delivery	5	13
10422	2019-10-12 07:31:45	2019-10-12	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3679	delivery	5	34
10423	2019-10-12 07:40:30	2019-10-12	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1088	pick-up	0	26
10424	2019-10-12 07:57:29	2019-10-12	9	[{"id_menu":6,"count":1}]	3685	delivery	5	14
10425	2019-10-12 08:08:25	2019-10-12	14	[{"id_menu":2,"count":1}]	950	delivery	5	19
10426	2019-10-12 08:18:04	2019-10-12	8	[{"id_menu":5,"count":1}]	3879	delivery	5	13
10427	2019-10-12 08:21:03	2019-10-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2674	pick-up	0	17
10428	2019-10-12 08:33:27	2019-10-12	8	[{"id_menu":5,"count":1}]	3880	delivery	5	13
10429	2019-10-12 08:56:53	2019-10-12	12	[{"id_menu":1,"count":1}]	3290	delivery	5	17
10430	2019-10-12 08:57:51	2019-10-12	14	[{"id_menu":2,"count":1}]	41	pick-up	0	14
10431	2019-10-12 09:21:21	2019-10-12	12	[{"id_menu":1,"count":1}]	3874	delivery	5	17
10432	2019-10-12 09:28:45	2019-10-12	17	[{"id_menu":4,"count":1}]	1834	pick-up	0	17
10433	2019-10-12 09:35:27	2019-10-12	8	[{"id_menu":5,"count":1}]	2523	delivery	5	13
10434	2019-10-12 09:47:51	2019-10-12	9	[{"id_menu":7,"count":1}]	3866	delivery	5	14
10435	2019-10-12 09:58:00	2019-10-12	17	[{"id_menu":4,"count":1}]	1462	delivery	5	22
10436	2019-10-12 10:00:42	2019-10-12	12	[{"id_menu":1,"count":1}]	1526	pick-up	0	12
10437	2019-10-12 10:19:32	2019-10-12	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3872	pick-up	0	43
10438	2019-10-12 10:50:45	2019-10-12	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2993	pick-up	0	38
10439	2019-10-12 11:02:20	2019-10-12	12	[{"id_menu":1,"count":1}]	408	delivery	5	17
10440	2019-10-12 11:02:42	2019-10-12	12	[{"id_menu":1,"count":1}]	2418	delivery	5	17
10441	2019-10-12 11:10:09	2019-10-12	12	[{"id_menu":1,"count":1}]	3862	delivery	5	17
10442	2019-10-12 11:15:02	2019-10-12	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3146	pick-up	0	26
10443	2019-10-12 11:32:59	2019-10-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1960	delivery	5	23
10444	2019-10-12 11:38:46	2019-10-12	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	623	delivery	5	28
10445	2019-10-12 11:43:56	2019-10-12	12	[{"id_menu":3,"count":1}]	431	pick-up	0	12
10446	2019-10-12 11:57:53	2019-10-12	9	[{"id_menu":6,"count":1}]	639	pick-up	0	9
10447	2019-10-12 12:17:48	2019-10-12	8	[{"id_menu":5,"count":1}]	1228	delivery	5	13
10448	2019-10-12 12:39:57	2019-10-12	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1889	pick-up	0	21
10449	2019-10-12 12:50:32	2019-10-12	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	2543	pick-up	0	20
10450	2019-10-12 12:59:09	2019-10-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	826	pick-up	0	18
10451	2019-10-12 13:09:23	2019-10-12	14	[{"id_menu":2,"count":2}]	3857	delivery	5	19
10452	2019-10-12 13:15:57	2019-10-12	8	[{"id_menu":5,"count":1}]	3860	delivery	5	13
10453	2019-10-12 13:21:21	2019-10-12	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2416	delivery	5	26
10454	2019-10-12 14:13:17	2019-10-12	14	[{"id_menu":2,"count":1}]	3864	pick-up	0	14
10455	2019-10-12 14:31:17	2019-10-12	9	[{"id_menu":6,"count":1}]	3858	delivery	5	14
10456	2019-10-12 14:34:19	2019-10-12	9	[{"id_menu":6,"count":1}]	3135	pick-up	0	9
10457	2019-10-12 14:53:27	2019-10-12	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3152	pick-up	0	21
10458	2019-10-12 15:12:05	2019-10-12	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1176	pick-up	0	26
10459	2019-10-12 15:23:46	2019-10-12	17	[{"id_menu":4,"count":1}]	3856	delivery	5	22
10460	2019-10-12 15:48:39	2019-10-12	12	[{"id_menu":3,"count":1}]	993	pick-up	0	12
10461	2019-10-12 16:03:13	2019-10-12	14	[{"id_menu":2,"count":1}]	584	pick-up	0	14
10462	2019-10-12 16:03:53	2019-10-12	12	[{"id_menu":1,"count":1}]	3444	pick-up	0	12
10463	2019-10-12 16:29:20	2019-10-12	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	640	delivery	5	29
10464	2019-10-12 16:35:26	2019-10-12	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3385	pick-up	0	47
10465	2019-10-12 16:59:32	2019-10-12	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3493	delivery	5	31
10466	2019-10-12 17:07:36	2019-10-12	9	[{"id_menu":7,"count":1}]	2736	pick-up	0	9
10467	2019-10-12 17:20:14	2019-10-12	9	[{"id_menu":6,"count":1}]	3881	delivery	5	14
10468	2019-10-12 17:28:25	2019-10-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2931	delivery	5	23
10469	2019-10-12 17:32:13	2019-10-12	17	[{"id_menu":4,"count":1}]	3876	delivery	5	22
10470	2019-10-12 17:44:37	2019-10-12	9	[{"id_menu":6,"count":1}]	26	delivery	5	14
10471	2019-10-12 18:08:07	2019-10-12	14	[{"id_menu":2,"count":1}]	1707	pick-up	0	14
10472	2019-10-12 18:12:22	2019-10-12	14	[{"id_menu":2,"count":1}]	3867	delivery	5	19
10473	2019-10-12 18:19:25	2019-10-12	12	[{"id_menu":3,"count":1}]	1050	pick-up	0	12
10474	2019-10-12 18:28:31	2019-10-12	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	3205	pick-up	0	20
10475	2019-10-12 18:32:05	2019-10-12	17	[{"id_menu":4,"count":1}]	3871	delivery	5	22
10476	2019-10-12 18:52:02	2019-10-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2125	pick-up	0	23
10477	2019-10-12 18:54:04	2019-10-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	3538	delivery	5	28
10478	2019-10-12 19:12:05	2019-10-12	9	[{"id_menu":6,"count":1}]	727	pick-up	0	9
10479	2019-10-12 19:21:30	2019-10-12	9	[{"id_menu":7,"count":1}]	15	pick-up	0	9
10480	2019-10-12 20:00:59	2019-10-12	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	1427	pick-up	0	20
10481	2019-10-12 20:09:00	2019-10-12	17	[{"id_menu":4,"count":1}]	641	delivery	5	22
10482	2019-10-12 20:21:21	2019-10-12	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	3873	delivery	5	37
10483	2019-10-12 20:24:44	2019-10-12	8	[{"id_menu":5,"count":1}]	1166	pick-up	0	8
10484	2019-10-12 20:40:19	2019-10-12	17	[{"id_menu":4,"count":1}]	3672	pick-up	0	17
10485	2019-10-12 21:29:40	2019-10-12	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	3002	pick-up	0	20
10486	2019-10-12 21:38:20	2019-10-12	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	3539	pick-up	0	21
10487	2019-10-12 21:40:43	2019-10-12	12	[{"id_menu":1,"count":1}]	3869	pick-up	0	12
10488	2019-10-12 22:02:49	2019-10-12	9	[{"id_menu":7,"count":1}]	2265	pick-up	0	9
10489	2019-10-12 22:12:57	2019-10-12	9	[{"id_menu":6,"count":1}]	3746	delivery	5	14
10490	2019-10-12 22:25:05	2019-10-12	8	[{"id_menu":5,"count":1}]	3420	pick-up	0	8
10491	2019-10-12 22:31:28	2019-10-12	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3883	delivery	5	31
10492	2019-10-12 22:44:35	2019-10-12	14	[{"id_menu":2,"count":1}]	3263	pick-up	0	14
10493	2019-10-12 22:52:51	2019-10-12	9	[{"id_menu":6,"count":1}]	3865	delivery	5	14
10494	2019-10-12 23:00:04	2019-10-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":3}]	3859	pick-up	0	18
10495	2019-10-12 23:06:55	2019-10-12	12	[{"id_menu":3,"count":1}]	3877	pick-up	0	12
10496	2019-10-12 23:33:59	2019-10-12	12	[{"id_menu":1,"count":1}]	2450	pick-up	0	12
10497	2019-10-12 23:58:46	2019-10-12	17	[{"id_menu":4,"count":1}]	3885	delivery	5	22
10498	2019-10-13 00:02:16	2019-10-13	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1258	pick-up	0	26
10499	2019-10-13 00:12:42	2019-10-13	17	[{"id_menu":4,"count":1}]	3055	delivery	5	22
10500	2019-10-13 00:20:11	2019-10-13	12	[{"id_menu":3,"count":1}]	1416	delivery	5	17
10501	2019-10-13 00:27:26	2019-10-13	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1435	pick-up	0	38
10502	2019-10-13 00:30:45	2019-10-13	9	[{"id_menu":6,"count":1}]	2660	pick-up	0	9
10503	2019-10-13 00:41:58	2019-10-13	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2470	pick-up	0	26
10504	2019-10-13 00:45:50	2019-10-13	8	[{"id_menu":5,"count":1}]	74	pick-up	0	8
10505	2019-10-13 00:45:58	2019-10-13	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3908	pick-up	0	26
10506	2019-10-13 01:01:19	2019-10-13	12	[{"id_menu":3,"count":1}]	2149	pick-up	0	12
10507	2019-10-13 01:02:20	2019-10-13	12	[{"id_menu":3,"count":1}]	3919	delivery	5	17
10508	2019-10-13 01:05:15	2019-10-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3915	pick-up	0	31
10509	2019-10-13 01:07:39	2019-10-13	9	[{"id_menu":6,"count":2}]	3892	delivery	5	14
10510	2019-10-13 01:51:59	2019-10-13	9	[{"id_menu":7,"count":1}]	3887	delivery	5	14
10511	2019-10-13 01:57:44	2019-10-13	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	593	pick-up	0	18
10512	2019-10-13 02:30:22	2019-10-13	17	[{"id_menu":4,"count":1}]	2528	pick-up	0	17
10513	2019-10-13 02:56:27	2019-10-13	17	[{"id_menu":4,"count":1}]	351	pick-up	0	17
10514	2019-10-13 02:56:48	2019-10-13	9	[{"id_menu":7,"count":2}]	3890	delivery	5	14
10515	2019-10-13 03:21:22	2019-10-13	8	[{"id_menu":5,"count":1}]	1925	pick-up	0	8
10516	2019-10-13 03:38:06	2019-10-13	12	[{"id_menu":1,"count":1}]	3900	pick-up	0	12
10517	2019-10-13 03:46:48	2019-10-13	12	[{"id_menu":3,"count":2}]	1322	delivery	5	17
10518	2019-10-13 03:55:50	2019-10-13	9	[{"id_menu":7,"count":1}]	3661	delivery	5	14
10519	2019-10-13 03:57:33	2019-10-13	17	[{"id_menu":4,"count":1}]	919	pick-up	0	17
10520	2019-10-13 04:01:45	2019-10-13	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1729	pick-up	0	26
10521	2019-10-13 04:02:48	2019-10-13	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1674	delivery	5	26
10522	2019-10-13 04:12:32	2019-10-13	8	[{"id_menu":5,"count":1}]	3894	pick-up	0	8
10523	2019-10-13 04:18:26	2019-10-13	14	[{"id_menu":2,"count":1}]	708	pick-up	0	14
10524	2019-10-13 04:38:58	2019-10-13	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	3918	pick-up	0	26
10525	2019-10-13 04:39:03	2019-10-13	14	[{"id_menu":2,"count":2}]	647	delivery	5	19
10526	2019-10-13 04:39:14	2019-10-13	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1485	pick-up	0	21
10527	2019-10-13 04:51:50	2019-10-13	14	[{"id_menu":2,"count":1}]	3895	delivery	5	19
10528	2019-10-13 05:22:44	2019-10-13	14	[{"id_menu":2,"count":1}]	136	pick-up	0	14
10529	2019-10-13 05:49:44	2019-10-13	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1344	pick-up	0	22
10530	2019-10-13 05:50:10	2019-10-13	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3100	delivery	5	40
10531	2019-10-13 05:59:51	2019-10-13	8	[{"id_menu":5,"count":1}]	3911	delivery	5	13
10532	2019-10-13 06:09:51	2019-10-13	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	706	delivery	5	37
10533	2019-10-13 06:30:54	2019-10-13	12	[{"id_menu":3,"count":1}]	295	pick-up	0	12
10534	2019-10-13 06:41:28	2019-10-13	17	[{"id_menu":4,"count":1}]	2147	pick-up	0	17
10535	2019-10-13 07:00:26	2019-10-13	17	[{"id_menu":4,"count":1}]	2339	delivery	5	22
10536	2019-10-13 07:01:40	2019-10-13	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2804	pick-up	0	33
10537	2019-10-13 07:08:54	2019-10-13	12	[{"id_menu":1,"count":1}]	595	pick-up	0	12
10538	2019-10-13 07:20:05	2019-10-13	9	[{"id_menu":6,"count":1}]	229	pick-up	0	9
10539	2019-10-13 07:25:11	2019-10-13	14	[{"id_menu":2,"count":1}]	3600	delivery	5	19
10540	2019-10-13 07:30:49	2019-10-13	17	[{"id_menu":4,"count":1}]	1996	pick-up	0	17
10541	2019-10-13 07:32:05	2019-10-13	8	[{"id_menu":5,"count":1}]	2133	pick-up	0	8
10542	2019-10-13 07:42:52	2019-10-13	8	[{"id_menu":5,"count":1}]	19	delivery	5	13
10543	2019-10-13 07:56:27	2019-10-13	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3893	delivery	5	36
10544	2019-10-13 08:32:13	2019-10-13	12	[{"id_menu":1,"count":1}]	1885	pick-up	0	12
10545	2019-10-13 08:48:31	2019-10-13	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3456	delivery	5	48
10546	2019-10-13 09:00:18	2019-10-13	12	[{"id_menu":1,"count":1}]	3896	pick-up	0	12
10547	2019-10-13 09:01:55	2019-10-13	17	[{"id_menu":4,"count":1}]	1860	delivery	5	22
10548	2019-10-13 09:07:13	2019-10-13	17	[{"id_menu":4,"count":1}]	2622	pick-up	0	17
10549	2019-10-13 09:09:05	2019-10-13	14	[{"id_menu":2,"count":1}]	993	delivery	5	19
10550	2019-10-13 09:12:54	2019-10-13	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3923	delivery	5	39
10551	2019-10-13 09:36:35	2019-10-13	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2853	delivery	5	34
10552	2019-10-13 09:39:23	2019-10-13	9	[{"id_menu":6,"count":1}]	2055	pick-up	0	9
10553	2019-10-13 09:55:35	2019-10-13	9	[{"id_menu":7,"count":1}]	2076	pick-up	0	9
10554	2019-10-13 10:12:48	2019-10-13	12	[{"id_menu":3,"count":1}]	2513	pick-up	0	12
10555	2019-10-13 10:15:26	2019-10-13	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	3910	delivery	5	25
10556	2019-10-13 10:18:28	2019-10-13	12	[{"id_menu":3,"count":1}]	3257	delivery	5	17
10557	2019-10-13 10:19:28	2019-10-13	9	[{"id_menu":6,"count":1}]	856	pick-up	0	9
10558	2019-10-13 10:28:18	2019-10-13	9	[{"id_menu":7,"count":1}]	3066	pick-up	0	9
10559	2019-10-13 10:36:55	2019-10-13	12	[{"id_menu":3,"count":1}]	3825	pick-up	0	12
10560	2019-10-13 10:42:26	2019-10-13	12	[{"id_menu":3,"count":2}]	3905	pick-up	0	12
10561	2019-10-13 10:51:53	2019-10-13	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3913	delivery	5	37
10562	2019-10-13 11:09:02	2019-10-13	14	[{"id_menu":2,"count":1}]	1155	pick-up	0	14
10563	2019-10-13 11:11:42	2019-10-13	12	[{"id_menu":1,"count":1}]	1303	delivery	5	17
10564	2019-10-13 11:16:13	2019-10-13	12	[{"id_menu":1,"count":1}]	3901	delivery	5	17
10565	2019-10-13 11:30:41	2019-10-13	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3224	pick-up	0	21
10566	2019-10-13 11:35:32	2019-10-13	14	[{"id_menu":2,"count":1}]	1988	delivery	5	19
10567	2019-10-13 11:45:20	2019-10-13	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3902	delivery	5	36
10568	2019-10-13 11:55:24	2019-10-13	12	[{"id_menu":3,"count":1}]	980	delivery	5	17
10569	2019-10-13 12:04:32	2019-10-13	12	[{"id_menu":1,"count":1}]	2457	pick-up	0	12
10570	2019-10-13 12:19:37	2019-10-13	34	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	3139	pick-up	0	34
10571	2019-10-13 12:30:21	2019-10-13	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	299	pick-up	0	38
10572	2019-10-13 12:46:04	2019-10-13	12	[{"id_menu":3,"count":1}]	3694	delivery	5	17
10573	2019-10-13 13:12:20	2019-10-13	14	[{"id_menu":2,"count":1}]	2463	pick-up	0	14
10574	2019-10-13 13:35:37	2019-10-13	14	[{"id_menu":2,"count":1}]	1962	delivery	5	19
10575	2019-10-13 14:20:23	2019-10-13	9	[{"id_menu":6,"count":1}]	3907	pick-up	0	9
10576	2019-10-13 14:22:08	2019-10-13	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	653	delivery	5	43
10577	2019-10-13 14:23:00	2019-10-13	17	[{"id_menu":4,"count":1}]	3912	delivery	5	22
10578	2019-10-13 14:26:54	2019-10-13	8	[{"id_menu":5,"count":1}]	744	delivery	5	13
10579	2019-10-13 14:33:49	2019-10-13	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	3917	delivery	5	26
10580	2019-10-13 14:34:24	2019-10-13	14	[{"id_menu":2,"count":1}]	3506	delivery	5	19
10581	2019-10-13 14:35:50	2019-10-13	17	[{"id_menu":4,"count":2}]	193	pick-up	0	17
10582	2019-10-13 14:46:14	2019-10-13	12	[{"id_menu":1,"count":1}]	669	delivery	5	17
10583	2019-10-13 14:46:24	2019-10-13	12	[{"id_menu":1,"count":1}]	1993	pick-up	0	12
10584	2019-10-13 15:01:06	2019-10-13	12	[{"id_menu":3,"count":1}]	1293	delivery	5	17
10585	2019-10-13 15:04:16	2019-10-13	9	[{"id_menu":6,"count":1}]	3754	delivery	5	14
10586	2019-10-13 15:05:36	2019-10-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	2872	pick-up	0	31
10587	2019-10-13 15:07:35	2019-10-13	9	[{"id_menu":7,"count":1}]	3889	delivery	5	14
10588	2019-10-13 15:09:09	2019-10-13	12	[{"id_menu":1,"count":1}]	3909	delivery	5	17
10589	2019-10-13 15:29:36	2019-10-13	14	[{"id_menu":2,"count":1}]	486	delivery	5	19
10590	2019-10-13 15:31:14	2019-10-13	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	3886	delivery	5	39
10591	2019-10-13 15:31:25	2019-10-13	14	[{"id_menu":2,"count":1}]	3906	pick-up	0	14
10592	2019-10-13 15:39:41	2019-10-13	8	[{"id_menu":5,"count":1}]	3258	delivery	5	13
10593	2019-10-13 15:41:29	2019-10-13	12	[{"id_menu":1,"count":1}]	3903	pick-up	0	12
10594	2019-10-13 15:52:37	2019-10-13	12	[{"id_menu":3,"count":1}]	2728	delivery	5	17
10595	2019-10-13 15:54:06	2019-10-13	12	[{"id_menu":3,"count":1}]	158	pick-up	0	12
10596	2019-10-13 15:54:37	2019-10-13	14	[{"id_menu":2,"count":1}]	3891	delivery	5	19
10597	2019-10-13 15:54:58	2019-10-13	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3899	pick-up	0	25
10598	2019-10-13 16:22:27	2019-10-13	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1892	delivery	5	37
10599	2019-10-13 16:32:21	2019-10-13	14	[{"id_menu":2,"count":1}]	684	delivery	5	19
10600	2019-10-13 16:39:00	2019-10-13	12	[{"id_menu":1,"count":1}]	3904	delivery	5	17
10601	2019-10-13 16:50:59	2019-10-13	9	[{"id_menu":7,"count":1}]	149	pick-up	0	9
10602	2019-10-13 17:19:50	2019-10-13	12	[{"id_menu":3,"count":1}]	154	pick-up	0	12
10603	2019-10-13 17:23:37	2019-10-13	8	[{"id_menu":5,"count":1}]	2699	delivery	5	13
10604	2019-10-13 17:27:53	2019-10-13	9	[{"id_menu":6,"count":1}]	585	delivery	5	14
10605	2019-10-13 17:35:02	2019-10-13	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3921	delivery	5	34
10606	2019-10-13 17:35:05	2019-10-13	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3888	delivery	5	28
10607	2019-10-13 17:36:54	2019-10-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3771	delivery	5	28
10608	2019-10-13 17:55:42	2019-10-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1755	pick-up	0	18
10609	2019-10-13 17:59:39	2019-10-13	9	[{"id_menu":7,"count":1}]	482	delivery	5	14
10610	2019-10-13 18:07:39	2019-10-13	8	[{"id_menu":5,"count":1}]	2968	pick-up	0	8
10611	2019-10-13 18:18:14	2019-10-13	14	[{"id_menu":2,"count":2}]	3922	delivery	5	19
10612	2019-10-13 18:23:47	2019-10-13	9	[{"id_menu":7,"count":1}]	3920	delivery	5	14
10613	2019-10-13 18:34:48	2019-10-13	9	[{"id_menu":6,"count":1}]	1896	pick-up	0	9
10614	2019-10-13 18:36:11	2019-10-13	8	[{"id_menu":5,"count":1}]	1862	pick-up	0	8
10615	2019-10-13 18:37:55	2019-10-13	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	813	delivery	5	38
10616	2019-10-13 18:38:28	2019-10-13	17	[{"id_menu":4,"count":1}]	3898	delivery	5	22
10617	2019-10-13 19:23:16	2019-10-13	14	[{"id_menu":2,"count":1}]	2575	pick-up	0	14
10618	2019-10-13 19:32:15	2019-10-13	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	729	delivery	5	30
10619	2019-10-13 19:37:53	2019-10-13	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2520	pick-up	0	26
10620	2019-10-13 20:04:49	2019-10-13	9	[{"id_menu":6,"count":1}]	1379	delivery	5	14
10621	2019-10-13 20:18:01	2019-10-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2951	delivery	5	28
10622	2019-10-13 20:28:43	2019-10-13	17	[{"id_menu":4,"count":1}]	257	pick-up	0	17
10623	2019-10-13 20:39:57	2019-10-13	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1592	delivery	5	31
10624	2019-10-13 20:41:34	2019-10-13	17	[{"id_menu":4,"count":1}]	2191	pick-up	0	17
10625	2019-10-13 20:48:02	2019-10-13	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2064	delivery	5	26
10626	2019-10-13 20:53:45	2019-10-13	12	[{"id_menu":1,"count":1}]	279	delivery	5	17
10627	2019-10-13 21:02:26	2019-10-13	8	[{"id_menu":5,"count":1}]	964	delivery	5	13
10628	2019-10-13 21:05:42	2019-10-13	12	[{"id_menu":1,"count":1}]	3916	pick-up	0	12
10629	2019-10-13 21:13:00	2019-10-13	9	[{"id_menu":6,"count":1}]	3111	delivery	5	14
10630	2019-10-13 21:14:35	2019-10-13	9	[{"id_menu":7,"count":1}]	2243	pick-up	0	9
10631	2019-10-13 21:15:39	2019-10-13	12	[{"id_menu":1,"count":1}]	3490	delivery	5	17
10632	2019-10-13 21:34:23	2019-10-13	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	355	pick-up	0	17
10633	2019-10-13 21:34:50	2019-10-13	9	[{"id_menu":7,"count":1}]	2020	delivery	5	14
10634	2019-10-13 21:55:33	2019-10-13	14	[{"id_menu":2,"count":1}]	3132	delivery	5	19
10635	2019-10-13 22:14:32	2019-10-13	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	741	delivery	5	31
10636	2019-10-13 22:36:51	2019-10-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3861	pick-up	0	23
10637	2019-10-13 22:40:43	2019-10-13	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	2573	pick-up	0	40
10638	2019-10-13 23:00:26	2019-10-13	9	[{"id_menu":6,"count":1}]	2919	delivery	5	14
10639	2019-10-13 23:06:05	2019-10-13	14	[{"id_menu":2,"count":2}]	3914	delivery	5	19
10640	2019-10-13 23:32:04	2019-10-13	9	[{"id_menu":6,"count":1}]	3531	delivery	5	14
10641	2019-10-13 23:57:52	2019-10-13	14	[{"id_menu":2,"count":1}]	2720	pick-up	0	14
10642	2019-10-14 00:14:22	2019-10-14	9	[{"id_menu":6,"count":1}]	3926	pick-up	0	9
10643	2019-10-14 01:09:38	2019-10-14	17	[{"id_menu":4,"count":1}]	3619	delivery	5	22
10644	2019-10-14 01:28:54	2019-10-14	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3945	delivery	5	40
10645	2019-10-14 01:39:16	2019-10-14	9	[{"id_menu":7,"count":1}]	3952	delivery	5	14
10646	2019-10-14 02:51:21	2019-10-14	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3957	pick-up	0	21
10647	2019-10-14 03:10:01	2019-10-14	14	[{"id_menu":2,"count":1}]	833	pick-up	0	14
10648	2019-10-14 03:14:17	2019-10-14	14	[{"id_menu":2,"count":3}]	2729	delivery	5	19
10649	2019-10-14 03:15:59	2019-10-14	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	62	pick-up	0	26
10650	2019-10-14 03:45:11	2019-10-14	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":3}]	3934	delivery	5	26
10651	2019-10-14 04:33:59	2019-10-14	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	295	pick-up	0	21
10652	2019-10-14 05:04:26	2019-10-14	14	[{"id_menu":2,"count":1}]	2857	pick-up	0	14
10653	2019-10-14 05:24:58	2019-10-14	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	3385	pick-up	0	26
10654	2019-10-14 05:34:59	2019-10-14	9	[{"id_menu":6,"count":1}]	3954	pick-up	0	9
10655	2019-10-14 05:52:03	2019-10-14	12	[{"id_menu":1,"count":1}]	66	pick-up	0	12
10656	2019-10-14 06:22:15	2019-10-14	14	[{"id_menu":2,"count":1}]	304	delivery	5	19
10657	2019-10-14 06:58:34	2019-10-14	14	[{"id_menu":2,"count":1}]	3750	pick-up	0	14
10658	2019-10-14 07:02:37	2019-10-14	8	[{"id_menu":5,"count":1}]	3633	delivery	5	13
10659	2019-10-14 07:05:27	2019-10-14	9	[{"id_menu":7,"count":1}]	1687	pick-up	0	9
10660	2019-10-14 07:11:04	2019-10-14	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3947	delivery	5	34
10661	2019-10-14 07:20:06	2019-10-14	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	981	pick-up	0	24
10662	2019-10-14 07:29:35	2019-10-14	17	[{"id_menu":4,"count":1}]	1334	pick-up	0	17
10663	2019-10-14 08:01:40	2019-10-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1531	pick-up	0	26
10664	2019-10-14 08:11:10	2019-10-14	12	[{"id_menu":1,"count":1}]	2287	pick-up	0	12
10665	2019-10-14 08:22:09	2019-10-14	12	[{"id_menu":3,"count":1}]	3426	pick-up	0	12
10666	2019-10-14 08:33:00	2019-10-14	9	[{"id_menu":7,"count":1}]	1259	delivery	5	14
10667	2019-10-14 08:45:00	2019-10-14	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2843	delivery	5	26
10668	2019-10-14 09:48:44	2019-10-14	8	[{"id_menu":5,"count":1}]	3932	delivery	5	13
10669	2019-10-14 10:09:35	2019-10-14	14	[{"id_menu":2,"count":1}]	3536	pick-up	0	14
10670	2019-10-14 10:24:08	2019-10-14	9	[{"id_menu":7,"count":1}]	3792	delivery	5	14
10671	2019-10-14 10:57:34	2019-10-14	12	[{"id_menu":1,"count":1}]	2511	pick-up	0	12
10672	2019-10-14 11:20:22	2019-10-14	9	[{"id_menu":6,"count":1}]	3949	pick-up	0	9
10673	2019-10-14 11:38:47	2019-10-14	8	[{"id_menu":5,"count":1}]	3958	delivery	5	13
10674	2019-10-14 11:39:48	2019-10-14	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3927	pick-up	0	26
10675	2019-10-14 12:31:57	2019-10-14	20	[{"id_menu":3,"count":3},{"id_menu":5,"count":1}]	3709	pick-up	0	20
10676	2019-10-14 13:54:52	2019-10-14	12	[{"id_menu":3,"count":1}]	3924	pick-up	0	12
10677	2019-10-14 14:18:56	2019-10-14	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	437	delivery	5	23
10678	2019-10-14 14:21:39	2019-10-14	9	[{"id_menu":6,"count":1}]	2780	pick-up	0	9
10679	2019-10-14 14:56:12	2019-10-14	12	[{"id_menu":1,"count":1}]	2863	delivery	5	17
10680	2019-10-14 15:12:50	2019-10-14	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1507	pick-up	0	26
10681	2019-10-14 15:19:20	2019-10-14	17	[{"id_menu":4,"count":1}]	759	delivery	5	22
10682	2019-10-14 15:48:32	2019-10-14	12	[{"id_menu":3,"count":1}]	169	pick-up	0	12
10683	2019-10-14 16:05:02	2019-10-14	12	[{"id_menu":1,"count":1}]	3211	delivery	5	17
10684	2019-10-14 16:11:51	2019-10-14	9	[{"id_menu":7,"count":1}]	3873	delivery	5	14
10685	2019-10-14 16:23:42	2019-10-14	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	3940	delivery	5	31
10686	2019-10-14 16:25:15	2019-10-14	9	[{"id_menu":7,"count":1}]	219	delivery	5	14
10687	2019-10-14 16:50:19	2019-10-14	8	[{"id_menu":5,"count":1}]	3928	pick-up	0	8
10688	2019-10-14 17:16:04	2019-10-14	9	[{"id_menu":7,"count":2}]	3942	delivery	5	14
10689	2019-10-14 17:36:34	2019-10-14	12	[{"id_menu":1,"count":1}]	3944	pick-up	0	12
10690	2019-10-14 17:57:15	2019-10-14	9	[{"id_menu":7,"count":1}]	2482	pick-up	0	9
10691	2019-10-14 18:06:11	2019-10-14	12	[{"id_menu":1,"count":1}]	2821	pick-up	0	12
10692	2019-10-14 18:20:30	2019-10-14	12	[{"id_menu":3,"count":1}]	3933	delivery	5	17
10693	2019-10-14 19:05:50	2019-10-14	14	[{"id_menu":2,"count":1}]	1223	delivery	5	19
10694	2019-10-14 19:13:22	2019-10-14	9	[{"id_menu":7,"count":1}]	167	pick-up	0	9
10695	2019-10-14 19:35:02	2019-10-14	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1317	pick-up	0	26
10696	2019-10-14 20:02:17	2019-10-14	9	[{"id_menu":6,"count":1}]	1140	delivery	5	14
10697	2019-10-14 20:19:36	2019-10-14	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	3752	pick-up	0	24
10698	2019-10-14 20:44:37	2019-10-14	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1087	delivery	5	26
10699	2019-10-14 21:25:19	2019-10-14	9	[{"id_menu":7,"count":1}]	3153	pick-up	0	9
10700	2019-10-14 21:45:37	2019-10-14	8	[{"id_menu":5,"count":1}]	3956	delivery	5	13
10701	2019-10-14 21:48:33	2019-10-14	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2416	pick-up	0	43
10702	2019-10-14 23:08:03	2019-10-14	12	[{"id_menu":1,"count":1}]	3305	delivery	5	17
10703	2019-10-14 23:50:01	2019-10-14	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3931	pick-up	0	21
10704	2019-10-14 23:56:12	2019-10-14	9	[{"id_menu":6,"count":1}]	1013	delivery	5	14
10705	2019-10-15 00:41:12	2019-10-15	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2333	delivery	5	34
10706	2019-10-15 00:43:11	2019-10-15	12	[{"id_menu":1,"count":1}]	1708	delivery	5	17
10707	2019-10-15 00:55:35	2019-10-15	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	3970	delivery	5	27
10708	2019-10-15 00:56:10	2019-10-15	9	[{"id_menu":7,"count":1}]	3961	pick-up	0	9
10709	2019-10-15 01:44:23	2019-10-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1173	delivery	5	28
10710	2019-10-15 01:54:17	2019-10-15	9	[{"id_menu":6,"count":1}]	338	pick-up	0	9
10711	2019-10-15 02:00:59	2019-10-15	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	29	pick-up	0	31
10712	2019-10-15 02:02:31	2019-10-15	12	[{"id_menu":3,"count":1}]	2301	pick-up	0	12
10713	2019-10-15 02:39:40	2019-10-15	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3964	delivery	5	55
10714	2019-10-15 02:42:30	2019-10-15	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1379	delivery	5	31
10715	2019-10-15 02:56:27	2019-10-15	14	[{"id_menu":2,"count":1}]	1212	pick-up	0	14
10716	2019-10-15 02:56:50	2019-10-15	9	[{"id_menu":6,"count":1}]	1343	pick-up	0	9
10717	2019-10-15 03:58:23	2019-10-15	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3348	delivery	5	27
10718	2019-10-15 04:11:16	2019-10-15	8	[{"id_menu":5,"count":1}]	143	pick-up	0	8
10719	2019-10-15 04:34:17	2019-10-15	14	[{"id_menu":2,"count":1}]	36	pick-up	0	14
10720	2019-10-15 04:38:03	2019-10-15	17	[{"id_menu":4,"count":1}]	826	pick-up	0	17
10721	2019-10-15 05:04:36	2019-10-15	12	[{"id_menu":1,"count":1}]	2579	pick-up	0	12
10722	2019-10-15 05:13:18	2019-10-15	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1705	pick-up	0	20
10723	2019-10-15 07:06:24	2019-10-15	9	[{"id_menu":6,"count":1}]	92	delivery	5	14
10724	2019-10-15 07:12:48	2019-10-15	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3977	delivery	5	45
10725	2019-10-15 07:26:26	2019-10-15	8	[{"id_menu":5,"count":1}]	3149	delivery	5	13
10726	2019-10-15 07:29:17	2019-10-15	14	[{"id_menu":2,"count":1}]	111	pick-up	0	14
10727	2019-10-15 07:49:48	2019-10-15	9	[{"id_menu":6,"count":1}]	1597	pick-up	0	9
10728	2019-10-15 08:26:02	2019-10-15	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1081	pick-up	0	22
10729	2019-10-15 08:34:58	2019-10-15	9	[{"id_menu":6,"count":1}]	2659	pick-up	0	9
10730	2019-10-15 08:44:11	2019-10-15	9	[{"id_menu":7,"count":1}]	1098	delivery	5	14
10731	2019-10-15 08:47:28	2019-10-15	9	[{"id_menu":7,"count":2}]	2856	pick-up	0	9
10732	2019-10-15 08:56:21	2019-10-15	17	[{"id_menu":4,"count":1}]	332	delivery	5	22
10733	2019-10-15 08:58:00	2019-10-15	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	285	pick-up	0	21
10734	2019-10-15 08:59:14	2019-10-15	14	[{"id_menu":2,"count":1}]	3988	delivery	5	19
10735	2019-10-15 09:41:14	2019-10-15	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1025	pick-up	0	51
10736	2019-10-15 09:41:48	2019-10-15	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	3985	delivery	5	36
10737	2019-10-15 10:01:42	2019-10-15	14	[{"id_menu":2,"count":1}]	998	pick-up	0	14
10738	2019-10-15 10:24:22	2019-10-15	9	[{"id_menu":6,"count":1}]	2140	pick-up	0	9
10739	2019-10-15 10:59:20	2019-10-15	9	[{"id_menu":6,"count":1}]	3975	delivery	5	14
10740	2019-10-15 11:34:28	2019-10-15	17	[{"id_menu":4,"count":1}]	1968	delivery	5	22
10741	2019-10-15 12:08:19	2019-10-15	14	[{"id_menu":2,"count":1}]	3976	pick-up	0	14
10742	2019-10-15 12:13:48	2019-10-15	9	[{"id_menu":7,"count":1}]	1183	pick-up	0	9
10743	2019-10-15 12:57:53	2019-10-15	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1485	pick-up	0	17
10744	2019-10-15 13:13:10	2019-10-15	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1259	delivery	5	34
10745	2019-10-15 13:14:10	2019-10-15	14	[{"id_menu":2,"count":1}]	467	delivery	5	19
10746	2019-10-15 13:27:28	2019-10-15	17	[{"id_menu":4,"count":1}]	3967	pick-up	0	17
10747	2019-10-15 14:05:57	2019-10-15	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	2427	delivery	5	26
10748	2019-10-15 14:58:31	2019-10-15	9	[{"id_menu":7,"count":1}]	3989	delivery	5	14
10749	2019-10-15 15:49:31	2019-10-15	8	[{"id_menu":5,"count":1}]	578	delivery	5	13
10750	2019-10-15 16:37:28	2019-10-15	12	[{"id_menu":3,"count":1}]	381	pick-up	0	12
10751	2019-10-15 16:52:12	2019-10-15	17	[{"id_menu":4,"count":1}]	3959	delivery	5	22
10752	2019-10-15 17:44:08	2019-10-15	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	2583	delivery	5	25
10753	2019-10-15 17:56:10	2019-10-15	8	[{"id_menu":5,"count":1}]	3992	delivery	5	13
10754	2019-10-15 18:06:29	2019-10-15	17	[{"id_menu":4,"count":1}]	3467	delivery	5	22
10755	2019-10-15 18:08:20	2019-10-15	12	[{"id_menu":1,"count":1}]	2193	pick-up	0	12
10756	2019-10-15 18:20:38	2019-10-15	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3960	pick-up	0	37
10757	2019-10-15 18:26:43	2019-10-15	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3362	pick-up	0	29
10758	2019-10-15 18:40:14	2019-10-15	17	[{"id_menu":4,"count":1}]	1676	delivery	5	22
10759	2019-10-15 18:45:49	2019-10-15	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3713	delivery	5	31
10760	2019-10-15 18:45:53	2019-10-15	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3966	pick-up	0	17
10761	2019-10-15 18:53:35	2019-10-15	14	[{"id_menu":2,"count":1}]	1896	pick-up	0	14
10762	2019-10-15 18:56:59	2019-10-15	14	[{"id_menu":2,"count":1}]	147	delivery	5	19
10763	2019-10-15 19:04:11	2019-10-15	12	[{"id_menu":1,"count":1}]	78	pick-up	0	12
10764	2019-10-15 19:31:53	2019-10-15	9	[{"id_menu":7,"count":1}]	3974	delivery	5	14
10765	2019-10-15 19:37:13	2019-10-15	14	[{"id_menu":2,"count":1}]	3973	delivery	5	19
10766	2019-10-15 19:40:54	2019-10-15	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3993	delivery	5	27
10767	2019-10-15 19:56:45	2019-10-15	14	[{"id_menu":2,"count":1}]	646	pick-up	0	14
10768	2019-10-15 19:58:47	2019-10-15	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3324	pick-up	0	29
10769	2019-10-15 19:59:42	2019-10-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1536	pick-up	0	23
10770	2019-10-15 20:11:03	2019-10-15	9	[{"id_menu":7,"count":1}]	2294	pick-up	0	9
10771	2019-10-15 21:17:16	2019-10-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3971	pick-up	0	23
10772	2019-10-15 21:30:31	2019-10-15	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1548	pick-up	0	29
10773	2019-10-15 21:38:40	2019-10-15	9	[{"id_menu":6,"count":1}]	3991	delivery	5	14
10774	2019-10-15 22:02:53	2019-10-15	14	[{"id_menu":2,"count":1}]	3965	delivery	5	19
10775	2019-10-15 22:14:30	2019-10-15	12	[{"id_menu":3,"count":1}]	123	pick-up	0	12
10776	2019-10-15 23:01:43	2019-10-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	62	pick-up	0	23
10777	2019-10-15 23:09:30	2019-10-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3153	pick-up	0	18
10778	2019-10-15 23:16:35	2019-10-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3221	delivery	5	28
10779	2019-10-15 23:19:31	2019-10-15	14	[{"id_menu":2,"count":1}]	572	delivery	5	19
10780	2019-10-15 23:22:02	2019-10-15	9	[{"id_menu":7,"count":1}]	3994	delivery	5	14
10781	2019-10-15 23:25:22	2019-10-15	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	528	delivery	5	43
10782	2019-10-15 23:40:11	2019-10-15	9	[{"id_menu":7,"count":1}]	3659	delivery	5	14
10783	2019-10-16 00:19:31	2019-10-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4031	pick-up	0	26
10784	2019-10-16 00:19:50	2019-10-16	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3996	delivery	5	22
10785	2019-10-16 00:25:25	2019-10-16	14	[{"id_menu":2,"count":1}]	4028	pick-up	0	14
10786	2019-10-16 01:01:50	2019-10-16	9	[{"id_menu":7,"count":1}]	4003	delivery	5	14
10787	2019-10-16 01:15:23	2019-10-16	12	[{"id_menu":3,"count":1}]	2857	pick-up	0	12
10788	2019-10-16 01:21:09	2019-10-16	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	4021	pick-up	0	21
10789	2019-10-16 01:24:46	2019-10-16	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4019	delivery	5	48
10790	2019-10-16 01:39:27	2019-10-16	8	[{"id_menu":5,"count":1}]	1233	delivery	5	13
10791	2019-10-16 02:15:43	2019-10-16	12	[{"id_menu":1,"count":1}]	1904	pick-up	0	12
10792	2019-10-16 02:20:10	2019-10-16	8	[{"id_menu":5,"count":1}]	799	pick-up	0	8
10793	2019-10-16 02:51:58	2019-10-16	9	[{"id_menu":6,"count":1}]	4020	pick-up	0	9
10794	2019-10-16 03:19:02	2019-10-16	12	[{"id_menu":1,"count":2}]	3858	pick-up	0	12
10795	2019-10-16 03:53:50	2019-10-16	14	[{"id_menu":2,"count":1}]	4015	pick-up	0	14
10796	2019-10-16 04:03:20	2019-10-16	9	[{"id_menu":7,"count":1}]	779	pick-up	0	9
10797	2019-10-16 04:15:48	2019-10-16	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1318	pick-up	0	22
10798	2019-10-16 04:25:25	2019-10-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1657	pick-up	0	23
10799	2019-10-16 04:32:26	2019-10-16	9	[{"id_menu":6,"count":1}]	3995	pick-up	0	9
10800	2019-10-16 04:57:21	2019-10-16	12	[{"id_menu":1,"count":1}]	1652	pick-up	0	12
10801	2019-10-16 04:57:42	2019-10-16	14	[{"id_menu":2,"count":1}]	408	pick-up	0	14
10802	2019-10-16 04:58:05	2019-10-16	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	3848	pick-up	0	26
10803	2019-10-16 05:24:18	2019-10-16	8	[{"id_menu":5,"count":1}]	4014	pick-up	0	8
10804	2019-10-16 05:38:04	2019-10-16	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	274	delivery	5	26
10805	2019-10-16 05:38:04	2019-10-16	14	[{"id_menu":2,"count":1}]	4006	delivery	5	19
10806	2019-10-16 05:49:03	2019-10-16	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	4024	delivery	5	23
10807	2019-10-16 05:52:55	2019-10-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1352	pick-up	0	18
10808	2019-10-16 06:15:44	2019-10-16	9	[{"id_menu":6,"count":2}]	304	pick-up	0	9
10809	2019-10-16 06:34:32	2019-10-16	8	[{"id_menu":5,"count":1}]	4000	pick-up	0	8
10810	2019-10-16 06:39:08	2019-10-16	14	[{"id_menu":2,"count":1}]	2938	pick-up	0	14
10811	2019-10-16 08:03:47	2019-10-16	9	[{"id_menu":7,"count":1}]	3241	delivery	5	14
10812	2019-10-16 09:06:48	2019-10-16	9	[{"id_menu":6,"count":1}]	1140	delivery	5	14
10813	2019-10-16 09:12:08	2019-10-16	12	[{"id_menu":3,"count":1}]	3997	delivery	5	17
10814	2019-10-16 09:15:04	2019-10-16	8	[{"id_menu":5,"count":1}]	4026	delivery	5	13
10815	2019-10-16 09:51:48	2019-10-16	9	[{"id_menu":7,"count":1}]	4008	delivery	5	14
10816	2019-10-16 10:10:45	2019-10-16	17	[{"id_menu":4,"count":2}]	449	pick-up	0	17
10817	2019-10-16 10:24:41	2019-10-16	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3623	delivery	5	34
10818	2019-10-16 10:32:10	2019-10-16	9	[{"id_menu":6,"count":1}]	868	pick-up	0	9
10819	2019-10-16 10:34:22	2019-10-16	9	[{"id_menu":6,"count":1}]	2255	delivery	5	14
10820	2019-10-16 10:42:48	2019-10-16	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2770	pick-up	0	21
10821	2019-10-16 11:21:55	2019-10-16	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2165	pick-up	0	29
10822	2019-10-16 11:34:59	2019-10-16	12	[{"id_menu":3,"count":1}]	4016	delivery	5	17
10823	2019-10-16 12:10:03	2019-10-16	9	[{"id_menu":7,"count":1}]	1155	delivery	5	14
10824	2019-10-16 12:18:46	2019-10-16	17	[{"id_menu":4,"count":1}]	4001	delivery	5	22
10825	2019-10-16 12:21:46	2019-10-16	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3863	pick-up	0	43
10826	2019-10-16 12:43:08	2019-10-16	12	[{"id_menu":1,"count":1}]	1629	pick-up	0	12
10827	2019-10-16 13:00:25	2019-10-16	17	[{"id_menu":4,"count":1}]	415	delivery	5	22
10828	2019-10-16 13:13:13	2019-10-16	12	[{"id_menu":1,"count":1}]	1545	delivery	5	17
10829	2019-10-16 13:15:23	2019-10-16	8	[{"id_menu":5,"count":1}]	1104	pick-up	0	8
10830	2019-10-16 13:33:20	2019-10-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	839	pick-up	0	21
10831	2019-10-16 14:18:49	2019-10-16	14	[{"id_menu":2,"count":2}]	3820	delivery	5	19
10832	2019-10-16 14:28:36	2019-10-16	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4017	delivery	5	31
10833	2019-10-16 15:01:53	2019-10-16	14	[{"id_menu":2,"count":1}]	389	pick-up	0	14
10834	2019-10-16 15:04:10	2019-10-16	9	[{"id_menu":7,"count":1}]	2082	pick-up	0	9
10835	2019-10-16 15:12:55	2019-10-16	14	[{"id_menu":2,"count":1}]	467	pick-up	0	14
10836	2019-10-16 15:17:17	2019-10-16	9	[{"id_menu":6,"count":1}]	4009	pick-up	0	9
10837	2019-10-16 15:22:07	2019-10-16	17	[{"id_menu":4,"count":1}]	717	pick-up	0	17
10838	2019-10-16 15:24:49	2019-10-16	12	[{"id_menu":1,"count":1}]	2419	delivery	5	17
10839	2019-10-16 15:50:41	2019-10-16	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	4018	delivery	5	42
10840	2019-10-16 15:59:14	2019-10-16	12	[{"id_menu":1,"count":1}]	2951	delivery	5	17
10841	2019-10-16 16:24:09	2019-10-16	12	[{"id_menu":1,"count":1}]	2735	pick-up	0	12
10842	2019-10-16 16:48:29	2019-10-16	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3825	delivery	5	36
10843	2019-10-16 17:00:10	2019-10-16	12	[{"id_menu":3,"count":1}]	976	pick-up	0	12
10844	2019-10-16 17:11:40	2019-10-16	9	[{"id_menu":6,"count":1}]	4013	pick-up	0	9
10845	2019-10-16 17:54:00	2019-10-16	12	[{"id_menu":3,"count":1}]	3999	delivery	5	17
10846	2019-10-16 18:05:07	2019-10-16	8	[{"id_menu":5,"count":2}]	4004	delivery	5	13
10847	2019-10-16 18:10:40	2019-10-16	14	[{"id_menu":2,"count":1}]	4002	delivery	5	19
10848	2019-10-16 18:26:27	2019-10-16	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	4029	delivery	5	31
10849	2019-10-16 18:35:04	2019-10-16	12	[{"id_menu":1,"count":1}]	4007	delivery	5	17
10850	2019-10-16 18:58:35	2019-10-16	17	[{"id_menu":4,"count":1}]	1834	delivery	5	22
10851	2019-10-16 19:02:44	2019-10-16	12	[{"id_menu":1,"count":1}]	3780	pick-up	0	12
10852	2019-10-16 19:02:47	2019-10-16	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	352	pick-up	0	41
10853	2019-10-16 20:05:34	2019-10-16	9	[{"id_menu":6,"count":1}]	153	pick-up	0	9
10854	2019-10-16 20:07:32	2019-10-16	14	[{"id_menu":2,"count":1}]	1144	pick-up	0	14
10855	2019-10-16 20:12:01	2019-10-16	9	[{"id_menu":7,"count":1}]	4012	pick-up	0	9
10856	2019-10-16 20:21:59	2019-10-16	9	[{"id_menu":6,"count":1}]	2520	pick-up	0	9
10857	2019-10-16 20:22:47	2019-10-16	9	[{"id_menu":7,"count":1}]	3102	pick-up	0	9
10858	2019-10-16 21:01:37	2019-10-16	9	[{"id_menu":6,"count":1}]	2661	delivery	5	14
10859	2019-10-16 21:40:21	2019-10-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3211	delivery	5	31
10860	2019-10-16 21:49:02	2019-10-16	17	[{"id_menu":4,"count":1}]	575	pick-up	0	17
10861	2019-10-16 21:58:34	2019-10-16	8	[{"id_menu":5,"count":1}]	4022	delivery	5	13
10862	2019-10-16 22:02:36	2019-10-16	14	[{"id_menu":2,"count":1}]	719	delivery	5	19
10863	2019-10-16 22:03:11	2019-10-16	14	[{"id_menu":2,"count":1}]	1258	pick-up	0	14
10864	2019-10-16 22:07:44	2019-10-16	17	[{"id_menu":4,"count":1}]	4027	delivery	5	22
10865	2019-10-16 22:13:32	2019-10-16	17	[{"id_menu":4,"count":1}]	141	pick-up	0	17
10866	2019-10-16 22:20:52	2019-10-16	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4032	delivery	5	45
10867	2019-10-16 22:23:57	2019-10-16	17	[{"id_menu":4,"count":2}]	1627	pick-up	0	17
10868	2019-10-16 22:30:16	2019-10-16	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1097	pick-up	0	52
10869	2019-10-16 22:41:10	2019-10-16	9	[{"id_menu":6,"count":1}]	2175	pick-up	0	9
10870	2019-10-16 22:49:43	2019-10-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	1848	delivery	5	28
10871	2019-10-16 23:02:37	2019-10-16	9	[{"id_menu":6,"count":1}]	3741	pick-up	0	9
10872	2019-10-16 23:19:26	2019-10-16	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":2}]	4010	delivery	5	28
10873	2019-10-17 00:06:31	2019-10-17	9	[{"id_menu":6,"count":1}]	4051	pick-up	0	9
10874	2019-10-17 00:12:55	2019-10-17	9	[{"id_menu":7,"count":1}]	1526	pick-up	0	9
10875	2019-10-17 00:30:22	2019-10-17	14	[{"id_menu":2,"count":1}]	4033	pick-up	0	14
10876	2019-10-17 00:48:13	2019-10-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	3240	delivery	5	28
10877	2019-10-17 00:49:24	2019-10-17	14	[{"id_menu":2,"count":1}]	4055	delivery	5	19
10878	2019-10-17 00:57:24	2019-10-17	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4059	delivery	5	47
10879	2019-10-17 01:18:15	2019-10-17	12	[{"id_menu":3,"count":1}]	1427	pick-up	0	12
10880	2019-10-17 01:27:40	2019-10-17	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3392	delivery	5	26
10881	2019-10-17 01:30:50	2019-10-17	9	[{"id_menu":7,"count":1}]	1362	delivery	5	14
10882	2019-10-17 01:42:29	2019-10-17	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	74	pick-up	0	21
10883	2019-10-17 01:55:16	2019-10-17	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3614	pick-up	0	22
10884	2019-10-17 01:56:01	2019-10-17	8	[{"id_menu":5,"count":1}]	3102	pick-up	0	8
10885	2019-10-17 02:08:52	2019-10-17	17	[{"id_menu":4,"count":1}]	4058	delivery	5	22
10886	2019-10-17 02:59:59	2019-10-17	9	[{"id_menu":6,"count":1}]	2379	pick-up	0	9
10887	2019-10-17 03:13:04	2019-10-17	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	3847	pick-up	0	26
10888	2019-10-17 03:50:43	2019-10-17	17	[{"id_menu":4,"count":1}]	4054	pick-up	0	17
10889	2019-10-17 04:02:04	2019-10-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1775	pick-up	0	18
10890	2019-10-17 04:06:25	2019-10-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1811	pick-up	0	23
10891	2019-10-17 04:36:55	2019-10-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	4056	delivery	5	28
10892	2019-10-17 04:56:05	2019-10-17	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2287	pick-up	0	26
10893	2019-10-17 04:58:00	2019-10-17	9	[{"id_menu":6,"count":1}]	2962	delivery	5	14
10894	2019-10-17 05:01:28	2019-10-17	9	[{"id_menu":7,"count":1}]	4042	pick-up	0	9
10895	2019-10-17 05:25:17	2019-10-17	9	[{"id_menu":6,"count":1}]	4048	delivery	5	14
10896	2019-10-17 05:25:35	2019-10-17	9	[{"id_menu":6,"count":1}]	2119	pick-up	0	9
10897	2019-10-17 05:27:38	2019-10-17	17	[{"id_menu":4,"count":1}]	2526	pick-up	0	17
10898	2019-10-17 05:29:37	2019-10-17	12	[{"id_menu":1,"count":1}]	343	pick-up	0	12
10899	2019-10-17 06:44:46	2019-10-17	12	[{"id_menu":1,"count":1}]	333	pick-up	0	12
10900	2019-10-17 06:50:08	2019-10-17	9	[{"id_menu":6,"count":1}]	4052	delivery	5	14
10901	2019-10-17 07:02:56	2019-10-17	14	[{"id_menu":2,"count":1}]	2807	delivery	5	19
10902	2019-10-17 07:04:20	2019-10-17	14	[{"id_menu":2,"count":1}]	1765	pick-up	0	14
10903	2019-10-17 07:07:47	2019-10-17	12	[{"id_menu":3,"count":1}]	1664	delivery	5	17
10904	2019-10-17 07:08:37	2019-10-17	12	[{"id_menu":1,"count":1}]	4053	delivery	5	17
10905	2019-10-17 07:25:48	2019-10-17	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	4049	delivery	5	31
10906	2019-10-17 07:44:17	2019-10-17	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4045	delivery	5	34
10907	2019-10-17 07:54:56	2019-10-17	8	[{"id_menu":5,"count":1}]	4064	delivery	5	13
10908	2019-10-17 08:09:41	2019-10-17	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1095	pick-up	0	29
10909	2019-10-17 08:11:59	2019-10-17	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4038	delivery	5	34
10910	2019-10-17 08:15:05	2019-10-17	9	[{"id_menu":6,"count":1}]	1388	delivery	5	14
10911	2019-10-17 08:26:30	2019-10-17	9	[{"id_menu":6,"count":1}]	2662	pick-up	0	9
10912	2019-10-17 08:34:57	2019-10-17	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1649	pick-up	0	26
10913	2019-10-17 08:59:39	2019-10-17	8	[{"id_menu":5,"count":1}]	2311	pick-up	0	8
10914	2019-10-17 09:06:30	2019-10-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4062	delivery	5	28
10915	2019-10-17 09:12:53	2019-10-17	9	[{"id_menu":6,"count":1}]	3449	delivery	5	14
10916	2019-10-17 09:37:13	2019-10-17	8	[{"id_menu":5,"count":1}]	4039	pick-up	0	8
10917	2019-10-17 09:58:35	2019-10-17	9	[{"id_menu":6,"count":1}]	4067	delivery	5	14
10918	2019-10-17 10:11:05	2019-10-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	213	pick-up	0	18
10919	2019-10-17 10:23:30	2019-10-17	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	713	delivery	5	36
10920	2019-10-17 11:19:25	2019-10-17	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4041	delivery	5	40
10921	2019-10-17 11:47:59	2019-10-17	14	[{"id_menu":2,"count":1}]	841	delivery	5	19
10922	2019-10-17 12:12:18	2019-10-17	9	[{"id_menu":7,"count":1}]	2200	pick-up	0	9
10923	2019-10-17 12:14:41	2019-10-17	12	[{"id_menu":1,"count":1}]	3180	pick-up	0	12
10924	2019-10-17 12:27:23	2019-10-17	12	[{"id_menu":3,"count":1}]	4034	pick-up	0	12
10925	2019-10-17 12:32:03	2019-10-17	17	[{"id_menu":4,"count":1}]	2333	pick-up	0	17
10926	2019-10-17 12:49:13	2019-10-17	9	[{"id_menu":7,"count":1}]	1241	pick-up	0	9
10927	2019-10-17 13:03:26	2019-10-17	14	[{"id_menu":2,"count":1}]	1352	pick-up	0	14
10928	2019-10-17 13:25:41	2019-10-17	9	[{"id_menu":7,"count":1}]	1185	delivery	5	14
10929	2019-10-17 13:32:49	2019-10-17	8	[{"id_menu":5,"count":1}]	3515	delivery	5	13
10930	2019-10-17 13:35:17	2019-10-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2436	pick-up	0	23
10931	2019-10-17 14:25:01	2019-10-17	14	[{"id_menu":2,"count":1}]	2891	pick-up	0	14
10932	2019-10-17 14:25:11	2019-10-17	9	[{"id_menu":7,"count":1}]	491	pick-up	0	9
10933	2019-10-17 14:30:09	2019-10-17	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2838	pick-up	0	31
10934	2019-10-17 14:33:48	2019-10-17	17	[{"id_menu":4,"count":1}]	1963	delivery	5	22
10935	2019-10-17 14:58:00	2019-10-17	17	[{"id_menu":4,"count":1}]	527	pick-up	0	17
10936	2019-10-17 15:09:31	2019-10-17	17	[{"id_menu":4,"count":1}]	4040	pick-up	0	17
10937	2019-10-17 15:32:47	2019-10-17	17	[{"id_menu":4,"count":1}]	1015	pick-up	0	17
10938	2019-10-17 15:35:19	2019-10-17	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3843	delivery	5	35
10939	2019-10-17 15:38:42	2019-10-17	8	[{"id_menu":5,"count":1}]	1912	pick-up	0	8
10940	2019-10-17 15:48:57	2019-10-17	9	[{"id_menu":6,"count":1}]	4065	pick-up	0	9
10941	2019-10-17 16:05:24	2019-10-17	12	[{"id_menu":1,"count":1}]	4061	delivery	5	17
10942	2019-10-17 16:15:51	2019-10-17	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3681	delivery	5	36
10943	2019-10-17 16:25:38	2019-10-17	9	[{"id_menu":6,"count":1}]	207	pick-up	0	9
10944	2019-10-17 16:51:15	2019-10-17	9	[{"id_menu":7,"count":1}]	4035	delivery	5	14
10945	2019-10-17 17:12:22	2019-10-17	9	[{"id_menu":7,"count":1}]	2731	delivery	5	14
10946	2019-10-17 17:24:42	2019-10-17	9	[{"id_menu":6,"count":1}]	1337	delivery	5	14
10947	2019-10-17 17:29:24	2019-10-17	12	[{"id_menu":1,"count":1}]	4037	delivery	5	17
10948	2019-10-17 17:56:21	2019-10-17	17	[{"id_menu":4,"count":1}]	4047	delivery	5	22
10949	2019-10-17 18:00:50	2019-10-17	9	[{"id_menu":6,"count":1}]	4046	delivery	5	14
10950	2019-10-17 18:01:56	2019-10-17	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	419	delivery	5	40
10951	2019-10-17 18:05:39	2019-10-17	12	[{"id_menu":3,"count":1}]	2590	pick-up	0	12
10952	2019-10-17 18:30:24	2019-10-17	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4043	delivery	5	34
10953	2019-10-17 19:25:17	2019-10-17	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4060	delivery	5	34
10954	2019-10-17 19:25:52	2019-10-17	9	[{"id_menu":7,"count":1}]	3997	delivery	5	14
10955	2019-10-17 19:32:02	2019-10-17	9	[{"id_menu":6,"count":1}]	4063	pick-up	0	9
10956	2019-10-17 20:59:20	2019-10-17	9	[{"id_menu":7,"count":1}]	3737	pick-up	0	9
10957	2019-10-17 21:18:32	2019-10-17	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2768	pick-up	0	35
10958	2019-10-17 21:22:00	2019-10-17	31	[{"id_menu":2,"count":3},{"id_menu":4,"count":1}]	2606	delivery	5	36
10959	2019-10-17 21:36:42	2019-10-17	12	[{"id_menu":1,"count":1}]	678	pick-up	0	12
10960	2019-10-17 21:38:56	2019-10-17	17	[{"id_menu":4,"count":1}]	1972	delivery	5	22
10961	2019-10-17 21:49:22	2019-10-17	9	[{"id_menu":7,"count":1}]	2052	pick-up	0	9
10962	2019-10-17 22:02:45	2019-10-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4044	delivery	5	23
10963	2019-10-17 22:22:13	2019-10-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3012	pick-up	0	26
10964	2019-10-17 22:49:10	2019-10-17	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3487	pick-up	0	31
10965	2019-10-17 23:01:48	2019-10-17	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2001	delivery	5	31
10966	2019-10-17 23:12:30	2019-10-17	9	[{"id_menu":7,"count":1}]	152	pick-up	0	9
10967	2019-10-17 23:13:43	2019-10-17	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4066	delivery	5	34
10968	2019-10-18 00:09:55	2019-10-18	9	[{"id_menu":7,"count":1}]	3735	pick-up	0	9
10969	2019-10-18 00:12:31	2019-10-18	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1531	pick-up	0	20
10970	2019-10-18 00:14:28	2019-10-18	9	[{"id_menu":6,"count":1}]	2244	pick-up	0	9
10971	2019-10-18 00:18:09	2019-10-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2358	pick-up	0	18
10972	2019-10-18 00:50:06	2019-10-18	12	[{"id_menu":1,"count":1}]	4071	pick-up	0	12
10973	2019-10-18 00:59:15	2019-10-18	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1308	delivery	5	29
10974	2019-10-18 01:25:00	2019-10-18	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3679	delivery	5	31
10975	2019-10-18 01:29:17	2019-10-18	8	[{"id_menu":5,"count":1}]	2943	pick-up	0	8
10976	2019-10-18 01:35:32	2019-10-18	14	[{"id_menu":2,"count":1}]	1685	pick-up	0	14
10977	2019-10-18 01:36:34	2019-10-18	9	[{"id_menu":6,"count":1}]	2706	pick-up	0	9
10978	2019-10-18 03:48:43	2019-10-18	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	4081	pick-up	0	29
10979	2019-10-18 03:57:29	2019-10-18	9	[{"id_menu":6,"count":1}]	1371	delivery	5	14
10980	2019-10-18 04:22:30	2019-10-18	12	[{"id_menu":1,"count":2}]	4092	pick-up	0	12
10981	2019-10-18 04:23:17	2019-10-18	9	[{"id_menu":7,"count":1}]	2134	pick-up	0	9
10982	2019-10-18 04:24:34	2019-10-18	14	[{"id_menu":2,"count":1}]	1375	pick-up	0	14
10983	2019-10-18 04:31:46	2019-10-18	8	[{"id_menu":5,"count":1}]	4073	delivery	5	13
10984	2019-10-18 04:53:55	2019-10-18	14	[{"id_menu":2,"count":1}]	4074	delivery	5	19
10985	2019-10-18 05:13:32	2019-10-18	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	455	delivery	5	26
10986	2019-10-18 05:15:18	2019-10-18	9	[{"id_menu":6,"count":2}]	630	pick-up	0	9
10987	2019-10-18 05:58:42	2019-10-18	12	[{"id_menu":3,"count":1}]	2909	delivery	5	17
10988	2019-10-18 06:02:23	2019-10-18	17	[{"id_menu":4,"count":1}]	2082	delivery	5	22
10989	2019-10-18 06:16:40	2019-10-18	9	[{"id_menu":7,"count":1}]	1052	pick-up	0	9
10990	2019-10-18 07:07:08	2019-10-18	12	[{"id_menu":1,"count":1}]	986	delivery	5	17
10991	2019-10-18 08:09:36	2019-10-18	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	1280	pick-up	0	29
10992	2019-10-18 08:22:29	2019-10-18	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4075	delivery	5	31
10993	2019-10-18 08:23:39	2019-10-18	14	[{"id_menu":2,"count":1}]	849	delivery	5	19
10994	2019-10-18 09:00:04	2019-10-18	8	[{"id_menu":5,"count":1}]	4107	delivery	5	13
10995	2019-10-18 09:28:35	2019-10-18	14	[{"id_menu":2,"count":1}]	431	pick-up	0	14
10996	2019-10-18 09:44:45	2019-10-18	8	[{"id_menu":5,"count":1}]	4085	delivery	5	13
10997	2019-10-18 10:09:18	2019-10-18	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4101	pick-up	0	26
10998	2019-10-18 10:09:46	2019-10-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	139	pick-up	0	23
10999	2019-10-18 10:16:02	2019-10-18	9	[{"id_menu":6,"count":1}]	867	delivery	5	14
11000	2019-10-18 10:28:54	2019-10-18	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	4078	delivery	5	36
11001	2019-10-18 10:35:03	2019-10-18	8	[{"id_menu":5,"count":1}]	4077	delivery	5	13
11002	2019-10-18 10:49:09	2019-10-18	14	[{"id_menu":2,"count":1}]	81	delivery	5	19
11003	2019-10-18 10:56:28	2019-10-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4072	pick-up	0	23
11004	2019-10-18 11:03:31	2019-10-18	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	3715	delivery	5	25
11005	2019-10-18 11:21:56	2019-10-18	12	[{"id_menu":1,"count":1}]	143	pick-up	0	12
11006	2019-10-18 12:17:11	2019-10-18	12	[{"id_menu":3,"count":1}]	575	pick-up	0	12
11007	2019-10-18 12:21:57	2019-10-18	14	[{"id_menu":2,"count":1}]	2928	pick-up	0	14
11008	2019-10-18 12:23:20	2019-10-18	8	[{"id_menu":5,"count":1}]	927	delivery	5	13
11009	2019-10-18 12:32:52	2019-10-18	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3467	delivery	5	34
11010	2019-10-18 12:34:45	2019-10-18	9	[{"id_menu":6,"count":1}]	2797	delivery	5	14
11011	2019-10-18 12:52:00	2019-10-18	12	[{"id_menu":1,"count":1}]	491	pick-up	0	12
11012	2019-10-18 13:05:19	2019-10-18	8	[{"id_menu":5,"count":1}]	4091	delivery	5	13
11013	2019-10-18 13:34:01	2019-10-18	14	[{"id_menu":2,"count":1}]	4109	pick-up	0	14
11014	2019-10-18 13:42:02	2019-10-18	12	[{"id_menu":3,"count":1}]	1970	delivery	5	17
11015	2019-10-18 13:59:01	2019-10-18	17	[{"id_menu":4,"count":1}]	2189	delivery	5	22
11016	2019-10-18 14:13:34	2019-10-18	8	[{"id_menu":5,"count":1}]	600	delivery	5	13
11017	2019-10-18 14:27:02	2019-10-18	9	[{"id_menu":6,"count":1}]	1693	pick-up	0	9
11018	2019-10-18 14:32:52	2019-10-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2546	pick-up	0	23
11019	2019-10-18 14:36:18	2019-10-18	9	[{"id_menu":6,"count":1}]	585	delivery	5	14
11020	2019-10-18 14:45:03	2019-10-18	14	[{"id_menu":2,"count":1}]	1810	pick-up	0	14
11021	2019-10-18 15:12:45	2019-10-18	9	[{"id_menu":6,"count":1}]	2959	pick-up	0	9
11022	2019-10-18 15:33:33	2019-10-18	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	41	pick-up	0	21
11023	2019-10-18 16:13:31	2019-10-18	9	[{"id_menu":6,"count":1}]	2050	pick-up	0	9
11024	2019-10-18 16:15:44	2019-10-18	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1303	delivery	5	26
11025	2019-10-18 16:30:06	2019-10-18	12	[{"id_menu":3,"count":2}]	2768	pick-up	0	12
11026	2019-10-18 16:58:47	2019-10-18	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	1656	pick-up	0	23
11027	2019-10-18 17:02:19	2019-10-18	17	[{"id_menu":4,"count":1}]	4098	delivery	5	22
11028	2019-10-18 17:08:32	2019-10-18	9	[{"id_menu":7,"count":1}]	2477	pick-up	0	9
11029	2019-10-18 17:26:56	2019-10-18	8	[{"id_menu":5,"count":1}]	3705	delivery	5	13
11030	2019-10-18 17:34:54	2019-10-18	14	[{"id_menu":2,"count":1}]	4090	pick-up	0	14
11031	2019-10-18 18:21:06	2019-10-18	9	[{"id_menu":7,"count":1}]	4100	delivery	5	14
11032	2019-10-18 18:38:28	2019-10-18	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2207	pick-up	0	44
11033	2019-10-18 18:41:52	2019-10-18	17	[{"id_menu":4,"count":2}]	4086	delivery	5	22
11034	2019-10-18 18:56:49	2019-10-18	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":2}]	3371	delivery	5	22
11035	2019-10-18 19:02:16	2019-10-18	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	577	delivery	5	42
11036	2019-10-18 19:42:57	2019-10-18	14	[{"id_menu":2,"count":1}]	1834	pick-up	0	14
11037	2019-10-18 19:44:42	2019-10-18	14	[{"id_menu":2,"count":1}]	1980	delivery	5	19
11038	2019-10-18 20:44:32	2019-10-18	9	[{"id_menu":7,"count":1}]	4087	pick-up	0	9
11039	2019-10-18 21:14:50	2019-10-18	17	[{"id_menu":4,"count":1}]	1905	delivery	5	22
11040	2019-10-18 21:55:10	2019-10-18	9	[{"id_menu":7,"count":1}]	4084	delivery	5	14
11041	2019-10-18 22:02:39	2019-10-18	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	427	delivery	5	54
11042	2019-10-18 22:06:16	2019-10-18	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4104	delivery	5	34
11043	2019-10-18 22:38:53	2019-10-18	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4069	delivery	5	22
11044	2019-10-18 22:46:27	2019-10-18	9	[{"id_menu":7,"count":1}]	3031	pick-up	0	9
11045	2019-10-18 23:13:51	2019-10-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4088	delivery	5	23
11046	2019-10-18 23:21:21	2019-10-18	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3165	delivery	5	38
11047	2019-10-18 23:27:57	2019-10-18	17	[{"id_menu":4,"count":1}]	1119	delivery	5	22
11048	2019-10-19 00:05:42	2019-10-19	12	[{"id_menu":3,"count":1}]	4116	delivery	5	17
11049	2019-10-19 00:38:17	2019-10-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	4134	pick-up	0	18
11050	2019-10-19 00:48:29	2019-10-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	706	delivery	5	36
11051	2019-10-19 00:49:05	2019-10-19	14	[{"id_menu":2,"count":2}]	4114	delivery	5	19
11052	2019-10-19 01:08:56	2019-10-19	12	[{"id_menu":1,"count":1}]	4111	delivery	5	17
11053	2019-10-19 01:22:46	2019-10-19	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4142	delivery	5	45
11054	2019-10-19 01:31:35	2019-10-19	14	[{"id_menu":2,"count":1}]	4130	delivery	5	19
11055	2019-10-19 01:36:30	2019-10-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	424	delivery	5	36
11056	2019-10-19 01:43:00	2019-10-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3153	pick-up	0	17
11057	2019-10-19 01:54:09	2019-10-19	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2055	pick-up	0	26
11058	2019-10-19 01:57:26	2019-10-19	9	[{"id_menu":7,"count":1}]	742	pick-up	0	9
11059	2019-10-19 02:12:14	2019-10-19	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	338	delivery	5	28
11060	2019-10-19 02:30:03	2019-10-19	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	4124	delivery	5	39
11061	2019-10-19 02:33:48	2019-10-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4119	delivery	5	22
11062	2019-10-19 02:35:40	2019-10-19	8	[{"id_menu":5,"count":1}]	3224	pick-up	0	8
11063	2019-10-19 02:38:52	2019-10-19	17	[{"id_menu":4,"count":1}]	1694	pick-up	0	17
11064	2019-10-19 02:43:20	2019-10-19	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1167	delivery	5	48
11065	2019-10-19 02:56:04	2019-10-19	14	[{"id_menu":2,"count":1}]	4131	delivery	5	19
11066	2019-10-19 02:57:17	2019-10-19	17	[{"id_menu":4,"count":1}]	2232	pick-up	0	17
11067	2019-10-19 02:58:04	2019-10-19	8	[{"id_menu":5,"count":1}]	3882	delivery	5	13
11068	2019-10-19 03:24:15	2019-10-19	9	[{"id_menu":7,"count":1}]	3384	pick-up	0	9
11069	2019-10-19 03:30:05	2019-10-19	9	[{"id_menu":6,"count":1}]	3784	delivery	5	14
11070	2019-10-19 03:39:12	2019-10-19	12	[{"id_menu":3,"count":1}]	1432	delivery	5	17
11071	2019-10-19 03:44:19	2019-10-19	17	[{"id_menu":4,"count":1}]	886	pick-up	0	17
11072	2019-10-19 03:53:15	2019-10-19	12	[{"id_menu":3,"count":1}]	3205	pick-up	0	12
11073	2019-10-19 04:28:41	2019-10-19	14	[{"id_menu":2,"count":1}]	4103	pick-up	0	14
11074	2019-10-19 04:52:45	2019-10-19	17	[{"id_menu":4,"count":1}]	4138	delivery	5	22
11075	2019-10-19 04:57:05	2019-10-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2193	delivery	5	28
11076	2019-10-19 05:07:47	2019-10-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3126	pick-up	0	17
11077	2019-10-19 05:09:05	2019-10-19	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2602	delivery	5	26
11078	2019-10-19 05:09:05	2019-10-19	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1058	pick-up	0	25
11079	2019-10-19 06:12:13	2019-10-19	9	[{"id_menu":6,"count":1}]	4132	pick-up	0	9
11080	2019-10-19 06:34:11	2019-10-19	9	[{"id_menu":7,"count":1}]	3281	delivery	5	14
11081	2019-10-19 06:44:49	2019-10-19	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1220	delivery	5	31
11082	2019-10-19 06:52:09	2019-10-19	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	701	pick-up	0	43
11083	2019-10-19 07:00:06	2019-10-19	12	[{"id_menu":1,"count":1}]	1053	pick-up	0	12
11084	2019-10-19 07:04:30	2019-10-19	9	[{"id_menu":6,"count":1}]	330	delivery	5	14
11085	2019-10-19 07:04:33	2019-10-19	12	[{"id_menu":3,"count":2}]	4143	delivery	5	17
11086	2019-10-19 07:04:46	2019-10-19	12	[{"id_menu":1,"count":1}]	2715	delivery	5	17
11087	2019-10-19 07:54:05	2019-10-19	14	[{"id_menu":2,"count":1}]	3040	delivery	5	19
11088	2019-10-19 08:14:51	2019-10-19	9	[{"id_menu":7,"count":1}]	4135	delivery	5	14
11089	2019-10-19 08:30:37	2019-10-19	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	3491	pick-up	0	29
11090	2019-10-19 09:22:46	2019-10-19	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	111	pick-up	0	43
11091	2019-10-19 09:27:09	2019-10-19	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	4125	delivery	5	30
11092	2019-10-19 09:30:22	2019-10-19	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	208	pick-up	0	26
11093	2019-10-19 09:37:24	2019-10-19	17	[{"id_menu":4,"count":1}]	4148	delivery	5	22
11094	2019-10-19 09:45:16	2019-10-19	8	[{"id_menu":5,"count":1}]	2801	delivery	5	13
11095	2019-10-19 09:45:50	2019-10-19	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	945	delivery	5	40
11096	2019-10-19 09:47:12	2019-10-19	9	[{"id_menu":6,"count":1}]	1070	pick-up	0	9
11097	2019-10-19 09:53:26	2019-10-19	14	[{"id_menu":2,"count":1}]	4014	pick-up	0	14
11098	2019-10-19 10:15:42	2019-10-19	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	4120	pick-up	0	26
11099	2019-10-19 10:33:08	2019-10-19	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3707	delivery	5	40
11100	2019-10-19 10:35:08	2019-10-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	138	pick-up	0	17
11101	2019-10-19 11:37:41	2019-10-19	12	[{"id_menu":3,"count":1}]	351	delivery	5	17
11102	2019-10-19 11:40:26	2019-10-19	9	[{"id_menu":7,"count":1}]	1626	delivery	5	14
11103	2019-10-19 11:44:53	2019-10-19	12	[{"id_menu":3,"count":1}]	531	delivery	5	17
11104	2019-10-19 11:46:07	2019-10-19	12	[{"id_menu":3,"count":1}]	314	pick-up	0	12
11105	2019-10-19 12:00:29	2019-10-19	14	[{"id_menu":2,"count":1}]	2413	delivery	5	19
11106	2019-10-19 12:31:02	2019-10-19	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2570	pick-up	0	20
11107	2019-10-19 12:33:24	2019-10-19	9	[{"id_menu":6,"count":1}]	2870	pick-up	0	9
11108	2019-10-19 12:38:25	2019-10-19	9	[{"id_menu":6,"count":1}]	4122	pick-up	0	9
11109	2019-10-19 12:43:13	2019-10-19	9	[{"id_menu":6,"count":1}]	4145	pick-up	0	9
11110	2019-10-19 12:45:46	2019-10-19	14	[{"id_menu":2,"count":1}]	2481	delivery	5	19
11111	2019-10-19 12:53:44	2019-10-19	17	[{"id_menu":4,"count":1}]	4140	delivery	5	22
11112	2019-10-19 12:59:02	2019-10-19	12	[{"id_menu":3,"count":1}]	4117	delivery	5	17
11113	2019-10-19 13:02:19	2019-10-19	9	[{"id_menu":7,"count":1}]	2130	pick-up	0	9
11114	2019-10-19 13:15:36	2019-10-19	17	[{"id_menu":4,"count":1}]	1010	delivery	5	22
11115	2019-10-19 13:32:47	2019-10-19	12	[{"id_menu":3,"count":1}]	4112	pick-up	0	12
11116	2019-10-19 13:58:51	2019-10-19	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4057	delivery	5	39
11117	2019-10-19 14:02:45	2019-10-19	14	[{"id_menu":2,"count":1}]	903	delivery	5	19
11118	2019-10-19 14:15:51	2019-10-19	12	[{"id_menu":3,"count":1}]	293	pick-up	0	12
11119	2019-10-19 14:37:00	2019-10-19	14	[{"id_menu":2,"count":1}]	1779	pick-up	0	14
11120	2019-10-19 14:43:25	2019-10-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2507	delivery	5	28
11121	2019-10-19 15:07:14	2019-10-19	12	[{"id_menu":3,"count":1}]	1382	pick-up	0	12
11122	2019-10-19 15:24:49	2019-10-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2948	delivery	5	36
11123	2019-10-19 16:13:15	2019-10-19	17	[{"id_menu":4,"count":1}]	126	pick-up	0	17
11124	2019-10-19 16:19:21	2019-10-19	14	[{"id_menu":2,"count":1}]	1068	pick-up	0	14
11125	2019-10-19 16:20:53	2019-10-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4141	delivery	5	28
11126	2019-10-19 16:27:07	2019-10-19	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4127	delivery	5	40
11127	2019-10-19 16:27:37	2019-10-19	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	921	delivery	5	48
11128	2019-10-19 16:31:02	2019-10-19	9	[{"id_menu":7,"count":1}]	299	delivery	5	14
11129	2019-10-19 16:41:37	2019-10-19	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	788	pick-up	0	21
11130	2019-10-19 16:42:40	2019-10-19	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1529	pick-up	0	29
11131	2019-10-19 16:42:58	2019-10-19	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4115	pick-up	0	29
11132	2019-10-19 16:44:50	2019-10-19	8	[{"id_menu":5,"count":1}]	1354	pick-up	0	8
11133	2019-10-19 17:27:04	2019-10-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3202	delivery	5	22
11134	2019-10-19 17:32:25	2019-10-19	17	[{"id_menu":4,"count":1}]	201	pick-up	0	17
11135	2019-10-19 17:36:13	2019-10-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3755	delivery	5	31
11136	2019-10-19 17:58:13	2019-10-19	17	[{"id_menu":4,"count":1}]	707	pick-up	0	17
11137	2019-10-19 18:01:00	2019-10-19	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	3892	delivery	5	22
11138	2019-10-19 18:03:37	2019-10-19	14	[{"id_menu":2,"count":2}]	3527	pick-up	0	14
11139	2019-10-19 18:10:33	2019-10-19	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	4121	pick-up	0	26
11140	2019-10-19 18:15:08	2019-10-19	12	[{"id_menu":1,"count":1}]	980	pick-up	0	12
11141	2019-10-19 18:18:08	2019-10-19	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	4129	delivery	5	31
11142	2019-10-19 18:23:44	2019-10-19	17	[{"id_menu":4,"count":1}]	2085	pick-up	0	17
11143	2019-10-19 19:05:42	2019-10-19	9	[{"id_menu":7,"count":1}]	4147	pick-up	0	9
11144	2019-10-19 19:07:08	2019-10-19	9	[{"id_menu":6,"count":1}]	551	pick-up	0	9
11145	2019-10-19 19:10:20	2019-10-19	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	2998	delivery	5	26
11146	2019-10-19 19:17:26	2019-10-19	14	[{"id_menu":2,"count":1}]	2076	pick-up	0	14
11147	2019-10-19 19:59:37	2019-10-19	12	[{"id_menu":1,"count":1}]	4144	pick-up	0	12
11148	2019-10-19 20:02:37	2019-10-19	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	492	delivery	5	23
11149	2019-10-19 20:05:19	2019-10-19	12	[{"id_menu":1,"count":1}]	3507	pick-up	0	12
11150	2019-10-19 20:08:28	2019-10-19	17	[{"id_menu":4,"count":1}]	4137	pick-up	0	17
11151	2019-10-19 20:13:24	2019-10-19	9	[{"id_menu":6,"count":1}]	2882	delivery	5	14
11152	2019-10-19 20:14:33	2019-10-19	49	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1204	pick-up	0	49
11153	2019-10-19 20:32:44	2019-10-19	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3868	delivery	5	26
11154	2019-10-19 21:18:10	2019-10-19	9	[{"id_menu":6,"count":1}]	4123	pick-up	0	9
11155	2019-10-19 21:21:09	2019-10-19	12	[{"id_menu":1,"count":1}]	3610	delivery	5	17
11156	2019-10-19 21:39:17	2019-10-19	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	1900	delivery	5	39
11157	2019-10-19 21:44:47	2019-10-19	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	372	delivery	5	36
11158	2019-10-19 21:54:04	2019-10-19	9	[{"id_menu":6,"count":2}]	2583	delivery	5	14
11159	2019-10-19 21:56:52	2019-10-19	17	[{"id_menu":4,"count":1}]	2851	pick-up	0	17
11160	2019-10-19 22:02:31	2019-10-19	9	[{"id_menu":7,"count":1}]	3765	delivery	5	14
11161	2019-10-19 22:33:27	2019-10-19	17	[{"id_menu":4,"count":2}]	4146	pick-up	0	17
11162	2019-10-19 22:47:55	2019-10-19	14	[{"id_menu":2,"count":1}]	2593	pick-up	0	14
11163	2019-10-19 23:01:33	2019-10-19	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1686	delivery	5	29
11164	2019-10-19 23:02:31	2019-10-19	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4133	delivery	5	53
11165	2019-10-19 23:06:43	2019-10-19	12	[{"id_menu":1,"count":1}]	2719	delivery	5	17
11166	2019-10-19 23:11:03	2019-10-19	14	[{"id_menu":2,"count":1}]	4126	delivery	5	19
11167	2019-10-19 23:13:41	2019-10-19	14	[{"id_menu":2,"count":1}]	2572	delivery	5	19
11168	2019-10-19 23:15:38	2019-10-19	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	401	pick-up	0	22
11169	2019-10-19 23:28:39	2019-10-19	9	[{"id_menu":6,"count":1}]	4139	delivery	5	14
11170	2019-10-19 23:44:49	2019-10-19	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	4113	delivery	5	30
11171	2019-10-19 23:58:00	2019-10-19	9	[{"id_menu":6,"count":1}]	4136	pick-up	0	9
11172	2019-10-20 00:01:53	2019-10-20	17	[{"id_menu":4,"count":1}]	1152	pick-up	0	17
11173	2019-10-20 00:17:58	2019-10-20	9	[{"id_menu":7,"count":1}]	2227	delivery	5	14
11174	2019-10-20 00:35:41	2019-10-20	9	[{"id_menu":7,"count":1}]	4154	delivery	5	14
11175	2019-10-20 00:43:21	2019-10-20	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4161	pick-up	0	31
11176	2019-10-20 00:51:12	2019-10-20	9	[{"id_menu":7,"count":1}]	4184	delivery	5	14
11177	2019-10-20 00:53:17	2019-10-20	12	[{"id_menu":3,"count":2}]	691	pick-up	0	12
11178	2019-10-20 00:56:17	2019-10-20	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	2597	pick-up	0	26
11179	2019-10-20 01:03:29	2019-10-20	12	[{"id_menu":1,"count":1}]	2795	pick-up	0	12
11180	2019-10-20 01:04:17	2019-10-20	9	[{"id_menu":7,"count":1}]	2197	pick-up	0	9
11181	2019-10-20 01:09:42	2019-10-20	9	[{"id_menu":6,"count":1}]	904	delivery	5	14
11182	2019-10-20 01:10:40	2019-10-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1088	pick-up	0	23
11183	2019-10-20 01:43:02	2019-10-20	17	[{"id_menu":4,"count":1}]	4156	pick-up	0	17
11184	2019-10-20 01:45:56	2019-10-20	9	[{"id_menu":6,"count":1}]	1894	pick-up	0	9
11185	2019-10-20 01:51:09	2019-10-20	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1025	delivery	5	27
11186	2019-10-20 01:51:12	2019-10-20	12	[{"id_menu":3,"count":1}]	313	delivery	5	17
11187	2019-10-20 02:01:12	2019-10-20	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":2}]	4181	delivery	5	28
11188	2019-10-20 02:04:28	2019-10-20	17	[{"id_menu":4,"count":1}]	1241	delivery	5	22
11189	2019-10-20 02:18:34	2019-10-20	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	4164	pick-up	0	21
11190	2019-10-20 02:19:21	2019-10-20	17	[{"id_menu":4,"count":1}]	855	delivery	5	22
11191	2019-10-20 02:20:39	2019-10-20	9	[{"id_menu":7,"count":1}]	996	pick-up	0	9
11192	2019-10-20 02:30:50	2019-10-20	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	528	delivery	5	27
11193	2019-10-20 02:34:27	2019-10-20	12	[{"id_menu":1,"count":1}]	4151	delivery	5	17
11194	2019-10-20 02:53:50	2019-10-20	9	[{"id_menu":7,"count":1}]	3821	delivery	5	14
11195	2019-10-20 02:55:32	2019-10-20	8	[{"id_menu":5,"count":1}]	4165	delivery	5	13
11196	2019-10-20 02:56:29	2019-10-20	9	[{"id_menu":7,"count":1}]	2524	delivery	5	14
11197	2019-10-20 02:59:03	2019-10-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4176	delivery	5	23
11198	2019-10-20 03:07:14	2019-10-20	12	[{"id_menu":1,"count":2}]	4183	delivery	5	17
11199	2019-10-20 03:17:14	2019-10-20	12	[{"id_menu":1,"count":1}]	135	pick-up	0	12
11200	2019-10-20 03:25:34	2019-10-20	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4152	delivery	5	37
11201	2019-10-20 03:27:49	2019-10-20	9	[{"id_menu":7,"count":1}]	1468	pick-up	0	9
11202	2019-10-20 04:09:01	2019-10-20	12	[{"id_menu":3,"count":1}]	4111	delivery	5	17
11203	2019-10-20 04:18:42	2019-10-20	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2434	pick-up	0	21
11204	2019-10-20 04:27:45	2019-10-20	12	[{"id_menu":3,"count":2}]	4175	pick-up	0	12
11205	2019-10-20 04:35:56	2019-10-20	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	25	pick-up	0	33
11206	2019-10-20 04:40:39	2019-10-20	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	4177	pick-up	0	24
11207	2019-10-20 05:12:14	2019-10-20	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4149	delivery	5	34
11208	2019-10-20 05:13:00	2019-10-20	12	[{"id_menu":3,"count":1}]	486	pick-up	0	12
11209	2019-10-20 05:19:30	2019-10-20	9	[{"id_menu":7,"count":1}]	1684	pick-up	0	9
11210	2019-10-20 05:20:52	2019-10-20	9	[{"id_menu":7,"count":1}]	2311	delivery	5	14
11211	2019-10-20 05:23:25	2019-10-20	17	[{"id_menu":4,"count":1}]	340	delivery	5	22
11212	2019-10-20 05:24:39	2019-10-20	17	[{"id_menu":4,"count":1}]	1618	pick-up	0	17
11213	2019-10-20 05:30:24	2019-10-20	12	[{"id_menu":3,"count":1}]	4168	pick-up	0	12
11214	2019-10-20 05:33:06	2019-10-20	9	[{"id_menu":7,"count":1}]	4132	pick-up	0	9
11215	2019-10-20 05:36:29	2019-10-20	17	[{"id_menu":4,"count":1}]	2038	pick-up	0	17
11216	2019-10-20 05:55:43	2019-10-20	14	[{"id_menu":2,"count":2}]	3488	delivery	5	19
11217	2019-10-20 06:11:44	2019-10-20	8	[{"id_menu":5,"count":1}]	3567	delivery	5	13
11218	2019-10-20 06:11:48	2019-10-20	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4159	delivery	5	22
11219	2019-10-20 06:28:28	2019-10-20	9	[{"id_menu":6,"count":1}]	919	pick-up	0	9
11220	2019-10-20 06:54:42	2019-10-20	17	[{"id_menu":4,"count":1}]	1053	pick-up	0	17
11221	2019-10-20 07:00:22	2019-10-20	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	3976	delivery	5	31
11222	2019-10-20 07:01:27	2019-10-20	9	[{"id_menu":7,"count":1}]	3812	delivery	5	14
11223	2019-10-20 07:13:34	2019-10-20	9	[{"id_menu":7,"count":1}]	1109	pick-up	0	9
11224	2019-10-20 07:18:50	2019-10-20	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	3574	delivery	5	25
11225	2019-10-20 07:30:25	2019-10-20	14	[{"id_menu":2,"count":1}]	806	pick-up	0	14
11226	2019-10-20 07:47:26	2019-10-20	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	4185	delivery	5	26
11227	2019-10-20 07:56:57	2019-10-20	9	[{"id_menu":6,"count":1}]	4170	pick-up	0	9
11228	2019-10-20 08:21:42	2019-10-20	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1518	delivery	5	43
11229	2019-10-20 08:22:16	2019-10-20	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	4169	delivery	5	29
11230	2019-10-20 08:26:01	2019-10-20	14	[{"id_menu":2,"count":1}]	2299	pick-up	0	14
11231	2019-10-20 08:27:36	2019-10-20	14	[{"id_menu":2,"count":1}]	1902	pick-up	0	14
11232	2019-10-20 08:30:42	2019-10-20	14	[{"id_menu":2,"count":1}]	1673	delivery	5	19
11233	2019-10-20 08:32:19	2019-10-20	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4153	delivery	5	45
11234	2019-10-20 08:47:17	2019-10-20	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1859	pick-up	0	26
11235	2019-10-20 08:57:04	2019-10-20	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4179	pick-up	0	26
11236	2019-10-20 09:39:23	2019-10-20	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2821	pick-up	0	21
11237	2019-10-20 09:42:53	2019-10-20	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	4178	delivery	5	25
11238	2019-10-20 09:48:05	2019-10-20	9	[{"id_menu":6,"count":1}]	1860	pick-up	0	9
11239	2019-10-20 09:48:25	2019-10-20	17	[{"id_menu":4,"count":1}]	1649	pick-up	0	17
11240	2019-10-20 09:49:05	2019-10-20	14	[{"id_menu":2,"count":1}]	4172	delivery	5	19
11241	2019-10-20 09:49:10	2019-10-20	12	[{"id_menu":3,"count":1}]	153	pick-up	0	12
11242	2019-10-20 10:10:33	2019-10-20	17	[{"id_menu":4,"count":1}]	4188	delivery	5	22
11243	2019-10-20 10:13:18	2019-10-20	14	[{"id_menu":2,"count":1}]	4174	delivery	5	19
11244	2019-10-20 10:13:30	2019-10-20	9	[{"id_menu":7,"count":1}]	4186	delivery	5	14
11245	2019-10-20 10:25:09	2019-10-20	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	54	delivery	5	25
11246	2019-10-20 10:38:35	2019-10-20	8	[{"id_menu":5,"count":1}]	3997	delivery	5	13
11247	2019-10-20 10:46:05	2019-10-20	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	907	delivery	5	26
11248	2019-10-20 10:47:08	2019-10-20	14	[{"id_menu":2,"count":1}]	2969	pick-up	0	14
11249	2019-10-20 10:51:33	2019-10-20	9	[{"id_menu":7,"count":1}]	2377	pick-up	0	9
11250	2019-10-20 11:05:25	2019-10-20	14	[{"id_menu":2,"count":1}]	2819	delivery	5	19
11251	2019-10-20 11:23:36	2019-10-20	14	[{"id_menu":2,"count":1}]	148	pick-up	0	14
11252	2019-10-20 12:05:24	2019-10-20	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4158	delivery	5	36
11253	2019-10-20 12:06:10	2019-10-20	8	[{"id_menu":5,"count":1}]	287	pick-up	0	8
11254	2019-10-20 12:19:59	2019-10-20	14	[{"id_menu":2,"count":1}]	4187	delivery	5	19
11255	2019-10-20 12:45:44	2019-10-20	12	[{"id_menu":1,"count":1}]	3801	pick-up	0	12
11256	2019-10-20 12:52:06	2019-10-20	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":3}]	3883	delivery	5	26
11257	2019-10-20 13:04:17	2019-10-20	17	[{"id_menu":4,"count":1}]	2474	pick-up	0	17
11258	2019-10-20 13:07:18	2019-10-20	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	4003	delivery	5	22
11259	2019-10-20 13:08:02	2019-10-20	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	863	delivery	5	30
11260	2019-10-20 13:16:23	2019-10-20	17	[{"id_menu":4,"count":1}]	1106	pick-up	0	17
11261	2019-10-20 13:21:21	2019-10-20	9	[{"id_menu":6,"count":1}]	1523	pick-up	0	9
11262	2019-10-20 13:22:00	2019-10-20	17	[{"id_menu":4,"count":1}]	2472	pick-up	0	17
11263	2019-10-20 13:23:25	2019-10-20	12	[{"id_menu":1,"count":1}]	573	delivery	5	17
11264	2019-10-20 13:33:30	2019-10-20	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3853	delivery	5	30
11265	2019-10-20 13:34:52	2019-10-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1971	delivery	5	28
11266	2019-10-20 13:50:27	2019-10-20	14	[{"id_menu":2,"count":1}]	1548	pick-up	0	14
11267	2019-10-20 14:03:21	2019-10-20	9	[{"id_menu":7,"count":1}]	4171	delivery	5	14
11268	2019-10-20 14:21:28	2019-10-20	9	[{"id_menu":7,"count":1}]	3927	pick-up	0	9
11269	2019-10-20 14:25:18	2019-10-20	14	[{"id_menu":2,"count":1}]	1119	delivery	5	19
11270	2019-10-20 14:39:08	2019-10-20	8	[{"id_menu":5,"count":1}]	1021	pick-up	0	8
11271	2019-10-20 14:40:49	2019-10-20	17	[{"id_menu":4,"count":1}]	3629	delivery	5	22
11272	2019-10-20 14:45:09	2019-10-20	12	[{"id_menu":3,"count":1}]	338	pick-up	0	12
11273	2019-10-20 14:49:20	2019-10-20	9	[{"id_menu":6,"count":1}]	2052	delivery	5	14
11274	2019-10-20 14:57:29	2019-10-20	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	4166	pick-up	0	21
11275	2019-10-20 15:25:29	2019-10-20	49	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1729	delivery	5	54
11276	2019-10-20 15:29:51	2019-10-20	17	[{"id_menu":4,"count":1}]	3372	delivery	5	22
11277	2019-10-20 15:37:27	2019-10-20	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1727	delivery	5	26
11278	2019-10-20 15:54:52	2019-10-20	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	729	delivery	5	22
11279	2019-10-20 16:07:05	2019-10-20	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	1260	delivery	5	36
11280	2019-10-20 16:16:26	2019-10-20	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2351	pick-up	0	26
11281	2019-10-20 16:29:46	2019-10-20	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	2540	delivery	5	22
11282	2019-10-20 16:41:40	2019-10-20	17	[{"id_menu":4,"count":1}]	1556	pick-up	0	17
11283	2019-10-20 17:00:42	2019-10-20	8	[{"id_menu":5,"count":1}]	4162	delivery	5	13
11284	2019-10-20 17:10:16	2019-10-20	14	[{"id_menu":2,"count":1}]	4126	pick-up	0	14
11285	2019-10-20 17:23:03	2019-10-20	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	2588	pick-up	0	22
11286	2019-10-20 17:36:37	2019-10-20	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2590	delivery	5	31
11287	2019-10-20 17:44:24	2019-10-20	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	3048	pick-up	0	29
11288	2019-10-20 17:56:35	2019-10-20	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1476	pick-up	0	35
11289	2019-10-20 18:04:30	2019-10-20	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1917	delivery	5	34
11290	2019-10-20 18:07:10	2019-10-20	17	[{"id_menu":4,"count":1}]	3679	delivery	5	22
11291	2019-10-20 18:12:24	2019-10-20	9	[{"id_menu":6,"count":1}]	1195	delivery	5	14
11292	2019-10-20 18:20:31	2019-10-20	12	[{"id_menu":3,"count":1}]	4155	delivery	5	17
11293	2019-10-20 18:21:13	2019-10-20	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1269	pick-up	0	21
11294	2019-10-20 18:25:03	2019-10-20	9	[{"id_menu":7,"count":1}]	4160	delivery	5	14
11295	2019-10-20 18:33:16	2019-10-20	9	[{"id_menu":6,"count":1}]	4157	delivery	5	14
11296	2019-10-20 18:38:55	2019-10-20	12	[{"id_menu":1,"count":1}]	2583	delivery	5	17
11297	2019-10-20 18:41:13	2019-10-20	9	[{"id_menu":7,"count":1}]	1832	pick-up	0	9
11298	2019-10-20 18:47:05	2019-10-20	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1294	pick-up	0	48
11299	2019-10-20 18:53:12	2019-10-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2025	pick-up	0	23
11300	2019-10-20 19:07:08	2019-10-20	14	[{"id_menu":2,"count":1}]	3172	delivery	5	19
11301	2019-10-20 19:18:15	2019-10-20	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	709	delivery	5	31
11302	2019-10-20 19:22:50	2019-10-20	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4189	delivery	5	31
11303	2019-10-20 19:27:56	2019-10-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2653	pick-up	0	18
11304	2019-10-20 19:30:47	2019-10-20	17	[{"id_menu":4,"count":1}]	226	pick-up	0	17
11305	2019-10-20 19:48:41	2019-10-20	12	[{"id_menu":3,"count":1}]	215	delivery	5	17
11306	2019-10-20 19:56:25	2019-10-20	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1956	pick-up	0	26
11307	2019-10-20 19:56:32	2019-10-20	14	[{"id_menu":2,"count":1}]	76	pick-up	0	14
11308	2019-10-20 19:57:42	2019-10-20	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	4167	delivery	5	22
11309	2019-10-20 20:01:51	2019-10-20	14	[{"id_menu":2,"count":1}]	149	pick-up	0	14
11310	2019-10-20 20:14:30	2019-10-20	12	[{"id_menu":3,"count":1}]	2507	delivery	5	17
11311	2019-10-20 20:24:12	2019-10-20	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4173	delivery	5	34
11312	2019-10-20 20:53:36	2019-10-20	12	[{"id_menu":3,"count":1}]	1428	pick-up	0	12
11313	2019-10-20 20:56:55	2019-10-20	17	[{"id_menu":4,"count":1}]	111	pick-up	0	17
11314	2019-10-20 20:57:37	2019-10-20	12	[{"id_menu":3,"count":1}]	1489	delivery	5	17
11315	2019-10-20 21:19:47	2019-10-20	17	[{"id_menu":4,"count":1}]	2386	delivery	5	22
11316	2019-10-20 21:35:26	2019-10-20	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2425	delivery	5	27
11317	2019-10-20 21:47:51	2019-10-20	9	[{"id_menu":6,"count":1}]	4163	delivery	5	14
11318	2019-10-20 22:31:16	2019-10-20	12	[{"id_menu":1,"count":1}]	2729	delivery	5	17
11319	2019-10-20 22:38:39	2019-10-20	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4182	delivery	5	26
11320	2019-10-20 22:59:32	2019-10-20	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	179	pick-up	0	26
11321	2019-10-20 22:59:39	2019-10-20	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1306	pick-up	0	26
11322	2019-10-20 23:08:32	2019-10-20	12	[{"id_menu":3,"count":1}]	3640	pick-up	0	12
11323	2019-10-20 23:26:50	2019-10-20	8	[{"id_menu":5,"count":1}]	3539	delivery	5	13
11324	2019-10-20 23:34:03	2019-10-20	12	[{"id_menu":1,"count":1}]	521	pick-up	0	12
11325	2019-10-20 23:42:18	2019-10-20	9	[{"id_menu":7,"count":1}]	37	pick-up	0	9
11326	2019-10-20 23:47:47	2019-10-20	14	[{"id_menu":2,"count":1}]	1741	delivery	5	19
11327	2019-10-20 23:48:04	2019-10-20	9	[{"id_menu":7,"count":1}]	4180	delivery	5	14
11328	2019-10-20 23:58:25	2019-10-20	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4150	delivery	5	45
11329	2019-10-21 00:46:23	2019-10-21	12	[{"id_menu":3,"count":1}]	4202	pick-up	0	12
11330	2019-10-21 01:01:31	2019-10-21	12	[{"id_menu":1,"count":1}]	295	delivery	5	17
11331	2019-10-21 01:51:03	2019-10-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	382	pick-up	0	23
11332	2019-10-21 01:57:20	2019-10-21	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	4207	pick-up	0	24
11333	2019-10-21 02:34:00	2019-10-21	14	[{"id_menu":2,"count":1}]	4215	delivery	5	19
11334	2019-10-21 02:55:22	2019-10-21	12	[{"id_menu":3,"count":1}]	612	delivery	5	17
11335	2019-10-21 03:01:19	2019-10-21	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	642	delivery	5	39
11336	2019-10-21 03:10:39	2019-10-21	9	[{"id_menu":6,"count":1}]	3324	delivery	5	14
11337	2019-10-21 03:15:42	2019-10-21	12	[{"id_menu":1,"count":1}]	4190	delivery	5	17
11338	2019-10-21 03:21:02	2019-10-21	8	[{"id_menu":5,"count":2}]	3988	delivery	5	13
11339	2019-10-21 03:36:46	2019-10-21	14	[{"id_menu":2,"count":1}]	2145	delivery	5	19
11340	2019-10-21 03:54:49	2019-10-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4195	pick-up	0	23
11341	2019-10-21 04:13:02	2019-10-21	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4197	pick-up	0	31
11342	2019-10-21 04:36:49	2019-10-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2404	pick-up	0	18
11409	2019-10-22 06:03:52	2019-10-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3320	delivery	5	28
11343	2019-10-21 04:58:21	2019-10-21	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4210	delivery	5	54
11344	2019-10-21 05:02:22	2019-10-21	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	4208	pick-up	0	29
11345	2019-10-21 06:07:36	2019-10-21	14	[{"id_menu":2,"count":1}]	2764	pick-up	0	14
11346	2019-10-21 06:32:19	2019-10-21	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	3949	pick-up	0	20
11347	2019-10-21 07:43:48	2019-10-21	8	[{"id_menu":5,"count":1}]	788	pick-up	0	8
11348	2019-10-21 07:58:08	2019-10-21	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4196	delivery	5	37
11349	2019-10-21 08:19:57	2019-10-21	17	[{"id_menu":4,"count":1}]	1736	pick-up	0	17
11350	2019-10-21 08:48:33	2019-10-21	9	[{"id_menu":7,"count":1}]	1140	pick-up	0	9
11351	2019-10-21 10:32:04	2019-10-21	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4214	delivery	5	48
11352	2019-10-21 10:34:33	2019-10-21	9	[{"id_menu":7,"count":1}]	2699	pick-up	0	9
11353	2019-10-21 10:59:41	2019-10-21	9	[{"id_menu":6,"count":1}]	134	pick-up	0	9
11354	2019-10-21 11:03:09	2019-10-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4193	delivery	5	22
11355	2019-10-21 11:07:10	2019-10-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4219	delivery	5	28
11356	2019-10-21 11:13:47	2019-10-21	17	[{"id_menu":4,"count":1}]	3785	pick-up	0	17
11357	2019-10-21 12:33:11	2019-10-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3545	delivery	5	22
11358	2019-10-21 12:45:40	2019-10-21	17	[{"id_menu":4,"count":1}]	2827	pick-up	0	17
11359	2019-10-21 12:59:21	2019-10-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	80	pick-up	0	23
11360	2019-10-21 13:17:22	2019-10-21	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	4211	delivery	5	26
11361	2019-10-21 13:43:50	2019-10-21	12	[{"id_menu":1,"count":1}]	4223	pick-up	0	12
11362	2019-10-21 14:01:55	2019-10-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":3}]	4205	delivery	5	23
11363	2019-10-21 14:12:53	2019-10-21	17	[{"id_menu":4,"count":1}]	3562	delivery	5	22
11364	2019-10-21 14:34:09	2019-10-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1085	pick-up	0	23
11365	2019-10-21 14:36:30	2019-10-21	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	4200	delivery	5	34
11366	2019-10-21 14:45:07	2019-10-21	12	[{"id_menu":1,"count":1}]	1953	pick-up	0	12
11367	2019-10-21 14:50:26	2019-10-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1390	pick-up	0	23
11368	2019-10-21 15:27:57	2019-10-21	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	675	delivery	5	29
11369	2019-10-21 16:01:09	2019-10-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	84	pick-up	0	23
11370	2019-10-21 16:24:51	2019-10-21	8	[{"id_menu":5,"count":1}]	4184	delivery	5	13
11371	2019-10-21 16:32:14	2019-10-21	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	1720	pick-up	0	34
11372	2019-10-21 17:12:15	2019-10-21	9	[{"id_menu":6,"count":1}]	213	pick-up	0	9
11373	2019-10-21 18:45:07	2019-10-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4199	delivery	5	28
11374	2019-10-21 18:49:22	2019-10-21	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3116	pick-up	0	22
11375	2019-10-21 19:08:12	2019-10-21	17	[{"id_menu":4,"count":1}]	1435	delivery	5	22
11376	2019-10-21 19:26:45	2019-10-21	8	[{"id_menu":5,"count":1}]	2200	pick-up	0	8
11377	2019-10-21 19:49:12	2019-10-21	14	[{"id_menu":2,"count":1}]	4203	pick-up	0	14
11378	2019-10-21 20:22:07	2019-10-21	17	[{"id_menu":4,"count":1}]	2276	pick-up	0	17
11379	2019-10-21 20:30:27	2019-10-21	9	[{"id_menu":6,"count":1}]	1155	pick-up	0	9
11380	2019-10-21 20:33:23	2019-10-21	14	[{"id_menu":2,"count":1}]	4220	delivery	5	19
11381	2019-10-21 20:39:59	2019-10-21	17	[{"id_menu":4,"count":1}]	3029	pick-up	0	17
11382	2019-10-21 20:53:51	2019-10-21	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1314	pick-up	0	21
11383	2019-10-21 21:06:35	2019-10-21	9	[{"id_menu":6,"count":1}]	4212	delivery	5	14
11384	2019-10-21 21:22:51	2019-10-21	8	[{"id_menu":5,"count":1}]	4221	pick-up	0	8
11385	2019-10-21 21:36:28	2019-10-21	12	[{"id_menu":1,"count":1}]	3205	pick-up	0	12
11386	2019-10-21 21:38:43	2019-10-21	9	[{"id_menu":6,"count":1}]	3631	delivery	5	14
11387	2019-10-21 22:28:50	2019-10-21	17	[{"id_menu":4,"count":1}]	531	pick-up	0	17
11388	2019-10-21 22:44:51	2019-10-21	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2605	delivery	5	36
11389	2019-10-21 22:56:08	2019-10-21	14	[{"id_menu":2,"count":1}]	4216	pick-up	0	14
11390	2019-10-21 23:17:18	2019-10-21	12	[{"id_menu":1,"count":1}]	1963	pick-up	0	12
11391	2019-10-21 23:22:59	2019-10-21	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	931	pick-up	0	25
11392	2019-10-21 23:33:54	2019-10-21	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	547	pick-up	0	30
11393	2019-10-21 23:41:07	2019-10-21	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4201	delivery	5	26
11394	2019-10-22 00:38:49	2019-10-22	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	4243	delivery	5	22
11395	2019-10-22 00:45:47	2019-10-22	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2633	pick-up	0	38
11396	2019-10-22 01:19:06	2019-10-22	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	3739	delivery	5	23
11397	2019-10-22 01:26:13	2019-10-22	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3082	pick-up	0	26
11398	2019-10-22 01:39:26	2019-10-22	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":2}]	4043	delivery	5	22
11399	2019-10-22 02:56:20	2019-10-22	9	[{"id_menu":7,"count":1}]	3052	pick-up	0	9
11400	2019-10-22 03:08:52	2019-10-22	9	[{"id_menu":6,"count":1}]	671	delivery	5	14
11401	2019-10-22 03:15:29	2019-10-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	946	pick-up	0	23
11402	2019-10-22 03:24:48	2019-10-22	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4230	delivery	5	31
11403	2019-10-22 03:33:21	2019-10-22	12	[{"id_menu":1,"count":1}]	1463	pick-up	0	12
11404	2019-10-22 03:54:43	2019-10-22	9	[{"id_menu":6,"count":1}]	4245	pick-up	0	9
11405	2019-10-22 03:56:12	2019-10-22	12	[{"id_menu":3,"count":1}]	2971	pick-up	0	12
11406	2019-10-22 05:11:07	2019-10-22	9	[{"id_menu":7,"count":1}]	1505	pick-up	0	9
11407	2019-10-22 05:21:44	2019-10-22	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	2730	delivery	5	39
11408	2019-10-22 05:30:01	2019-10-22	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	3827	pick-up	0	20
11410	2019-10-22 06:21:40	2019-10-22	9	[{"id_menu":7,"count":1}]	2130	pick-up	0	9
11411	2019-10-22 06:58:41	2019-10-22	14	[{"id_menu":2,"count":1}]	4251	delivery	5	19
11412	2019-10-22 07:06:42	2019-10-22	14	[{"id_menu":2,"count":2}]	257	pick-up	0	14
11413	2019-10-22 07:40:34	2019-10-22	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4224	delivery	5	30
11414	2019-10-22 08:24:42	2019-10-22	12	[{"id_menu":1,"count":1}]	4257	pick-up	0	12
11415	2019-10-22 08:31:49	2019-10-22	8	[{"id_menu":5,"count":1}]	43	pick-up	0	8
11416	2019-10-22 08:40:24	2019-10-22	14	[{"id_menu":2,"count":1}]	1597	pick-up	0	14
11417	2019-10-22 08:48:10	2019-10-22	9	[{"id_menu":7,"count":1}]	78	pick-up	0	9
11418	2019-10-22 08:48:32	2019-10-22	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	563	pick-up	0	24
11419	2019-10-22 08:58:57	2019-10-22	9	[{"id_menu":6,"count":1}]	1215	delivery	5	14
11420	2019-10-22 09:37:35	2019-10-22	9	[{"id_menu":7,"count":1}]	453	pick-up	0	9
11421	2019-10-22 10:43:19	2019-10-22	12	[{"id_menu":3,"count":1}]	4246	delivery	5	17
11422	2019-10-22 10:44:20	2019-10-22	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4240	delivery	5	37
11423	2019-10-22 11:16:45	2019-10-22	17	[{"id_menu":4,"count":1}]	3977	delivery	5	22
11424	2019-10-22 11:26:53	2019-10-22	9	[{"id_menu":6,"count":1}]	4261	delivery	5	14
11425	2019-10-22 11:32:25	2019-10-22	12	[{"id_menu":1,"count":1}]	2579	pick-up	0	12
11426	2019-10-22 11:45:47	2019-10-22	12	[{"id_menu":1,"count":1}]	2827	delivery	5	17
11427	2019-10-22 12:00:38	2019-10-22	9	[{"id_menu":6,"count":1}]	1130	pick-up	0	9
11428	2019-10-22 12:13:20	2019-10-22	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1627	delivery	5	34
11429	2019-10-22 12:16:40	2019-10-22	8	[{"id_menu":5,"count":1}]	676	delivery	5	13
11430	2019-10-22 12:36:45	2019-10-22	14	[{"id_menu":2,"count":1}]	4234	delivery	5	19
11431	2019-10-22 12:37:42	2019-10-22	8	[{"id_menu":5,"count":1}]	2434	pick-up	0	8
11432	2019-10-22 12:59:36	2019-10-22	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1223	pick-up	0	43
11433	2019-10-22 13:29:03	2019-10-22	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3619	pick-up	0	21
11434	2019-10-22 13:35:31	2019-10-22	9	[{"id_menu":6,"count":1}]	802	pick-up	0	9
11435	2019-10-22 13:51:39	2019-10-22	12	[{"id_menu":1,"count":1}]	1685	pick-up	0	12
11436	2019-10-22 13:55:54	2019-10-22	8	[{"id_menu":5,"count":1}]	684	pick-up	0	8
11437	2019-10-22 13:57:25	2019-10-22	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2887	delivery	5	43
11438	2019-10-22 15:05:03	2019-10-22	8	[{"id_menu":5,"count":1}]	4244	pick-up	0	8
11439	2019-10-22 15:10:33	2019-10-22	9	[{"id_menu":7,"count":1}]	4233	delivery	5	14
11440	2019-10-22 15:32:32	2019-10-22	9	[{"id_menu":7,"count":1}]	4227	delivery	5	14
11441	2019-10-22 15:47:12	2019-10-22	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4250	pick-up	0	29
11442	2019-10-22 15:50:20	2019-10-22	17	[{"id_menu":4,"count":1}]	4226	pick-up	0	17
11443	2019-10-22 15:54:14	2019-10-22	17	[{"id_menu":4,"count":1}]	1457	delivery	5	22
11444	2019-10-22 16:07:36	2019-10-22	8	[{"id_menu":5,"count":1}]	1435	delivery	5	13
11445	2019-10-22 16:31:22	2019-10-22	9	[{"id_menu":6,"count":1}]	2134	pick-up	0	9
11446	2019-10-22 16:37:35	2019-10-22	9	[{"id_menu":6,"count":1}]	1557	delivery	5	14
11447	2019-10-22 16:43:16	2019-10-22	17	[{"id_menu":4,"count":1}]	3019	delivery	5	22
11448	2019-10-22 17:00:49	2019-10-22	9	[{"id_menu":7,"count":1}]	4236	delivery	5	14
11449	2019-10-22 17:17:34	2019-10-22	9	[{"id_menu":6,"count":1}]	1157	pick-up	0	9
11450	2019-10-22 17:21:59	2019-10-22	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	426	delivery	5	26
11451	2019-10-22 17:30:47	2019-10-22	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4232	delivery	5	48
11452	2019-10-22 17:35:02	2019-10-22	14	[{"id_menu":2,"count":2}]	1559	pick-up	0	14
11453	2019-10-22 18:12:34	2019-10-22	9	[{"id_menu":6,"count":1}]	1649	pick-up	0	9
11454	2019-10-22 18:23:59	2019-10-22	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	169	pick-up	0	21
11455	2019-10-22 18:31:52	2019-10-22	12	[{"id_menu":3,"count":1}]	2608	pick-up	0	12
11456	2019-10-22 18:45:17	2019-10-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4238	pick-up	0	31
11457	2019-10-22 19:20:27	2019-10-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4259	delivery	5	22
11458	2019-10-22 19:28:41	2019-10-22	12	[{"id_menu":1,"count":1}]	4225	delivery	5	17
11459	2019-10-22 19:38:44	2019-10-22	9	[{"id_menu":6,"count":1}]	2189	delivery	5	14
11460	2019-10-22 19:52:49	2019-10-22	14	[{"id_menu":2,"count":1}]	2965	delivery	5	19
11461	2019-10-22 20:29:01	2019-10-22	17	[{"id_menu":4,"count":1}]	3834	pick-up	0	17
11462	2019-10-22 21:29:11	2019-10-22	12	[{"id_menu":3,"count":1}]	1482	pick-up	0	12
11463	2019-10-22 21:48:33	2019-10-22	8	[{"id_menu":5,"count":1}]	1106	pick-up	0	8
11464	2019-10-22 21:51:13	2019-10-22	9	[{"id_menu":7,"count":1}]	4256	delivery	5	14
11465	2019-10-22 22:03:06	2019-10-22	12	[{"id_menu":1,"count":1}]	3300	delivery	5	17
11466	2019-10-22 22:25:19	2019-10-22	9	[{"id_menu":6,"count":1}]	3858	pick-up	0	9
11467	2019-10-22 22:35:21	2019-10-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	489	pick-up	0	18
11468	2019-10-22 22:50:52	2019-10-22	9	[{"id_menu":6,"count":1}]	356	delivery	5	14
11469	2019-10-22 23:04:23	2019-10-22	9	[{"id_menu":6,"count":1}]	3335	pick-up	0	9
11470	2019-10-22 23:18:38	2019-10-22	9	[{"id_menu":7,"count":1}]	3688	delivery	5	14
11471	2019-10-22 23:29:20	2019-10-22	12	[{"id_menu":3,"count":1}]	270	delivery	5	17
11472	2019-10-23 00:02:45	2019-10-23	17	[{"id_menu":4,"count":1}]	4295	pick-up	0	17
11473	2019-10-23 00:30:41	2019-10-23	12	[{"id_menu":3,"count":1}]	3361	delivery	5	17
11474	2019-10-23 00:35:22	2019-10-23	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4299	delivery	5	42
11475	2019-10-23 00:44:38	2019-10-23	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2540	delivery	5	26
11476	2019-10-23 00:49:01	2019-10-23	9	[{"id_menu":6,"count":1}]	1380	delivery	5	14
11477	2019-10-23 01:11:40	2019-10-23	9	[{"id_menu":6,"count":2}]	233	pick-up	0	9
11478	2019-10-23 01:12:16	2019-10-23	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	2327	pick-up	0	17
11479	2019-10-23 01:19:40	2019-10-23	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4290	delivery	5	27
11480	2019-10-23 01:19:52	2019-10-23	14	[{"id_menu":2,"count":1}]	4283	delivery	5	19
11481	2019-10-23 01:21:57	2019-10-23	9	[{"id_menu":7,"count":1}]	3172	pick-up	0	9
11482	2019-10-23 02:16:36	2019-10-23	14	[{"id_menu":2,"count":1}]	265	pick-up	0	14
11483	2019-10-23 02:57:05	2019-10-23	17	[{"id_menu":4,"count":1}]	4267	delivery	5	22
11484	2019-10-23 03:02:01	2019-10-23	17	[{"id_menu":4,"count":1}]	1979	pick-up	0	17
11485	2019-10-23 03:05:47	2019-10-23	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3076	delivery	5	42
11486	2019-10-23 03:13:57	2019-10-23	17	[{"id_menu":4,"count":2}]	229	delivery	5	22
11487	2019-10-23 03:15:32	2019-10-23	14	[{"id_menu":2,"count":2}]	2291	pick-up	0	14
11488	2019-10-23 03:21:46	2019-10-23	9	[{"id_menu":6,"count":1}]	4269	delivery	5	14
11489	2019-10-23 03:36:47	2019-10-23	9	[{"id_menu":6,"count":3}]	4288	delivery	5	14
11490	2019-10-23 03:42:00	2019-10-23	9	[{"id_menu":7,"count":1}]	3653	delivery	5	14
11491	2019-10-23 03:43:38	2019-10-23	12	[{"id_menu":3,"count":1}]	4273	pick-up	0	12
11492	2019-10-23 04:01:58	2019-10-23	14	[{"id_menu":2,"count":1}]	1559	pick-up	0	14
11493	2019-10-23 04:10:59	2019-10-23	17	[{"id_menu":4,"count":1}]	4286	delivery	5	22
11494	2019-10-23 04:13:58	2019-10-23	9	[{"id_menu":6,"count":1}]	2282	pick-up	0	9
11495	2019-10-23 04:23:09	2019-10-23	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	4118	delivery	5	31
11496	2019-10-23 04:32:08	2019-10-23	14	[{"id_menu":2,"count":1}]	4280	delivery	5	19
11497	2019-10-23 04:35:51	2019-10-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4277	delivery	5	23
11498	2019-10-23 04:58:06	2019-10-23	12	[{"id_menu":3,"count":1}]	1642	pick-up	0	12
11499	2019-10-23 05:04:39	2019-10-23	32	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	3757	delivery	5	37
11500	2019-10-23 05:04:47	2019-10-23	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3343	delivery	5	40
11501	2019-10-23 05:19:43	2019-10-23	14	[{"id_menu":2,"count":1}]	159	pick-up	0	14
11502	2019-10-23 06:04:38	2019-10-23	8	[{"id_menu":5,"count":1}]	4270	pick-up	0	8
11503	2019-10-23 06:27:00	2019-10-23	8	[{"id_menu":5,"count":1}]	4300	delivery	5	13
11504	2019-10-23 06:27:27	2019-10-23	14	[{"id_menu":2,"count":1}]	4297	delivery	5	19
11505	2019-10-23 06:31:06	2019-10-23	14	[{"id_menu":2,"count":1}]	1896	pick-up	0	14
11506	2019-10-23 06:38:46	2019-10-23	9	[{"id_menu":6,"count":1}]	2838	pick-up	0	9
11507	2019-10-23 06:50:45	2019-10-23	9	[{"id_menu":7,"count":1}]	984	pick-up	0	9
11508	2019-10-23 07:04:47	2019-10-23	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4272	delivery	5	40
11509	2019-10-23 07:36:17	2019-10-23	9	[{"id_menu":6,"count":1}]	1992	pick-up	0	9
11510	2019-10-23 08:03:33	2019-10-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1869	delivery	5	23
11511	2019-10-23 08:18:07	2019-10-23	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1148	pick-up	0	24
11512	2019-10-23 08:26:12	2019-10-23	12	[{"id_menu":1,"count":1}]	4275	pick-up	0	12
11513	2019-10-23 08:36:09	2019-10-23	14	[{"id_menu":2,"count":1}]	170	pick-up	0	14
11514	2019-10-23 09:19:22	2019-10-23	9	[{"id_menu":6,"count":1}]	2228	pick-up	0	9
11515	2019-10-23 09:19:36	2019-10-23	14	[{"id_menu":2,"count":1}]	1068	pick-up	0	14
11516	2019-10-23 10:00:38	2019-10-23	12	[{"id_menu":3,"count":1}]	1104	pick-up	0	12
11517	2019-10-23 10:02:08	2019-10-23	17	[{"id_menu":4,"count":1}]	3554	delivery	5	22
11518	2019-10-23 10:03:38	2019-10-23	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4265	delivery	5	39
11519	2019-10-23 10:13:00	2019-10-23	14	[{"id_menu":2,"count":1}]	1722	pick-up	0	14
11520	2019-10-23 10:50:53	2019-10-23	12	[{"id_menu":1,"count":1}]	1581	pick-up	0	12
11521	2019-10-23 11:11:41	2019-10-23	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	511	pick-up	0	38
11522	2019-10-23 11:20:05	2019-10-23	9	[{"id_menu":6,"count":1}]	3920	delivery	5	14
11523	2019-10-23 11:23:23	2019-10-23	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2885	delivery	5	44
11524	2019-10-23 11:24:23	2019-10-23	9	[{"id_menu":6,"count":1}]	695	pick-up	0	9
11525	2019-10-23 11:29:25	2019-10-23	12	[{"id_menu":1,"count":1}]	123	pick-up	0	12
11526	2019-10-23 11:32:19	2019-10-23	8	[{"id_menu":5,"count":1}]	1342	pick-up	0	8
11527	2019-10-23 11:39:28	2019-10-23	14	[{"id_menu":2,"count":1}]	1278	pick-up	0	14
11528	2019-10-23 11:44:54	2019-10-23	14	[{"id_menu":2,"count":1}]	274	pick-up	0	14
11529	2019-10-23 11:45:05	2019-10-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	932	pick-up	0	23
11530	2019-10-23 11:46:48	2019-10-23	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4294	delivery	5	31
11531	2019-10-23 11:59:46	2019-10-23	17	[{"id_menu":4,"count":1}]	2639	delivery	5	22
11532	2019-10-23 12:21:10	2019-10-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	1677	delivery	5	28
11533	2019-10-23 13:03:22	2019-10-23	8	[{"id_menu":5,"count":1}]	1461	pick-up	0	8
11534	2019-10-23 13:10:09	2019-10-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1365	delivery	5	31
11535	2019-10-23 13:46:46	2019-10-23	9	[{"id_menu":7,"count":1}]	1701	pick-up	0	9
11536	2019-10-23 14:06:00	2019-10-23	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4293	delivery	5	40
11537	2019-10-23 14:21:02	2019-10-23	9	[{"id_menu":7,"count":1}]	4282	delivery	5	14
11538	2019-10-23 14:22:09	2019-10-23	17	[{"id_menu":4,"count":1}]	2052	pick-up	0	17
11539	2019-10-23 14:32:51	2019-10-23	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	3752	delivery	5	45
11540	2019-10-23 14:35:28	2019-10-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	2264	pick-up	0	17
11541	2019-10-23 14:37:29	2019-10-23	12	[{"id_menu":1,"count":1}]	3705	delivery	5	17
11542	2019-10-23 14:39:55	2019-10-23	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	528	delivery	5	49
11543	2019-10-23 14:53:02	2019-10-23	12	[{"id_menu":1,"count":1}]	1085	pick-up	0	12
11544	2019-10-23 15:02:48	2019-10-23	9	[{"id_menu":7,"count":1}]	962	delivery	5	14
11545	2019-10-23 15:03:19	2019-10-23	9	[{"id_menu":7,"count":1}]	4296	pick-up	0	9
11546	2019-10-23 15:41:48	2019-10-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3722	delivery	5	31
11547	2019-10-23 16:03:00	2019-10-23	12	[{"id_menu":1,"count":1}]	178	delivery	5	17
11548	2019-10-23 16:12:49	2019-10-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	490	delivery	5	22
11549	2019-10-23 16:14:29	2019-10-23	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4287	delivery	5	26
11550	2019-10-23 16:19:34	2019-10-23	9	[{"id_menu":6,"count":1}]	4278	delivery	5	14
11551	2019-10-23 16:33:58	2019-10-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	3491	pick-up	0	26
11552	2019-10-23 16:34:49	2019-10-23	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	4284	delivery	5	23
11553	2019-10-23 16:38:32	2019-10-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4289	delivery	5	36
11554	2019-10-23 16:52:22	2019-10-23	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	790	pick-up	0	30
11555	2019-10-23 17:28:13	2019-10-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1795	pick-up	0	21
11556	2019-10-23 17:39:37	2019-10-23	17	[{"id_menu":4,"count":1}]	1781	pick-up	0	17
11557	2019-10-23 17:42:19	2019-10-23	8	[{"id_menu":5,"count":1}]	688	delivery	5	13
11558	2019-10-23 17:43:58	2019-10-23	12	[{"id_menu":3,"count":1}]	4266	pick-up	0	12
11559	2019-10-23 18:13:50	2019-10-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3788	pick-up	0	31
11560	2019-10-23 18:14:52	2019-10-23	9	[{"id_menu":6,"count":1}]	3320	pick-up	0	9
11561	2019-10-23 18:32:23	2019-10-23	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	4281	delivery	5	23
11562	2019-10-23 18:38:28	2019-10-23	14	[{"id_menu":2,"count":1}]	3774	pick-up	0	14
11563	2019-10-23 19:12:15	2019-10-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	4248	pick-up	0	26
11564	2019-10-23 19:34:53	2019-10-23	9	[{"id_menu":6,"count":1}]	4264	delivery	5	14
11565	2019-10-23 19:44:47	2019-10-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3372	delivery	5	23
11566	2019-10-23 20:00:05	2019-10-23	17	[{"id_menu":4,"count":2}]	2056	delivery	5	22
11567	2019-10-23 20:15:57	2019-10-23	14	[{"id_menu":2,"count":2}]	2981	pick-up	0	14
11568	2019-10-23 20:23:45	2019-10-23	17	[{"id_menu":4,"count":2}]	1241	pick-up	0	17
11569	2019-10-23 20:46:04	2019-10-23	12	[{"id_menu":1,"count":1}]	4291	delivery	5	17
11570	2019-10-23 20:54:57	2019-10-23	17	[{"id_menu":4,"count":1}]	4268	pick-up	0	17
11571	2019-10-23 21:04:20	2019-10-23	8	[{"id_menu":5,"count":1}]	1325	delivery	5	13
11572	2019-10-23 21:09:30	2019-10-23	17	[{"id_menu":4,"count":1}]	2114	delivery	5	22
11573	2019-10-23 21:15:55	2019-10-23	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3160	pick-up	0	25
11574	2019-10-23 21:22:49	2019-10-23	14	[{"id_menu":2,"count":1}]	4274	pick-up	0	14
11575	2019-10-23 22:08:36	2019-10-23	12	[{"id_menu":3,"count":1}]	3180	delivery	5	17
11576	2019-10-23 22:10:06	2019-10-23	9	[{"id_menu":6,"count":1}]	599	delivery	5	14
11577	2019-10-23 22:25:06	2019-10-23	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3600	delivery	5	31
11578	2019-10-23 23:17:13	2019-10-23	9	[{"id_menu":7,"count":1}]	2868	delivery	5	14
11579	2019-10-23 23:17:17	2019-10-23	9	[{"id_menu":6,"count":1}]	1449	pick-up	0	9
11580	2019-10-23 23:27:25	2019-10-23	8	[{"id_menu":5,"count":1}]	4292	delivery	5	13
11581	2019-10-23 23:32:01	2019-10-23	8	[{"id_menu":5,"count":1}]	4298	delivery	5	13
11582	2019-10-23 23:57:07	2019-10-23	9	[{"id_menu":6,"count":1}]	4279	pick-up	0	9
11583	2019-10-24 00:03:28	2019-10-24	9	[{"id_menu":6,"count":1}]	3825	pick-up	0	9
11584	2019-10-24 00:07:04	2019-10-24	8	[{"id_menu":5,"count":1}]	4306	delivery	5	13
11585	2019-10-24 00:07:51	2019-10-24	9	[{"id_menu":6,"count":1}]	3499	delivery	5	14
11586	2019-10-24 00:12:10	2019-10-24	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	4310	delivery	5	26
11587	2019-10-24 00:58:42	2019-10-24	9	[{"id_menu":7,"count":1}]	4093	delivery	5	14
11588	2019-10-24 01:00:22	2019-10-24	14	[{"id_menu":2,"count":1}]	1837	delivery	5	19
11589	2019-10-24 02:02:19	2019-10-24	8	[{"id_menu":5,"count":1}]	4335	pick-up	0	8
11590	2019-10-24 02:11:51	2019-10-24	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	3115	delivery	5	39
11591	2019-10-24 02:23:36	2019-10-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2122	pick-up	0	23
11592	2019-10-24 02:55:33	2019-10-24	12	[{"id_menu":3,"count":1}]	4313	delivery	5	17
11593	2019-10-24 03:15:36	2019-10-24	17	[{"id_menu":4,"count":1}]	4324	delivery	5	22
11594	2019-10-24 03:34:45	2019-10-24	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	699	delivery	5	34
11595	2019-10-24 03:46:26	2019-10-24	9	[{"id_menu":6,"count":2}]	3562	delivery	5	14
11596	2019-10-24 04:15:43	2019-10-24	17	[{"id_menu":4,"count":1}]	1468	pick-up	0	17
11597	2019-10-24 04:23:55	2019-10-24	9	[{"id_menu":6,"count":1}]	1806	delivery	5	14
11598	2019-10-24 05:05:40	2019-10-24	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	362	delivery	5	25
11599	2019-10-24 05:13:54	2019-10-24	17	[{"id_menu":4,"count":1}]	2116	delivery	5	22
11600	2019-10-24 05:24:54	2019-10-24	9	[{"id_menu":6,"count":1}]	465	pick-up	0	9
11601	2019-10-24 05:37:10	2019-10-24	8	[{"id_menu":5,"count":1}]	2221	delivery	5	13
11602	2019-10-24 05:38:48	2019-10-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1344	pick-up	0	26
11603	2019-10-24 05:47:50	2019-10-24	9	[{"id_menu":7,"count":1}]	970	pick-up	0	9
11604	2019-10-24 05:49:12	2019-10-24	17	[{"id_menu":4,"count":1}]	1324	delivery	5	22
11605	2019-10-24 05:51:21	2019-10-24	12	[{"id_menu":3,"count":1}]	2506	delivery	5	17
11606	2019-10-24 05:53:53	2019-10-24	9	[{"id_menu":6,"count":1}]	173	pick-up	0	9
11607	2019-10-24 06:10:04	2019-10-24	8	[{"id_menu":5,"count":1}]	2387	pick-up	0	8
11608	2019-10-24 06:30:43	2019-10-24	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2451	delivery	5	26
11609	2019-10-24 06:45:26	2019-10-24	9	[{"id_menu":7,"count":1}]	1170	delivery	5	14
11610	2019-10-24 06:50:26	2019-10-24	12	[{"id_menu":3,"count":1}]	4309	pick-up	0	12
11611	2019-10-24 06:56:00	2019-10-24	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	349	pick-up	0	23
11612	2019-10-24 07:06:12	2019-10-24	12	[{"id_menu":1,"count":1}]	1676	pick-up	0	12
11613	2019-10-24 07:08:41	2019-10-24	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	4314	delivery	5	36
11614	2019-10-24 08:22:04	2019-10-24	9	[{"id_menu":7,"count":2}]	849	delivery	5	14
11615	2019-10-24 08:30:11	2019-10-24	9	[{"id_menu":6,"count":1}]	4317	delivery	5	14
11616	2019-10-24 08:32:17	2019-10-24	9	[{"id_menu":7,"count":1}]	28	pick-up	0	9
11617	2019-10-24 08:42:13	2019-10-24	8	[{"id_menu":5,"count":1}]	4325	delivery	5	13
11618	2019-10-24 08:44:34	2019-10-24	8	[{"id_menu":5,"count":1}]	3643	pick-up	0	8
11619	2019-10-24 08:54:14	2019-10-24	9	[{"id_menu":7,"count":1}]	4321	delivery	5	14
11620	2019-10-24 09:21:00	2019-10-24	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	847	delivery	5	36
11621	2019-10-24 09:24:45	2019-10-24	9	[{"id_menu":6,"count":1}]	1166	pick-up	0	9
11622	2019-10-24 09:27:48	2019-10-24	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	3119	delivery	5	34
11623	2019-10-24 09:32:42	2019-10-24	9	[{"id_menu":7,"count":3}]	3988	delivery	5	14
11624	2019-10-24 09:37:10	2019-10-24	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	489	pick-up	0	31
11625	2019-10-24 09:47:54	2019-10-24	14	[{"id_menu":2,"count":1}]	691	pick-up	0	14
11626	2019-10-24 09:51:43	2019-10-24	14	[{"id_menu":2,"count":1}]	4090	pick-up	0	14
11627	2019-10-24 10:36:39	2019-10-24	14	[{"id_menu":2,"count":1}]	2570	delivery	5	19
11628	2019-10-24 10:59:17	2019-10-24	8	[{"id_menu":5,"count":1}]	4308	delivery	5	13
11629	2019-10-24 11:03:15	2019-10-24	9	[{"id_menu":6,"count":1}]	4318	delivery	5	14
11630	2019-10-24 11:04:32	2019-10-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4170	pick-up	0	23
11631	2019-10-24 11:11:15	2019-10-24	14	[{"id_menu":2,"count":1}]	3512	pick-up	0	14
11632	2019-10-24 11:15:52	2019-10-24	9	[{"id_menu":7,"count":1}]	4316	pick-up	0	9
11633	2019-10-24 11:29:30	2019-10-24	14	[{"id_menu":2,"count":1}]	3952	delivery	5	19
11634	2019-10-24 11:45:57	2019-10-24	12	[{"id_menu":1,"count":1}]	2586	delivery	5	17
11635	2019-10-24 11:48:13	2019-10-24	8	[{"id_menu":5,"count":1}]	4320	delivery	5	13
11636	2019-10-24 12:31:47	2019-10-24	9	[{"id_menu":6,"count":1}]	629	pick-up	0	9
11637	2019-10-24 12:59:42	2019-10-24	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	359	pick-up	0	29
11638	2019-10-24 13:59:53	2019-10-24	8	[{"id_menu":5,"count":1}]	4311	delivery	5	13
11639	2019-10-24 14:01:56	2019-10-24	9	[{"id_menu":7,"count":1}]	1754	delivery	5	14
11640	2019-10-24 14:02:48	2019-10-24	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	4304	pick-up	0	26
11641	2019-10-24 14:12:52	2019-10-24	8	[{"id_menu":5,"count":1}]	4328	delivery	5	13
11642	2019-10-24 14:14:58	2019-10-24	39	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4329	pick-up	0	39
11643	2019-10-24 14:39:39	2019-10-24	9	[{"id_menu":7,"count":1}]	4322	pick-up	0	9
11644	2019-10-24 14:54:19	2019-10-24	9	[{"id_menu":6,"count":1}]	4236	delivery	5	14
11645	2019-10-24 14:55:53	2019-10-24	12	[{"id_menu":1,"count":1}]	986	pick-up	0	12
11646	2019-10-24 15:09:15	2019-10-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3794	delivery	5	23
11647	2019-10-24 15:21:19	2019-10-24	9	[{"id_menu":7,"count":1}]	4307	delivery	5	14
11648	2019-10-24 15:42:23	2019-10-24	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2845	delivery	5	38
11649	2019-10-24 16:30:52	2019-10-24	9	[{"id_menu":7,"count":1}]	164	delivery	5	14
11650	2019-10-24 16:49:40	2019-10-24	17	[{"id_menu":4,"count":1}]	4301	delivery	5	22
11651	2019-10-24 16:55:27	2019-10-24	9	[{"id_menu":6,"count":1}]	3411	delivery	5	14
11652	2019-10-24 16:56:43	2019-10-24	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3711	pick-up	0	22
11653	2019-10-24 17:04:09	2019-10-24	8	[{"id_menu":5,"count":1}]	2946	pick-up	0	8
11654	2019-10-24 17:06:43	2019-10-24	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	240	delivery	5	26
11655	2019-10-24 17:10:35	2019-10-24	12	[{"id_menu":3,"count":1}]	4305	delivery	5	17
11656	2019-10-24 17:15:26	2019-10-24	17	[{"id_menu":4,"count":1}]	2306	delivery	5	22
11657	2019-10-24 17:16:53	2019-10-24	14	[{"id_menu":2,"count":2}]	49	pick-up	0	14
11658	2019-10-24 17:20:37	2019-10-24	12	[{"id_menu":1,"count":1}]	3008	delivery	5	17
11659	2019-10-24 17:33:48	2019-10-24	8	[{"id_menu":5,"count":1}]	1118	pick-up	0	8
11660	2019-10-24 17:35:17	2019-10-24	9	[{"id_menu":6,"count":1}]	4267	pick-up	0	9
11661	2019-10-24 17:44:30	2019-10-24	17	[{"id_menu":4,"count":1}]	4332	pick-up	0	17
11662	2019-10-24 18:06:02	2019-10-24	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	633	delivery	5	46
11663	2019-10-24 18:07:32	2019-10-24	9	[{"id_menu":7,"count":1}]	3997	delivery	5	14
11664	2019-10-24 18:11:42	2019-10-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	96	pick-up	0	26
11665	2019-10-24 18:23:21	2019-10-24	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2580	pick-up	0	35
11666	2019-10-24 19:02:25	2019-10-24	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	567	delivery	5	22
11667	2019-10-24 19:21:40	2019-10-24	12	[{"id_menu":3,"count":1}]	4302	delivery	5	17
11668	2019-10-24 19:22:59	2019-10-24	14	[{"id_menu":2,"count":1}]	789	delivery	5	19
11669	2019-10-24 19:24:03	2019-10-24	9	[{"id_menu":7,"count":1}]	547	pick-up	0	9
11670	2019-10-24 19:38:42	2019-10-24	17	[{"id_menu":4,"count":1}]	2585	pick-up	0	17
11671	2019-10-24 19:43:32	2019-10-24	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	44	pick-up	0	34
11672	2019-10-24 19:47:02	2019-10-24	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2815	pick-up	0	31
11673	2019-10-24 19:51:26	2019-10-24	9	[{"id_menu":7,"count":1}]	3469	delivery	5	14
11674	2019-10-24 19:58:07	2019-10-24	9	[{"id_menu":7,"count":2}]	2798	delivery	5	14
11675	2019-10-24 20:04:07	2019-10-24	12	[{"id_menu":3,"count":1}]	3621	pick-up	0	12
11676	2019-10-24 20:09:37	2019-10-24	9	[{"id_menu":7,"count":1}]	209	delivery	5	14
11677	2019-10-24 20:44:46	2019-10-24	17	[{"id_menu":4,"count":1}]	1924	delivery	5	22
11678	2019-10-24 21:04:34	2019-10-24	14	[{"id_menu":2,"count":1}]	2666	delivery	5	19
11679	2019-10-24 21:14:21	2019-10-24	12	[{"id_menu":3,"count":1}]	2715	pick-up	0	12
11680	2019-10-24 21:21:34	2019-10-24	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4315	pick-up	0	25
11681	2019-10-24 21:25:43	2019-10-24	9	[{"id_menu":7,"count":1}]	4319	pick-up	0	9
11682	2019-10-24 21:40:23	2019-10-24	14	[{"id_menu":2,"count":1}]	2653	delivery	5	19
11683	2019-10-24 22:34:43	2019-10-24	17	[{"id_menu":4,"count":1}]	4303	delivery	5	22
11684	2019-10-24 22:35:49	2019-10-24	9	[{"id_menu":7,"count":1}]	876	delivery	5	14
11685	2019-10-24 22:43:06	2019-10-24	9	[{"id_menu":7,"count":1}]	4333	delivery	5	14
11686	2019-10-24 22:52:23	2019-10-24	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	679	delivery	5	34
11687	2019-10-24 23:03:45	2019-10-24	9	[{"id_menu":7,"count":1}]	4330	pick-up	0	9
11688	2019-10-24 23:28:27	2019-10-24	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	438	pick-up	0	26
11689	2019-10-24 23:29:45	2019-10-24	9	[{"id_menu":7,"count":1}]	1684	pick-up	0	9
11690	2019-10-25 00:16:28	2019-10-25	8	[{"id_menu":5,"count":1}]	2443	pick-up	0	8
11691	2019-10-25 01:34:28	2019-10-25	9	[{"id_menu":7,"count":1}]	2310	pick-up	0	9
11692	2019-10-25 01:38:37	2019-10-25	14	[{"id_menu":2,"count":1}]	1187	pick-up	0	14
11693	2019-10-25 01:41:42	2019-10-25	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1729	pick-up	0	31
11694	2019-10-25 01:58:57	2019-10-25	17	[{"id_menu":4,"count":1}]	1629	pick-up	0	17
11695	2019-10-25 01:59:33	2019-10-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2511	pick-up	0	18
11696	2019-10-25 02:03:04	2019-10-25	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	3016	delivery	5	26
11697	2019-10-25 02:05:40	2019-10-25	14	[{"id_menu":2,"count":1}]	2631	pick-up	0	14
11698	2019-10-25 02:07:05	2019-10-25	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	440	delivery	5	30
11699	2019-10-25 02:14:31	2019-10-25	12	[{"id_menu":3,"count":1}]	3620	pick-up	0	12
11700	2019-10-25 02:17:55	2019-10-25	12	[{"id_menu":1,"count":1}]	4042	pick-up	0	12
11701	2019-10-25 02:37:39	2019-10-25	14	[{"id_menu":2,"count":1}]	482	delivery	5	19
11702	2019-10-25 03:03:38	2019-10-25	9	[{"id_menu":6,"count":1}]	2827	pick-up	0	9
11703	2019-10-25 03:12:33	2019-10-25	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2072	delivery	5	31
11704	2019-10-25 03:52:37	2019-10-25	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4346	delivery	5	57
11705	2019-10-25 04:03:23	2019-10-25	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2291	pick-up	0	31
11706	2019-10-25 04:07:54	2019-10-25	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	1309	pick-up	0	21
11707	2019-10-25 04:08:56	2019-10-25	12	[{"id_menu":1,"count":1}]	612	pick-up	0	12
11708	2019-10-25 04:17:57	2019-10-25	12	[{"id_menu":1,"count":1}]	1397	delivery	5	17
11709	2019-10-25 04:21:35	2019-10-25	8	[{"id_menu":5,"count":1}]	4344	delivery	5	13
11710	2019-10-25 04:24:26	2019-10-25	14	[{"id_menu":2,"count":2}]	787	pick-up	0	14
11711	2019-10-25 04:30:19	2019-10-25	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":2}]	4336	pick-up	0	22
11712	2019-10-25 04:44:48	2019-10-25	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	3728	pick-up	0	21
11713	2019-10-25 05:21:36	2019-10-25	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2065	pick-up	0	26
11714	2019-10-25 05:56:16	2019-10-25	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4354	delivery	5	42
11715	2019-10-25 06:28:46	2019-10-25	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	833	pick-up	0	24
11716	2019-10-25 06:32:35	2019-10-25	12	[{"id_menu":3,"count":1}]	2771	delivery	5	17
11717	2019-10-25 06:52:18	2019-10-25	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1085	delivery	5	29
11718	2019-10-25 06:53:15	2019-10-25	12	[{"id_menu":1,"count":1}]	4345	delivery	5	17
11719	2019-10-25 07:51:24	2019-10-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	581	delivery	5	22
11720	2019-10-25 08:18:30	2019-10-25	9	[{"id_menu":7,"count":1}]	4376	delivery	5	14
11721	2019-10-25 08:20:48	2019-10-25	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	927	delivery	5	39
11722	2019-10-25 08:34:58	2019-10-25	9	[{"id_menu":6,"count":1}]	4353	pick-up	0	9
11723	2019-10-25 08:35:35	2019-10-25	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1468	pick-up	0	39
11724	2019-10-25 09:03:13	2019-10-25	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	4361	pick-up	0	26
11725	2019-10-25 09:10:11	2019-10-25	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4339	delivery	5	40
11726	2019-10-25 09:39:16	2019-10-25	9	[{"id_menu":7,"count":1}]	627	delivery	5	14
11727	2019-10-25 09:40:56	2019-10-25	8	[{"id_menu":5,"count":1}]	4365	pick-up	0	8
11728	2019-10-25 09:44:13	2019-10-25	9	[{"id_menu":6,"count":1}]	1412	delivery	5	14
11729	2019-10-25 09:58:15	2019-10-25	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	3494	pick-up	0	31
11730	2019-10-25 10:10:04	2019-10-25	12	[{"id_menu":3,"count":1}]	2762	pick-up	0	12
11731	2019-10-25 10:30:30	2019-10-25	9	[{"id_menu":7,"count":1}]	1183	pick-up	0	9
11732	2019-10-25 10:31:35	2019-10-25	17	[{"id_menu":4,"count":1}]	3391	pick-up	0	17
11733	2019-10-25 10:49:18	2019-10-25	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	295	delivery	5	26
11734	2019-10-25 10:51:12	2019-10-25	17	[{"id_menu":4,"count":1}]	586	pick-up	0	17
11735	2019-10-25 11:01:09	2019-10-25	12	[{"id_menu":1,"count":1}]	4369	delivery	5	17
11736	2019-10-25 11:34:24	2019-10-25	8	[{"id_menu":5,"count":1}]	1841	delivery	5	13
11737	2019-10-25 11:38:07	2019-10-25	9	[{"id_menu":6,"count":1}]	124	delivery	5	14
11738	2019-10-25 11:38:22	2019-10-25	8	[{"id_menu":5,"count":1}]	4351	pick-up	0	8
11739	2019-10-25 11:42:11	2019-10-25	9	[{"id_menu":7,"count":1}]	427	delivery	5	14
11740	2019-10-25 11:46:38	2019-10-25	12	[{"id_menu":1,"count":1}]	4363	pick-up	0	12
11741	2019-10-25 12:00:41	2019-10-25	14	[{"id_menu":2,"count":1}]	3384	pick-up	0	14
11742	2019-10-25 12:07:16	2019-10-25	14	[{"id_menu":2,"count":1}]	3093	delivery	5	19
11743	2019-10-25 12:10:46	2019-10-25	9	[{"id_menu":7,"count":1}]	4355	delivery	5	14
11744	2019-10-25 12:35:05	2019-10-25	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	2774	delivery	5	40
11745	2019-10-25 13:06:08	2019-10-25	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3961	pick-up	0	29
11746	2019-10-25 13:15:15	2019-10-25	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	767	delivery	5	26
11747	2019-10-25 13:28:24	2019-10-25	14	[{"id_menu":2,"count":2}]	1322	delivery	5	19
11748	2019-10-25 14:20:57	2019-10-25	12	[{"id_menu":1,"count":1}]	4350	pick-up	0	12
11749	2019-10-25 14:43:47	2019-10-25	9	[{"id_menu":6,"count":2}]	3182	delivery	5	14
11750	2019-10-25 15:09:57	2019-10-25	8	[{"id_menu":5,"count":1}]	1854	pick-up	0	8
11751	2019-10-25 15:24:15	2019-10-25	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	383	delivery	5	31
11752	2019-10-25 15:39:58	2019-10-25	12	[{"id_menu":3,"count":2}]	4370	pick-up	0	12
11753	2019-10-25 15:43:09	2019-10-25	12	[{"id_menu":3,"count":1}]	4347	delivery	5	17
11754	2019-10-25 15:45:09	2019-10-25	9	[{"id_menu":7,"count":1}]	4017	delivery	5	14
11755	2019-10-25 16:02:24	2019-10-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2790	delivery	5	23
11756	2019-10-25 16:23:11	2019-10-25	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1320	pick-up	0	23
11757	2019-10-25 16:31:11	2019-10-25	9	[{"id_menu":7,"count":1}]	117	pick-up	0	9
11758	2019-10-25 16:44:27	2019-10-25	14	[{"id_menu":2,"count":1}]	3373	delivery	5	19
11759	2019-10-25 17:03:03	2019-10-25	17	[{"id_menu":4,"count":1}]	4341	pick-up	0	17
11760	2019-10-25 17:07:01	2019-10-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2562	pick-up	0	18
11761	2019-10-25 17:29:09	2019-10-25	17	[{"id_menu":4,"count":1}]	3451	pick-up	0	17
11762	2019-10-25 17:30:29	2019-10-25	17	[{"id_menu":4,"count":1}]	4315	delivery	5	22
11763	2019-10-25 18:04:48	2019-10-25	9	[{"id_menu":6,"count":1}]	1649	delivery	5	14
11764	2019-10-25 18:08:58	2019-10-25	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":2}]	4343	delivery	5	25
11765	2019-10-25 18:11:08	2019-10-25	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2366	pick-up	0	21
11766	2019-10-25 18:29:59	2019-10-25	9	[{"id_menu":7,"count":1}]	3993	delivery	5	14
11767	2019-10-25 18:56:19	2019-10-25	9	[{"id_menu":6,"count":1}]	3135	pick-up	0	9
11768	2019-10-25 19:38:52	2019-10-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4337	pick-up	0	26
11769	2019-10-25 19:56:37	2019-10-25	12	[{"id_menu":3,"count":1}]	3577	delivery	5	17
11770	2019-10-25 20:08:44	2019-10-25	12	[{"id_menu":1,"count":1}]	4338	delivery	5	17
11771	2019-10-25 20:10:34	2019-10-25	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1473	pick-up	0	31
11772	2019-10-25 20:15:09	2019-10-25	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	4357	delivery	5	25
11773	2019-10-25 20:20:44	2019-10-25	14	[{"id_menu":2,"count":1}]	4373	delivery	5	19
11774	2019-10-25 20:45:31	2019-10-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4299	delivery	5	31
11775	2019-10-25 21:00:03	2019-10-25	9	[{"id_menu":6,"count":1}]	4352	pick-up	0	9
11776	2019-10-25 21:09:21	2019-10-25	14	[{"id_menu":2,"count":1}]	2604	delivery	5	19
11777	2019-10-25 21:39:26	2019-10-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4356	pick-up	0	23
11778	2019-10-25 22:07:36	2019-10-25	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4360	delivery	5	31
11779	2019-10-25 22:21:31	2019-10-25	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	2517	pick-up	0	24
11780	2019-10-25 22:31:58	2019-10-25	17	[{"id_menu":4,"count":1}]	596	delivery	5	22
11781	2019-10-25 22:54:45	2019-10-25	14	[{"id_menu":2,"count":1}]	189	pick-up	0	14
11782	2019-10-25 23:32:17	2019-10-25	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4372	pick-up	0	21
11783	2019-10-25 23:39:21	2019-10-25	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1380	delivery	5	26
11784	2019-10-26 00:07:37	2019-10-26	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4403	delivery	5	31
11785	2019-10-26 00:12:18	2019-10-26	9	[{"id_menu":6,"count":1}]	3301	delivery	5	14
11786	2019-10-26 00:20:42	2019-10-26	14	[{"id_menu":2,"count":1}]	340	pick-up	0	14
11787	2019-10-26 00:42:41	2019-10-26	17	[{"id_menu":4,"count":1}]	4411	pick-up	0	17
11788	2019-10-26 00:47:20	2019-10-26	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	4402	delivery	5	34
11789	2019-10-26 01:14:16	2019-10-26	17	[{"id_menu":4,"count":1}]	4418	delivery	5	22
11790	2019-10-26 01:19:58	2019-10-26	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4398	delivery	5	36
11791	2019-10-26 01:38:13	2019-10-26	12	[{"id_menu":1,"count":2}]	209	delivery	5	17
11792	2019-10-26 01:47:31	2019-10-26	12	[{"id_menu":1,"count":1}]	919	pick-up	0	12
11793	2019-10-26 01:50:30	2019-10-26	9	[{"id_menu":6,"count":1}]	1256	delivery	5	14
11794	2019-10-26 01:55:52	2019-10-26	17	[{"id_menu":4,"count":1}]	3142	delivery	5	22
11795	2019-10-26 02:00:23	2019-10-26	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	4399	delivery	5	29
11796	2019-10-26 02:00:23	2019-10-26	17	[{"id_menu":4,"count":1}]	3812	pick-up	0	17
11797	2019-10-26 02:02:58	2019-10-26	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	424	delivery	5	46
11798	2019-10-26 02:03:12	2019-10-26	9	[{"id_menu":7,"count":1}]	3399	pick-up	0	9
11799	2019-10-26 02:04:05	2019-10-26	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2465	pick-up	0	25
11800	2019-10-26 02:05:20	2019-10-26	17	[{"id_menu":4,"count":1}]	4386	delivery	5	22
11801	2019-10-26 02:06:37	2019-10-26	9	[{"id_menu":7,"count":1}]	1334	delivery	5	14
11802	2019-10-26 02:08:29	2019-10-26	8	[{"id_menu":5,"count":1}]	2542	pick-up	0	8
11803	2019-10-26 02:09:38	2019-10-26	14	[{"id_menu":2,"count":1}]	4417	delivery	5	19
11804	2019-10-26 02:18:44	2019-10-26	8	[{"id_menu":5,"count":1}]	4426	delivery	5	13
11805	2019-10-26 02:20:52	2019-10-26	14	[{"id_menu":2,"count":1}]	1512	pick-up	0	14
11806	2019-10-26 02:25:05	2019-10-26	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	2088	pick-up	0	26
11807	2019-10-26 02:26:10	2019-10-26	9	[{"id_menu":6,"count":1}]	491	delivery	5	14
11808	2019-10-26 02:27:08	2019-10-26	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	569	delivery	5	45
11809	2019-10-26 02:54:02	2019-10-26	9	[{"id_menu":7,"count":1}]	4408	pick-up	0	9
11810	2019-10-26 03:11:09	2019-10-26	9	[{"id_menu":6,"count":1}]	4192	delivery	5	14
11811	2019-10-26 03:23:49	2019-10-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2771	pick-up	0	23
11812	2019-10-26 03:40:02	2019-10-26	14	[{"id_menu":2,"count":1}]	1352	pick-up	0	14
11813	2019-10-26 03:45:28	2019-10-26	14	[{"id_menu":2,"count":1}]	3271	pick-up	0	14
11814	2019-10-26 03:53:42	2019-10-26	17	[{"id_menu":4,"count":1}]	350	pick-up	0	17
11815	2019-10-26 04:09:12	2019-10-26	12	[{"id_menu":3,"count":1}]	970	delivery	5	17
11816	2019-10-26 04:35:02	2019-10-26	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4422	delivery	5	48
11817	2019-10-26 04:44:30	2019-10-26	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	4427	delivery	5	34
11818	2019-10-26 04:52:04	2019-10-26	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4419	delivery	5	48
11819	2019-10-26 05:35:12	2019-10-26	17	[{"id_menu":4,"count":1}]	531	pick-up	0	17
11820	2019-10-26 05:38:26	2019-10-26	8	[{"id_menu":5,"count":1}]	2089	delivery	5	13
11821	2019-10-26 05:58:26	2019-10-26	9	[{"id_menu":7,"count":1}]	4022	delivery	5	14
11822	2019-10-26 06:09:16	2019-10-26	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2469	pick-up	0	29
11823	2019-10-26 06:40:09	2019-10-26	14	[{"id_menu":2,"count":1}]	4330	pick-up	0	14
11824	2019-10-26 06:53:41	2019-10-26	8	[{"id_menu":5,"count":1}]	4406	delivery	5	13
11825	2019-10-26 07:08:42	2019-10-26	12	[{"id_menu":3,"count":1}]	4423	pick-up	0	12
11826	2019-10-26 07:11:58	2019-10-26	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1089	pick-up	0	20
11827	2019-10-26 07:21:32	2019-10-26	8	[{"id_menu":5,"count":1}]	4383	delivery	5	13
11828	2019-10-26 07:41:33	2019-10-26	14	[{"id_menu":2,"count":1}]	905	delivery	5	19
11829	2019-10-26 07:42:10	2019-10-26	14	[{"id_menu":2,"count":1}]	4396	delivery	5	19
11830	2019-10-26 08:22:59	2019-10-26	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2119	delivery	5	36
11831	2019-10-26 08:23:51	2019-10-26	12	[{"id_menu":1,"count":2}]	2015	delivery	5	17
11832	2019-10-26 08:27:01	2019-10-26	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1687	pick-up	0	21
11833	2019-10-26 08:51:29	2019-10-26	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1504	delivery	5	40
11834	2019-10-26 09:23:18	2019-10-26	8	[{"id_menu":5,"count":1}]	4389	delivery	5	13
11835	2019-10-26 09:25:09	2019-10-26	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	243	delivery	5	40
11836	2019-10-26 09:27:01	2019-10-26	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	4415	pick-up	0	24
11837	2019-10-26 09:27:31	2019-10-26	12	[{"id_menu":1,"count":1}]	2928	delivery	5	17
11838	2019-10-26 10:20:03	2019-10-26	14	[{"id_menu":2,"count":1}]	4378	delivery	5	19
11839	2019-10-26 10:25:03	2019-10-26	9	[{"id_menu":6,"count":1}]	4421	delivery	5	14
11840	2019-10-26 10:42:30	2019-10-26	9	[{"id_menu":7,"count":1}]	4393	delivery	5	14
11841	2019-10-26 10:57:04	2019-10-26	12	[{"id_menu":1,"count":1}]	4412	delivery	5	17
11842	2019-10-26 11:27:45	2019-10-26	17	[{"id_menu":4,"count":1}]	1072	pick-up	0	17
11843	2019-10-26 11:49:54	2019-10-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2843	delivery	5	28
11844	2019-10-26 11:54:06	2019-10-26	12	[{"id_menu":1,"count":1}]	3046	delivery	5	17
11845	2019-10-26 12:05:46	2019-10-26	12	[{"id_menu":3,"count":1}]	4387	pick-up	0	12
11846	2019-10-26 12:09:08	2019-10-26	12	[{"id_menu":1,"count":1}]	104	pick-up	0	12
11847	2019-10-26 12:16:38	2019-10-26	9	[{"id_menu":6,"count":1}]	4413	delivery	5	14
11848	2019-10-26 12:21:35	2019-10-26	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2538	pick-up	0	29
11849	2019-10-26 12:28:39	2019-10-26	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	4416	pick-up	0	30
11850	2019-10-26 12:36:02	2019-10-26	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	729	pick-up	0	22
11851	2019-10-26 12:50:29	2019-10-26	8	[{"id_menu":5,"count":1}]	4394	delivery	5	13
11852	2019-10-26 12:55:55	2019-10-26	9	[{"id_menu":6,"count":1}]	4395	pick-up	0	9
11853	2019-10-26 13:13:40	2019-10-26	9	[{"id_menu":7,"count":1}]	4391	delivery	5	14
11854	2019-10-26 13:16:09	2019-10-26	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	3940	pick-up	0	26
11855	2019-10-26 13:30:35	2019-10-26	9	[{"id_menu":6,"count":1}]	3647	pick-up	0	9
11856	2019-10-26 14:11:20	2019-10-26	12	[{"id_menu":3,"count":1}]	2195	pick-up	0	12
11857	2019-10-26 14:16:22	2019-10-26	8	[{"id_menu":5,"count":1}]	4356	pick-up	0	8
11858	2019-10-26 14:25:04	2019-10-26	12	[{"id_menu":3,"count":1}]	4381	delivery	5	17
11859	2019-10-26 14:30:04	2019-10-26	9	[{"id_menu":6,"count":1}]	4379	delivery	5	14
11860	2019-10-26 14:31:20	2019-10-26	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	470	delivery	5	29
11861	2019-10-26 14:32:27	2019-10-26	14	[{"id_menu":2,"count":1}]	4397	pick-up	0	14
11862	2019-10-26 14:35:46	2019-10-26	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1267	delivery	5	25
11863	2019-10-26 15:07:34	2019-10-26	9	[{"id_menu":7,"count":1}]	4407	delivery	5	14
11864	2019-10-26 15:15:00	2019-10-26	9	[{"id_menu":6,"count":1}]	131	delivery	5	14
11865	2019-10-26 15:15:42	2019-10-26	8	[{"id_menu":5,"count":1}]	430	delivery	5	13
11866	2019-10-26 15:37:13	2019-10-26	8	[{"id_menu":5,"count":1}]	4414	pick-up	0	8
11867	2019-10-26 15:50:28	2019-10-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2000	delivery	5	26
11868	2019-10-26 15:56:41	2019-10-26	9	[{"id_menu":6,"count":1}]	720	delivery	5	14
11869	2019-10-26 16:04:59	2019-10-26	12	[{"id_menu":3,"count":1}]	3148	pick-up	0	12
11870	2019-10-26 16:15:09	2019-10-26	9	[{"id_menu":7,"count":1}]	833	pick-up	0	9
11871	2019-10-26 16:38:43	2019-10-26	17	[{"id_menu":4,"count":1}]	4377	delivery	5	22
11872	2019-10-26 16:44:17	2019-10-26	12	[{"id_menu":1,"count":1}]	4424	delivery	5	17
11873	2019-10-26 16:45:30	2019-10-26	14	[{"id_menu":2,"count":1}]	4392	pick-up	0	14
11874	2019-10-26 16:48:28	2019-10-26	17	[{"id_menu":4,"count":1}]	4405	delivery	5	22
11875	2019-10-26 17:01:09	2019-10-26	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	203	delivery	5	34
11876	2019-10-26 17:02:55	2019-10-26	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	2052	delivery	5	39
11877	2019-10-26 17:03:13	2019-10-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2071	pick-up	0	23
11878	2019-10-26 17:09:53	2019-10-26	14	[{"id_menu":2,"count":1}]	3527	delivery	5	19
11879	2019-10-26 17:46:16	2019-10-26	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":3}]	2647	delivery	5	26
11880	2019-10-26 18:03:29	2019-10-26	8	[{"id_menu":5,"count":1}]	3066	pick-up	0	8
11881	2019-10-26 18:11:19	2019-10-26	9	[{"id_menu":6,"count":1}]	1522	delivery	5	14
11882	2019-10-26 18:22:11	2019-10-26	9	[{"id_menu":6,"count":1}]	1101	delivery	5	14
11883	2019-10-26 18:31:39	2019-10-26	14	[{"id_menu":2,"count":1}]	4370	pick-up	0	14
11884	2019-10-26 18:43:55	2019-10-26	17	[{"id_menu":4,"count":1}]	3174	pick-up	0	17
11885	2019-10-26 18:44:28	2019-10-26	12	[{"id_menu":3,"count":1}]	4382	delivery	5	17
11886	2019-10-26 19:23:14	2019-10-26	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3260	pick-up	0	35
11887	2019-10-26 19:38:51	2019-10-26	8	[{"id_menu":5,"count":1}]	1044	pick-up	0	8
11888	2019-10-26 19:40:55	2019-10-26	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	34	pick-up	0	41
11889	2019-10-26 19:56:03	2019-10-26	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	211	pick-up	0	21
11890	2019-10-26 20:00:22	2019-10-26	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	4410	pick-up	0	21
11891	2019-10-26 20:05:19	2019-10-26	9	[{"id_menu":6,"count":1}]	3971	pick-up	0	9
11892	2019-10-26 20:12:35	2019-10-26	9	[{"id_menu":7,"count":2}]	4390	delivery	5	14
11893	2019-10-26 20:14:56	2019-10-26	14	[{"id_menu":2,"count":1}]	4384	pick-up	0	14
11894	2019-10-26 20:15:06	2019-10-26	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	444	pick-up	0	31
11895	2019-10-26 20:25:27	2019-10-26	12	[{"id_menu":1,"count":1}]	4400	delivery	5	17
11896	2019-10-26 20:33:15	2019-10-26	14	[{"id_menu":2,"count":1}]	2185	pick-up	0	14
11897	2019-10-26 20:35:15	2019-10-26	9	[{"id_menu":7,"count":1}]	4425	delivery	5	14
11898	2019-10-26 20:56:46	2019-10-26	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4380	delivery	5	43
11899	2019-10-26 20:58:41	2019-10-26	14	[{"id_menu":2,"count":1}]	623	delivery	5	19
11900	2019-10-26 21:11:40	2019-10-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	4388	delivery	5	26
11901	2019-10-26 21:14:15	2019-10-26	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1996	delivery	5	36
11902	2019-10-26 21:42:35	2019-10-26	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4409	pick-up	0	21
11903	2019-10-26 21:46:39	2019-10-26	17	[{"id_menu":4,"count":1}]	4401	delivery	5	22
11904	2019-10-26 21:51:07	2019-10-26	9	[{"id_menu":6,"count":1}]	4180	pick-up	0	9
11905	2019-10-26 22:05:44	2019-10-26	17	[{"id_menu":4,"count":2}]	343	pick-up	0	17
11906	2019-10-26 22:28:54	2019-10-26	12	[{"id_menu":1,"count":1}]	4385	delivery	5	17
11907	2019-10-26 22:50:26	2019-10-26	9	[{"id_menu":7,"count":1}]	4357	delivery	5	14
11908	2019-10-26 22:51:44	2019-10-26	17	[{"id_menu":4,"count":1}]	2633	delivery	5	22
11909	2019-10-26 22:52:13	2019-10-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3600	pick-up	0	23
11910	2019-10-26 22:54:18	2019-10-26	14	[{"id_menu":2,"count":1}]	617	delivery	5	19
11911	2019-10-26 23:08:09	2019-10-26	8	[{"id_menu":5,"count":2}]	4404	delivery	5	13
11912	2019-10-26 23:54:24	2019-10-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2729	delivery	5	26
11913	2019-10-27 00:06:11	2019-10-27	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1376	pick-up	0	29
11914	2019-10-27 00:27:49	2019-10-27	12	[{"id_menu":3,"count":1}]	387	pick-up	0	12
11915	2019-10-27 00:31:00	2019-10-27	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1598	delivery	5	28
11916	2019-10-27 00:49:26	2019-10-27	12	[{"id_menu":3,"count":1}]	1468	delivery	5	17
11917	2019-10-27 01:07:05	2019-10-27	9	[{"id_menu":6,"count":2}]	4433	delivery	5	14
11918	2019-10-27 01:10:48	2019-10-27	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	229	pick-up	0	26
11919	2019-10-27 01:23:50	2019-10-27	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3086	delivery	5	55
11920	2019-10-27 01:32:56	2019-10-27	12	[{"id_menu":1,"count":1}]	2439	pick-up	0	12
11921	2019-10-27 01:33:19	2019-10-27	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	4441	pick-up	0	21
11922	2019-10-27 01:38:34	2019-10-27	9	[{"id_menu":6,"count":1}]	4451	delivery	5	14
11923	2019-10-27 01:43:20	2019-10-27	9	[{"id_menu":7,"count":1}]	931	pick-up	0	9
11924	2019-10-27 01:50:36	2019-10-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1686	delivery	5	28
11925	2019-10-27 02:51:50	2019-10-27	12	[{"id_menu":1,"count":1}]	2204	pick-up	0	12
11926	2019-10-27 02:56:33	2019-10-27	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	3345	delivery	5	31
11927	2019-10-27 03:05:23	2019-10-27	14	[{"id_menu":2,"count":1}]	2200	delivery	5	19
11928	2019-10-27 03:10:27	2019-10-27	9	[{"id_menu":7,"count":1}]	4442	delivery	5	14
11929	2019-10-27 03:16:55	2019-10-27	9	[{"id_menu":6,"count":1}]	4458	pick-up	0	9
11930	2019-10-27 03:17:46	2019-10-27	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2653	pick-up	0	23
11931	2019-10-27 03:45:08	2019-10-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2728	pick-up	0	18
11932	2019-10-27 04:00:31	2019-10-27	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3567	pick-up	0	40
11933	2019-10-27 04:09:16	2019-10-27	12	[{"id_menu":1,"count":1}]	2153	pick-up	0	12
11934	2019-10-27 04:10:39	2019-10-27	12	[{"id_menu":3,"count":1}]	4356	pick-up	0	12
11935	2019-10-27 04:17:50	2019-10-27	9	[{"id_menu":7,"count":1}]	4464	delivery	5	14
11936	2019-10-27 04:19:27	2019-10-27	17	[{"id_menu":4,"count":1}]	4130	pick-up	0	17
11937	2019-10-27 04:20:16	2019-10-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3393	delivery	5	36
11938	2019-10-27 04:20:19	2019-10-27	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	4467	pick-up	0	33
11939	2019-10-27 04:22:24	2019-10-27	9	[{"id_menu":7,"count":1}]	4460	delivery	5	14
11940	2019-10-27 04:23:48	2019-10-27	17	[{"id_menu":4,"count":1}]	4450	delivery	5	22
11941	2019-10-27 04:28:58	2019-10-27	12	[{"id_menu":3,"count":1}]	3409	delivery	5	17
11942	2019-10-27 04:38:12	2019-10-27	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	4192	delivery	5	29
11943	2019-10-27 04:41:49	2019-10-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	4457	delivery	5	23
11944	2019-10-27 04:49:05	2019-10-27	17	[{"id_menu":4,"count":1}]	2080	pick-up	0	17
11945	2019-10-27 04:50:03	2019-10-27	12	[{"id_menu":1,"count":1}]	2339	delivery	5	17
11946	2019-10-27 04:54:45	2019-10-27	9	[{"id_menu":6,"count":1}]	3451	pick-up	0	9
11947	2019-10-27 04:56:29	2019-10-27	12	[{"id_menu":3,"count":1}]	4091	delivery	5	17
11948	2019-10-27 05:02:54	2019-10-27	8	[{"id_menu":5,"count":1}]	4443	delivery	5	13
11949	2019-10-27 05:15:34	2019-10-27	9	[{"id_menu":6,"count":1}]	1941	pick-up	0	9
11950	2019-10-27 05:29:20	2019-10-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1560	pick-up	0	18
11951	2019-10-27 05:53:34	2019-10-27	9	[{"id_menu":7,"count":1}]	843	pick-up	0	9
11952	2019-10-27 05:53:59	2019-10-27	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3112	delivery	5	31
11953	2019-10-27 05:59:01	2019-10-27	17	[{"id_menu":4,"count":1}]	1602	pick-up	0	17
11954	2019-10-27 06:06:57	2019-10-27	17	[{"id_menu":4,"count":1}]	2706	pick-up	0	17
11955	2019-10-27 06:10:34	2019-10-27	12	[{"id_menu":1,"count":1}]	242	pick-up	0	12
11956	2019-10-27 06:59:24	2019-10-27	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4465	pick-up	0	43
11957	2019-10-27 07:11:53	2019-10-27	9	[{"id_menu":7,"count":1}]	2691	pick-up	0	9
11958	2019-10-27 07:30:02	2019-10-27	17	[{"id_menu":4,"count":1}]	3406	delivery	5	22
11959	2019-10-27 07:38:14	2019-10-27	14	[{"id_menu":2,"count":1}]	2753	pick-up	0	14
11960	2019-10-27 07:57:59	2019-10-27	9	[{"id_menu":7,"count":2}]	4449	pick-up	0	9
11961	2019-10-27 08:05:46	2019-10-27	8	[{"id_menu":5,"count":1}]	4445	pick-up	0	8
11962	2019-10-27 08:08:24	2019-10-27	9	[{"id_menu":6,"count":1}]	3006	delivery	5	14
11963	2019-10-27 08:11:34	2019-10-27	12	[{"id_menu":1,"count":1}]	3433	pick-up	0	12
11964	2019-10-27 08:39:39	2019-10-27	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	730	pick-up	0	41
11965	2019-10-27 08:41:38	2019-10-27	12	[{"id_menu":1,"count":1}]	757	pick-up	0	12
11966	2019-10-27 08:48:22	2019-10-27	14	[{"id_menu":2,"count":1}]	3918	pick-up	0	14
11967	2019-10-27 08:50:07	2019-10-27	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	3619	pick-up	0	29
11968	2019-10-27 08:55:22	2019-10-27	8	[{"id_menu":5,"count":1}]	4429	delivery	5	13
11969	2019-10-27 08:58:14	2019-10-27	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1337	pick-up	0	21
11970	2019-10-27 09:08:05	2019-10-27	12	[{"id_menu":1,"count":1}]	4436	pick-up	0	12
11971	2019-10-27 09:19:33	2019-10-27	9	[{"id_menu":7,"count":1}]	2877	delivery	5	14
11972	2019-10-27 09:20:06	2019-10-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4432	delivery	5	23
11973	2019-10-27 09:31:34	2019-10-27	8	[{"id_menu":5,"count":1}]	4454	delivery	5	13
11974	2019-10-27 09:34:24	2019-10-27	14	[{"id_menu":2,"count":1}]	4434	delivery	5	19
11975	2019-10-27 09:47:48	2019-10-27	17	[{"id_menu":4,"count":1}]	3976	pick-up	0	17
11976	2019-10-27 09:50:18	2019-10-27	9	[{"id_menu":7,"count":1}]	1334	pick-up	0	9
11977	2019-10-27 09:56:02	2019-10-27	9	[{"id_menu":6,"count":1}]	4453	delivery	5	14
11978	2019-10-27 10:45:12	2019-10-27	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	212	delivery	5	40
11979	2019-10-27 10:50:40	2019-10-27	12	[{"id_menu":3,"count":1}]	4459	delivery	5	17
11980	2019-10-27 10:51:46	2019-10-27	9	[{"id_menu":6,"count":1}]	1536	pick-up	0	9
11981	2019-10-27 10:55:01	2019-10-27	9	[{"id_menu":7,"count":1}]	4431	pick-up	0	9
11982	2019-10-27 10:59:42	2019-10-27	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3289	pick-up	0	26
11983	2019-10-27 11:44:06	2019-10-27	14	[{"id_menu":2,"count":1}]	3730	pick-up	0	14
11984	2019-10-27 11:50:21	2019-10-27	14	[{"id_menu":2,"count":1}]	1659	pick-up	0	14
11985	2019-10-27 11:53:56	2019-10-27	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2644	delivery	5	38
11986	2019-10-27 11:54:00	2019-10-27	9	[{"id_menu":6,"count":1}]	1513	pick-up	0	9
11987	2019-10-27 11:58:23	2019-10-27	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	89	delivery	5	31
11988	2019-10-27 12:11:16	2019-10-27	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2054	pick-up	0	52
11989	2019-10-27 12:18:22	2019-10-27	8	[{"id_menu":5,"count":1}]	4139	pick-up	0	8
11990	2019-10-27 12:20:15	2019-10-27	9	[{"id_menu":7,"count":1}]	1760	pick-up	0	9
11991	2019-10-27 12:33:11	2019-10-27	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1409	pick-up	0	25
11992	2019-10-27 12:39:59	2019-10-27	8	[{"id_menu":5,"count":1}]	4439	delivery	5	13
11993	2019-10-27 12:55:14	2019-10-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	4108	delivery	5	22
11994	2019-10-27 13:01:08	2019-10-27	9	[{"id_menu":6,"count":1}]	765	pick-up	0	9
11995	2019-10-27 13:32:59	2019-10-27	14	[{"id_menu":2,"count":1}]	1764	pick-up	0	14
11996	2019-10-27 13:33:32	2019-10-27	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	401	delivery	5	31
11997	2019-10-27 13:36:33	2019-10-27	17	[{"id_menu":4,"count":1}]	1093	pick-up	0	17
11998	2019-10-27 13:37:11	2019-10-27	9	[{"id_menu":7,"count":1}]	4437	delivery	5	14
11999	2019-10-27 13:39:05	2019-10-27	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	125	pick-up	0	29
12000	2019-10-27 13:40:56	2019-10-27	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	3066	pick-up	0	20
12001	2019-10-27 13:41:57	2019-10-27	9	[{"id_menu":6,"count":1}]	4447	delivery	5	14
12002	2019-10-27 13:44:26	2019-10-27	9	[{"id_menu":6,"count":1}]	4462	pick-up	0	9
12003	2019-10-27 13:58:56	2019-10-27	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1618	delivery	5	42
12004	2019-10-27 14:10:52	2019-10-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4428	pick-up	0	31
12005	2019-10-27 14:12:17	2019-10-27	17	[{"id_menu":4,"count":1}]	376	delivery	5	22
12006	2019-10-27 14:33:22	2019-10-27	9	[{"id_menu":7,"count":1}]	3583	delivery	5	14
12007	2019-10-27 14:40:15	2019-10-27	17	[{"id_menu":4,"count":2}]	2252	pick-up	0	17
12008	2019-10-27 14:40:59	2019-10-27	14	[{"id_menu":2,"count":1}]	671	delivery	5	19
12009	2019-10-27 14:41:54	2019-10-27	9	[{"id_menu":6,"count":1}]	3063	delivery	5	14
12010	2019-10-27 14:46:02	2019-10-27	8	[{"id_menu":5,"count":1}]	4461	pick-up	0	8
12011	2019-10-27 14:52:58	2019-10-27	9	[{"id_menu":7,"count":1}]	1155	pick-up	0	9
12012	2019-10-27 15:09:10	2019-10-27	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4106	pick-up	0	52
12013	2019-10-27 15:49:52	2019-10-27	9	[{"id_menu":7,"count":1}]	3883	delivery	5	14
12014	2019-10-27 16:03:48	2019-10-27	9	[{"id_menu":7,"count":1}]	389	pick-up	0	9
12015	2019-10-27 16:16:17	2019-10-27	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2798	pick-up	0	29
12016	2019-10-27 16:22:57	2019-10-27	12	[{"id_menu":1,"count":1}]	1090	delivery	5	17
12017	2019-10-27 16:23:05	2019-10-27	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	643	delivery	5	25
12018	2019-10-27 16:23:30	2019-10-27	8	[{"id_menu":5,"count":1}]	2731	pick-up	0	8
12019	2019-10-27 16:23:39	2019-10-27	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4446	delivery	5	40
12020	2019-10-27 16:25:01	2019-10-27	9	[{"id_menu":6,"count":1}]	3647	pick-up	0	9
12021	2019-10-27 16:35:45	2019-10-27	12	[{"id_menu":1,"count":1}]	4463	pick-up	0	12
12022	2019-10-27 16:41:07	2019-10-27	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	3121	delivery	5	26
12023	2019-10-27 17:01:12	2019-10-27	14	[{"id_menu":2,"count":1}]	382	pick-up	0	14
12024	2019-10-27 17:03:42	2019-10-27	9	[{"id_menu":6,"count":1}]	4466	delivery	5	14
12025	2019-10-27 17:03:55	2019-10-27	14	[{"id_menu":2,"count":1}]	2807	pick-up	0	14
12026	2019-10-27 17:07:59	2019-10-27	17	[{"id_menu":4,"count":1}]	559	delivery	5	22
12027	2019-10-27 17:27:23	2019-10-27	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4438	delivery	5	31
12028	2019-10-27 17:40:07	2019-10-27	14	[{"id_menu":2,"count":1}]	377	pick-up	0	14
12029	2019-10-27 17:56:53	2019-10-27	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	274	pick-up	0	29
12030	2019-10-27 18:01:10	2019-10-27	9	[{"id_menu":7,"count":1}]	638	delivery	5	14
12031	2019-10-27 18:03:30	2019-10-27	9	[{"id_menu":7,"count":1}]	172	pick-up	0	9
12032	2019-10-27 18:26:21	2019-10-27	12	[{"id_menu":3,"count":1}]	1997	pick-up	0	12
12033	2019-10-27 18:30:00	2019-10-27	17	[{"id_menu":5,"count":3},{"id_menu":6,"count":1}]	308	delivery	5	22
12034	2019-10-27 18:45:05	2019-10-27	17	[{"id_menu":4,"count":1}]	524	delivery	5	22
12035	2019-10-27 18:53:06	2019-10-27	17	[{"id_menu":4,"count":1}]	4444	pick-up	0	17
12036	2019-10-27 19:01:26	2019-10-27	12	[{"id_menu":1,"count":1}]	1763	pick-up	0	12
12037	2019-10-27 19:02:59	2019-10-27	8	[{"id_menu":5,"count":1}]	315	pick-up	0	8
12038	2019-10-27 19:08:48	2019-10-27	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	3338	pick-up	0	26
12039	2019-10-27 19:13:18	2019-10-27	17	[{"id_menu":4,"count":1}]	1693	pick-up	0	17
12040	2019-10-27 19:25:06	2019-10-27	9	[{"id_menu":7,"count":1}]	3995	pick-up	0	9
12041	2019-10-27 19:25:42	2019-10-27	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	154	pick-up	0	40
12042	2019-10-27 19:34:29	2019-10-27	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4456	delivery	5	28
12043	2019-10-27 19:54:16	2019-10-27	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	917	delivery	5	25
12044	2019-10-27 20:29:11	2019-10-27	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4452	delivery	5	45
12045	2019-10-27 21:12:53	2019-10-27	17	[{"id_menu":4,"count":1}]	4455	delivery	5	22
12046	2019-10-27 21:13:06	2019-10-27	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	4279	delivery	5	40
12047	2019-10-27 21:16:16	2019-10-27	9	[{"id_menu":6,"count":1}]	2824	pick-up	0	9
12048	2019-10-27 21:30:18	2019-10-27	14	[{"id_menu":2,"count":1}]	313	pick-up	0	14
12049	2019-10-27 21:35:52	2019-10-27	8	[{"id_menu":5,"count":1}]	3511	pick-up	0	8
12050	2019-10-27 21:40:38	2019-10-27	14	[{"id_menu":2,"count":1}]	932	pick-up	0	14
12051	2019-10-27 21:44:05	2019-10-27	12	[{"id_menu":3,"count":1}]	1715	pick-up	0	12
12052	2019-10-27 21:59:47	2019-10-27	9	[{"id_menu":6,"count":1}]	1473	delivery	5	14
12053	2019-10-27 22:12:51	2019-10-27	9	[{"id_menu":7,"count":1}]	4435	pick-up	0	9
12054	2019-10-27 22:14:59	2019-10-27	8	[{"id_menu":5,"count":1}]	1366	pick-up	0	8
12055	2019-10-27 22:28:25	2019-10-27	9	[{"id_menu":6,"count":2}]	4430	pick-up	0	9
12056	2019-10-27 22:51:58	2019-10-27	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	272	delivery	5	43
12057	2019-10-27 22:54:12	2019-10-27	12	[{"id_menu":3,"count":1}]	3954	delivery	5	17
12058	2019-10-27 22:54:38	2019-10-27	9	[{"id_menu":6,"count":1}]	2298	delivery	5	14
12059	2019-10-27 23:06:56	2019-10-27	12	[{"id_menu":3,"count":1}]	3758	pick-up	0	12
12060	2019-10-27 23:07:15	2019-10-27	9	[{"id_menu":6,"count":1}]	4440	delivery	5	14
12061	2019-10-27 23:08:15	2019-10-27	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	4448	pick-up	0	26
12062	2019-10-27 23:41:45	2019-10-27	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	514	delivery	5	43
12063	2019-10-27 23:52:08	2019-10-27	9	[{"id_menu":6,"count":1}]	2393	delivery	5	14
12064	2019-10-28 00:29:38	2019-10-28	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	4475	delivery	5	26
12065	2019-10-28 00:48:02	2019-10-28	14	[{"id_menu":2,"count":1}]	1886	pick-up	0	14
12066	2019-10-28 01:13:11	2019-10-28	9	[{"id_menu":7,"count":1}]	1264	pick-up	0	9
12067	2019-10-28 01:25:19	2019-10-28	9	[{"id_menu":6,"count":1}]	94	delivery	5	14
12068	2019-10-28 01:28:32	2019-10-28	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3219	delivery	5	34
12069	2019-10-28 01:46:02	2019-10-28	12	[{"id_menu":3,"count":1}]	2242	delivery	5	17
12070	2019-10-28 02:19:59	2019-10-28	14	[{"id_menu":2,"count":1}]	4500	pick-up	0	14
12071	2019-10-28 02:20:00	2019-10-28	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1632	delivery	5	37
12072	2019-10-28 03:08:21	2019-10-28	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	138	pick-up	0	29
12073	2019-10-28 03:11:14	2019-10-28	14	[{"id_menu":2,"count":1}]	4273	delivery	5	19
12074	2019-10-28 03:32:47	2019-10-28	9	[{"id_menu":7,"count":1}]	786	pick-up	0	9
12075	2019-10-28 04:46:14	2019-10-28	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	4507	delivery	5	26
12076	2019-10-28 05:16:11	2019-10-28	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	4495	delivery	5	34
12077	2019-10-28 05:31:28	2019-10-28	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	3721	delivery	5	23
12078	2019-10-28 06:12:37	2019-10-28	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2567	delivery	5	40
12079	2019-10-28 06:18:51	2019-10-28	9	[{"id_menu":7,"count":1}]	1889	pick-up	0	9
12080	2019-10-28 06:37:44	2019-10-28	12	[{"id_menu":3,"count":1}]	4494	pick-up	0	12
12081	2019-10-28 07:01:55	2019-10-28	12	[{"id_menu":1,"count":1}]	4102	pick-up	0	12
12082	2019-10-28 07:02:04	2019-10-28	8	[{"id_menu":5,"count":1}]	4503	delivery	5	13
12083	2019-10-28 07:22:38	2019-10-28	12	[{"id_menu":1,"count":1}]	2932	pick-up	0	12
12084	2019-10-28 07:24:52	2019-10-28	14	[{"id_menu":2,"count":1}]	925	delivery	5	19
12085	2019-10-28 07:33:21	2019-10-28	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	4502	delivery	5	31
12086	2019-10-28 07:55:13	2019-10-28	9	[{"id_menu":7,"count":1}]	4477	pick-up	0	9
12087	2019-10-28 08:40:07	2019-10-28	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2571	delivery	5	52
12088	2019-10-28 08:48:42	2019-10-28	12	[{"id_menu":3,"count":1}]	4497	pick-up	0	12
12089	2019-10-28 09:17:34	2019-10-28	9	[{"id_menu":6,"count":1}]	2589	delivery	5	14
12090	2019-10-28 09:35:34	2019-10-28	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4482	delivery	5	39
12091	2019-10-28 09:45:39	2019-10-28	9	[{"id_menu":6,"count":1}]	851	delivery	5	14
12092	2019-10-28 10:04:56	2019-10-28	8	[{"id_menu":5,"count":1}]	4501	pick-up	0	8
12093	2019-10-28 10:21:23	2019-10-28	17	[{"id_menu":4,"count":1}]	2142	pick-up	0	17
12094	2019-10-28 10:54:24	2019-10-28	12	[{"id_menu":3,"count":2}]	4470	delivery	5	17
12095	2019-10-28 11:14:16	2019-10-28	14	[{"id_menu":2,"count":1}]	1673	pick-up	0	14
12096	2019-10-28 11:22:41	2019-10-28	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4506	pick-up	0	31
12097	2019-10-28 11:28:40	2019-10-28	17	[{"id_menu":4,"count":1}]	1302	pick-up	0	17
12098	2019-10-28 11:37:34	2019-10-28	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2759	pick-up	0	26
12099	2019-10-28 11:46:41	2019-10-28	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	4468	delivery	5	25
12100	2019-10-28 11:53:33	2019-10-28	9	[{"id_menu":6,"count":1}]	1070	pick-up	0	9
12101	2019-10-28 11:53:34	2019-10-28	8	[{"id_menu":5,"count":1}]	1114	delivery	5	13
12102	2019-10-28 12:38:30	2019-10-28	9	[{"id_menu":6,"count":2}]	1620	delivery	5	14
12103	2019-10-28 12:48:22	2019-10-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4488	delivery	5	22
12104	2019-10-28 12:48:50	2019-10-28	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1681	pick-up	0	24
12105	2019-10-28 13:06:51	2019-10-28	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3634	pick-up	0	21
12106	2019-10-28 13:08:12	2019-10-28	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1740	delivery	5	36
12107	2019-10-28 13:14:31	2019-10-28	12	[{"id_menu":1,"count":1}]	2168	delivery	5	17
12108	2019-10-28 13:20:54	2019-10-28	37	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4489	delivery	5	42
12109	2019-10-28 13:39:40	2019-10-28	17	[{"id_menu":4,"count":1}]	74	delivery	5	22
12110	2019-10-28 13:53:10	2019-10-28	17	[{"id_menu":4,"count":1}]	3565	delivery	5	22
12111	2019-10-28 14:22:34	2019-10-28	12	[{"id_menu":3,"count":1}]	4496	delivery	5	17
12112	2019-10-28 14:37:22	2019-10-28	9	[{"id_menu":7,"count":1}]	4073	delivery	5	14
12113	2019-10-28 14:42:09	2019-10-28	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4505	delivery	5	37
12114	2019-10-28 15:00:13	2019-10-28	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	4487	delivery	5	25
12115	2019-10-28 15:04:01	2019-10-28	9	[{"id_menu":6,"count":1}]	805	pick-up	0	9
12116	2019-10-28 16:22:47	2019-10-28	17	[{"id_menu":4,"count":1}]	806	delivery	5	22
12117	2019-10-28 16:39:44	2019-10-28	17	[{"id_menu":4,"count":1}]	170	delivery	5	22
12118	2019-10-28 17:22:03	2019-10-28	12	[{"id_menu":3,"count":1}]	1393	delivery	5	17
12119	2019-10-28 17:25:07	2019-10-28	17	[{"id_menu":4,"count":1}]	177	delivery	5	22
12120	2019-10-28 17:49:57	2019-10-28	17	[{"id_menu":4,"count":1}]	764	delivery	5	22
12121	2019-10-28 18:14:33	2019-10-28	17	[{"id_menu":4,"count":1}]	3507	pick-up	0	17
12122	2019-10-28 18:27:12	2019-10-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3540	delivery	5	23
12123	2019-10-28 19:28:31	2019-10-28	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4498	delivery	5	36
12124	2019-10-28 19:37:15	2019-10-28	9	[{"id_menu":6,"count":1}]	2602	pick-up	0	9
12125	2019-10-28 19:55:09	2019-10-28	12	[{"id_menu":1,"count":1}]	1929	delivery	5	17
12126	2019-10-28 19:55:48	2019-10-28	12	[{"id_menu":3,"count":1}]	4473	delivery	5	17
12127	2019-10-28 19:56:04	2019-10-28	9	[{"id_menu":7,"count":1}]	281	pick-up	0	9
12128	2019-10-28 20:01:38	2019-10-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4509	delivery	5	22
12129	2019-10-28 20:29:29	2019-10-28	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2000	pick-up	0	26
12130	2019-10-28 20:31:24	2019-10-28	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	4478	delivery	5	25
12131	2019-10-28 20:51:29	2019-10-28	9	[{"id_menu":6,"count":1}]	1541	pick-up	0	9
12132	2019-10-28 21:51:24	2019-10-28	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4258	delivery	5	43
12133	2019-10-28 21:52:56	2019-10-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4469	delivery	5	31
12134	2019-10-28 22:07:12	2019-10-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	358	pick-up	0	17
12135	2019-10-28 22:29:45	2019-10-28	8	[{"id_menu":5,"count":1}]	3406	delivery	5	13
12136	2019-10-28 22:40:16	2019-10-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2962	pick-up	0	17
12137	2019-10-28 22:46:49	2019-10-28	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	3853	delivery	5	34
12138	2019-10-29 00:50:35	2019-10-29	9	[{"id_menu":6,"count":1}]	1967	pick-up	0	9
12139	2019-10-29 00:59:52	2019-10-29	14	[{"id_menu":2,"count":2}]	4525	delivery	5	19
12140	2019-10-29 01:15:44	2019-10-29	9	[{"id_menu":7,"count":1}]	4270	pick-up	0	9
12141	2019-10-29 01:16:36	2019-10-29	8	[{"id_menu":5,"count":1}]	3324	pick-up	0	8
12142	2019-10-29 01:45:58	2019-10-29	8	[{"id_menu":5,"count":1}]	2029	delivery	5	13
12143	2019-10-29 02:36:33	2019-10-29	14	[{"id_menu":2,"count":1}]	2766	delivery	5	19
12144	2019-10-29 02:39:07	2019-10-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2310	delivery	5	28
12145	2019-10-29 03:15:55	2019-10-29	8	[{"id_menu":5,"count":1}]	2827	pick-up	0	8
12146	2019-10-29 03:29:23	2019-10-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4533	delivery	5	31
12147	2019-10-29 03:56:23	2019-10-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4541	delivery	5	27
12148	2019-10-29 03:57:28	2019-10-29	17	[{"id_menu":4,"count":1}]	3214	pick-up	0	17
12149	2019-10-29 04:09:05	2019-10-29	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2776	delivery	5	49
12150	2019-10-29 04:29:15	2019-10-29	9	[{"id_menu":6,"count":1}]	4521	delivery	5	14
12151	2019-10-29 04:53:18	2019-10-29	17	[{"id_menu":4,"count":1}]	3557	delivery	5	22
12152	2019-10-29 05:18:13	2019-10-29	12	[{"id_menu":3,"count":1}]	639	delivery	5	17
12153	2019-10-29 05:19:01	2019-10-29	12	[{"id_menu":1,"count":1}]	2273	delivery	5	17
12154	2019-10-29 05:37:21	2019-10-29	9	[{"id_menu":7,"count":1}]	3115	delivery	5	14
12155	2019-10-29 05:38:20	2019-10-29	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	4537	delivery	5	25
12156	2019-10-29 05:49:37	2019-10-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	1023	delivery	5	27
12157	2019-10-29 06:02:11	2019-10-29	17	[{"id_menu":4,"count":1}]	4101	pick-up	0	17
12158	2019-10-29 06:06:48	2019-10-29	12	[{"id_menu":1,"count":1}]	525	delivery	5	17
12159	2019-10-29 07:27:49	2019-10-29	9	[{"id_menu":6,"count":1}]	4518	delivery	5	14
12160	2019-10-29 07:45:42	2019-10-29	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4544	delivery	5	43
12161	2019-10-29 08:04:28	2019-10-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1742	pick-up	0	17
12162	2019-10-29 08:10:17	2019-10-29	9	[{"id_menu":6,"count":1}]	4350	pick-up	0	9
12163	2019-10-29 08:21:19	2019-10-29	12	[{"id_menu":3,"count":1}]	1663	delivery	5	17
12164	2019-10-29 08:39:32	2019-10-29	8	[{"id_menu":5,"count":1}]	1072	delivery	5	13
12165	2019-10-29 09:08:18	2019-10-29	14	[{"id_menu":2,"count":1}]	3539	delivery	5	19
12166	2019-10-29 09:16:21	2019-10-29	14	[{"id_menu":2,"count":1}]	213	pick-up	0	14
12167	2019-10-29 09:17:03	2019-10-29	17	[{"id_menu":4,"count":1}]	338	pick-up	0	17
12168	2019-10-29 09:20:45	2019-10-29	17	[{"id_menu":4,"count":1}]	748	delivery	5	22
12169	2019-10-29 09:50:05	2019-10-29	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	4517	delivery	5	34
12170	2019-10-29 10:58:02	2019-10-29	14	[{"id_menu":2,"count":1}]	1829	pick-up	0	14
12171	2019-10-29 11:23:06	2019-10-29	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	802	pick-up	0	26
12172	2019-10-29 11:43:21	2019-10-29	14	[{"id_menu":2,"count":1}]	2931	delivery	5	19
12173	2019-10-29 11:52:14	2019-10-29	8	[{"id_menu":5,"count":1}]	3467	delivery	5	13
12174	2019-10-29 12:06:42	2019-10-29	12	[{"id_menu":1,"count":1}]	4524	pick-up	0	12
12175	2019-10-29 12:49:58	2019-10-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	766	pick-up	0	21
12176	2019-10-29 12:53:31	2019-10-29	9	[{"id_menu":7,"count":1}]	4530	delivery	5	14
12177	2019-10-29 12:58:13	2019-10-29	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4523	delivery	5	40
12178	2019-10-29 13:52:27	2019-10-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2867	pick-up	0	21
12179	2019-10-29 13:59:38	2019-10-29	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	3160	pick-up	0	21
12180	2019-10-29 14:15:01	2019-10-29	8	[{"id_menu":5,"count":1}]	4529	delivery	5	13
12181	2019-10-29 14:21:55	2019-10-29	9	[{"id_menu":7,"count":1}]	4527	delivery	5	14
12182	2019-10-29 14:56:38	2019-10-29	12	[{"id_menu":3,"count":1}]	3034	pick-up	0	12
12183	2019-10-29 15:35:30	2019-10-29	12	[{"id_menu":1,"count":1}]	4511	delivery	5	17
12184	2019-10-29 15:39:24	2019-10-29	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	4364	delivery	5	25
12185	2019-10-29 15:41:25	2019-10-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	4510	delivery	5	26
12186	2019-10-29 16:58:03	2019-10-29	9	[{"id_menu":7,"count":2}]	441	delivery	5	14
12187	2019-10-29 17:44:06	2019-10-29	17	[{"id_menu":4,"count":2}]	4212	delivery	5	22
12188	2019-10-29 17:47:00	2019-10-29	14	[{"id_menu":2,"count":1}]	4512	pick-up	0	14
12189	2019-10-29 18:00:50	2019-10-29	12	[{"id_menu":3,"count":1}]	790	delivery	5	17
12190	2019-10-29 18:39:09	2019-10-29	12	[{"id_menu":1,"count":1}]	3647	delivery	5	17
12191	2019-10-29 18:54:21	2019-10-29	9	[{"id_menu":7,"count":1}]	153	pick-up	0	9
12192	2019-10-29 18:54:52	2019-10-29	9	[{"id_menu":6,"count":1}]	1446	pick-up	0	9
12193	2019-10-29 19:21:12	2019-10-29	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4542	delivery	5	51
12194	2019-10-29 19:38:47	2019-10-29	8	[{"id_menu":5,"count":1}]	105	pick-up	0	8
12195	2019-10-29 19:53:23	2019-10-29	12	[{"id_menu":1,"count":1}]	1029	pick-up	0	12
12196	2019-10-29 20:08:10	2019-10-29	9	[{"id_menu":7,"count":1}]	1145	pick-up	0	9
12197	2019-10-29 20:32:30	2019-10-29	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	3896	pick-up	0	20
12198	2019-10-29 20:44:28	2019-10-29	9	[{"id_menu":6,"count":1}]	4539	delivery	5	14
12199	2019-10-29 20:48:24	2019-10-29	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	4514	delivery	5	23
12200	2019-10-29 20:51:43	2019-10-29	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1306	pick-up	0	20
12201	2019-10-29 21:20:23	2019-10-29	14	[{"id_menu":2,"count":1}]	2523	pick-up	0	14
12202	2019-10-29 21:24:21	2019-10-29	17	[{"id_menu":4,"count":1}]	2638	delivery	5	22
12203	2019-10-29 21:43:34	2019-10-29	12	[{"id_menu":3,"count":1}]	4540	delivery	5	17
12204	2019-10-29 22:00:38	2019-10-29	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1191	pick-up	0	26
12205	2019-10-29 22:55:43	2019-10-29	12	[{"id_menu":1,"count":1}]	3745	pick-up	0	12
12206	2019-10-29 23:04:10	2019-10-29	12	[{"id_menu":1,"count":1}]	1592	delivery	5	17
12207	2019-10-29 23:41:21	2019-10-29	9	[{"id_menu":6,"count":1}]	3478	delivery	5	14
12208	2019-10-29 23:44:56	2019-10-29	9	[{"id_menu":6,"count":2}]	4526	pick-up	0	9
12209	2019-10-30 00:07:12	2019-10-30	9	[{"id_menu":7,"count":1}]	459	delivery	5	14
12210	2019-10-30 00:14:02	2019-10-30	8	[{"id_menu":5,"count":1}]	89	pick-up	0	8
12211	2019-10-30 00:19:21	2019-10-30	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	4558	delivery	5	37
12212	2019-10-30 00:19:55	2019-10-30	12	[{"id_menu":3,"count":2}]	4562	delivery	5	17
12213	2019-10-30 00:21:01	2019-10-30	9	[{"id_menu":6,"count":1}]	4591	delivery	5	14
12214	2019-10-30 00:36:42	2019-10-30	9	[{"id_menu":6,"count":1}]	1529	delivery	5	14
12215	2019-10-30 00:49:31	2019-10-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4589	delivery	5	28
12216	2019-10-30 00:53:37	2019-10-30	14	[{"id_menu":2,"count":1}]	2593	pick-up	0	14
12217	2019-10-30 00:58:59	2019-10-30	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	467	pick-up	0	29
12218	2019-10-30 01:14:13	2019-10-30	9	[{"id_menu":7,"count":1}]	4551	delivery	5	14
12219	2019-10-30 01:19:28	2019-10-30	9	[{"id_menu":7,"count":1}]	2570	pick-up	0	9
12220	2019-10-30 01:32:25	2019-10-30	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	4365	pick-up	0	31
12221	2019-10-30 01:34:14	2019-10-30	14	[{"id_menu":2,"count":1}]	2029	delivery	5	19
12222	2019-10-30 01:35:55	2019-10-30	9	[{"id_menu":6,"count":1}]	3826	delivery	5	14
12223	2019-10-30 01:51:10	2019-10-30	17	[{"id_menu":4,"count":1}]	4590	pick-up	0	17
12224	2019-10-30 01:59:09	2019-10-30	12	[{"id_menu":1,"count":1}]	2447	delivery	5	17
12225	2019-10-30 02:33:02	2019-10-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4587	delivery	5	31
12226	2019-10-30 02:33:07	2019-10-30	9	[{"id_menu":6,"count":1}]	3156	delivery	5	14
12227	2019-10-30 02:45:46	2019-10-30	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	4557	delivery	5	34
12228	2019-10-30 03:12:23	2019-10-30	12	[{"id_menu":1,"count":1}]	3363	pick-up	0	12
12229	2019-10-30 03:26:41	2019-10-30	9	[{"id_menu":7,"count":1}]	4559	delivery	5	14
12230	2019-10-30 03:38:26	2019-10-30	14	[{"id_menu":2,"count":1}]	729	pick-up	0	14
12231	2019-10-30 03:38:30	2019-10-30	12	[{"id_menu":1,"count":1}]	2916	pick-up	0	12
12232	2019-10-30 03:43:56	2019-10-30	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3527	delivery	5	30
12233	2019-10-30 04:09:26	2019-10-30	12	[{"id_menu":3,"count":1}]	4584	delivery	5	17
12234	2019-10-30 04:19:35	2019-10-30	8	[{"id_menu":5,"count":1}]	4567	delivery	5	13
12235	2019-10-30 04:27:28	2019-10-30	12	[{"id_menu":3,"count":1}]	1728	delivery	5	17
12236	2019-10-30 04:28:15	2019-10-30	17	[{"id_menu":4,"count":1}]	4546	pick-up	0	17
12237	2019-10-30 04:34:08	2019-10-30	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	4552	pick-up	0	21
12238	2019-10-30 04:49:57	2019-10-30	8	[{"id_menu":5,"count":1}]	3297	delivery	5	13
12239	2019-10-30 05:02:48	2019-10-30	9	[{"id_menu":7,"count":1}]	1026	pick-up	0	9
12240	2019-10-30 05:11:27	2019-10-30	14	[{"id_menu":2,"count":2}]	4585	pick-up	0	14
12241	2019-10-30 05:28:06	2019-10-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1615	pick-up	0	23
12242	2019-10-30 05:39:12	2019-10-30	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	4582	delivery	5	26
12243	2019-10-30 05:55:10	2019-10-30	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4577	pick-up	0	43
12244	2019-10-30 05:56:19	2019-10-30	17	[{"id_menu":4,"count":1}]	1900	pick-up	0	17
12245	2019-10-30 06:10:07	2019-10-30	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	4574	delivery	5	31
12246	2019-10-30 06:19:37	2019-10-30	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1840	delivery	5	26
12247	2019-10-30 06:27:52	2019-10-30	9	[{"id_menu":7,"count":1}]	4575	delivery	5	14
12248	2019-10-30 07:05:07	2019-10-30	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1138	pick-up	0	31
12249	2019-10-30 07:29:23	2019-10-30	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3537	delivery	5	43
12250	2019-10-30 07:43:20	2019-10-30	8	[{"id_menu":5,"count":1}]	4592	delivery	5	13
12251	2019-10-30 07:47:12	2019-10-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4580	delivery	5	31
12252	2019-10-30 07:53:27	2019-10-30	8	[{"id_menu":5,"count":1}]	4549	delivery	5	13
12253	2019-10-30 07:59:29	2019-10-30	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1645	delivery	5	40
12254	2019-10-30 07:59:32	2019-10-30	9	[{"id_menu":7,"count":1}]	4572	delivery	5	14
12255	2019-10-30 08:09:48	2019-10-30	17	[{"id_menu":4,"count":1}]	2418	pick-up	0	17
12256	2019-10-30 08:13:00	2019-10-30	9	[{"id_menu":7,"count":1}]	4550	pick-up	0	9
12257	2019-10-30 08:34:57	2019-10-30	9	[{"id_menu":6,"count":1}]	3478	pick-up	0	9
12258	2019-10-30 09:02:26	2019-10-30	8	[{"id_menu":5,"count":1}]	4081	pick-up	0	8
12259	2019-10-30 09:23:20	2019-10-30	12	[{"id_menu":3,"count":1}]	2496	pick-up	0	12
12260	2019-10-30 09:24:03	2019-10-30	17	[{"id_menu":4,"count":1}]	3012	pick-up	0	17
12261	2019-10-30 09:40:21	2019-10-30	14	[{"id_menu":2,"count":1}]	1481	pick-up	0	14
12262	2019-10-30 10:19:38	2019-10-30	12	[{"id_menu":1,"count":1}]	3959	delivery	5	17
12263	2019-10-30 10:23:31	2019-10-30	12	[{"id_menu":3,"count":2}]	2461	delivery	5	17
12264	2019-10-30 10:30:34	2019-10-30	9	[{"id_menu":6,"count":2}]	3673	delivery	5	14
12265	2019-10-30 10:54:44	2019-10-30	9	[{"id_menu":7,"count":1}]	178	pick-up	0	9
12266	2019-10-30 11:10:06	2019-10-30	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4555	delivery	5	34
12267	2019-10-30 11:16:19	2019-10-30	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	4411	delivery	5	43
12268	2019-10-30 11:25:52	2019-10-30	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1406	delivery	5	25
12269	2019-10-30 11:32:57	2019-10-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2050	pick-up	0	26
12270	2019-10-30 12:04:19	2019-10-30	8	[{"id_menu":5,"count":1}]	286	pick-up	0	8
12271	2019-10-30 12:16:36	2019-10-30	9	[{"id_menu":6,"count":1}]	71	pick-up	0	9
12272	2019-10-30 12:18:12	2019-10-30	8	[{"id_menu":5,"count":1}]	4451	pick-up	0	8
12273	2019-10-30 13:04:04	2019-10-30	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2123	pick-up	0	29
12274	2019-10-30 13:07:17	2019-10-30	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	4571	delivery	5	25
12275	2019-10-30 13:24:36	2019-10-30	8	[{"id_menu":5,"count":1}]	177	pick-up	0	8
12276	2019-10-30 13:29:00	2019-10-30	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4287	delivery	5	46
12277	2019-10-30 14:12:56	2019-10-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4561	delivery	5	27
12278	2019-10-30 14:34:23	2019-10-30	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	4563	delivery	5	44
12279	2019-10-30 14:39:50	2019-10-30	12	[{"id_menu":1,"count":1}]	4132	pick-up	0	12
12280	2019-10-30 14:43:00	2019-10-30	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	4547	delivery	5	28
12281	2019-10-30 14:52:39	2019-10-30	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	4553	delivery	5	25
12282	2019-10-30 15:16:13	2019-10-30	9	[{"id_menu":6,"count":1}]	3130	pick-up	0	9
12283	2019-10-30 15:23:56	2019-10-30	12	[{"id_menu":3,"count":1}]	4565	delivery	5	17
12284	2019-10-30 15:53:26	2019-10-30	8	[{"id_menu":5,"count":1}]	1685	delivery	5	13
12285	2019-10-30 15:58:35	2019-10-30	12	[{"id_menu":1,"count":1}]	593	pick-up	0	12
12286	2019-10-30 16:05:52	2019-10-30	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4573	delivery	5	40
12287	2019-10-30 17:00:42	2019-10-30	17	[{"id_menu":4,"count":1}]	4583	pick-up	0	17
12288	2019-10-30 17:05:36	2019-10-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1376	pick-up	0	26
12289	2019-10-30 17:35:08	2019-10-30	9	[{"id_menu":7,"count":1}]	2815	pick-up	0	9
12290	2019-10-30 17:37:16	2019-10-30	12	[{"id_menu":3,"count":1}]	1897	delivery	5	17
12291	2019-10-30 17:40:32	2019-10-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	798	pick-up	0	17
12292	2019-10-30 18:04:08	2019-10-30	12	[{"id_menu":3,"count":1}]	4352	pick-up	0	12
12293	2019-10-30 18:13:52	2019-10-30	8	[{"id_menu":5,"count":1}]	4566	pick-up	0	8
12294	2019-10-30 18:21:16	2019-10-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	4578	pick-up	0	17
12295	2019-10-30 18:28:13	2019-10-30	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1269	pick-up	0	26
12296	2019-10-30 18:34:22	2019-10-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1272	delivery	5	31
12297	2019-10-30 18:38:20	2019-10-30	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	2184	pick-up	0	23
12298	2019-10-30 18:47:03	2019-10-30	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	4556	delivery	5	39
12299	2019-10-30 18:51:59	2019-10-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1337	pick-up	0	26
12300	2019-10-30 19:11:12	2019-10-30	9	[{"id_menu":6,"count":1}]	1468	delivery	5	14
12301	2019-10-30 19:37:44	2019-10-30	8	[{"id_menu":5,"count":1}]	2752	pick-up	0	8
12302	2019-10-30 19:43:39	2019-10-30	9	[{"id_menu":7,"count":1}]	4569	delivery	5	14
12303	2019-10-30 19:47:13	2019-10-30	14	[{"id_menu":2,"count":1}]	1379	delivery	5	19
12304	2019-10-30 19:58:01	2019-10-30	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4586	delivery	5	36
12305	2019-10-30 20:21:55	2019-10-30	12	[{"id_menu":1,"count":1}]	1486	pick-up	0	12
12306	2019-10-30 20:26:41	2019-10-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1813	delivery	5	28
12307	2019-10-30 20:32:49	2019-10-30	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	223	delivery	5	30
12308	2019-10-30 20:34:16	2019-10-30	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4548	delivery	5	44
12309	2019-10-30 20:53:42	2019-10-30	14	[{"id_menu":2,"count":1}]	3157	pick-up	0	14
12310	2019-10-30 20:54:32	2019-10-30	17	[{"id_menu":4,"count":1}]	2651	pick-up	0	17
12311	2019-10-30 21:07:33	2019-10-30	9	[{"id_menu":6,"count":1}]	399	pick-up	0	9
12312	2019-10-30 21:25:43	2019-10-30	9	[{"id_menu":6,"count":1}]	2082	pick-up	0	9
12313	2019-10-30 21:42:19	2019-10-30	12	[{"id_menu":3,"count":1}]	4564	delivery	5	17
12314	2019-10-30 21:49:20	2019-10-30	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	3372	delivery	5	31
12315	2019-10-30 21:56:59	2019-10-30	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2799	pick-up	0	31
12316	2019-10-30 22:03:43	2019-10-30	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1820	pick-up	0	43
12317	2019-10-30 22:35:41	2019-10-30	14	[{"id_menu":2,"count":1}]	1885	delivery	5	19
12318	2019-10-30 22:37:37	2019-10-30	8	[{"id_menu":5,"count":1}]	3173	delivery	5	13
12319	2019-10-30 23:08:16	2019-10-30	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1273	pick-up	0	34
12320	2019-10-30 23:37:39	2019-10-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	916	delivery	5	31
12321	2019-10-30 23:53:03	2019-10-30	17	[{"id_menu":4,"count":2}]	1184	pick-up	0	17
12322	2019-10-31 00:11:13	2019-10-31	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2140	pick-up	0	25
12323	2019-10-31 00:11:41	2019-10-31	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2160	delivery	5	27
12324	2019-10-31 00:15:46	2019-10-31	9	[{"id_menu":7,"count":1}]	1953	delivery	5	14
12325	2019-10-31 00:29:48	2019-10-31	12	[{"id_menu":3,"count":1}]	118	pick-up	0	12
12326	2019-10-31 00:41:53	2019-10-31	8	[{"id_menu":5,"count":1}]	1745	pick-up	0	8
12327	2019-10-31 00:50:19	2019-10-31	9	[{"id_menu":7,"count":1}]	3759	delivery	5	14
12328	2019-10-31 00:58:48	2019-10-31	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":3}]	4619	delivery	5	26
12329	2019-10-31 01:28:06	2019-10-31	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	4594	delivery	5	45
12330	2019-10-31 01:42:07	2019-10-31	17	[{"id_menu":4,"count":1}]	153	pick-up	0	17
12331	2019-10-31 01:51:34	2019-10-31	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	1167	delivery	5	35
12332	2019-10-31 02:46:22	2019-10-31	9	[{"id_menu":6,"count":1}]	4601	delivery	5	14
12333	2019-10-31 02:57:39	2019-10-31	9	[{"id_menu":6,"count":1}]	4145	delivery	5	14
12334	2019-10-31 03:21:00	2019-10-31	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	4631	delivery	5	40
12335	2019-10-31 03:40:57	2019-10-31	17	[{"id_menu":4,"count":1}]	4624	pick-up	0	17
12336	2019-10-31 03:41:36	2019-10-31	9	[{"id_menu":7,"count":1}]	4599	delivery	5	14
12337	2019-10-31 03:42:51	2019-10-31	12	[{"id_menu":1,"count":1}]	802	delivery	5	17
12338	2019-10-31 03:42:54	2019-10-31	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	3123	pick-up	0	29
12339	2019-10-31 03:45:42	2019-10-31	17	[{"id_menu":4,"count":1}]	111	pick-up	0	17
12340	2019-10-31 03:48:04	2019-10-31	9	[{"id_menu":7,"count":1}]	3988	delivery	5	14
12341	2019-10-31 03:53:01	2019-10-31	8	[{"id_menu":5,"count":1}]	4378	delivery	5	13
12342	2019-10-31 04:00:07	2019-10-31	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3745	pick-up	0	26
12343	2019-10-31 04:01:38	2019-10-31	14	[{"id_menu":2,"count":1}]	4617	pick-up	0	14
12344	2019-10-31 04:49:20	2019-10-31	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	4635	pick-up	0	24
12345	2019-10-31 05:01:58	2019-10-31	14	[{"id_menu":2,"count":1}]	926	delivery	5	19
12346	2019-10-31 05:05:17	2019-10-31	9	[{"id_menu":7,"count":1}]	3848	delivery	5	14
12347	2019-10-31 05:10:30	2019-10-31	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1447	delivery	5	51
12348	2019-10-31 05:22:06	2019-10-31	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	4614	delivery	5	26
12349	2019-10-31 05:26:26	2019-10-31	9	[{"id_menu":6,"count":2}]	2659	pick-up	0	9
12350	2019-10-31 05:36:32	2019-10-31	17	[{"id_menu":4,"count":1}]	707	delivery	5	22
12351	2019-10-31 05:38:47	2019-10-31	12	[{"id_menu":3,"count":1}]	3372	pick-up	0	12
12352	2019-10-31 05:39:27	2019-10-31	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	681	delivery	5	39
12353	2019-10-31 05:54:11	2019-10-31	8	[{"id_menu":5,"count":1}]	4618	delivery	5	13
12354	2019-10-31 06:17:12	2019-10-31	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	4636	delivery	5	31
12355	2019-10-31 06:27:17	2019-10-31	12	[{"id_menu":3,"count":1}]	2847	delivery	5	17
12356	2019-10-31 06:29:36	2019-10-31	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4339	delivery	5	22
12357	2019-10-31 06:29:38	2019-10-31	12	[{"id_menu":3,"count":1}]	2615	pick-up	0	12
12358	2019-10-31 06:32:36	2019-10-31	17	[{"id_menu":4,"count":1}]	2761	delivery	5	22
12359	2019-10-31 06:39:02	2019-10-31	8	[{"id_menu":5,"count":1}]	477	pick-up	0	8
12360	2019-10-31 06:42:04	2019-10-31	14	[{"id_menu":2,"count":1}]	2309	delivery	5	19
12361	2019-10-31 06:47:12	2019-10-31	9	[{"id_menu":7,"count":1}]	236	pick-up	0	9
12362	2019-10-31 06:47:30	2019-10-31	12	[{"id_menu":1,"count":1}]	541	pick-up	0	12
12363	2019-10-31 06:49:45	2019-10-31	8	[{"id_menu":5,"count":1}]	3382	delivery	5	13
12364	2019-10-31 06:51:07	2019-10-31	8	[{"id_menu":5,"count":1}]	4608	delivery	5	13
12365	2019-10-31 06:51:24	2019-10-31	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	4595	delivery	5	26
12366	2019-10-31 07:02:53	2019-10-31	17	[{"id_menu":4,"count":1}]	4606	delivery	5	22
12367	2019-10-31 07:05:07	2019-10-31	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	654	delivery	5	31
12368	2019-10-31 07:24:00	2019-10-31	14	[{"id_menu":2,"count":1}]	877	pick-up	0	14
12369	2019-10-31 07:30:44	2019-10-31	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4600	pick-up	0	17
12370	2019-10-31 08:00:22	2019-10-31	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	4622	delivery	5	25
12371	2019-10-31 08:04:55	2019-10-31	23	[{"id_menu":2,"count":3},{"id_menu":7,"count":1}]	4146	pick-up	0	23
12372	2019-10-31 08:12:41	2019-10-31	8	[{"id_menu":5,"count":1}]	3306	delivery	5	13
12373	2019-10-31 08:13:59	2019-10-31	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2748	pick-up	0	26
12374	2019-10-31 08:22:07	2019-10-31	17	[{"id_menu":4,"count":1}]	3711	delivery	5	22
12375	2019-10-31 08:35:08	2019-10-31	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	4607	delivery	5	31
12376	2019-10-31 08:38:51	2019-10-31	9	[{"id_menu":6,"count":1}]	4625	delivery	5	14
12377	2019-10-31 09:11:54	2019-10-31	12	[{"id_menu":1,"count":1}]	3688	delivery	5	17
12378	2019-10-31 09:20:07	2019-10-31	9	[{"id_menu":7,"count":1}]	3077	delivery	5	14
12379	2019-10-31 09:21:03	2019-10-31	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3540	delivery	5	31
12380	2019-10-31 09:24:55	2019-10-31	9	[{"id_menu":7,"count":1}]	4602	delivery	5	14
12381	2019-10-31 09:27:59	2019-10-31	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4613	pick-up	0	29
12382	2019-10-31 09:43:20	2019-10-31	9	[{"id_menu":6,"count":1}]	2651	pick-up	0	9
12383	2019-10-31 10:12:39	2019-10-31	8	[{"id_menu":5,"count":1}]	1266	delivery	5	13
12384	2019-10-31 10:16:48	2019-10-31	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	4629	pick-up	0	26
12385	2019-10-31 10:46:09	2019-10-31	14	[{"id_menu":2,"count":1}]	697	delivery	5	19
12386	2019-10-31 11:09:05	2019-10-31	14	[{"id_menu":2,"count":1}]	2056	pick-up	0	14
12387	2019-10-31 11:20:28	2019-10-31	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2783	delivery	5	31
12388	2019-10-31 11:31:23	2019-10-31	9	[{"id_menu":6,"count":2}]	2225	delivery	5	14
12389	2019-10-31 11:35:22	2019-10-31	12	[{"id_menu":1,"count":1}]	1684	delivery	5	17
12390	2019-10-31 12:09:29	2019-10-31	12	[{"id_menu":1,"count":1}]	2706	pick-up	0	12
12391	2019-10-31 12:29:00	2019-10-31	9	[{"id_menu":7,"count":1}]	1402	pick-up	0	9
12392	2019-10-31 12:39:13	2019-10-31	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	4605	delivery	5	40
12393	2019-10-31 12:44:42	2019-10-31	9	[{"id_menu":6,"count":1}]	510	delivery	5	14
12394	2019-10-31 13:13:23	2019-10-31	12	[{"id_menu":1,"count":1}]	3052	pick-up	0	12
12395	2019-10-31 13:14:41	2019-10-31	8	[{"id_menu":5,"count":1}]	1258	pick-up	0	8
12396	2019-10-31 13:16:31	2019-10-31	9	[{"id_menu":6,"count":1}]	2590	pick-up	0	9
12397	2019-10-31 13:23:39	2019-10-31	14	[{"id_menu":2,"count":2}]	1456	delivery	5	19
12398	2019-10-31 13:29:37	2019-10-31	17	[{"id_menu":4,"count":1}]	3332	pick-up	0	17
12399	2019-10-31 14:04:43	2019-10-31	9	[{"id_menu":7,"count":1}]	4597	pick-up	0	9
12400	2019-10-31 14:20:52	2019-10-31	14	[{"id_menu":2,"count":1}]	1819	pick-up	0	14
12401	2019-10-31 14:35:06	2019-10-31	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	401	pick-up	0	35
12402	2019-10-31 14:36:01	2019-10-31	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1893	pick-up	0	26
12403	2019-10-31 15:30:03	2019-10-31	21	[{"id_menu":1,"count":3},{"id_menu":6,"count":1}]	3393	delivery	5	26
12404	2019-10-31 15:40:57	2019-10-31	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	4632	delivery	5	39
12405	2019-10-31 15:43:43	2019-10-31	9	[{"id_menu":6,"count":1}]	2067	delivery	5	14
12406	2019-10-31 16:01:21	2019-10-31	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1696	pick-up	0	17
12407	2019-10-31 16:13:06	2019-10-31	8	[{"id_menu":5,"count":1}]	4596	pick-up	0	8
12408	2019-10-31 16:14:48	2019-10-31	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4598	delivery	5	39
12409	2019-10-31 16:23:12	2019-10-31	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4621	delivery	5	52
12410	2019-10-31 16:36:48	2019-10-31	12	[{"id_menu":1,"count":1}]	4615	delivery	5	17
12411	2019-10-31 16:47:00	2019-10-31	12	[{"id_menu":3,"count":1}]	801	pick-up	0	12
12412	2019-10-31 17:07:31	2019-10-31	9	[{"id_menu":7,"count":1}]	203	delivery	5	14
12413	2019-10-31 17:16:47	2019-10-31	9	[{"id_menu":7,"count":1}]	4616	delivery	5	14
12414	2019-10-31 17:21:11	2019-10-31	9	[{"id_menu":7,"count":1}]	2619	pick-up	0	9
12415	2019-10-31 17:32:08	2019-10-31	14	[{"id_menu":2,"count":1}]	4603	delivery	5	19
12416	2019-10-31 17:33:49	2019-10-31	14	[{"id_menu":2,"count":1}]	4198	pick-up	0	14
12417	2019-10-31 17:40:23	2019-10-31	14	[{"id_menu":2,"count":1}]	2477	pick-up	0	14
12418	2019-10-31 17:43:45	2019-10-31	17	[{"id_menu":4,"count":1}]	868	pick-up	0	17
12419	2019-10-31 17:52:40	2019-10-31	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	197	delivery	5	34
12420	2019-10-31 17:53:36	2019-10-31	12	[{"id_menu":3,"count":1}]	3825	pick-up	0	12
12421	2019-10-31 18:32:52	2019-10-31	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	227	delivery	5	28
12422	2019-10-31 18:41:37	2019-10-31	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	3887	delivery	5	22
12423	2019-10-31 19:21:21	2019-10-31	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4612	delivery	5	51
12424	2019-10-31 19:38:33	2019-10-31	8	[{"id_menu":5,"count":1}]	4620	delivery	5	13
12425	2019-10-31 19:53:16	2019-10-31	9	[{"id_menu":6,"count":1}]	2956	delivery	5	14
12426	2019-10-31 20:28:09	2019-10-31	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1811	pick-up	0	24
12427	2019-10-31 20:32:21	2019-10-31	17	[{"id_menu":4,"count":1}]	4628	pick-up	0	17
12428	2019-10-31 21:00:52	2019-10-31	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4609	pick-up	0	34
12429	2019-10-31 21:14:30	2019-10-31	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3754	pick-up	0	38
12430	2019-10-31 21:29:19	2019-10-31	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":3}]	4224	delivery	5	31
12431	2019-10-31 22:02:27	2019-10-31	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	748	delivery	5	28
12432	2019-10-31 22:05:31	2019-10-31	9	[{"id_menu":7,"count":1}]	2366	delivery	5	14
12433	2019-10-31 22:11:24	2019-10-31	12	[{"id_menu":3,"count":1}]	29	pick-up	0	12
12434	2019-10-31 22:40:56	2019-10-31	9	[{"id_menu":7,"count":1}]	4626	pick-up	0	9
12435	2019-10-31 22:50:18	2019-10-31	9	[{"id_menu":6,"count":1}]	2674	delivery	5	14
12436	2019-10-31 22:58:30	2019-10-31	12	[{"id_menu":1,"count":1}]	4634	pick-up	0	12
12437	2019-10-31 23:16:23	2019-10-31	14	[{"id_menu":2,"count":1}]	638	pick-up	0	14
12438	2019-10-31 23:22:45	2019-10-31	14	[{"id_menu":2,"count":1}]	1490	pick-up	0	14
12439	2019-10-31 23:24:00	2019-10-31	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1587	delivery	5	28
12440	2019-10-31 23:28:08	2019-10-31	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	997	pick-up	0	43
12441	2019-10-31 23:34:18	2019-10-31	12	[{"id_menu":3,"count":1}]	4611	pick-up	0	12
12442	2019-11-01 00:01:03	2019-11-01	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	931	delivery	5	26
12443	2019-11-01 01:06:18	2019-11-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1927	delivery	5	26
12444	2019-11-01 01:08:42	2019-11-01	9	[{"id_menu":6,"count":1}]	4657	delivery	5	14
12445	2019-11-01 01:10:15	2019-11-01	12	[{"id_menu":3,"count":1}]	966	pick-up	0	12
12446	2019-11-01 01:15:16	2019-11-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	252	delivery	5	31
12447	2019-11-01 01:25:34	2019-11-01	9	[{"id_menu":7,"count":1}]	3679	delivery	5	14
12448	2019-11-01 01:25:47	2019-11-01	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4509	delivery	5	45
12449	2019-11-01 01:32:57	2019-11-01	14	[{"id_menu":2,"count":1}]	829	pick-up	0	14
12450	2019-11-01 01:36:39	2019-11-01	12	[{"id_menu":1,"count":1}]	4647	pick-up	0	12
12451	2019-11-01 01:44:01	2019-11-01	9	[{"id_menu":6,"count":1}]	3000	pick-up	0	9
12452	2019-11-01 02:15:13	2019-11-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	4459	delivery	5	26
12453	2019-11-01 02:36:11	2019-11-01	9	[{"id_menu":7,"count":1}]	1970	delivery	5	14
12454	2019-11-01 02:38:39	2019-11-01	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3956	delivery	5	27
12455	2019-11-01 02:40:21	2019-11-01	9	[{"id_menu":7,"count":1}]	4265	delivery	5	14
12456	2019-11-01 03:00:33	2019-11-01	9	[{"id_menu":7,"count":1}]	2041	pick-up	0	9
12457	2019-11-01 03:12:03	2019-11-01	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":3}]	1390	pick-up	0	26
12458	2019-11-01 03:15:17	2019-11-01	12	[{"id_menu":3,"count":1}]	2415	pick-up	0	12
12459	2019-11-01 03:26:31	2019-11-01	17	[{"id_menu":4,"count":1}]	309	delivery	5	22
12460	2019-11-01 03:54:53	2019-11-01	9	[{"id_menu":6,"count":1}]	3893	delivery	5	14
12461	2019-11-01 04:05:47	2019-11-01	8	[{"id_menu":5,"count":1}]	4072	pick-up	0	8
12462	2019-11-01 04:20:39	2019-11-01	9	[{"id_menu":7,"count":1}]	4075	pick-up	0	9
12463	2019-11-01 04:34:58	2019-11-01	17	[{"id_menu":4,"count":1}]	1070	pick-up	0	17
12464	2019-11-01 05:28:20	2019-11-01	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2165	pick-up	0	35
12465	2019-11-01 05:31:08	2019-11-01	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3870	pick-up	0	38
12466	2019-11-01 05:33:46	2019-11-01	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	2910	delivery	5	36
12467	2019-11-01 05:43:05	2019-11-01	8	[{"id_menu":5,"count":1}]	422	delivery	5	13
12468	2019-11-01 05:48:54	2019-11-01	12	[{"id_menu":1,"count":1}]	1352	delivery	5	17
12469	2019-11-01 06:12:29	2019-11-01	9	[{"id_menu":7,"count":1}]	697	delivery	5	14
12470	2019-11-01 06:22:48	2019-11-01	14	[{"id_menu":2,"count":1}]	4363	pick-up	0	14
12471	2019-11-01 06:25:54	2019-11-01	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4254	delivery	5	43
12472	2019-11-01 07:09:51	2019-11-01	9	[{"id_menu":6,"count":1}]	4672	delivery	5	14
12473	2019-11-01 07:23:15	2019-11-01	9	[{"id_menu":6,"count":1}]	708	delivery	5	14
12474	2019-11-01 07:45:13	2019-11-01	8	[{"id_menu":5,"count":2}]	4667	delivery	5	13
12475	2019-11-01 08:23:51	2019-11-01	17	[{"id_menu":4,"count":1}]	4648	pick-up	0	17
12476	2019-11-01 08:40:53	2019-11-01	9	[{"id_menu":7,"count":1}]	2498	pick-up	0	9
12477	2019-11-01 09:00:11	2019-11-01	8	[{"id_menu":5,"count":1}]	813	pick-up	0	8
12478	2019-11-01 09:06:26	2019-11-01	12	[{"id_menu":1,"count":1}]	2659	delivery	5	17
12479	2019-11-01 09:15:58	2019-11-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3172	pick-up	0	23
12480	2019-11-01 09:28:15	2019-11-01	14	[{"id_menu":2,"count":1}]	3174	delivery	5	19
12481	2019-11-01 09:30:24	2019-11-01	17	[{"id_menu":4,"count":1}]	947	pick-up	0	17
12482	2019-11-01 09:30:41	2019-11-01	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	4659	pick-up	0	21
12483	2019-11-01 09:54:10	2019-11-01	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4656	pick-up	0	29
12484	2019-11-01 10:10:08	2019-11-01	12	[{"id_menu":1,"count":1}]	1034	delivery	5	17
12485	2019-11-01 10:24:46	2019-11-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4661	pick-up	0	26
12486	2019-11-01 10:24:50	2019-11-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1831	delivery	5	28
12487	2019-11-01 10:27:38	2019-11-01	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3040	delivery	5	43
12488	2019-11-01 10:57:25	2019-11-01	17	[{"id_menu":4,"count":1}]	1688	delivery	5	22
12489	2019-11-01 11:16:49	2019-11-01	17	[{"id_menu":4,"count":2}]	4650	pick-up	0	17
12490	2019-11-01 11:17:38	2019-11-01	9	[{"id_menu":7,"count":1}]	2083	pick-up	0	9
12491	2019-11-01 11:21:26	2019-11-01	12	[{"id_menu":3,"count":1}]	4654	pick-up	0	12
12492	2019-11-01 11:25:19	2019-11-01	9	[{"id_menu":6,"count":1}]	2070	pick-up	0	9
12493	2019-11-01 11:28:36	2019-11-01	14	[{"id_menu":2,"count":1}]	97	pick-up	0	14
12494	2019-11-01 11:41:28	2019-11-01	12	[{"id_menu":1,"count":1}]	379	pick-up	0	12
12495	2019-11-01 12:00:00	2019-11-01	8	[{"id_menu":5,"count":1}]	2304	pick-up	0	8
12496	2019-11-01 12:04:40	2019-11-01	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	546	delivery	5	43
12702	2019-11-03 04:48:51	2019-11-03	14	[{"id_menu":2,"count":1}]	2601	pick-up	0	14
12497	2019-11-01 12:51:02	2019-11-01	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3858	pick-up	0	30
12498	2019-11-01 12:57:50	2019-11-01	14	[{"id_menu":2,"count":1}]	126	pick-up	0	14
12499	2019-11-01 13:04:04	2019-11-01	9	[{"id_menu":6,"count":1}]	625	pick-up	0	9
12500	2019-11-01 13:06:34	2019-11-01	9	[{"id_menu":6,"count":1}]	37	pick-up	0	9
12501	2019-11-01 13:07:55	2019-11-01	17	[{"id_menu":4,"count":1}]	1209	pick-up	0	17
12502	2019-11-01 13:09:22	2019-11-01	9	[{"id_menu":6,"count":1}]	4662	delivery	5	14
12503	2019-11-01 13:15:37	2019-11-01	9	[{"id_menu":7,"count":1}]	575	delivery	5	14
12504	2019-11-01 13:17:59	2019-11-01	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	4665	delivery	5	30
12505	2019-11-01 13:55:04	2019-11-01	14	[{"id_menu":2,"count":1}]	4671	delivery	5	19
12506	2019-11-01 13:55:59	2019-11-01	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	376	pick-up	0	20
12507	2019-11-01 13:58:38	2019-11-01	14	[{"id_menu":2,"count":1}]	735	pick-up	0	14
12508	2019-11-01 14:04:28	2019-11-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3211	delivery	5	36
12509	2019-11-01 14:42:28	2019-11-01	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	271	delivery	5	31
12510	2019-11-01 15:30:48	2019-11-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3433	pick-up	0	17
12511	2019-11-01 15:32:37	2019-11-01	12	[{"id_menu":3,"count":1}]	562	delivery	5	17
12512	2019-11-01 15:33:01	2019-11-01	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	4645	pick-up	0	35
12513	2019-11-01 15:38:49	2019-11-01	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	1760	pick-up	0	23
12514	2019-11-01 16:44:18	2019-11-01	14	[{"id_menu":2,"count":1}]	1781	pick-up	0	14
12515	2019-11-01 17:00:07	2019-11-01	9	[{"id_menu":6,"count":1}]	4644	pick-up	0	9
12516	2019-11-01 17:01:46	2019-11-01	8	[{"id_menu":5,"count":1}]	624	pick-up	0	8
12517	2019-11-01 17:05:23	2019-11-01	17	[{"id_menu":4,"count":2}]	3655	delivery	5	22
12518	2019-11-01 17:38:20	2019-11-01	12	[{"id_menu":3,"count":1}]	4638	delivery	5	17
12519	2019-11-01 17:51:31	2019-11-01	12	[{"id_menu":3,"count":1}]	4666	delivery	5	17
12520	2019-11-01 17:53:38	2019-11-01	9	[{"id_menu":7,"count":1}]	4655	delivery	5	14
12521	2019-11-01 18:18:11	2019-11-01	9	[{"id_menu":7,"count":1}]	3517	delivery	5	14
12522	2019-11-01 18:20:22	2019-11-01	12	[{"id_menu":1,"count":1}]	3755	pick-up	0	12
12523	2019-11-01 18:40:41	2019-11-01	9	[{"id_menu":6,"count":2}]	4653	delivery	5	14
12524	2019-11-01 18:46:57	2019-11-01	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4640	delivery	5	48
12525	2019-11-01 18:52:40	2019-11-01	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4663	delivery	5	40
12526	2019-11-01 19:11:03	2019-11-01	9	[{"id_menu":6,"count":1}]	3237	delivery	5	14
12527	2019-11-01 19:13:38	2019-11-01	17	[{"id_menu":4,"count":1}]	143	delivery	5	22
12528	2019-11-01 19:15:19	2019-11-01	17	[{"id_menu":4,"count":1}]	2056	pick-up	0	17
12529	2019-11-01 19:35:27	2019-11-01	8	[{"id_menu":5,"count":2}]	435	delivery	5	13
12530	2019-11-01 19:42:30	2019-11-01	9	[{"id_menu":7,"count":1}]	4658	delivery	5	14
12531	2019-11-01 19:55:41	2019-11-01	9	[{"id_menu":6,"count":1}]	4669	delivery	5	14
12532	2019-11-01 20:16:51	2019-11-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1093	delivery	5	26
12533	2019-11-01 20:31:37	2019-11-01	12	[{"id_menu":1,"count":1}]	596	pick-up	0	12
12534	2019-11-01 21:44:00	2019-11-01	12	[{"id_menu":3,"count":2}]	3383	pick-up	0	12
12535	2019-11-01 22:21:09	2019-11-01	14	[{"id_menu":2,"count":1}]	1170	pick-up	0	14
12536	2019-11-01 22:31:08	2019-11-01	9	[{"id_menu":7,"count":1}]	950	pick-up	0	9
12537	2019-11-01 22:35:40	2019-11-01	12	[{"id_menu":1,"count":1}]	3968	pick-up	0	12
12538	2019-11-01 22:52:05	2019-11-01	8	[{"id_menu":5,"count":1}]	2574	delivery	5	13
12539	2019-11-01 22:58:26	2019-11-01	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1263	delivery	5	51
12540	2019-11-01 23:02:52	2019-11-01	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3459	pick-up	0	21
12541	2019-11-01 23:35:10	2019-11-01	14	[{"id_menu":2,"count":1}]	1860	pick-up	0	14
12542	2019-11-02 00:05:54	2019-11-02	9	[{"id_menu":6,"count":1}]	2184	delivery	5	14
12543	2019-11-02 00:24:16	2019-11-02	9	[{"id_menu":6,"count":1}]	3719	delivery	5	14
12544	2019-11-02 00:36:27	2019-11-02	9	[{"id_menu":7,"count":1}]	4681	delivery	5	14
12545	2019-11-02 00:40:22	2019-11-02	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	743	pick-up	0	38
12546	2019-11-02 00:42:28	2019-11-02	9	[{"id_menu":6,"count":1}]	1468	delivery	5	14
12547	2019-11-02 01:01:01	2019-11-02	17	[{"id_menu":4,"count":1}]	4706	delivery	5	22
12548	2019-11-02 01:16:41	2019-11-02	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1442	pick-up	0	29
12549	2019-11-02 01:37:26	2019-11-02	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3393	delivery	5	34
12550	2019-11-02 01:46:33	2019-11-02	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	822	pick-up	0	26
12551	2019-11-02 01:49:48	2019-11-02	8	[{"id_menu":5,"count":1}]	3931	delivery	5	13
12552	2019-11-02 02:12:12	2019-11-02	9	[{"id_menu":7,"count":1}]	3948	pick-up	0	9
12553	2019-11-02 02:14:45	2019-11-02	17	[{"id_menu":4,"count":1}]	2442	pick-up	0	17
12554	2019-11-02 02:17:11	2019-11-02	8	[{"id_menu":5,"count":1}]	4699	delivery	5	13
12555	2019-11-02 02:45:55	2019-11-02	12	[{"id_menu":3,"count":1}]	1053	pick-up	0	12
12556	2019-11-02 02:47:02	2019-11-02	12	[{"id_menu":3,"count":1}]	464	pick-up	0	12
12557	2019-11-02 03:00:06	2019-11-02	9	[{"id_menu":7,"count":1}]	4683	delivery	5	14
12558	2019-11-02 03:01:02	2019-11-02	8	[{"id_menu":5,"count":1}]	4680	delivery	5	13
12559	2019-11-02 03:22:15	2019-11-02	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4675	delivery	5	52
12560	2019-11-02 04:00:57	2019-11-02	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1088	pick-up	0	31
12561	2019-11-02 04:33:28	2019-11-02	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	2741	delivery	5	28
12562	2019-11-02 05:20:05	2019-11-02	12	[{"id_menu":3,"count":1}]	2590	pick-up	0	12
12563	2019-11-02 05:43:50	2019-11-02	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2608	pick-up	0	29
12703	2019-11-03 04:51:59	2019-11-03	9	[{"id_menu":7,"count":1}]	4328	delivery	5	14
12564	2019-11-02 05:53:00	2019-11-02	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4704	delivery	5	40
12565	2019-11-02 05:59:52	2019-11-02	12	[{"id_menu":1,"count":1}]	1314	pick-up	0	12
12566	2019-11-02 06:07:14	2019-11-02	12	[{"id_menu":3,"count":1}]	4590	delivery	5	17
12567	2019-11-02 06:14:58	2019-11-02	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1900	pick-up	0	26
12568	2019-11-02 06:19:34	2019-11-02	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	95	pick-up	0	29
12569	2019-11-02 06:23:54	2019-11-02	17	[{"id_menu":4,"count":1}]	4192	delivery	5	22
12570	2019-11-02 06:30:31	2019-11-02	9	[{"id_menu":6,"count":1}]	2332	delivery	5	14
12571	2019-11-02 06:40:09	2019-11-02	8	[{"id_menu":5,"count":1}]	1618	pick-up	0	8
12572	2019-11-02 06:40:56	2019-11-02	8	[{"id_menu":5,"count":1}]	4673	delivery	5	13
12573	2019-11-02 06:44:28	2019-11-02	17	[{"id_menu":4,"count":1}]	708	pick-up	0	17
12574	2019-11-02 06:45:44	2019-11-02	14	[{"id_menu":2,"count":1}]	4500	delivery	5	19
12575	2019-11-02 06:49:17	2019-11-02	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4141	delivery	5	44
12576	2019-11-02 06:58:33	2019-11-02	9	[{"id_menu":7,"count":1}]	48	pick-up	0	9
12577	2019-11-02 07:10:54	2019-11-02	12	[{"id_menu":1,"count":1}]	3052	pick-up	0	12
12578	2019-11-02 07:16:53	2019-11-02	14	[{"id_menu":2,"count":1}]	4676	delivery	5	19
12579	2019-11-02 07:17:56	2019-11-02	8	[{"id_menu":5,"count":1}]	1453	delivery	5	13
12580	2019-11-02 07:22:15	2019-11-02	9	[{"id_menu":7,"count":1}]	4701	delivery	5	14
12581	2019-11-02 07:38:40	2019-11-02	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4686	delivery	5	31
12582	2019-11-02 07:44:10	2019-11-02	8	[{"id_menu":5,"count":1}]	4703	delivery	5	13
12583	2019-11-02 08:04:47	2019-11-02	12	[{"id_menu":1,"count":1}]	4711	delivery	5	17
12584	2019-11-02 08:08:26	2019-11-02	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	4707	delivery	5	31
12585	2019-11-02 08:09:03	2019-11-02	9	[{"id_menu":6,"count":1}]	4692	delivery	5	14
12586	2019-11-02 08:09:17	2019-11-02	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1834	pick-up	0	26
12587	2019-11-02 08:16:30	2019-11-02	8	[{"id_menu":5,"count":1}]	1870	pick-up	0	8
12588	2019-11-02 09:12:17	2019-11-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	207	delivery	5	28
12589	2019-11-02 09:14:43	2019-11-02	30	[{"id_menu":1,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	378	pick-up	0	30
12590	2019-11-02 09:26:38	2019-11-02	12	[{"id_menu":3,"count":1}]	4695	pick-up	0	12
12591	2019-11-02 09:38:17	2019-11-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	420	delivery	5	28
12592	2019-11-02 09:44:54	2019-11-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1940	pick-up	0	18
12593	2019-11-02 09:50:40	2019-11-02	14	[{"id_menu":2,"count":1}]	2672	pick-up	0	14
12594	2019-11-02 09:55:18	2019-11-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	4674	delivery	5	28
12595	2019-11-02 10:18:49	2019-11-02	14	[{"id_menu":2,"count":1}]	4709	delivery	5	19
12596	2019-11-02 10:28:19	2019-11-02	12	[{"id_menu":1,"count":1}]	4713	delivery	5	17
12597	2019-11-02 10:46:16	2019-11-02	9	[{"id_menu":6,"count":3}]	3119	delivery	5	14
12598	2019-11-02 11:01:57	2019-11-02	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4716	delivery	5	30
12599	2019-11-02 11:10:24	2019-11-02	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	3063	delivery	5	29
12600	2019-11-02 11:11:29	2019-11-02	8	[{"id_menu":5,"count":1}]	3697	delivery	5	13
12601	2019-11-02 11:11:46	2019-11-02	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3451	delivery	5	22
12602	2019-11-02 11:21:15	2019-11-02	17	[{"id_menu":4,"count":1}]	1549	delivery	5	22
12603	2019-11-02 11:21:29	2019-11-02	17	[{"id_menu":4,"count":1}]	4714	pick-up	0	17
12604	2019-11-02 11:22:01	2019-11-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	245	delivery	5	22
12605	2019-11-02 11:22:43	2019-11-02	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	3540	delivery	5	26
12606	2019-11-02 11:32:49	2019-11-02	17	[{"id_menu":4,"count":1}]	1633	pick-up	0	17
12607	2019-11-02 11:47:31	2019-11-02	9	[{"id_menu":6,"count":1}]	29	pick-up	0	9
12608	2019-11-02 11:49:36	2019-11-02	9	[{"id_menu":7,"count":1}]	1929	pick-up	0	9
12609	2019-11-02 11:59:53	2019-11-02	9	[{"id_menu":6,"count":1}]	3883	delivery	5	14
12610	2019-11-02 12:08:35	2019-11-02	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	4708	delivery	5	23
12611	2019-11-02 12:34:57	2019-11-02	12	[{"id_menu":1,"count":1}]	946	pick-up	0	12
12612	2019-11-02 12:49:08	2019-11-02	12	[{"id_menu":1,"count":1}]	3066	pick-up	0	12
12613	2019-11-02 12:49:50	2019-11-02	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2266	delivery	5	27
12614	2019-11-02 12:53:15	2019-11-02	12	[{"id_menu":1,"count":1}]	4685	delivery	5	17
12615	2019-11-02 13:17:46	2019-11-02	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4700	delivery	5	26
12616	2019-11-02 13:34:46	2019-11-02	17	[{"id_menu":4,"count":1}]	4710	pick-up	0	17
12617	2019-11-02 14:09:43	2019-11-02	17	[{"id_menu":4,"count":1}]	4717	pick-up	0	17
12618	2019-11-02 14:29:25	2019-11-02	17	[{"id_menu":4,"count":1}]	2386	delivery	5	22
12619	2019-11-02 14:32:24	2019-11-02	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	3730	pick-up	0	24
12620	2019-11-02 14:48:29	2019-11-02	14	[{"id_menu":2,"count":1}]	4677	delivery	5	19
12621	2019-11-02 15:01:56	2019-11-02	8	[{"id_menu":5,"count":1}]	3825	pick-up	0	8
12622	2019-11-02 15:06:26	2019-11-02	12	[{"id_menu":3,"count":1}]	4698	delivery	5	17
12623	2019-11-02 15:06:53	2019-11-02	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3069	pick-up	0	25
12624	2019-11-02 15:15:52	2019-11-02	12	[{"id_menu":1,"count":1}]	4684	pick-up	0	12
12625	2019-11-02 15:16:01	2019-11-02	12	[{"id_menu":3,"count":1}]	2540	pick-up	0	12
12626	2019-11-02 15:17:16	2019-11-02	9	[{"id_menu":6,"count":1}]	4696	delivery	5	14
12627	2019-11-02 15:21:10	2019-11-02	9	[{"id_menu":7,"count":1}]	4702	delivery	5	14
12628	2019-11-02 15:22:39	2019-11-02	14	[{"id_menu":2,"count":1}]	3148	pick-up	0	14
12629	2019-11-02 15:25:42	2019-11-02	14	[{"id_menu":2,"count":1}]	1481	delivery	5	19
12630	2019-11-02 15:36:41	2019-11-02	12	[{"id_menu":1,"count":1}]	1401	pick-up	0	12
12631	2019-11-02 15:54:12	2019-11-02	14	[{"id_menu":2,"count":1}]	2804	pick-up	0	14
12632	2019-11-02 15:58:18	2019-11-02	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	4687	delivery	5	40
12633	2019-11-02 16:08:47	2019-11-02	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4697	delivery	5	37
12634	2019-11-02 16:19:27	2019-11-02	12	[{"id_menu":3,"count":1}]	4693	pick-up	0	12
12635	2019-11-02 16:21:00	2019-11-02	12	[{"id_menu":1,"count":1}]	1469	delivery	5	17
12636	2019-11-02 16:21:23	2019-11-02	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	4705	pick-up	0	35
12637	2019-11-02 16:29:42	2019-11-02	8	[{"id_menu":5,"count":2}]	4689	delivery	5	13
12638	2019-11-02 16:29:48	2019-11-02	17	[{"id_menu":4,"count":1}]	4718	delivery	5	22
12639	2019-11-02 16:55:17	2019-11-02	12	[{"id_menu":3,"count":2}]	2416	delivery	5	17
12640	2019-11-02 17:04:46	2019-11-02	8	[{"id_menu":5,"count":1}]	1337	pick-up	0	8
12641	2019-11-02 17:08:40	2019-11-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1988	delivery	5	23
12642	2019-11-02 17:28:56	2019-11-02	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2289	pick-up	0	26
12643	2019-11-02 17:37:47	2019-11-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1768	delivery	5	31
12644	2019-11-02 17:55:27	2019-11-02	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1859	pick-up	0	29
12645	2019-11-02 18:14:30	2019-11-02	14	[{"id_menu":2,"count":1}]	4715	delivery	5	19
12646	2019-11-02 18:18:09	2019-11-02	9	[{"id_menu":7,"count":1}]	4691	delivery	5	14
12647	2019-11-02 18:29:01	2019-11-02	9	[{"id_menu":6,"count":1}]	2275	pick-up	0	9
12648	2019-11-02 18:29:07	2019-11-02	14	[{"id_menu":2,"count":1}]	546	delivery	5	19
12649	2019-11-02 18:35:58	2019-11-02	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1369	pick-up	0	26
12650	2019-11-02 19:01:19	2019-11-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4690	pick-up	0	17
12651	2019-11-02 19:20:32	2019-11-02	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4719	delivery	5	45
12652	2019-11-02 19:20:36	2019-11-02	12	[{"id_menu":3,"count":1}]	2125	pick-up	0	12
12653	2019-11-02 19:34:26	2019-11-02	9	[{"id_menu":7,"count":1}]	2604	delivery	5	14
12654	2019-11-02 19:38:38	2019-11-02	9	[{"id_menu":6,"count":1}]	4712	delivery	5	14
12655	2019-11-02 19:42:27	2019-11-02	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1729	pick-up	0	35
12656	2019-11-02 19:59:27	2019-11-02	17	[{"id_menu":4,"count":1}]	727	delivery	5	22
12657	2019-11-02 20:03:32	2019-11-02	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	4682	pick-up	0	23
12658	2019-11-02 20:17:27	2019-11-02	17	[{"id_menu":4,"count":1}]	356	pick-up	0	17
12659	2019-11-02 20:33:54	2019-11-02	9	[{"id_menu":7,"count":1}]	123	pick-up	0	9
12660	2019-11-02 21:00:57	2019-11-02	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1569	pick-up	0	24
12661	2019-11-02 21:41:16	2019-11-02	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3388	delivery	5	28
12662	2019-11-02 21:53:26	2019-11-02	14	[{"id_menu":2,"count":1}]	1309	pick-up	0	14
12663	2019-11-02 21:58:20	2019-11-02	8	[{"id_menu":5,"count":1}]	4688	delivery	5	13
12664	2019-11-02 22:02:20	2019-11-02	9	[{"id_menu":6,"count":1}]	655	pick-up	0	9
12665	2019-11-02 22:38:04	2019-11-02	12	[{"id_menu":3,"count":1}]	3192	pick-up	0	12
12666	2019-11-02 22:39:31	2019-11-02	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	4042	delivery	5	29
12667	2019-11-02 22:54:53	2019-11-02	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2553	delivery	5	31
12668	2019-11-02 23:10:42	2019-11-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2928	pick-up	0	17
12669	2019-11-02 23:14:22	2019-11-02	17	[{"id_menu":4,"count":1}]	3035	pick-up	0	17
12670	2019-11-02 23:19:45	2019-11-02	9	[{"id_menu":7,"count":1}]	4694	delivery	5	14
12671	2019-11-02 23:37:49	2019-11-02	14	[{"id_menu":2,"count":1}]	2200	pick-up	0	14
12672	2019-11-03 00:01:12	2019-11-03	8	[{"id_menu":5,"count":2}]	4722	pick-up	0	8
12673	2019-11-03 00:12:10	2019-11-03	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	172	pick-up	0	22
12674	2019-11-03 00:16:38	2019-11-03	12	[{"id_menu":1,"count":1}]	1605	delivery	5	17
12675	2019-11-03 00:17:07	2019-11-03	9	[{"id_menu":6,"count":1}]	4744	delivery	5	14
12676	2019-11-03 00:18:43	2019-11-03	8	[{"id_menu":5,"count":1}]	4773	delivery	5	13
12677	2019-11-03 00:24:16	2019-11-03	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4730	delivery	5	22
12678	2019-11-03 00:37:40	2019-11-03	12	[{"id_menu":1,"count":1}]	820	pick-up	0	12
12679	2019-11-03 00:48:03	2019-11-03	14	[{"id_menu":2,"count":1}]	4769	delivery	5	19
12680	2019-11-03 00:57:07	2019-11-03	12	[{"id_menu":3,"count":1}]	4731	pick-up	0	12
12681	2019-11-03 01:01:34	2019-11-03	14	[{"id_menu":2,"count":1}]	4760	delivery	5	19
12682	2019-11-03 01:10:22	2019-11-03	14	[{"id_menu":2,"count":1}]	1563	pick-up	0	14
12683	2019-11-03 01:13:20	2019-11-03	9	[{"id_menu":7,"count":1}]	967	pick-up	0	9
12684	2019-11-03 01:42:00	2019-11-03	17	[{"id_menu":4,"count":2}]	4642	pick-up	0	17
12685	2019-11-03 01:52:00	2019-11-03	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	4655	delivery	5	27
12686	2019-11-03 02:31:02	2019-11-03	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4733	delivery	5	31
12687	2019-11-03 02:32:34	2019-11-03	14	[{"id_menu":2,"count":1}]	2213	delivery	5	19
12688	2019-11-03 02:35:57	2019-11-03	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	4771	pick-up	0	26
12689	2019-11-03 02:38:51	2019-11-03	12	[{"id_menu":3,"count":1}]	4772	delivery	5	17
12690	2019-11-03 02:57:55	2019-11-03	14	[{"id_menu":2,"count":1}]	4748	delivery	5	19
12691	2019-11-03 03:07:44	2019-11-03	12	[{"id_menu":1,"count":1}]	4755	delivery	5	17
12692	2019-11-03 03:08:25	2019-11-03	12	[{"id_menu":1,"count":1}]	4728	delivery	5	17
12693	2019-11-03 03:16:33	2019-11-03	12	[{"id_menu":1,"count":1}]	396	delivery	5	17
12694	2019-11-03 03:24:35	2019-11-03	12	[{"id_menu":1,"count":1}]	2538	delivery	5	17
12695	2019-11-03 03:37:00	2019-11-03	8	[{"id_menu":5,"count":1}]	1888	pick-up	0	8
12696	2019-11-03 04:09:27	2019-11-03	9	[{"id_menu":7,"count":1}]	1285	pick-up	0	9
12697	2019-11-03 04:15:35	2019-11-03	9	[{"id_menu":7,"count":1}]	4757	delivery	5	14
12698	2019-11-03 04:15:55	2019-11-03	14	[{"id_menu":2,"count":1}]	2317	pick-up	0	14
12699	2019-11-03 04:21:30	2019-11-03	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	2440	delivery	5	29
12700	2019-11-03 04:29:33	2019-11-03	17	[{"id_menu":4,"count":1}]	4721	pick-up	0	17
12701	2019-11-03 04:30:03	2019-11-03	9	[{"id_menu":6,"count":1}]	2651	pick-up	0	9
12704	2019-11-03 05:24:12	2019-11-03	8	[{"id_menu":5,"count":1}]	2776	pick-up	0	8
12705	2019-11-03 05:36:20	2019-11-03	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4766	delivery	5	22
12706	2019-11-03 05:42:01	2019-11-03	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	4747	pick-up	0	21
12707	2019-11-03 05:50:44	2019-11-03	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	4445	delivery	5	26
12708	2019-11-03 05:55:06	2019-11-03	9	[{"id_menu":7,"count":1}]	360	pick-up	0	9
12709	2019-11-03 06:00:26	2019-11-03	8	[{"id_menu":5,"count":1}]	4743	delivery	5	13
12710	2019-11-03 06:00:30	2019-11-03	9	[{"id_menu":6,"count":2}]	3268	pick-up	0	9
12711	2019-11-03 06:02:31	2019-11-03	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":2}]	499	delivery	5	22
12712	2019-11-03 06:12:13	2019-11-03	8	[{"id_menu":5,"count":1}]	4094	delivery	5	13
12713	2019-11-03 06:24:10	2019-11-03	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4292	pick-up	0	17
12714	2019-11-03 06:27:10	2019-11-03	14	[{"id_menu":2,"count":1}]	4765	pick-up	0	14
12715	2019-11-03 06:34:39	2019-11-03	17	[{"id_menu":4,"count":2}]	2123	pick-up	0	17
12716	2019-11-03 06:35:31	2019-11-03	21	[{"id_menu":1,"count":3},{"id_menu":6,"count":1}]	2995	delivery	5	26
12717	2019-11-03 06:46:27	2019-11-03	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	2664	delivery	5	39
12718	2019-11-03 06:47:40	2019-11-03	12	[{"id_menu":1,"count":1}]	1843	delivery	5	17
12719	2019-11-03 06:56:01	2019-11-03	14	[{"id_menu":2,"count":1}]	1306	pick-up	0	14
12720	2019-11-03 06:57:27	2019-11-03	9	[{"id_menu":6,"count":1}]	4720	pick-up	0	9
12721	2019-11-03 07:16:58	2019-11-03	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	4738	delivery	5	22
12722	2019-11-03 07:19:11	2019-11-03	8	[{"id_menu":5,"count":2}]	4734	pick-up	0	8
12723	2019-11-03 07:20:58	2019-11-03	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4062	pick-up	0	17
12724	2019-11-03 07:24:14	2019-11-03	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4672	pick-up	0	21
12725	2019-11-03 07:52:32	2019-11-03	43	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4732	delivery	5	48
12726	2019-11-03 07:55:43	2019-11-03	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	876	delivery	5	34
12727	2019-11-03 08:09:48	2019-11-03	8	[{"id_menu":5,"count":1}]	4770	pick-up	0	8
12728	2019-11-03 08:09:55	2019-11-03	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	2618	pick-up	0	24
12729	2019-11-03 08:10:40	2019-11-03	12	[{"id_menu":1,"count":1}]	3097	delivery	5	17
12730	2019-11-03 08:12:39	2019-11-03	8	[{"id_menu":5,"count":1}]	1143	delivery	5	13
12731	2019-11-03 08:13:44	2019-11-03	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	4750	pick-up	0	21
12732	2019-11-03 08:17:25	2019-11-03	9	[{"id_menu":7,"count":1}]	4756	delivery	5	14
12733	2019-11-03 08:27:23	2019-11-03	14	[{"id_menu":2,"count":1}]	3296	delivery	5	19
12734	2019-11-03 08:34:54	2019-11-03	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4763	delivery	5	51
12735	2019-11-03 08:50:35	2019-11-03	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3864	pick-up	0	31
12736	2019-11-03 08:58:02	2019-11-03	12	[{"id_menu":3,"count":1}]	1507	delivery	5	17
12737	2019-11-03 08:58:17	2019-11-03	14	[{"id_menu":2,"count":1}]	4607	delivery	5	19
12738	2019-11-03 09:06:38	2019-11-03	9	[{"id_menu":6,"count":1}]	749	pick-up	0	9
12739	2019-11-03 09:08:58	2019-11-03	17	[{"id_menu":4,"count":1}]	4726	delivery	5	22
12740	2019-11-03 09:14:13	2019-11-03	9	[{"id_menu":7,"count":1}]	3224	pick-up	0	9
12741	2019-11-03 09:14:45	2019-11-03	17	[{"id_menu":4,"count":2}]	3168	pick-up	0	17
12742	2019-11-03 09:18:39	2019-11-03	8	[{"id_menu":5,"count":1}]	2033	pick-up	0	8
12743	2019-11-03 09:28:09	2019-11-03	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2867	pick-up	0	26
12744	2019-11-03 09:36:00	2019-11-03	12	[{"id_menu":3,"count":2}]	4752	pick-up	0	12
12745	2019-11-03 09:41:09	2019-11-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	4723	delivery	5	31
12746	2019-11-03 09:43:14	2019-11-03	14	[{"id_menu":2,"count":2}]	4754	delivery	5	19
12747	2019-11-03 09:43:51	2019-11-03	9	[{"id_menu":6,"count":1}]	527	pick-up	0	9
12748	2019-11-03 09:45:50	2019-11-03	9	[{"id_menu":6,"count":1}]	4745	delivery	5	14
12749	2019-11-03 09:46:12	2019-11-03	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1255	pick-up	0	21
12750	2019-11-03 09:46:22	2019-11-03	17	[{"id_menu":4,"count":1}]	2599	pick-up	0	17
12751	2019-11-03 10:00:49	2019-11-03	9	[{"id_menu":6,"count":1}]	4370	pick-up	0	9
12752	2019-11-03 10:20:04	2019-11-03	9	[{"id_menu":7,"count":1}]	2339	delivery	5	14
12753	2019-11-03 10:39:44	2019-11-03	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4742	delivery	5	36
12754	2019-11-03 10:50:37	2019-11-03	9	[{"id_menu":6,"count":1}]	3709	delivery	5	14
12755	2019-11-03 11:07:16	2019-11-03	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2932	pick-up	0	43
12756	2019-11-03 11:14:21	2019-11-03	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1376	delivery	5	26
12757	2019-11-03 11:51:30	2019-11-03	9	[{"id_menu":7,"count":1}]	2799	pick-up	0	9
12758	2019-11-03 11:58:43	2019-11-03	14	[{"id_menu":2,"count":1}]	212	delivery	5	19
12759	2019-11-03 12:05:16	2019-11-03	9	[{"id_menu":6,"count":1}]	4749	delivery	5	14
12760	2019-11-03 12:05:53	2019-11-03	9	[{"id_menu":7,"count":1}]	3017	delivery	5	14
12761	2019-11-03 12:30:35	2019-11-03	12	[{"id_menu":3,"count":1}]	4764	delivery	5	17
12762	2019-11-03 12:44:40	2019-11-03	9	[{"id_menu":6,"count":1}]	4762	pick-up	0	9
12763	2019-11-03 12:45:50	2019-11-03	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2065	pick-up	0	18
12764	2019-11-03 13:07:12	2019-11-03	17	[{"id_menu":4,"count":1}]	1212	delivery	5	22
12765	2019-11-03 13:09:16	2019-11-03	12	[{"id_menu":1,"count":1}]	235	pick-up	0	12
12766	2019-11-03 13:11:06	2019-11-03	14	[{"id_menu":2,"count":1}]	4751	pick-up	0	14
12767	2019-11-03 13:11:23	2019-11-03	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4767	pick-up	0	32
12768	2019-11-03 13:18:07	2019-11-03	12	[{"id_menu":3,"count":1}]	4149	delivery	5	17
12769	2019-11-03 13:35:35	2019-11-03	17	[{"id_menu":4,"count":1}]	1748	pick-up	0	17
12770	2019-11-03 13:36:18	2019-11-03	12	[{"id_menu":1,"count":1}]	4759	delivery	5	17
12771	2019-11-03 13:57:14	2019-11-03	8	[{"id_menu":5,"count":1}]	4736	delivery	5	13
12772	2019-11-03 14:14:18	2019-11-03	14	[{"id_menu":2,"count":1}]	233	pick-up	0	14
12773	2019-11-03 14:16:59	2019-11-03	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2546	delivery	5	30
12774	2019-11-03 14:36:24	2019-11-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4737	delivery	5	31
12775	2019-11-03 14:36:33	2019-11-03	17	[{"id_menu":4,"count":1}]	3938	delivery	5	22
12776	2019-11-03 14:40:47	2019-11-03	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2951	delivery	5	27
12777	2019-11-03 14:41:39	2019-11-03	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	2590	pick-up	0	26
12778	2019-11-03 15:20:23	2019-11-03	9	[{"id_menu":6,"count":1}]	4758	pick-up	0	9
12779	2019-11-03 15:22:43	2019-11-03	17	[{"id_menu":4,"count":1}]	4725	delivery	5	22
12780	2019-11-03 15:26:34	2019-11-03	9	[{"id_menu":6,"count":1}]	140	pick-up	0	9
12781	2019-11-03 15:28:40	2019-11-03	9	[{"id_menu":7,"count":1}]	1183	pick-up	0	9
12782	2019-11-03 15:31:49	2019-11-03	17	[{"id_menu":4,"count":1}]	4740	delivery	5	22
12783	2019-11-03 15:39:24	2019-11-03	9	[{"id_menu":6,"count":1}]	541	pick-up	0	9
12784	2019-11-03 15:49:57	2019-11-03	8	[{"id_menu":5,"count":1}]	586	pick-up	0	8
12785	2019-11-03 15:51:08	2019-11-03	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	376	delivery	5	23
12786	2019-11-03 15:57:29	2019-11-03	14	[{"id_menu":2,"count":1}]	2826	delivery	5	19
12787	2019-11-03 16:00:58	2019-11-03	9	[{"id_menu":6,"count":1}]	3828	delivery	5	14
12788	2019-11-03 16:05:48	2019-11-03	17	[{"id_menu":4,"count":1}]	3661	delivery	5	22
12789	2019-11-03 16:11:16	2019-11-03	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1236	pick-up	0	18
12790	2019-11-03 16:21:54	2019-11-03	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	96	pick-up	0	32
12791	2019-11-03 16:28:44	2019-11-03	8	[{"id_menu":5,"count":1}]	660	pick-up	0	8
12792	2019-11-03 16:32:43	2019-11-03	17	[{"id_menu":4,"count":1}]	1900	pick-up	0	17
12793	2019-11-03 16:38:27	2019-11-03	12	[{"id_menu":1,"count":1}]	4746	delivery	5	17
12794	2019-11-03 16:54:12	2019-11-03	12	[{"id_menu":1,"count":1}]	2367	pick-up	0	12
12795	2019-11-03 17:03:50	2019-11-03	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	4088	delivery	5	22
12796	2019-11-03 17:10:49	2019-11-03	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1192	delivery	5	36
12797	2019-11-03 17:11:40	2019-11-03	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	1956	delivery	5	22
12798	2019-11-03 17:21:46	2019-11-03	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3051	pick-up	0	17
12799	2019-11-03 17:26:47	2019-11-03	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4282	delivery	5	40
12800	2019-11-03 18:08:42	2019-11-03	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	638	pick-up	0	35
12801	2019-11-03 18:13:26	2019-11-03	14	[{"id_menu":2,"count":1}]	2519	delivery	5	19
12802	2019-11-03 18:19:28	2019-11-03	8	[{"id_menu":5,"count":1}]	467	pick-up	0	8
12803	2019-11-03 18:33:50	2019-11-03	12	[{"id_menu":3,"count":1}]	4195	delivery	5	17
12804	2019-11-03 18:36:22	2019-11-03	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1289	pick-up	0	20
12805	2019-11-03 18:50:04	2019-11-03	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	4710	pick-up	0	24
12806	2019-11-03 19:27:00	2019-11-03	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	4768	delivery	5	38
12807	2019-11-03 19:29:30	2019-11-03	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4727	delivery	5	23
12808	2019-11-03 19:56:31	2019-11-03	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2434	delivery	5	30
12809	2019-11-03 19:56:43	2019-11-03	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1371	pick-up	0	29
12810	2019-11-03 20:26:04	2019-11-03	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3248	pick-up	0	31
12811	2019-11-03 20:26:11	2019-11-03	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":2}]	4741	delivery	5	26
12812	2019-11-03 20:33:15	2019-11-03	17	[{"id_menu":4,"count":1}]	1688	delivery	5	22
12813	2019-11-03 20:39:00	2019-11-03	14	[{"id_menu":2,"count":1}]	997	pick-up	0	14
12814	2019-11-03 20:49:46	2019-11-03	17	[{"id_menu":4,"count":1}]	4753	pick-up	0	17
12815	2019-11-03 20:54:18	2019-11-03	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2954	pick-up	0	20
12816	2019-11-03 21:00:27	2019-11-03	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2916	pick-up	0	34
12817	2019-11-03 21:15:43	2019-11-03	17	[{"id_menu":4,"count":1}]	4735	pick-up	0	17
12818	2019-11-03 21:58:00	2019-11-03	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4729	delivery	5	39
12819	2019-11-03 22:25:20	2019-11-03	9	[{"id_menu":7,"count":1}]	2477	pick-up	0	9
12820	2019-11-03 22:26:05	2019-11-03	14	[{"id_menu":2,"count":1}]	1085	delivery	5	19
12821	2019-11-03 22:29:33	2019-11-03	12	[{"id_menu":3,"count":1}]	1704	pick-up	0	12
12822	2019-11-03 22:35:16	2019-11-03	41	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3227	pick-up	0	41
12823	2019-11-03 22:42:35	2019-11-03	12	[{"id_menu":1,"count":1}]	1685	delivery	5	17
12824	2019-11-03 22:43:09	2019-11-03	14	[{"id_menu":2,"count":1}]	4590	pick-up	0	14
12825	2019-11-03 22:43:28	2019-11-03	17	[{"id_menu":4,"count":1}]	1025	pick-up	0	17
12826	2019-11-03 22:51:13	2019-11-03	8	[{"id_menu":5,"count":1}]	3614	delivery	5	13
12827	2019-11-03 23:00:33	2019-11-03	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	444	pick-up	0	25
12828	2019-11-03 23:04:32	2019-11-03	14	[{"id_menu":2,"count":1}]	4761	delivery	5	19
12829	2019-11-03 23:18:00	2019-11-03	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	4122	pick-up	0	21
12830	2019-11-03 23:18:53	2019-11-03	12	[{"id_menu":1,"count":1}]	4739	delivery	5	17
12831	2019-11-03 23:28:10	2019-11-03	17	[{"id_menu":4,"count":1}]	1441	delivery	5	22
12832	2019-11-03 23:35:59	2019-11-03	12	[{"id_menu":3,"count":1}]	4557	delivery	5	17
12833	2019-11-03 23:42:29	2019-11-03	9	[{"id_menu":7,"count":1}]	3890	delivery	5	14
12834	2019-11-03 23:42:32	2019-11-03	17	[{"id_menu":4,"count":1}]	676	pick-up	0	17
12835	2019-11-03 23:45:27	2019-11-03	8	[{"id_menu":5,"count":1}]	4724	pick-up	0	8
12836	2019-11-03 23:49:31	2019-11-03	17	[{"id_menu":4,"count":1}]	369	pick-up	0	17
12837	2019-11-03 23:56:37	2019-11-03	12	[{"id_menu":3,"count":1}]	164	pick-up	0	12
12838	2019-11-03 23:58:16	2019-11-03	9	[{"id_menu":7,"count":1}]	1057	pick-up	0	9
12839	2019-11-04 00:11:45	2019-11-04	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	4559	delivery	5	34
12840	2019-11-04 00:53:12	2019-11-04	9	[{"id_menu":7,"count":1}]	4818	delivery	5	14
12841	2019-11-04 01:11:01	2019-11-04	12	[{"id_menu":1,"count":1}]	299	delivery	5	17
12842	2019-11-04 01:44:41	2019-11-04	12	[{"id_menu":3,"count":1}]	2813	pick-up	0	12
12843	2019-11-04 02:00:30	2019-11-04	9	[{"id_menu":7,"count":1}]	4776	delivery	5	14
12844	2019-11-04 02:02:13	2019-11-04	9	[{"id_menu":6,"count":1}]	4810	delivery	5	14
12845	2019-11-04 02:08:46	2019-11-04	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	21	pick-up	0	25
12846	2019-11-04 02:33:09	2019-11-04	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	4817	pick-up	0	21
12847	2019-11-04 03:00:49	2019-11-04	8	[{"id_menu":5,"count":1}]	4786	delivery	5	13
12848	2019-11-04 03:03:02	2019-11-04	12	[{"id_menu":1,"count":1}]	832	pick-up	0	12
12849	2019-11-04 04:10:51	2019-11-04	9	[{"id_menu":6,"count":1}]	4774	delivery	5	14
12850	2019-11-04 04:16:44	2019-11-04	9	[{"id_menu":7,"count":1}]	4798	pick-up	0	9
12851	2019-11-04 05:54:31	2019-11-04	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4714	pick-up	0	31
12852	2019-11-04 06:03:49	2019-11-04	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1153	delivery	5	22
12853	2019-11-04 06:08:02	2019-11-04	12	[{"id_menu":1,"count":1}]	4789	pick-up	0	12
12854	2019-11-04 06:22:02	2019-11-04	17	[{"id_menu":4,"count":1}]	1963	pick-up	0	17
12855	2019-11-04 06:29:43	2019-11-04	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4807	delivery	5	42
12856	2019-11-04 06:39:48	2019-11-04	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	833	delivery	5	40
12857	2019-11-04 06:49:10	2019-11-04	9	[{"id_menu":7,"count":1}]	3720	pick-up	0	9
12858	2019-11-04 06:56:40	2019-11-04	14	[{"id_menu":2,"count":1}]	4819	delivery	5	19
12859	2019-11-04 07:29:46	2019-11-04	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2420	pick-up	0	43
12860	2019-11-04 07:40:44	2019-11-04	14	[{"id_menu":2,"count":1}]	4812	pick-up	0	14
12861	2019-11-04 08:37:40	2019-11-04	17	[{"id_menu":4,"count":1}]	4780	pick-up	0	17
12862	2019-11-04 08:41:41	2019-11-04	9	[{"id_menu":6,"count":1}]	2863	delivery	5	14
12863	2019-11-04 08:46:05	2019-11-04	12	[{"id_menu":3,"count":1}]	1053	delivery	5	17
12864	2019-11-04 08:50:16	2019-11-04	9	[{"id_menu":7,"count":1}]	2794	pick-up	0	9
12865	2019-11-04 09:11:24	2019-11-04	9	[{"id_menu":7,"count":1}]	4801	pick-up	0	9
12866	2019-11-04 09:18:42	2019-11-04	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	3901	delivery	5	40
12867	2019-11-04 09:19:31	2019-11-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	655	delivery	5	28
12868	2019-11-04 09:25:51	2019-11-04	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4799	delivery	5	23
12869	2019-11-04 09:30:35	2019-11-04	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	917	delivery	5	26
12870	2019-11-04 09:35:35	2019-11-04	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	204	pick-up	0	21
12871	2019-11-04 09:53:44	2019-11-04	12	[{"id_menu":3,"count":1}]	379	delivery	5	17
12872	2019-11-04 10:12:03	2019-11-04	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4007	pick-up	0	26
12873	2019-11-04 10:25:17	2019-11-04	9	[{"id_menu":6,"count":2}]	4788	delivery	5	14
12874	2019-11-04 10:33:51	2019-11-04	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4811	delivery	5	37
12875	2019-11-04 11:01:42	2019-11-04	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	2889	pick-up	0	26
12876	2019-11-04 11:03:15	2019-11-04	9	[{"id_menu":7,"count":1}]	4795	delivery	5	14
12877	2019-11-04 11:08:10	2019-11-04	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4792	delivery	5	43
12878	2019-11-04 11:19:46	2019-11-04	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	964	delivery	5	22
12879	2019-11-04 11:36:23	2019-11-04	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3205	pick-up	0	32
12880	2019-11-04 11:42:07	2019-11-04	8	[{"id_menu":5,"count":1}]	4797	delivery	5	13
12881	2019-11-04 11:49:36	2019-11-04	17	[{"id_menu":4,"count":1}]	1167	delivery	5	22
12882	2019-11-04 11:53:00	2019-11-04	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4808	delivery	5	23
12883	2019-11-04 12:10:25	2019-11-04	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	466	delivery	5	35
12884	2019-11-04 12:11:38	2019-11-04	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4796	delivery	5	22
12885	2019-11-04 12:21:37	2019-11-04	8	[{"id_menu":5,"count":1}]	3863	pick-up	0	8
12886	2019-11-04 12:43:20	2019-11-04	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3101	delivery	5	31
12887	2019-11-04 13:34:19	2019-11-04	9	[{"id_menu":6,"count":1}]	1000	delivery	5	14
12888	2019-11-04 13:34:31	2019-11-04	14	[{"id_menu":2,"count":1}]	1140	delivery	5	19
12889	2019-11-04 13:44:10	2019-11-04	9	[{"id_menu":6,"count":1}]	592	pick-up	0	9
12890	2019-11-04 13:49:12	2019-11-04	9	[{"id_menu":7,"count":1}]	4804	pick-up	0	9
12891	2019-11-04 13:56:48	2019-11-04	9	[{"id_menu":7,"count":1}]	4800	pick-up	0	9
12892	2019-11-04 14:14:39	2019-11-04	12	[{"id_menu":1,"count":1}]	4783	pick-up	0	12
12893	2019-11-04 14:14:47	2019-11-04	8	[{"id_menu":5,"count":1}]	4790	pick-up	0	8
12894	2019-11-04 15:00:58	2019-11-04	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4815	delivery	5	22
12895	2019-11-04 15:05:52	2019-11-04	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	2653	pick-up	0	21
12896	2019-11-04 15:18:43	2019-11-04	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	4778	delivery	5	26
12897	2019-11-04 15:25:36	2019-11-04	8	[{"id_menu":5,"count":1}]	2807	pick-up	0	8
12898	2019-11-04 16:20:21	2019-11-04	17	[{"id_menu":4,"count":1}]	889	delivery	5	22
12899	2019-11-04 16:56:38	2019-11-04	9	[{"id_menu":6,"count":1}]	63	delivery	5	14
12900	2019-11-04 17:23:12	2019-11-04	12	[{"id_menu":1,"count":1}]	2649	delivery	5	17
12901	2019-11-04 17:31:31	2019-11-04	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4802	delivery	5	43
12902	2019-11-04 17:32:18	2019-11-04	9	[{"id_menu":6,"count":1}]	4116	delivery	5	14
12903	2019-11-04 17:59:27	2019-11-04	9	[{"id_menu":6,"count":1}]	3180	pick-up	0	9
12904	2019-11-04 18:04:39	2019-11-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4793	delivery	5	28
12905	2019-11-04 18:18:39	2019-11-04	12	[{"id_menu":3,"count":1}]	4794	delivery	5	17
12906	2019-11-04 19:33:43	2019-11-04	9	[{"id_menu":7,"count":1}]	1337	pick-up	0	9
12907	2019-11-04 19:46:39	2019-11-04	9	[{"id_menu":7,"count":1}]	4784	delivery	5	14
12908	2019-11-04 20:23:03	2019-11-04	8	[{"id_menu":5,"count":1}]	2264	delivery	5	13
12909	2019-11-04 20:28:49	2019-11-04	12	[{"id_menu":3,"count":1}]	2990	delivery	5	17
12910	2019-11-04 20:56:17	2019-11-04	17	[{"id_menu":4,"count":1}]	2000	delivery	5	22
12911	2019-11-04 21:01:14	2019-11-04	12	[{"id_menu":3,"count":1}]	4806	delivery	5	17
12912	2019-11-04 21:05:27	2019-11-04	12	[{"id_menu":3,"count":1}]	4813	delivery	5	17
12913	2019-11-04 21:10:11	2019-11-04	9	[{"id_menu":6,"count":1}]	1122	delivery	5	14
12914	2019-11-04 21:22:42	2019-11-04	17	[{"id_menu":4,"count":1}]	4444	pick-up	0	17
12915	2019-11-04 21:22:49	2019-11-04	17	[{"id_menu":4,"count":1}]	1048	delivery	5	22
12916	2019-11-04 21:26:10	2019-11-04	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	220	pick-up	0	31
12917	2019-11-04 22:09:36	2019-11-04	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	822	delivery	5	38
12918	2019-11-04 23:10:46	2019-11-04	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	486	pick-up	0	26
12919	2019-11-04 23:21:12	2019-11-04	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	4524	pick-up	0	26
12920	2019-11-05 00:14:18	2019-11-05	17	[{"id_menu":4,"count":1}]	3906	pick-up	0	17
12921	2019-11-05 00:16:36	2019-11-05	9	[{"id_menu":6,"count":2}]	3234	delivery	5	14
12922	2019-11-05 00:30:27	2019-11-05	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	542	delivery	5	23
12923	2019-11-05 00:44:59	2019-11-05	17	[{"id_menu":4,"count":1}]	2776	pick-up	0	17
12924	2019-11-05 00:53:00	2019-11-05	17	[{"id_menu":4,"count":1}]	4461	delivery	5	22
12925	2019-11-05 01:02:48	2019-11-05	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1119	pick-up	0	21
12926	2019-11-05 01:11:18	2019-11-05	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	2855	pick-up	0	30
12927	2019-11-05 01:13:42	2019-11-05	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	580	pick-up	0	40
12928	2019-11-05 01:22:42	2019-11-05	9	[{"id_menu":7,"count":1}]	491	delivery	5	14
12929	2019-11-05 01:55:33	2019-11-05	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	260	pick-up	0	31
12930	2019-11-05 02:09:15	2019-11-05	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":2}]	4831	delivery	5	31
12931	2019-11-05 02:14:34	2019-11-05	9	[{"id_menu":7,"count":1}]	4496	pick-up	0	9
12932	2019-11-05 02:45:31	2019-11-05	17	[{"id_menu":4,"count":1}]	856	pick-up	0	17
12933	2019-11-05 03:49:38	2019-11-05	12	[{"id_menu":3,"count":1}]	4823	pick-up	0	12
12934	2019-11-05 03:57:21	2019-11-05	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4802	delivery	5	43
12935	2019-11-05 04:29:40	2019-11-05	12	[{"id_menu":3,"count":1}]	4833	pick-up	0	12
12936	2019-11-05 04:37:35	2019-11-05	9	[{"id_menu":6,"count":2}]	1025	delivery	5	14
12937	2019-11-05 04:53:27	2019-11-05	12	[{"id_menu":3,"count":1}]	1088	pick-up	0	12
12938	2019-11-05 05:22:31	2019-11-05	17	[{"id_menu":4,"count":1}]	3394	pick-up	0	17
12939	2019-11-05 05:44:12	2019-11-05	12	[{"id_menu":1,"count":1}]	1076	pick-up	0	12
12940	2019-11-05 05:47:20	2019-11-05	14	[{"id_menu":2,"count":1}]	400	pick-up	0	14
12941	2019-11-05 05:51:58	2019-11-05	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	512	delivery	5	26
12942	2019-11-05 06:02:05	2019-11-05	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4824	delivery	5	30
12943	2019-11-05 06:28:52	2019-11-05	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	2083	pick-up	0	35
12944	2019-11-05 06:36:38	2019-11-05	17	[{"id_menu":4,"count":1}]	3148	pick-up	0	17
12945	2019-11-05 06:41:57	2019-11-05	12	[{"id_menu":1,"count":1}]	4653	delivery	5	17
12946	2019-11-05 07:07:37	2019-11-05	17	[{"id_menu":4,"count":1}]	980	pick-up	0	17
12947	2019-11-05 07:09:40	2019-11-05	12	[{"id_menu":3,"count":1}]	4834	pick-up	0	12
12948	2019-11-05 07:13:24	2019-11-05	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4043	delivery	5	22
12949	2019-11-05 07:16:53	2019-11-05	9	[{"id_menu":7,"count":1}]	4846	pick-up	0	9
12950	2019-11-05 07:23:27	2019-11-05	9	[{"id_menu":7,"count":1}]	4853	delivery	5	14
12951	2019-11-05 07:33:40	2019-11-05	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	612	delivery	5	36
12952	2019-11-05 07:47:42	2019-11-05	12	[{"id_menu":1,"count":1}]	4370	pick-up	0	12
12953	2019-11-05 07:51:28	2019-11-05	9	[{"id_menu":6,"count":2}]	4860	delivery	5	14
12954	2019-11-05 07:57:55	2019-11-05	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3678	pick-up	0	29
12955	2019-11-05 08:00:08	2019-11-05	8	[{"id_menu":5,"count":1}]	4837	delivery	5	13
12956	2019-11-05 08:10:23	2019-11-05	9	[{"id_menu":6,"count":1}]	4825	pick-up	0	9
12957	2019-11-05 08:19:53	2019-11-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3553	delivery	5	23
12958	2019-11-05 08:42:59	2019-11-05	12	[{"id_menu":1,"count":2}]	3258	delivery	5	17
12959	2019-11-05 08:48:01	2019-11-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4845	delivery	5	23
12960	2019-11-05 09:23:17	2019-11-05	14	[{"id_menu":2,"count":1}]	4852	delivery	5	19
12961	2019-11-05 10:20:48	2019-11-05	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	304	delivery	5	26
12962	2019-11-05 10:22:45	2019-11-05	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2867	pick-up	0	26
12963	2019-11-05 10:26:14	2019-11-05	14	[{"id_menu":2,"count":1}]	4861	delivery	5	19
12964	2019-11-05 10:53:28	2019-11-05	9	[{"id_menu":6,"count":1}]	4820	delivery	5	14
12965	2019-11-05 11:08:56	2019-11-05	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4839	delivery	5	53
12966	2019-11-05 11:36:07	2019-11-05	14	[{"id_menu":2,"count":1}]	3931	delivery	5	19
12967	2019-11-05 11:55:24	2019-11-05	14	[{"id_menu":2,"count":1}]	1260	delivery	5	19
12968	2019-11-05 12:09:09	2019-11-05	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4578	delivery	5	26
12969	2019-11-05 12:14:48	2019-11-05	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3996	delivery	5	28
12970	2019-11-05 12:29:06	2019-11-05	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4849	delivery	5	31
12971	2019-11-05 12:44:22	2019-11-05	17	[{"id_menu":4,"count":1}]	2556	delivery	5	22
12972	2019-11-05 12:55:05	2019-11-05	8	[{"id_menu":5,"count":1}]	4855	delivery	5	13
12973	2019-11-05 13:07:10	2019-11-05	9	[{"id_menu":7,"count":1}]	4854	pick-up	0	9
12974	2019-11-05 13:26:35	2019-11-05	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	826	pick-up	0	21
12975	2019-11-05 13:38:37	2019-11-05	17	[{"id_menu":4,"count":1}]	1093	delivery	5	22
12976	2019-11-05 13:43:32	2019-11-05	9	[{"id_menu":7,"count":1}]	4841	delivery	5	14
12977	2019-11-05 13:48:08	2019-11-05	8	[{"id_menu":5,"count":1}]	4821	delivery	5	13
12978	2019-11-05 13:52:38	2019-11-05	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	711	pick-up	0	21
12979	2019-11-05 14:02:47	2019-11-05	14	[{"id_menu":2,"count":1}]	2500	pick-up	0	14
12980	2019-11-05 14:39:14	2019-11-05	9	[{"id_menu":6,"count":1}]	2863	delivery	5	14
12981	2019-11-05 14:43:23	2019-11-05	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4832	delivery	5	39
12982	2019-11-05 14:58:42	2019-11-05	17	[{"id_menu":4,"count":1}]	295	pick-up	0	17
12983	2019-11-05 15:01:19	2019-11-05	12	[{"id_menu":1,"count":1}]	4842	delivery	5	17
12984	2019-11-05 15:15:08	2019-11-05	14	[{"id_menu":2,"count":1}]	1647	delivery	5	19
12985	2019-11-05 16:03:29	2019-11-05	9	[{"id_menu":6,"count":1}]	4629	delivery	5	14
12986	2019-11-05 16:06:17	2019-11-05	9	[{"id_menu":7,"count":1}]	1963	pick-up	0	9
12987	2019-11-05 16:23:06	2019-11-05	9	[{"id_menu":6,"count":2}]	2868	delivery	5	14
12988	2019-11-05 16:27:50	2019-11-05	14	[{"id_menu":2,"count":1}]	4844	delivery	5	19
12989	2019-11-05 16:46:38	2019-11-05	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1215	pick-up	0	31
12990	2019-11-05 16:52:14	2019-11-05	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1756	pick-up	0	39
12991	2019-11-05 16:55:49	2019-11-05	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1380	delivery	5	27
12992	2019-11-05 17:00:19	2019-11-05	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	4828	delivery	5	31
12993	2019-11-05 17:23:15	2019-11-05	8	[{"id_menu":5,"count":1}]	3151	pick-up	0	8
12994	2019-11-05 18:18:16	2019-11-05	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2527	delivery	5	26
12995	2019-11-05 18:21:14	2019-11-05	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	822	delivery	5	27
12996	2019-11-05 18:26:05	2019-11-05	8	[{"id_menu":5,"count":1}]	2056	delivery	5	13
12997	2019-11-05 18:45:30	2019-11-05	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	1970	pick-up	0	26
12998	2019-11-05 18:46:25	2019-11-05	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4836	delivery	5	55
12999	2019-11-05 18:49:47	2019-11-05	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4857	delivery	5	48
13000	2019-11-05 18:54:08	2019-11-05	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4116	delivery	5	43
13001	2019-11-05 19:06:27	2019-11-05	12	[{"id_menu":1,"count":1}]	2564	delivery	5	17
13002	2019-11-05 19:25:50	2019-11-05	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	479	delivery	5	53
13003	2019-11-05 19:26:26	2019-11-05	8	[{"id_menu":5,"count":1}]	4848	delivery	5	13
13004	2019-11-05 19:40:52	2019-11-05	14	[{"id_menu":2,"count":1}]	4843	pick-up	0	14
13005	2019-11-05 19:49:06	2019-11-05	17	[{"id_menu":4,"count":1}]	1338	pick-up	0	17
13006	2019-11-05 19:49:20	2019-11-05	17	[{"id_menu":4,"count":1}]	4786	delivery	5	22
13007	2019-11-05 20:08:51	2019-11-05	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	4851	delivery	5	28
13008	2019-11-05 20:38:42	2019-11-05	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4193	pick-up	0	37
13009	2019-11-05 21:09:18	2019-11-05	9	[{"id_menu":7,"count":1}]	3172	pick-up	0	9
13010	2019-11-05 21:24:06	2019-11-05	17	[{"id_menu":4,"count":1}]	1432	pick-up	0	17
13011	2019-11-05 21:28:41	2019-11-05	14	[{"id_menu":2,"count":1}]	4847	pick-up	0	14
13012	2019-11-05 21:37:42	2019-11-05	12	[{"id_menu":1,"count":1}]	3483	pick-up	0	12
13013	2019-11-05 22:23:36	2019-11-05	12	[{"id_menu":3,"count":1}]	2465	delivery	5	17
13014	2019-11-05 22:47:08	2019-11-05	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2237	pick-up	0	25
13015	2019-11-05 23:07:31	2019-11-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4859	delivery	5	31
13016	2019-11-05 23:43:56	2019-11-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3820	delivery	5	28
13017	2019-11-05 23:50:59	2019-11-05	9	[{"id_menu":7,"count":1}]	2367	pick-up	0	9
13018	2019-11-05 23:51:21	2019-11-05	14	[{"id_menu":2,"count":2}]	2080	delivery	5	19
13019	2019-11-06 00:24:14	2019-11-06	12	[{"id_menu":3,"count":1}]	1085	delivery	5	17
13020	2019-11-06 00:40:43	2019-11-06	9	[{"id_menu":7,"count":1}]	3006	delivery	5	14
13021	2019-11-06 00:55:21	2019-11-06	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	3680	pick-up	0	18
13022	2019-11-06 01:22:09	2019-11-06	17	[{"id_menu":4,"count":1}]	1909	pick-up	0	17
13023	2019-11-06 01:29:50	2019-11-06	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4889	pick-up	0	21
13024	2019-11-06 01:43:37	2019-11-06	14	[{"id_menu":2,"count":1}]	1406	pick-up	0	14
13025	2019-11-06 02:25:39	2019-11-06	17	[{"id_menu":4,"count":1}]	4867	delivery	5	22
13026	2019-11-06 02:40:11	2019-11-06	12	[{"id_menu":1,"count":1}]	4872	pick-up	0	12
13027	2019-11-06 02:40:42	2019-11-06	9	[{"id_menu":6,"count":1}]	4890	delivery	5	14
13028	2019-11-06 03:05:47	2019-11-06	9	[{"id_menu":6,"count":1}]	4900	delivery	5	14
13029	2019-11-06 03:11:11	2019-11-06	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	822	pick-up	0	18
13030	2019-11-06 03:25:36	2019-11-06	9	[{"id_menu":7,"count":1}]	2965	delivery	5	14
13031	2019-11-06 03:26:30	2019-11-06	14	[{"id_menu":2,"count":2}]	3984	delivery	5	19
13032	2019-11-06 03:39:14	2019-11-06	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2792	delivery	5	25
13033	2019-11-06 03:40:38	2019-11-06	9	[{"id_menu":7,"count":1}]	4595	pick-up	0	9
13034	2019-11-06 03:57:59	2019-11-06	12	[{"id_menu":3,"count":1}]	4223	delivery	5	17
13035	2019-11-06 04:15:37	2019-11-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4877	delivery	5	28
13036	2019-11-06 04:33:27	2019-11-06	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4880	delivery	5	39
13037	2019-11-06 04:37:48	2019-11-06	8	[{"id_menu":5,"count":1}]	531	pick-up	0	8
13038	2019-11-06 04:38:31	2019-11-06	14	[{"id_menu":2,"count":1}]	932	pick-up	0	14
13039	2019-11-06 05:09:04	2019-11-06	12	[{"id_menu":1,"count":1}]	1427	delivery	5	17
13040	2019-11-06 06:01:00	2019-11-06	8	[{"id_menu":5,"count":1}]	4353	pick-up	0	8
13041	2019-11-06 06:04:24	2019-11-06	14	[{"id_menu":2,"count":1}]	569	delivery	5	19
13042	2019-11-06 06:07:51	2019-11-06	17	[{"id_menu":4,"count":1}]	4902	delivery	5	22
13043	2019-11-06 06:10:52	2019-11-06	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1289	pick-up	0	26
13044	2019-11-06 06:10:54	2019-11-06	9	[{"id_menu":7,"count":1}]	2807	pick-up	0	9
13045	2019-11-06 06:25:57	2019-11-06	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1941	pick-up	0	29
13046	2019-11-06 06:51:29	2019-11-06	17	[{"id_menu":4,"count":1}]	200	pick-up	0	17
13047	2019-11-06 07:17:59	2019-11-06	9	[{"id_menu":7,"count":1}]	2221	pick-up	0	9
13048	2019-11-06 07:25:42	2019-11-06	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1280	pick-up	0	35
13049	2019-11-06 07:28:04	2019-11-06	17	[{"id_menu":4,"count":1}]	2570	pick-up	0	17
13050	2019-11-06 07:40:26	2019-11-06	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1115	delivery	5	31
13051	2019-11-06 07:43:52	2019-11-06	9	[{"id_menu":6,"count":1}]	2414	pick-up	0	9
13052	2019-11-06 07:44:31	2019-11-06	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1820	delivery	5	35
13053	2019-11-06 08:13:26	2019-11-06	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	677	delivery	5	31
13054	2019-11-06 08:15:39	2019-11-06	9	[{"id_menu":6,"count":2}]	4868	delivery	5	14
13055	2019-11-06 08:18:58	2019-11-06	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	4870	pick-up	0	24
13056	2019-11-06 08:31:08	2019-11-06	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4892	delivery	5	22
13057	2019-11-06 08:33:25	2019-11-06	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4905	delivery	5	43
13058	2019-11-06 08:39:16	2019-11-06	9	[{"id_menu":6,"count":1}]	1066	delivery	5	14
13059	2019-11-06 09:09:31	2019-11-06	12	[{"id_menu":3,"count":1}]	1832	pick-up	0	12
13060	2019-11-06 09:23:05	2019-11-06	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	4873	delivery	5	28
13061	2019-11-06 09:24:52	2019-11-06	8	[{"id_menu":5,"count":1}]	4866	delivery	5	13
13062	2019-11-06 09:27:15	2019-11-06	9	[{"id_menu":6,"count":1}]	4907	delivery	5	14
13063	2019-11-06 09:29:33	2019-11-06	17	[{"id_menu":4,"count":1}]	4906	pick-up	0	17
13064	2019-11-06 09:30:53	2019-11-06	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1514	delivery	5	23
13065	2019-11-06 09:32:20	2019-11-06	17	[{"id_menu":4,"count":1}]	2146	pick-up	0	17
13066	2019-11-06 09:41:10	2019-11-06	12	[{"id_menu":3,"count":1}]	4887	delivery	5	17
13067	2019-11-06 09:43:14	2019-11-06	17	[{"id_menu":4,"count":1}]	3578	pick-up	0	17
13068	2019-11-06 10:06:04	2019-11-06	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2627	pick-up	0	34
13069	2019-11-06 10:10:00	2019-11-06	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	3635	pick-up	0	26
13070	2019-11-06 11:14:09	2019-11-06	9	[{"id_menu":6,"count":1}]	1433	delivery	5	14
13071	2019-11-06 11:16:10	2019-11-06	12	[{"id_menu":3,"count":1}]	4888	delivery	5	17
13072	2019-11-06 11:43:01	2019-11-06	14	[{"id_menu":2,"count":1}]	2278	delivery	5	19
13073	2019-11-06 11:57:55	2019-11-06	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4878	delivery	5	37
13074	2019-11-06 12:18:00	2019-11-06	14	[{"id_menu":2,"count":1}]	4891	pick-up	0	14
13075	2019-11-06 12:19:12	2019-11-06	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4901	pick-up	0	25
13076	2019-11-06 12:19:35	2019-11-06	17	[{"id_menu":4,"count":1}]	4894	delivery	5	22
13077	2019-11-06 12:48:26	2019-11-06	17	[{"id_menu":4,"count":1}]	4864	delivery	5	22
13078	2019-11-06 13:00:19	2019-11-06	12	[{"id_menu":3,"count":1}]	4411	pick-up	0	12
13079	2019-11-06 13:01:27	2019-11-06	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2752	pick-up	0	25
13080	2019-11-06 13:24:56	2019-11-06	14	[{"id_menu":2,"count":1}]	4885	delivery	5	19
13081	2019-11-06 13:29:00	2019-11-06	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4042	pick-up	0	39
13082	2019-11-06 13:33:55	2019-11-06	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	1557	pick-up	0	29
13083	2019-11-06 13:39:03	2019-11-06	9	[{"id_menu":6,"count":1}]	757	delivery	5	14
13084	2019-11-06 13:40:49	2019-11-06	12	[{"id_menu":1,"count":1}]	4863	pick-up	0	12
13085	2019-11-06 13:53:07	2019-11-06	17	[{"id_menu":4,"count":1}]	754	pick-up	0	17
13086	2019-11-06 14:19:29	2019-11-06	9	[{"id_menu":6,"count":1}]	826	pick-up	0	9
13087	2019-11-06 14:30:59	2019-11-06	14	[{"id_menu":2,"count":1}]	2244	pick-up	0	14
13088	2019-11-06 14:51:03	2019-11-06	14	[{"id_menu":2,"count":1}]	1015	pick-up	0	14
13089	2019-11-06 14:52:54	2019-11-06	9	[{"id_menu":7,"count":1}]	4881	delivery	5	14
13090	2019-11-06 15:00:26	2019-11-06	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1241	delivery	5	39
13091	2019-11-06 15:03:57	2019-11-06	9	[{"id_menu":6,"count":1}]	4904	pick-up	0	9
13092	2019-11-06 16:01:21	2019-11-06	14	[{"id_menu":2,"count":1}]	4874	pick-up	0	14
13093	2019-11-06 16:14:08	2019-11-06	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1092	delivery	5	43
13094	2019-11-06 16:35:49	2019-11-06	8	[{"id_menu":5,"count":1}]	872	delivery	5	13
13095	2019-11-06 16:36:08	2019-11-06	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3823	delivery	5	31
13096	2019-11-06 16:36:42	2019-11-06	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4903	delivery	5	44
13097	2019-11-06 16:39:36	2019-11-06	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2980	pick-up	0	29
13098	2019-11-06 16:58:18	2019-11-06	12	[{"id_menu":3,"count":1}]	4899	delivery	5	17
13099	2019-11-06 17:25:52	2019-11-06	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4876	delivery	5	51
13100	2019-11-06 17:36:11	2019-11-06	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	4284	delivery	5	31
13101	2019-11-06 17:44:39	2019-11-06	14	[{"id_menu":2,"count":1}]	1548	pick-up	0	14
13102	2019-11-06 17:55:47	2019-11-06	12	[{"id_menu":1,"count":1}]	2798	delivery	5	17
13103	2019-11-06 17:58:31	2019-11-06	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	4727	delivery	5	35
13104	2019-11-06 18:27:51	2019-11-06	14	[{"id_menu":2,"count":1}]	773	pick-up	0	14
13105	2019-11-06 19:06:24	2019-11-06	12	[{"id_menu":3,"count":1}]	4453	pick-up	0	12
13106	2019-11-06 19:08:28	2019-11-06	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	285	pick-up	0	26
13107	2019-11-06 19:15:21	2019-11-06	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	728	pick-up	0	34
13108	2019-11-06 19:17:24	2019-11-06	17	[{"id_menu":4,"count":1}]	81	pick-up	0	17
13109	2019-11-06 19:33:22	2019-11-06	9	[{"id_menu":7,"count":1}]	787	delivery	5	14
13110	2019-11-06 19:33:58	2019-11-06	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4121	pick-up	0	26
13111	2019-11-06 19:49:43	2019-11-06	14	[{"id_menu":2,"count":1}]	4898	delivery	5	19
13112	2019-11-06 20:01:00	2019-11-06	14	[{"id_menu":2,"count":1}]	4875	delivery	5	19
13113	2019-11-06 20:48:47	2019-11-06	17	[{"id_menu":4,"count":1}]	2692	pick-up	0	17
13114	2019-11-06 20:51:57	2019-11-06	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4149	delivery	5	35
13115	2019-11-06 21:25:13	2019-11-06	17	[{"id_menu":4,"count":1}]	4896	delivery	5	22
13116	2019-11-06 21:40:38	2019-11-06	8	[{"id_menu":5,"count":2}]	4879	delivery	5	13
13117	2019-11-06 22:00:31	2019-11-06	14	[{"id_menu":2,"count":1}]	4742	delivery	5	19
13118	2019-11-06 22:22:39	2019-11-06	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	2843	delivery	5	31
13119	2019-11-06 22:33:08	2019-11-06	14	[{"id_menu":2,"count":1}]	401	pick-up	0	14
13120	2019-11-06 22:33:31	2019-11-06	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1486	pick-up	0	20
13121	2019-11-06 22:44:10	2019-11-06	8	[{"id_menu":5,"count":1}]	4869	pick-up	0	8
13122	2019-11-06 23:07:57	2019-11-06	14	[{"id_menu":2,"count":1}]	4862	pick-up	0	14
13123	2019-11-06 23:35:03	2019-11-06	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":2}]	1951	delivery	5	31
13124	2019-11-06 23:35:30	2019-11-06	14	[{"id_menu":2,"count":1}]	1822	delivery	5	19
13125	2019-11-06 23:40:27	2019-11-06	9	[{"id_menu":7,"count":1}]	4895	delivery	5	14
13126	2019-11-06 23:54:24	2019-11-06	9	[{"id_menu":7,"count":1}]	1170	pick-up	0	9
13127	2019-11-06 23:59:17	2019-11-06	9	[{"id_menu":7,"count":1}]	4883	delivery	5	14
13128	2019-11-07 00:00:18	2019-11-07	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4023	delivery	5	27
13129	2019-11-07 00:57:19	2019-11-07	55	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2242	pick-up	0	55
13130	2019-11-07 01:33:38	2019-11-07	9	[{"id_menu":6,"count":1}]	3968	pick-up	0	9
13131	2019-11-07 01:40:19	2019-11-07	12	[{"id_menu":1,"count":1}]	3385	pick-up	0	12
13132	2019-11-07 01:44:52	2019-11-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3301	delivery	5	23
13133	2019-11-07 01:46:25	2019-11-07	12	[{"id_menu":3,"count":1}]	4916	pick-up	0	12
13134	2019-11-07 02:01:27	2019-11-07	17	[{"id_menu":4,"count":1}]	4658	delivery	5	22
13135	2019-11-07 02:11:20	2019-11-07	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4915	delivery	5	49
13136	2019-11-07 02:20:13	2019-11-07	17	[{"id_menu":4,"count":1}]	4926	delivery	5	22
13137	2019-11-07 02:32:13	2019-11-07	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	4943	pick-up	0	26
13138	2019-11-07 02:37:20	2019-11-07	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	4948	delivery	5	25
13139	2019-11-07 02:52:20	2019-11-07	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1540	pick-up	0	21
13140	2019-11-07 03:00:19	2019-11-07	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	4955	pick-up	0	26
13141	2019-11-07 03:08:07	2019-11-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2911	delivery	5	22
13142	2019-11-07 03:13:19	2019-11-07	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	4549	delivery	5	25
13143	2019-11-07 03:15:45	2019-11-07	8	[{"id_menu":5,"count":1}]	4910	delivery	5	13
13144	2019-11-07 03:22:50	2019-11-07	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	2198	pick-up	0	33
13145	2019-11-07 03:38:19	2019-11-07	12	[{"id_menu":3,"count":1}]	1489	pick-up	0	12
13146	2019-11-07 04:06:43	2019-11-07	9	[{"id_menu":7,"count":1}]	1670	pick-up	0	9
13147	2019-11-07 04:17:12	2019-11-07	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	4651	pick-up	0	26
13148	2019-11-07 04:17:59	2019-11-07	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3865	delivery	5	40
13149	2019-11-07 04:27:21	2019-11-07	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	4697	delivery	5	31
13150	2019-11-07 04:27:26	2019-11-07	8	[{"id_menu":5,"count":1}]	3895	delivery	5	13
13151	2019-11-07 05:03:51	2019-11-07	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	4924	delivery	5	40
13152	2019-11-07 05:16:00	2019-11-07	12	[{"id_menu":1,"count":1}]	1140	delivery	5	17
13153	2019-11-07 05:39:17	2019-11-07	14	[{"id_menu":2,"count":1}]	1392	pick-up	0	14
13154	2019-11-07 05:42:26	2019-11-07	17	[{"id_menu":4,"count":1}]	1434	delivery	5	22
13155	2019-11-07 05:47:37	2019-11-07	9	[{"id_menu":6,"count":1}]	4735	delivery	5	14
13156	2019-11-07 06:03:09	2019-11-07	17	[{"id_menu":4,"count":1}]	1369	pick-up	0	17
13157	2019-11-07 06:33:08	2019-11-07	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	4942	pick-up	0	29
13158	2019-11-07 06:33:54	2019-11-07	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4925	delivery	5	40
13159	2019-11-07 06:57:13	2019-11-07	8	[{"id_menu":5,"count":1}]	4805	delivery	5	13
13160	2019-11-07 07:01:15	2019-11-07	8	[{"id_menu":5,"count":1}]	1529	delivery	5	13
13161	2019-11-07 07:18:25	2019-11-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	454	delivery	5	28
13162	2019-11-07 07:23:19	2019-11-07	9	[{"id_menu":6,"count":1}]	976	pick-up	0	9
13163	2019-11-07 07:35:14	2019-11-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2672	delivery	5	23
13164	2019-11-07 08:37:15	2019-11-07	12	[{"id_menu":1,"count":1}]	4950	pick-up	0	12
13165	2019-11-07 08:51:41	2019-11-07	17	[{"id_menu":4,"count":1}]	4929	pick-up	0	17
13166	2019-11-07 08:58:47	2019-11-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	4854	pick-up	0	21
13167	2019-11-07 08:59:55	2019-11-07	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	640	delivery	5	26
13168	2019-11-07 09:05:18	2019-11-07	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4458	delivery	5	45
13169	2019-11-07 09:15:41	2019-11-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2413	pick-up	0	21
13170	2019-11-07 09:39:36	2019-11-07	17	[{"id_menu":4,"count":1}]	1731	pick-up	0	17
13171	2019-11-07 10:12:10	2019-11-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3142	delivery	5	23
13172	2019-11-07 10:17:52	2019-11-07	17	[{"id_menu":4,"count":1}]	4281	delivery	5	22
13173	2019-11-07 10:27:14	2019-11-07	17	[{"id_menu":4,"count":1}]	2423	delivery	5	22
13174	2019-11-07 10:38:01	2019-11-07	17	[{"id_menu":4,"count":1}]	1684	delivery	5	22
13175	2019-11-07 10:42:26	2019-11-07	14	[{"id_menu":2,"count":1}]	2169	pick-up	0	14
13176	2019-11-07 10:54:04	2019-11-07	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	2438	pick-up	0	30
13177	2019-11-07 10:55:29	2019-11-07	14	[{"id_menu":2,"count":1}]	4952	delivery	5	19
13178	2019-11-07 11:01:49	2019-11-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4944	delivery	5	23
13179	2019-11-07 11:02:58	2019-11-07	14	[{"id_menu":2,"count":1}]	2889	pick-up	0	14
13180	2019-11-07 11:03:01	2019-11-07	9	[{"id_menu":6,"count":1}]	1256	delivery	5	14
13181	2019-11-07 11:29:16	2019-11-07	8	[{"id_menu":5,"count":1}]	4914	pick-up	0	8
13182	2019-11-07 11:47:50	2019-11-07	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	376	delivery	5	34
13183	2019-11-07 11:49:03	2019-11-07	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3477	pick-up	0	26
13184	2019-11-07 11:54:39	2019-11-07	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4919	delivery	5	45
13185	2019-11-07 12:25:56	2019-11-07	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	4911	delivery	5	43
13186	2019-11-07 12:28:54	2019-11-07	8	[{"id_menu":5,"count":1}]	2928	pick-up	0	8
13187	2019-11-07 12:31:52	2019-11-07	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3126	pick-up	0	21
13188	2019-11-07 13:07:34	2019-11-07	14	[{"id_menu":2,"count":1}]	4912	delivery	5	19
13189	2019-11-07 13:13:48	2019-11-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	4567	delivery	5	26
13190	2019-11-07 13:14:41	2019-11-07	12	[{"id_menu":1,"count":1}]	3117	delivery	5	17
13191	2019-11-07 13:21:26	2019-11-07	14	[{"id_menu":2,"count":1}]	4939	delivery	5	19
13192	2019-11-07 13:22:04	2019-11-07	8	[{"id_menu":5,"count":1}]	4951	delivery	5	13
13193	2019-11-07 13:52:41	2019-11-07	9	[{"id_menu":7,"count":1}]	4921	pick-up	0	9
13194	2019-11-07 14:00:20	2019-11-07	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4953	delivery	5	26
13195	2019-11-07 14:09:24	2019-11-07	12	[{"id_menu":3,"count":1}]	3255	pick-up	0	12
13196	2019-11-07 14:20:58	2019-11-07	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	4580	delivery	5	26
13197	2019-11-07 14:36:30	2019-11-07	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	4917	delivery	5	31
13198	2019-11-07 14:43:42	2019-11-07	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2472	pick-up	0	25
13199	2019-11-07 14:46:40	2019-11-07	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2605	delivery	5	53
13200	2019-11-07 14:53:46	2019-11-07	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	4922	delivery	5	31
13201	2019-11-07 15:08:11	2019-11-07	9	[{"id_menu":6,"count":2}]	4932	delivery	5	14
13202	2019-11-07 15:10:20	2019-11-07	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2507	delivery	5	22
13203	2019-11-07 15:35:19	2019-11-07	9	[{"id_menu":6,"count":1}]	2547	pick-up	0	9
13204	2019-11-07 15:49:24	2019-11-07	14	[{"id_menu":2,"count":1}]	1360	delivery	5	19
13205	2019-11-07 15:49:33	2019-11-07	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4931	delivery	5	30
13206	2019-11-07 15:51:40	2019-11-07	14	[{"id_menu":2,"count":1}]	862	pick-up	0	14
13207	2019-11-07 15:53:27	2019-11-07	14	[{"id_menu":2,"count":1}]	80	pick-up	0	14
13208	2019-11-07 15:59:36	2019-11-07	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1952	delivery	5	31
13209	2019-11-07 16:05:54	2019-11-07	17	[{"id_menu":4,"count":1}]	4938	delivery	5	22
13210	2019-11-07 16:23:55	2019-11-07	14	[{"id_menu":2,"count":1}]	4670	delivery	5	19
13211	2019-11-07 16:38:01	2019-11-07	9	[{"id_menu":6,"count":1}]	2252	delivery	5	14
13212	2019-11-07 16:45:19	2019-11-07	12	[{"id_menu":1,"count":1}]	3228	delivery	5	17
13213	2019-11-07 17:02:54	2019-11-07	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	4708	delivery	5	35
13214	2019-11-07 17:07:12	2019-11-07	12	[{"id_menu":3,"count":1}]	4949	delivery	5	17
13215	2019-11-07 17:22:21	2019-11-07	12	[{"id_menu":3,"count":1}]	4920	delivery	5	17
13216	2019-11-07 17:38:00	2019-11-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1944	delivery	5	22
13217	2019-11-07 17:54:55	2019-11-07	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3623	delivery	5	31
13218	2019-11-07 18:03:17	2019-11-07	17	[{"id_menu":4,"count":1}]	4261	pick-up	0	17
13219	2019-11-07 18:06:33	2019-11-07	8	[{"id_menu":5,"count":1}]	2358	pick-up	0	8
13220	2019-11-07 18:08:35	2019-11-07	14	[{"id_menu":2,"count":2}]	3883	delivery	5	19
13221	2019-11-07 18:10:24	2019-11-07	9	[{"id_menu":6,"count":1}]	4918	delivery	5	14
13222	2019-11-07 18:12:33	2019-11-07	14	[{"id_menu":2,"count":1}]	841	delivery	5	19
13223	2019-11-07 18:26:13	2019-11-07	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2768	pick-up	0	21
13224	2019-11-07 18:36:03	2019-11-07	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	341	delivery	5	31
13225	2019-11-07 18:48:02	2019-11-07	12	[{"id_menu":3,"count":1}]	139	pick-up	0	12
13226	2019-11-07 19:01:35	2019-11-07	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	4760	delivery	5	40
13227	2019-11-07 19:53:16	2019-11-07	12	[{"id_menu":1,"count":1}]	1321	pick-up	0	12
13228	2019-11-07 19:56:42	2019-11-07	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3689	delivery	5	39
13229	2019-11-07 20:08:47	2019-11-07	12	[{"id_menu":1,"count":1}]	4941	delivery	5	17
13230	2019-11-07 20:17:09	2019-11-07	9	[{"id_menu":6,"count":1}]	3616	pick-up	0	9
13231	2019-11-07 20:24:54	2019-11-07	12	[{"id_menu":1,"count":1}]	1453	pick-up	0	12
13232	2019-11-07 20:29:45	2019-11-07	14	[{"id_menu":2,"count":1}]	2199	delivery	5	19
13233	2019-11-07 20:41:33	2019-11-07	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1317	pick-up	0	24
13234	2019-11-07 20:49:47	2019-11-07	9	[{"id_menu":7,"count":1}]	2101	delivery	5	14
13235	2019-11-07 20:55:45	2019-11-07	9	[{"id_menu":7,"count":1}]	4935	delivery	5	14
13236	2019-11-07 21:12:31	2019-11-07	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4927	delivery	5	45
13237	2019-11-07 21:15:23	2019-11-07	14	[{"id_menu":2,"count":1}]	2653	pick-up	0	14
13238	2019-11-07 21:28:44	2019-11-07	14	[{"id_menu":2,"count":1}]	722	delivery	5	19
13239	2019-11-07 21:31:34	2019-11-07	14	[{"id_menu":2,"count":2}]	431	pick-up	0	14
13240	2019-11-07 21:50:23	2019-11-07	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4928	delivery	5	34
13241	2019-11-07 22:03:48	2019-11-07	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3361	pick-up	0	26
13242	2019-11-07 22:11:36	2019-11-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	196	delivery	5	22
13243	2019-11-07 22:23:56	2019-11-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	3645	delivery	5	28
13244	2019-11-07 22:24:40	2019-11-07	14	[{"id_menu":2,"count":1}]	1679	delivery	5	19
13245	2019-11-07 22:26:15	2019-11-07	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4909	delivery	5	55
13246	2019-11-07 22:30:24	2019-11-07	17	[{"id_menu":4,"count":1}]	4937	pick-up	0	17
13247	2019-11-07 22:47:56	2019-11-07	17	[{"id_menu":4,"count":1}]	4954	delivery	5	22
13248	2019-11-07 23:29:06	2019-11-07	9	[{"id_menu":6,"count":1}]	4933	pick-up	0	9
13249	2019-11-07 23:33:03	2019-11-07	17	[{"id_menu":4,"count":1}]	4934	delivery	5	22
13250	2019-11-07 23:33:17	2019-11-07	8	[{"id_menu":5,"count":1}]	2052	delivery	5	13
13251	2019-11-07 23:34:30	2019-11-07	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	2868	delivery	5	31
13252	2019-11-07 23:52:50	2019-11-07	12	[{"id_menu":3,"count":1}]	135	pick-up	0	12
13253	2019-11-08 00:39:17	2019-11-08	17	[{"id_menu":4,"count":1}]	1255	pick-up	0	17
13254	2019-11-08 00:47:43	2019-11-08	14	[{"id_menu":2,"count":2}]	4644	pick-up	0	14
13255	2019-11-08 00:51:20	2019-11-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4965	delivery	5	22
13256	2019-11-08 01:01:29	2019-11-08	12	[{"id_menu":1,"count":2}]	76	pick-up	0	12
13257	2019-11-08 01:04:54	2019-11-08	14	[{"id_menu":2,"count":1}]	3295	pick-up	0	14
13258	2019-11-08 01:14:47	2019-11-08	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	5003	delivery	5	36
13259	2019-11-08 01:16:10	2019-11-08	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4981	pick-up	0	22
13260	2019-11-08 01:18:08	2019-11-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4975	delivery	5	28
13261	2019-11-08 01:21:26	2019-11-08	14	[{"id_menu":2,"count":1}]	1858	pick-up	0	14
13262	2019-11-08 01:29:26	2019-11-08	8	[{"id_menu":5,"count":1}]	1051	pick-up	0	8
13263	2019-11-08 01:46:06	2019-11-08	9	[{"id_menu":6,"count":1}]	4961	delivery	5	14
13264	2019-11-08 01:54:09	2019-11-08	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	111	pick-up	0	22
13265	2019-11-08 02:03:23	2019-11-08	9	[{"id_menu":7,"count":1}]	4081	delivery	5	14
13266	2019-11-08 02:23:36	2019-11-08	12	[{"id_menu":1,"count":1}]	623	delivery	5	17
13267	2019-11-08 02:41:29	2019-11-08	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	4960	pick-up	0	43
13268	2019-11-08 03:03:45	2019-11-08	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	47	delivery	5	26
13269	2019-11-08 03:46:37	2019-11-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4972	delivery	5	22
13270	2019-11-08 03:54:17	2019-11-08	12	[{"id_menu":3,"count":1}]	561	pick-up	0	12
13271	2019-11-08 04:20:21	2019-11-08	9	[{"id_menu":6,"count":1}]	519	delivery	5	14
13272	2019-11-08 04:23:26	2019-11-08	8	[{"id_menu":5,"count":1}]	257	pick-up	0	8
13273	2019-11-08 04:25:58	2019-11-08	9	[{"id_menu":6,"count":1}]	650	delivery	5	14
13274	2019-11-08 04:38:29	2019-11-08	17	[{"id_menu":4,"count":1}]	2850	pick-up	0	17
13275	2019-11-08 04:42:51	2019-11-08	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2124	delivery	5	22
13276	2019-11-08 04:42:58	2019-11-08	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	4978	delivery	5	26
13277	2019-11-08 04:47:36	2019-11-08	9	[{"id_menu":6,"count":1}]	2838	pick-up	0	9
13278	2019-11-08 04:49:02	2019-11-08	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1736	delivery	5	26
13279	2019-11-08 04:49:32	2019-11-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4970	delivery	5	28
13280	2019-11-08 04:59:03	2019-11-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	80	pick-up	0	23
13281	2019-11-08 05:07:37	2019-11-08	12	[{"id_menu":1,"count":1}]	708	delivery	5	17
13282	2019-11-08 05:18:30	2019-11-08	14	[{"id_menu":2,"count":2}]	813	pick-up	0	14
13283	2019-11-08 05:23:44	2019-11-08	17	[{"id_menu":4,"count":1}]	4120	pick-up	0	17
13284	2019-11-08 05:36:21	2019-11-08	8	[{"id_menu":5,"count":2}]	4979	delivery	5	13
13285	2019-11-08 05:38:43	2019-11-08	12	[{"id_menu":3,"count":2}]	4984	pick-up	0	12
13286	2019-11-08 05:49:00	2019-11-08	8	[{"id_menu":5,"count":1}]	4992	pick-up	0	8
13287	2019-11-08 06:14:18	2019-11-08	9	[{"id_menu":6,"count":1}]	3754	pick-up	0	9
13288	2019-11-08 06:58:21	2019-11-08	9	[{"id_menu":7,"count":1}]	4996	delivery	5	14
13289	2019-11-08 07:03:51	2019-11-08	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	788	pick-up	0	30
13290	2019-11-08 07:20:21	2019-11-08	14	[{"id_menu":2,"count":1}]	3736	pick-up	0	14
13291	2019-11-08 07:24:35	2019-11-08	14	[{"id_menu":2,"count":1}]	4991	delivery	5	19
13292	2019-11-08 07:35:08	2019-11-08	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":2}]	5004	delivery	5	25
13293	2019-11-08 07:36:11	2019-11-08	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2907	pick-up	0	49
13294	2019-11-08 08:07:58	2019-11-08	9	[{"id_menu":6,"count":1}]	4088	delivery	5	14
13295	2019-11-08 08:09:54	2019-11-08	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4193	pick-up	0	31
13296	2019-11-08 08:29:16	2019-11-08	9	[{"id_menu":7,"count":1}]	4995	pick-up	0	9
13297	2019-11-08 08:51:44	2019-11-08	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3504	pick-up	0	29
13298	2019-11-08 09:17:36	2019-11-08	12	[{"id_menu":3,"count":1}]	4223	delivery	5	17
13299	2019-11-08 09:45:11	2019-11-08	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	4498	delivery	5	23
13300	2019-11-08 09:50:17	2019-11-08	9	[{"id_menu":6,"count":1}]	2605	delivery	5	14
13301	2019-11-08 10:03:01	2019-11-08	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4969	delivery	5	36
13302	2019-11-08 10:11:18	2019-11-08	17	[{"id_menu":4,"count":2}]	2090	pick-up	0	17
13303	2019-11-08 10:16:19	2019-11-08	12	[{"id_menu":1,"count":1}]	4966	delivery	5	17
13304	2019-11-08 10:22:42	2019-11-08	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	223	pick-up	0	29
13305	2019-11-08 10:25:50	2019-11-08	8	[{"id_menu":5,"count":1}]	3949	pick-up	0	8
13306	2019-11-08 10:33:34	2019-11-08	17	[{"id_menu":4,"count":1}]	2556	pick-up	0	17
13307	2019-11-08 10:36:34	2019-11-08	17	[{"id_menu":4,"count":1}]	914	pick-up	0	17
13308	2019-11-08 10:43:10	2019-11-08	9	[{"id_menu":6,"count":1}]	4977	pick-up	0	9
13309	2019-11-08 10:47:27	2019-11-08	9	[{"id_menu":6,"count":1}]	4989	delivery	5	14
13310	2019-11-08 11:01:43	2019-11-08	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	4971	delivery	5	31
13311	2019-11-08 11:32:01	2019-11-08	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	626	pick-up	0	21
13312	2019-11-08 11:50:19	2019-11-08	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	4132	pick-up	0	29
13313	2019-11-08 11:58:48	2019-11-08	9	[{"id_menu":6,"count":1}]	4980	delivery	5	14
13314	2019-11-08 12:40:50	2019-11-08	9	[{"id_menu":7,"count":1}]	5002	delivery	5	14
13315	2019-11-08 12:57:09	2019-11-08	12	[{"id_menu":3,"count":1}]	1640	pick-up	0	12
13316	2019-11-08 13:09:54	2019-11-08	12	[{"id_menu":3,"count":1}]	4987	delivery	5	17
13317	2019-11-08 13:15:58	2019-11-08	8	[{"id_menu":5,"count":1}]	328	delivery	5	13
13318	2019-11-08 13:53:57	2019-11-08	8	[{"id_menu":5,"count":1}]	527	pick-up	0	8
13319	2019-11-08 13:56:25	2019-11-08	8	[{"id_menu":5,"count":1}]	2277	pick-up	0	8
13320	2019-11-08 13:59:18	2019-11-08	29	[{"id_menu":3,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4190	delivery	5	34
13321	2019-11-08 14:00:45	2019-11-08	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3645	delivery	5	34
13322	2019-11-08 14:01:52	2019-11-08	12	[{"id_menu":3,"count":1}]	4957	pick-up	0	12
13323	2019-11-08 14:02:05	2019-11-08	17	[{"id_menu":4,"count":1}]	1093	pick-up	0	17
13324	2019-11-08 14:03:29	2019-11-08	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4964	delivery	5	36
13325	2019-11-08 14:12:23	2019-11-08	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	676	pick-up	0	29
13326	2019-11-08 14:22:14	2019-11-08	8	[{"id_menu":5,"count":1}]	2539	pick-up	0	8
13327	2019-11-08 15:01:25	2019-11-08	14	[{"id_menu":2,"count":1}]	2984	delivery	5	19
13328	2019-11-08 15:18:28	2019-11-08	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	5001	delivery	5	31
13329	2019-11-08 15:19:01	2019-11-08	9	[{"id_menu":6,"count":1}]	1727	delivery	5	14
13330	2019-11-08 15:52:06	2019-11-08	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5000	delivery	5	31
13331	2019-11-08 15:59:58	2019-11-08	17	[{"id_menu":4,"count":1}]	2573	pick-up	0	17
13332	2019-11-08 16:01:20	2019-11-08	9	[{"id_menu":7,"count":1}]	956	pick-up	0	9
13333	2019-11-08 16:30:01	2019-11-08	17	[{"id_menu":4,"count":1}]	674	delivery	5	22
13334	2019-11-08 16:46:33	2019-11-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5006	delivery	5	22
13335	2019-11-08 16:55:49	2019-11-08	17	[{"id_menu":4,"count":1}]	286	pick-up	0	17
13336	2019-11-08 17:23:04	2019-11-08	9	[{"id_menu":6,"count":1}]	2962	delivery	5	14
13337	2019-11-08 17:25:35	2019-11-08	17	[{"id_menu":4,"count":1}]	3258	pick-up	0	17
13338	2019-11-08 17:26:16	2019-11-08	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4998	pick-up	0	34
13339	2019-11-08 17:27:48	2019-11-08	12	[{"id_menu":3,"count":1}]	2980	pick-up	0	12
13340	2019-11-08 17:27:54	2019-11-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4753	delivery	5	22
13341	2019-11-08 17:55:32	2019-11-08	17	[{"id_menu":4,"count":1}]	3193	pick-up	0	17
13342	2019-11-08 17:58:04	2019-11-08	17	[{"id_menu":4,"count":1}]	1730	pick-up	0	17
13343	2019-11-08 18:19:04	2019-11-08	17	[{"id_menu":4,"count":1}]	2291	delivery	5	22
13344	2019-11-08 18:21:09	2019-11-08	9	[{"id_menu":7,"count":1}]	4986	pick-up	0	9
13345	2019-11-08 18:21:49	2019-11-08	9	[{"id_menu":7,"count":1}]	1212	pick-up	0	9
13346	2019-11-08 18:41:39	2019-11-08	9	[{"id_menu":7,"count":1}]	2237	pick-up	0	9
13347	2019-11-08 19:06:10	2019-11-08	9	[{"id_menu":7,"count":2}]	4862	delivery	5	14
13348	2019-11-08 19:12:02	2019-11-08	9	[{"id_menu":7,"count":1}]	2579	pick-up	0	9
13349	2019-11-08 19:16:58	2019-11-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3864	pick-up	0	18
13350	2019-11-08 19:17:34	2019-11-08	12	[{"id_menu":3,"count":1}]	4976	pick-up	0	12
13351	2019-11-08 19:23:08	2019-11-08	12	[{"id_menu":3,"count":1}]	2998	delivery	5	17
13352	2019-11-08 19:25:18	2019-11-08	8	[{"id_menu":5,"count":1}]	748	delivery	5	13
13353	2019-11-08 19:27:51	2019-11-08	9	[{"id_menu":7,"count":1}]	5005	delivery	5	14
13354	2019-11-08 19:47:39	2019-11-08	12	[{"id_menu":1,"count":1}]	1184	pick-up	0	12
13355	2019-11-08 19:48:41	2019-11-08	9	[{"id_menu":7,"count":1}]	4997	pick-up	0	9
13356	2019-11-08 19:49:58	2019-11-08	8	[{"id_menu":5,"count":1}]	4968	delivery	5	13
13357	2019-11-08 19:53:56	2019-11-08	14	[{"id_menu":2,"count":1}]	2309	pick-up	0	14
13358	2019-11-08 20:05:41	2019-11-08	14	[{"id_menu":2,"count":1}]	4506	pick-up	0	14
13359	2019-11-08 20:07:57	2019-11-08	9	[{"id_menu":6,"count":1}]	2267	pick-up	0	9
13360	2019-11-08 20:24:05	2019-11-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1815	pick-up	0	18
13361	2019-11-08 20:33:29	2019-11-08	12	[{"id_menu":3,"count":1}]	4800	pick-up	0	12
13362	2019-11-08 21:05:30	2019-11-08	43	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4993	pick-up	0	43
13363	2019-11-08 21:07:29	2019-11-08	14	[{"id_menu":2,"count":1}]	981	pick-up	0	14
13364	2019-11-08 21:17:13	2019-11-08	14	[{"id_menu":2,"count":1}]	2613	pick-up	0	14
13365	2019-11-08 22:11:32	2019-11-08	9	[{"id_menu":6,"count":1}]	2690	pick-up	0	9
13366	2019-11-08 22:19:52	2019-11-08	12	[{"id_menu":1,"count":3}]	4710	pick-up	0	12
13367	2019-11-08 22:22:31	2019-11-08	14	[{"id_menu":2,"count":1}]	2304	pick-up	0	14
13368	2019-11-08 23:19:25	2019-11-08	14	[{"id_menu":2,"count":1}]	2082	pick-up	0	14
13369	2019-11-08 23:19:47	2019-11-08	14	[{"id_menu":2,"count":1}]	1801	delivery	5	19
13370	2019-11-08 23:31:26	2019-11-08	9	[{"id_menu":6,"count":1}]	4973	pick-up	0	9
13371	2019-11-08 23:39:17	2019-11-08	9	[{"id_menu":6,"count":3}]	4994	delivery	5	14
13372	2019-11-08 23:47:07	2019-11-08	17	[{"id_menu":4,"count":1}]	4983	delivery	5	22
13373	2019-11-08 23:47:39	2019-11-08	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3688	delivery	5	26
13374	2019-11-08 23:51:02	2019-11-08	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	4985	pick-up	0	23
13375	2019-11-08 23:55:03	2019-11-08	17	[{"id_menu":4,"count":1}]	1889	delivery	5	22
13376	2019-11-09 00:09:12	2019-11-09	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1343	delivery	5	48
13377	2019-11-09 00:14:07	2019-11-09	17	[{"id_menu":4,"count":1}]	5052	pick-up	0	17
13378	2019-11-09 00:24:23	2019-11-09	8	[{"id_menu":5,"count":1}]	5032	delivery	5	13
13379	2019-11-09 00:37:31	2019-11-09	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4606	delivery	5	35
13380	2019-11-09 00:37:57	2019-11-09	12	[{"id_menu":3,"count":1}]	3135	pick-up	0	12
13381	2019-11-09 01:00:49	2019-11-09	12	[{"id_menu":3,"count":1}]	5045	delivery	5	17
13382	2019-11-09 01:09:08	2019-11-09	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4196	delivery	5	31
13383	2019-11-09 01:26:37	2019-11-09	8	[{"id_menu":5,"count":1}]	221	delivery	5	13
13384	2019-11-09 01:33:41	2019-11-09	17	[{"id_menu":4,"count":1}]	4166	delivery	5	22
13385	2019-11-09 01:39:46	2019-11-09	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5059	delivery	5	44
13386	2019-11-09 01:45:10	2019-11-09	17	[{"id_menu":4,"count":1}]	712	delivery	5	22
13387	2019-11-09 01:53:11	2019-11-09	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	5033	pick-up	0	24
13388	2019-11-09 02:07:47	2019-11-09	12	[{"id_menu":1,"count":1}]	4960	pick-up	0	12
13389	2019-11-09 02:22:59	2019-11-09	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	5017	delivery	5	26
13390	2019-11-09 02:39:51	2019-11-09	17	[{"id_menu":4,"count":1}]	80	pick-up	0	17
13391	2019-11-09 02:46:05	2019-11-09	8	[{"id_menu":5,"count":1}]	2560	delivery	5	13
13392	2019-11-09 02:49:59	2019-11-09	9	[{"id_menu":6,"count":1}]	1988	pick-up	0	9
13393	2019-11-09 02:52:52	2019-11-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	925	pick-up	0	17
13394	2019-11-09 03:05:06	2019-11-09	17	[{"id_menu":4,"count":1}]	5053	delivery	5	22
13395	2019-11-09 03:09:50	2019-11-09	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5022	delivery	5	35
13396	2019-11-09 03:10:06	2019-11-09	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	5029	delivery	5	34
13397	2019-11-09 03:14:00	2019-11-09	9	[{"id_menu":6,"count":1}]	3328	delivery	5	14
13398	2019-11-09 03:16:54	2019-11-09	12	[{"id_menu":3,"count":1}]	4157	pick-up	0	12
13399	2019-11-09 03:25:42	2019-11-09	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	2352	pick-up	0	29
13400	2019-11-09 03:36:35	2019-11-09	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3378	delivery	5	26
13401	2019-11-09 03:43:37	2019-11-09	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	4836	delivery	5	31
13402	2019-11-09 04:01:44	2019-11-09	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	5030	delivery	5	27
13403	2019-11-09 04:22:12	2019-11-09	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	5026	pick-up	0	24
13404	2019-11-09 04:33:38	2019-11-09	9	[{"id_menu":6,"count":1}]	3434	pick-up	0	9
13405	2019-11-09 04:42:31	2019-11-09	9	[{"id_menu":7,"count":1}]	2868	delivery	5	14
13406	2019-11-09 04:50:47	2019-11-09	8	[{"id_menu":5,"count":1}]	5047	delivery	5	13
13407	2019-11-09 04:59:55	2019-11-09	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	5013	delivery	5	27
13408	2019-11-09 05:04:31	2019-11-09	14	[{"id_menu":2,"count":1}]	5057	delivery	5	19
13409	2019-11-09 05:09:49	2019-11-09	12	[{"id_menu":1,"count":1}]	905	delivery	5	17
13410	2019-11-09 05:34:36	2019-11-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3617	pick-up	0	23
13411	2019-11-09 05:45:42	2019-11-09	12	[{"id_menu":3,"count":1}]	5024	delivery	5	17
13412	2019-11-09 05:52:16	2019-11-09	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5021	delivery	5	43
13413	2019-11-09 05:59:49	2019-11-09	17	[{"id_menu":4,"count":1}]	3579	delivery	5	22
13414	2019-11-09 06:02:40	2019-11-09	14	[{"id_menu":2,"count":1}]	3600	pick-up	0	14
13415	2019-11-09 06:10:35	2019-11-09	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3169	delivery	5	27
13416	2019-11-09 06:25:36	2019-11-09	9	[{"id_menu":6,"count":1}]	5015	pick-up	0	9
13417	2019-11-09 06:32:43	2019-11-09	8	[{"id_menu":5,"count":1}]	1547	pick-up	0	8
13418	2019-11-09 06:33:05	2019-11-09	14	[{"id_menu":2,"count":1}]	355	delivery	5	19
13419	2019-11-09 06:47:38	2019-11-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	5027	pick-up	0	23
13420	2019-11-09 06:58:29	2019-11-09	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5046	delivery	5	31
13421	2019-11-09 07:23:15	2019-11-09	17	[{"id_menu":4,"count":1}]	1637	pick-up	0	17
13422	2019-11-09 07:36:53	2019-11-09	14	[{"id_menu":2,"count":1}]	4624	pick-up	0	14
13423	2019-11-09 07:37:03	2019-11-09	14	[{"id_menu":2,"count":1}]	5037	delivery	5	19
13424	2019-11-09 07:50:54	2019-11-09	14	[{"id_menu":2,"count":1}]	2494	pick-up	0	14
13425	2019-11-09 07:53:55	2019-11-09	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5035	delivery	5	22
13426	2019-11-09 08:08:36	2019-11-09	12	[{"id_menu":1,"count":1}]	4021	pick-up	0	12
13427	2019-11-09 08:09:13	2019-11-09	9	[{"id_menu":7,"count":3}]	3298	delivery	5	14
13428	2019-11-09 08:14:05	2019-11-09	12	[{"id_menu":3,"count":1}]	4576	delivery	5	17
13429	2019-11-09 08:14:24	2019-11-09	8	[{"id_menu":5,"count":1}]	5009	pick-up	0	8
13430	2019-11-09 08:15:10	2019-11-09	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	5016	delivery	5	35
13431	2019-11-09 08:29:08	2019-11-09	12	[{"id_menu":1,"count":2}]	3274	pick-up	0	12
13432	2019-11-09 08:29:56	2019-11-09	12	[{"id_menu":3,"count":1}]	1594	delivery	5	17
13433	2019-11-09 08:30:04	2019-11-09	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	5056	delivery	5	27
13434	2019-11-09 08:33:58	2019-11-09	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	3562	delivery	5	35
13435	2019-11-09 08:36:28	2019-11-09	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2752	pick-up	0	21
13436	2019-11-09 08:42:47	2019-11-09	9	[{"id_menu":6,"count":1}]	5051	pick-up	0	9
13437	2019-11-09 08:44:18	2019-11-09	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	691	pick-up	0	34
13438	2019-11-09 08:50:01	2019-11-09	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	806	pick-up	0	21
13439	2019-11-09 08:59:59	2019-11-09	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	538	delivery	5	37
13440	2019-11-09 09:04:16	2019-11-09	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	5014	pick-up	0	26
13441	2019-11-09 09:10:52	2019-11-09	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2362	delivery	5	31
13442	2019-11-09 09:22:04	2019-11-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5040	delivery	5	22
13443	2019-11-09 09:24:52	2019-11-09	9	[{"id_menu":7,"count":1}]	5031	delivery	5	14
13444	2019-11-09 10:16:55	2019-11-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1313	pick-up	0	23
13445	2019-11-09 10:17:16	2019-11-09	14	[{"id_menu":2,"count":1}]	4874	pick-up	0	14
13446	2019-11-09 10:36:08	2019-11-09	12	[{"id_menu":3,"count":1}]	2556	pick-up	0	12
13447	2019-11-09 10:39:34	2019-11-09	14	[{"id_menu":2,"count":1}]	2472	delivery	5	19
13448	2019-11-09 10:50:09	2019-11-09	9	[{"id_menu":6,"count":1}]	781	pick-up	0	9
13449	2019-11-09 10:50:14	2019-11-09	8	[{"id_menu":5,"count":1}]	3052	pick-up	0	8
13450	2019-11-09 11:06:25	2019-11-09	12	[{"id_menu":3,"count":1}]	4414	pick-up	0	12
13451	2019-11-09 11:10:27	2019-11-09	9	[{"id_menu":6,"count":1}]	5007	delivery	5	14
13452	2019-11-09 11:15:18	2019-11-09	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5050	delivery	5	36
13453	2019-11-09 11:27:17	2019-11-09	9	[{"id_menu":7,"count":1}]	5044	delivery	5	14
13454	2019-11-09 11:29:05	2019-11-09	9	[{"id_menu":7,"count":3}]	5020	delivery	5	14
13455	2019-11-09 11:30:03	2019-11-09	12	[{"id_menu":3,"count":1}]	2926	pick-up	0	12
13456	2019-11-09 11:30:16	2019-11-09	9	[{"id_menu":6,"count":1}]	1104	pick-up	0	9
13457	2019-11-09 11:40:31	2019-11-09	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5034	delivery	5	39
13458	2019-11-09 11:42:19	2019-11-09	8	[{"id_menu":5,"count":1}]	3040	delivery	5	13
13459	2019-11-09 11:55:17	2019-11-09	14	[{"id_menu":2,"count":1}]	2422	delivery	5	19
13460	2019-11-09 11:57:06	2019-11-09	9	[{"id_menu":6,"count":1}]	1490	delivery	5	14
13461	2019-11-09 11:59:03	2019-11-09	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	5036	delivery	5	31
13462	2019-11-09 12:07:35	2019-11-09	14	[{"id_menu":2,"count":1}]	788	pick-up	0	14
13463	2019-11-09 12:26:13	2019-11-09	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	669	pick-up	0	26
13464	2019-11-09 12:27:56	2019-11-09	14	[{"id_menu":2,"count":1}]	4565	delivery	5	19
13465	2019-11-09 12:49:26	2019-11-09	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2942	delivery	5	22
13466	2019-11-09 12:55:31	2019-11-09	9	[{"id_menu":7,"count":1}]	1461	pick-up	0	9
13467	2019-11-09 13:15:13	2019-11-09	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5025	delivery	5	22
13468	2019-11-09 13:19:34	2019-11-09	9	[{"id_menu":6,"count":2}]	1223	pick-up	0	9
13469	2019-11-09 13:20:54	2019-11-09	12	[{"id_menu":3,"count":2}]	2943	pick-up	0	12
13470	2019-11-09 13:23:44	2019-11-09	9	[{"id_menu":7,"count":1}]	4793	pick-up	0	9
13471	2019-11-09 13:56:50	2019-11-09	9	[{"id_menu":7,"count":1}]	5039	pick-up	0	9
13472	2019-11-09 14:00:12	2019-11-09	9	[{"id_menu":6,"count":1}]	2791	delivery	5	14
13473	2019-11-09 14:17:00	2019-11-09	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	950	pick-up	0	29
13474	2019-11-09 14:19:08	2019-11-09	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	5023	delivery	5	34
13475	2019-11-09 14:20:17	2019-11-09	14	[{"id_menu":2,"count":1}]	223	delivery	5	19
13476	2019-11-09 14:50:21	2019-11-09	17	[{"id_menu":4,"count":1}]	3820	pick-up	0	17
13477	2019-11-09 14:57:00	2019-11-09	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2653	pick-up	0	17
13478	2019-11-09 15:07:53	2019-11-09	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5028	delivery	5	34
13479	2019-11-09 15:17:55	2019-11-09	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	373	pick-up	0	38
13480	2019-11-09 15:21:22	2019-11-09	14	[{"id_menu":2,"count":1}]	4996	delivery	5	19
13481	2019-11-09 15:46:07	2019-11-09	9	[{"id_menu":6,"count":1}]	5054	delivery	5	14
13482	2019-11-09 15:55:55	2019-11-09	12	[{"id_menu":1,"count":1}]	5012	pick-up	0	12
13483	2019-11-09 15:59:43	2019-11-09	12	[{"id_menu":3,"count":1}]	5049	pick-up	0	12
13484	2019-11-09 16:03:07	2019-11-09	12	[{"id_menu":3,"count":1}]	3102	pick-up	0	12
13485	2019-11-09 16:07:40	2019-11-09	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2142	pick-up	0	31
13486	2019-11-09 16:27:56	2019-11-09	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	2476	pick-up	0	21
13487	2019-11-09 16:32:58	2019-11-09	9	[{"id_menu":6,"count":1}]	5058	delivery	5	14
13488	2019-11-09 16:47:07	2019-11-09	14	[{"id_menu":2,"count":1}]	21	delivery	5	19
13489	2019-11-09 17:17:32	2019-11-09	55	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3173	delivery	5	60
13490	2019-11-09 17:55:34	2019-11-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3511	pick-up	0	23
13491	2019-11-09 18:04:23	2019-11-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5008	delivery	5	22
13492	2019-11-09 18:05:07	2019-11-09	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1063	pick-up	0	26
13493	2019-11-09 18:12:59	2019-11-09	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5000	delivery	5	31
13494	2019-11-09 18:41:42	2019-11-09	14	[{"id_menu":2,"count":1}]	2130	pick-up	0	14
13495	2019-11-09 18:42:11	2019-11-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3871	delivery	5	28
13496	2019-11-09 18:48:31	2019-11-09	9	[{"id_menu":7,"count":1}]	1467	delivery	5	14
13497	2019-11-09 19:23:34	2019-11-09	8	[{"id_menu":5,"count":1}]	4622	delivery	5	13
13498	2019-11-09 19:23:38	2019-11-09	8	[{"id_menu":5,"count":1}]	3338	pick-up	0	8
13499	2019-11-09 19:38:31	2019-11-09	9	[{"id_menu":7,"count":1}]	3261	delivery	5	14
13500	2019-11-09 19:39:15	2019-11-09	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	943	delivery	5	30
13501	2019-11-09 19:48:43	2019-11-09	17	[{"id_menu":4,"count":1}]	2200	pick-up	0	17
13502	2019-11-09 20:04:31	2019-11-09	9	[{"id_menu":7,"count":1}]	3451	pick-up	0	9
13503	2019-11-09 20:31:56	2019-11-09	14	[{"id_menu":2,"count":1}]	2168	delivery	5	19
13504	2019-11-09 20:41:08	2019-11-09	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	1742	pick-up	0	17
13505	2019-11-09 20:44:02	2019-11-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5010	delivery	5	28
13506	2019-11-09 20:56:33	2019-11-09	9	[{"id_menu":7,"count":1}]	1659	pick-up	0	9
13507	2019-11-09 21:02:24	2019-11-09	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	200	pick-up	0	21
13508	2019-11-09 21:13:15	2019-11-09	9	[{"id_menu":6,"count":1}]	5038	delivery	5	14
13576	2019-11-10 06:22:01	2019-11-10	9	[{"id_menu":7,"count":1}]	4165	delivery	5	14
13509	2019-11-09 21:20:30	2019-11-09	46	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	5041	pick-up	0	46
13510	2019-11-09 21:21:35	2019-11-09	12	[{"id_menu":1,"count":1}]	209	delivery	5	17
13511	2019-11-09 21:28:09	2019-11-09	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5018	delivery	5	45
13512	2019-11-09 21:31:46	2019-11-09	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2502	pick-up	0	26
13513	2019-11-09 21:35:26	2019-11-09	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	5019	delivery	5	29
13514	2019-11-09 21:37:35	2019-11-09	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	68	pick-up	0	21
13515	2019-11-09 21:55:28	2019-11-09	9	[{"id_menu":7,"count":1}]	3106	delivery	5	14
13516	2019-11-09 22:12:30	2019-11-09	9	[{"id_menu":7,"count":1}]	962	delivery	5	14
13517	2019-11-09 22:21:09	2019-11-09	46	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	5055	delivery	5	51
13518	2019-11-09 22:21:50	2019-11-09	9	[{"id_menu":6,"count":1}]	5011	pick-up	0	9
13519	2019-11-09 22:22:56	2019-11-09	8	[{"id_menu":5,"count":1}]	3509	pick-up	0	8
13520	2019-11-09 22:38:29	2019-11-09	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	3444	pick-up	0	20
13521	2019-11-09 22:43:59	2019-11-09	17	[{"id_menu":4,"count":1}]	2799	pick-up	0	17
13522	2019-11-09 22:45:42	2019-11-09	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	4144	pick-up	0	21
13523	2019-11-09 22:48:45	2019-11-09	29	[{"id_menu":3,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5042	delivery	5	34
13524	2019-11-09 22:55:50	2019-11-09	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3552	delivery	5	36
13525	2019-11-09 23:33:18	2019-11-09	8	[{"id_menu":5,"count":1}]	1250	pick-up	0	8
13526	2019-11-09 23:44:16	2019-11-09	9	[{"id_menu":7,"count":1}]	184	pick-up	0	9
13527	2019-11-09 23:44:27	2019-11-09	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1851	delivery	5	31
13528	2019-11-09 23:45:25	2019-11-09	12	[{"id_menu":1,"count":1}]	5048	pick-up	0	12
13529	2019-11-09 23:51:10	2019-11-09	12	[{"id_menu":1,"count":1}]	5043	delivery	5	17
13530	2019-11-10 00:00:22	2019-11-10	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	3835	delivery	5	22
13531	2019-11-10 00:08:05	2019-11-10	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	3860	delivery	5	34
13532	2019-11-10 00:11:35	2019-11-10	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2511	pick-up	0	29
13533	2019-11-10 00:23:05	2019-11-10	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	5099	pick-up	0	20
13534	2019-11-10 00:23:15	2019-11-10	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2766	delivery	5	40
13535	2019-11-10 00:26:22	2019-11-10	12	[{"id_menu":3,"count":1}]	5109	delivery	5	17
13536	2019-11-10 00:41:12	2019-11-10	9	[{"id_menu":7,"count":1}]	2140	pick-up	0	9
13537	2019-11-10 00:56:55	2019-11-10	9	[{"id_menu":6,"count":1}]	4329	pick-up	0	9
13538	2019-11-10 01:23:37	2019-11-10	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5072	delivery	5	30
13539	2019-11-10 01:26:42	2019-11-10	12	[{"id_menu":3,"count":1}]	5050	pick-up	0	12
13540	2019-11-10 01:45:46	2019-11-10	17	[{"id_menu":4,"count":1}]	1344	delivery	5	22
13541	2019-11-10 01:56:34	2019-11-10	12	[{"id_menu":3,"count":1}]	5080	pick-up	0	12
13542	2019-11-10 02:11:02	2019-11-10	14	[{"id_menu":2,"count":1}]	4146	pick-up	0	14
13543	2019-11-10 02:20:46	2019-11-10	12	[{"id_menu":1,"count":1}]	4286	delivery	5	17
13544	2019-11-10 02:27:40	2019-11-10	12	[{"id_menu":3,"count":1}]	1729	pick-up	0	12
13545	2019-11-10 02:35:01	2019-11-10	14	[{"id_menu":2,"count":1}]	1896	delivery	5	19
13546	2019-11-10 02:44:33	2019-11-10	12	[{"id_menu":3,"count":1}]	2546	delivery	5	17
13547	2019-11-10 02:46:05	2019-11-10	14	[{"id_menu":2,"count":1}]	2682	delivery	5	19
13548	2019-11-10 02:56:12	2019-11-10	14	[{"id_menu":2,"count":1}]	5071	delivery	5	19
13549	2019-11-10 03:01:17	2019-11-10	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	32	delivery	5	31
13550	2019-11-10 03:08:29	2019-11-10	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	5090	pick-up	0	34
13551	2019-11-10 03:25:23	2019-11-10	9	[{"id_menu":7,"count":1}]	5086	delivery	5	14
13552	2019-11-10 03:32:47	2019-11-10	12	[{"id_menu":1,"count":1}]	3506	delivery	5	17
13553	2019-11-10 03:37:49	2019-11-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	23	delivery	5	28
13554	2019-11-10 03:46:31	2019-11-10	12	[{"id_menu":3,"count":1}]	2300	pick-up	0	12
13555	2019-11-10 04:04:17	2019-11-10	17	[{"id_menu":4,"count":1}]	2985	pick-up	0	17
13556	2019-11-10 04:05:00	2019-11-10	12	[{"id_menu":1,"count":1}]	1382	pick-up	0	12
13557	2019-11-10 04:13:24	2019-11-10	12	[{"id_menu":3,"count":1}]	2450	pick-up	0	12
13558	2019-11-10 04:15:57	2019-11-10	9	[{"id_menu":7,"count":2}]	3687	delivery	5	14
13559	2019-11-10 04:19:35	2019-11-10	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2275	delivery	5	26
13560	2019-11-10 04:29:16	2019-11-10	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5097	delivery	5	43
13561	2019-11-10 04:34:00	2019-11-10	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":2}]	457	pick-up	0	31
13562	2019-11-10 04:42:50	2019-11-10	8	[{"id_menu":5,"count":2}]	2175	pick-up	0	8
13563	2019-11-10 04:47:11	2019-11-10	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1199	delivery	5	31
13564	2019-11-10 05:12:13	2019-11-10	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	609	pick-up	0	20
13565	2019-11-10 05:17:23	2019-11-10	14	[{"id_menu":2,"count":1}]	374	pick-up	0	14
13566	2019-11-10 05:26:31	2019-11-10	26	[{"id_menu":4,"count":3},{"id_menu":7,"count":1}]	4723	delivery	5	31
13567	2019-11-10 05:44:20	2019-11-10	9	[{"id_menu":6,"count":1}]	3629	delivery	5	14
13568	2019-11-10 05:50:31	2019-11-10	12	[{"id_menu":1,"count":1}]	5106	delivery	5	17
13569	2019-11-10 05:52:25	2019-11-10	14	[{"id_menu":2,"count":1}]	5084	delivery	5	19
13570	2019-11-10 05:59:01	2019-11-10	12	[{"id_menu":1,"count":1}]	3324	pick-up	0	12
13571	2019-11-10 06:01:27	2019-11-10	17	[{"id_menu":4,"count":1}]	1687	pick-up	0	17
13572	2019-11-10 06:03:20	2019-11-10	8	[{"id_menu":5,"count":1}]	1715	delivery	5	13
13573	2019-11-10 06:03:35	2019-11-10	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	3846	pick-up	0	29
13574	2019-11-10 06:04:10	2019-11-10	8	[{"id_menu":5,"count":1}]	4033	pick-up	0	8
13575	2019-11-10 06:05:21	2019-11-10	8	[{"id_menu":5,"count":1}]	3916	pick-up	0	8
13577	2019-11-10 06:27:37	2019-11-10	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5061	delivery	5	53
13578	2019-11-10 06:42:59	2019-11-10	17	[{"id_menu":4,"count":1}]	2374	delivery	5	22
13579	2019-11-10 06:47:35	2019-11-10	9	[{"id_menu":7,"count":1}]	2552	pick-up	0	9
13580	2019-11-10 06:53:54	2019-11-10	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1700	pick-up	0	34
13581	2019-11-10 07:11:41	2019-11-10	9	[{"id_menu":7,"count":1}]	3989	delivery	5	14
13582	2019-11-10 07:12:55	2019-11-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	172	pick-up	0	17
13583	2019-11-10 07:20:44	2019-11-10	9	[{"id_menu":7,"count":1}]	1101	delivery	5	14
13584	2019-11-10 07:41:33	2019-11-10	9	[{"id_menu":6,"count":1}]	5092	delivery	5	14
13585	2019-11-10 08:00:26	2019-11-10	9	[{"id_menu":7,"count":1}]	1169	pick-up	0	9
13586	2019-11-10 08:17:37	2019-11-10	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5091	delivery	5	43
13587	2019-11-10 08:21:18	2019-11-10	17	[{"id_menu":4,"count":1}]	259	delivery	5	22
13588	2019-11-10 08:24:49	2019-11-10	9	[{"id_menu":7,"count":1}]	4385	delivery	5	14
13589	2019-11-10 08:39:17	2019-11-10	9	[{"id_menu":6,"count":1}]	5093	delivery	5	14
13590	2019-11-10 08:40:16	2019-11-10	14	[{"id_menu":2,"count":1}]	802	pick-up	0	14
13591	2019-11-10 08:40:54	2019-11-10	12	[{"id_menu":1,"count":1}]	3385	delivery	5	17
13592	2019-11-10 08:47:33	2019-11-10	8	[{"id_menu":5,"count":1}]	1509	pick-up	0	8
13593	2019-11-10 08:57:11	2019-11-10	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	5078	delivery	5	40
13594	2019-11-10 09:00:59	2019-11-10	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3108	delivery	5	40
13595	2019-11-10 09:08:19	2019-11-10	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	5079	delivery	5	27
13596	2019-11-10 09:14:05	2019-11-10	14	[{"id_menu":2,"count":1}]	3468	delivery	5	19
13597	2019-11-10 09:15:26	2019-11-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	5085	delivery	5	22
13598	2019-11-10 09:27:17	2019-11-10	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2774	delivery	5	31
13599	2019-11-10 09:29:19	2019-11-10	17	[{"id_menu":4,"count":1}]	3780	pick-up	0	17
13600	2019-11-10 09:41:36	2019-11-10	12	[{"id_menu":1,"count":1}]	612	pick-up	0	12
13601	2019-11-10 09:50:43	2019-11-10	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2518	pick-up	0	21
13602	2019-11-10 09:57:01	2019-11-10	8	[{"id_menu":5,"count":1}]	786	pick-up	0	8
13603	2019-11-10 09:58:08	2019-11-10	8	[{"id_menu":5,"count":1}]	5066	delivery	5	13
13604	2019-11-10 10:00:57	2019-11-10	8	[{"id_menu":5,"count":1}]	922	pick-up	0	8
13605	2019-11-10 10:02:06	2019-11-10	8	[{"id_menu":5,"count":1}]	5111	delivery	5	13
13606	2019-11-10 10:08:15	2019-11-10	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	179	pick-up	0	35
13607	2019-11-10 10:17:26	2019-11-10	49	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5105	delivery	5	54
13608	2019-11-10 10:23:31	2019-11-10	14	[{"id_menu":2,"count":1}]	5070	pick-up	0	14
13609	2019-11-10 10:54:36	2019-11-10	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4655	delivery	5	39
13610	2019-11-10 10:56:23	2019-11-10	12	[{"id_menu":1,"count":1}]	5094	delivery	5	17
13611	2019-11-10 10:59:08	2019-11-10	17	[{"id_menu":4,"count":1}]	5112	pick-up	0	17
13612	2019-11-10 11:23:37	2019-11-10	8	[{"id_menu":5,"count":1}]	1490	delivery	5	13
13613	2019-11-10 11:31:04	2019-11-10	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5104	delivery	5	31
13614	2019-11-10 11:33:06	2019-11-10	12	[{"id_menu":3,"count":1}]	177	delivery	5	17
13615	2019-11-10 11:33:18	2019-11-10	9	[{"id_menu":7,"count":1}]	1716	pick-up	0	9
13616	2019-11-10 11:41:50	2019-11-10	14	[{"id_menu":2,"count":2}]	3459	delivery	5	19
13617	2019-11-10 11:59:08	2019-11-10	9	[{"id_menu":7,"count":1}]	2072	pick-up	0	9
13618	2019-11-10 12:01:12	2019-11-10	9	[{"id_menu":6,"count":1}]	1548	pick-up	0	9
13619	2019-11-10 12:03:00	2019-11-10	9	[{"id_menu":7,"count":1}]	5041	pick-up	0	9
13620	2019-11-10 12:22:54	2019-11-10	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3848	pick-up	0	31
13621	2019-11-10 12:22:57	2019-11-10	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5102	delivery	5	39
13622	2019-11-10 12:25:23	2019-11-10	9	[{"id_menu":7,"count":1}]	4235	pick-up	0	9
13623	2019-11-10 12:43:43	2019-11-10	9	[{"id_menu":6,"count":2}]	5098	delivery	5	14
13624	2019-11-10 12:53:33	2019-11-10	12	[{"id_menu":3,"count":2}]	5075	pick-up	0	12
13625	2019-11-10 12:56:58	2019-11-10	8	[{"id_menu":5,"count":1}]	4271	delivery	5	13
13626	2019-11-10 13:00:35	2019-11-10	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2305	delivery	5	43
13627	2019-11-10 13:02:50	2019-11-10	17	[{"id_menu":4,"count":1}]	285	pick-up	0	17
13628	2019-11-10 13:06:06	2019-11-10	9	[{"id_menu":7,"count":1}]	2392	pick-up	0	9
13629	2019-11-10 13:14:11	2019-11-10	9	[{"id_menu":7,"count":1}]	329	pick-up	0	9
13630	2019-11-10 13:23:58	2019-11-10	12	[{"id_menu":3,"count":1}]	1862	delivery	5	17
13631	2019-11-10 13:24:57	2019-11-10	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	981	pick-up	0	39
13632	2019-11-10 13:31:23	2019-11-10	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	80	pick-up	0	31
13633	2019-11-10 13:51:10	2019-11-10	17	[{"id_menu":4,"count":2}]	1210	delivery	5	22
13634	2019-11-10 13:51:29	2019-11-10	9	[{"id_menu":6,"count":2}]	2855	pick-up	0	9
13635	2019-11-10 14:00:13	2019-11-10	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2306	pick-up	0	21
13636	2019-11-10 14:01:56	2019-11-10	14	[{"id_menu":2,"count":1}]	5067	delivery	5	19
13637	2019-11-10 14:18:33	2019-11-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1135	delivery	5	23
13638	2019-11-10 14:21:15	2019-11-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5074	delivery	5	28
13639	2019-11-10 14:23:21	2019-11-10	8	[{"id_menu":5,"count":1}]	5082	pick-up	0	8
13640	2019-11-10 14:24:26	2019-11-10	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	432	delivery	5	25
13641	2019-11-10 14:27:59	2019-11-10	9	[{"id_menu":6,"count":1}]	314	delivery	5	14
13642	2019-11-10 14:57:57	2019-11-10	12	[{"id_menu":3,"count":1}]	5083	delivery	5	17
13643	2019-11-10 15:34:56	2019-11-10	8	[{"id_menu":5,"count":1}]	1339	delivery	5	13
13644	2019-11-10 15:41:32	2019-11-10	8	[{"id_menu":5,"count":1}]	2403	delivery	5	13
13645	2019-11-10 15:49:07	2019-11-10	12	[{"id_menu":1,"count":1}]	5100	delivery	5	17
13646	2019-11-10 15:53:07	2019-11-10	12	[{"id_menu":1,"count":1}]	5103	delivery	5	17
13647	2019-11-10 16:17:04	2019-11-10	14	[{"id_menu":2,"count":1}]	1103	pick-up	0	14
13648	2019-11-10 16:26:22	2019-11-10	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	1227	delivery	5	40
13649	2019-11-10 16:28:12	2019-11-10	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3885	delivery	5	22
13650	2019-11-10 17:07:20	2019-11-10	9	[{"id_menu":6,"count":2}]	3463	pick-up	0	9
13651	2019-11-10 17:13:54	2019-11-10	14	[{"id_menu":2,"count":1}]	78	delivery	5	19
13652	2019-11-10 17:22:39	2019-11-10	8	[{"id_menu":5,"count":1}]	5069	delivery	5	13
13653	2019-11-10 17:28:58	2019-11-10	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1693	pick-up	0	21
13654	2019-11-10 17:29:13	2019-11-10	17	[{"id_menu":4,"count":1}]	291	delivery	5	22
13655	2019-11-10 17:42:54	2019-11-10	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3679	delivery	5	54
13656	2019-11-10 17:44:01	2019-11-10	9	[{"id_menu":7,"count":1}]	5077	delivery	5	14
13657	2019-11-10 17:49:59	2019-11-10	9	[{"id_menu":7,"count":1}]	5087	delivery	5	14
13658	2019-11-10 18:25:24	2019-11-10	17	[{"id_menu":4,"count":1}]	573	pick-up	0	17
13659	2019-11-10 18:41:31	2019-11-10	9	[{"id_menu":7,"count":2}]	5107	pick-up	0	9
13660	2019-11-10 18:43:33	2019-11-10	9	[{"id_menu":7,"count":1}]	5063	pick-up	0	9
13661	2019-11-10 19:01:30	2019-11-10	9	[{"id_menu":6,"count":1}]	5076	delivery	5	14
13662	2019-11-10 19:01:40	2019-11-10	12	[{"id_menu":3,"count":1}]	2738	pick-up	0	12
13663	2019-11-10 19:05:08	2019-11-10	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	5065	delivery	5	26
13664	2019-11-10 19:06:16	2019-11-10	9	[{"id_menu":6,"count":1}]	251	delivery	5	14
13665	2019-11-10 19:19:30	2019-11-10	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4351	pick-up	0	40
13666	2019-11-10 19:33:10	2019-11-10	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5064	pick-up	0	17
13667	2019-11-10 19:40:13	2019-11-10	12	[{"id_menu":3,"count":1}]	296	delivery	5	17
13668	2019-11-10 19:42:50	2019-11-10	12	[{"id_menu":1,"count":1}]	5068	pick-up	0	12
13669	2019-11-10 19:45:40	2019-11-10	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1194	pick-up	0	29
13670	2019-11-10 19:54:30	2019-11-10	8	[{"id_menu":5,"count":1}]	2995	delivery	5	13
13671	2019-11-10 20:01:12	2019-11-10	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	677	pick-up	0	21
13672	2019-11-10 20:07:47	2019-11-10	12	[{"id_menu":1,"count":1}]	4161	pick-up	0	12
13673	2019-11-10 20:13:15	2019-11-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	1271	pick-up	0	23
13674	2019-11-10 20:20:38	2019-11-10	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":2}]	3569	delivery	5	31
13675	2019-11-10 20:38:05	2019-11-10	9	[{"id_menu":7,"count":1}]	2681	delivery	5	14
13676	2019-11-10 20:51:18	2019-11-10	9	[{"id_menu":7,"count":1}]	5060	pick-up	0	9
13677	2019-11-10 20:54:30	2019-11-10	14	[{"id_menu":2,"count":1}]	5081	delivery	5	19
13678	2019-11-10 21:23:09	2019-11-10	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4574	delivery	5	26
13679	2019-11-10 21:34:22	2019-11-10	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	382	delivery	5	42
13680	2019-11-10 21:46:33	2019-11-10	8	[{"id_menu":5,"count":1}]	2868	delivery	5	13
13681	2019-11-10 21:56:36	2019-11-10	9	[{"id_menu":6,"count":1}]	337	pick-up	0	9
13682	2019-11-10 22:03:33	2019-11-10	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2885	delivery	5	43
13683	2019-11-10 22:05:41	2019-11-10	9	[{"id_menu":7,"count":1}]	993	pick-up	0	9
13684	2019-11-10 22:19:09	2019-11-10	14	[{"id_menu":2,"count":1}]	5108	pick-up	0	14
13685	2019-11-10 22:22:58	2019-11-10	12	[{"id_menu":3,"count":1}]	1196	pick-up	0	12
13686	2019-11-10 22:28:42	2019-11-10	14	[{"id_menu":2,"count":1}]	2916	delivery	5	19
13687	2019-11-10 22:38:42	2019-11-10	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5089	delivery	5	37
13688	2019-11-10 22:45:42	2019-11-10	9	[{"id_menu":6,"count":1}]	5096	delivery	5	14
13689	2019-11-10 22:46:11	2019-11-10	9	[{"id_menu":7,"count":1}]	4498	delivery	5	14
13690	2019-11-10 22:57:32	2019-11-10	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	5073	delivery	5	30
13691	2019-11-10 23:10:28	2019-11-10	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	5062	delivery	5	35
13692	2019-11-10 23:11:44	2019-11-10	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5110	delivery	5	31
13693	2019-11-10 23:49:18	2019-11-10	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	5095	delivery	5	26
13694	2019-11-10 23:49:59	2019-11-10	12	[{"id_menu":1,"count":1}]	4172	delivery	5	17
13695	2019-11-10 23:57:10	2019-11-10	12	[{"id_menu":3,"count":1}]	5101	delivery	5	17
13696	2019-11-11 00:52:09	2019-11-11	9	[{"id_menu":7,"count":1}]	3153	pick-up	0	9
13697	2019-11-11 01:03:52	2019-11-11	12	[{"id_menu":3,"count":1}]	5141	pick-up	0	12
13698	2019-11-11 01:04:23	2019-11-11	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	833	delivery	5	43
13699	2019-11-11 01:17:59	2019-11-11	9	[{"id_menu":6,"count":1}]	3241	pick-up	0	9
13700	2019-11-11 01:22:39	2019-11-11	8	[{"id_menu":5,"count":1}]	1244	delivery	5	13
13701	2019-11-11 01:51:30	2019-11-11	12	[{"id_menu":3,"count":1}]	1914	pick-up	0	12
13702	2019-11-11 02:06:41	2019-11-11	12	[{"id_menu":3,"count":1}]	3097	delivery	5	17
13703	2019-11-11 02:43:00	2019-11-11	9	[{"id_menu":7,"count":1}]	5153	delivery	5	14
13704	2019-11-11 02:50:25	2019-11-11	17	[{"id_menu":4,"count":1}]	404	pick-up	0	17
13705	2019-11-11 03:11:04	2019-11-11	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1387	pick-up	0	21
13706	2019-11-11 03:14:57	2019-11-11	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4995	delivery	5	31
13707	2019-11-11 03:38:22	2019-11-11	38	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4190	delivery	5	43
13708	2019-11-11 03:42:21	2019-11-11	8	[{"id_menu":5,"count":1}]	5119	pick-up	0	8
13709	2019-11-11 03:49:53	2019-11-11	12	[{"id_menu":3,"count":1}]	1713	pick-up	0	12
13710	2019-11-11 04:06:40	2019-11-11	17	[{"id_menu":4,"count":1}]	1093	pick-up	0	17
13711	2019-11-11 04:13:36	2019-11-11	9	[{"id_menu":6,"count":1}]	1282	pick-up	0	9
13712	2019-11-11 05:13:12	2019-11-11	12	[{"id_menu":3,"count":1}]	2941	pick-up	0	12
13713	2019-11-11 05:23:50	2019-11-11	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	2605	delivery	5	30
13714	2019-11-11 05:49:07	2019-11-11	12	[{"id_menu":3,"count":1}]	2868	delivery	5	17
13715	2019-11-11 05:57:16	2019-11-11	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	5127	delivery	5	26
13716	2019-11-11 06:00:49	2019-11-11	9	[{"id_menu":7,"count":2}]	5149	pick-up	0	9
13717	2019-11-11 06:01:35	2019-11-11	14	[{"id_menu":2,"count":1}]	691	delivery	5	19
13718	2019-11-11 06:04:35	2019-11-11	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3507	pick-up	0	26
13719	2019-11-11 06:20:31	2019-11-11	14	[{"id_menu":2,"count":1}]	5152	delivery	5	19
13720	2019-11-11 06:52:48	2019-11-11	9	[{"id_menu":7,"count":1}]	4114	delivery	5	14
13721	2019-11-11 07:00:25	2019-11-11	12	[{"id_menu":3,"count":1}]	2041	pick-up	0	12
13722	2019-11-11 07:06:16	2019-11-11	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5115	delivery	5	31
13723	2019-11-11 07:09:57	2019-11-11	9	[{"id_menu":6,"count":1}]	4943	pick-up	0	9
13724	2019-11-11 07:19:59	2019-11-11	8	[{"id_menu":5,"count":1}]	1781	pick-up	0	8
13725	2019-11-11 07:38:18	2019-11-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5124	delivery	5	22
13726	2019-11-11 08:02:47	2019-11-11	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	4853	delivery	5	29
13727	2019-11-11 08:22:49	2019-11-11	9	[{"id_menu":6,"count":1}]	4608	delivery	5	14
13728	2019-11-11 08:39:10	2019-11-11	14	[{"id_menu":2,"count":1}]	3018	pick-up	0	14
13729	2019-11-11 08:47:56	2019-11-11	9	[{"id_menu":7,"count":1}]	5139	pick-up	0	9
13730	2019-11-11 08:58:30	2019-11-11	29	[{"id_menu":3,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2995	delivery	5	34
13731	2019-11-11 09:29:35	2019-11-11	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3174	pick-up	0	26
13732	2019-11-11 09:31:50	2019-11-11	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	5158	delivery	5	22
13733	2019-11-11 09:36:23	2019-11-11	14	[{"id_menu":2,"count":1}]	1638	delivery	5	19
13734	2019-11-11 09:47:03	2019-11-11	12	[{"id_menu":1,"count":1}]	1780	pick-up	0	12
13735	2019-11-11 09:54:46	2019-11-11	17	[{"id_menu":4,"count":1}]	3171	delivery	5	22
13736	2019-11-11 10:14:23	2019-11-11	12	[{"id_menu":3,"count":1}]	3529	pick-up	0	12
13737	2019-11-11 11:07:23	2019-11-11	9	[{"id_menu":6,"count":1}]	1418	pick-up	0	9
13738	2019-11-11 11:10:46	2019-11-11	17	[{"id_menu":4,"count":1}]	2901	delivery	5	22
13739	2019-11-11 11:24:41	2019-11-11	14	[{"id_menu":2,"count":1}]	4350	delivery	5	19
13740	2019-11-11 11:30:27	2019-11-11	9	[{"id_menu":6,"count":2}]	5121	delivery	5	14
13741	2019-11-11 11:32:47	2019-11-11	14	[{"id_menu":2,"count":1}]	2623	pick-up	0	14
13742	2019-11-11 11:36:59	2019-11-11	8	[{"id_menu":5,"count":1}]	2475	delivery	5	13
13743	2019-11-11 11:57:30	2019-11-11	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5150	delivery	5	22
13744	2019-11-11 12:02:05	2019-11-11	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1968	pick-up	0	23
13745	2019-11-11 13:16:11	2019-11-11	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5147	delivery	5	49
13746	2019-11-11 14:09:15	2019-11-11	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2993	pick-up	0	17
13747	2019-11-11 14:19:46	2019-11-11	9	[{"id_menu":7,"count":1}]	2797	delivery	5	14
13748	2019-11-11 14:56:20	2019-11-11	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5155	delivery	5	51
13749	2019-11-11 15:43:37	2019-11-11	12	[{"id_menu":1,"count":2}]	1073	pick-up	0	12
13750	2019-11-11 16:02:17	2019-11-11	12	[{"id_menu":3,"count":1}]	2540	pick-up	0	12
13751	2019-11-11 16:07:14	2019-11-11	17	[{"id_menu":4,"count":1}]	5113	delivery	5	22
13752	2019-11-11 16:43:36	2019-11-11	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	5137	delivery	5	26
13753	2019-11-11 16:55:16	2019-11-11	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3314	delivery	5	30
13754	2019-11-11 17:09:40	2019-11-11	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5117	delivery	5	51
13755	2019-11-11 17:30:21	2019-11-11	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	5143	pick-up	0	21
13756	2019-11-11 17:34:09	2019-11-11	12	[{"id_menu":3,"count":1}]	2618	pick-up	0	12
13757	2019-11-11 18:01:52	2019-11-11	8	[{"id_menu":5,"count":1}]	5151	delivery	5	13
13758	2019-11-11 18:12:45	2019-11-11	8	[{"id_menu":5,"count":1}]	5156	delivery	5	13
13759	2019-11-11 18:22:09	2019-11-11	12	[{"id_menu":3,"count":1}]	4471	delivery	5	17
13760	2019-11-11 18:51:05	2019-11-11	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1810	delivery	5	40
13761	2019-11-11 19:26:47	2019-11-11	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5135	delivery	5	37
13762	2019-11-11 19:29:39	2019-11-11	12	[{"id_menu":3,"count":1}]	5118	pick-up	0	12
13763	2019-11-11 19:33:56	2019-11-11	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5136	delivery	5	34
13764	2019-11-11 19:38:29	2019-11-11	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	4562	delivery	5	26
13765	2019-11-11 19:55:33	2019-11-11	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2044	pick-up	0	21
13766	2019-11-11 20:13:18	2019-11-11	9	[{"id_menu":6,"count":1}]	1992	pick-up	0	9
13767	2019-11-11 20:18:57	2019-11-11	17	[{"id_menu":4,"count":1}]	5064	pick-up	0	17
13768	2019-11-11 20:43:06	2019-11-11	8	[{"id_menu":5,"count":1}]	3129	delivery	5	13
13769	2019-11-11 21:00:01	2019-11-11	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	5125	pick-up	0	26
13770	2019-11-11 21:24:48	2019-11-11	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1786	delivery	5	31
13771	2019-11-11 21:36:55	2019-11-11	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	5122	delivery	5	29
13772	2019-11-11 21:44:13	2019-11-11	8	[{"id_menu":5,"count":1}]	2916	pick-up	0	8
13773	2019-11-11 21:47:53	2019-11-11	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	3155	pick-up	0	24
13774	2019-11-11 21:54:43	2019-11-11	17	[{"id_menu":4,"count":2}]	5116	pick-up	0	17
13775	2019-11-11 22:29:50	2019-11-11	9	[{"id_menu":7,"count":1}]	2439	delivery	5	14
13776	2019-11-11 22:31:35	2019-11-11	17	[{"id_menu":4,"count":1}]	2400	delivery	5	22
13777	2019-11-11 23:34:01	2019-11-11	9	[{"id_menu":7,"count":1}]	5148	delivery	5	14
13778	2019-11-11 23:42:48	2019-11-11	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	5138	pick-up	0	20
13779	2019-11-12 00:04:05	2019-11-12	9	[{"id_menu":7,"count":1}]	527	pick-up	0	9
13780	2019-11-12 00:23:18	2019-11-12	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4629	delivery	5	31
13781	2019-11-12 00:48:04	2019-11-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	865	pick-up	0	26
13782	2019-11-12 00:55:12	2019-11-12	14	[{"id_menu":2,"count":1}]	204	pick-up	0	14
13783	2019-11-12 01:10:53	2019-11-12	14	[{"id_menu":2,"count":1}]	1975	delivery	5	19
13784	2019-11-12 01:57:26	2019-11-12	14	[{"id_menu":2,"count":1}]	187	pick-up	0	14
13785	2019-11-12 02:16:46	2019-11-12	14	[{"id_menu":2,"count":1}]	5170	delivery	5	19
13786	2019-11-12 02:16:58	2019-11-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4146	pick-up	0	26
13787	2019-11-12 02:45:00	2019-11-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4391	delivery	5	31
13788	2019-11-12 02:52:19	2019-11-12	12	[{"id_menu":3,"count":1}]	5009	delivery	5	17
13789	2019-11-12 02:53:11	2019-11-12	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3393	delivery	5	45
13790	2019-11-12 03:04:34	2019-11-12	14	[{"id_menu":2,"count":1}]	1373	delivery	5	19
13791	2019-11-12 03:08:49	2019-11-12	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	5184	delivery	5	26
13792	2019-11-12 03:34:18	2019-11-12	14	[{"id_menu":2,"count":1}]	232	delivery	5	19
13793	2019-11-12 03:41:03	2019-11-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5182	delivery	5	22
13794	2019-11-12 03:50:33	2019-11-12	12	[{"id_menu":1,"count":1}]	5169	pick-up	0	12
13795	2019-11-12 04:08:26	2019-11-12	9	[{"id_menu":7,"count":1}]	3659	pick-up	0	9
13796	2019-11-12 04:15:55	2019-11-12	9	[{"id_menu":7,"count":1}]	5162	delivery	5	14
13797	2019-11-12 04:33:37	2019-11-12	9	[{"id_menu":7,"count":1}]	4846	pick-up	0	9
13798	2019-11-12 05:23:50	2019-11-12	14	[{"id_menu":2,"count":1}]	3848	pick-up	0	14
13799	2019-11-12 05:36:16	2019-11-12	14	[{"id_menu":2,"count":1}]	1834	pick-up	0	14
13800	2019-11-12 05:39:48	2019-11-12	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	27	delivery	5	31
13801	2019-11-12 05:49:30	2019-11-12	9	[{"id_menu":6,"count":1}]	4872	pick-up	0	9
13802	2019-11-12 05:53:44	2019-11-12	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	5196	delivery	5	40
13803	2019-11-12 05:54:33	2019-11-12	12	[{"id_menu":1,"count":1}]	5168	delivery	5	17
13804	2019-11-12 06:14:20	2019-11-12	12	[{"id_menu":1,"count":1}]	4613	pick-up	0	12
13805	2019-11-12 06:32:48	2019-11-12	17	[{"id_menu":4,"count":1}]	2215	delivery	5	22
13806	2019-11-12 06:40:25	2019-11-12	14	[{"id_menu":2,"count":1}]	4451	delivery	5	19
13807	2019-11-12 06:40:46	2019-11-12	12	[{"id_menu":3,"count":1}]	3629	delivery	5	17
13808	2019-11-12 07:11:48	2019-11-12	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	5194	pick-up	0	29
13809	2019-11-12 07:29:37	2019-11-12	12	[{"id_menu":1,"count":1}]	3713	pick-up	0	12
13810	2019-11-12 07:32:31	2019-11-12	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1537	pick-up	0	23
13811	2019-11-12 07:50:29	2019-11-12	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	5175	delivery	5	34
13812	2019-11-12 07:54:26	2019-11-12	17	[{"id_menu":4,"count":1}]	1645	pick-up	0	17
13813	2019-11-12 08:22:35	2019-11-12	9	[{"id_menu":6,"count":1}]	3864	pick-up	0	9
13814	2019-11-12 08:26:10	2019-11-12	9	[{"id_menu":6,"count":1}]	2136	pick-up	0	9
13815	2019-11-12 08:52:41	2019-11-12	14	[{"id_menu":2,"count":1}]	655	delivery	5	19
13816	2019-11-12 08:56:53	2019-11-12	12	[{"id_menu":1,"count":1}]	2572	pick-up	0	12
13817	2019-11-12 08:57:28	2019-11-12	14	[{"id_menu":2,"count":1}]	1638	delivery	5	19
13818	2019-11-12 09:09:38	2019-11-12	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5171	delivery	5	34
13819	2019-11-12 09:22:01	2019-11-12	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2068	delivery	5	43
13820	2019-11-12 09:30:23	2019-11-12	14	[{"id_menu":2,"count":1}]	5206	delivery	5	19
13821	2019-11-12 09:45:01	2019-11-12	9	[{"id_menu":7,"count":2}]	3006	delivery	5	14
13822	2019-11-12 09:51:09	2019-11-12	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5188	delivery	5	51
13823	2019-11-12 10:25:01	2019-11-12	12	[{"id_menu":1,"count":1}]	2573	delivery	5	17
13824	2019-11-12 10:28:48	2019-11-12	14	[{"id_menu":2,"count":1}]	1568	pick-up	0	14
13825	2019-11-12 10:43:35	2019-11-12	12	[{"id_menu":1,"count":1}]	2536	pick-up	0	12
13826	2019-11-12 10:45:34	2019-11-12	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	5207	delivery	5	40
13827	2019-11-12 10:52:57	2019-11-12	12	[{"id_menu":1,"count":1}]	5164	delivery	5	17
13828	2019-11-12 10:56:05	2019-11-12	12	[{"id_menu":1,"count":1}]	1068	pick-up	0	12
13829	2019-11-12 11:12:29	2019-11-12	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	5181	delivery	5	27
13830	2019-11-12 11:12:50	2019-11-12	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5177	delivery	5	39
13831	2019-11-12 11:20:49	2019-11-12	8	[{"id_menu":5,"count":2}]	4395	pick-up	0	8
13832	2019-11-12 11:30:35	2019-11-12	14	[{"id_menu":2,"count":1}]	3293	delivery	5	19
13833	2019-11-12 11:34:01	2019-11-12	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	5187	delivery	5	43
13834	2019-11-12 11:36:35	2019-11-12	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1245	pick-up	0	26
13835	2019-11-12 11:47:42	2019-11-12	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2446	pick-up	0	38
13836	2019-11-12 11:50:32	2019-11-12	17	[{"id_menu":4,"count":2}]	3903	delivery	5	22
13837	2019-11-12 11:55:10	2019-11-12	8	[{"id_menu":5,"count":1}]	4342	delivery	5	13
13838	2019-11-12 12:02:49	2019-11-12	8	[{"id_menu":5,"count":1}]	2620	pick-up	0	8
13839	2019-11-12 12:15:18	2019-11-12	9	[{"id_menu":6,"count":1}]	5202	delivery	5	14
13840	2019-11-12 12:35:33	2019-11-12	9	[{"id_menu":7,"count":1}]	5201	pick-up	0	9
13841	2019-11-12 12:37:35	2019-11-12	12	[{"id_menu":1,"count":1}]	5160	pick-up	0	12
13842	2019-11-12 12:46:23	2019-11-12	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3435	delivery	5	44
13843	2019-11-12 12:55:00	2019-11-12	9	[{"id_menu":7,"count":2}]	4529	pick-up	0	9
13844	2019-11-12 13:06:39	2019-11-12	8	[{"id_menu":5,"count":1}]	3891	delivery	5	13
13845	2019-11-12 13:17:03	2019-11-12	12	[{"id_menu":3,"count":1}]	3820	delivery	5	17
13846	2019-11-12 13:22:34	2019-11-12	9	[{"id_menu":7,"count":1}]	5185	delivery	5	14
13847	2019-11-12 13:38:35	2019-11-12	9	[{"id_menu":7,"count":1}]	5163	pick-up	0	9
13848	2019-11-12 13:43:53	2019-11-12	17	[{"id_menu":4,"count":1}]	1720	delivery	5	22
13849	2019-11-12 13:48:31	2019-11-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5179	delivery	5	22
13850	2019-11-12 13:49:26	2019-11-12	8	[{"id_menu":5,"count":1}]	2547	delivery	5	13
13851	2019-11-12 14:09:13	2019-11-12	8	[{"id_menu":5,"count":1}]	4594	delivery	5	13
13852	2019-11-12 14:13:15	2019-11-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2540	delivery	5	28
13853	2019-11-12 14:39:23	2019-11-12	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	13	delivery	5	31
13854	2019-11-12 15:01:12	2019-11-12	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	4815	delivery	5	36
13855	2019-11-12 15:12:53	2019-11-12	9	[{"id_menu":7,"count":1}]	299	pick-up	0	9
13856	2019-11-12 15:59:31	2019-11-12	9	[{"id_menu":6,"count":1}]	3806	delivery	5	14
13857	2019-11-12 16:12:06	2019-11-12	8	[{"id_menu":5,"count":1}]	2352	pick-up	0	8
13858	2019-11-12 16:23:14	2019-11-12	12	[{"id_menu":1,"count":1}]	5183	delivery	5	17
13859	2019-11-12 16:24:03	2019-11-12	9	[{"id_menu":7,"count":1}]	1166	delivery	5	14
13860	2019-11-12 16:38:23	2019-11-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5195	delivery	5	31
13861	2019-11-12 16:59:02	2019-11-12	14	[{"id_menu":2,"count":1}]	5167	pick-up	0	14
13862	2019-11-12 17:17:57	2019-11-12	14	[{"id_menu":2,"count":1}]	5176	delivery	5	19
13863	2019-11-12 17:30:00	2019-11-12	14	[{"id_menu":2,"count":1}]	5193	delivery	5	19
13864	2019-11-12 17:36:02	2019-11-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5191	delivery	5	28
13865	2019-11-12 17:45:43	2019-11-12	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1970	pick-up	0	23
13866	2019-11-12 17:46:58	2019-11-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5178	delivery	5	22
13867	2019-11-12 17:54:49	2019-11-12	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	4400	pick-up	0	20
13868	2019-11-12 18:00:50	2019-11-12	14	[{"id_menu":2,"count":1}]	5166	pick-up	0	14
13869	2019-11-12 18:29:38	2019-11-12	14	[{"id_menu":2,"count":1}]	5208	delivery	5	19
13870	2019-11-12 19:08:02	2019-11-12	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5192	delivery	5	48
13871	2019-11-12 19:37:06	2019-11-12	17	[{"id_menu":4,"count":1}]	1513	pick-up	0	17
13872	2019-11-12 20:11:48	2019-11-12	14	[{"id_menu":2,"count":1}]	351	pick-up	0	14
13873	2019-11-12 20:22:52	2019-11-12	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	5199	delivery	5	34
13874	2019-11-12 20:46:40	2019-11-12	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	5186	delivery	5	27
13875	2019-11-12 21:26:43	2019-11-12	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	5165	delivery	5	25
13876	2019-11-12 21:39:10	2019-11-12	9	[{"id_menu":7,"count":1}]	4551	pick-up	0	9
13877	2019-11-12 21:41:19	2019-11-12	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	66	delivery	5	34
13878	2019-11-12 21:55:07	2019-11-12	12	[{"id_menu":3,"count":1}]	5198	delivery	5	17
13879	2019-11-12 21:59:59	2019-11-12	9	[{"id_menu":7,"count":2}]	5205	delivery	5	14
13880	2019-11-12 22:09:23	2019-11-12	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3211	delivery	5	38
13881	2019-11-12 22:42:35	2019-11-12	9	[{"id_menu":7,"count":1}]	1450	pick-up	0	9
13882	2019-11-12 23:00:10	2019-11-12	12	[{"id_menu":1,"count":1}]	3199	delivery	5	17
13883	2019-11-12 23:09:27	2019-11-12	9	[{"id_menu":6,"count":1}]	3134	delivery	5	14
13884	2019-11-12 23:31:15	2019-11-12	8	[{"id_menu":5,"count":1}]	2995	delivery	5	13
13885	2019-11-12 23:32:58	2019-11-12	8	[{"id_menu":5,"count":1}]	981	pick-up	0	8
13886	2019-11-12 23:46:43	2019-11-12	12	[{"id_menu":3,"count":1}]	1517	pick-up	0	12
13887	2019-11-12 23:53:12	2019-11-12	17	[{"id_menu":4,"count":1}]	1402	pick-up	0	17
13888	2019-11-13 00:04:41	2019-11-13	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	5213	delivery	5	26
13889	2019-11-13 00:12:19	2019-11-13	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	4818	delivery	5	22
13890	2019-11-13 00:31:04	2019-11-13	9	[{"id_menu":6,"count":2}]	5211	delivery	5	14
13891	2019-11-13 00:42:50	2019-11-13	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3971	pick-up	0	26
13892	2019-11-13 00:53:55	2019-11-13	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2616	delivery	5	26
13893	2019-11-13 01:16:48	2019-11-13	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2139	pick-up	0	37
13894	2019-11-13 01:18:02	2019-11-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	569	delivery	5	36
13895	2019-11-13 01:19:16	2019-11-13	17	[{"id_menu":4,"count":1}]	3327	pick-up	0	17
13896	2019-11-13 01:37:21	2019-11-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5220	delivery	5	28
13897	2019-11-13 01:37:55	2019-11-13	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5250	delivery	5	40
13898	2019-11-13 01:43:46	2019-11-13	17	[{"id_menu":4,"count":2}]	1896	pick-up	0	17
13899	2019-11-13 01:43:52	2019-11-13	9	[{"id_menu":6,"count":1}]	2884	delivery	5	14
13900	2019-11-13 01:54:06	2019-11-13	9	[{"id_menu":6,"count":1}]	1413	pick-up	0	9
13901	2019-11-13 01:55:43	2019-11-13	12	[{"id_menu":1,"count":1}]	980	delivery	5	17
13902	2019-11-13 02:06:23	2019-11-13	9	[{"id_menu":7,"count":1}]	585	delivery	5	14
13903	2019-11-13 02:10:45	2019-11-13	9	[{"id_menu":7,"count":1}]	4622	delivery	5	14
13904	2019-11-13 02:11:54	2019-11-13	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	5226	delivery	5	40
13905	2019-11-13 02:15:41	2019-11-13	9	[{"id_menu":6,"count":1}]	1968	pick-up	0	9
13906	2019-11-13 02:24:28	2019-11-13	9	[{"id_menu":6,"count":1}]	5236	delivery	5	14
13907	2019-11-13 02:25:09	2019-11-13	9	[{"id_menu":7,"count":1}]	2951	delivery	5	14
13908	2019-11-13 02:36:08	2019-11-13	8	[{"id_menu":5,"count":1}]	1820	pick-up	0	8
13909	2019-11-13 02:40:33	2019-11-13	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	5229	delivery	5	38
13910	2019-11-13 02:42:28	2019-11-13	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2270	delivery	5	38
13911	2019-11-13 02:43:07	2019-11-13	12	[{"id_menu":3,"count":1}]	139	pick-up	0	12
13912	2019-11-13 02:52:54	2019-11-13	9	[{"id_menu":7,"count":1}]	1562	pick-up	0	9
13913	2019-11-13 03:06:33	2019-11-13	17	[{"id_menu":4,"count":1}]	847	pick-up	0	17
13914	2019-11-13 03:16:03	2019-11-13	9	[{"id_menu":7,"count":1}]	1924	pick-up	0	9
13915	2019-11-13 03:23:47	2019-11-13	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2894	pick-up	0	35
13916	2019-11-13 03:39:56	2019-11-13	12	[{"id_menu":3,"count":1}]	4682	delivery	5	17
13917	2019-11-13 03:56:06	2019-11-13	14	[{"id_menu":2,"count":1}]	2193	pick-up	0	14
13918	2019-11-13 03:56:07	2019-11-13	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3973	delivery	5	37
13919	2019-11-13 04:23:54	2019-11-13	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	2050	pick-up	0	20
13920	2019-11-13 04:35:51	2019-11-13	14	[{"id_menu":2,"count":1}]	3190	pick-up	0	14
13921	2019-11-13 04:53:21	2019-11-13	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	4100	delivery	5	25
13922	2019-11-13 05:06:38	2019-11-13	14	[{"id_menu":2,"count":1}]	2801	pick-up	0	14
13923	2019-11-13 05:12:27	2019-11-13	17	[{"id_menu":4,"count":1}]	5232	pick-up	0	17
13924	2019-11-13 05:20:48	2019-11-13	14	[{"id_menu":2,"count":1}]	2630	pick-up	0	14
13925	2019-11-13 05:28:37	2019-11-13	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3447	pick-up	0	17
13926	2019-11-13 05:31:22	2019-11-13	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2706	delivery	5	26
13927	2019-11-13 05:36:07	2019-11-13	9	[{"id_menu":6,"count":1}]	2567	pick-up	0	9
13928	2019-11-13 05:38:25	2019-11-13	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	5214	delivery	5	26
13929	2019-11-13 05:43:35	2019-11-13	9	[{"id_menu":6,"count":1}]	5237	pick-up	0	9
13930	2019-11-13 06:03:31	2019-11-13	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	4260	pick-up	0	26
13931	2019-11-13 06:06:13	2019-11-13	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	5218	delivery	5	28
13932	2019-11-13 06:40:53	2019-11-13	9	[{"id_menu":7,"count":1}]	5221	delivery	5	14
13933	2019-11-13 06:42:02	2019-11-13	8	[{"id_menu":5,"count":1}]	5249	delivery	5	13
13934	2019-11-13 06:42:09	2019-11-13	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	378	pick-up	0	24
13935	2019-11-13 06:47:36	2019-11-13	9	[{"id_menu":6,"count":1}]	956	delivery	5	14
13936	2019-11-13 07:16:21	2019-11-13	14	[{"id_menu":2,"count":1}]	1266	pick-up	0	14
13937	2019-11-13 07:42:04	2019-11-13	12	[{"id_menu":3,"count":1}]	2735	delivery	5	17
13938	2019-11-13 07:43:31	2019-11-13	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1825	pick-up	0	23
13939	2019-11-13 07:58:41	2019-11-13	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	472	pick-up	0	35
13940	2019-11-13 08:19:21	2019-11-13	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2148	delivery	5	35
13941	2019-11-13 08:27:10	2019-11-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1501	delivery	5	36
13942	2019-11-13 08:38:54	2019-11-13	12	[{"id_menu":3,"count":1}]	58	pick-up	0	12
13943	2019-11-13 08:47:41	2019-11-13	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4946	delivery	5	34
13944	2019-11-13 08:57:09	2019-11-13	14	[{"id_menu":2,"count":1}]	784	pick-up	0	14
13945	2019-11-13 08:58:19	2019-11-13	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5246	pick-up	0	17
13946	2019-11-13 09:11:53	2019-11-13	12	[{"id_menu":1,"count":1}]	5239	delivery	5	17
13947	2019-11-13 09:47:30	2019-11-13	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	5032	delivery	5	40
13948	2019-11-13 10:06:02	2019-11-13	9	[{"id_menu":7,"count":1}]	3293	delivery	5	14
13949	2019-11-13 10:11:38	2019-11-13	14	[{"id_menu":2,"count":1}]	4245	pick-up	0	14
13950	2019-11-13 10:34:29	2019-11-13	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1633	pick-up	0	21
13951	2019-11-13 10:42:18	2019-11-13	17	[{"id_menu":4,"count":1}]	678	pick-up	0	17
13952	2019-11-13 11:21:01	2019-11-13	14	[{"id_menu":2,"count":1}]	5079	delivery	5	19
13953	2019-11-13 11:22:03	2019-11-13	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1640	pick-up	0	23
13954	2019-11-13 11:23:53	2019-11-13	9	[{"id_menu":7,"count":1}]	5231	delivery	5	14
13955	2019-11-13 11:38:14	2019-11-13	8	[{"id_menu":5,"count":1}]	4411	delivery	5	13
13956	2019-11-13 12:13:31	2019-11-13	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5230	delivery	5	57
13957	2019-11-13 12:18:45	2019-11-13	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4535	delivery	5	34
13958	2019-11-13 12:20:25	2019-11-13	9	[{"id_menu":7,"count":1}]	2536	pick-up	0	9
13959	2019-11-13 12:32:47	2019-11-13	12	[{"id_menu":1,"count":1}]	3111	pick-up	0	12
13960	2019-11-13 12:58:37	2019-11-13	12	[{"id_menu":3,"count":1}]	626	delivery	5	17
13961	2019-11-13 13:03:46	2019-11-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3178	pick-up	0	31
13962	2019-11-13 13:07:18	2019-11-13	9	[{"id_menu":7,"count":1}]	2669	delivery	5	14
13963	2019-11-13 13:08:51	2019-11-13	14	[{"id_menu":2,"count":1}]	5241	pick-up	0	14
13964	2019-11-13 13:10:21	2019-11-13	17	[{"id_menu":5,"count":3},{"id_menu":7,"count":1}]	5251	delivery	5	22
13965	2019-11-13 13:16:30	2019-11-13	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	820	pick-up	0	25
13966	2019-11-13 13:27:03	2019-11-13	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3651	delivery	5	31
13967	2019-11-13 13:39:39	2019-11-13	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5224	pick-up	0	35
13968	2019-11-13 13:54:25	2019-11-13	14	[{"id_menu":2,"count":1}]	5228	delivery	5	19
13969	2019-11-13 13:57:20	2019-11-13	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	4406	delivery	5	26
13970	2019-11-13 14:31:54	2019-11-13	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	5225	delivery	5	36
13971	2019-11-13 14:43:20	2019-11-13	12	[{"id_menu":1,"count":1}]	4870	delivery	5	17
13972	2019-11-13 14:51:21	2019-11-13	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1409	pick-up	0	23
13973	2019-11-13 15:01:22	2019-11-13	9	[{"id_menu":6,"count":1}]	5238	pick-up	0	9
13974	2019-11-13 15:08:47	2019-11-13	14	[{"id_menu":2,"count":1}]	5215	pick-up	0	14
13975	2019-11-13 15:10:36	2019-11-13	14	[{"id_menu":2,"count":1}]	5243	pick-up	0	14
13976	2019-11-13 15:11:12	2019-11-13	8	[{"id_menu":5,"count":1}]	2218	pick-up	0	8
13977	2019-11-13 15:29:54	2019-11-13	9	[{"id_menu":6,"count":1}]	5222	delivery	5	14
13978	2019-11-13 15:35:06	2019-11-13	9	[{"id_menu":6,"count":1}]	4428	pick-up	0	9
13979	2019-11-13 15:35:34	2019-11-13	14	[{"id_menu":2,"count":1}]	2631	pick-up	0	14
13980	2019-11-13 15:36:31	2019-11-13	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	87	delivery	5	43
13981	2019-11-13 15:45:16	2019-11-13	9	[{"id_menu":7,"count":1}]	5247	delivery	5	14
13982	2019-11-13 16:26:33	2019-11-13	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	2179	pick-up	0	17
13983	2019-11-13 16:28:01	2019-11-13	14	[{"id_menu":2,"count":1}]	2850	pick-up	0	14
13984	2019-11-13 16:35:30	2019-11-13	14	[{"id_menu":2,"count":1}]	546	delivery	5	19
13985	2019-11-13 17:25:25	2019-11-13	14	[{"id_menu":2,"count":1}]	1595	delivery	5	19
13986	2019-11-13 17:32:54	2019-11-13	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2935	delivery	5	39
13987	2019-11-13 17:38:04	2019-11-13	12	[{"id_menu":3,"count":1}]	5223	pick-up	0	12
13988	2019-11-13 18:05:46	2019-11-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	5227	delivery	5	28
13989	2019-11-13 18:08:30	2019-11-13	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	5233	delivery	5	31
13990	2019-11-13 18:11:43	2019-11-13	12	[{"id_menu":1,"count":1}]	1715	delivery	5	17
13991	2019-11-13 18:16:52	2019-11-13	9	[{"id_menu":7,"count":1}]	701	pick-up	0	9
13992	2019-11-13 18:31:55	2019-11-13	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	80	delivery	5	28
13993	2019-11-13 18:39:24	2019-11-13	9	[{"id_menu":7,"count":1}]	5245	delivery	5	14
13994	2019-11-13 18:50:23	2019-11-13	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	729	delivery	5	31
13995	2019-11-13 18:52:16	2019-11-13	9	[{"id_menu":7,"count":1}]	2820	delivery	5	14
13996	2019-11-13 19:05:54	2019-11-13	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	616	delivery	5	40
13997	2019-11-13 19:11:15	2019-11-13	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2078	pick-up	0	43
13998	2019-11-13 19:16:40	2019-11-13	17	[{"id_menu":4,"count":1}]	478	pick-up	0	17
13999	2019-11-13 19:21:53	2019-11-13	8	[{"id_menu":5,"count":1}]	1055	pick-up	0	8
14000	2019-11-13 20:02:21	2019-11-13	17	[{"id_menu":4,"count":1}]	5234	pick-up	0	17
14001	2019-11-13 20:10:04	2019-11-13	14	[{"id_menu":2,"count":1}]	1523	pick-up	0	14
14002	2019-11-13 20:10:21	2019-11-13	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4800	delivery	5	31
14003	2019-11-13 20:42:21	2019-11-13	12	[{"id_menu":3,"count":1}]	5252	pick-up	0	12
14004	2019-11-13 20:45:29	2019-11-13	8	[{"id_menu":5,"count":1}]	601	pick-up	0	8
14005	2019-11-13 21:04:55	2019-11-13	12	[{"id_menu":3,"count":1}]	5240	pick-up	0	12
14006	2019-11-13 21:21:19	2019-11-13	12	[{"id_menu":3,"count":1}]	5146	delivery	5	17
14007	2019-11-13 21:39:34	2019-11-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3501	pick-up	0	23
14008	2019-11-13 21:46:22	2019-11-13	9	[{"id_menu":6,"count":1}]	1174	delivery	5	14
14009	2019-11-13 21:51:53	2019-11-13	12	[{"id_menu":1,"count":1}]	5235	delivery	5	17
14010	2019-11-13 22:04:31	2019-11-13	8	[{"id_menu":5,"count":1}]	376	pick-up	0	8
14011	2019-11-13 22:09:02	2019-11-13	9	[{"id_menu":6,"count":1}]	3887	delivery	5	14
14012	2019-11-13 22:20:45	2019-11-13	9	[{"id_menu":6,"count":1}]	5212	delivery	5	14
14013	2019-11-13 22:26:20	2019-11-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5244	delivery	5	23
14014	2019-11-13 22:27:17	2019-11-13	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3835	delivery	5	40
14015	2019-11-13 22:33:33	2019-11-13	9	[{"id_menu":6,"count":1}]	4642	pick-up	0	9
14016	2019-11-13 22:39:30	2019-11-13	9	[{"id_menu":7,"count":1}]	5217	delivery	5	14
14017	2019-11-13 22:58:23	2019-11-13	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1736	pick-up	0	21
14018	2019-11-13 23:01:03	2019-11-13	9	[{"id_menu":6,"count":1}]	4094	pick-up	0	9
14019	2019-11-13 23:01:05	2019-11-13	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	3428	delivery	5	29
14020	2019-11-13 23:14:04	2019-11-13	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	301	delivery	5	35
14021	2019-11-14 00:00:50	2019-11-14	12	[{"id_menu":1,"count":1}]	1076	pick-up	0	12
14022	2019-11-14 00:26:06	2019-11-14	14	[{"id_menu":2,"count":1}]	5274	delivery	5	19
14023	2019-11-14 00:36:23	2019-11-14	14	[{"id_menu":2,"count":1}]	5260	pick-up	0	14
14024	2019-11-14 00:49:43	2019-11-14	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2993	pick-up	0	35
14025	2019-11-14 00:57:55	2019-11-14	9	[{"id_menu":6,"count":1}]	5290	delivery	5	14
14026	2019-11-14 00:57:57	2019-11-14	9	[{"id_menu":7,"count":1}]	3211	delivery	5	14
14027	2019-11-14 01:22:21	2019-11-14	9	[{"id_menu":6,"count":1}]	5217	delivery	5	14
14028	2019-11-14 01:39:53	2019-11-14	17	[{"id_menu":4,"count":1}]	3578	pick-up	0	17
14029	2019-11-14 01:53:00	2019-11-14	14	[{"id_menu":2,"count":1}]	1095	pick-up	0	14
14030	2019-11-14 01:53:40	2019-11-14	8	[{"id_menu":5,"count":1}]	5279	pick-up	0	8
14031	2019-11-14 01:56:05	2019-11-14	9	[{"id_menu":6,"count":1}]	856	pick-up	0	9
14032	2019-11-14 02:03:26	2019-11-14	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	697	pick-up	0	24
14033	2019-11-14 02:09:51	2019-11-14	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	5292	delivery	5	26
14034	2019-11-14 02:13:12	2019-11-14	12	[{"id_menu":1,"count":1}]	5287	delivery	5	17
14035	2019-11-14 02:20:06	2019-11-14	12	[{"id_menu":3,"count":1}]	2002	pick-up	0	12
14036	2019-11-14 02:21:28	2019-11-14	9	[{"id_menu":7,"count":2}]	5254	delivery	5	14
14037	2019-11-14 02:35:52	2019-11-14	9	[{"id_menu":7,"count":2}]	5262	delivery	5	14
14038	2019-11-14 02:59:57	2019-11-14	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	5265	delivery	5	23
14039	2019-11-14 03:02:59	2019-11-14	9	[{"id_menu":6,"count":1}]	1372	pick-up	0	9
14040	2019-11-14 03:33:02	2019-11-14	12	[{"id_menu":3,"count":1}]	2672	pick-up	0	12
14041	2019-11-14 03:37:11	2019-11-14	12	[{"id_menu":1,"count":1}]	3005	delivery	5	17
14042	2019-11-14 03:38:51	2019-11-14	17	[{"id_menu":4,"count":1}]	2171	delivery	5	22
14043	2019-11-14 03:41:28	2019-11-14	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	536	pick-up	0	35
14044	2019-11-14 03:56:12	2019-11-14	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	2163	delivery	5	29
14045	2019-11-14 04:19:05	2019-11-14	9	[{"id_menu":6,"count":1}]	3399	pick-up	0	9
14046	2019-11-14 04:20:46	2019-11-14	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	788	delivery	5	45
14047	2019-11-14 04:33:33	2019-11-14	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	811	pick-up	0	22
14048	2019-11-14 04:36:02	2019-11-14	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5297	delivery	5	36
14049	2019-11-14 04:47:42	2019-11-14	17	[{"id_menu":4,"count":1}]	626	delivery	5	22
14050	2019-11-14 05:06:54	2019-11-14	14	[{"id_menu":2,"count":2}]	3198	pick-up	0	14
14051	2019-11-14 05:18:58	2019-11-14	9	[{"id_menu":7,"count":1}]	5269	delivery	5	14
14052	2019-11-14 05:23:54	2019-11-14	8	[{"id_menu":5,"count":1}]	4289	delivery	5	13
14053	2019-11-14 05:24:36	2019-11-14	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5284	delivery	5	45
14054	2019-11-14 05:31:11	2019-11-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	5253	pick-up	0	31
14055	2019-11-14 06:14:29	2019-11-14	9	[{"id_menu":6,"count":1}]	2552	pick-up	0	9
14056	2019-11-14 06:27:55	2019-11-14	12	[{"id_menu":3,"count":1}]	4295	pick-up	0	12
14057	2019-11-14 06:36:34	2019-11-14	14	[{"id_menu":2,"count":1}]	5259	pick-up	0	14
14058	2019-11-14 07:11:32	2019-11-14	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4044	delivery	5	22
14059	2019-11-14 07:11:41	2019-11-14	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	5277	delivery	5	46
14060	2019-11-14 07:28:37	2019-11-14	9	[{"id_menu":6,"count":1}]	3421	pick-up	0	9
14061	2019-11-14 07:29:38	2019-11-14	12	[{"id_menu":1,"count":1}]	888	pick-up	0	12
14062	2019-11-14 07:52:42	2019-11-14	14	[{"id_menu":2,"count":1}]	708	pick-up	0	14
14063	2019-11-14 07:54:35	2019-11-14	17	[{"id_menu":4,"count":1}]	418	pick-up	0	17
14064	2019-11-14 08:01:14	2019-11-14	12	[{"id_menu":3,"count":1}]	4462	pick-up	0	12
14065	2019-11-14 08:08:39	2019-11-14	14	[{"id_menu":2,"count":1}]	802	pick-up	0	14
14066	2019-11-14 08:36:21	2019-11-14	12	[{"id_menu":3,"count":1}]	742	delivery	5	17
14067	2019-11-14 08:57:47	2019-11-14	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5285	delivery	5	23
14068	2019-11-14 08:59:55	2019-11-14	12	[{"id_menu":1,"count":1}]	575	delivery	5	17
14069	2019-11-14 09:31:20	2019-11-14	9	[{"id_menu":6,"count":1}]	906	delivery	5	14
14070	2019-11-14 10:22:56	2019-11-14	12	[{"id_menu":3,"count":1}]	3527	pick-up	0	12
14071	2019-11-14 10:48:43	2019-11-14	17	[{"id_menu":4,"count":1}]	1432	pick-up	0	17
14072	2019-11-14 11:03:54	2019-11-14	17	[{"id_menu":4,"count":1}]	5268	delivery	5	22
14073	2019-11-14 11:29:02	2019-11-14	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	4333	delivery	5	22
14074	2019-11-14 11:52:55	2019-11-14	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2875	pick-up	0	35
14075	2019-11-14 11:54:28	2019-11-14	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3513	delivery	5	28
14076	2019-11-14 12:04:59	2019-11-14	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4393	pick-up	0	22
14077	2019-11-14 12:09:47	2019-11-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1563	delivery	5	36
14078	2019-11-14 12:13:35	2019-11-14	12	[{"id_menu":1,"count":1}]	5258	delivery	5	17
14079	2019-11-14 12:16:19	2019-11-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	2931	delivery	5	31
14080	2019-11-14 12:49:41	2019-11-14	17	[{"id_menu":4,"count":1}]	5298	delivery	5	22
14081	2019-11-14 13:08:22	2019-11-14	12	[{"id_menu":3,"count":1}]	5291	delivery	5	17
14082	2019-11-14 13:09:37	2019-11-14	9	[{"id_menu":7,"count":1}]	2731	delivery	5	14
14083	2019-11-14 13:14:29	2019-11-14	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5271	delivery	5	37
14084	2019-11-14 13:24:53	2019-11-14	8	[{"id_menu":5,"count":1}]	5272	delivery	5	13
14085	2019-11-14 13:43:16	2019-11-14	8	[{"id_menu":5,"count":1}]	5293	pick-up	0	8
14086	2019-11-14 14:17:17	2019-11-14	12	[{"id_menu":1,"count":1}]	5275	delivery	5	17
14087	2019-11-14 14:24:32	2019-11-14	17	[{"id_menu":4,"count":1}]	5255	delivery	5	22
14088	2019-11-14 14:49:59	2019-11-14	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	552	pick-up	0	38
14089	2019-11-14 14:58:15	2019-11-14	8	[{"id_menu":5,"count":1}]	5282	delivery	5	13
14090	2019-11-14 15:28:04	2019-11-14	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5276	delivery	5	35
14091	2019-11-14 15:30:26	2019-11-14	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2959	pick-up	0	21
14092	2019-11-14 15:31:23	2019-11-14	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5289	delivery	5	43
14093	2019-11-14 15:43:53	2019-11-14	17	[{"id_menu":4,"count":1}]	2798	delivery	5	22
14094	2019-11-14 15:44:05	2019-11-14	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	5278	delivery	5	38
14095	2019-11-14 16:05:41	2019-11-14	14	[{"id_menu":2,"count":1}]	1542	pick-up	0	14
14096	2019-11-14 16:11:26	2019-11-14	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	4499	delivery	5	34
14097	2019-11-14 16:12:53	2019-11-14	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1072	pick-up	0	23
14098	2019-11-14 16:16:18	2019-11-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1107	pick-up	0	31
14099	2019-11-14 16:45:55	2019-11-14	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2439	delivery	5	45
14100	2019-11-14 16:50:25	2019-11-14	14	[{"id_menu":2,"count":1}]	1177	pick-up	0	14
14101	2019-11-14 17:00:12	2019-11-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5264	delivery	5	31
14102	2019-11-14 17:22:54	2019-11-14	9	[{"id_menu":7,"count":2}]	3148	delivery	5	14
14103	2019-11-14 17:23:29	2019-11-14	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4709	delivery	5	55
14104	2019-11-14 18:01:03	2019-11-14	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5295	delivery	5	31
14105	2019-11-14 18:11:32	2019-11-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	778	pick-up	0	17
14106	2019-11-14 18:15:34	2019-11-14	9	[{"id_menu":7,"count":1}]	5261	delivery	5	14
14107	2019-11-14 18:22:46	2019-11-14	14	[{"id_menu":2,"count":1}]	2661	delivery	5	19
14108	2019-11-14 18:29:58	2019-11-14	8	[{"id_menu":5,"count":1}]	4755	delivery	5	13
14109	2019-11-14 18:31:31	2019-11-14	12	[{"id_menu":3,"count":1}]	5283	pick-up	0	12
14110	2019-11-14 18:37:40	2019-11-14	12	[{"id_menu":3,"count":1}]	1820	pick-up	0	12
14111	2019-11-14 18:40:40	2019-11-14	9	[{"id_menu":7,"count":1}]	4874	pick-up	0	9
14112	2019-11-14 18:43:25	2019-11-14	9	[{"id_menu":6,"count":1}]	5013	delivery	5	14
14113	2019-11-14 18:49:39	2019-11-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4629	pick-up	0	23
14114	2019-11-14 18:56:48	2019-11-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	5286	pick-up	0	31
14115	2019-11-14 19:39:40	2019-11-14	12	[{"id_menu":1,"count":1}]	1864	delivery	5	17
14116	2019-11-14 20:22:24	2019-11-14	9	[{"id_menu":7,"count":1}]	2567	pick-up	0	9
14117	2019-11-14 20:25:05	2019-11-14	9	[{"id_menu":7,"count":1}]	5256	pick-up	0	9
14118	2019-11-14 20:35:57	2019-11-14	14	[{"id_menu":2,"count":1}]	2420	pick-up	0	14
14119	2019-11-14 21:02:32	2019-11-14	12	[{"id_menu":3,"count":1}]	3567	pick-up	0	12
14120	2019-11-14 21:09:43	2019-11-14	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	5294	delivery	5	40
14121	2019-11-14 21:29:11	2019-11-14	14	[{"id_menu":2,"count":1}]	236	pick-up	0	14
14122	2019-11-14 21:37:07	2019-11-14	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2513	pick-up	0	21
14123	2019-11-14 21:48:39	2019-11-14	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2640	delivery	5	26
14124	2019-11-14 21:55:59	2019-11-14	9	[{"id_menu":6,"count":1}]	304	pick-up	0	9
14125	2019-11-14 22:05:49	2019-11-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2739	delivery	5	28
14126	2019-11-14 22:39:27	2019-11-14	8	[{"id_menu":5,"count":1}]	5281	delivery	5	13
14127	2019-11-14 22:58:53	2019-11-14	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	317	delivery	5	36
14128	2019-11-14 23:06:22	2019-11-14	8	[{"id_menu":5,"count":1}]	1760	pick-up	0	8
14129	2019-11-14 23:13:53	2019-11-14	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4980	delivery	5	40
14130	2019-11-14 23:18:53	2019-11-14	17	[{"id_menu":4,"count":1}]	1925	pick-up	0	17
14131	2019-11-14 23:23:22	2019-11-14	9	[{"id_menu":6,"count":1}]	98	delivery	5	14
14132	2019-11-14 23:32:55	2019-11-14	8	[{"id_menu":5,"count":1}]	66	pick-up	0	8
14133	2019-11-14 23:36:57	2019-11-14	12	[{"id_menu":3,"count":1}]	3688	delivery	5	17
14134	2019-11-14 23:57:06	2019-11-14	8	[{"id_menu":5,"count":1}]	813	delivery	5	13
14135	2019-11-15 00:00:46	2019-11-15	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	5312	delivery	5	28
14136	2019-11-15 00:02:38	2019-11-15	9	[{"id_menu":6,"count":1}]	2562	delivery	5	14
14137	2019-11-15 00:11:49	2019-11-15	9	[{"id_menu":7,"count":1}]	5354	delivery	5	14
14138	2019-11-15 00:21:46	2019-11-15	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	2581	pick-up	0	20
14139	2019-11-15 00:37:37	2019-11-15	8	[{"id_menu":5,"count":1}]	1149	pick-up	0	8
14140	2019-11-15 01:00:17	2019-11-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2667	pick-up	0	26
14141	2019-11-15 01:48:31	2019-11-15	14	[{"id_menu":2,"count":1}]	2277	delivery	5	19
14142	2019-11-15 01:50:50	2019-11-15	17	[{"id_menu":4,"count":1}]	5311	delivery	5	22
14143	2019-11-15 01:52:09	2019-11-15	14	[{"id_menu":2,"count":1}]	2798	pick-up	0	14
14144	2019-11-15 01:52:15	2019-11-15	12	[{"id_menu":3,"count":1}]	3372	delivery	5	17
14145	2019-11-15 02:30:38	2019-11-15	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1072	delivery	5	34
14146	2019-11-15 02:54:44	2019-11-15	12	[{"id_menu":3,"count":1}]	2339	pick-up	0	12
14147	2019-11-15 02:56:24	2019-11-15	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5340	delivery	5	34
14148	2019-11-15 03:19:42	2019-11-15	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2503	pick-up	0	21
14149	2019-11-15 03:23:41	2019-11-15	8	[{"id_menu":5,"count":1}]	5309	delivery	5	13
14150	2019-11-15 03:28:30	2019-11-15	17	[{"id_menu":4,"count":1}]	3003	pick-up	0	17
14151	2019-11-15 04:02:34	2019-11-15	17	[{"id_menu":4,"count":1}]	2838	pick-up	0	17
14152	2019-11-15 04:20:45	2019-11-15	9	[{"id_menu":7,"count":1}]	5326	delivery	5	14
14153	2019-11-15 04:30:26	2019-11-15	12	[{"id_menu":1,"count":1}]	127	delivery	5	17
14154	2019-11-15 04:42:10	2019-11-15	12	[{"id_menu":3,"count":1}]	5335	delivery	5	17
14155	2019-11-15 04:42:25	2019-11-15	9	[{"id_menu":6,"count":1}]	5347	delivery	5	14
14156	2019-11-15 04:42:41	2019-11-15	8	[{"id_menu":5,"count":1}]	3568	delivery	5	13
14157	2019-11-15 04:58:27	2019-11-15	9	[{"id_menu":6,"count":3}]	5304	delivery	5	14
14158	2019-11-15 05:10:19	2019-11-15	8	[{"id_menu":5,"count":1}]	552	pick-up	0	8
14159	2019-11-15 05:11:20	2019-11-15	9	[{"id_menu":6,"count":1}]	4361	pick-up	0	9
14160	2019-11-15 05:16:24	2019-11-15	17	[{"id_menu":4,"count":1}]	4874	pick-up	0	17
14161	2019-11-15 05:17:22	2019-11-15	12	[{"id_menu":1,"count":1}]	2065	delivery	5	17
14162	2019-11-15 05:24:06	2019-11-15	9	[{"id_menu":6,"count":1}]	5310	pick-up	0	9
14163	2019-11-15 05:43:47	2019-11-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1435	pick-up	0	26
14164	2019-11-15 05:49:15	2019-11-15	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1523	delivery	5	31
14165	2019-11-15 05:53:42	2019-11-15	9	[{"id_menu":6,"count":1}]	5303	pick-up	0	9
14166	2019-11-15 06:00:14	2019-11-15	17	[{"id_menu":4,"count":1}]	401	delivery	5	22
14167	2019-11-15 06:25:59	2019-11-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2272	pick-up	0	23
14168	2019-11-15 06:51:31	2019-11-15	17	[{"id_menu":4,"count":1}]	5349	delivery	5	22
14169	2019-11-15 07:14:51	2019-11-15	9	[{"id_menu":7,"count":1}]	5306	pick-up	0	9
14170	2019-11-15 07:29:36	2019-11-15	9	[{"id_menu":7,"count":1}]	5220	delivery	5	14
14171	2019-11-15 07:29:59	2019-11-15	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4946	delivery	5	22
14172	2019-11-15 07:40:53	2019-11-15	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	5345	delivery	5	31
14173	2019-11-15 07:43:13	2019-11-15	12	[{"id_menu":1,"count":1}]	5343	delivery	5	17
14174	2019-11-15 08:11:14	2019-11-15	14	[{"id_menu":2,"count":1}]	5313	pick-up	0	14
14175	2019-11-15 08:21:56	2019-11-15	14	[{"id_menu":2,"count":1}]	5338	pick-up	0	14
14176	2019-11-15 08:42:20	2019-11-15	14	[{"id_menu":2,"count":1}]	4590	delivery	5	19
14177	2019-11-15 09:17:34	2019-11-15	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5348	delivery	5	43
14178	2019-11-15 09:19:41	2019-11-15	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":2}]	754	pick-up	0	22
14179	2019-11-15 09:27:21	2019-11-15	14	[{"id_menu":2,"count":1}]	4804	pick-up	0	14
14180	2019-11-15 09:28:13	2019-11-15	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	787	pick-up	0	29
14181	2019-11-15 09:28:53	2019-11-15	9	[{"id_menu":7,"count":1}]	2375	delivery	5	14
14182	2019-11-15 10:03:50	2019-11-15	9	[{"id_menu":6,"count":1}]	766	pick-up	0	9
14183	2019-11-15 10:11:59	2019-11-15	9	[{"id_menu":6,"count":1}]	5355	delivery	5	14
14184	2019-11-15 10:16:05	2019-11-15	9	[{"id_menu":6,"count":1}]	5333	delivery	5	14
14185	2019-11-15 10:25:57	2019-11-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3413	delivery	5	28
14186	2019-11-15 10:33:13	2019-11-15	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	5352	delivery	5	26
14187	2019-11-15 10:33:20	2019-11-15	14	[{"id_menu":2,"count":1}]	2056	pick-up	0	14
14188	2019-11-15 10:37:35	2019-11-15	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5329	delivery	5	51
14189	2019-11-15 10:51:24	2019-11-15	9	[{"id_menu":7,"count":1}]	1766	delivery	5	14
14190	2019-11-15 10:53:03	2019-11-15	9	[{"id_menu":6,"count":1}]	243	delivery	5	14
14191	2019-11-15 10:54:38	2019-11-15	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5316	delivery	5	40
14192	2019-11-15 11:22:12	2019-11-15	8	[{"id_menu":5,"count":1}]	2228	pick-up	0	8
14193	2019-11-15 11:39:58	2019-11-15	12	[{"id_menu":3,"count":1}]	5336	pick-up	0	12
14194	2019-11-15 11:41:33	2019-11-15	9	[{"id_menu":6,"count":1}]	5201	pick-up	0	9
14195	2019-11-15 12:34:57	2019-11-15	14	[{"id_menu":2,"count":1}]	1860	delivery	5	19
14196	2019-11-15 12:40:30	2019-11-15	14	[{"id_menu":2,"count":1}]	1075	delivery	5	19
14197	2019-11-15 12:41:39	2019-11-15	8	[{"id_menu":5,"count":1}]	5322	delivery	5	13
14198	2019-11-15 12:43:03	2019-11-15	9	[{"id_menu":6,"count":1}]	4800	pick-up	0	9
14199	2019-11-15 12:56:12	2019-11-15	12	[{"id_menu":1,"count":1}]	676	pick-up	0	12
14200	2019-11-15 12:58:25	2019-11-15	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	527	pick-up	0	29
14201	2019-11-15 13:02:23	2019-11-15	9	[{"id_menu":6,"count":1}]	4737	delivery	5	14
14202	2019-11-15 13:03:27	2019-11-15	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5075	pick-up	0	25
14203	2019-11-15 13:10:52	2019-11-15	12	[{"id_menu":3,"count":1}]	1183	pick-up	0	12
14204	2019-11-15 13:40:31	2019-11-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1922	pick-up	0	23
14205	2019-11-15 13:50:42	2019-11-15	9	[{"id_menu":7,"count":1}]	3973	delivery	5	14
14206	2019-11-15 14:07:40	2019-11-15	8	[{"id_menu":5,"count":1}]	4211	delivery	5	13
14207	2019-11-15 14:32:20	2019-11-15	9	[{"id_menu":7,"count":2}]	5328	delivery	5	14
14208	2019-11-15 14:48:28	2019-11-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	790	pick-up	0	23
14209	2019-11-15 15:47:12	2019-11-15	9	[{"id_menu":6,"count":1}]	5327	delivery	5	14
14210	2019-11-15 15:56:29	2019-11-15	17	[{"id_menu":4,"count":1}]	5330	pick-up	0	17
14211	2019-11-15 16:07:57	2019-11-15	17	[{"id_menu":4,"count":1}]	5300	pick-up	0	17
14212	2019-11-15 16:09:59	2019-11-15	14	[{"id_menu":2,"count":1}]	5302	pick-up	0	14
14213	2019-11-15 16:42:18	2019-11-15	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5337	delivery	5	31
14214	2019-11-15 16:49:40	2019-11-15	12	[{"id_menu":1,"count":1}]	822	pick-up	0	12
14215	2019-11-15 16:53:21	2019-11-15	9	[{"id_menu":7,"count":1}]	856	pick-up	0	9
14216	2019-11-15 17:05:42	2019-11-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5332	delivery	5	28
14217	2019-11-15 17:17:07	2019-11-15	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5346	delivery	5	53
14218	2019-11-15 17:52:13	2019-11-15	17	[{"id_menu":4,"count":1}]	305	delivery	5	22
14219	2019-11-15 18:11:28	2019-11-15	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1106	pick-up	0	21
14220	2019-11-15 18:19:58	2019-11-15	12	[{"id_menu":1,"count":1}]	404	delivery	5	17
14221	2019-11-15 18:25:29	2019-11-15	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5003	delivery	5	53
14222	2019-11-15 18:30:31	2019-11-15	8	[{"id_menu":5,"count":1}]	2054	pick-up	0	8
14223	2019-11-15 18:39:24	2019-11-15	12	[{"id_menu":1,"count":1}]	5301	pick-up	0	12
14224	2019-11-15 19:21:41	2019-11-15	14	[{"id_menu":2,"count":1}]	4459	delivery	5	19
14225	2019-11-15 19:24:48	2019-11-15	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5331	delivery	5	31
14226	2019-11-15 19:50:46	2019-11-15	9	[{"id_menu":6,"count":1}]	4369	delivery	5	14
14227	2019-11-15 19:59:19	2019-11-15	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	5323	delivery	5	26
14228	2019-11-15 20:27:18	2019-11-15	14	[{"id_menu":2,"count":1}]	5314	pick-up	0	14
14229	2019-11-15 20:30:14	2019-11-15	9	[{"id_menu":7,"count":2}]	2373	pick-up	0	9
14230	2019-11-15 20:31:13	2019-11-15	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5350	pick-up	0	29
14231	2019-11-15 20:40:13	2019-11-15	8	[{"id_menu":5,"count":1}]	5226	delivery	5	13
14232	2019-11-15 20:48:35	2019-11-15	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	3634	pick-up	0	29
14233	2019-11-15 20:54:56	2019-11-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	3125	delivery	5	31
14234	2019-11-15 20:58:47	2019-11-15	9	[{"id_menu":6,"count":1}]	614	delivery	5	14
14235	2019-11-15 21:02:55	2019-11-15	9	[{"id_menu":6,"count":1}]	1021	pick-up	0	9
14236	2019-11-15 21:09:20	2019-11-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5320	delivery	5	31
14237	2019-11-15 21:15:53	2019-11-15	12	[{"id_menu":3,"count":1}]	5321	delivery	5	17
14238	2019-11-15 21:31:42	2019-11-15	8	[{"id_menu":5,"count":1}]	2623	pick-up	0	8
14239	2019-11-15 21:42:59	2019-11-15	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	5351	delivery	5	34
14240	2019-11-15 22:50:58	2019-11-15	17	[{"id_menu":4,"count":1}]	563	pick-up	0	17
14241	2019-11-15 23:05:56	2019-11-15	12	[{"id_menu":3,"count":1}]	2007	pick-up	0	12
14242	2019-11-15 23:10:18	2019-11-15	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1209	pick-up	0	21
14243	2019-11-15 23:46:52	2019-11-15	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2227	pick-up	0	29
14244	2019-11-16 00:03:44	2019-11-16	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	594	delivery	5	26
14245	2019-11-16 00:06:19	2019-11-16	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	852	delivery	5	23
14246	2019-11-16 00:10:13	2019-11-16	14	[{"id_menu":2,"count":1}]	5332	pick-up	0	14
14247	2019-11-16 00:21:36	2019-11-16	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1293	delivery	5	34
14248	2019-11-16 00:35:13	2019-11-16	12	[{"id_menu":1,"count":1}]	387	pick-up	0	12
14249	2019-11-16 00:46:51	2019-11-16	12	[{"id_menu":1,"count":1}]	1611	delivery	5	17
14250	2019-11-16 00:52:01	2019-11-16	17	[{"id_menu":4,"count":1}]	1931	pick-up	0	17
14251	2019-11-16 00:52:35	2019-11-16	14	[{"id_menu":2,"count":1}]	2274	delivery	5	19
14252	2019-11-16 01:04:49	2019-11-16	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1490	pick-up	0	24
14253	2019-11-16 01:28:12	2019-11-16	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	4628	pick-up	0	24
14254	2019-11-16 02:00:15	2019-11-16	14	[{"id_menu":2,"count":1}]	1140	pick-up	0	14
14255	2019-11-16 02:18:09	2019-11-16	9	[{"id_menu":7,"count":1}]	4248	pick-up	0	9
14256	2019-11-16 02:29:42	2019-11-16	14	[{"id_menu":2,"count":1}]	333	pick-up	0	14
14257	2019-11-16 02:36:32	2019-11-16	14	[{"id_menu":2,"count":1}]	2962	pick-up	0	14
14258	2019-11-16 02:49:59	2019-11-16	17	[{"id_menu":4,"count":1}]	5387	pick-up	0	17
14259	2019-11-16 03:01:40	2019-11-16	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	5071	delivery	5	31
14260	2019-11-16 03:03:50	2019-11-16	17	[{"id_menu":4,"count":1}]	851	delivery	5	22
14261	2019-11-16 03:04:38	2019-11-16	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	5379	delivery	5	22
14262	2019-11-16 03:06:23	2019-11-16	9	[{"id_menu":6,"count":1}]	2725	pick-up	0	9
14263	2019-11-16 03:15:03	2019-11-16	17	[{"id_menu":4,"count":1}]	4684	pick-up	0	17
14264	2019-11-16 03:28:46	2019-11-16	9	[{"id_menu":6,"count":1}]	5390	pick-up	0	9
14265	2019-11-16 03:29:00	2019-11-16	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	15	delivery	5	34
14266	2019-11-16 03:33:43	2019-11-16	9	[{"id_menu":6,"count":1}]	3320	pick-up	0	9
14267	2019-11-16 03:39:44	2019-11-16	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	5374	pick-up	0	26
14268	2019-11-16 04:07:30	2019-11-16	12	[{"id_menu":3,"count":1}]	2867	pick-up	0	12
14269	2019-11-16 04:08:16	2019-11-16	8	[{"id_menu":5,"count":1}]	5389	delivery	5	13
14270	2019-11-16 04:09:03	2019-11-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5343	pick-up	0	23
14271	2019-11-16 04:50:30	2019-11-16	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5364	delivery	5	37
14272	2019-11-16 04:53:38	2019-11-16	14	[{"id_menu":2,"count":2}]	5388	delivery	5	19
14273	2019-11-16 04:54:34	2019-11-16	9	[{"id_menu":7,"count":1}]	5381	delivery	5	14
14274	2019-11-16 04:59:54	2019-11-16	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2037	delivery	5	36
14275	2019-11-16 05:05:20	2019-11-16	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3916	delivery	5	40
14276	2019-11-16 05:10:29	2019-11-16	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1342	pick-up	0	35
14277	2019-11-16 05:14:30	2019-11-16	9	[{"id_menu":6,"count":1}]	5411	delivery	5	14
14278	2019-11-16 05:38:00	2019-11-16	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5380	delivery	5	22
14279	2019-11-16 05:38:57	2019-11-16	12	[{"id_menu":3,"count":1}]	2471	pick-up	0	12
14280	2019-11-16 05:44:19	2019-11-16	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4034	pick-up	0	35
14281	2019-11-16 05:55:31	2019-11-16	14	[{"id_menu":2,"count":1}]	5383	pick-up	0	14
14282	2019-11-16 05:56:55	2019-11-16	9	[{"id_menu":6,"count":1}]	3181	delivery	5	14
14283	2019-11-16 05:59:02	2019-11-16	12	[{"id_menu":3,"count":1}]	1681	pick-up	0	12
14284	2019-11-16 06:18:16	2019-11-16	9	[{"id_menu":7,"count":1}]	5376	delivery	5	14
14285	2019-11-16 06:18:23	2019-11-16	17	[{"id_menu":4,"count":1}]	5385	delivery	5	22
14286	2019-11-16 06:20:30	2019-11-16	14	[{"id_menu":2,"count":1}]	5400	pick-up	0	14
14287	2019-11-16 06:22:22	2019-11-16	14	[{"id_menu":2,"count":1}]	5409	pick-up	0	14
14288	2019-11-16 06:23:42	2019-11-16	12	[{"id_menu":3,"count":1}]	1720	pick-up	0	12
14289	2019-11-16 06:25:05	2019-11-16	17	[{"id_menu":4,"count":1}]	1023	delivery	5	22
14290	2019-11-16 06:28:17	2019-11-16	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	113	pick-up	0	26
14291	2019-11-16 06:36:40	2019-11-16	14	[{"id_menu":2,"count":1}]	5369	delivery	5	19
14292	2019-11-16 06:43:19	2019-11-16	17	[{"id_menu":4,"count":1}]	4090	pick-up	0	17
14293	2019-11-16 06:43:50	2019-11-16	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	5125	delivery	5	25
14294	2019-11-16 06:46:49	2019-11-16	8	[{"id_menu":5,"count":1}]	4634	pick-up	0	8
14295	2019-11-16 07:07:49	2019-11-16	9	[{"id_menu":6,"count":1}]	5375	delivery	5	14
14296	2019-11-16 07:24:21	2019-11-16	9	[{"id_menu":6,"count":1}]	2373	pick-up	0	9
14297	2019-11-16 07:29:06	2019-11-16	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5408	delivery	5	36
14298	2019-11-16 07:37:59	2019-11-16	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2853	delivery	5	36
14299	2019-11-16 07:39:29	2019-11-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2546	pick-up	0	23
14300	2019-11-16 07:46:02	2019-11-16	12	[{"id_menu":1,"count":1}]	1765	pick-up	0	12
14301	2019-11-16 08:18:49	2019-11-16	8	[{"id_menu":5,"count":1}]	359	pick-up	0	8
14302	2019-11-16 08:20:11	2019-11-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	5394	delivery	5	28
14303	2019-11-16 08:36:35	2019-11-16	12	[{"id_menu":3,"count":1}]	4635	delivery	5	17
14304	2019-11-16 08:43:49	2019-11-16	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4959	pick-up	0	22
14305	2019-11-16 08:45:19	2019-11-16	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1568	pick-up	0	26
14306	2019-11-16 08:51:45	2019-11-16	17	[{"id_menu":4,"count":1}]	4568	pick-up	0	17
14307	2019-11-16 09:05:41	2019-11-16	14	[{"id_menu":2,"count":1}]	2498	delivery	5	19
14308	2019-11-16 09:24:57	2019-11-16	9	[{"id_menu":6,"count":1}]	1072	pick-up	0	9
14309	2019-11-16 09:28:26	2019-11-16	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	1321	pick-up	0	21
14310	2019-11-16 09:32:29	2019-11-16	12	[{"id_menu":1,"count":1}]	5386	delivery	5	17
14311	2019-11-16 09:48:31	2019-11-16	14	[{"id_menu":2,"count":1}]	5091	delivery	5	19
14312	2019-11-16 09:59:01	2019-11-16	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3491	pick-up	0	26
14313	2019-11-16 09:59:20	2019-11-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":3}]	5371	delivery	5	28
14314	2019-11-16 10:00:33	2019-11-16	12	[{"id_menu":3,"count":1}]	2627	pick-up	0	12
14315	2019-11-16 10:16:12	2019-11-16	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3869	delivery	5	43
14316	2019-11-16 10:21:03	2019-11-16	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2082	delivery	5	31
14317	2019-11-16 10:22:03	2019-11-16	12	[{"id_menu":3,"count":1}]	573	pick-up	0	12
14318	2019-11-16 10:31:37	2019-11-16	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	601	pick-up	0	24
14319	2019-11-16 10:40:59	2019-11-16	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4786	delivery	5	43
14320	2019-11-16 10:50:11	2019-11-16	12	[{"id_menu":1,"count":1}]	745	pick-up	0	12
14321	2019-11-16 10:51:27	2019-11-16	9	[{"id_menu":7,"count":1}]	3896	delivery	5	14
14322	2019-11-16 10:54:13	2019-11-16	9	[{"id_menu":7,"count":1}]	352	pick-up	0	9
14323	2019-11-16 11:54:19	2019-11-16	12	[{"id_menu":1,"count":1}]	1085	pick-up	0	12
14324	2019-11-16 12:01:12	2019-11-16	14	[{"id_menu":2,"count":2}]	2870	delivery	5	19
14325	2019-11-16 12:12:39	2019-11-16	9	[{"id_menu":6,"count":1}]	4354	delivery	5	14
14326	2019-11-16 12:15:28	2019-11-16	9	[{"id_menu":7,"count":1}]	5406	delivery	5	14
14327	2019-11-16 12:16:38	2019-11-16	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5373	pick-up	0	52
14328	2019-11-16 12:25:58	2019-11-16	9	[{"id_menu":7,"count":1}]	874	pick-up	0	9
14329	2019-11-16 12:27:13	2019-11-16	8	[{"id_menu":5,"count":1}]	2173	pick-up	0	8
14330	2019-11-16 12:28:35	2019-11-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	285	pick-up	0	26
14331	2019-11-16 12:30:46	2019-11-16	17	[{"id_menu":4,"count":2}]	1288	pick-up	0	17
14332	2019-11-16 12:33:31	2019-11-16	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	5360	delivery	5	38
14333	2019-11-16 12:46:04	2019-11-16	14	[{"id_menu":2,"count":1}]	2333	pick-up	0	14
14334	2019-11-16 12:47:17	2019-11-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	5368	delivery	5	26
14335	2019-11-16 13:06:47	2019-11-16	9	[{"id_menu":6,"count":1}]	2050	pick-up	0	9
14336	2019-11-16 13:07:32	2019-11-16	12	[{"id_menu":3,"count":1}]	4436	delivery	5	17
14337	2019-11-16 13:10:54	2019-11-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4356	pick-up	0	18
14338	2019-11-16 13:19:11	2019-11-16	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1435	pick-up	0	29
14339	2019-11-16 13:24:40	2019-11-16	8	[{"id_menu":5,"count":1}]	477	delivery	5	13
14340	2019-11-16 13:30:00	2019-11-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4060	delivery	5	22
14341	2019-11-16 13:34:39	2019-11-16	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	5358	delivery	5	40
14342	2019-11-16 13:44:43	2019-11-16	14	[{"id_menu":2,"count":1}]	1400	delivery	5	19
14343	2019-11-16 13:55:26	2019-11-16	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	5402	pick-up	0	35
14344	2019-11-16 13:59:37	2019-11-16	14	[{"id_menu":2,"count":1}]	3146	pick-up	0	14
14345	2019-11-16 14:00:11	2019-11-16	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2605	delivery	5	26
14346	2019-11-16 14:05:07	2019-11-16	12	[{"id_menu":1,"count":1}]	754	delivery	5	17
14347	2019-11-16 14:06:30	2019-11-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5359	delivery	5	22
14348	2019-11-16 14:06:39	2019-11-16	14	[{"id_menu":2,"count":1}]	2352	delivery	5	19
14349	2019-11-16 14:08:34	2019-11-16	17	[{"id_menu":4,"count":1}]	4132	pick-up	0	17
14350	2019-11-16 14:22:57	2019-11-16	17	[{"id_menu":4,"count":1}]	2184	pick-up	0	17
14351	2019-11-16 14:29:53	2019-11-16	8	[{"id_menu":5,"count":1}]	3211	delivery	5	13
14352	2019-11-16 14:30:46	2019-11-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	460	delivery	5	23
14353	2019-11-16 14:32:16	2019-11-16	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1015	delivery	5	34
14354	2019-11-16 14:43:48	2019-11-16	8	[{"id_menu":5,"count":1}]	3404	delivery	5	13
14355	2019-11-16 14:45:24	2019-11-16	12	[{"id_menu":1,"count":1}]	5401	delivery	5	17
14356	2019-11-16 15:00:11	2019-11-16	9	[{"id_menu":7,"count":2}]	5382	delivery	5	14
14357	2019-11-16 15:04:04	2019-11-16	9	[{"id_menu":6,"count":1}]	5378	pick-up	0	9
14358	2019-11-16 15:05:08	2019-11-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3688	delivery	5	22
14359	2019-11-16 15:27:16	2019-11-16	14	[{"id_menu":2,"count":1}]	3614	pick-up	0	14
14360	2019-11-16 15:28:02	2019-11-16	12	[{"id_menu":1,"count":1}]	5370	delivery	5	17
14361	2019-11-16 15:33:32	2019-11-16	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5395	delivery	5	44
14362	2019-11-16 15:36:51	2019-11-16	17	[{"id_menu":4,"count":1}]	207	pick-up	0	17
14363	2019-11-16 15:41:58	2019-11-16	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4396	delivery	5	40
14364	2019-11-16 15:45:52	2019-11-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1119	pick-up	0	23
14365	2019-11-16 15:46:10	2019-11-16	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4622	delivery	5	40
14366	2019-11-16 15:53:55	2019-11-16	14	[{"id_menu":2,"count":1}]	625	pick-up	0	14
14367	2019-11-16 16:00:40	2019-11-16	12	[{"id_menu":1,"count":1}]	3260	pick-up	0	12
14368	2019-11-16 16:06:14	2019-11-16	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	5361	pick-up	0	26
14369	2019-11-16 16:09:27	2019-11-16	17	[{"id_menu":4,"count":1}]	820	pick-up	0	17
14370	2019-11-16 16:20:54	2019-11-16	12	[{"id_menu":3,"count":1}]	2619	delivery	5	17
14371	2019-11-16 16:22:48	2019-11-16	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	5412	delivery	5	26
14372	2019-11-16 16:23:00	2019-11-16	9	[{"id_menu":7,"count":1}]	5372	delivery	5	14
14373	2019-11-16 16:24:48	2019-11-16	17	[{"id_menu":4,"count":1}]	868	delivery	5	22
14374	2019-11-16 16:27:01	2019-11-16	14	[{"id_menu":2,"count":1}]	3822	pick-up	0	14
14375	2019-11-16 16:27:22	2019-11-16	9	[{"id_menu":7,"count":1}]	2644	delivery	5	14
14376	2019-11-16 17:16:27	2019-11-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	2676	pick-up	0	17
14377	2019-11-16 17:38:51	2019-11-16	12	[{"id_menu":1,"count":1}]	5106	delivery	5	17
14378	2019-11-16 17:41:31	2019-11-16	9	[{"id_menu":6,"count":1}]	5405	delivery	5	14
14379	2019-11-16 17:41:41	2019-11-16	14	[{"id_menu":2,"count":1}]	4289	delivery	5	19
14380	2019-11-16 17:50:06	2019-11-16	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	2790	delivery	5	23
14381	2019-11-16 17:52:08	2019-11-16	9	[{"id_menu":7,"count":1}]	5398	delivery	5	14
14382	2019-11-16 18:03:45	2019-11-16	14	[{"id_menu":2,"count":1}]	1161	pick-up	0	14
14383	2019-11-16 18:04:24	2019-11-16	17	[{"id_menu":4,"count":1}]	5404	delivery	5	22
14384	2019-11-16 18:06:03	2019-11-16	14	[{"id_menu":2,"count":1}]	5399	delivery	5	19
14385	2019-11-16 18:08:33	2019-11-16	17	[{"id_menu":4,"count":2}]	2252	delivery	5	22
14386	2019-11-16 18:08:58	2019-11-16	8	[{"id_menu":5,"count":1}]	4793	delivery	5	13
14387	2019-11-16 18:09:12	2019-11-16	9	[{"id_menu":6,"count":1}]	5407	delivery	5	14
14388	2019-11-16 18:09:53	2019-11-16	17	[{"id_menu":4,"count":1}]	1504	delivery	5	22
14389	2019-11-16 18:10:13	2019-11-16	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3542	delivery	5	39
14390	2019-11-16 18:11:13	2019-11-16	12	[{"id_menu":1,"count":1}]	3312	delivery	5	17
14391	2019-11-16 18:12:55	2019-11-16	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4896	delivery	5	26
14392	2019-11-16 18:33:41	2019-11-16	14	[{"id_menu":2,"count":1}]	5363	delivery	5	19
14393	2019-11-16 18:39:26	2019-11-16	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5362	delivery	5	40
14394	2019-11-16 18:46:27	2019-11-16	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	3398	delivery	5	23
14395	2019-11-16 18:49:54	2019-11-16	9	[{"id_menu":6,"count":1}]	245	delivery	5	14
14396	2019-11-16 18:50:20	2019-11-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":3}]	2602	delivery	5	22
14397	2019-11-16 18:55:46	2019-11-16	14	[{"id_menu":2,"count":1}]	5397	delivery	5	19
14398	2019-11-16 18:59:54	2019-11-16	9	[{"id_menu":7,"count":1}]	5377	delivery	5	14
14399	2019-11-16 19:10:48	2019-11-16	12	[{"id_menu":3,"count":1}]	5384	pick-up	0	12
14400	2019-11-16 19:16:51	2019-11-16	12	[{"id_menu":1,"count":1}]	655	pick-up	0	12
14401	2019-11-16 19:31:56	2019-11-16	9	[{"id_menu":6,"count":1}]	3385	pick-up	0	9
14402	2019-11-16 19:40:49	2019-11-16	9	[{"id_menu":6,"count":1}]	5365	delivery	5	14
14403	2019-11-16 19:52:12	2019-11-16	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4889	pick-up	0	25
14404	2019-11-16 20:00:09	2019-11-16	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	5356	delivery	5	31
14405	2019-11-16 20:04:23	2019-11-16	9	[{"id_menu":7,"count":1}]	5396	delivery	5	14
14406	2019-11-16 20:06:21	2019-11-16	12	[{"id_menu":1,"count":1}]	2440	delivery	5	17
14407	2019-11-16 20:19:10	2019-11-16	9	[{"id_menu":7,"count":1}]	4669	delivery	5	14
14408	2019-11-16 20:29:23	2019-11-16	14	[{"id_menu":2,"count":1}]	456	delivery	5	19
14409	2019-11-16 20:39:34	2019-11-16	9	[{"id_menu":6,"count":1}]	5357	delivery	5	14
14410	2019-11-16 20:45:03	2019-11-16	12	[{"id_menu":1,"count":1}]	5392	delivery	5	17
14411	2019-11-16 20:57:01	2019-11-16	17	[{"id_menu":4,"count":1}]	4430	pick-up	0	17
14412	2019-11-16 21:04:16	2019-11-16	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1996	pick-up	0	20
14413	2019-11-16 21:05:18	2019-11-16	12	[{"id_menu":1,"count":1}]	5410	pick-up	0	12
14414	2019-11-16 21:10:29	2019-11-16	8	[{"id_menu":5,"count":1}]	3241	pick-up	0	8
14415	2019-11-16 21:13:27	2019-11-16	12	[{"id_menu":1,"count":1}]	3752	delivery	5	17
14416	2019-11-16 21:38:14	2019-11-16	9	[{"id_menu":6,"count":1}]	5367	pick-up	0	9
14417	2019-11-16 22:17:48	2019-11-16	9	[{"id_menu":7,"count":1}]	3478	pick-up	0	9
14418	2019-11-16 22:22:27	2019-11-16	9	[{"id_menu":7,"count":1}]	1547	delivery	5	14
14419	2019-11-16 22:43:02	2019-11-16	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1702	delivery	5	31
14420	2019-11-16 23:03:47	2019-11-16	8	[{"id_menu":5,"count":1}]	5393	delivery	5	13
14421	2019-11-16 23:13:15	2019-11-16	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5403	delivery	5	52
14422	2019-11-16 23:14:50	2019-11-16	12	[{"id_menu":3,"count":1}]	5366	delivery	5	17
14423	2019-11-16 23:16:05	2019-11-16	9	[{"id_menu":7,"count":1}]	5004	delivery	5	14
14424	2019-11-16 23:24:29	2019-11-16	12	[{"id_menu":3,"count":1}]	922	pick-up	0	12
14425	2019-11-16 23:25:47	2019-11-16	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	153	pick-up	0	40
14426	2019-11-16 23:36:31	2019-11-16	14	[{"id_menu":2,"count":1}]	3363	delivery	5	19
14427	2019-11-16 23:45:55	2019-11-16	9	[{"id_menu":7,"count":1}]	592	pick-up	0	9
14428	2019-11-16 23:56:24	2019-11-16	9	[{"id_menu":7,"count":1}]	3419	pick-up	0	9
14429	2019-11-16 23:57:06	2019-11-16	8	[{"id_menu":5,"count":1}]	1727	pick-up	0	8
14430	2019-11-17 00:06:18	2019-11-17	17	[{"id_menu":4,"count":2}]	3493	delivery	5	22
14431	2019-11-17 00:08:25	2019-11-17	14	[{"id_menu":2,"count":1}]	1306	delivery	5	19
14432	2019-11-17 00:13:37	2019-11-17	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	5423	delivery	5	34
14433	2019-11-17 00:14:08	2019-11-17	14	[{"id_menu":2,"count":1}]	3788	pick-up	0	14
14434	2019-11-17 00:18:17	2019-11-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4455	delivery	5	23
14435	2019-11-17 00:25:48	2019-11-17	14	[{"id_menu":2,"count":1}]	5310	pick-up	0	14
14436	2019-11-17 00:42:28	2019-11-17	9	[{"id_menu":6,"count":1}]	5425	delivery	5	14
14437	2019-11-17 00:42:40	2019-11-17	12	[{"id_menu":3,"count":1}]	4090	pick-up	0	12
14438	2019-11-17 00:58:55	2019-11-17	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5453	delivery	5	54
14439	2019-11-17 01:04:53	2019-11-17	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	5456	delivery	5	22
14440	2019-11-17 01:05:00	2019-11-17	17	[{"id_menu":4,"count":1}]	5434	delivery	5	22
14441	2019-11-17 01:13:10	2019-11-17	17	[{"id_menu":4,"count":1}]	3877	delivery	5	22
14442	2019-11-17 01:14:02	2019-11-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1531	delivery	5	31
14443	2019-11-17 01:35:00	2019-11-17	9	[{"id_menu":6,"count":1}]	3345	delivery	5	14
14444	2019-11-17 01:37:39	2019-11-17	17	[{"id_menu":4,"count":1}]	1021	pick-up	0	17
14445	2019-11-17 01:43:05	2019-11-17	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	4076	delivery	5	28
14446	2019-11-17 01:44:29	2019-11-17	12	[{"id_menu":1,"count":1}]	5430	pick-up	0	12
14447	2019-11-17 01:52:54	2019-11-17	12	[{"id_menu":3,"count":1}]	5447	pick-up	0	12
14448	2019-11-17 01:59:37	2019-11-17	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2410	pick-up	0	43
14449	2019-11-17 02:03:10	2019-11-17	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1184	pick-up	0	35
14450	2019-11-17 02:10:19	2019-11-17	12	[{"id_menu":1,"count":1}]	2131	delivery	5	17
14451	2019-11-17 02:12:11	2019-11-17	9	[{"id_menu":7,"count":1}]	1979	pick-up	0	9
14452	2019-11-17 02:14:16	2019-11-17	12	[{"id_menu":3,"count":1}]	2776	pick-up	0	12
14453	2019-11-17 02:14:44	2019-11-17	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	634	pick-up	0	26
14454	2019-11-17 02:18:20	2019-11-17	8	[{"id_menu":5,"count":1}]	4540	pick-up	0	8
14455	2019-11-17 02:28:21	2019-11-17	12	[{"id_menu":3,"count":1}]	273	pick-up	0	12
14456	2019-11-17 02:32:24	2019-11-17	12	[{"id_menu":3,"count":1}]	2232	pick-up	0	12
14457	2019-11-17 02:37:33	2019-11-17	9	[{"id_menu":7,"count":1}]	5428	delivery	5	14
14458	2019-11-17 02:40:52	2019-11-17	17	[{"id_menu":4,"count":1}]	5418	delivery	5	22
14459	2019-11-17 02:47:46	2019-11-17	9	[{"id_menu":7,"count":1}]	1416	delivery	5	14
14460	2019-11-17 02:47:59	2019-11-17	9	[{"id_menu":7,"count":1}]	5437	delivery	5	14
14461	2019-11-17 02:52:09	2019-11-17	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1547	pick-up	0	32
14462	2019-11-17 03:04:42	2019-11-17	17	[{"id_menu":4,"count":1}]	5462	delivery	5	22
14463	2019-11-17 03:31:12	2019-11-17	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	5424	delivery	5	40
14464	2019-11-17 03:38:36	2019-11-17	9	[{"id_menu":6,"count":1}]	4414	pick-up	0	9
14465	2019-11-17 03:40:23	2019-11-17	17	[{"id_menu":4,"count":1}]	3246	delivery	5	22
14466	2019-11-17 03:46:39	2019-11-17	17	[{"id_menu":4,"count":1}]	5426	pick-up	0	17
14467	2019-11-17 03:55:34	2019-11-17	9	[{"id_menu":7,"count":1}]	5449	pick-up	0	9
14468	2019-11-17 03:59:07	2019-11-17	8	[{"id_menu":5,"count":1}]	2413	pick-up	0	8
14469	2019-11-17 04:25:13	2019-11-17	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2064	delivery	5	27
14470	2019-11-17 04:29:41	2019-11-17	17	[{"id_menu":4,"count":1}]	5444	pick-up	0	17
14471	2019-11-17 04:34:45	2019-11-17	8	[{"id_menu":5,"count":1}]	5414	delivery	5	13
14472	2019-11-17 04:36:45	2019-11-17	17	[{"id_menu":4,"count":1}]	5439	pick-up	0	17
14473	2019-11-17 04:40:04	2019-11-17	17	[{"id_menu":4,"count":1}]	977	delivery	5	22
14474	2019-11-17 04:43:06	2019-11-17	17	[{"id_menu":4,"count":1}]	820	delivery	5	22
14475	2019-11-17 05:03:50	2019-11-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2916	pick-up	0	18
14476	2019-11-17 05:28:02	2019-11-17	14	[{"id_menu":2,"count":1}]	547	pick-up	0	14
14477	2019-11-17 05:51:47	2019-11-17	8	[{"id_menu":5,"count":1}]	68	pick-up	0	8
14478	2019-11-17 06:05:51	2019-11-17	12	[{"id_menu":1,"count":1}]	2434	pick-up	0	12
14479	2019-11-17 06:16:17	2019-11-17	12	[{"id_menu":1,"count":1}]	1506	delivery	5	17
14480	2019-11-17 06:16:23	2019-11-17	12	[{"id_menu":1,"count":1}]	1427	pick-up	0	12
14481	2019-11-17 06:21:53	2019-11-17	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2234	delivery	5	43
14482	2019-11-17 06:22:43	2019-11-17	12	[{"id_menu":1,"count":1}]	1568	pick-up	0	12
14483	2019-11-17 06:29:08	2019-11-17	9	[{"id_menu":7,"count":1}]	4206	delivery	5	14
14484	2019-11-17 06:32:14	2019-11-17	9	[{"id_menu":6,"count":1}]	5431	delivery	5	14
14485	2019-11-17 06:41:07	2019-11-17	9	[{"id_menu":7,"count":1}]	5454	delivery	5	14
14486	2019-11-17 06:47:06	2019-11-17	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5464	delivery	5	45
14487	2019-11-17 06:53:41	2019-11-17	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1860	pick-up	0	26
14488	2019-11-17 06:58:07	2019-11-17	8	[{"id_menu":5,"count":1}]	1334	pick-up	0	8
14489	2019-11-17 06:59:18	2019-11-17	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	5441	delivery	5	26
14490	2019-11-17 07:14:41	2019-11-17	12	[{"id_menu":1,"count":1}]	3590	pick-up	0	12
14491	2019-11-17 07:15:03	2019-11-17	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	5338	pick-up	0	26
14492	2019-11-17 07:29:49	2019-11-17	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1415	pick-up	0	26
14493	2019-11-17 07:29:49	2019-11-17	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3705	delivery	5	57
14494	2019-11-17 07:32:14	2019-11-17	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	4223	pick-up	0	29
14495	2019-11-17 07:41:48	2019-11-17	9	[{"id_menu":7,"count":1}]	3155	delivery	5	14
14496	2019-11-17 07:56:33	2019-11-17	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4683	delivery	5	55
14497	2019-11-17 07:57:50	2019-11-17	12	[{"id_menu":3,"count":2}]	799	pick-up	0	12
14498	2019-11-17 08:02:41	2019-11-17	17	[{"id_menu":4,"count":1}]	5062	delivery	5	22
14499	2019-11-17 08:08:52	2019-11-17	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5443	delivery	5	57
14500	2019-11-17 08:09:07	2019-11-17	17	[{"id_menu":4,"count":1}]	1438	pick-up	0	17
14501	2019-11-17 08:20:56	2019-11-17	9	[{"id_menu":7,"count":1}]	27	delivery	5	14
14502	2019-11-17 08:22:47	2019-11-17	14	[{"id_menu":2,"count":1}]	3812	pick-up	0	14
14503	2019-11-17 08:28:59	2019-11-17	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3025	delivery	5	40
14504	2019-11-17 08:30:35	2019-11-17	8	[{"id_menu":5,"count":1}]	5433	delivery	5	13
14505	2019-11-17 08:46:23	2019-11-17	8	[{"id_menu":5,"count":1}]	4682	pick-up	0	8
14506	2019-11-17 08:46:23	2019-11-17	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	5435	delivery	5	26
14507	2019-11-17 08:54:51	2019-11-17	17	[{"id_menu":4,"count":1}]	3332	delivery	5	22
14508	2019-11-17 09:00:50	2019-11-17	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5463	delivery	5	43
14509	2019-11-17 09:10:08	2019-11-17	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3558	delivery	5	34
14510	2019-11-17 09:20:05	2019-11-17	9	[{"id_menu":6,"count":1}]	5450	delivery	5	14
14511	2019-11-17 09:22:16	2019-11-17	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	431	pick-up	0	40
14512	2019-11-17 09:30:18	2019-11-17	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5445	delivery	5	54
14513	2019-11-17 09:32:06	2019-11-17	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5429	pick-up	0	26
14514	2019-11-17 09:37:43	2019-11-17	9	[{"id_menu":7,"count":1}]	3467	delivery	5	14
14515	2019-11-17 09:40:21	2019-11-17	12	[{"id_menu":1,"count":1}]	786	pick-up	0	12
14516	2019-11-17 09:44:32	2019-11-17	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5459	delivery	5	37
14517	2019-11-17 09:46:09	2019-11-17	17	[{"id_menu":4,"count":1}]	2498	pick-up	0	17
14518	2019-11-17 09:49:04	2019-11-17	12	[{"id_menu":3,"count":1}]	3875	pick-up	0	12
14519	2019-11-17 09:49:17	2019-11-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5446	delivery	5	31
14520	2019-11-17 09:49:26	2019-11-17	9	[{"id_menu":6,"count":1}]	5427	pick-up	0	9
14521	2019-11-17 10:01:41	2019-11-17	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5448	delivery	5	35
14522	2019-11-17 10:06:10	2019-11-17	14	[{"id_menu":2,"count":1}]	519	delivery	5	19
14523	2019-11-17 10:20:52	2019-11-17	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2659	pick-up	0	26
14524	2019-11-17 10:31:11	2019-11-17	14	[{"id_menu":2,"count":1}]	583	delivery	5	19
14525	2019-11-17 10:46:35	2019-11-17	9	[{"id_menu":6,"count":1}]	3035	delivery	5	14
14526	2019-11-17 10:46:41	2019-11-17	17	[{"id_menu":4,"count":1}]	5417	delivery	5	22
14527	2019-11-17 11:12:50	2019-11-17	8	[{"id_menu":5,"count":1}]	4798	pick-up	0	8
14528	2019-11-17 11:17:36	2019-11-17	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	201	pick-up	0	31
14529	2019-11-17 11:19:03	2019-11-17	12	[{"id_menu":3,"count":1}]	1457	delivery	5	17
14530	2019-11-17 11:33:11	2019-11-17	9	[{"id_menu":6,"count":1}]	2110	pick-up	0	9
14531	2019-11-17 11:45:42	2019-11-17	12	[{"id_menu":3,"count":1}]	5276	delivery	5	17
14532	2019-11-17 11:46:18	2019-11-17	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	5406	pick-up	0	21
14533	2019-11-17 11:49:01	2019-11-17	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	813	pick-up	0	21
14534	2019-11-17 11:53:42	2019-11-17	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4478	delivery	5	49
14535	2019-11-17 12:03:34	2019-11-17	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	4161	pick-up	0	20
14536	2019-11-17 12:08:57	2019-11-17	8	[{"id_menu":5,"count":1}]	1375	delivery	5	13
14537	2019-11-17 12:40:47	2019-11-17	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2189	pick-up	0	29
14538	2019-11-17 12:47:38	2019-11-17	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3651	delivery	5	22
14539	2019-11-17 12:49:53	2019-11-17	12	[{"id_menu":3,"count":1}]	4788	delivery	5	17
14540	2019-11-17 13:02:44	2019-11-17	9	[{"id_menu":6,"count":1}]	5455	delivery	5	14
14541	2019-11-17 13:09:36	2019-11-17	9	[{"id_menu":6,"count":1}]	5442	delivery	5	14
14542	2019-11-17 13:20:54	2019-11-17	17	[{"id_menu":4,"count":1}]	386	pick-up	0	17
14543	2019-11-17 13:53:50	2019-11-17	8	[{"id_menu":5,"count":1}]	4020	delivery	5	13
14544	2019-11-17 13:55:01	2019-11-17	14	[{"id_menu":2,"count":1}]	5440	pick-up	0	14
14545	2019-11-17 14:05:53	2019-11-17	9	[{"id_menu":6,"count":1}]	437	delivery	5	14
14546	2019-11-17 14:06:03	2019-11-17	14	[{"id_menu":2,"count":1}]	5460	pick-up	0	14
14547	2019-11-17 14:25:28	2019-11-17	14	[{"id_menu":2,"count":1}]	1236	pick-up	0	14
14548	2019-11-17 14:37:46	2019-11-17	9	[{"id_menu":7,"count":1}]	5422	delivery	5	14
14549	2019-11-17 14:40:00	2019-11-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5438	pick-up	0	18
14550	2019-11-17 14:59:16	2019-11-17	12	[{"id_menu":3,"count":1}]	5452	pick-up	0	12
14551	2019-11-17 15:07:34	2019-11-17	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4628	pick-up	0	17
14552	2019-11-17 15:10:00	2019-11-17	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1011	delivery	5	39
14553	2019-11-17 15:20:32	2019-11-17	9	[{"id_menu":6,"count":2}]	5457	pick-up	0	9
14554	2019-11-17 15:24:24	2019-11-17	14	[{"id_menu":2,"count":1}]	1119	delivery	5	19
14555	2019-11-17 15:26:20	2019-11-17	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	5019	pick-up	0	22
14556	2019-11-17 15:28:20	2019-11-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1258	delivery	5	28
14557	2019-11-17 15:38:42	2019-11-17	14	[{"id_menu":2,"count":1}]	4552	pick-up	0	14
14558	2019-11-17 16:00:24	2019-11-17	9	[{"id_menu":7,"count":1}]	548	pick-up	0	9
14559	2019-11-17 16:07:38	2019-11-17	8	[{"id_menu":5,"count":1}]	1076	pick-up	0	8
14560	2019-11-17 16:16:48	2019-11-17	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	26	pick-up	0	29
14561	2019-11-17 16:29:35	2019-11-17	9	[{"id_menu":7,"count":1}]	3851	pick-up	0	9
14562	2019-11-17 17:05:51	2019-11-17	12	[{"id_menu":1,"count":1}]	623	delivery	5	17
14563	2019-11-17 17:13:35	2019-11-17	9	[{"id_menu":6,"count":1}]	826	pick-up	0	9
14564	2019-11-17 17:19:08	2019-11-17	12	[{"id_menu":1,"count":1}]	1929	delivery	5	17
14565	2019-11-17 17:29:38	2019-11-17	12	[{"id_menu":1,"count":1}]	378	pick-up	0	12
14566	2019-11-17 17:46:55	2019-11-17	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	2442	delivery	5	29
14567	2019-11-17 18:10:15	2019-11-17	12	[{"id_menu":1,"count":2}]	1559	pick-up	0	12
14568	2019-11-17 18:16:16	2019-11-17	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2951	delivery	5	43
14569	2019-11-17 18:18:51	2019-11-17	8	[{"id_menu":5,"count":1}]	748	delivery	5	13
14570	2019-11-17 18:40:07	2019-11-17	12	[{"id_menu":3,"count":1}]	1261	delivery	5	17
14571	2019-11-17 18:41:53	2019-11-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	385	delivery	5	31
14572	2019-11-17 18:51:28	2019-11-17	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	5077	delivery	5	28
14573	2019-11-17 18:55:04	2019-11-17	12	[{"id_menu":1,"count":1}]	2197	pick-up	0	12
14574	2019-11-17 19:16:22	2019-11-17	9	[{"id_menu":6,"count":1}]	2859	pick-up	0	9
14575	2019-11-17 19:17:37	2019-11-17	12	[{"id_menu":1,"count":1}]	715	delivery	5	17
14576	2019-11-17 19:18:22	2019-11-17	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	4544	pick-up	0	29
14577	2019-11-17 19:24:58	2019-11-17	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	5451	delivery	5	34
14578	2019-11-17 19:26:56	2019-11-17	17	[{"id_menu":4,"count":1}]	3871	pick-up	0	17
14579	2019-11-17 19:49:52	2019-11-17	14	[{"id_menu":2,"count":1}]	4077	delivery	5	19
14580	2019-11-17 19:50:59	2019-11-17	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	5419	pick-up	0	22
14581	2019-11-17 19:54:52	2019-11-17	14	[{"id_menu":2,"count":1}]	2983	pick-up	0	14
14582	2019-11-17 20:01:08	2019-11-17	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":2}]	3783	delivery	5	22
14583	2019-11-17 20:12:26	2019-11-17	17	[{"id_menu":4,"count":2}]	4988	pick-up	0	17
14584	2019-11-17 20:15:19	2019-11-17	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	5416	pick-up	0	20
14585	2019-11-17 20:21:43	2019-11-17	12	[{"id_menu":1,"count":1}]	2311	pick-up	0	12
14586	2019-11-17 20:27:08	2019-11-17	8	[{"id_menu":5,"count":1}]	4716	delivery	5	13
14587	2019-11-17 20:38:43	2019-11-17	9	[{"id_menu":7,"count":2}]	1555	pick-up	0	9
14588	2019-11-17 20:42:11	2019-11-17	9	[{"id_menu":7,"count":1}]	3835	delivery	5	14
14589	2019-11-17 20:43:45	2019-11-17	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	4376	delivery	5	35
14590	2019-11-17 20:48:49	2019-11-17	9	[{"id_menu":6,"count":1}]	3380	pick-up	0	9
14591	2019-11-17 20:53:17	2019-11-17	9	[{"id_menu":6,"count":1}]	5026	pick-up	0	9
14592	2019-11-17 20:54:24	2019-11-17	12	[{"id_menu":1,"count":1}]	5432	delivery	5	17
14593	2019-11-17 20:55:29	2019-11-17	9	[{"id_menu":7,"count":1}]	4639	delivery	5	14
14594	2019-11-17 21:20:30	2019-11-17	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5413	delivery	5	22
14595	2019-11-17 21:22:32	2019-11-17	9	[{"id_menu":7,"count":1}]	5461	delivery	5	14
14596	2019-11-17 21:25:47	2019-11-17	17	[{"id_menu":4,"count":1}]	719	delivery	5	22
14597	2019-11-17 21:32:02	2019-11-17	9	[{"id_menu":7,"count":1}]	5458	pick-up	0	9
14598	2019-11-17 21:38:55	2019-11-17	9	[{"id_menu":6,"count":1}]	4428	pick-up	0	9
14599	2019-11-17 21:51:58	2019-11-17	8	[{"id_menu":5,"count":1}]	5436	delivery	5	13
14600	2019-11-17 21:56:04	2019-11-17	12	[{"id_menu":1,"count":1}]	2089	pick-up	0	12
14601	2019-11-17 21:56:59	2019-11-17	8	[{"id_menu":5,"count":1}]	2932	pick-up	0	8
14602	2019-11-17 22:08:02	2019-11-17	14	[{"id_menu":2,"count":1}]	824	pick-up	0	14
14603	2019-11-17 22:27:52	2019-11-17	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4655	delivery	5	43
14604	2019-11-17 22:34:10	2019-11-17	9	[{"id_menu":6,"count":1}]	3249	delivery	5	14
14605	2019-11-17 22:37:10	2019-11-17	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	5465	delivery	5	26
14606	2019-11-17 22:42:16	2019-11-17	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	501	delivery	5	34
14607	2019-11-17 22:51:12	2019-11-17	12	[{"id_menu":1,"count":1}]	2953	pick-up	0	12
14608	2019-11-17 23:08:54	2019-11-17	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	5421	pick-up	0	21
14609	2019-11-17 23:16:01	2019-11-17	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5415	delivery	5	34
14610	2019-11-17 23:20:10	2019-11-17	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	467	pick-up	0	29
14611	2019-11-17 23:21:52	2019-11-17	9	[{"id_menu":7,"count":1}]	581	delivery	5	14
14612	2019-11-17 23:28:52	2019-11-17	12	[{"id_menu":1,"count":1}]	1409	pick-up	0	12
14613	2019-11-17 23:33:32	2019-11-17	9	[{"id_menu":6,"count":1}]	4349	delivery	5	14
14614	2019-11-17 23:47:28	2019-11-17	9	[{"id_menu":6,"count":1}]	1079	delivery	5	14
14615	2019-11-17 23:53:37	2019-11-17	12	[{"id_menu":1,"count":1}]	73	delivery	5	17
14616	2019-11-17 23:54:06	2019-11-17	8	[{"id_menu":5,"count":1}]	2855	delivery	5	13
14617	2019-11-17 23:57:35	2019-11-17	9	[{"id_menu":6,"count":1}]	3627	pick-up	0	9
14618	2019-11-18 00:04:02	2019-11-18	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1383	pick-up	0	22
14619	2019-11-18 00:13:34	2019-11-18	14	[{"id_menu":2,"count":1}]	5501	pick-up	0	14
14620	2019-11-18 00:14:26	2019-11-18	9	[{"id_menu":7,"count":1}]	2526	pick-up	0	9
14621	2019-11-18 00:18:18	2019-11-18	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	424	pick-up	0	35
14622	2019-11-18 00:30:52	2019-11-18	8	[{"id_menu":5,"count":1}]	2443	pick-up	0	8
14623	2019-11-18 00:32:45	2019-11-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5468	delivery	5	22
14624	2019-11-18 00:39:46	2019-11-18	8	[{"id_menu":5,"count":1}]	2554	pick-up	0	8
14625	2019-11-18 00:41:25	2019-11-18	9	[{"id_menu":7,"count":1}]	3054	pick-up	0	9
14626	2019-11-18 00:44:38	2019-11-18	8	[{"id_menu":5,"count":1}]	5497	delivery	5	13
14627	2019-11-18 01:25:06	2019-11-18	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4194	delivery	5	51
14628	2019-11-18 01:31:50	2019-11-18	12	[{"id_menu":3,"count":1}]	567	delivery	5	17
14629	2019-11-18 02:33:29	2019-11-18	17	[{"id_menu":4,"count":1}]	815	pick-up	0	17
14630	2019-11-18 02:42:55	2019-11-18	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2420	pick-up	0	31
14631	2019-11-18 02:43:04	2019-11-18	14	[{"id_menu":2,"count":1}]	3324	pick-up	0	14
14632	2019-11-18 02:52:38	2019-11-18	17	[{"id_menu":4,"count":1}]	434	pick-up	0	17
14633	2019-11-18 02:52:55	2019-11-18	14	[{"id_menu":2,"count":1}]	2951	delivery	5	19
14634	2019-11-18 03:31:24	2019-11-18	8	[{"id_menu":5,"count":1}]	4330	pick-up	0	8
14635	2019-11-18 04:32:18	2019-11-18	12	[{"id_menu":3,"count":1}]	3858	pick-up	0	12
14636	2019-11-18 05:42:01	2019-11-18	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4099	delivery	5	27
14637	2019-11-18 05:44:30	2019-11-18	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4835	delivery	5	45
14638	2019-11-18 06:31:59	2019-11-18	8	[{"id_menu":5,"count":1}]	5484	delivery	5	13
14639	2019-11-18 06:39:39	2019-11-18	9	[{"id_menu":6,"count":1}]	476	pick-up	0	9
14640	2019-11-18 07:05:58	2019-11-18	12	[{"id_menu":1,"count":1}]	4436	delivery	5	17
14641	2019-11-18 07:09:13	2019-11-18	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	136	delivery	5	34
14642	2019-11-18 07:20:27	2019-11-18	9	[{"id_menu":6,"count":1}]	4215	delivery	5	14
14643	2019-11-18 08:05:07	2019-11-18	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	719	pick-up	0	29
14644	2019-11-18 09:29:21	2019-11-18	14	[{"id_menu":2,"count":1}]	1212	delivery	5	19
14645	2019-11-18 09:41:11	2019-11-18	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	964	delivery	5	36
14646	2019-11-18 10:29:28	2019-11-18	17	[{"id_menu":4,"count":1}]	5500	delivery	5	22
14647	2019-11-18 10:46:35	2019-11-18	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	4482	delivery	5	26
14648	2019-11-18 10:53:40	2019-11-18	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5052	pick-up	0	38
14649	2019-11-18 11:06:40	2019-11-18	14	[{"id_menu":2,"count":1}]	586	delivery	5	19
14650	2019-11-18 11:16:22	2019-11-18	12	[{"id_menu":1,"count":1}]	2956	delivery	5	17
14651	2019-11-18 11:21:29	2019-11-18	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1756	pick-up	0	33
14652	2019-11-18 11:49:22	2019-11-18	14	[{"id_menu":2,"count":1}]	5471	pick-up	0	14
14653	2019-11-18 11:55:51	2019-11-18	17	[{"id_menu":4,"count":1}]	5470	delivery	5	22
14654	2019-11-18 12:12:52	2019-11-18	14	[{"id_menu":2,"count":2}]	4710	delivery	5	19
14655	2019-11-18 12:28:50	2019-11-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	5485	delivery	5	23
14656	2019-11-18 12:29:25	2019-11-18	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	5494	delivery	5	27
14657	2019-11-18 12:52:11	2019-11-18	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	553	delivery	5	40
14658	2019-11-18 12:54:43	2019-11-18	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5479	delivery	5	34
14659	2019-11-18 13:14:04	2019-11-18	17	[{"id_menu":4,"count":1}]	1085	pick-up	0	17
14660	2019-11-18 14:17:30	2019-11-18	9	[{"id_menu":7,"count":1}]	5475	delivery	5	14
14661	2019-11-18 14:33:56	2019-11-18	14	[{"id_menu":2,"count":1}]	5489	delivery	5	19
14662	2019-11-18 14:41:25	2019-11-18	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	3224	delivery	5	25
14663	2019-11-18 15:05:27	2019-11-18	9	[{"id_menu":6,"count":2}]	5481	delivery	5	14
14664	2019-11-18 15:18:50	2019-11-18	9	[{"id_menu":6,"count":1}]	841	delivery	5	14
14665	2019-11-18 15:36:07	2019-11-18	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2413	pick-up	0	32
14666	2019-11-18 15:36:27	2019-11-18	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3151	pick-up	0	26
14667	2019-11-18 15:36:31	2019-11-18	9	[{"id_menu":6,"count":1}]	5502	delivery	5	14
14668	2019-11-18 16:15:26	2019-11-18	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	4779	delivery	5	34
14669	2019-11-18 16:19:15	2019-11-18	17	[{"id_menu":4,"count":1}]	4870	pick-up	0	17
14670	2019-11-18 16:33:20	2019-11-18	9	[{"id_menu":6,"count":1}]	4682	pick-up	0	9
14671	2019-11-18 16:38:15	2019-11-18	12	[{"id_menu":3,"count":1}]	851	delivery	5	17
14672	2019-11-18 16:56:38	2019-11-18	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2190	pick-up	0	29
14673	2019-11-18 16:59:26	2019-11-18	9	[{"id_menu":6,"count":1}]	5476	delivery	5	14
14674	2019-11-18 17:03:16	2019-11-18	17	[{"id_menu":4,"count":1}]	5491	pick-up	0	17
14675	2019-11-18 17:08:43	2019-11-18	12	[{"id_menu":1,"count":1}]	5474	pick-up	0	12
14676	2019-11-18 17:19:02	2019-11-18	8	[{"id_menu":5,"count":1}]	1893	delivery	5	13
14677	2019-11-18 17:22:59	2019-11-18	17	[{"id_menu":4,"count":1}]	3052	pick-up	0	17
14678	2019-11-18 17:30:58	2019-11-18	9	[{"id_menu":7,"count":1}]	351	delivery	5	14
14679	2019-11-18 18:08:16	2019-11-18	9	[{"id_menu":7,"count":1}]	5504	delivery	5	14
14680	2019-11-18 18:24:13	2019-11-18	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5490	delivery	5	39
14681	2019-11-18 18:48:26	2019-11-18	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	4643	pick-up	0	33
14682	2019-11-18 18:52:01	2019-11-18	12	[{"id_menu":1,"count":1}]	5493	delivery	5	17
14683	2019-11-18 18:59:15	2019-11-18	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1239	pick-up	0	24
14684	2019-11-18 19:14:23	2019-11-18	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5506	delivery	5	30
14685	2019-11-18 19:14:43	2019-11-18	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	270	pick-up	0	22
14686	2019-11-18 19:16:27	2019-11-18	8	[{"id_menu":5,"count":1}]	3146	pick-up	0	8
14687	2019-11-18 19:27:36	2019-11-18	9	[{"id_menu":6,"count":1}]	1621	pick-up	0	9
14688	2019-11-18 19:29:28	2019-11-18	9	[{"id_menu":6,"count":3}]	3640	delivery	5	14
14689	2019-11-18 19:53:09	2019-11-18	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":2}]	4001	delivery	5	26
14690	2019-11-18 20:14:17	2019-11-18	9	[{"id_menu":6,"count":1}]	80	delivery	5	14
14691	2019-11-18 21:58:39	2019-11-18	14	[{"id_menu":2,"count":1}]	1435	pick-up	0	14
14692	2019-11-18 22:32:13	2019-11-18	12	[{"id_menu":3,"count":1}]	5503	delivery	5	17
14693	2019-11-18 22:36:31	2019-11-18	14	[{"id_menu":2,"count":1}]	1722	delivery	5	19
14694	2019-11-18 22:39:45	2019-11-18	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	5483	delivery	5	31
14695	2019-11-18 23:06:24	2019-11-18	9	[{"id_menu":6,"count":1}]	1329	pick-up	0	9
14696	2019-11-18 23:28:12	2019-11-18	9	[{"id_menu":6,"count":1}]	5466	pick-up	0	9
14697	2019-11-18 23:56:34	2019-11-18	14	[{"id_menu":2,"count":1}]	512	pick-up	0	14
14698	2019-11-19 00:08:05	2019-11-19	9	[{"id_menu":7,"count":1}]	3271	pick-up	0	9
14699	2019-11-19 00:09:27	2019-11-19	8	[{"id_menu":5,"count":1}]	1727	pick-up	0	8
14700	2019-11-19 00:24:01	2019-11-19	9	[{"id_menu":6,"count":3}]	5509	delivery	5	14
14701	2019-11-19 00:31:47	2019-11-19	9	[{"id_menu":7,"count":1}]	5540	delivery	5	14
14702	2019-11-19 00:38:59	2019-11-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1143	pick-up	0	31
14703	2019-11-19 00:44:58	2019-11-19	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	3731	delivery	5	26
14704	2019-11-19 00:49:27	2019-11-19	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	5525	delivery	5	31
14705	2019-11-19 01:08:07	2019-11-19	17	[{"id_menu":4,"count":1}]	4445	pick-up	0	17
14706	2019-11-19 01:20:15	2019-11-19	14	[{"id_menu":2,"count":1}]	5526	delivery	5	19
14707	2019-11-19 01:22:28	2019-11-19	8	[{"id_menu":5,"count":1}]	5548	pick-up	0	8
14708	2019-11-19 01:48:56	2019-11-19	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2752	pick-up	0	29
14709	2019-11-19 01:51:41	2019-11-19	14	[{"id_menu":2,"count":1}]	5537	delivery	5	19
14710	2019-11-19 01:59:33	2019-11-19	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4860	delivery	5	39
14711	2019-11-19 02:05:24	2019-11-19	9	[{"id_menu":6,"count":1}]	2521	pick-up	0	9
14712	2019-11-19 02:08:08	2019-11-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	5519	pick-up	0	23
14713	2019-11-19 02:25:19	2019-11-19	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	5547	delivery	5	38
14714	2019-11-19 02:26:32	2019-11-19	12	[{"id_menu":3,"count":1}]	78	pick-up	0	12
14715	2019-11-19 03:09:53	2019-11-19	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5511	delivery	5	49
14716	2019-11-19 03:41:12	2019-11-19	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	5180	delivery	5	25
14717	2019-11-19 04:10:32	2019-11-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5541	delivery	5	28
14718	2019-11-19 04:24:33	2019-11-19	9	[{"id_menu":6,"count":1}]	5542	delivery	5	14
14719	2019-11-19 04:27:38	2019-11-19	9	[{"id_menu":6,"count":1}]	2007	pick-up	0	9
14720	2019-11-19 04:29:46	2019-11-19	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	5527	delivery	5	25
14721	2019-11-19 05:16:05	2019-11-19	9	[{"id_menu":6,"count":1}]	5545	delivery	5	14
14722	2019-11-19 05:19:07	2019-11-19	17	[{"id_menu":4,"count":1}]	5536	pick-up	0	17
14723	2019-11-19 05:39:10	2019-11-19	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	1659	pick-up	0	35
14724	2019-11-19 05:42:23	2019-11-19	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	5552	delivery	5	27
14725	2019-11-19 06:27:51	2019-11-19	17	[{"id_menu":4,"count":1}]	4804	pick-up	0	17
14726	2019-11-19 06:34:45	2019-11-19	14	[{"id_menu":2,"count":1}]	5553	pick-up	0	14
14727	2019-11-19 06:35:24	2019-11-19	9	[{"id_menu":6,"count":1}]	1828	pick-up	0	9
14728	2019-11-19 06:41:24	2019-11-19	12	[{"id_menu":3,"count":1}]	190	delivery	5	17
14729	2019-11-19 06:49:04	2019-11-19	12	[{"id_menu":3,"count":1}]	802	pick-up	0	12
14730	2019-11-19 06:49:22	2019-11-19	12	[{"id_menu":1,"count":2}]	143	delivery	5	17
14731	2019-11-19 06:55:48	2019-11-19	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5399	delivery	5	30
14732	2019-11-19 07:03:18	2019-11-19	12	[{"id_menu":3,"count":3}]	5528	pick-up	0	12
14733	2019-11-19 07:04:02	2019-11-19	9	[{"id_menu":7,"count":1}]	2561	pick-up	0	9
14734	2019-11-19 07:19:39	2019-11-19	8	[{"id_menu":5,"count":1}]	1337	pick-up	0	8
14735	2019-11-19 07:28:01	2019-11-19	12	[{"id_menu":1,"count":1}]	5463	delivery	5	17
14736	2019-11-19 08:16:58	2019-11-19	14	[{"id_menu":2,"count":1}]	3971	pick-up	0	14
14737	2019-11-19 08:42:38	2019-11-19	14	[{"id_menu":2,"count":1}]	3241	pick-up	0	14
14738	2019-11-19 08:44:19	2019-11-19	12	[{"id_menu":3,"count":1}]	1462	pick-up	0	12
14739	2019-11-19 08:59:28	2019-11-19	9	[{"id_menu":6,"count":1}]	5151	delivery	5	14
14740	2019-11-19 09:07:47	2019-11-19	12	[{"id_menu":3,"count":1}]	4682	pick-up	0	12
14741	2019-11-19 09:40:11	2019-11-19	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	1255	pick-up	0	26
14742	2019-11-19 09:44:23	2019-11-19	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	5533	delivery	5	26
14743	2019-11-19 09:54:27	2019-11-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4870	pick-up	0	23
14744	2019-11-19 10:16:24	2019-11-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3593	pick-up	0	17
14745	2019-11-19 10:40:35	2019-11-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1860	delivery	5	28
14746	2019-11-19 10:47:25	2019-11-19	9	[{"id_menu":6,"count":1}]	2887	delivery	5	14
14747	2019-11-19 11:12:59	2019-11-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	5556	delivery	5	28
14748	2019-11-19 11:58:23	2019-11-19	8	[{"id_menu":5,"count":1}]	4636	pick-up	0	8
14749	2019-11-19 12:12:40	2019-11-19	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	236	pick-up	0	26
14750	2019-11-19 12:25:06	2019-11-19	9	[{"id_menu":6,"count":1}]	2180	delivery	5	14
14751	2019-11-19 12:33:10	2019-11-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4112	pick-up	0	17
14752	2019-11-19 12:50:19	2019-11-19	9	[{"id_menu":6,"count":1}]	5544	delivery	5	14
14753	2019-11-19 13:11:22	2019-11-19	12	[{"id_menu":1,"count":1}]	543	delivery	5	17
14754	2019-11-19 14:10:30	2019-11-19	12	[{"id_menu":1,"count":1}]	2615	delivery	5	17
14755	2019-11-19 14:48:02	2019-11-19	14	[{"id_menu":2,"count":1}]	5549	delivery	5	19
14756	2019-11-19 14:56:01	2019-11-19	17	[{"id_menu":4,"count":1}]	1119	pick-up	0	17
14757	2019-11-19 15:07:41	2019-11-19	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	730	pick-up	0	21
14758	2019-11-19 15:24:40	2019-11-19	9	[{"id_menu":6,"count":1}]	4883	delivery	5	14
14759	2019-11-19 15:24:56	2019-11-19	14	[{"id_menu":2,"count":1}]	4360	delivery	5	19
14760	2019-11-19 15:31:13	2019-11-19	12	[{"id_menu":1,"count":1}]	2902	pick-up	0	12
14761	2019-11-19 16:31:12	2019-11-19	14	[{"id_menu":2,"count":1}]	5550	delivery	5	19
14762	2019-11-19 16:56:52	2019-11-19	9	[{"id_menu":6,"count":1}]	3439	pick-up	0	9
14763	2019-11-19 17:08:53	2019-11-19	9	[{"id_menu":6,"count":1}]	2081	delivery	5	14
14764	2019-11-19 17:39:04	2019-11-19	9	[{"id_menu":7,"count":1}]	5539	delivery	5	14
14765	2019-11-19 17:47:13	2019-11-19	17	[{"id_menu":4,"count":1}]	267	delivery	5	22
14766	2019-11-19 18:08:15	2019-11-19	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	5510	delivery	5	26
14767	2019-11-19 18:25:39	2019-11-19	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4420	pick-up	0	22
14768	2019-11-19 18:31:34	2019-11-19	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	994	pick-up	0	26
14769	2019-11-19 18:37:07	2019-11-19	9	[{"id_menu":6,"count":1}]	3909	pick-up	0	9
14770	2019-11-19 18:42:28	2019-11-19	9	[{"id_menu":7,"count":1}]	4921	pick-up	0	9
14771	2019-11-19 18:51:02	2019-11-19	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	5521	delivery	5	34
14772	2019-11-19 18:52:44	2019-11-19	8	[{"id_menu":5,"count":1}]	5531	delivery	5	13
14773	2019-11-19 19:17:08	2019-11-19	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	213	delivery	5	25
14774	2019-11-19 19:38:39	2019-11-19	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	5554	delivery	5	31
14775	2019-11-19 19:48:30	2019-11-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5516	pick-up	0	23
14776	2019-11-19 20:09:57	2019-11-19	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1093	pick-up	0	43
14777	2019-11-19 20:25:29	2019-11-19	9	[{"id_menu":7,"count":1}]	4652	pick-up	0	9
14778	2019-11-19 20:46:04	2019-11-19	12	[{"id_menu":3,"count":1}]	5518	delivery	5	17
14779	2019-11-19 21:14:50	2019-11-19	9	[{"id_menu":6,"count":1}]	1817	pick-up	0	9
14780	2019-11-19 21:16:06	2019-11-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2477	pick-up	0	17
14781	2019-11-19 21:34:18	2019-11-19	14	[{"id_menu":2,"count":1}]	708	pick-up	0	14
14782	2019-11-19 21:40:46	2019-11-19	17	[{"id_menu":4,"count":1}]	2351	delivery	5	22
14783	2019-11-19 21:41:23	2019-11-19	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1104	pick-up	0	21
14784	2019-11-19 21:49:07	2019-11-19	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	5535	delivery	5	31
14785	2019-11-19 21:49:45	2019-11-19	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2933	delivery	5	26
14786	2019-11-19 22:30:06	2019-11-19	12	[{"id_menu":1,"count":1}]	5532	delivery	5	17
14787	2019-11-19 22:58:30	2019-11-19	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	13	pick-up	0	20
14788	2019-11-19 23:00:42	2019-11-19	17	[{"id_menu":4,"count":1}]	1379	pick-up	0	17
14789	2019-11-19 23:25:16	2019-11-19	12	[{"id_menu":3,"count":1}]	1212	pick-up	0	12
14790	2019-11-19 23:28:11	2019-11-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2582	pick-up	0	31
14791	2019-11-20 00:25:12	2019-11-20	9	[{"id_menu":7,"count":1}]	5593	delivery	5	14
14792	2019-11-20 00:33:28	2019-11-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5591	delivery	5	28
14793	2019-11-20 00:41:19	2019-11-20	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2630	delivery	5	42
14794	2019-11-20 00:43:13	2019-11-20	14	[{"id_menu":2,"count":2}]	424	delivery	5	19
14795	2019-11-20 00:43:29	2019-11-20	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	5594	delivery	5	40
14796	2019-11-20 00:52:12	2019-11-20	9	[{"id_menu":7,"count":1}]	4804	pick-up	0	9
14797	2019-11-20 00:55:49	2019-11-20	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	5579	delivery	5	23
14798	2019-11-20 01:14:07	2019-11-20	14	[{"id_menu":2,"count":1}]	3065	pick-up	0	14
14799	2019-11-20 01:22:13	2019-11-20	8	[{"id_menu":5,"count":1}]	5605	pick-up	0	8
14800	2019-11-20 01:28:32	2019-11-20	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5198	pick-up	0	26
14801	2019-11-20 01:35:12	2019-11-20	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2965	delivery	5	26
14802	2019-11-20 01:37:31	2019-11-20	17	[{"id_menu":4,"count":1}]	2243	pick-up	0	17
14803	2019-11-20 01:43:31	2019-11-20	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5558	delivery	5	22
14804	2019-11-20 02:56:36	2019-11-20	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	5585	delivery	5	39
14805	2019-11-20 03:10:05	2019-11-20	31	[{"id_menu":2,"count":3},{"id_menu":4,"count":1}]	2951	delivery	5	36
14806	2019-11-20 03:20:18	2019-11-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1028	delivery	5	23
14807	2019-11-20 03:28:58	2019-11-20	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	2885	delivery	5	25
14808	2019-11-20 03:53:17	2019-11-20	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1631	pick-up	0	22
14809	2019-11-20 03:57:58	2019-11-20	9	[{"id_menu":7,"count":2}]	1025	pick-up	0	9
14810	2019-11-20 03:58:41	2019-11-20	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	5559	pick-up	0	21
14811	2019-11-20 04:03:02	2019-11-20	17	[{"id_menu":4,"count":1}]	5561	delivery	5	22
14812	2019-11-20 04:21:06	2019-11-20	17	[{"id_menu":4,"count":1}]	1715	pick-up	0	17
14813	2019-11-20 04:39:33	2019-11-20	12	[{"id_menu":1,"count":1}]	4908	delivery	5	17
14814	2019-11-20 04:48:27	2019-11-20	14	[{"id_menu":2,"count":1}]	3621	pick-up	0	14
14815	2019-11-20 05:00:55	2019-11-20	8	[{"id_menu":5,"count":1}]	3960	delivery	5	13
14816	2019-11-20 05:03:49	2019-11-20	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	5568	delivery	5	34
14817	2019-11-20 05:16:16	2019-11-20	12	[{"id_menu":1,"count":1}]	5564	delivery	5	17
14818	2019-11-20 05:36:14	2019-11-20	12	[{"id_menu":3,"count":1}]	1156	delivery	5	17
14819	2019-11-20 05:45:57	2019-11-20	8	[{"id_menu":5,"count":1}]	5575	delivery	5	13
14820	2019-11-20 05:49:04	2019-11-20	9	[{"id_menu":6,"count":1}]	2007	pick-up	0	9
14821	2019-11-20 05:54:58	2019-11-20	9	[{"id_menu":7,"count":1}]	5194	delivery	5	14
14822	2019-11-20 06:02:09	2019-11-20	8	[{"id_menu":5,"count":1}]	1101	pick-up	0	8
14823	2019-11-20 06:08:12	2019-11-20	12	[{"id_menu":3,"count":1}]	721	pick-up	0	12
14824	2019-11-20 06:15:50	2019-11-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3119	delivery	5	28
14825	2019-11-20 06:23:01	2019-11-20	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	3125	delivery	5	26
14826	2019-11-20 06:26:18	2019-11-20	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5572	delivery	5	34
14827	2019-11-20 06:27:55	2019-11-20	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	4312	pick-up	0	24
14828	2019-11-20 06:34:05	2019-11-20	9	[{"id_menu":6,"count":1}]	4526	pick-up	0	9
14829	2019-11-20 06:35:49	2019-11-20	9	[{"id_menu":6,"count":1}]	4867	delivery	5	14
14830	2019-11-20 06:38:06	2019-11-20	8	[{"id_menu":5,"count":1}]	3725	pick-up	0	8
14831	2019-11-20 06:52:31	2019-11-20	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4450	delivery	5	43
14832	2019-11-20 07:07:01	2019-11-20	12	[{"id_menu":3,"count":1}]	5596	delivery	5	17
14833	2019-11-20 07:23:15	2019-11-20	9	[{"id_menu":6,"count":1}]	5590	delivery	5	14
14834	2019-11-20 08:26:29	2019-11-20	9	[{"id_menu":7,"count":1}]	219	delivery	5	14
14835	2019-11-20 08:35:41	2019-11-20	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5573	delivery	5	51
14836	2019-11-20 08:48:48	2019-11-20	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	962	delivery	5	27
14837	2019-11-20 08:49:49	2019-11-20	9	[{"id_menu":7,"count":1}]	5359	delivery	5	14
14838	2019-11-20 09:00:08	2019-11-20	14	[{"id_menu":2,"count":1}]	2471	pick-up	0	14
14839	2019-11-20 09:00:43	2019-11-20	9	[{"id_menu":6,"count":1}]	2311	delivery	5	14
14840	2019-11-20 09:07:45	2019-11-20	8	[{"id_menu":5,"count":1}]	5598	delivery	5	13
14841	2019-11-20 09:10:26	2019-11-20	9	[{"id_menu":7,"count":1}]	2384	pick-up	0	9
14842	2019-11-20 09:14:45	2019-11-20	8	[{"id_menu":5,"count":1}]	827	delivery	5	13
14843	2019-11-20 09:35:20	2019-11-20	9	[{"id_menu":7,"count":1}]	5236	delivery	5	14
14844	2019-11-20 09:48:08	2019-11-20	17	[{"id_menu":4,"count":1}]	5577	pick-up	0	17
14845	2019-11-20 09:48:53	2019-11-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	5608	pick-up	0	23
14846	2019-11-20 10:07:57	2019-11-20	17	[{"id_menu":4,"count":1}]	3511	pick-up	0	17
14847	2019-11-20 10:10:31	2019-11-20	14	[{"id_menu":2,"count":1}]	4370	pick-up	0	14
14848	2019-11-20 10:16:27	2019-11-20	14	[{"id_menu":2,"count":1}]	5601	pick-up	0	14
14849	2019-11-20 10:18:55	2019-11-20	14	[{"id_menu":2,"count":1}]	5583	delivery	5	19
14850	2019-11-20 10:27:30	2019-11-20	9	[{"id_menu":6,"count":1}]	2397	pick-up	0	9
14851	2019-11-20 10:33:00	2019-11-20	17	[{"id_menu":4,"count":2}]	2598	pick-up	0	17
14852	2019-11-20 10:44:07	2019-11-20	12	[{"id_menu":1,"count":1}]	970	pick-up	0	12
14853	2019-11-20 11:11:44	2019-11-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5567	delivery	5	22
14854	2019-11-20 11:13:10	2019-11-20	12	[{"id_menu":1,"count":1}]	5604	pick-up	0	12
14855	2019-11-20 11:48:10	2019-11-20	9	[{"id_menu":6,"count":1}]	491	delivery	5	14
14856	2019-11-20 12:08:34	2019-11-20	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5603	delivery	5	30
14857	2019-11-20 12:16:18	2019-11-20	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5565	delivery	5	46
14858	2019-11-20 12:23:14	2019-11-20	12	[{"id_menu":1,"count":1}]	5597	delivery	5	17
14859	2019-11-20 12:30:35	2019-11-20	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	5443	delivery	5	23
14860	2019-11-20 13:14:18	2019-11-20	17	[{"id_menu":4,"count":1}]	5587	delivery	5	22
14861	2019-11-20 13:45:37	2019-11-20	14	[{"id_menu":2,"count":1}]	5582	delivery	5	19
14862	2019-11-20 13:53:44	2019-11-20	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	1263	pick-up	0	38
14863	2019-11-20 14:07:37	2019-11-20	17	[{"id_menu":4,"count":1}]	1877	pick-up	0	17
14864	2019-11-20 14:10:18	2019-11-20	14	[{"id_menu":2,"count":1}]	1380	delivery	5	19
14865	2019-11-20 14:18:59	2019-11-20	17	[{"id_menu":4,"count":1}]	2980	delivery	5	22
14866	2019-11-20 14:25:12	2019-11-20	9	[{"id_menu":7,"count":1}]	5576	delivery	5	14
14867	2019-11-20 14:26:17	2019-11-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3851	delivery	5	28
14868	2019-11-20 14:29:14	2019-11-20	9	[{"id_menu":6,"count":1}]	5584	delivery	5	14
14869	2019-11-20 14:31:58	2019-11-20	9	[{"id_menu":7,"count":1}]	3311	delivery	5	14
14870	2019-11-20 14:32:19	2019-11-20	12	[{"id_menu":3,"count":1}]	5569	delivery	5	17
14871	2019-11-20 14:32:32	2019-11-20	12	[{"id_menu":3,"count":1}]	1638	delivery	5	17
14872	2019-11-20 14:34:28	2019-11-20	9	[{"id_menu":6,"count":2}]	527	delivery	5	14
14873	2019-11-20 14:42:00	2019-11-20	12	[{"id_menu":3,"count":1}]	5600	pick-up	0	12
14874	2019-11-20 15:03:23	2019-11-20	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5580	delivery	5	34
14875	2019-11-20 15:07:15	2019-11-20	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	2401	delivery	5	31
14876	2019-11-20 15:22:13	2019-11-20	12	[{"id_menu":1,"count":1}]	4729	delivery	5	17
14877	2019-11-20 15:22:26	2019-11-20	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4333	delivery	5	42
14878	2019-11-20 15:32:02	2019-11-20	12	[{"id_menu":3,"count":1}]	5562	delivery	5	17
14879	2019-11-20 15:45:44	2019-11-20	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3372	pick-up	0	26
14880	2019-11-20 15:45:57	2019-11-20	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	694	delivery	5	26
14881	2019-11-20 16:04:33	2019-11-20	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	904	delivery	5	26
14882	2019-11-20 16:06:46	2019-11-20	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	833	pick-up	0	29
14883	2019-11-20 16:10:57	2019-11-20	9	[{"id_menu":6,"count":1}]	5607	delivery	5	14
14884	2019-11-20 16:15:31	2019-11-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5563	pick-up	0	23
14885	2019-11-20 16:25:34	2019-11-20	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	5465	pick-up	0	20
14886	2019-11-20 16:53:18	2019-11-20	12	[{"id_menu":3,"count":1}]	4782	pick-up	0	12
14887	2019-11-20 17:06:32	2019-11-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	5571	delivery	5	28
14888	2019-11-20 17:11:04	2019-11-20	14	[{"id_menu":2,"count":1}]	5588	pick-up	0	14
14889	2019-11-20 17:42:20	2019-11-20	17	[{"id_menu":4,"count":1}]	1861	delivery	5	22
14890	2019-11-20 18:02:09	2019-11-20	14	[{"id_menu":2,"count":1}]	2649	delivery	5	19
14891	2019-11-20 18:05:05	2019-11-20	9	[{"id_menu":6,"count":2}]	5574	delivery	5	14
14892	2019-11-20 18:06:43	2019-11-20	14	[{"id_menu":2,"count":1}]	2657	delivery	5	19
14893	2019-11-20 18:38:12	2019-11-20	9	[{"id_menu":7,"count":1}]	5595	delivery	5	14
14894	2019-11-20 18:45:25	2019-11-20	12	[{"id_menu":1,"count":1}]	2443	pick-up	0	12
14895	2019-11-20 18:48:16	2019-11-20	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2780	pick-up	0	40
14896	2019-11-20 18:56:27	2019-11-20	14	[{"id_menu":2,"count":2}]	456	pick-up	0	14
14897	2019-11-20 19:02:36	2019-11-20	17	[{"id_menu":4,"count":1}]	4634	delivery	5	22
14898	2019-11-20 19:13:40	2019-11-20	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	113	pick-up	0	26
14899	2019-11-20 19:20:00	2019-11-20	12	[{"id_menu":1,"count":1}]	3458	pick-up	0	12
14900	2019-11-20 19:25:33	2019-11-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1187	pick-up	0	17
14901	2019-11-20 19:30:30	2019-11-20	9	[{"id_menu":6,"count":1}]	3797	delivery	5	14
14902	2019-11-20 19:44:44	2019-11-20	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2843	delivery	5	45
14903	2019-11-20 19:50:00	2019-11-20	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":2}]	5560	delivery	5	31
14904	2019-11-20 20:08:32	2019-11-20	12	[{"id_menu":3,"count":1}]	3952	delivery	5	17
14905	2019-11-20 20:09:05	2019-11-20	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	1273	pick-up	0	38
14906	2019-11-20 20:40:29	2019-11-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1593	pick-up	0	23
14907	2019-11-20 20:47:00	2019-11-20	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2083	pick-up	0	22
14908	2019-11-20 20:55:07	2019-11-20	9	[{"id_menu":6,"count":1}]	4524	pick-up	0	9
14909	2019-11-20 20:56:35	2019-11-20	9	[{"id_menu":6,"count":1}]	5592	delivery	5	14
14910	2019-11-20 20:58:58	2019-11-20	17	[{"id_menu":4,"count":1}]	5599	delivery	5	22
14911	2019-11-20 21:08:19	2019-11-20	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	5308	pick-up	0	20
14912	2019-11-20 21:16:07	2019-11-20	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2173	delivery	5	31
14913	2019-11-20 21:26:09	2019-11-20	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	708	pick-up	0	35
14914	2019-11-20 21:38:07	2019-11-20	14	[{"id_menu":2,"count":1}]	2416	pick-up	0	14
14915	2019-11-20 21:43:24	2019-11-20	12	[{"id_menu":3,"count":1}]	1279	pick-up	0	12
14916	2019-11-20 21:51:46	2019-11-20	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3451	pick-up	0	26
14917	2019-11-20 22:42:33	2019-11-20	17	[{"id_menu":4,"count":1}]	5581	delivery	5	22
14918	2019-11-20 22:43:11	2019-11-20	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	5606	delivery	5	38
14919	2019-11-20 22:47:46	2019-11-20	9	[{"id_menu":6,"count":1}]	4130	pick-up	0	9
14920	2019-11-20 22:50:23	2019-11-20	14	[{"id_menu":2,"count":1}]	1597	pick-up	0	14
14921	2019-11-20 23:32:30	2019-11-20	9	[{"id_menu":6,"count":1}]	5578	delivery	5	14
14922	2019-11-20 23:51:27	2019-11-20	9	[{"id_menu":7,"count":1}]	5609	delivery	5	14
14991	2019-11-21 11:18:22	2019-11-21	14	[{"id_menu":2,"count":1}]	2101	pick-up	0	14
14923	2019-11-21 00:00:31	2019-11-21	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5639	pick-up	0	29
14924	2019-11-21 00:02:12	2019-11-21	14	[{"id_menu":2,"count":1}]	5660	pick-up	0	14
14925	2019-11-21 00:03:19	2019-11-21	14	[{"id_menu":2,"count":1}]	3295	delivery	5	19
14926	2019-11-21 00:03:29	2019-11-21	14	[{"id_menu":2,"count":1}]	1270	delivery	5	19
14927	2019-11-21 00:13:27	2019-11-21	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2993	delivery	5	25
14928	2019-11-21 00:19:28	2019-11-21	9	[{"id_menu":7,"count":1}]	5650	pick-up	0	9
14929	2019-11-21 00:26:19	2019-11-21	17	[{"id_menu":4,"count":2}]	5663	delivery	5	22
14930	2019-11-21 00:27:17	2019-11-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	5666	delivery	5	31
14931	2019-11-21 00:45:40	2019-11-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2423	delivery	5	31
14932	2019-11-21 00:49:24	2019-11-21	17	[{"id_menu":4,"count":1}]	764	delivery	5	22
14933	2019-11-21 00:55:23	2019-11-21	9	[{"id_menu":6,"count":1}]	5615	delivery	5	14
14934	2019-11-21 01:01:06	2019-11-21	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5620	delivery	5	40
14935	2019-11-21 01:09:11	2019-11-21	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	790	pick-up	0	31
14936	2019-11-21 01:16:55	2019-11-21	12	[{"id_menu":1,"count":1}]	138	pick-up	0	12
14937	2019-11-21 01:19:29	2019-11-21	14	[{"id_menu":2,"count":1}]	3285	pick-up	0	14
14938	2019-11-21 01:21:37	2019-11-21	9	[{"id_menu":6,"count":1}]	2402	pick-up	0	9
14939	2019-11-21 01:23:03	2019-11-21	17	[{"id_menu":4,"count":1}]	994	pick-up	0	17
14940	2019-11-21 01:31:55	2019-11-21	9	[{"id_menu":6,"count":1}]	5617	pick-up	0	9
14941	2019-11-21 01:44:08	2019-11-21	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2305	delivery	5	30
14942	2019-11-21 02:04:20	2019-11-21	12	[{"id_menu":3,"count":1}]	5308	delivery	5	17
14943	2019-11-21 02:18:47	2019-11-21	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	5290	pick-up	0	29
14944	2019-11-21 02:29:16	2019-11-21	9	[{"id_menu":6,"count":1}]	5649	delivery	5	14
14945	2019-11-21 02:45:32	2019-11-21	9	[{"id_menu":6,"count":1}]	1441	pick-up	0	9
14946	2019-11-21 02:47:09	2019-11-21	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2398	delivery	5	34
14947	2019-11-21 02:58:09	2019-11-21	12	[{"id_menu":1,"count":1}]	5623	pick-up	0	12
14948	2019-11-21 03:05:30	2019-11-21	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	5105	delivery	5	40
14949	2019-11-21 03:21:20	2019-11-21	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	5645	delivery	5	23
14950	2019-11-21 03:37:58	2019-11-21	12	[{"id_menu":3,"count":1}]	5080	pick-up	0	12
14951	2019-11-21 04:00:34	2019-11-21	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	5618	delivery	5	26
14952	2019-11-21 04:03:17	2019-11-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	5651	delivery	5	22
14953	2019-11-21 04:11:48	2019-11-21	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4547	delivery	5	40
14954	2019-11-21 04:13:02	2019-11-21	12	[{"id_menu":3,"count":1}]	5653	delivery	5	17
14955	2019-11-21 04:25:02	2019-11-21	17	[{"id_menu":4,"count":1}]	171	pick-up	0	17
14956	2019-11-21 04:59:17	2019-11-21	12	[{"id_menu":1,"count":1}]	2038	pick-up	0	12
14957	2019-11-21 05:09:22	2019-11-21	17	[{"id_menu":4,"count":1}]	3721	delivery	5	22
14958	2019-11-21 05:11:32	2019-11-21	17	[{"id_menu":4,"count":1}]	66	pick-up	0	17
14959	2019-11-21 05:15:35	2019-11-21	8	[{"id_menu":5,"count":1}]	5664	delivery	5	13
14960	2019-11-21 05:25:32	2019-11-21	14	[{"id_menu":2,"count":1}]	2190	pick-up	0	14
14961	2019-11-21 05:32:51	2019-11-21	9	[{"id_menu":7,"count":1}]	1462	pick-up	0	9
14962	2019-11-21 05:34:30	2019-11-21	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5632	delivery	5	56
14963	2019-11-21 05:39:11	2019-11-21	12	[{"id_menu":1,"count":1}]	847	pick-up	0	12
14964	2019-11-21 05:41:14	2019-11-21	17	[{"id_menu":4,"count":1}]	612	pick-up	0	17
14965	2019-11-21 05:50:00	2019-11-21	17	[{"id_menu":4,"count":1}]	5141	pick-up	0	17
14966	2019-11-21 05:58:07	2019-11-21	12	[{"id_menu":3,"count":1}]	5643	pick-up	0	12
14967	2019-11-21 06:07:00	2019-11-21	14	[{"id_menu":2,"count":1}]	5627	delivery	5	19
14968	2019-11-21 06:27:37	2019-11-21	8	[{"id_menu":5,"count":1}]	1322	pick-up	0	8
14969	2019-11-21 06:30:34	2019-11-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	467	pick-up	0	26
14970	2019-11-21 06:40:34	2019-11-21	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5631	delivery	5	37
14971	2019-11-21 06:43:29	2019-11-21	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	377	pick-up	0	43
14972	2019-11-21 06:48:25	2019-11-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5652	delivery	5	31
14973	2019-11-21 07:45:43	2019-11-21	9	[{"id_menu":6,"count":1}]	5659	delivery	5	14
14974	2019-11-21 07:49:25	2019-11-21	14	[{"id_menu":2,"count":1}]	5646	delivery	5	19
14975	2019-11-21 08:25:34	2019-11-21	17	[{"id_menu":4,"count":2}]	5622	delivery	5	22
14976	2019-11-21 08:28:21	2019-11-21	9	[{"id_menu":6,"count":1}]	2616	pick-up	0	9
14977	2019-11-21 08:40:44	2019-11-21	9	[{"id_menu":7,"count":2}]	1051	pick-up	0	9
14978	2019-11-21 08:47:12	2019-11-21	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	5064	delivery	5	36
14979	2019-11-21 08:53:36	2019-11-21	17	[{"id_menu":4,"count":1}]	361	delivery	5	22
14980	2019-11-21 09:24:24	2019-11-21	14	[{"id_menu":2,"count":1}]	799	pick-up	0	14
14981	2019-11-21 09:26:01	2019-11-21	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	3578	delivery	5	27
14982	2019-11-21 09:26:28	2019-11-21	8	[{"id_menu":5,"count":1}]	2200	pick-up	0	8
14983	2019-11-21 09:57:30	2019-11-21	9	[{"id_menu":6,"count":1}]	5638	delivery	5	14
14984	2019-11-21 10:04:39	2019-11-21	12	[{"id_menu":1,"count":1}]	2799	delivery	5	17
14985	2019-11-21 10:20:34	2019-11-21	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5634	delivery	5	30
14986	2019-11-21 10:29:43	2019-11-21	9	[{"id_menu":6,"count":1}]	5621	delivery	5	14
14987	2019-11-21 10:36:12	2019-11-21	8	[{"id_menu":5,"count":1}]	5658	delivery	5	13
14988	2019-11-21 10:47:23	2019-11-21	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	4664	delivery	5	34
14989	2019-11-21 11:01:37	2019-11-21	17	[{"id_menu":4,"count":1}]	3619	delivery	5	22
14990	2019-11-21 11:06:02	2019-11-21	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1989	pick-up	0	25
14992	2019-11-21 11:18:37	2019-11-21	14	[{"id_menu":2,"count":1}]	2119	pick-up	0	14
14993	2019-11-21 12:21:44	2019-11-21	8	[{"id_menu":5,"count":1}]	4798	pick-up	0	8
14994	2019-11-21 12:23:13	2019-11-21	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2575	delivery	5	30
14995	2019-11-21 12:28:50	2019-11-21	12	[{"id_menu":3,"count":1}]	1079	delivery	5	17
14996	2019-11-21 12:31:49	2019-11-21	9	[{"id_menu":6,"count":1}]	3647	pick-up	0	9
14997	2019-11-21 12:42:28	2019-11-21	12	[{"id_menu":3,"count":1}]	4804	pick-up	0	12
14998	2019-11-21 12:54:22	2019-11-21	12	[{"id_menu":3,"count":1}]	1014	delivery	5	17
14999	2019-11-21 12:56:42	2019-11-21	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1132	delivery	5	37
15000	2019-11-21 13:14:21	2019-11-21	17	[{"id_menu":4,"count":1}]	2445	delivery	5	22
15001	2019-11-21 13:31:11	2019-11-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	5657	delivery	5	22
15002	2019-11-21 13:34:16	2019-11-21	8	[{"id_menu":5,"count":1}]	2567	pick-up	0	8
15003	2019-11-21 13:37:00	2019-11-21	8	[{"id_menu":5,"count":1}]	5446	delivery	5	13
15004	2019-11-21 13:39:03	2019-11-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3335	pick-up	0	23
15005	2019-11-21 13:47:19	2019-11-21	12	[{"id_menu":1,"count":1}]	1023	delivery	5	17
15006	2019-11-21 14:28:09	2019-11-21	17	[{"id_menu":4,"count":1}]	1919	delivery	5	22
15007	2019-11-21 14:31:00	2019-11-21	12	[{"id_menu":1,"count":1}]	676	pick-up	0	12
15008	2019-11-21 14:35:15	2019-11-21	17	[{"id_menu":4,"count":1}]	2227	pick-up	0	17
15009	2019-11-21 14:43:59	2019-11-21	8	[{"id_menu":5,"count":1}]	3587	delivery	5	13
15010	2019-11-21 14:44:50	2019-11-21	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1640	pick-up	0	20
15011	2019-11-21 15:03:18	2019-11-21	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2870	pick-up	0	34
15012	2019-11-21 15:11:22	2019-11-21	9	[{"id_menu":6,"count":1}]	3345	delivery	5	14
15013	2019-11-21 15:28:08	2019-11-21	9	[{"id_menu":7,"count":1}]	5619	delivery	5	14
15014	2019-11-21 15:34:49	2019-11-21	9	[{"id_menu":7,"count":1}]	5612	delivery	5	14
15015	2019-11-21 15:41:23	2019-11-21	9	[{"id_menu":6,"count":1}]	5661	delivery	5	14
15016	2019-11-21 15:45:00	2019-11-21	9	[{"id_menu":6,"count":1}]	4973	delivery	5	14
15017	2019-11-21 16:07:00	2019-11-21	9	[{"id_menu":6,"count":1}]	304	pick-up	0	9
15018	2019-11-21 16:09:21	2019-11-21	14	[{"id_menu":2,"count":2}]	557	delivery	5	19
15019	2019-11-21 16:09:43	2019-11-21	17	[{"id_menu":4,"count":1}]	5665	pick-up	0	17
15020	2019-11-21 16:10:42	2019-11-21	17	[{"id_menu":4,"count":1}]	2440	delivery	5	22
15021	2019-11-21 16:15:10	2019-11-21	8	[{"id_menu":5,"count":1}]	5636	delivery	5	13
15022	2019-11-21 16:43:12	2019-11-21	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5654	delivery	5	51
15023	2019-11-21 16:45:10	2019-11-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4946	delivery	5	23
15024	2019-11-21 17:01:23	2019-11-21	8	[{"id_menu":5,"count":1}]	3970	delivery	5	13
15025	2019-11-21 17:10:31	2019-11-21	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3961	pick-up	0	31
15026	2019-11-21 17:16:24	2019-11-21	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5629	delivery	5	51
15027	2019-11-21 17:23:42	2019-11-21	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	5616	pick-up	0	20
15028	2019-11-21 17:25:17	2019-11-21	14	[{"id_menu":2,"count":1}]	1563	delivery	5	19
15029	2019-11-21 17:28:56	2019-11-21	12	[{"id_menu":3,"count":1}]	352	pick-up	0	12
15030	2019-11-21 17:52:35	2019-11-21	38	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	5640	delivery	5	43
15031	2019-11-21 17:53:40	2019-11-21	8	[{"id_menu":5,"count":1}]	4042	pick-up	0	8
15032	2019-11-21 18:15:27	2019-11-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5662	delivery	5	23
15033	2019-11-21 18:16:13	2019-11-21	12	[{"id_menu":1,"count":1}]	4789	delivery	5	17
15034	2019-11-21 18:23:30	2019-11-21	12	[{"id_menu":3,"count":1}]	5613	delivery	5	17
15035	2019-11-21 18:42:54	2019-11-21	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5656	delivery	5	31
15036	2019-11-21 18:48:01	2019-11-21	9	[{"id_menu":6,"count":1}]	5628	delivery	5	14
15037	2019-11-21 19:02:25	2019-11-21	12	[{"id_menu":3,"count":1}]	5633	delivery	5	17
15038	2019-11-21 19:29:33	2019-11-21	14	[{"id_menu":2,"count":1}]	5626	delivery	5	19
15039	2019-11-21 19:37:45	2019-11-21	17	[{"id_menu":4,"count":1}]	5648	pick-up	0	17
15040	2019-11-21 19:41:52	2019-11-21	9	[{"id_menu":6,"count":1}]	5630	delivery	5	14
15041	2019-11-21 19:49:48	2019-11-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2222	pick-up	0	23
15042	2019-11-21 19:50:47	2019-11-21	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	5644	delivery	5	26
15043	2019-11-21 20:07:19	2019-11-21	12	[{"id_menu":3,"count":1}]	1266	pick-up	0	12
15044	2019-11-21 20:09:28	2019-11-21	9	[{"id_menu":6,"count":1}]	1311	pick-up	0	9
15045	2019-11-21 20:20:50	2019-11-21	12	[{"id_menu":1,"count":2}]	1490	pick-up	0	12
15046	2019-11-21 20:58:18	2019-11-21	14	[{"id_menu":2,"count":1}]	5625	delivery	5	19
15047	2019-11-21 20:58:37	2019-11-21	17	[{"id_menu":4,"count":1}]	5440	pick-up	0	17
15048	2019-11-21 21:00:05	2019-11-21	8	[{"id_menu":5,"count":1}]	2053	pick-up	0	8
15049	2019-11-21 21:00:26	2019-11-21	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	2176	pick-up	0	31
15050	2019-11-21 21:10:02	2019-11-21	12	[{"id_menu":3,"count":1}]	5642	pick-up	0	12
15051	2019-11-21 21:25:10	2019-11-21	17	[{"id_menu":4,"count":1}]	4279	pick-up	0	17
15052	2019-11-21 21:33:19	2019-11-21	14	[{"id_menu":2,"count":1}]	2139	pick-up	0	14
15053	2019-11-21 21:34:43	2019-11-21	12	[{"id_menu":3,"count":1}]	1781	pick-up	0	12
15054	2019-11-21 21:35:29	2019-11-21	12	[{"id_menu":1,"count":1}]	3905	pick-up	0	12
15055	2019-11-21 21:51:34	2019-11-21	12	[{"id_menu":1,"count":1}]	2531	pick-up	0	12
15056	2019-11-21 21:53:38	2019-11-21	12	[{"id_menu":1,"count":1}]	5647	delivery	5	17
15057	2019-11-21 22:24:52	2019-11-21	12	[{"id_menu":1,"count":1}]	4967	pick-up	0	12
15058	2019-11-21 22:37:54	2019-11-21	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4160	delivery	5	26
15059	2019-11-21 22:45:50	2019-11-21	8	[{"id_menu":5,"count":1}]	3962	delivery	5	13
15060	2019-11-21 22:55:13	2019-11-21	12	[{"id_menu":1,"count":1}]	5611	pick-up	0	12
15061	2019-11-21 23:10:06	2019-11-21	12	[{"id_menu":1,"count":1}]	3451	delivery	5	17
15062	2019-11-21 23:12:25	2019-11-21	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2523	pick-up	0	43
15063	2019-11-21 23:12:37	2019-11-21	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	3567	pick-up	0	26
15064	2019-11-21 23:18:27	2019-11-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2097	pick-up	0	26
15065	2019-11-21 23:31:03	2019-11-21	9	[{"id_menu":6,"count":1}]	4107	delivery	5	14
15066	2019-11-21 23:39:48	2019-11-21	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2244	pick-up	0	21
15067	2019-11-22 00:10:21	2019-11-22	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2615	pick-up	0	26
15068	2019-11-22 00:19:39	2019-11-22	14	[{"id_menu":2,"count":1}]	2025	pick-up	0	14
15069	2019-11-22 00:31:53	2019-11-22	17	[{"id_menu":4,"count":1}]	2579	delivery	5	22
15070	2019-11-22 00:32:59	2019-11-22	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	5713	delivery	5	22
15071	2019-11-22 00:36:17	2019-11-22	17	[{"id_menu":4,"count":1}]	5695	delivery	5	22
15072	2019-11-22 00:37:56	2019-11-22	12	[{"id_menu":3,"count":2}]	5686	delivery	5	17
15073	2019-11-22 00:49:33	2019-11-22	9	[{"id_menu":6,"count":1}]	3998	delivery	5	14
15074	2019-11-22 00:58:23	2019-11-22	9	[{"id_menu":7,"count":1}]	604	delivery	5	14
15075	2019-11-22 01:03:59	2019-11-22	14	[{"id_menu":2,"count":1}]	1991	delivery	5	19
15076	2019-11-22 01:09:21	2019-11-22	12	[{"id_menu":1,"count":2}]	2463	delivery	5	17
15077	2019-11-22 01:10:41	2019-11-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5682	delivery	5	23
15078	2019-11-22 01:15:47	2019-11-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	5712	pick-up	0	31
15079	2019-11-22 01:42:41	2019-11-22	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3385	delivery	5	26
15080	2019-11-22 01:45:11	2019-11-22	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	5681	delivery	5	43
15081	2019-11-22 01:59:46	2019-11-22	12	[{"id_menu":1,"count":1}]	1427	pick-up	0	12
15082	2019-11-22 02:16:35	2019-11-22	9	[{"id_menu":6,"count":1}]	4401	pick-up	0	9
15083	2019-11-22 02:46:12	2019-11-22	12	[{"id_menu":1,"count":2}]	3684	delivery	5	17
15084	2019-11-22 02:55:19	2019-11-22	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3754	pick-up	0	21
15085	2019-11-22 03:12:24	2019-11-22	9	[{"id_menu":7,"count":1}]	5677	delivery	5	14
15086	2019-11-22 03:14:05	2019-11-22	12	[{"id_menu":1,"count":1}]	2378	pick-up	0	12
15087	2019-11-22 03:15:11	2019-11-22	14	[{"id_menu":2,"count":2}]	5701	pick-up	0	14
15088	2019-11-22 03:37:21	2019-11-22	17	[{"id_menu":4,"count":1}]	1073	pick-up	0	17
15089	2019-11-22 03:41:09	2019-11-22	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5673	delivery	5	43
15090	2019-11-22 03:58:54	2019-11-22	12	[{"id_menu":1,"count":1}]	3785	delivery	5	17
15091	2019-11-22 04:18:54	2019-11-22	12	[{"id_menu":1,"count":1}]	3909	pick-up	0	12
15092	2019-11-22 04:40:33	2019-11-22	9	[{"id_menu":6,"count":1}]	5724	delivery	5	14
15093	2019-11-22 04:48:31	2019-11-22	9	[{"id_menu":6,"count":1}]	5684	delivery	5	14
15094	2019-11-22 04:55:38	2019-11-22	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2521	pick-up	0	38
15095	2019-11-22 05:00:26	2019-11-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4748	delivery	5	36
15096	2019-11-22 05:49:51	2019-11-22	21	[{"id_menu":3,"count":3},{"id_menu":7,"count":1}]	5706	delivery	5	26
15097	2019-11-22 05:55:04	2019-11-22	9	[{"id_menu":6,"count":1}]	2119	pick-up	0	9
15098	2019-11-22 06:03:15	2019-11-22	12	[{"id_menu":3,"count":1}]	3699	delivery	5	17
15099	2019-11-22 06:25:19	2019-11-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4665	delivery	5	36
15100	2019-11-22 06:27:14	2019-11-22	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1614	pick-up	0	21
15101	2019-11-22 06:31:04	2019-11-22	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	4290	delivery	5	26
15102	2019-11-22 07:02:24	2019-11-22	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1547	pick-up	0	29
15103	2019-11-22 07:12:58	2019-11-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	5723	delivery	5	28
15104	2019-11-22 07:24:46	2019-11-22	12	[{"id_menu":1,"count":1}]	357	delivery	5	17
15105	2019-11-22 07:38:10	2019-11-22	8	[{"id_menu":5,"count":1}]	4158	delivery	5	13
15106	2019-11-22 07:38:36	2019-11-22	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	5721	pick-up	0	35
15107	2019-11-22 07:39:49	2019-11-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":3}]	2031	pick-up	0	31
15108	2019-11-22 07:52:11	2019-11-22	17	[{"id_menu":4,"count":1}]	1529	delivery	5	22
15109	2019-11-22 07:59:49	2019-11-22	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	2176	delivery	5	36
15110	2019-11-22 08:21:36	2019-11-22	14	[{"id_menu":2,"count":1}]	1296	pick-up	0	14
15111	2019-11-22 08:38:58	2019-11-22	8	[{"id_menu":5,"count":1}]	2392	delivery	5	13
15112	2019-11-22 09:12:17	2019-11-22	8	[{"id_menu":5,"count":1}]	5715	delivery	5	13
15113	2019-11-22 09:44:40	2019-11-22	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	5668	pick-up	0	24
15114	2019-11-22 09:52:49	2019-11-22	9	[{"id_menu":7,"count":2}]	5691	delivery	5	14
15115	2019-11-22 09:53:19	2019-11-22	9	[{"id_menu":6,"count":1}]	5676	delivery	5	14
15116	2019-11-22 10:00:31	2019-11-22	12	[{"id_menu":1,"count":1}]	1147	pick-up	0	12
15117	2019-11-22 10:06:55	2019-11-22	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	5678	delivery	5	22
15118	2019-11-22 10:22:45	2019-11-22	9	[{"id_menu":7,"count":1}]	5692	pick-up	0	9
15119	2019-11-22 10:22:56	2019-11-22	9	[{"id_menu":6,"count":1}]	4562	delivery	5	14
15120	2019-11-22 10:58:58	2019-11-22	14	[{"id_menu":2,"count":1}]	3656	pick-up	0	14
15121	2019-11-22 11:02:09	2019-11-22	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2052	pick-up	0	43
15122	2019-11-22 11:14:58	2019-11-22	9	[{"id_menu":6,"count":1}]	5718	delivery	5	14
15123	2019-11-22 11:57:47	2019-11-22	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	2135	pick-up	0	43
15124	2019-11-22 12:14:21	2019-11-22	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	5710	delivery	5	28
15125	2019-11-22 12:15:58	2019-11-22	14	[{"id_menu":2,"count":1}]	3059	delivery	5	19
15126	2019-11-22 12:20:03	2019-11-22	17	[{"id_menu":4,"count":1}]	2551	pick-up	0	17
15127	2019-11-22 12:56:49	2019-11-22	14	[{"id_menu":2,"count":1}]	4480	pick-up	0	14
15128	2019-11-22 13:03:35	2019-11-22	17	[{"id_menu":4,"count":1}]	5670	delivery	5	22
15129	2019-11-22 13:05:52	2019-11-22	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	5711	delivery	5	34
15130	2019-11-22 13:19:49	2019-11-22	9	[{"id_menu":7,"count":1}]	5708	delivery	5	14
15131	2019-11-22 13:22:37	2019-11-22	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	5720	delivery	5	26
15132	2019-11-22 13:26:51	2019-11-22	14	[{"id_menu":2,"count":1}]	467	pick-up	0	14
15133	2019-11-22 13:27:24	2019-11-22	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	5675	delivery	5	31
15134	2019-11-22 13:34:38	2019-11-22	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2309	pick-up	0	44
15135	2019-11-22 14:12:50	2019-11-22	14	[{"id_menu":2,"count":3}]	5717	delivery	5	19
15136	2019-11-22 14:36:57	2019-11-22	9	[{"id_menu":6,"count":2}]	5325	delivery	5	14
15137	2019-11-22 14:47:12	2019-11-22	8	[{"id_menu":5,"count":2}]	5669	delivery	5	13
15138	2019-11-22 15:14:59	2019-11-22	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5680	delivery	5	52
15139	2019-11-22 15:17:28	2019-11-22	14	[{"id_menu":2,"count":1}]	1067	pick-up	0	14
15140	2019-11-22 15:25:16	2019-11-22	9	[{"id_menu":6,"count":1}]	5693	delivery	5	14
15141	2019-11-22 15:32:12	2019-11-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	48	delivery	5	28
15142	2019-11-22 15:35:27	2019-11-22	12	[{"id_menu":3,"count":1}]	1343	pick-up	0	12
15143	2019-11-22 16:22:18	2019-11-22	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2291	delivery	5	31
15144	2019-11-22 16:36:34	2019-11-22	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	3080	pick-up	0	25
15145	2019-11-22 16:43:20	2019-11-22	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	5704	delivery	5	22
15146	2019-11-22 16:54:56	2019-11-22	9	[{"id_menu":7,"count":1}]	2606	pick-up	0	9
15147	2019-11-22 17:10:05	2019-11-22	14	[{"id_menu":2,"count":1}]	5697	delivery	5	19
15148	2019-11-22 17:20:50	2019-11-22	8	[{"id_menu":5,"count":1}]	1676	pick-up	0	8
15149	2019-11-22 17:27:55	2019-11-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2110	pick-up	0	17
15150	2019-11-22 17:28:18	2019-11-22	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	145	pick-up	0	17
15151	2019-11-22 17:36:47	2019-11-22	17	[{"id_menu":4,"count":1}]	1883	pick-up	0	17
15152	2019-11-22 17:42:09	2019-11-22	14	[{"id_menu":2,"count":2}]	2276	pick-up	0	14
15153	2019-11-22 17:50:19	2019-11-22	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1490	delivery	5	48
15154	2019-11-22 17:58:27	2019-11-22	9	[{"id_menu":6,"count":2}]	4099	pick-up	0	9
15155	2019-11-22 18:05:49	2019-11-22	12	[{"id_menu":3,"count":1}]	765	pick-up	0	12
15156	2019-11-22 18:06:18	2019-11-22	9	[{"id_menu":6,"count":2}]	4479	pick-up	0	9
15157	2019-11-22 18:07:29	2019-11-22	17	[{"id_menu":4,"count":1}]	235	pick-up	0	17
15158	2019-11-22 18:13:02	2019-11-22	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	2187	delivery	5	30
15159	2019-11-22 18:16:51	2019-11-22	8	[{"id_menu":5,"count":1}]	4477	pick-up	0	8
15160	2019-11-22 18:22:34	2019-11-22	12	[{"id_menu":3,"count":1}]	5707	delivery	5	17
15161	2019-11-22 18:25:15	2019-11-22	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2614	pick-up	0	21
15162	2019-11-22 18:28:49	2019-11-22	9	[{"id_menu":6,"count":1}]	2806	delivery	5	14
15163	2019-11-22 18:33:02	2019-11-22	9	[{"id_menu":7,"count":1}]	2251	pick-up	0	9
15164	2019-11-22 18:33:33	2019-11-22	17	[{"id_menu":4,"count":1}]	778	pick-up	0	17
15165	2019-11-22 19:17:56	2019-11-22	8	[{"id_menu":5,"count":1}]	547	delivery	5	13
15166	2019-11-22 19:37:14	2019-11-22	9	[{"id_menu":7,"count":1}]	5699	delivery	5	14
15167	2019-11-22 19:48:00	2019-11-22	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5689	delivery	5	36
15168	2019-11-22 19:50:30	2019-11-22	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	4291	pick-up	0	26
15169	2019-11-22 20:14:27	2019-11-22	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	5696	delivery	5	48
15170	2019-11-22 21:08:54	2019-11-22	8	[{"id_menu":5,"count":1}]	5698	delivery	5	13
15171	2019-11-22 21:21:47	2019-11-22	9	[{"id_menu":7,"count":1}]	3594	pick-up	0	9
15172	2019-11-22 21:24:31	2019-11-22	17	[{"id_menu":4,"count":1}]	1081	pick-up	0	17
15173	2019-11-22 21:43:45	2019-11-22	14	[{"id_menu":2,"count":1}]	821	pick-up	0	14
15174	2019-11-22 22:17:53	2019-11-22	8	[{"id_menu":5,"count":1}]	1742	pick-up	0	8
15175	2019-11-22 22:18:32	2019-11-22	12	[{"id_menu":1,"count":1}]	1953	pick-up	0	12
15176	2019-11-22 22:20:20	2019-11-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	5106	delivery	5	36
15177	2019-11-22 22:52:45	2019-11-22	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3655	pick-up	0	26
15178	2019-11-22 22:55:23	2019-11-22	12	[{"id_menu":3,"count":1}]	5687	pick-up	0	12
15179	2019-11-22 23:03:56	2019-11-22	17	[{"id_menu":4,"count":1}]	1819	pick-up	0	17
15180	2019-11-22 23:30:31	2019-11-22	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	5705	delivery	5	34
15181	2019-11-22 23:33:35	2019-11-22	12	[{"id_menu":3,"count":1}]	708	pick-up	0	12
15182	2019-11-22 23:37:53	2019-11-22	17	[{"id_menu":4,"count":1}]	3847	pick-up	0	17
15183	2019-11-22 23:42:28	2019-11-22	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1587	pick-up	0	29
15184	2019-11-22 23:45:45	2019-11-22	9	[{"id_menu":6,"count":3}]	397	delivery	5	14
15185	2019-11-22 23:46:01	2019-11-22	9	[{"id_menu":6,"count":1}]	3791	delivery	5	14
15186	2019-11-22 23:52:22	2019-11-22	9	[{"id_menu":6,"count":1}]	5709	pick-up	0	9
15187	2019-11-23 00:05:37	2019-11-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	5767	delivery	5	36
15188	2019-11-23 00:08:16	2019-11-23	17	[{"id_menu":4,"count":1}]	4823	pick-up	0	17
15189	2019-11-23 00:10:08	2019-11-23	8	[{"id_menu":5,"count":1}]	3048	pick-up	0	8
15190	2019-11-23 00:19:45	2019-11-23	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5773	delivery	5	39
15191	2019-11-23 00:28:27	2019-11-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3686	pick-up	0	17
15192	2019-11-23 00:37:29	2019-11-23	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	5732	pick-up	0	21
15193	2019-11-23 00:38:24	2019-11-23	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3293	delivery	5	26
15194	2019-11-23 00:45:57	2019-11-23	17	[{"id_menu":4,"count":1}]	1505	pick-up	0	17
15195	2019-11-23 00:47:41	2019-11-23	8	[{"id_menu":5,"count":1}]	4487	delivery	5	13
15196	2019-11-23 00:48:16	2019-11-23	14	[{"id_menu":2,"count":1}]	149	pick-up	0	14
15197	2019-11-23 00:49:04	2019-11-23	12	[{"id_menu":3,"count":1}]	3748	delivery	5	17
15198	2019-11-23 00:49:36	2019-11-23	17	[{"id_menu":4,"count":1}]	3153	pick-up	0	17
15199	2019-11-23 00:54:57	2019-11-23	12	[{"id_menu":1,"count":1}]	5755	delivery	5	17
15200	2019-11-23 00:59:40	2019-11-23	17	[{"id_menu":4,"count":1}]	5769	delivery	5	22
15201	2019-11-23 01:00:35	2019-11-23	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	5771	delivery	5	34
15202	2019-11-23 01:01:33	2019-11-23	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3052	delivery	5	30
15203	2019-11-23 01:29:33	2019-11-23	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	841	delivery	5	34
15204	2019-11-23 01:32:37	2019-11-23	12	[{"id_menu":1,"count":1}]	3309	pick-up	0	12
15205	2019-11-23 01:36:18	2019-11-23	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	5787	delivery	5	27
15206	2019-11-23 01:47:16	2019-11-23	17	[{"id_menu":4,"count":1}]	5144	pick-up	0	17
15207	2019-11-23 01:53:08	2019-11-23	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	1432	pick-up	0	35
15208	2019-11-23 02:07:10	2019-11-23	12	[{"id_menu":1,"count":1}]	5770	pick-up	0	12
15209	2019-11-23 02:07:23	2019-11-23	14	[{"id_menu":2,"count":1}]	980	pick-up	0	14
15210	2019-11-23 02:15:37	2019-11-23	14	[{"id_menu":2,"count":1}]	2611	pick-up	0	14
15211	2019-11-23 02:25:13	2019-11-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5763	delivery	5	31
15212	2019-11-23 02:30:01	2019-11-23	17	[{"id_menu":4,"count":1}]	5779	pick-up	0	17
15213	2019-11-23 02:43:09	2019-11-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3863	pick-up	0	23
15214	2019-11-23 02:57:14	2019-11-23	14	[{"id_menu":2,"count":2}]	5738	pick-up	0	14
15215	2019-11-23 02:59:08	2019-11-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5796	delivery	5	23
15216	2019-11-23 03:01:50	2019-11-23	17	[{"id_menu":4,"count":1}]	5777	delivery	5	22
15217	2019-11-23 03:07:30	2019-11-23	14	[{"id_menu":2,"count":1}]	5745	pick-up	0	14
15218	2019-11-23 03:19:18	2019-11-23	12	[{"id_menu":1,"count":1}]	2565	delivery	5	17
15219	2019-11-23 03:37:06	2019-11-23	9	[{"id_menu":6,"count":2}]	4590	pick-up	0	9
15220	2019-11-23 03:51:09	2019-11-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	5293	delivery	5	26
15221	2019-11-23 04:02:09	2019-11-23	9	[{"id_menu":6,"count":1}]	4791	delivery	5	14
15222	2019-11-23 04:03:35	2019-11-23	8	[{"id_menu":5,"count":1}]	5793	delivery	5	13
15223	2019-11-23 04:09:48	2019-11-23	12	[{"id_menu":3,"count":1}]	5742	delivery	5	17
15224	2019-11-23 04:27:14	2019-11-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	5786	delivery	5	26
15225	2019-11-23 04:55:09	2019-11-23	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3796	delivery	5	54
15226	2019-11-23 05:05:29	2019-11-23	9	[{"id_menu":6,"count":1}]	5753	pick-up	0	9
15227	2019-11-23 05:10:13	2019-11-23	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	304	pick-up	0	21
15228	2019-11-23 05:27:03	2019-11-23	9	[{"id_menu":7,"count":1}]	4495	delivery	5	14
15229	2019-11-23 05:33:33	2019-11-23	14	[{"id_menu":2,"count":1}]	5794	delivery	5	19
15230	2019-11-23 05:35:48	2019-11-23	14	[{"id_menu":2,"count":1}]	5498	pick-up	0	14
15231	2019-11-23 06:23:59	2019-11-23	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	766	delivery	5	43
15232	2019-11-23 07:01:38	2019-11-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3485	delivery	5	28
15233	2019-11-23 07:18:53	2019-11-23	17	[{"id_menu":4,"count":1}]	4643	delivery	5	22
15234	2019-11-23 07:30:16	2019-11-23	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	1925	pick-up	0	21
15235	2019-11-23 07:35:00	2019-11-23	8	[{"id_menu":5,"count":1}]	5783	pick-up	0	8
15236	2019-11-23 07:50:09	2019-11-23	12	[{"id_menu":1,"count":1}]	5750	delivery	5	17
15237	2019-11-23 07:58:24	2019-11-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	5784	delivery	5	28
15238	2019-11-23 07:59:23	2019-11-23	9	[{"id_menu":7,"count":1}]	315	pick-up	0	9
15239	2019-11-23 08:01:28	2019-11-23	14	[{"id_menu":2,"count":1}]	4862	pick-up	0	14
15240	2019-11-23 08:01:43	2019-11-23	12	[{"id_menu":3,"count":1}]	4242	pick-up	0	12
15241	2019-11-23 08:07:53	2019-11-23	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5751	delivery	5	22
15242	2019-11-23 08:25:26	2019-11-23	12	[{"id_menu":1,"count":1}]	1176	pick-up	0	12
15243	2019-11-23 08:51:05	2019-11-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5768	delivery	5	22
15244	2019-11-23 08:51:48	2019-11-23	9	[{"id_menu":6,"count":1}]	5047	pick-up	0	9
15245	2019-11-23 09:16:49	2019-11-23	9	[{"id_menu":6,"count":1}]	2150	pick-up	0	9
15246	2019-11-23 09:32:21	2019-11-23	14	[{"id_menu":2,"count":1}]	5795	pick-up	0	14
15247	2019-11-23 09:37:40	2019-11-23	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	5790	pick-up	0	20
15248	2019-11-23 09:39:36	2019-11-23	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3545	delivery	5	27
15249	2019-11-23 09:42:09	2019-11-23	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	1461	pick-up	0	40
15250	2019-11-23 09:42:29	2019-11-23	9	[{"id_menu":7,"count":1}]	760	pick-up	0	9
15251	2019-11-23 09:56:46	2019-11-23	12	[{"id_menu":1,"count":1}]	3101	delivery	5	17
15252	2019-11-23 10:01:16	2019-11-23	12	[{"id_menu":1,"count":1}]	5766	delivery	5	17
15253	2019-11-23 10:07:01	2019-11-23	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	925	delivery	5	31
15254	2019-11-23 10:11:37	2019-11-23	9	[{"id_menu":7,"count":1}]	3335	pick-up	0	9
15255	2019-11-23 10:16:57	2019-11-23	8	[{"id_menu":5,"count":1}]	5739	delivery	5	13
15256	2019-11-23 10:22:22	2019-11-23	8	[{"id_menu":5,"count":1}]	5731	delivery	5	13
15257	2019-11-23 10:34:39	2019-11-23	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	1833	delivery	5	28
15258	2019-11-23 10:36:19	2019-11-23	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	5775	delivery	5	29
15259	2019-11-23 10:46:30	2019-11-23	17	[{"id_menu":4,"count":1}]	3870	pick-up	0	17
15260	2019-11-23 11:01:13	2019-11-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	909	delivery	5	28
15261	2019-11-23 11:10:30	2019-11-23	14	[{"id_menu":2,"count":1}]	5741	delivery	5	19
15262	2019-11-23 11:12:50	2019-11-23	22	[{"id_menu":2,"count":3},{"id_menu":5,"count":1}]	5762	delivery	5	27
15263	2019-11-23 11:16:45	2019-11-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	5791	delivery	5	22
15264	2019-11-23 11:20:58	2019-11-23	9	[{"id_menu":7,"count":1}]	2858	delivery	5	14
15265	2019-11-23 11:26:50	2019-11-23	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	5310	pick-up	0	20
15266	2019-11-23 11:34:45	2019-11-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	5737	delivery	5	31
15267	2019-11-23 11:50:25	2019-11-23	14	[{"id_menu":2,"count":1}]	1670	pick-up	0	14
15268	2019-11-23 12:15:47	2019-11-23	9	[{"id_menu":7,"count":1}]	3961	pick-up	0	9
15269	2019-11-23 12:23:42	2019-11-23	17	[{"id_menu":4,"count":1}]	1352	pick-up	0	17
15270	2019-11-23 12:32:47	2019-11-23	9	[{"id_menu":7,"count":1}]	4347	delivery	5	14
15271	2019-11-23 12:36:38	2019-11-23	17	[{"id_menu":4,"count":1}]	5747	delivery	5	22
15272	2019-11-23 12:45:35	2019-11-23	14	[{"id_menu":2,"count":1}]	764	delivery	5	19
15273	2019-11-23 12:54:37	2019-11-23	17	[{"id_menu":4,"count":1}]	5764	delivery	5	22
15274	2019-11-23 12:57:29	2019-11-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	5727	delivery	5	28
15275	2019-11-23 13:11:47	2019-11-23	12	[{"id_menu":1,"count":1}]	257	pick-up	0	12
15276	2019-11-23 13:32:03	2019-11-23	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5511	delivery	5	22
15277	2019-11-23 13:34:18	2019-11-23	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1267	pick-up	0	21
15278	2019-11-23 13:38:42	2019-11-23	8	[{"id_menu":5,"count":1}]	5744	delivery	5	13
15279	2019-11-23 13:53:03	2019-11-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5778	delivery	5	23
15280	2019-11-23 13:57:43	2019-11-23	12	[{"id_menu":1,"count":1}]	5780	pick-up	0	12
15281	2019-11-23 14:33:20	2019-11-23	14	[{"id_menu":2,"count":1}]	5748	pick-up	0	14
15282	2019-11-23 14:38:01	2019-11-23	9	[{"id_menu":6,"count":1}]	5789	delivery	5	14
15283	2019-11-23 14:59:11	2019-11-23	17	[{"id_menu":4,"count":1}]	5785	delivery	5	22
15284	2019-11-23 15:04:49	2019-11-23	9	[{"id_menu":7,"count":1}]	5792	delivery	5	14
15285	2019-11-23 15:10:02	2019-11-23	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5726	delivery	5	31
15286	2019-11-23 15:14:44	2019-11-23	17	[{"id_menu":4,"count":1}]	5772	delivery	5	22
15287	2019-11-23 15:16:18	2019-11-23	8	[{"id_menu":5,"count":1}]	2729	delivery	5	13
15288	2019-11-23 15:23:11	2019-11-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3949	pick-up	0	26
15289	2019-11-23 15:25:23	2019-11-23	14	[{"id_menu":2,"count":1}]	1679	delivery	5	19
15290	2019-11-23 15:47:32	2019-11-23	12	[{"id_menu":1,"count":1}]	2446	pick-up	0	12
15291	2019-11-23 15:56:08	2019-11-23	12	[{"id_menu":1,"count":1}]	310	pick-up	0	12
15292	2019-11-23 15:58:46	2019-11-23	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5774	delivery	5	30
15293	2019-11-23 15:59:31	2019-11-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	593	pick-up	0	17
15294	2019-11-23 16:00:04	2019-11-23	12	[{"id_menu":1,"count":1}]	4943	delivery	5	17
15295	2019-11-23 16:09:53	2019-11-23	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	5746	delivery	5	22
15296	2019-11-23 16:17:04	2019-11-23	8	[{"id_menu":5,"count":1}]	5756	pick-up	0	8
15297	2019-11-23 16:17:11	2019-11-23	9	[{"id_menu":6,"count":1}]	5729	pick-up	0	9
15298	2019-11-23 16:19:53	2019-11-23	17	[{"id_menu":4,"count":1}]	1589	pick-up	0	17
15299	2019-11-23 16:23:49	2019-11-23	9	[{"id_menu":7,"count":1}]	1170	pick-up	0	9
15300	2019-11-23 16:31:38	2019-11-23	8	[{"id_menu":5,"count":1}]	5733	delivery	5	13
15301	2019-11-23 16:34:12	2019-11-23	8	[{"id_menu":5,"count":1}]	5725	delivery	5	13
15302	2019-11-23 16:35:26	2019-11-23	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	923	delivery	5	26
15303	2019-11-23 16:46:35	2019-11-23	9	[{"id_menu":7,"count":1}]	5776	delivery	5	14
15304	2019-11-23 16:54:59	2019-11-23	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":2}]	5757	delivery	5	22
15305	2019-11-23 16:56:13	2019-11-23	8	[{"id_menu":5,"count":1}]	5782	pick-up	0	8
15306	2019-11-23 16:58:37	2019-11-23	12	[{"id_menu":1,"count":1}]	2227	pick-up	0	12
15307	2019-11-23 17:03:24	2019-11-23	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	5730	delivery	5	40
15308	2019-11-23 17:22:07	2019-11-23	9	[{"id_menu":7,"count":3}]	5157	delivery	5	14
15309	2019-11-23 17:23:55	2019-11-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	1115	pick-up	0	23
15310	2019-11-23 17:31:33	2019-11-23	9	[{"id_menu":6,"count":1}]	5754	delivery	5	14
15311	2019-11-23 17:51:14	2019-11-23	8	[{"id_menu":5,"count":1}]	5752	delivery	5	13
15312	2019-11-23 17:57:44	2019-11-23	8	[{"id_menu":5,"count":1}]	5759	delivery	5	13
15313	2019-11-23 18:07:05	2019-11-23	9	[{"id_menu":7,"count":1}]	2847	pick-up	0	9
15314	2019-11-23 18:09:39	2019-11-23	14	[{"id_menu":2,"count":1}]	5736	pick-up	0	14
15315	2019-11-23 18:10:50	2019-11-23	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2689	delivery	5	30
15316	2019-11-23 18:15:24	2019-11-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	2119	delivery	5	31
15317	2019-11-23 18:26:55	2019-11-23	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	5743	delivery	5	45
15318	2019-11-23 18:30:37	2019-11-23	12	[{"id_menu":1,"count":1}]	2190	pick-up	0	12
15319	2019-11-23 18:32:12	2019-11-23	12	[{"id_menu":1,"count":1}]	2492	pick-up	0	12
15320	2019-11-23 18:38:12	2019-11-23	12	[{"id_menu":1,"count":1}]	5749	delivery	5	17
15321	2019-11-23 18:47:30	2019-11-23	12	[{"id_menu":1,"count":1}]	1334	pick-up	0	12
15322	2019-11-23 18:58:34	2019-11-23	14	[{"id_menu":2,"count":1}]	5761	delivery	5	19
15323	2019-11-23 19:13:54	2019-11-23	9	[{"id_menu":6,"count":1}]	5306	pick-up	0	9
15324	2019-11-23 19:19:04	2019-11-23	12	[{"id_menu":1,"count":1}]	4356	delivery	5	17
15325	2019-11-23 19:35:47	2019-11-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	1333	delivery	5	31
15326	2019-11-23 19:45:45	2019-11-23	9	[{"id_menu":6,"count":1}]	1241	pick-up	0	9
15327	2019-11-23 19:52:48	2019-11-23	9	[{"id_menu":6,"count":1}]	274	delivery	5	14
15328	2019-11-23 20:03:11	2019-11-23	17	[{"id_menu":4,"count":1}]	2399	pick-up	0	17
15329	2019-11-23 20:26:57	2019-11-23	9	[{"id_menu":7,"count":1}]	3825	pick-up	0	9
15330	2019-11-23 20:40:20	2019-11-23	9	[{"id_menu":7,"count":1}]	3921	pick-up	0	9
15331	2019-11-23 20:52:21	2019-11-23	12	[{"id_menu":1,"count":1}]	5735	delivery	5	17
15332	2019-11-23 20:56:53	2019-11-23	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	5740	delivery	5	25
15333	2019-11-23 21:14:35	2019-11-23	17	[{"id_menu":4,"count":1}]	2962	pick-up	0	17
15334	2019-11-23 21:17:51	2019-11-23	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	752	delivery	5	22
15335	2019-11-23 21:23:13	2019-11-23	12	[{"id_menu":3,"count":1}]	968	pick-up	0	12
15336	2019-11-23 21:28:34	2019-11-23	9	[{"id_menu":7,"count":2}]	5765	delivery	5	14
15337	2019-11-23 21:29:33	2019-11-23	9	[{"id_menu":7,"count":1}]	684	delivery	5	14
15338	2019-11-23 21:30:44	2019-11-23	8	[{"id_menu":5,"count":1}]	4368	pick-up	0	8
15339	2019-11-23 21:37:37	2019-11-23	12	[{"id_menu":1,"count":1}]	5781	delivery	5	17
15340	2019-11-23 21:38:10	2019-11-23	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5760	pick-up	0	38
15341	2019-11-23 21:53:51	2019-11-23	14	[{"id_menu":2,"count":1}]	2526	pick-up	0	14
15342	2019-11-23 21:58:05	2019-11-23	14	[{"id_menu":2,"count":1}]	3123	pick-up	0	14
15343	2019-11-23 22:11:36	2019-11-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	1314	pick-up	0	31
15344	2019-11-23 22:15:58	2019-11-23	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	158	pick-up	0	26
15345	2019-11-23 22:24:41	2019-11-23	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5788	delivery	5	45
15346	2019-11-23 22:37:46	2019-11-23	8	[{"id_menu":5,"count":1}]	3592	delivery	5	13
15347	2019-11-23 23:06:55	2019-11-23	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	4355	delivery	5	31
15348	2019-11-23 23:19:49	2019-11-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	5758	pick-up	0	26
15349	2019-11-23 23:22:58	2019-11-23	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	3369	delivery	5	35
15350	2019-11-23 23:25:07	2019-11-23	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2450	pick-up	0	26
15351	2019-11-23 23:29:56	2019-11-23	12	[{"id_menu":3,"count":1}]	3852	delivery	5	17
15352	2019-11-23 23:53:03	2019-11-23	8	[{"id_menu":5,"count":1}]	2311	pick-up	0	8
15353	2019-11-23 23:53:18	2019-11-23	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	641	delivery	5	35
15354	2019-11-24 00:00:22	2019-11-24	14	[{"id_menu":2,"count":2}]	3616	delivery	5	19
15355	2019-11-24 00:01:41	2019-11-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	73	pick-up	0	26
15356	2019-11-24 00:10:06	2019-11-24	14	[{"id_menu":2,"count":1}]	1127	delivery	5	19
15357	2019-11-24 00:16:58	2019-11-24	14	[{"id_menu":2,"count":1}]	1839	pick-up	0	14
15358	2019-11-24 00:21:30	2019-11-24	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	2228	pick-up	0	21
15359	2019-11-24 00:25:09	2019-11-24	17	[{"id_menu":5,"count":3},{"id_menu":6,"count":1}]	5078	delivery	5	22
15360	2019-11-24 00:26:25	2019-11-24	14	[{"id_menu":2,"count":1}]	5491	delivery	5	19
15361	2019-11-24 00:32:58	2019-11-24	12	[{"id_menu":1,"count":1}]	1679	pick-up	0	12
15362	2019-11-24 00:33:21	2019-11-24	8	[{"id_menu":5,"count":1}]	5832	pick-up	0	8
15363	2019-11-24 00:44:17	2019-11-24	17	[{"id_menu":4,"count":1}]	1820	delivery	5	22
15364	2019-11-24 00:44:47	2019-11-24	12	[{"id_menu":1,"count":3}]	1293	delivery	5	17
15365	2019-11-24 00:46:28	2019-11-24	9	[{"id_menu":7,"count":1}]	5834	delivery	5	14
15366	2019-11-24 00:49:08	2019-11-24	17	[{"id_menu":4,"count":1}]	5853	delivery	5	22
15367	2019-11-24 00:50:08	2019-11-24	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1076	delivery	5	26
15368	2019-11-24 00:50:42	2019-11-24	17	[{"id_menu":4,"count":2}]	3135	delivery	5	22
15369	2019-11-24 00:58:15	2019-11-24	9	[{"id_menu":7,"count":1}]	5423	delivery	5	14
15370	2019-11-24 01:18:12	2019-11-24	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2104	pick-up	0	31
15371	2019-11-24 01:48:11	2019-11-24	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5846	delivery	5	22
15372	2019-11-24 02:12:48	2019-11-24	9	[{"id_menu":6,"count":3}]	5847	delivery	5	14
15373	2019-11-24 02:15:56	2019-11-24	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2752	delivery	5	40
15374	2019-11-24 02:23:33	2019-11-24	8	[{"id_menu":5,"count":1}]	5825	pick-up	0	8
15375	2019-11-24 02:30:37	2019-11-24	17	[{"id_menu":4,"count":1}]	3752	pick-up	0	17
15376	2019-11-24 02:36:28	2019-11-24	9	[{"id_menu":6,"count":1}]	5831	delivery	5	14
15377	2019-11-24 02:37:47	2019-11-24	8	[{"id_menu":5,"count":1}]	3812	pick-up	0	8
15378	2019-11-24 02:45:55	2019-11-24	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2891	delivery	5	31
15379	2019-11-24 02:46:28	2019-11-24	17	[{"id_menu":4,"count":1}]	3675	pick-up	0	17
15380	2019-11-24 02:58:20	2019-11-24	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	3911	delivery	5	39
15381	2019-11-24 03:14:46	2019-11-24	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	5845	delivery	5	31
15382	2019-11-24 03:25:18	2019-11-24	8	[{"id_menu":5,"count":1}]	3468	delivery	5	13
15383	2019-11-24 03:30:06	2019-11-24	9	[{"id_menu":6,"count":1}]	2563	pick-up	0	9
15384	2019-11-24 03:34:41	2019-11-24	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5842	delivery	5	53
15385	2019-11-24 03:37:01	2019-11-24	12	[{"id_menu":1,"count":1}]	2526	pick-up	0	12
15386	2019-11-24 04:02:08	2019-11-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5509	delivery	5	31
15387	2019-11-24 04:08:04	2019-11-24	14	[{"id_menu":2,"count":1}]	5814	delivery	5	19
15388	2019-11-24 04:09:52	2019-11-24	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	3372	pick-up	0	21
15389	2019-11-24 04:11:48	2019-11-24	12	[{"id_menu":3,"count":1}]	2729	delivery	5	17
15390	2019-11-24 04:19:18	2019-11-24	14	[{"id_menu":2,"count":1}]	619	delivery	5	19
15391	2019-11-24 04:27:15	2019-11-24	9	[{"id_menu":6,"count":1}]	5844	delivery	5	14
15392	2019-11-24 04:29:02	2019-11-24	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4116	delivery	5	40
15393	2019-11-24 04:33:52	2019-11-24	9	[{"id_menu":7,"count":1}]	5426	pick-up	0	9
15394	2019-11-24 04:41:15	2019-11-24	9	[{"id_menu":7,"count":1}]	1353	pick-up	0	9
15395	2019-11-24 04:49:46	2019-11-24	8	[{"id_menu":5,"count":1}]	5808	pick-up	0	8
15396	2019-11-24 04:50:25	2019-11-24	14	[{"id_menu":2,"count":1}]	638	pick-up	0	14
15397	2019-11-24 04:58:01	2019-11-24	12	[{"id_menu":1,"count":1}]	2821	pick-up	0	12
15398	2019-11-24 04:59:53	2019-11-24	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1021	delivery	5	45
15399	2019-11-24 05:06:24	2019-11-24	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	1079	delivery	5	31
15400	2019-11-24 05:10:44	2019-11-24	12	[{"id_menu":3,"count":1}]	5811	pick-up	0	12
15401	2019-11-24 05:31:32	2019-11-24	14	[{"id_menu":2,"count":1}]	477	pick-up	0	14
15402	2019-11-24 05:45:31	2019-11-24	14	[{"id_menu":2,"count":1}]	5798	delivery	5	19
15403	2019-11-24 05:45:45	2019-11-24	17	[{"id_menu":4,"count":1}]	5027	pick-up	0	17
15404	2019-11-24 05:58:35	2019-11-24	12	[{"id_menu":3,"count":1}]	1088	pick-up	0	12
15405	2019-11-24 06:06:07	2019-11-24	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5855	delivery	5	43
15406	2019-11-24 06:08:30	2019-11-24	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5840	delivery	5	43
15407	2019-11-24 06:46:58	2019-11-24	12	[{"id_menu":1,"count":1}]	5837	delivery	5	17
15408	2019-11-24 06:54:31	2019-11-24	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	2555	delivery	5	37
15409	2019-11-24 06:56:27	2019-11-24	12	[{"id_menu":3,"count":1}]	4147	pick-up	0	12
15410	2019-11-24 07:18:43	2019-11-24	14	[{"id_menu":2,"count":1}]	5830	delivery	5	19
15411	2019-11-24 07:20:04	2019-11-24	9	[{"id_menu":7,"count":1}]	584	pick-up	0	9
15412	2019-11-24 07:39:01	2019-11-24	8	[{"id_menu":5,"count":1}]	29	delivery	5	13
15413	2019-11-24 07:40:23	2019-11-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4115	pick-up	0	23
15414	2019-11-24 07:51:00	2019-11-24	8	[{"id_menu":5,"count":1}]	5839	delivery	5	13
15415	2019-11-24 07:53:11	2019-11-24	14	[{"id_menu":2,"count":1}]	5810	delivery	5	19
15416	2019-11-24 07:58:42	2019-11-24	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	4218	pick-up	0	21
15417	2019-11-24 08:15:36	2019-11-24	9	[{"id_menu":7,"count":1}]	547	delivery	5	14
15418	2019-11-24 08:25:42	2019-11-24	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3007	delivery	5	22
15419	2019-11-24 08:29:08	2019-11-24	8	[{"id_menu":5,"count":1}]	5841	delivery	5	13
15420	2019-11-24 08:29:49	2019-11-24	12	[{"id_menu":3,"count":1}]	5833	delivery	5	17
15421	2019-11-24 08:29:54	2019-11-24	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	5192	delivery	5	31
15422	2019-11-24 08:32:41	2019-11-24	17	[{"id_menu":4,"count":1}]	2111	delivery	5	22
15423	2019-11-24 08:34:42	2019-11-24	17	[{"id_menu":4,"count":1}]	2980	pick-up	0	17
15424	2019-11-24 08:35:07	2019-11-24	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2352	delivery	5	27
15425	2019-11-24 08:37:26	2019-11-24	17	[{"id_menu":4,"count":1}]	5843	delivery	5	22
15426	2019-11-24 08:51:26	2019-11-24	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	3228	pick-up	0	21
15427	2019-11-24 08:58:03	2019-11-24	12	[{"id_menu":3,"count":1}]	5848	delivery	5	17
15428	2019-11-24 09:07:41	2019-11-24	9	[{"id_menu":6,"count":1}]	5856	pick-up	0	9
15429	2019-11-24 09:11:52	2019-11-24	9	[{"id_menu":7,"count":1}]	5801	delivery	5	14
15430	2019-11-24 09:12:52	2019-11-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1736	pick-up	0	23
15431	2019-11-24 09:15:36	2019-11-24	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5854	delivery	5	40
15432	2019-11-24 09:27:18	2019-11-24	14	[{"id_menu":2,"count":1}]	1012	pick-up	0	14
15433	2019-11-24 09:29:01	2019-11-24	17	[{"id_menu":4,"count":1}]	1438	delivery	5	22
15434	2019-11-24 09:31:06	2019-11-24	12	[{"id_menu":1,"count":1}]	5852	delivery	5	17
15435	2019-11-24 09:34:02	2019-11-24	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1006	delivery	5	48
15436	2019-11-24 09:47:09	2019-11-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1509	delivery	5	31
15437	2019-11-24 10:07:36	2019-11-24	12	[{"id_menu":1,"count":1}]	3158	pick-up	0	12
15438	2019-11-24 10:16:40	2019-11-24	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	5827	delivery	5	38
15439	2019-11-24 10:20:57	2019-11-24	8	[{"id_menu":5,"count":1}]	5838	delivery	5	13
15440	2019-11-24 10:29:04	2019-11-24	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4646	delivery	5	36
15441	2019-11-24 10:31:28	2019-11-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4785	delivery	5	23
15442	2019-11-24 10:39:40	2019-11-24	9	[{"id_menu":7,"count":1}]	4081	pick-up	0	9
15443	2019-11-24 10:42:20	2019-11-24	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4451	pick-up	0	39
15444	2019-11-24 10:45:09	2019-11-24	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	4875	delivery	5	26
15445	2019-11-24 10:51:08	2019-11-24	9	[{"id_menu":7,"count":2}]	988	delivery	5	14
15446	2019-11-24 11:00:54	2019-11-24	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	4192	delivery	5	31
15447	2019-11-24 11:02:09	2019-11-24	12	[{"id_menu":3,"count":1}]	5799	pick-up	0	12
15448	2019-11-24 11:20:00	2019-11-24	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2237	pick-up	0	40
15449	2019-11-24 11:31:08	2019-11-24	9	[{"id_menu":7,"count":1}]	3271	pick-up	0	9
15450	2019-11-24 11:34:55	2019-11-24	17	[{"id_menu":4,"count":1}]	5822	delivery	5	22
15451	2019-11-24 11:51:32	2019-11-24	12	[{"id_menu":3,"count":1}]	4688	pick-up	0	12
15452	2019-11-24 11:51:44	2019-11-24	12	[{"id_menu":3,"count":2}]	2308	pick-up	0	12
15453	2019-11-24 11:56:22	2019-11-24	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2572	pick-up	0	21
15454	2019-11-24 12:07:10	2019-11-24	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	4234	delivery	5	26
15455	2019-11-24 12:07:43	2019-11-24	9	[{"id_menu":7,"count":1}]	310	pick-up	0	9
15456	2019-11-24 12:12:22	2019-11-24	12	[{"id_menu":1,"count":1}]	257	pick-up	0	12
15457	2019-11-24 12:25:18	2019-11-24	9	[{"id_menu":6,"count":1}]	338	pick-up	0	9
15458	2019-11-24 12:32:17	2019-11-24	9	[{"id_menu":6,"count":1}]	5824	pick-up	0	9
15459	2019-11-24 12:36:34	2019-11-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	5095	delivery	5	28
15460	2019-11-24 12:52:00	2019-11-24	14	[{"id_menu":2,"count":1}]	1760	delivery	5	19
15461	2019-11-24 12:55:00	2019-11-24	9	[{"id_menu":6,"count":1}]	5819	delivery	5	14
15462	2019-11-24 13:08:50	2019-11-24	9	[{"id_menu":7,"count":1}]	1926	pick-up	0	9
15463	2019-11-24 13:39:14	2019-11-24	12	[{"id_menu":3,"count":1}]	4390	delivery	5	17
15464	2019-11-24 13:43:41	2019-11-24	9	[{"id_menu":6,"count":1}]	3501	pick-up	0	9
15465	2019-11-24 13:51:00	2019-11-24	14	[{"id_menu":2,"count":1}]	4479	pick-up	0	14
15466	2019-11-24 13:53:14	2019-11-24	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4173	delivery	5	31
15467	2019-11-24 14:02:37	2019-11-24	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	5806	delivery	5	36
15468	2019-11-24 14:04:15	2019-11-24	12	[{"id_menu":3,"count":1}]	140	pick-up	0	12
15469	2019-11-24 14:39:38	2019-11-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1569	pick-up	0	26
15470	2019-11-24 14:45:00	2019-11-24	9	[{"id_menu":7,"count":1}]	5835	delivery	5	14
15471	2019-11-24 14:49:29	2019-11-24	17	[{"id_menu":4,"count":1}]	5495	pick-up	0	17
15472	2019-11-24 14:52:56	2019-11-24	9	[{"id_menu":6,"count":1}]	5807	pick-up	0	9
15473	2019-11-24 14:57:39	2019-11-24	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1100	delivery	5	40
15474	2019-11-24 14:57:45	2019-11-24	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3992	delivery	5	37
15475	2019-11-24 15:10:20	2019-11-24	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	5829	delivery	5	36
15476	2019-11-24 15:14:51	2019-11-24	14	[{"id_menu":2,"count":2}]	149	delivery	5	19
15477	2019-11-24 15:19:41	2019-11-24	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	2332	delivery	5	38
15478	2019-11-24 15:28:19	2019-11-24	12	[{"id_menu":1,"count":1}]	4782	pick-up	0	12
15479	2019-11-24 15:55:36	2019-11-24	8	[{"id_menu":5,"count":1}]	172	delivery	5	13
15480	2019-11-24 16:01:43	2019-11-24	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5818	delivery	5	22
15481	2019-11-24 16:02:19	2019-11-24	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	5805	delivery	5	34
15482	2019-11-24 16:02:38	2019-11-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	5125	pick-up	0	23
15483	2019-11-24 16:03:25	2019-11-24	14	[{"id_menu":2,"count":1}]	2366	pick-up	0	14
15484	2019-11-24 16:11:55	2019-11-24	14	[{"id_menu":2,"count":1}]	356	pick-up	0	14
15485	2019-11-24 16:15:39	2019-11-24	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3621	pick-up	0	17
15486	2019-11-24 16:18:05	2019-11-24	17	[{"id_menu":4,"count":1}]	203	delivery	5	22
15487	2019-11-24 16:22:31	2019-11-24	9	[{"id_menu":6,"count":1}]	3729	delivery	5	14
15488	2019-11-24 16:24:56	2019-11-24	9	[{"id_menu":7,"count":1}]	4820	delivery	5	14
15489	2019-11-24 16:32:38	2019-11-24	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2485	pick-up	0	35
15490	2019-11-24 16:36:37	2019-11-24	8	[{"id_menu":5,"count":1}]	3352	pick-up	0	8
15491	2019-11-24 16:38:34	2019-11-24	49	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5850	delivery	5	54
15492	2019-11-24 16:39:05	2019-11-24	12	[{"id_menu":1,"count":1}]	3679	delivery	5	17
15493	2019-11-24 16:41:51	2019-11-24	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2492	delivery	5	26
15494	2019-11-24 16:43:29	2019-11-24	12	[{"id_menu":1,"count":1}]	4588	delivery	5	17
15495	2019-11-24 16:45:47	2019-11-24	12	[{"id_menu":1,"count":1}]	5804	delivery	5	17
15496	2019-11-24 16:52:52	2019-11-24	17	[{"id_menu":4,"count":1}]	2450	pick-up	0	17
15497	2019-11-24 17:03:02	2019-11-24	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1259	pick-up	0	21
15498	2019-11-24 17:08:24	2019-11-24	33	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	832	pick-up	0	33
15499	2019-11-24 17:10:24	2019-11-24	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	5802	pick-up	0	31
15500	2019-11-24 17:11:51	2019-11-24	17	[{"id_menu":4,"count":1}]	4113	delivery	5	22
15501	2019-11-24 17:18:29	2019-11-24	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	5817	delivery	5	22
15502	2019-11-24 17:19:21	2019-11-24	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3138	pick-up	0	39
15503	2019-11-24 17:19:37	2019-11-24	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2048	pick-up	0	22
15504	2019-11-24 17:20:44	2019-11-24	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	5828	pick-up	0	29
15505	2019-11-24 17:21:16	2019-11-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4612	delivery	5	31
15506	2019-11-24 17:30:50	2019-11-24	9	[{"id_menu":7,"count":1}]	5756	pick-up	0	9
15507	2019-11-24 17:32:53	2019-11-24	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	184	pick-up	0	20
15508	2019-11-24 17:34:22	2019-11-24	9	[{"id_menu":7,"count":1}]	4454	delivery	5	14
15509	2019-11-24 17:35:27	2019-11-24	14	[{"id_menu":2,"count":1}]	843	delivery	5	19
15510	2019-11-24 17:41:15	2019-11-24	9	[{"id_menu":7,"count":1}]	4983	delivery	5	14
15511	2019-11-24 17:48:27	2019-11-24	9	[{"id_menu":6,"count":1}]	5815	delivery	5	14
15512	2019-11-24 18:13:16	2019-11-24	9	[{"id_menu":6,"count":1}]	4987	pick-up	0	9
15513	2019-11-24 18:19:01	2019-11-24	14	[{"id_menu":2,"count":1}]	1111	delivery	5	19
15514	2019-11-24 18:25:15	2019-11-24	8	[{"id_menu":5,"count":1}]	2517	pick-up	0	8
15515	2019-11-24 18:31:41	2019-11-24	9	[{"id_menu":6,"count":1}]	4368	delivery	5	14
15516	2019-11-24 18:42:54	2019-11-24	14	[{"id_menu":2,"count":1}]	5061	delivery	5	19
15517	2019-11-24 18:46:18	2019-11-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4083	pick-up	0	23
15518	2019-11-24 18:53:53	2019-11-24	9	[{"id_menu":6,"count":1}]	3694	delivery	5	14
15519	2019-11-24 19:00:53	2019-11-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	890	delivery	5	22
15520	2019-11-24 19:12:43	2019-11-24	8	[{"id_menu":5,"count":1}]	1606	delivery	5	13
15521	2019-11-24 19:17:01	2019-11-24	9	[{"id_menu":7,"count":1}]	519	delivery	5	14
15522	2019-11-24 19:17:30	2019-11-24	14	[{"id_menu":2,"count":1}]	1092	delivery	5	19
15523	2019-11-24 19:19:52	2019-11-24	14	[{"id_menu":2,"count":1}]	2928	pick-up	0	14
15524	2019-11-24 19:29:30	2019-11-24	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4614	delivery	5	46
15525	2019-11-24 19:37:41	2019-11-24	9	[{"id_menu":6,"count":1}]	1877	pick-up	0	9
15526	2019-11-24 19:44:53	2019-11-24	8	[{"id_menu":5,"count":1}]	2706	pick-up	0	8
15527	2019-11-24 19:46:10	2019-11-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5821	delivery	5	28
15528	2019-11-24 20:13:11	2019-11-24	14	[{"id_menu":2,"count":1}]	1662	delivery	5	19
15529	2019-11-24 20:27:12	2019-11-24	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1445	pick-up	0	31
15530	2019-11-24 20:30:41	2019-11-24	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1810	pick-up	0	21
15531	2019-11-24 20:36:15	2019-11-24	12	[{"id_menu":1,"count":1}]	5812	pick-up	0	12
15532	2019-11-24 20:39:02	2019-11-24	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	5823	delivery	5	34
15533	2019-11-24 20:42:27	2019-11-24	12	[{"id_menu":1,"count":1}]	5797	delivery	5	17
15534	2019-11-24 20:46:05	2019-11-24	14	[{"id_menu":2,"count":1}]	3461	pick-up	0	14
15535	2019-11-24 21:14:59	2019-11-24	9	[{"id_menu":6,"count":1}]	5820	pick-up	0	9
15536	2019-11-24 21:15:46	2019-11-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5183	delivery	5	23
15537	2019-11-24 21:16:20	2019-11-24	34	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	5800	delivery	5	39
15538	2019-11-24 21:16:21	2019-11-24	9	[{"id_menu":7,"count":1}]	2081	delivery	5	14
15539	2019-11-24 21:25:31	2019-11-24	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	5826	delivery	5	31
15540	2019-11-24 21:33:40	2019-11-24	9	[{"id_menu":7,"count":2}]	2651	delivery	5	14
15541	2019-11-24 21:34:24	2019-11-24	9	[{"id_menu":6,"count":1}]	4580	delivery	5	14
15542	2019-11-24 21:40:02	2019-11-24	17	[{"id_menu":4,"count":1}]	1170	delivery	5	22
15543	2019-11-24 21:45:01	2019-11-24	12	[{"id_menu":3,"count":1}]	5803	delivery	5	17
15544	2019-11-24 21:50:47	2019-11-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3629	delivery	5	31
15545	2019-11-24 21:51:28	2019-11-24	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2638	delivery	5	45
15546	2019-11-24 21:54:56	2019-11-24	9	[{"id_menu":7,"count":1}]	5851	delivery	5	14
15547	2019-11-24 22:29:51	2019-11-24	14	[{"id_menu":2,"count":1}]	232	delivery	5	19
15548	2019-11-24 22:30:58	2019-11-24	9	[{"id_menu":7,"count":1}]	5809	delivery	5	14
15549	2019-11-24 22:36:38	2019-11-24	9	[{"id_menu":7,"count":1}]	3961	delivery	5	14
15550	2019-11-24 22:40:12	2019-11-24	17	[{"id_menu":4,"count":1}]	2561	delivery	5	22
15551	2019-11-24 22:40:14	2019-11-24	9	[{"id_menu":7,"count":1}]	5520	pick-up	0	9
15552	2019-11-24 22:44:28	2019-11-24	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1334	delivery	5	34
15553	2019-11-24 22:49:56	2019-11-24	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	5816	pick-up	0	26
15554	2019-11-24 23:00:28	2019-11-24	17	[{"id_menu":4,"count":1}]	1409	pick-up	0	17
15555	2019-11-24 23:14:59	2019-11-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5836	pick-up	0	26
15556	2019-11-24 23:16:53	2019-11-24	9	[{"id_menu":7,"count":1}]	5813	pick-up	0	9
15557	2019-11-24 23:18:47	2019-11-24	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5405	delivery	5	39
15558	2019-11-24 23:32:53	2019-11-24	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4357	delivery	5	36
15559	2019-11-24 23:34:01	2019-11-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1230	pick-up	0	23
15560	2019-11-24 23:44:19	2019-11-24	12	[{"id_menu":1,"count":1}]	5849	pick-up	0	12
15561	2019-11-25 00:33:11	2019-11-25	12	[{"id_menu":3,"count":1}]	634	delivery	5	17
15562	2019-11-25 00:45:58	2019-11-25	17	[{"id_menu":4,"count":1}]	5862	pick-up	0	17
15563	2019-11-25 01:05:52	2019-11-25	8	[{"id_menu":5,"count":1}]	5885	delivery	5	13
15564	2019-11-25 01:07:40	2019-11-25	14	[{"id_menu":2,"count":1}]	5890	pick-up	0	14
15565	2019-11-25 01:20:51	2019-11-25	12	[{"id_menu":1,"count":1}]	170	delivery	5	17
15566	2019-11-25 01:32:19	2019-11-25	14	[{"id_menu":2,"count":1}]	2022	pick-up	0	14
15567	2019-11-25 01:32:46	2019-11-25	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	165	delivery	5	35
15568	2019-11-25 02:22:15	2019-11-25	9	[{"id_menu":6,"count":1}]	2546	pick-up	0	9
15569	2019-11-25 03:15:52	2019-11-25	9	[{"id_menu":7,"count":1}]	2064	pick-up	0	9
15570	2019-11-25 03:51:51	2019-11-25	12	[{"id_menu":1,"count":1}]	4529	pick-up	0	12
15571	2019-11-25 04:05:55	2019-11-25	12	[{"id_menu":3,"count":1}]	5857	pick-up	0	12
15572	2019-11-25 04:15:57	2019-11-25	9	[{"id_menu":6,"count":1}]	2381	pick-up	0	9
15573	2019-11-25 04:24:40	2019-11-25	9	[{"id_menu":6,"count":2}]	4363	pick-up	0	9
15574	2019-11-25 04:29:12	2019-11-25	8	[{"id_menu":5,"count":1}]	1756	pick-up	0	8
15575	2019-11-25 05:07:31	2019-11-25	17	[{"id_menu":4,"count":1}]	5466	delivery	5	22
15576	2019-11-25 05:19:02	2019-11-25	9	[{"id_menu":6,"count":1}]	3678	pick-up	0	9
15577	2019-11-25 05:21:14	2019-11-25	9	[{"id_menu":6,"count":1}]	5846	delivery	5	14
15578	2019-11-25 05:27:28	2019-11-25	12	[{"id_menu":3,"count":1}]	5909	delivery	5	17
15579	2019-11-25 05:46:49	2019-11-25	9	[{"id_menu":6,"count":1}]	2457	pick-up	0	9
15580	2019-11-25 06:05:06	2019-11-25	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	54	pick-up	0	20
15581	2019-11-25 06:20:04	2019-11-25	9	[{"id_menu":7,"count":1}]	5875	pick-up	0	9
15582	2019-11-25 06:39:55	2019-11-25	9	[{"id_menu":6,"count":1}]	820	delivery	5	14
15583	2019-11-25 07:05:40	2019-11-25	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5867	delivery	5	34
15584	2019-11-25 07:10:06	2019-11-25	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	1239	pick-up	0	29
15585	2019-11-25 07:24:52	2019-11-25	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3948	pick-up	0	22
15586	2019-11-25 08:09:55	2019-11-25	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	5473	pick-up	0	31
15587	2019-11-25 08:12:39	2019-11-25	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	5866	pick-up	0	34
15588	2019-11-25 08:24:12	2019-11-25	9	[{"id_menu":7,"count":1}]	5338	delivery	5	14
15589	2019-11-25 09:06:30	2019-11-25	12	[{"id_menu":3,"count":1}]	2190	pick-up	0	12
15590	2019-11-25 09:16:30	2019-11-25	14	[{"id_menu":2,"count":1}]	2045	pick-up	0	14
15591	2019-11-25 09:28:23	2019-11-25	8	[{"id_menu":5,"count":1}]	5881	delivery	5	13
15592	2019-11-25 09:28:39	2019-11-25	33	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	5631	delivery	5	38
15593	2019-11-25 09:31:50	2019-11-25	9	[{"id_menu":6,"count":1}]	5894	delivery	5	14
15594	2019-11-25 09:48:40	2019-11-25	12	[{"id_menu":1,"count":2}]	5876	delivery	5	17
15595	2019-11-25 09:57:06	2019-11-25	14	[{"id_menu":2,"count":2}]	3828	delivery	5	19
15596	2019-11-25 09:58:38	2019-11-25	12	[{"id_menu":1,"count":1}]	3433	delivery	5	17
15597	2019-11-25 10:05:04	2019-11-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	5882	delivery	5	28
15598	2019-11-25 10:10:53	2019-11-25	8	[{"id_menu":5,"count":1}]	5873	delivery	5	13
15599	2019-11-25 10:25:21	2019-11-25	9	[{"id_menu":6,"count":1}]	491	delivery	5	14
15600	2019-11-25 10:42:21	2019-11-25	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5908	delivery	5	22
15601	2019-11-25 10:43:45	2019-11-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5901	delivery	5	31
15602	2019-11-25 10:54:53	2019-11-25	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5877	delivery	5	43
15603	2019-11-25 11:02:54	2019-11-25	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	5880	delivery	5	22
15604	2019-11-25 11:15:23	2019-11-25	12	[{"id_menu":3,"count":1}]	2570	pick-up	0	12
15605	2019-11-25 11:21:28	2019-11-25	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	5899	delivery	5	26
15606	2019-11-25 11:31:12	2019-11-25	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	2191	pick-up	0	26
15607	2019-11-25 11:38:05	2019-11-25	9	[{"id_menu":6,"count":1}]	3102	pick-up	0	9
15608	2019-11-25 11:38:38	2019-11-25	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	5878	delivery	5	40
15609	2019-11-25 11:46:02	2019-11-25	9	[{"id_menu":6,"count":1}]	4790	pick-up	0	9
15610	2019-11-25 12:01:49	2019-11-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2401	pick-up	0	17
15611	2019-11-25 12:45:21	2019-11-25	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2574	pick-up	0	48
15612	2019-11-25 12:49:50	2019-11-25	9	[{"id_menu":7,"count":1}]	1555	pick-up	0	9
15613	2019-11-25 12:54:01	2019-11-25	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5895	pick-up	0	26
15614	2019-11-25 12:55:30	2019-11-25	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	5886	delivery	5	26
15615	2019-11-25 13:17:31	2019-11-25	12	[{"id_menu":1,"count":1}]	888	pick-up	0	12
15616	2019-11-25 13:31:29	2019-11-25	17	[{"id_menu":4,"count":1}]	4296	pick-up	0	17
15617	2019-11-25 13:32:21	2019-11-25	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5897	delivery	5	40
15618	2019-11-25 14:06:46	2019-11-25	9	[{"id_menu":7,"count":1}]	3048	pick-up	0	9
15619	2019-11-25 14:16:04	2019-11-25	9	[{"id_menu":6,"count":1}]	2539	pick-up	0	9
15620	2019-11-25 14:35:42	2019-11-25	8	[{"id_menu":5,"count":1}]	5907	pick-up	0	8
15621	2019-11-25 14:53:02	2019-11-25	9	[{"id_menu":7,"count":1}]	153	pick-up	0	9
15622	2019-11-25 15:08:44	2019-11-25	17	[{"id_menu":4,"count":1}]	5879	pick-up	0	17
15623	2019-11-25 15:15:22	2019-11-25	9	[{"id_menu":6,"count":1}]	5906	delivery	5	14
15624	2019-11-25 15:19:30	2019-11-25	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	3332	pick-up	0	20
15625	2019-11-25 15:56:51	2019-11-25	17	[{"id_menu":4,"count":1}]	4782	pick-up	0	17
15626	2019-11-25 16:28:37	2019-11-25	9	[{"id_menu":7,"count":1}]	5905	delivery	5	14
15627	2019-11-25 16:44:14	2019-11-25	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	41	pick-up	0	31
15628	2019-11-25 16:44:23	2019-11-25	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	290	delivery	5	26
15629	2019-11-25 17:13:14	2019-11-25	12	[{"id_menu":1,"count":1}]	997	pick-up	0	12
15630	2019-11-25 17:25:10	2019-11-25	17	[{"id_menu":4,"count":1}]	2351	pick-up	0	17
15631	2019-11-25 18:05:54	2019-11-25	12	[{"id_menu":3,"count":1}]	5858	pick-up	0	12
15632	2019-11-25 18:31:36	2019-11-25	17	[{"id_menu":4,"count":1}]	788	pick-up	0	17
15633	2019-11-25 18:45:31	2019-11-25	8	[{"id_menu":5,"count":1}]	1269	pick-up	0	8
15634	2019-11-25 19:12:44	2019-11-25	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	5903	delivery	5	35
15635	2019-11-25 19:16:23	2019-11-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2653	pick-up	0	17
15636	2019-11-25 19:32:31	2019-11-25	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	2659	delivery	5	25
15637	2019-11-25 19:56:11	2019-11-25	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5884	delivery	5	31
15638	2019-11-25 20:05:30	2019-11-25	12	[{"id_menu":1,"count":1}]	4063	pick-up	0	12
15639	2019-11-25 20:07:40	2019-11-25	12	[{"id_menu":3,"count":1}]	2021	pick-up	0	12
15640	2019-11-25 20:24:52	2019-11-25	8	[{"id_menu":5,"count":1}]	399	pick-up	0	8
15641	2019-11-25 20:29:05	2019-11-25	12	[{"id_menu":1,"count":1}]	5174	delivery	5	17
15642	2019-11-25 20:42:48	2019-11-25	14	[{"id_menu":2,"count":1}]	1477	delivery	5	19
15643	2019-11-25 20:44:53	2019-11-25	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5900	delivery	5	30
15644	2019-11-25 20:47:20	2019-11-25	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	5891	delivery	5	34
15645	2019-11-25 21:27:16	2019-11-25	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4044	delivery	5	28
15646	2019-11-25 21:29:12	2019-11-25	9	[{"id_menu":7,"count":1}]	4834	pick-up	0	9
15647	2019-11-25 21:38:38	2019-11-25	14	[{"id_menu":2,"count":1}]	197	delivery	5	19
15648	2019-11-25 22:18:38	2019-11-25	9	[{"id_menu":6,"count":1}]	1255	pick-up	0	9
15649	2019-11-25 22:20:19	2019-11-25	12	[{"id_menu":1,"count":1}]	5892	delivery	5	17
15650	2019-11-25 22:35:53	2019-11-25	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	5910	delivery	5	23
15651	2019-11-25 22:47:08	2019-11-25	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	5188	delivery	5	22
15652	2019-11-25 22:58:51	2019-11-25	12	[{"id_menu":1,"count":1}]	178	pick-up	0	12
15653	2019-11-25 23:02:33	2019-11-25	17	[{"id_menu":4,"count":1}]	1810	pick-up	0	17
15654	2019-11-25 23:06:30	2019-11-25	12	[{"id_menu":3,"count":1}]	2980	pick-up	0	12
15655	2019-11-25 23:14:27	2019-11-25	9	[{"id_menu":7,"count":1}]	2003	pick-up	0	9
15656	2019-11-25 23:22:54	2019-11-25	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4309	pick-up	0	29
15657	2019-11-25 23:43:27	2019-11-25	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	5037	delivery	5	40
15658	2019-11-25 23:49:24	2019-11-25	9	[{"id_menu":7,"count":1}]	4183	delivery	5	14
15659	2019-11-25 23:55:14	2019-11-25	8	[{"id_menu":5,"count":1}]	5868	delivery	5	13
15660	2019-11-26 00:12:35	2019-11-26	9	[{"id_menu":7,"count":2}]	4181	delivery	5	14
15661	2019-11-26 00:27:58	2019-11-26	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	5931	delivery	5	29
15662	2019-11-26 00:51:45	2019-11-26	12	[{"id_menu":3,"count":1}]	5916	delivery	5	17
15663	2019-11-26 01:16:56	2019-11-26	9	[{"id_menu":6,"count":1}]	3868	pick-up	0	9
15664	2019-11-26 01:49:06	2019-11-26	9	[{"id_menu":7,"count":1}]	3779	delivery	5	14
15665	2019-11-26 01:50:05	2019-11-26	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	5915	delivery	5	31
15666	2019-11-26 02:01:40	2019-11-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2882	delivery	5	31
15667	2019-11-26 02:36:39	2019-11-26	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5948	delivery	5	55
15668	2019-11-26 02:51:17	2019-11-26	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5918	delivery	5	42
15669	2019-11-26 02:58:52	2019-11-26	14	[{"id_menu":2,"count":1}]	627	pick-up	0	14
15670	2019-11-26 03:01:16	2019-11-26	14	[{"id_menu":2,"count":1}]	5925	delivery	5	19
15671	2019-11-26 03:12:20	2019-11-26	9	[{"id_menu":7,"count":1}]	5938	delivery	5	14
15672	2019-11-26 03:17:42	2019-11-26	12	[{"id_menu":3,"count":1}]	5953	delivery	5	17
15673	2019-11-26 03:31:44	2019-11-26	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1143	pick-up	0	32
15674	2019-11-26 03:34:26	2019-11-26	9	[{"id_menu":6,"count":1}]	5928	delivery	5	14
15675	2019-11-26 03:39:47	2019-11-26	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	680	delivery	5	31
15676	2019-11-26 03:57:17	2019-11-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5912	delivery	5	22
15677	2019-11-26 04:05:51	2019-11-26	12	[{"id_menu":1,"count":1}]	629	delivery	5	17
15678	2019-11-26 04:09:30	2019-11-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	5954	delivery	5	28
15679	2019-11-26 04:12:20	2019-11-26	12	[{"id_menu":1,"count":1}]	1174	pick-up	0	12
15680	2019-11-26 06:16:39	2019-11-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	5456	delivery	5	26
15681	2019-11-26 06:46:56	2019-11-26	17	[{"id_menu":4,"count":1}]	3652	pick-up	0	17
15682	2019-11-26 07:00:35	2019-11-26	9	[{"id_menu":6,"count":1}]	2313	pick-up	0	9
15683	2019-11-26 07:04:40	2019-11-26	9	[{"id_menu":6,"count":1}]	5914	delivery	5	14
15684	2019-11-26 07:37:30	2019-11-26	17	[{"id_menu":4,"count":1}]	740	pick-up	0	17
15685	2019-11-26 07:39:36	2019-11-26	9	[{"id_menu":7,"count":1}]	5072	delivery	5	14
15686	2019-11-26 07:44:28	2019-11-26	9	[{"id_menu":6,"count":1}]	3706	pick-up	0	9
15687	2019-11-26 08:00:50	2019-11-26	8	[{"id_menu":5,"count":1}]	5106	delivery	5	13
15688	2019-11-26 08:10:52	2019-11-26	14	[{"id_menu":2,"count":1}]	1244	pick-up	0	14
15689	2019-11-26 08:26:54	2019-11-26	17	[{"id_menu":4,"count":1}]	2026	pick-up	0	17
15690	2019-11-26 08:36:59	2019-11-26	9	[{"id_menu":6,"count":1}]	4184	pick-up	0	9
15691	2019-11-26 08:42:20	2019-11-26	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4108	delivery	5	26
15692	2019-11-26 08:43:10	2019-11-26	14	[{"id_menu":2,"count":1}]	5962	pick-up	0	14
15693	2019-11-26 08:45:25	2019-11-26	9	[{"id_menu":6,"count":2}]	5922	pick-up	0	9
15694	2019-11-26 08:50:59	2019-11-26	12	[{"id_menu":3,"count":1}]	2540	pick-up	0	12
15695	2019-11-26 09:05:32	2019-11-26	17	[{"id_menu":4,"count":2}]	5292	pick-up	0	17
15696	2019-11-26 09:10:18	2019-11-26	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	232	delivery	5	31
15697	2019-11-26 09:32:53	2019-11-26	8	[{"id_menu":5,"count":1}]	5939	pick-up	0	8
15698	2019-11-26 09:40:05	2019-11-26	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	5941	pick-up	0	35
15699	2019-11-26 09:44:31	2019-11-26	9	[{"id_menu":6,"count":1}]	5930	delivery	5	14
15700	2019-11-26 09:52:42	2019-11-26	9	[{"id_menu":7,"count":1}]	461	delivery	5	14
15701	2019-11-26 10:11:16	2019-11-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":3}]	3438	delivery	5	28
15702	2019-11-26 10:30:39	2019-11-26	12	[{"id_menu":1,"count":1}]	2708	pick-up	0	12
15703	2019-11-26 10:36:24	2019-11-26	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2917	pick-up	0	35
15704	2019-11-26 10:38:28	2019-11-26	9	[{"id_menu":6,"count":1}]	377	pick-up	0	9
15705	2019-11-26 10:46:40	2019-11-26	8	[{"id_menu":5,"count":1}]	1104	pick-up	0	8
15706	2019-11-26 10:58:06	2019-11-26	17	[{"id_menu":4,"count":1}]	5936	delivery	5	22
15707	2019-11-26 11:06:48	2019-11-26	12	[{"id_menu":1,"count":1}]	5950	delivery	5	17
15708	2019-11-26 11:07:58	2019-11-26	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	5875	delivery	5	39
15709	2019-11-26 11:12:10	2019-11-26	9	[{"id_menu":7,"count":2}]	887	delivery	5	14
15710	2019-11-26 11:23:02	2019-11-26	12	[{"id_menu":3,"count":1}]	2590	pick-up	0	12
15711	2019-11-26 11:47:06	2019-11-26	17	[{"id_menu":4,"count":1}]	1369	delivery	5	22
15712	2019-11-26 12:02:24	2019-11-26	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	2958	delivery	5	26
15713	2019-11-26 12:31:23	2019-11-26	12	[{"id_menu":3,"count":1}]	201	delivery	5	17
15714	2019-11-26 12:39:59	2019-11-26	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	5923	delivery	5	26
15715	2019-11-26 12:57:15	2019-11-26	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	5926	pick-up	0	21
15716	2019-11-26 13:07:30	2019-11-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1255	pick-up	0	18
15717	2019-11-26 13:55:30	2019-11-26	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1116	pick-up	0	31
15718	2019-11-26 14:11:33	2019-11-26	9	[{"id_menu":6,"count":1}]	5911	delivery	5	14
15719	2019-11-26 14:23:22	2019-11-26	14	[{"id_menu":2,"count":2}]	5963	delivery	5	19
15720	2019-11-26 14:24:59	2019-11-26	9	[{"id_menu":6,"count":1}]	5965	pick-up	0	9
15721	2019-11-26 14:27:23	2019-11-26	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	4281	delivery	5	26
15722	2019-11-26 14:29:13	2019-11-26	14	[{"id_menu":2,"count":1}]	5919	delivery	5	19
15723	2019-11-26 14:49:46	2019-11-26	9	[{"id_menu":6,"count":1}]	2468	delivery	5	14
15724	2019-11-26 14:55:29	2019-11-26	8	[{"id_menu":5,"count":1}]	1713	pick-up	0	8
15725	2019-11-26 15:11:30	2019-11-26	9	[{"id_menu":7,"count":2}]	1082	pick-up	0	9
15726	2019-11-26 15:37:38	2019-11-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2472	pick-up	0	18
15727	2019-11-26 15:43:09	2019-11-26	8	[{"id_menu":5,"count":1}]	4682	pick-up	0	8
15728	2019-11-26 16:15:11	2019-11-26	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	150	pick-up	0	21
15729	2019-11-26 16:19:50	2019-11-26	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	5848	delivery	5	31
15730	2019-11-26 16:23:35	2019-11-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	5937	delivery	5	26
15731	2019-11-26 16:48:03	2019-11-26	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	5952	delivery	5	34
15732	2019-11-26 17:02:43	2019-11-26	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	1044	pick-up	0	33
15733	2019-11-26 17:23:35	2019-11-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5934	delivery	5	22
15734	2019-11-26 17:32:48	2019-11-26	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	5947	delivery	5	36
15735	2019-11-26 17:47:14	2019-11-26	14	[{"id_menu":2,"count":1}]	5945	pick-up	0	14
15736	2019-11-26 18:13:28	2019-11-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5935	delivery	5	28
15737	2019-11-26 18:16:00	2019-11-26	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4414	pick-up	0	41
15738	2019-11-26 18:22:34	2019-11-26	14	[{"id_menu":2,"count":1}]	5940	delivery	5	19
15739	2019-11-26 18:51:56	2019-11-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2101	pick-up	0	23
15740	2019-11-26 19:33:33	2019-11-26	12	[{"id_menu":3,"count":1}]	545	delivery	5	17
15741	2019-11-26 19:49:22	2019-11-26	17	[{"id_menu":4,"count":1}]	746	pick-up	0	17
15742	2019-11-26 19:50:57	2019-11-26	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4279	pick-up	0	47
15743	2019-11-26 20:11:56	2019-11-26	9	[{"id_menu":7,"count":1}]	2799	pick-up	0	9
15744	2019-11-26 20:13:33	2019-11-26	9	[{"id_menu":6,"count":1}]	2452	delivery	5	14
15745	2019-11-26 20:29:38	2019-11-26	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4794	delivery	5	30
15746	2019-11-26 20:53:24	2019-11-26	12	[{"id_menu":3,"count":1}]	5596	delivery	5	17
15747	2019-11-26 21:06:30	2019-11-26	8	[{"id_menu":5,"count":1}]	5957	delivery	5	13
15748	2019-11-26 21:30:53	2019-11-26	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3674	pick-up	0	31
15749	2019-11-26 22:11:07	2019-11-26	8	[{"id_menu":5,"count":1}]	5961	delivery	5	13
15750	2019-11-26 22:25:04	2019-11-26	14	[{"id_menu":2,"count":2}]	5956	pick-up	0	14
15751	2019-11-26 22:38:14	2019-11-26	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	5929	delivery	5	23
15752	2019-11-26 22:59:37	2019-11-26	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1212	pick-up	0	31
15753	2019-11-26 23:58:38	2019-11-26	17	[{"id_menu":4,"count":1}]	757	delivery	5	22
15754	2019-11-27 00:14:47	2019-11-27	12	[{"id_menu":3,"count":1}]	4319	delivery	5	17
15755	2019-11-27 00:44:29	2019-11-27	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1211	pick-up	0	25
15756	2019-11-27 00:45:22	2019-11-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4772	delivery	5	28
15757	2019-11-27 00:58:47	2019-11-27	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	2624	delivery	5	26
15758	2019-11-27 01:48:05	2019-11-27	17	[{"id_menu":4,"count":1}]	2947	pick-up	0	17
15759	2019-11-27 01:50:37	2019-11-27	9	[{"id_menu":6,"count":1}]	3949	delivery	5	14
15760	2019-11-27 02:06:15	2019-11-27	17	[{"id_menu":4,"count":1}]	2867	pick-up	0	17
15761	2019-11-27 02:10:21	2019-11-27	9	[{"id_menu":7,"count":1}]	626	pick-up	0	9
15762	2019-11-27 02:18:03	2019-11-27	17	[{"id_menu":4,"count":2}]	6006	delivery	5	22
15763	2019-11-27 02:18:42	2019-11-27	9	[{"id_menu":7,"count":2}]	5989	delivery	5	14
15764	2019-11-27 02:26:23	2019-11-27	9	[{"id_menu":7,"count":1}]	5982	delivery	5	14
15765	2019-11-27 02:30:18	2019-11-27	17	[{"id_menu":4,"count":1}]	88	pick-up	0	17
15766	2019-11-27 02:30:41	2019-11-27	8	[{"id_menu":5,"count":1}]	6009	pick-up	0	8
15767	2019-11-27 02:31:14	2019-11-27	17	[{"id_menu":4,"count":1}]	3129	delivery	5	22
15768	2019-11-27 02:37:35	2019-11-27	9	[{"id_menu":7,"count":1}]	1914	delivery	5	14
15769	2019-11-27 02:40:33	2019-11-27	14	[{"id_menu":2,"count":1}]	5979	delivery	5	19
15770	2019-11-27 02:40:52	2019-11-27	9	[{"id_menu":6,"count":1}]	3111	delivery	5	14
15771	2019-11-27 02:59:47	2019-11-27	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2778	delivery	5	45
15772	2019-11-27 03:07:12	2019-11-27	12	[{"id_menu":3,"count":1}]	6004	pick-up	0	12
15773	2019-11-27 03:07:18	2019-11-27	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4896	delivery	5	27
15774	2019-11-27 03:08:15	2019-11-27	9	[{"id_menu":7,"count":1}]	5094	delivery	5	14
15775	2019-11-27 03:42:20	2019-11-27	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2748	delivery	5	40
15776	2019-11-27 03:48:30	2019-11-27	9	[{"id_menu":7,"count":1}]	6005	delivery	5	14
15777	2019-11-27 03:58:49	2019-11-27	12	[{"id_menu":1,"count":1}]	5149	pick-up	0	12
15778	2019-11-27 04:03:05	2019-11-27	9	[{"id_menu":6,"count":1}]	5968	delivery	5	14
15779	2019-11-27 04:14:52	2019-11-27	9	[{"id_menu":6,"count":1}]	6002	pick-up	0	9
15780	2019-11-27 04:18:26	2019-11-27	17	[{"id_menu":4,"count":1}]	5981	delivery	5	22
15781	2019-11-27 04:42:57	2019-11-27	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	1933	pick-up	0	35
15782	2019-11-27 05:09:28	2019-11-27	9	[{"id_menu":6,"count":1}]	4728	delivery	5	14
15783	2019-11-27 05:13:03	2019-11-27	12	[{"id_menu":1,"count":1}]	3971	pick-up	0	12
15784	2019-11-27 05:30:25	2019-11-27	9	[{"id_menu":7,"count":1}]	1093	delivery	5	14
15785	2019-11-27 05:37:27	2019-11-27	9	[{"id_menu":7,"count":1}]	6007	delivery	5	14
15786	2019-11-27 05:39:16	2019-11-27	9	[{"id_menu":6,"count":1}]	6003	pick-up	0	9
15787	2019-11-27 05:45:58	2019-11-27	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	2729	delivery	5	22
15788	2019-11-27 05:56:41	2019-11-27	9	[{"id_menu":6,"count":1}]	2630	pick-up	0	9
15789	2019-11-27 06:06:01	2019-11-27	8	[{"id_menu":5,"count":1}]	5974	delivery	5	13
15790	2019-11-27 06:12:38	2019-11-27	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5763	delivery	5	39
15791	2019-11-27 07:10:37	2019-11-27	17	[{"id_menu":4,"count":1}]	5978	delivery	5	22
15792	2019-11-27 07:10:56	2019-11-27	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5992	delivery	5	45
15793	2019-11-27 07:25:44	2019-11-27	12	[{"id_menu":1,"count":1}]	5969	delivery	5	17
15794	2019-11-27 07:50:39	2019-11-27	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4132	pick-up	0	25
15795	2019-11-27 08:08:02	2019-11-27	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	3621	delivery	5	43
15796	2019-11-27 08:13:35	2019-11-27	17	[{"id_menu":4,"count":1}]	1147	delivery	5	22
15797	2019-11-27 08:40:22	2019-11-27	9	[{"id_menu":6,"count":1}]	2082	pick-up	0	9
15798	2019-11-27 08:46:40	2019-11-27	9	[{"id_menu":6,"count":1}]	5999	delivery	5	14
15799	2019-11-27 08:51:04	2019-11-27	17	[{"id_menu":4,"count":1}]	4985	pick-up	0	17
15800	2019-11-27 08:54:38	2019-11-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1819	pick-up	0	31
15801	2019-11-27 09:06:26	2019-11-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4436	pick-up	0	23
15802	2019-11-27 09:40:45	2019-11-27	9	[{"id_menu":7,"count":1}]	6011	pick-up	0	9
15803	2019-11-27 09:48:26	2019-11-27	14	[{"id_menu":2,"count":1}]	2232	delivery	5	19
15804	2019-11-27 09:50:24	2019-11-27	17	[{"id_menu":4,"count":1}]	2401	pick-up	0	17
15805	2019-11-27 09:54:26	2019-11-27	17	[{"id_menu":4,"count":1}]	5998	delivery	5	22
15806	2019-11-27 10:14:42	2019-11-27	8	[{"id_menu":5,"count":1}]	4578	pick-up	0	8
15807	2019-11-27 10:16:25	2019-11-27	17	[{"id_menu":4,"count":1}]	5520	pick-up	0	17
15808	2019-11-27 10:27:59	2019-11-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6008	delivery	5	23
15809	2019-11-27 10:30:22	2019-11-27	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4792	delivery	5	30
15810	2019-11-27 10:40:17	2019-11-27	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	236	pick-up	0	22
15811	2019-11-27 10:42:55	2019-11-27	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	209	pick-up	0	26
15812	2019-11-27 10:46:12	2019-11-27	17	[{"id_menu":4,"count":1}]	1963	pick-up	0	17
15813	2019-11-27 10:54:18	2019-11-27	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4459	delivery	5	39
15814	2019-11-27 11:23:10	2019-11-27	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	560	delivery	5	34
15815	2019-11-27 11:29:46	2019-11-27	8	[{"id_menu":5,"count":1}]	6017	delivery	5	13
15816	2019-11-27 11:33:52	2019-11-27	17	[{"id_menu":4,"count":1}]	638	pick-up	0	17
15817	2019-11-27 11:56:13	2019-11-27	17	[{"id_menu":4,"count":1}]	6010	delivery	5	22
15818	2019-11-27 11:59:40	2019-11-27	8	[{"id_menu":5,"count":1}]	6014	delivery	5	13
15819	2019-11-27 12:02:56	2019-11-27	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	6013	delivery	5	31
15820	2019-11-27 12:05:43	2019-11-27	8	[{"id_menu":5,"count":1}]	850	pick-up	0	8
15821	2019-11-27 12:15:25	2019-11-27	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	66	delivery	5	26
15822	2019-11-27 12:16:06	2019-11-27	12	[{"id_menu":1,"count":1}]	5971	pick-up	0	12
15823	2019-11-27 12:39:59	2019-11-27	17	[{"id_menu":4,"count":1}]	1201	pick-up	0	17
15824	2019-11-27 12:50:41	2019-11-27	8	[{"id_menu":5,"count":1}]	5994	delivery	5	13
15825	2019-11-27 12:54:46	2019-11-27	9	[{"id_menu":7,"count":1}]	5993	delivery	5	14
15826	2019-11-27 13:10:41	2019-11-27	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	6018	delivery	5	27
15827	2019-11-27 13:14:36	2019-11-27	17	[{"id_menu":4,"count":1}]	5817	delivery	5	22
15828	2019-11-27 13:34:21	2019-11-27	9	[{"id_menu":7,"count":1}]	5990	delivery	5	14
15829	2019-11-27 13:37:33	2019-11-27	9	[{"id_menu":6,"count":1}]	5991	delivery	5	14
15830	2019-11-27 13:41:41	2019-11-27	9	[{"id_menu":6,"count":1}]	2520	pick-up	0	9
15831	2019-11-27 14:16:33	2019-11-27	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5930	delivery	5	37
15832	2019-11-27 14:26:29	2019-11-27	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4116	delivery	5	27
15833	2019-11-27 14:29:18	2019-11-27	14	[{"id_menu":2,"count":1}]	2599	delivery	5	19
15834	2019-11-27 14:30:56	2019-11-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	5977	delivery	5	28
15835	2019-11-27 14:39:28	2019-11-27	12	[{"id_menu":1,"count":1}]	233	delivery	5	17
15836	2019-11-27 14:56:35	2019-11-27	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	5983	delivery	5	40
15837	2019-11-27 15:23:03	2019-11-27	14	[{"id_menu":2,"count":1}]	3168	delivery	5	19
15838	2019-11-27 15:28:42	2019-11-27	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	1244	delivery	5	43
15839	2019-11-27 15:34:03	2019-11-27	9	[{"id_menu":6,"count":1}]	5985	delivery	5	14
15840	2019-11-27 15:40:24	2019-11-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5996	pick-up	0	23
15841	2019-11-27 15:43:54	2019-11-27	9	[{"id_menu":7,"count":1}]	4356	pick-up	0	9
15842	2019-11-27 15:50:17	2019-11-27	12	[{"id_menu":1,"count":2}]	6012	delivery	5	17
15843	2019-11-27 15:59:23	2019-11-27	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	3123	pick-up	0	20
15844	2019-11-27 16:05:19	2019-11-27	14	[{"id_menu":2,"count":1}]	3242	pick-up	0	14
15845	2019-11-27 16:25:54	2019-11-27	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	5984	delivery	5	22
15846	2019-11-27 16:27:05	2019-11-27	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1800	pick-up	0	26
15847	2019-11-27 16:36:25	2019-11-27	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	5987	delivery	5	26
15848	2019-11-27 17:07:49	2019-11-27	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3473	delivery	5	55
15849	2019-11-27 17:11:03	2019-11-27	17	[{"id_menu":4,"count":1}]	361	delivery	5	22
15850	2019-11-27 17:11:25	2019-11-27	9	[{"id_menu":6,"count":1}]	487	delivery	5	14
15851	2019-11-27 17:14:08	2019-11-27	9	[{"id_menu":7,"count":1}]	1258	pick-up	0	9
15852	2019-11-27 17:14:23	2019-11-27	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1376	pick-up	0	29
15853	2019-11-27 17:24:10	2019-11-27	8	[{"id_menu":5,"count":1}]	5966	pick-up	0	8
15854	2019-11-27 17:26:05	2019-11-27	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3736	delivery	5	27
15855	2019-11-27 17:32:29	2019-11-27	9	[{"id_menu":7,"count":1}]	149	pick-up	0	9
15856	2019-11-27 17:36:23	2019-11-27	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	5986	delivery	5	26
15857	2019-11-27 17:40:06	2019-11-27	9	[{"id_menu":6,"count":1}]	4117	delivery	5	14
15858	2019-11-27 18:03:24	2019-11-27	8	[{"id_menu":5,"count":1}]	4100	delivery	5	13
15859	2019-11-27 18:04:43	2019-11-27	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	5967	delivery	5	26
15860	2019-11-27 18:09:49	2019-11-27	14	[{"id_menu":2,"count":1}]	5466	pick-up	0	14
15861	2019-11-27 18:23:07	2019-11-27	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	6015	delivery	5	25
15862	2019-11-27 19:16:09	2019-11-27	12	[{"id_menu":3,"count":1}]	349	pick-up	0	12
15863	2019-11-27 19:31:54	2019-11-27	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5995	pick-up	0	26
15864	2019-11-27 19:37:51	2019-11-27	14	[{"id_menu":2,"count":1}]	5430	delivery	5	19
15865	2019-11-27 19:47:10	2019-11-27	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	4695	pick-up	0	43
15866	2019-11-27 19:54:19	2019-11-27	9	[{"id_menu":6,"count":1}]	1583	pick-up	0	9
15867	2019-11-27 19:59:38	2019-11-27	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1409	delivery	5	28
15868	2019-11-27 20:06:06	2019-11-27	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5975	delivery	5	37
15869	2019-11-27 20:12:53	2019-11-27	14	[{"id_menu":2,"count":1}]	547	pick-up	0	14
15870	2019-11-27 20:16:08	2019-11-27	14	[{"id_menu":2,"count":1}]	5976	delivery	5	19
15871	2019-11-27 20:21:35	2019-11-27	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1154	pick-up	0	17
15872	2019-11-27 20:23:43	2019-11-27	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	113	pick-up	0	21
15873	2019-11-27 20:35:14	2019-11-27	12	[{"id_menu":3,"count":2}]	5886	delivery	5	17
15874	2019-11-27 20:44:39	2019-11-27	14	[{"id_menu":2,"count":1}]	2530	delivery	5	19
15875	2019-11-27 20:47:31	2019-11-27	9	[{"id_menu":6,"count":1}]	2171	pick-up	0	9
15876	2019-11-27 21:17:14	2019-11-27	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	5972	pick-up	0	29
15877	2019-11-27 22:13:11	2019-11-27	14	[{"id_menu":2,"count":1}]	4943	pick-up	0	14
15878	2019-11-27 22:18:52	2019-11-27	9	[{"id_menu":6,"count":1}]	5758	pick-up	0	9
15879	2019-11-27 23:21:22	2019-11-27	9	[{"id_menu":6,"count":1}]	270	pick-up	0	9
15880	2019-11-27 23:32:05	2019-11-27	8	[{"id_menu":5,"count":2}]	1924	pick-up	0	8
15881	2019-11-27 23:40:56	2019-11-27	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	5997	delivery	5	26
15882	2019-11-28 00:10:30	2019-11-28	17	[{"id_menu":4,"count":2}]	3620	pick-up	0	17
15883	2019-11-28 00:13:40	2019-11-28	14	[{"id_menu":2,"count":1}]	79	pick-up	0	14
15884	2019-11-28 00:20:19	2019-11-28	12	[{"id_menu":1,"count":1}]	1562	pick-up	0	12
15885	2019-11-28 00:35:38	2019-11-28	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6034	delivery	5	51
15886	2019-11-28 00:40:35	2019-11-28	12	[{"id_menu":1,"count":1}]	3417	delivery	5	17
15887	2019-11-28 00:53:43	2019-11-28	17	[{"id_menu":4,"count":2}]	2253	pick-up	0	17
15888	2019-11-28 01:12:44	2019-11-28	12	[{"id_menu":3,"count":1}]	3634	pick-up	0	12
15889	2019-11-28 01:22:41	2019-11-28	12	[{"id_menu":3,"count":1}]	6073	delivery	5	17
15890	2019-11-28 01:28:24	2019-11-28	9	[{"id_menu":6,"count":1}]	6033	pick-up	0	9
15891	2019-11-28 01:41:27	2019-11-28	12	[{"id_menu":1,"count":1}]	330	pick-up	0	12
15892	2019-11-28 01:53:09	2019-11-28	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	4747	pick-up	0	21
15893	2019-11-28 01:53:23	2019-11-28	12	[{"id_menu":3,"count":1}]	6021	delivery	5	17
15894	2019-11-28 01:58:16	2019-11-28	14	[{"id_menu":2,"count":1}]	1659	pick-up	0	14
15895	2019-11-28 02:09:21	2019-11-28	12	[{"id_menu":1,"count":1}]	3529	delivery	5	17
15896	2019-11-28 02:10:56	2019-11-28	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	3266	delivery	5	27
15897	2019-11-28 02:11:47	2019-11-28	12	[{"id_menu":3,"count":1}]	5205	delivery	5	17
15898	2019-11-28 02:12:13	2019-11-28	12	[{"id_menu":3,"count":1}]	3940	pick-up	0	12
15899	2019-11-28 02:12:14	2019-11-28	9	[{"id_menu":7,"count":1}]	4610	delivery	5	14
15900	2019-11-28 02:12:23	2019-11-28	12	[{"id_menu":1,"count":1}]	1267	pick-up	0	12
15901	2019-11-28 02:12:55	2019-11-28	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3101	delivery	5	51
15902	2019-11-28 02:18:27	2019-11-28	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	6066	delivery	5	46
15903	2019-11-28 02:19:21	2019-11-28	43	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	6054	delivery	5	48
15904	2019-11-28 02:24:05	2019-11-28	9	[{"id_menu":7,"count":1}]	5387	delivery	5	14
15905	2019-11-28 02:24:17	2019-11-28	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6058	delivery	5	31
15906	2019-11-28 02:29:23	2019-11-28	14	[{"id_menu":2,"count":1}]	4049	pick-up	0	14
15907	2019-11-28 02:54:57	2019-11-28	14	[{"id_menu":2,"count":1}]	356	pick-up	0	14
15908	2019-11-28 03:02:26	2019-11-28	9	[{"id_menu":7,"count":1}]	2082	pick-up	0	9
15909	2019-11-28 03:35:42	2019-11-28	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	4962	delivery	5	31
15910	2019-11-28 03:36:38	2019-11-28	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	970	pick-up	0	32
15911	2019-11-28 03:37:18	2019-11-28	17	[{"id_menu":4,"count":1}]	2081	delivery	5	22
15912	2019-11-28 03:40:23	2019-11-28	17	[{"id_menu":4,"count":1}]	6075	delivery	5	22
15913	2019-11-28 03:44:50	2019-11-28	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3588	delivery	5	44
15914	2019-11-28 04:03:57	2019-11-28	9	[{"id_menu":7,"count":2}]	6035	delivery	5	14
15915	2019-11-28 04:06:04	2019-11-28	17	[{"id_menu":4,"count":1}]	3005	pick-up	0	17
15916	2019-11-28 04:10:48	2019-11-28	9	[{"id_menu":6,"count":1}]	6071	delivery	5	14
15917	2019-11-28 04:28:03	2019-11-28	17	[{"id_menu":4,"count":1}]	6043	pick-up	0	17
15918	2019-11-28 04:44:54	2019-11-28	8	[{"id_menu":5,"count":1}]	6061	pick-up	0	8
15919	2019-11-28 04:46:38	2019-11-28	9	[{"id_menu":7,"count":1}]	6070	delivery	5	14
15920	2019-11-28 05:09:32	2019-11-28	9	[{"id_menu":7,"count":1}]	6044	delivery	5	14
15921	2019-11-28 05:21:17	2019-11-28	17	[{"id_menu":4,"count":1}]	177	pick-up	0	17
15922	2019-11-28 05:22:34	2019-11-28	12	[{"id_menu":3,"count":1}]	6031	delivery	5	17
15923	2019-11-28 05:25:00	2019-11-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	6069	delivery	5	28
15924	2019-11-28 05:32:08	2019-11-28	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4306	delivery	5	31
15925	2019-11-28 05:32:51	2019-11-28	9	[{"id_menu":6,"count":1}]	4782	pick-up	0	9
15926	2019-11-28 06:23:04	2019-11-28	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6059	delivery	5	48
15927	2019-11-28 06:36:25	2019-11-28	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	196	pick-up	0	31
15928	2019-11-28 07:06:56	2019-11-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3219	pick-up	0	17
15929	2019-11-28 07:12:47	2019-11-28	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	6057	delivery	5	27
15930	2019-11-28 07:14:59	2019-11-28	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6037	pick-up	0	43
15931	2019-11-28 07:15:34	2019-11-28	14	[{"id_menu":2,"count":2}]	1229	pick-up	0	14
15932	2019-11-28 07:21:36	2019-11-28	14	[{"id_menu":2,"count":1}]	2715	pick-up	0	14
15933	2019-11-28 08:18:53	2019-11-28	12	[{"id_menu":1,"count":1}]	1544	pick-up	0	12
15934	2019-11-28 08:34:47	2019-11-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	6022	delivery	5	22
15935	2019-11-28 08:52:55	2019-11-28	17	[{"id_menu":4,"count":1}]	83	pick-up	0	17
15936	2019-11-28 08:56:07	2019-11-28	12	[{"id_menu":1,"count":1}]	2575	pick-up	0	12
15937	2019-11-28 08:59:04	2019-11-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4233	delivery	5	28
15938	2019-11-28 08:59:06	2019-11-28	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	5966	pick-up	0	21
15939	2019-11-28 08:59:36	2019-11-28	8	[{"id_menu":5,"count":1}]	1555	delivery	5	13
15940	2019-11-28 09:06:02	2019-11-28	9	[{"id_menu":6,"count":1}]	4607	pick-up	0	9
15941	2019-11-28 09:10:34	2019-11-28	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	6055	delivery	5	31
15942	2019-11-28 09:16:26	2019-11-28	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1851	delivery	5	45
15943	2019-11-28 09:36:24	2019-11-28	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	6028	delivery	5	31
15944	2019-11-28 09:41:09	2019-11-28	8	[{"id_menu":5,"count":1}]	1415	pick-up	0	8
15945	2019-11-28 09:49:39	2019-11-28	8	[{"id_menu":5,"count":1}]	2899	delivery	5	13
15946	2019-11-28 09:50:13	2019-11-28	9	[{"id_menu":6,"count":1}]	133	pick-up	0	9
15947	2019-11-28 09:55:35	2019-11-28	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	6074	pick-up	0	21
15948	2019-11-28 10:26:26	2019-11-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6040	pick-up	0	18
15949	2019-11-28 10:38:35	2019-11-28	9	[{"id_menu":6,"count":1}]	6019	delivery	5	14
15950	2019-11-28 10:40:52	2019-11-28	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	3566	delivery	5	26
15951	2019-11-28 10:41:22	2019-11-28	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	2850	pick-up	0	25
15952	2019-11-28 10:41:55	2019-11-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	764	delivery	5	28
15953	2019-11-28 10:47:02	2019-11-28	17	[{"id_menu":4,"count":1}]	150	pick-up	0	17
15954	2019-11-28 10:49:28	2019-11-28	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	3393	delivery	5	22
15955	2019-11-28 11:06:10	2019-11-28	12	[{"id_menu":1,"count":1}]	6052	delivery	5	17
15956	2019-11-28 11:17:22	2019-11-28	12	[{"id_menu":1,"count":1}]	6049	pick-up	0	12
15957	2019-11-28 11:18:11	2019-11-28	17	[{"id_menu":4,"count":1}]	5642	pick-up	0	17
15958	2019-11-28 11:22:38	2019-11-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	260	pick-up	0	18
15959	2019-11-28 11:49:44	2019-11-28	14	[{"id_menu":2,"count":1}]	1931	delivery	5	19
15960	2019-11-28 11:57:49	2019-11-28	9	[{"id_menu":7,"count":1}]	3585	delivery	5	14
15961	2019-11-28 12:07:46	2019-11-28	9	[{"id_menu":6,"count":1}]	634	pick-up	0	9
15962	2019-11-28 12:09:47	2019-11-28	17	[{"id_menu":4,"count":1}]	1965	pick-up	0	17
15963	2019-11-28 12:12:21	2019-11-28	12	[{"id_menu":1,"count":1}]	4110	delivery	5	17
15964	2019-11-28 12:37:21	2019-11-28	12	[{"id_menu":1,"count":1}]	6038	pick-up	0	12
15965	2019-11-28 12:37:32	2019-11-28	9	[{"id_menu":7,"count":1}]	4909	delivery	5	14
15966	2019-11-28 12:39:06	2019-11-28	8	[{"id_menu":5,"count":1}]	5286	pick-up	0	8
15967	2019-11-28 12:43:31	2019-11-28	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6072	delivery	5	51
15968	2019-11-28 13:06:32	2019-11-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1557	pick-up	0	26
15969	2019-11-28 13:07:58	2019-11-28	9	[{"id_menu":6,"count":1}]	6032	delivery	5	14
15970	2019-11-28 13:10:29	2019-11-28	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	6050	pick-up	0	29
15971	2019-11-28 13:12:17	2019-11-28	9	[{"id_menu":7,"count":1}]	4020	delivery	5	14
15972	2019-11-28 13:19:48	2019-11-28	12	[{"id_menu":1,"count":1}]	3722	delivery	5	17
15973	2019-11-28 13:22:38	2019-11-28	9	[{"id_menu":7,"count":1}]	878	pick-up	0	9
15974	2019-11-28 14:09:30	2019-11-28	17	[{"id_menu":4,"count":1}]	2699	pick-up	0	17
15975	2019-11-28 14:23:54	2019-11-28	9	[{"id_menu":6,"count":1}]	772	delivery	5	14
15976	2019-11-28 14:27:16	2019-11-28	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1348	delivery	5	39
15977	2019-11-28 14:31:13	2019-11-28	43	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3693	delivery	5	48
15978	2019-11-28 14:37:23	2019-11-28	12	[{"id_menu":3,"count":1}]	6026	delivery	5	17
15979	2019-11-28 14:42:13	2019-11-28	14	[{"id_menu":2,"count":1}]	3564	pick-up	0	14
15980	2019-11-28 14:46:02	2019-11-28	9	[{"id_menu":6,"count":2}]	6051	delivery	5	14
15981	2019-11-28 15:12:40	2019-11-28	17	[{"id_menu":4,"count":1}]	1900	pick-up	0	17
15982	2019-11-28 15:26:16	2019-11-28	9	[{"id_menu":7,"count":1}]	6056	delivery	5	14
15983	2019-11-28 15:33:59	2019-11-28	17	[{"id_menu":4,"count":1}]	4914	delivery	5	22
15984	2019-11-28 15:39:43	2019-11-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2694	delivery	5	31
15985	2019-11-28 15:59:59	2019-11-28	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2564	pick-up	0	25
15986	2019-11-28 16:00:33	2019-11-28	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":2}]	6060	delivery	5	30
15987	2019-11-28 16:08:20	2019-11-28	8	[{"id_menu":5,"count":1}]	6046	pick-up	0	8
15988	2019-11-28 16:12:23	2019-11-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4022	delivery	5	22
15989	2019-11-28 16:13:01	2019-11-28	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	6067	delivery	5	34
15990	2019-11-28 16:33:56	2019-11-28	8	[{"id_menu":5,"count":1}]	1977	delivery	5	13
15991	2019-11-28 16:37:20	2019-11-28	9	[{"id_menu":7,"count":1}]	5558	delivery	5	14
15992	2019-11-28 16:38:56	2019-11-28	17	[{"id_menu":4,"count":2}]	3411	pick-up	0	17
15993	2019-11-28 17:27:05	2019-11-28	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	6062	pick-up	0	29
15994	2019-11-28 17:31:06	2019-11-28	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6041	delivery	5	31
15995	2019-11-28 17:31:56	2019-11-28	12	[{"id_menu":3,"count":1}]	6039	pick-up	0	12
15996	2019-11-28 18:02:03	2019-11-28	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2915	delivery	5	27
15997	2019-11-28 18:02:39	2019-11-28	12	[{"id_menu":1,"count":1}]	2455	pick-up	0	12
15998	2019-11-28 18:05:37	2019-11-28	14	[{"id_menu":2,"count":1}]	669	pick-up	0	14
15999	2019-11-28 18:05:50	2019-11-28	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	6064	pick-up	0	29
16000	2019-11-28 18:15:41	2019-11-28	8	[{"id_menu":5,"count":1}]	6023	delivery	5	13
16001	2019-11-28 18:45:36	2019-11-28	9	[{"id_menu":7,"count":1}]	6030	delivery	5	14
16002	2019-11-28 18:48:24	2019-11-28	9	[{"id_menu":6,"count":1}]	5649	delivery	5	14
16003	2019-11-28 18:58:51	2019-11-28	12	[{"id_menu":1,"count":1}]	296	pick-up	0	12
16004	2019-11-28 19:07:26	2019-11-28	12	[{"id_menu":3,"count":1}]	4428	pick-up	0	12
16005	2019-11-28 19:10:08	2019-11-28	9	[{"id_menu":7,"count":1}]	3621	pick-up	0	9
16006	2019-11-28 19:30:24	2019-11-28	12	[{"id_menu":1,"count":1}]	1119	pick-up	0	12
16007	2019-11-28 19:30:48	2019-11-28	9	[{"id_menu":6,"count":1}]	6027	delivery	5	14
16008	2019-11-28 20:02:39	2019-11-28	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	5864	delivery	5	28
16009	2019-11-28 20:05:14	2019-11-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	602	delivery	5	23
16010	2019-11-28 20:07:08	2019-11-28	12	[{"id_menu":3,"count":1}]	1255	pick-up	0	12
16011	2019-11-28 20:08:00	2019-11-28	12	[{"id_menu":1,"count":1}]	1914	pick-up	0	12
16012	2019-11-28 20:21:10	2019-11-28	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	3644	delivery	5	26
16013	2019-11-28 20:22:11	2019-11-28	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2264	delivery	5	34
16014	2019-11-28 20:29:51	2019-11-28	14	[{"id_menu":2,"count":1}]	3968	pick-up	0	14
16015	2019-11-28 20:30:05	2019-11-28	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":2}]	6053	delivery	5	28
16016	2019-11-28 20:32:28	2019-11-28	9	[{"id_menu":6,"count":1}]	6036	delivery	5	14
16017	2019-11-28 20:38:10	2019-11-28	17	[{"id_menu":4,"count":1}]	6063	delivery	5	22
16018	2019-11-28 21:03:22	2019-11-28	8	[{"id_menu":5,"count":1}]	5240	pick-up	0	8
16019	2019-11-28 21:41:22	2019-11-28	14	[{"id_menu":2,"count":1}]	584	pick-up	0	14
16020	2019-11-28 21:43:12	2019-11-28	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	6068	delivery	5	40
16021	2019-11-28 21:53:59	2019-11-28	17	[{"id_menu":4,"count":1}]	3736	pick-up	0	17
16022	2019-11-28 22:03:14	2019-11-28	14	[{"id_menu":2,"count":1}]	2087	delivery	5	19
16023	2019-11-28 22:10:34	2019-11-28	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1306	pick-up	0	46
16024	2019-11-28 22:20:01	2019-11-28	12	[{"id_menu":3,"count":1}]	1970	delivery	5	17
16025	2019-11-28 22:46:46	2019-11-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3984	delivery	5	23
16026	2019-11-28 22:57:43	2019-11-28	8	[{"id_menu":5,"count":1}]	2140	delivery	5	13
16027	2019-11-28 23:15:09	2019-11-28	14	[{"id_menu":2,"count":1}]	6048	pick-up	0	14
16028	2019-11-28 23:40:13	2019-11-28	12	[{"id_menu":3,"count":1}]	4116	delivery	5	17
16029	2019-11-28 23:40:18	2019-11-28	9	[{"id_menu":6,"count":1}]	2507	delivery	5	14
16030	2019-11-28 23:53:09	2019-11-28	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	6065	delivery	5	27
16031	2019-11-29 00:18:53	2019-11-29	17	[{"id_menu":4,"count":2}]	6096	delivery	5	22
16032	2019-11-29 00:26:36	2019-11-29	9	[{"id_menu":6,"count":1}]	1079	delivery	5	14
16033	2019-11-29 00:30:55	2019-11-29	9	[{"id_menu":7,"count":1}]	3013	delivery	5	14
16034	2019-11-29 00:32:29	2019-11-29	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3123	pick-up	0	26
16035	2019-11-29 00:32:31	2019-11-29	9	[{"id_menu":6,"count":2}]	530	delivery	5	14
16036	2019-11-29 00:45:54	2019-11-29	12	[{"id_menu":1,"count":1}]	476	pick-up	0	12
16037	2019-11-29 01:06:39	2019-11-29	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	5576	delivery	5	48
16038	2019-11-29 01:10:50	2019-11-29	14	[{"id_menu":2,"count":1}]	1454	pick-up	0	14
16039	2019-11-29 01:12:05	2019-11-29	14	[{"id_menu":2,"count":1}]	749	pick-up	0	14
16040	2019-11-29 01:19:17	2019-11-29	9	[{"id_menu":6,"count":1}]	1258	pick-up	0	9
16041	2019-11-29 01:27:25	2019-11-29	14	[{"id_menu":2,"count":1}]	6119	delivery	5	19
16042	2019-11-29 01:33:17	2019-11-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6115	delivery	5	23
16043	2019-11-29 01:46:45	2019-11-29	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	5466	pick-up	0	29
16044	2019-11-29 01:46:54	2019-11-29	8	[{"id_menu":5,"count":1}]	2838	delivery	5	13
16045	2019-11-29 01:58:01	2019-11-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	3267	delivery	5	22
16046	2019-11-29 01:59:56	2019-11-29	8	[{"id_menu":5,"count":1}]	6114	delivery	5	13
16047	2019-11-29 02:13:39	2019-11-29	17	[{"id_menu":4,"count":1}]	2172	pick-up	0	17
16048	2019-11-29 02:15:18	2019-11-29	8	[{"id_menu":5,"count":1}]	4395	delivery	5	13
16049	2019-11-29 02:16:49	2019-11-29	17	[{"id_menu":4,"count":1}]	4798	delivery	5	22
16050	2019-11-29 02:17:58	2019-11-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4590	pick-up	0	31
16051	2019-11-29 02:20:08	2019-11-29	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	5414	delivery	5	40
16052	2019-11-29 02:39:55	2019-11-29	12	[{"id_menu":3,"count":1}]	5491	pick-up	0	12
16053	2019-11-29 02:39:59	2019-11-29	14	[{"id_menu":2,"count":1}]	6089	delivery	5	19
16054	2019-11-29 02:44:06	2019-11-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2646	delivery	5	22
16055	2019-11-29 03:15:01	2019-11-29	9	[{"id_menu":7,"count":1}]	4484	pick-up	0	9
16056	2019-11-29 03:21:10	2019-11-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	6127	delivery	5	27
16057	2019-11-29 03:28:01	2019-11-29	14	[{"id_menu":2,"count":1}]	3492	delivery	5	19
16058	2019-11-29 03:35:09	2019-11-29	14	[{"id_menu":2,"count":1}]	6137	pick-up	0	14
16059	2019-11-29 03:36:57	2019-11-29	9	[{"id_menu":6,"count":1}]	5081	delivery	5	14
16060	2019-11-29 03:39:22	2019-11-29	14	[{"id_menu":2,"count":1}]	1593	pick-up	0	14
16061	2019-11-29 03:45:48	2019-11-29	8	[{"id_menu":5,"count":1}]	6135	delivery	5	13
16062	2019-11-29 03:59:26	2019-11-29	9	[{"id_menu":6,"count":1}]	5007	delivery	5	14
16063	2019-11-29 04:01:35	2019-11-29	12	[{"id_menu":1,"count":1}]	4486	pick-up	0	12
16064	2019-11-29 04:05:38	2019-11-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5050	pick-up	0	17
16065	2019-11-29 04:30:34	2019-11-29	9	[{"id_menu":6,"count":1}]	3961	pick-up	0	9
16066	2019-11-29 04:32:07	2019-11-29	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	718	delivery	5	26
16067	2019-11-29 05:06:36	2019-11-29	9	[{"id_menu":7,"count":1}]	6122	pick-up	0	9
16068	2019-11-29 05:18:04	2019-11-29	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	6085	delivery	5	35
16069	2019-11-29 05:24:26	2019-11-29	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	6129	delivery	5	26
16070	2019-11-29 05:58:55	2019-11-29	17	[{"id_menu":4,"count":1}]	5768	delivery	5	22
16071	2019-11-29 06:28:03	2019-11-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	993	pick-up	0	18
16072	2019-11-29 06:35:31	2019-11-29	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3002	pick-up	0	26
16073	2019-11-29 06:39:18	2019-11-29	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	6138	delivery	5	34
16074	2019-11-29 06:41:51	2019-11-29	9	[{"id_menu":7,"count":1}]	4982	delivery	5	14
16075	2019-11-29 06:45:41	2019-11-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6124	delivery	5	23
16076	2019-11-29 06:55:50	2019-11-29	14	[{"id_menu":2,"count":1}]	6105	delivery	5	19
16077	2019-11-29 07:18:48	2019-11-29	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	5530	pick-up	0	29
16078	2019-11-29 07:40:27	2019-11-29	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1992	pick-up	0	52
16079	2019-11-29 07:42:31	2019-11-29	14	[{"id_menu":2,"count":1}]	6080	delivery	5	19
16080	2019-11-29 07:48:26	2019-11-29	8	[{"id_menu":5,"count":1}]	2615	pick-up	0	8
16081	2019-11-29 07:51:59	2019-11-29	9	[{"id_menu":7,"count":1}]	35	delivery	5	14
16082	2019-11-29 07:58:36	2019-11-29	9	[{"id_menu":6,"count":1}]	6140	delivery	5	14
16083	2019-11-29 08:07:16	2019-11-29	9	[{"id_menu":7,"count":1}]	3069	delivery	5	14
16084	2019-11-29 08:10:10	2019-11-29	8	[{"id_menu":5,"count":1}]	6092	delivery	5	13
16085	2019-11-29 08:16:16	2019-11-29	8	[{"id_menu":5,"count":1}]	6087	delivery	5	13
16086	2019-11-29 08:52:31	2019-11-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	6118	delivery	5	27
16087	2019-11-29 09:17:39	2019-11-29	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6106	delivery	5	39
16088	2019-11-29 09:21:13	2019-11-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4710	pick-up	0	21
16089	2019-11-29 09:32:16	2019-11-29	12	[{"id_menu":3,"count":1}]	1541	pick-up	0	12
16090	2019-11-29 09:35:15	2019-11-29	9	[{"id_menu":7,"count":2}]	639	pick-up	0	9
16091	2019-11-29 09:58:31	2019-11-29	8	[{"id_menu":5,"count":1}]	6126	delivery	5	13
16092	2019-11-29 09:59:26	2019-11-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5338	pick-up	0	17
16093	2019-11-29 10:13:34	2019-11-29	12	[{"id_menu":3,"count":1}]	2418	pick-up	0	12
16094	2019-11-29 10:14:21	2019-11-29	9	[{"id_menu":6,"count":1}]	5727	delivery	5	14
16095	2019-11-29 10:25:24	2019-11-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1447	pick-up	0	23
16096	2019-11-29 10:35:51	2019-11-29	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	6084	delivery	5	42
16097	2019-11-29 10:37:40	2019-11-29	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1700	pick-up	0	24
16098	2019-11-29 10:39:12	2019-11-29	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4732	delivery	5	43
16099	2019-11-29 10:55:23	2019-11-29	9	[{"id_menu":6,"count":1}]	340	delivery	5	14
16100	2019-11-29 10:56:09	2019-11-29	17	[{"id_menu":4,"count":1}]	6090	delivery	5	22
16101	2019-11-29 11:04:07	2019-11-29	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	6088	delivery	5	34
16102	2019-11-29 11:08:20	2019-11-29	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	1015	pick-up	0	21
16103	2019-11-29 11:08:42	2019-11-29	14	[{"id_menu":2,"count":1}]	5701	pick-up	0	14
16104	2019-11-29 11:15:49	2019-11-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1905	pick-up	0	22
16105	2019-11-29 11:21:57	2019-11-29	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	770	delivery	5	29
16106	2019-11-29 11:38:24	2019-11-29	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	880	delivery	5	36
16107	2019-11-29 11:45:29	2019-11-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6141	pick-up	0	26
16108	2019-11-29 12:12:34	2019-11-29	12	[{"id_menu":3,"count":1}]	6097	pick-up	0	12
16109	2019-11-29 12:35:25	2019-11-29	17	[{"id_menu":4,"count":1}]	6120	delivery	5	22
16110	2019-11-29 12:55:43	2019-11-29	14	[{"id_menu":2,"count":1}]	3385	pick-up	0	14
16111	2019-11-29 13:13:49	2019-11-29	17	[{"id_menu":4,"count":2}]	1681	delivery	5	22
16112	2019-11-29 13:19:46	2019-11-29	14	[{"id_menu":2,"count":1}]	4546	pick-up	0	14
16113	2019-11-29 13:30:22	2019-11-29	14	[{"id_menu":2,"count":1}]	2384	pick-up	0	14
16114	2019-11-29 13:50:34	2019-11-29	12	[{"id_menu":3,"count":1}]	830	delivery	5	17
16115	2019-11-29 14:03:26	2019-11-29	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2770	pick-up	0	29
16116	2019-11-29 14:09:57	2019-11-29	12	[{"id_menu":3,"count":1}]	6111	delivery	5	17
16117	2019-11-29 14:26:29	2019-11-29	14	[{"id_menu":2,"count":1}]	78	pick-up	0	14
16118	2019-11-29 14:28:01	2019-11-29	9	[{"id_menu":6,"count":1}]	2189	pick-up	0	9
16119	2019-11-29 14:33:02	2019-11-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2477	delivery	5	31
16120	2019-11-29 14:37:26	2019-11-29	17	[{"id_menu":4,"count":1}]	6077	delivery	5	22
16121	2019-11-29 14:41:43	2019-11-29	14	[{"id_menu":2,"count":1}]	1722	pick-up	0	14
16122	2019-11-29 14:44:04	2019-11-29	17	[{"id_menu":4,"count":1}]	6108	delivery	5	22
16123	2019-11-29 14:49:00	2019-11-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6116	delivery	5	22
16124	2019-11-29 14:52:14	2019-11-29	12	[{"id_menu":1,"count":1}]	6121	delivery	5	17
16125	2019-11-29 14:52:42	2019-11-29	17	[{"id_menu":4,"count":1}]	541	pick-up	0	17
16126	2019-11-29 14:53:37	2019-11-29	14	[{"id_menu":2,"count":1}]	3380	delivery	5	19
16127	2019-11-29 15:23:34	2019-11-29	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	5287	delivery	5	31
16128	2019-11-29 15:36:11	2019-11-29	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2943	delivery	5	26
16129	2019-11-29 15:36:53	2019-11-29	12	[{"id_menu":1,"count":1}]	5506	pick-up	0	12
16130	2019-11-29 15:36:59	2019-11-29	14	[{"id_menu":2,"count":1}]	3979	delivery	5	19
16131	2019-11-29 15:38:47	2019-11-29	9	[{"id_menu":6,"count":2}]	6109	delivery	5	14
16132	2019-11-29 16:20:20	2019-11-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	5930	delivery	5	28
16133	2019-11-29 16:27:15	2019-11-29	9	[{"id_menu":7,"count":1}]	4145	delivery	5	14
16134	2019-11-29 16:38:33	2019-11-29	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2434	delivery	5	31
16135	2019-11-29 16:40:32	2019-11-29	8	[{"id_menu":5,"count":1}]	1734	delivery	5	13
16136	2019-11-29 17:13:41	2019-11-29	14	[{"id_menu":2,"count":1}]	1785	delivery	5	19
16137	2019-11-29 17:32:44	2019-11-29	14	[{"id_menu":2,"count":1}]	753	delivery	5	19
16138	2019-11-29 17:36:50	2019-11-29	17	[{"id_menu":4,"count":1}]	6101	pick-up	0	17
16139	2019-11-29 17:45:53	2019-11-29	9	[{"id_menu":7,"count":1}]	6100	pick-up	0	9
16140	2019-11-29 17:46:21	2019-11-29	9	[{"id_menu":6,"count":1}]	6081	pick-up	0	9
16141	2019-11-29 17:49:27	2019-11-29	8	[{"id_menu":5,"count":1}]	1104	pick-up	0	8
16142	2019-11-29 17:59:04	2019-11-29	12	[{"id_menu":1,"count":1}]	6112	delivery	5	17
16143	2019-11-29 18:01:33	2019-11-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1278	delivery	5	26
16144	2019-11-29 18:09:44	2019-11-29	9	[{"id_menu":6,"count":1}]	6078	delivery	5	14
16145	2019-11-29 18:14:46	2019-11-29	9	[{"id_menu":6,"count":1}]	660	pick-up	0	9
16146	2019-11-29 18:41:38	2019-11-29	12	[{"id_menu":1,"count":1}]	153	pick-up	0	12
16147	2019-11-29 18:48:54	2019-11-29	12	[{"id_menu":1,"count":1}]	2627	pick-up	0	12
16148	2019-11-29 18:56:10	2019-11-29	12	[{"id_menu":1,"count":1}]	2517	pick-up	0	12
16149	2019-11-29 19:06:29	2019-11-29	12	[{"id_menu":3,"count":1}]	6132	delivery	5	17
16150	2019-11-29 19:11:29	2019-11-29	8	[{"id_menu":5,"count":1}]	4737	delivery	5	13
16151	2019-11-29 19:14:30	2019-11-29	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6113	delivery	5	40
16152	2019-11-29 19:19:52	2019-11-29	14	[{"id_menu":2,"count":1}]	3917	delivery	5	19
16153	2019-11-29 19:22:15	2019-11-29	12	[{"id_menu":1,"count":1}]	6133	delivery	5	17
16154	2019-11-29 19:28:19	2019-11-29	12	[{"id_menu":3,"count":1}]	1442	pick-up	0	12
16155	2019-11-29 19:37:52	2019-11-29	12	[{"id_menu":3,"count":1}]	273	delivery	5	17
16156	2019-11-29 19:52:09	2019-11-29	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	905	delivery	5	42
16157	2019-11-29 19:57:23	2019-11-29	9	[{"id_menu":6,"count":1}]	1470	pick-up	0	9
16158	2019-11-29 20:11:24	2019-11-29	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	5983	delivery	5	34
16159	2019-11-29 20:21:02	2019-11-29	9	[{"id_menu":7,"count":1}]	6104	delivery	5	14
16160	2019-11-29 20:41:34	2019-11-29	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	2006	pick-up	0	22
16161	2019-11-29 20:43:25	2019-11-29	9	[{"id_menu":6,"count":1}]	140	pick-up	0	9
16162	2019-11-29 20:48:56	2019-11-29	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1720	pick-up	0	31
16163	2019-11-29 21:21:36	2019-11-29	12	[{"id_menu":1,"count":1}]	6082	delivery	5	17
16164	2019-11-29 21:22:09	2019-11-29	17	[{"id_menu":4,"count":1}]	6091	delivery	5	22
16165	2019-11-29 21:24:00	2019-11-29	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2890	pick-up	0	30
16166	2019-11-29 21:34:30	2019-11-29	12	[{"id_menu":3,"count":1}]	2511	delivery	5	17
16167	2019-11-29 21:39:50	2019-11-29	12	[{"id_menu":3,"count":2}]	5857	pick-up	0	12
16168	2019-11-29 21:40:39	2019-11-29	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	4676	delivery	5	31
16169	2019-11-29 21:44:51	2019-11-29	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	6128	delivery	5	34
16170	2019-11-29 22:29:01	2019-11-29	8	[{"id_menu":5,"count":1}]	3151	pick-up	0	8
16171	2019-11-29 22:31:06	2019-11-29	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	304	pick-up	0	21
16172	2019-11-29 22:34:59	2019-11-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6123	delivery	5	23
16173	2019-11-29 22:48:32	2019-11-29	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6079	delivery	5	31
16174	2019-11-29 22:49:43	2019-11-29	17	[{"id_menu":4,"count":2}]	1463	pick-up	0	17
16175	2019-11-29 22:50:16	2019-11-29	17	[{"id_menu":4,"count":1}]	4446	delivery	5	22
16176	2019-11-29 22:52:54	2019-11-29	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6107	delivery	5	34
16177	2019-11-29 23:02:16	2019-11-29	14	[{"id_menu":2,"count":2}]	4550	pick-up	0	14
16178	2019-11-29 23:32:04	2019-11-29	9	[{"id_menu":6,"count":1}]	4495	delivery	5	14
16179	2019-11-29 23:52:09	2019-11-29	17	[{"id_menu":4,"count":1}]	6139	delivery	5	22
16180	2019-11-29 23:55:31	2019-11-29	17	[{"id_menu":4,"count":1}]	3096	delivery	5	22
16181	2019-11-30 00:01:56	2019-11-30	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6161	delivery	5	45
16182	2019-11-30 00:45:00	2019-11-30	8	[{"id_menu":5,"count":1}]	6080	delivery	5	13
16183	2019-11-30 00:54:50	2019-11-30	9	[{"id_menu":7,"count":1}]	382	pick-up	0	9
16184	2019-11-30 00:58:13	2019-11-30	12	[{"id_menu":1,"count":1}]	950	delivery	5	17
16185	2019-11-30 01:30:38	2019-11-30	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1733	delivery	5	31
16186	2019-11-30 01:31:22	2019-11-30	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	3806	delivery	5	26
16187	2019-11-30 01:33:17	2019-11-30	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5339	delivery	5	34
16188	2019-11-30 01:45:39	2019-11-30	8	[{"id_menu":5,"count":1}]	5512	delivery	5	13
16189	2019-11-30 01:52:33	2019-11-30	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2231	pick-up	0	20
16190	2019-11-30 01:59:33	2019-11-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	6164	delivery	5	27
16191	2019-11-30 02:01:43	2019-11-30	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4960	pick-up	0	43
16192	2019-11-30 02:02:23	2019-11-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4847	delivery	5	22
16193	2019-11-30 02:04:26	2019-11-30	14	[{"id_menu":2,"count":1}]	6176	delivery	5	19
16194	2019-11-30 02:24:31	2019-11-30	12	[{"id_menu":1,"count":1}]	6147	delivery	5	17
16195	2019-11-30 02:39:10	2019-11-30	12	[{"id_menu":1,"count":1}]	3198	pick-up	0	12
16196	2019-11-30 02:44:16	2019-11-30	9	[{"id_menu":7,"count":1}]	3519	delivery	5	14
16197	2019-11-30 02:59:24	2019-11-30	8	[{"id_menu":5,"count":1}]	6143	delivery	5	13
16198	2019-11-30 03:12:28	2019-11-30	9	[{"id_menu":6,"count":1}]	2804	pick-up	0	9
16199	2019-11-30 03:25:05	2019-11-30	9	[{"id_menu":7,"count":1}]	6182	pick-up	0	9
16200	2019-11-30 03:28:07	2019-11-30	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	4619	delivery	5	27
16201	2019-11-30 03:32:07	2019-11-30	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2699	pick-up	0	20
16202	2019-11-30 03:50:17	2019-11-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3224	pick-up	0	23
16203	2019-11-30 03:57:40	2019-11-30	12	[{"id_menu":3,"count":1}]	1344	pick-up	0	12
16204	2019-11-30 04:02:26	2019-11-30	8	[{"id_menu":5,"count":1}]	397	delivery	5	13
16205	2019-11-30 04:08:02	2019-11-30	9	[{"id_menu":7,"count":1}]	6155	delivery	5	14
16206	2019-11-30 04:11:24	2019-11-30	9	[{"id_menu":7,"count":1}]	2415	pick-up	0	9
16207	2019-11-30 04:12:30	2019-11-30	17	[{"id_menu":4,"count":1}]	2421	delivery	5	22
16208	2019-11-30 04:21:14	2019-11-30	8	[{"id_menu":5,"count":1}]	4912	delivery	5	13
16209	2019-11-30 04:32:47	2019-11-30	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6180	delivery	5	57
16210	2019-11-30 04:34:42	2019-11-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2875	pick-up	0	23
16211	2019-11-30 04:53:22	2019-11-30	9	[{"id_menu":6,"count":2}]	3293	delivery	5	14
16212	2019-11-30 05:08:28	2019-11-30	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4710	pick-up	0	31
16213	2019-11-30 05:26:07	2019-11-30	14	[{"id_menu":2,"count":1}]	2661	delivery	5	19
16214	2019-11-30 05:30:47	2019-11-30	8	[{"id_menu":5,"count":1}]	1531	pick-up	0	8
16215	2019-11-30 05:34:25	2019-11-30	12	[{"id_menu":1,"count":1}]	6159	delivery	5	17
16216	2019-11-30 05:37:15	2019-11-30	14	[{"id_menu":2,"count":1}]	6162	delivery	5	19
16217	2019-11-30 05:37:53	2019-11-30	14	[{"id_menu":2,"count":1}]	6121	pick-up	0	14
16218	2019-11-30 05:43:59	2019-11-30	9	[{"id_menu":6,"count":1}]	6165	delivery	5	14
16219	2019-11-30 05:48:25	2019-11-30	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6160	delivery	5	42
16220	2019-11-30 05:50:11	2019-11-30	34	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	2532	delivery	5	39
16221	2019-11-30 05:53:11	2019-11-30	12	[{"id_menu":1,"count":1}]	2477	delivery	5	17
16222	2019-11-30 05:56:54	2019-11-30	9	[{"id_menu":6,"count":1}]	6184	pick-up	0	9
16223	2019-11-30 06:00:16	2019-11-30	12	[{"id_menu":3,"count":1}]	3688	delivery	5	17
16224	2019-11-30 06:14:05	2019-11-30	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2101	pick-up	0	21
16225	2019-11-30 06:17:02	2019-11-30	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3124	delivery	5	22
16226	2019-11-30 06:25:57	2019-11-30	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	709	delivery	5	31
16227	2019-11-30 06:33:32	2019-11-30	9	[{"id_menu":7,"count":1}]	5082	delivery	5	14
16228	2019-11-30 06:57:52	2019-11-30	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	536	delivery	5	25
16229	2019-11-30 07:06:58	2019-11-30	12	[{"id_menu":3,"count":1}]	3163	delivery	5	17
16230	2019-11-30 07:11:38	2019-11-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	6172	pick-up	0	17
16231	2019-11-30 07:23:22	2019-11-30	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5105	delivery	5	44
16232	2019-11-30 07:56:08	2019-11-30	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	143	pick-up	0	21
16233	2019-11-30 08:01:37	2019-11-30	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	6177	pick-up	0	26
16234	2019-11-30 08:02:12	2019-11-30	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6189	delivery	5	37
16235	2019-11-30 08:25:05	2019-11-30	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	6070	pick-up	0	34
16236	2019-11-30 08:29:28	2019-11-30	12	[{"id_menu":3,"count":1}]	6156	pick-up	0	12
16237	2019-11-30 08:31:37	2019-11-30	9	[{"id_menu":7,"count":1}]	2476	delivery	5	14
16238	2019-11-30 08:39:48	2019-11-30	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3361	pick-up	0	38
16239	2019-11-30 08:52:51	2019-11-30	12	[{"id_menu":1,"count":1}]	1968	pick-up	0	12
16240	2019-11-30 09:08:45	2019-11-30	17	[{"id_menu":4,"count":1}]	4943	delivery	5	22
16241	2019-11-30 09:34:58	2019-11-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3469	delivery	5	31
16242	2019-11-30 09:37:35	2019-11-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6148	delivery	5	28
16243	2019-11-30 10:02:32	2019-11-30	9	[{"id_menu":6,"count":1}]	6150	delivery	5	14
16244	2019-11-30 10:11:10	2019-11-30	8	[{"id_menu":5,"count":1}]	6185	delivery	5	13
16245	2019-11-30 10:11:29	2019-11-30	9	[{"id_menu":7,"count":1}]	1524	delivery	5	14
16246	2019-11-30 10:15:45	2019-11-30	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1681	delivery	5	30
16247	2019-11-30 10:23:59	2019-11-30	12	[{"id_menu":1,"count":1}]	5002	delivery	5	17
16248	2019-11-30 10:36:49	2019-11-30	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2230	pick-up	0	40
16249	2019-11-30 10:38:17	2019-11-30	12	[{"id_menu":1,"count":1}]	4525	pick-up	0	12
16250	2019-11-30 10:43:50	2019-11-30	9	[{"id_menu":7,"count":1}]	6173	delivery	5	14
16251	2019-11-30 10:44:26	2019-11-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2853	delivery	5	26
16252	2019-11-30 10:48:17	2019-11-30	12	[{"id_menu":1,"count":1}]	172	pick-up	0	12
16253	2019-11-30 10:48:46	2019-11-30	9	[{"id_menu":6,"count":1}]	6169	delivery	5	14
16254	2019-11-30 11:02:16	2019-11-30	12	[{"id_menu":3,"count":1}]	2631	pick-up	0	12
16255	2019-11-30 11:08:04	2019-11-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4247	delivery	5	31
16256	2019-11-30 11:12:27	2019-11-30	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	6170	delivery	5	40
16257	2019-11-30 11:21:44	2019-11-30	9	[{"id_menu":6,"count":1}]	642	delivery	5	14
16258	2019-11-30 11:45:53	2019-11-30	9	[{"id_menu":7,"count":1}]	3499	delivery	5	14
16259	2019-11-30 11:52:05	2019-11-30	12	[{"id_menu":1,"count":1}]	6142	delivery	5	17
16260	2019-11-30 12:00:36	2019-11-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6151	pick-up	0	23
16261	2019-11-30 12:03:49	2019-11-30	9	[{"id_menu":7,"count":1}]	6145	delivery	5	14
16262	2019-11-30 12:22:59	2019-11-30	17	[{"id_menu":4,"count":1}]	6166	delivery	5	22
16263	2019-11-30 12:22:59	2019-11-30	17	[{"id_menu":4,"count":1}]	378	pick-up	0	17
16264	2019-11-30 12:29:13	2019-11-30	12	[{"id_menu":1,"count":1}]	4652	delivery	5	17
16265	2019-11-30 12:37:51	2019-11-30	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	687	delivery	5	23
16266	2019-11-30 12:38:42	2019-11-30	8	[{"id_menu":5,"count":2}]	2702	pick-up	0	8
16267	2019-11-30 12:50:00	2019-11-30	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1810	pick-up	0	31
16268	2019-11-30 12:54:43	2019-11-30	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6154	delivery	5	36
16269	2019-11-30 13:00:19	2019-11-30	9	[{"id_menu":6,"count":1}]	4081	delivery	5	14
16270	2019-11-30 13:10:23	2019-11-30	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	5125	delivery	5	34
16271	2019-11-30 13:10:43	2019-11-30	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1627	pick-up	0	17
16272	2019-11-30 13:11:40	2019-11-30	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1251	delivery	5	34
16273	2019-11-30 13:16:23	2019-11-30	12	[{"id_menu":3,"count":1}]	4393	pick-up	0	12
16274	2019-11-30 13:17:29	2019-11-30	12	[{"id_menu":1,"count":1}]	1075	pick-up	0	12
16275	2019-11-30 13:19:39	2019-11-30	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1427	delivery	5	25
16276	2019-11-30 13:23:46	2019-11-30	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	6183	pick-up	0	21
16277	2019-11-30 14:00:54	2019-11-30	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	749	pick-up	0	24
16278	2019-11-30 14:11:07	2019-11-30	17	[{"id_menu":4,"count":1}]	246	pick-up	0	17
16279	2019-11-30 14:11:26	2019-11-30	17	[{"id_menu":4,"count":1}]	2587	pick-up	0	17
16280	2019-11-30 14:13:27	2019-11-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5699	delivery	5	31
16281	2019-11-30 14:13:56	2019-11-30	14	[{"id_menu":2,"count":1}]	5998	delivery	5	19
16282	2019-11-30 14:22:17	2019-11-30	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	6168	delivery	5	28
16283	2019-11-30 14:22:38	2019-11-30	12	[{"id_menu":3,"count":1}]	4501	pick-up	0	12
16284	2019-11-30 14:25:49	2019-11-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	4016	delivery	5	23
16285	2019-11-30 14:39:21	2019-11-30	9	[{"id_menu":7,"count":1}]	1441	delivery	5	14
16286	2019-11-30 14:53:35	2019-11-30	12	[{"id_menu":1,"count":1}]	6179	delivery	5	17
16287	2019-11-30 15:12:49	2019-11-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3764	delivery	5	23
16288	2019-11-30 15:15:00	2019-11-30	8	[{"id_menu":5,"count":1}]	4590	pick-up	0	8
16289	2019-11-30 15:17:06	2019-11-30	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	6149	delivery	5	43
16290	2019-11-30 15:30:06	2019-11-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	401	delivery	5	28
16291	2019-11-30 15:41:52	2019-11-30	12	[{"id_menu":3,"count":1}]	2697	pick-up	0	12
16292	2019-11-30 15:43:47	2019-11-30	9	[{"id_menu":7,"count":1}]	1424	pick-up	0	9
16293	2019-11-30 15:56:36	2019-11-30	9	[{"id_menu":7,"count":1}]	1819	pick-up	0	9
16294	2019-11-30 16:07:18	2019-11-30	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5455	delivery	5	42
16295	2019-11-30 16:17:10	2019-11-30	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3471	delivery	5	38
16296	2019-11-30 16:21:56	2019-11-30	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1406	pick-up	0	20
16297	2019-11-30 16:39:05	2019-11-30	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5491	pick-up	0	17
16298	2019-11-30 16:46:05	2019-11-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6158	pick-up	0	18
16299	2019-11-30 16:49:08	2019-11-30	14	[{"id_menu":2,"count":1}]	550	delivery	5	19
16300	2019-11-30 16:51:02	2019-11-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3641	delivery	5	31
16301	2019-11-30 16:57:59	2019-11-30	17	[{"id_menu":4,"count":1}]	1727	delivery	5	22
16302	2019-11-30 17:04:28	2019-11-30	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3421	pick-up	0	21
16303	2019-11-30 17:05:15	2019-11-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	847	delivery	5	31
16304	2019-11-30 17:07:54	2019-11-30	14	[{"id_menu":2,"count":2}]	6157	delivery	5	19
16305	2019-11-30 17:08:44	2019-11-30	12	[{"id_menu":1,"count":1}]	6191	delivery	5	17
16306	2019-11-30 17:22:43	2019-11-30	14	[{"id_menu":2,"count":1}]	4248	delivery	5	19
16307	2019-11-30 17:40:27	2019-11-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	6153	delivery	5	27
16308	2019-11-30 18:09:30	2019-11-30	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	6146	delivery	5	31
16309	2019-11-30 18:23:10	2019-11-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6167	delivery	5	31
16310	2019-11-30 18:39:02	2019-11-30	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5712	pick-up	0	17
16311	2019-11-30 18:50:36	2019-11-30	8	[{"id_menu":5,"count":1}]	6178	delivery	5	13
16312	2019-11-30 19:01:29	2019-11-30	12	[{"id_menu":1,"count":1}]	6144	delivery	5	17
16313	2019-11-30 19:08:34	2019-11-30	8	[{"id_menu":5,"count":1}]	6174	delivery	5	13
16314	2019-11-30 19:22:27	2019-11-30	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	6181	delivery	5	43
16315	2019-11-30 19:23:23	2019-11-30	14	[{"id_menu":2,"count":1}]	841	pick-up	0	14
16316	2019-11-30 19:30:15	2019-11-30	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5670	delivery	5	46
16317	2019-11-30 19:37:43	2019-11-30	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6152	pick-up	0	31
16318	2019-11-30 19:46:08	2019-11-30	17	[{"id_menu":4,"count":1}]	6163	pick-up	0	17
16319	2019-11-30 19:50:40	2019-11-30	8	[{"id_menu":5,"count":1}]	2333	pick-up	0	8
16320	2019-11-30 20:01:02	2019-11-30	14	[{"id_menu":2,"count":1}]	5019	pick-up	0	14
16321	2019-11-30 20:03:26	2019-11-30	17	[{"id_menu":4,"count":1}]	6188	delivery	5	22
16322	2019-11-30 20:04:51	2019-11-30	12	[{"id_menu":1,"count":1}]	2646	pick-up	0	12
16323	2019-11-30 20:32:29	2019-11-30	14	[{"id_menu":2,"count":1}]	2508	delivery	5	19
16324	2019-11-30 20:34:35	2019-11-30	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	3548	delivery	5	31
16325	2019-11-30 20:35:17	2019-11-30	17	[{"id_menu":4,"count":1}]	1704	pick-up	0	17
16326	2019-11-30 20:51:05	2019-11-30	9	[{"id_menu":7,"count":1}]	1731	pick-up	0	9
16327	2019-11-30 21:00:52	2019-11-30	9	[{"id_menu":7,"count":1}]	3152	pick-up	0	9
16328	2019-11-30 21:10:56	2019-11-30	9	[{"id_menu":6,"count":1}]	3670	pick-up	0	9
16329	2019-11-30 21:14:17	2019-11-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5196	pick-up	0	18
16330	2019-11-30 21:36:12	2019-11-30	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	4451	pick-up	0	41
16331	2019-11-30 21:52:55	2019-11-30	14	[{"id_menu":2,"count":1}]	2139	pick-up	0	14
16332	2019-11-30 21:54:40	2019-11-30	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	3243	delivery	5	26
16333	2019-11-30 22:22:05	2019-11-30	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	299	delivery	5	25
16334	2019-11-30 22:31:02	2019-11-30	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	6171	delivery	5	34
16335	2019-11-30 22:34:03	2019-11-30	14	[{"id_menu":2,"count":1}]	380	delivery	5	19
16336	2019-11-30 22:54:39	2019-11-30	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5777	delivery	5	31
16337	2019-11-30 23:16:42	2019-11-30	14	[{"id_menu":2,"count":1}]	389	delivery	5	19
16338	2019-11-30 23:24:05	2019-11-30	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6186	pick-up	0	31
16339	2019-11-30 23:25:53	2019-11-30	9	[{"id_menu":7,"count":1}]	6175	delivery	5	14
16340	2019-11-30 23:33:28	2019-11-30	17	[{"id_menu":4,"count":1}]	53	delivery	5	22
16341	2019-11-30 23:53:29	2019-11-30	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4223	pick-up	0	21
16342	2019-12-01 00:02:30	2019-12-01	9	[{"id_menu":6,"count":1}]	6233	delivery	5	14
16343	2019-12-01 00:03:13	2019-12-01	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	3852	pick-up	0	32
16344	2019-12-01 00:04:25	2019-12-01	14	[{"id_menu":2,"count":1}]	3123	pick-up	0	14
16345	2019-12-01 00:34:11	2019-12-01	30	[{"id_menu":1,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6225	delivery	5	35
16346	2019-12-01 00:35:03	2019-12-01	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	4592	delivery	5	46
16347	2019-12-01 00:40:50	2019-12-01	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4979	delivery	5	53
16348	2019-12-01 00:44:51	2019-12-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	6217	delivery	5	22
16349	2019-12-01 00:49:51	2019-12-01	14	[{"id_menu":2,"count":1}]	381	delivery	5	19
16350	2019-12-01 00:55:00	2019-12-01	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	6198	delivery	5	23
16351	2019-12-01 00:56:12	2019-12-01	12	[{"id_menu":3,"count":1}]	8	pick-up	0	12
16352	2019-12-01 01:08:43	2019-12-01	12	[{"id_menu":1,"count":1}]	1148	pick-up	0	12
16353	2019-12-01 01:10:06	2019-12-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3802	pick-up	0	23
16354	2019-12-01 01:19:24	2019-12-01	8	[{"id_menu":5,"count":1}]	4928	delivery	5	13
16355	2019-12-01 01:25:21	2019-12-01	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	6216	pick-up	0	26
16356	2019-12-01 01:25:23	2019-12-01	14	[{"id_menu":2,"count":1}]	6201	delivery	5	19
16357	2019-12-01 01:40:16	2019-12-01	9	[{"id_menu":7,"count":1}]	4805	delivery	5	14
16358	2019-12-01 01:49:47	2019-12-01	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	874	delivery	5	34
16359	2019-12-01 01:57:54	2019-12-01	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5038	pick-up	0	44
16360	2019-12-01 01:58:06	2019-12-01	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	4309	pick-up	0	26
16361	2019-12-01 01:59:56	2019-12-01	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2110	pick-up	0	29
16362	2019-12-01 02:01:43	2019-12-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3912	delivery	5	28
16363	2019-12-01 02:03:55	2019-12-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6172	delivery	5	31
16364	2019-12-01 02:04:29	2019-12-01	14	[{"id_menu":2,"count":1}]	6238	pick-up	0	14
16365	2019-12-01 02:33:55	2019-12-01	9	[{"id_menu":6,"count":1}]	113	pick-up	0	9
16366	2019-12-01 02:36:27	2019-12-01	9	[{"id_menu":7,"count":1}]	6243	pick-up	0	9
16367	2019-12-01 02:44:19	2019-12-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	4824	delivery	5	28
16368	2019-12-01 02:52:07	2019-12-01	9	[{"id_menu":7,"count":1}]	6215	delivery	5	14
16369	2019-12-01 03:01:37	2019-12-01	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	6255	delivery	5	26
16370	2019-12-01 03:26:38	2019-12-01	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1214	delivery	5	48
16371	2019-12-01 03:32:01	2019-12-01	9	[{"id_menu":6,"count":1}]	4573	delivery	5	14
16372	2019-12-01 03:58:17	2019-12-01	14	[{"id_menu":2,"count":1}]	2915	delivery	5	19
16373	2019-12-01 04:08:25	2019-12-01	12	[{"id_menu":1,"count":1}]	2734	delivery	5	17
16374	2019-12-01 04:27:43	2019-12-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3590	pick-up	0	23
16375	2019-12-01 04:44:14	2019-12-01	17	[{"id_menu":4,"count":1}]	3894	pick-up	0	17
16376	2019-12-01 04:46:38	2019-12-01	12	[{"id_menu":1,"count":1}]	6195	delivery	5	17
16377	2019-12-01 04:47:36	2019-12-01	17	[{"id_menu":4,"count":1}]	5350	pick-up	0	17
16378	2019-12-01 04:55:19	2019-12-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3842	pick-up	0	17
16379	2019-12-01 04:55:48	2019-12-01	9	[{"id_menu":7,"count":1}]	116	pick-up	0	9
16380	2019-12-01 04:58:42	2019-12-01	12	[{"id_menu":1,"count":1}]	1569	pick-up	0	12
16381	2019-12-01 05:01:31	2019-12-01	8	[{"id_menu":5,"count":1}]	728	delivery	5	13
16382	2019-12-01 05:06:06	2019-12-01	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	6239	delivery	5	29
16383	2019-12-01 05:07:27	2019-12-01	9	[{"id_menu":7,"count":1}]	2339	pick-up	0	9
16384	2019-12-01 05:09:25	2019-12-01	12	[{"id_menu":3,"count":1}]	5940	delivery	5	17
16385	2019-12-01 05:14:20	2019-12-01	9	[{"id_menu":7,"count":1}]	1480	delivery	5	14
16386	2019-12-01 05:16:25	2019-12-01	9	[{"id_menu":7,"count":1}]	4079	delivery	5	14
16387	2019-12-01 05:17:57	2019-12-01	14	[{"id_menu":2,"count":1}]	6164	pick-up	0	14
16388	2019-12-01 05:19:33	2019-12-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	6234	delivery	5	22
16389	2019-12-01 05:22:55	2019-12-01	12	[{"id_menu":1,"count":1}]	2715	delivery	5	17
16390	2019-12-01 05:24:11	2019-12-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6192	delivery	5	31
16391	2019-12-01 05:24:18	2019-12-01	9	[{"id_menu":6,"count":1}]	5453	delivery	5	14
16392	2019-12-01 05:27:42	2019-12-01	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5791	delivery	5	45
16393	2019-12-01 05:31:22	2019-12-01	12	[{"id_menu":1,"count":1}]	6221	pick-up	0	12
16394	2019-12-01 05:32:17	2019-12-01	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3734	pick-up	0	25
16395	2019-12-01 05:32:26	2019-12-01	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	6229	delivery	5	31
16396	2019-12-01 05:56:42	2019-12-01	9	[{"id_menu":7,"count":1}]	2092	delivery	5	14
16397	2019-12-01 05:56:49	2019-12-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3898	pick-up	0	31
16398	2019-12-01 05:57:32	2019-12-01	26	[{"id_menu":4,"count":3},{"id_menu":6,"count":1}]	2068	pick-up	0	26
16399	2019-12-01 06:16:45	2019-12-01	17	[{"id_menu":4,"count":1}]	1835	delivery	5	22
16400	2019-12-01 06:18:51	2019-12-01	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	4370	delivery	5	26
16401	2019-12-01 06:21:11	2019-12-01	9	[{"id_menu":6,"count":1}]	6041	delivery	5	14
16402	2019-12-01 06:36:51	2019-12-01	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	1170	delivery	5	30
16403	2019-12-01 06:48:46	2019-12-01	9	[{"id_menu":7,"count":1}]	6214	delivery	5	14
16404	2019-12-01 07:00:12	2019-12-01	8	[{"id_menu":5,"count":1}]	6212	delivery	5	13
16405	2019-12-01 07:08:37	2019-12-01	9	[{"id_menu":7,"count":1}]	2761	delivery	5	14
16406	2019-12-01 07:16:38	2019-12-01	8	[{"id_menu":5,"count":1}]	6235	pick-up	0	8
16407	2019-12-01 07:26:26	2019-12-01	17	[{"id_menu":4,"count":1}]	286	delivery	5	22
16408	2019-12-01 07:27:33	2019-12-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2705	delivery	5	28
16409	2019-12-01 08:01:07	2019-12-01	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6210	delivery	5	40
16410	2019-12-01 08:04:53	2019-12-01	14	[{"id_menu":2,"count":1}]	382	delivery	5	19
16411	2019-12-01 08:10:35	2019-12-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3703	delivery	5	22
16412	2019-12-01 08:16:53	2019-12-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2522	pick-up	0	23
16413	2019-12-01 08:20:41	2019-12-01	17	[{"id_menu":4,"count":1}]	304	pick-up	0	17
16414	2019-12-01 08:38:30	2019-12-01	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4802	delivery	5	42
16415	2019-12-01 08:48:57	2019-12-01	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1865	delivery	5	40
16416	2019-12-01 08:55:16	2019-12-01	12	[{"id_menu":1,"count":1}]	6204	delivery	5	17
16417	2019-12-01 08:59:33	2019-12-01	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	6219	delivery	5	22
16418	2019-12-01 09:03:14	2019-12-01	14	[{"id_menu":2,"count":1}]	3754	pick-up	0	14
16419	2019-12-01 09:05:42	2019-12-01	12	[{"id_menu":1,"count":1}]	754	delivery	5	17
16420	2019-12-01 09:05:45	2019-12-01	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6237	delivery	5	43
16421	2019-12-01 09:13:43	2019-12-01	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":3}]	6241	delivery	5	26
16422	2019-12-01 09:13:57	2019-12-01	14	[{"id_menu":2,"count":1}]	256	pick-up	0	14
16423	2019-12-01 09:14:09	2019-12-01	12	[{"id_menu":3,"count":1}]	6205	delivery	5	17
16424	2019-12-01 09:19:49	2019-12-01	14	[{"id_menu":2,"count":1}]	6251	delivery	5	19
16425	2019-12-01 09:27:41	2019-12-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2417	delivery	5	23
16426	2019-12-01 09:42:12	2019-12-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6208	delivery	5	22
16427	2019-12-01 09:42:39	2019-12-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4072	pick-up	0	17
16428	2019-12-01 09:50:10	2019-12-01	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	6248	pick-up	0	29
16429	2019-12-01 09:55:32	2019-12-01	9	[{"id_menu":6,"count":1}]	6250	pick-up	0	9
16430	2019-12-01 09:57:29	2019-12-01	9	[{"id_menu":7,"count":1}]	6196	delivery	5	14
16431	2019-12-01 10:05:37	2019-12-01	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	84	pick-up	0	20
16432	2019-12-01 10:13:08	2019-12-01	8	[{"id_menu":5,"count":1}]	6015	delivery	5	13
16433	2019-12-01 10:34:56	2019-12-01	12	[{"id_menu":3,"count":1}]	229	pick-up	0	12
16434	2019-12-01 10:53:17	2019-12-01	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	5927	delivery	5	39
16435	2019-12-01 10:55:19	2019-12-01	12	[{"id_menu":3,"count":1}]	615	delivery	5	17
16436	2019-12-01 10:57:08	2019-12-01	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6194	delivery	5	48
16437	2019-12-01 11:04:06	2019-12-01	8	[{"id_menu":5,"count":1}]	1993	pick-up	0	8
16438	2019-12-01 11:05:27	2019-12-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	21	pick-up	0	23
16439	2019-12-01 11:10:15	2019-12-01	9	[{"id_menu":7,"count":1}]	6222	delivery	5	14
16440	2019-12-01 11:12:33	2019-12-01	9	[{"id_menu":6,"count":1}]	2375	pick-up	0	9
16441	2019-12-01 11:23:31	2019-12-01	9	[{"id_menu":7,"count":1}]	1019	pick-up	0	9
16442	2019-12-01 11:25:05	2019-12-01	9	[{"id_menu":7,"count":1}]	6220	pick-up	0	9
16443	2019-12-01 11:45:27	2019-12-01	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2829	pick-up	0	30
16444	2019-12-01 12:00:24	2019-12-01	9	[{"id_menu":6,"count":1}]	5787	delivery	5	14
16445	2019-12-01 12:12:09	2019-12-01	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	6207	delivery	5	43
16446	2019-12-01 12:17:57	2019-12-01	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	4622	delivery	5	26
16447	2019-12-01 12:20:08	2019-12-01	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	2567	pick-up	0	26
16448	2019-12-01 12:23:28	2019-12-01	9	[{"id_menu":6,"count":1}]	5790	pick-up	0	9
16449	2019-12-01 12:24:13	2019-12-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	486	delivery	5	26
16450	2019-12-01 12:29:54	2019-12-01	9	[{"id_menu":7,"count":1}]	5639	pick-up	0	9
16451	2019-12-01 12:41:59	2019-12-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3458	pick-up	0	17
16452	2019-12-01 12:47:29	2019-12-01	9	[{"id_menu":7,"count":1}]	4580	delivery	5	14
16453	2019-12-01 12:56:12	2019-12-01	14	[{"id_menu":2,"count":1}]	4782	pick-up	0	14
16454	2019-12-01 12:58:42	2019-12-01	9	[{"id_menu":6,"count":1}]	6193	delivery	5	14
16455	2019-12-01 13:03:15	2019-12-01	9	[{"id_menu":6,"count":1}]	5125	pick-up	0	9
16456	2019-12-01 13:05:39	2019-12-01	17	[{"id_menu":4,"count":1}]	1676	pick-up	0	17
16457	2019-12-01 13:20:17	2019-12-01	9	[{"id_menu":7,"count":1}]	2752	pick-up	0	9
16458	2019-12-01 13:24:40	2019-12-01	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6206	delivery	5	43
16459	2019-12-01 13:30:57	2019-12-01	17	[{"id_menu":4,"count":1}]	6173	pick-up	0	17
16460	2019-12-01 13:37:45	2019-12-01	17	[{"id_menu":4,"count":1}]	6224	delivery	5	22
16461	2019-12-01 13:38:08	2019-12-01	14	[{"id_menu":2,"count":1}]	2770	pick-up	0	14
16462	2019-12-01 13:40:50	2019-12-01	17	[{"id_menu":4,"count":1}]	378	pick-up	0	17
16463	2019-12-01 14:06:33	2019-12-01	12	[{"id_menu":1,"count":1}]	6226	delivery	5	17
16464	2019-12-01 14:15:05	2019-12-01	12	[{"id_menu":1,"count":1}]	586	delivery	5	17
16465	2019-12-01 14:15:45	2019-12-01	8	[{"id_menu":5,"count":1}]	198	pick-up	0	8
16466	2019-12-01 14:16:52	2019-12-01	17	[{"id_menu":4,"count":1}]	352	delivery	5	22
16467	2019-12-01 14:23:48	2019-12-01	17	[{"id_menu":4,"count":1}]	721	pick-up	0	17
16468	2019-12-01 14:26:26	2019-12-01	8	[{"id_menu":5,"count":1}]	401	pick-up	0	8
16469	2019-12-01 14:28:11	2019-12-01	9	[{"id_menu":7,"count":1}]	3563	delivery	5	14
16470	2019-12-01 14:31:46	2019-12-01	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	5151	delivery	5	23
16471	2019-12-01 14:37:04	2019-12-01	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6245	delivery	5	34
16472	2019-12-01 14:41:41	2019-12-01	9	[{"id_menu":7,"count":1}]	4568	pick-up	0	9
16473	2019-12-01 14:49:34	2019-12-01	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3945	delivery	5	43
16474	2019-12-01 14:54:20	2019-12-01	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	6242	pick-up	0	26
16475	2019-12-01 15:01:21	2019-12-01	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	386	pick-up	0	34
16476	2019-12-01 15:01:41	2019-12-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	6249	delivery	5	22
16477	2019-12-01 15:08:15	2019-12-01	17	[{"id_menu":4,"count":1}]	1194	delivery	5	22
16478	2019-12-01 15:10:52	2019-12-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3755	delivery	5	31
16479	2019-12-01 15:12:57	2019-12-01	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6200	delivery	5	43
16480	2019-12-01 15:15:24	2019-12-01	9	[{"id_menu":7,"count":1}]	4289	delivery	5	14
16481	2019-12-01 15:15:47	2019-12-01	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	5545	delivery	5	52
16482	2019-12-01 15:26:40	2019-12-01	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6213	delivery	5	37
16483	2019-12-01 15:29:06	2019-12-01	12	[{"id_menu":1,"count":1}]	6246	pick-up	0	12
16484	2019-12-01 15:34:35	2019-12-01	9	[{"id_menu":7,"count":1}]	2477	pick-up	0	9
16485	2019-12-01 15:46:27	2019-12-01	12	[{"id_menu":3,"count":1}]	6094	delivery	5	17
16486	2019-12-01 15:46:43	2019-12-01	9	[{"id_menu":6,"count":1}]	688	pick-up	0	9
16487	2019-12-01 15:55:43	2019-12-01	12	[{"id_menu":1,"count":1}]	2608	pick-up	0	12
16488	2019-12-01 16:14:57	2019-12-01	9	[{"id_menu":6,"count":3}]	5366	delivery	5	14
16489	2019-12-01 16:27:29	2019-12-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":3}]	3173	delivery	5	26
16490	2019-12-01 16:48:02	2019-12-01	9	[{"id_menu":7,"count":1}]	1919	pick-up	0	9
16491	2019-12-01 17:01:17	2019-12-01	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	5891	delivery	5	31
16492	2019-12-01 17:11:24	2019-12-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1547	pick-up	0	23
16493	2019-12-01 17:17:53	2019-12-01	9	[{"id_menu":7,"count":1}]	1370	delivery	5	14
16494	2019-12-01 17:19:03	2019-12-01	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5301	delivery	5	55
16495	2019-12-01 17:29:47	2019-12-01	12	[{"id_menu":1,"count":1}]	6247	pick-up	0	12
16496	2019-12-01 17:42:18	2019-12-01	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	4590	pick-up	0	26
16497	2019-12-01 17:46:57	2019-12-01	12	[{"id_menu":1,"count":1}]	330	pick-up	0	12
16498	2019-12-01 17:51:12	2019-12-01	14	[{"id_menu":2,"count":1}]	964	delivery	5	19
16499	2019-12-01 17:58:51	2019-12-01	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6252	delivery	5	40
16500	2019-12-01 18:21:36	2019-12-01	14	[{"id_menu":2,"count":1}]	4356	pick-up	0	14
16501	2019-12-01 18:23:28	2019-12-01	9	[{"id_menu":7,"count":1}]	3507	pick-up	0	9
16502	2019-12-01 18:29:26	2019-12-01	12	[{"id_menu":3,"count":1}]	2176	pick-up	0	12
16503	2019-12-01 18:32:25	2019-12-01	17	[{"id_menu":4,"count":1}]	6209	delivery	5	22
16504	2019-12-01 18:34:17	2019-12-01	9	[{"id_menu":7,"count":1}]	6257	delivery	5	14
16505	2019-12-01 18:37:12	2019-12-01	12	[{"id_menu":3,"count":1}]	6254	pick-up	0	12
16506	2019-12-01 18:37:36	2019-12-01	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2631	pick-up	0	21
16507	2019-12-01 18:48:32	2019-12-01	12	[{"id_menu":1,"count":1}]	946	pick-up	0	12
16508	2019-12-01 18:49:43	2019-12-01	9	[{"id_menu":7,"count":1}]	2526	delivery	5	14
16509	2019-12-01 18:54:11	2019-12-01	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1038	delivery	5	31
16510	2019-12-01 19:13:44	2019-12-01	8	[{"id_menu":5,"count":1}]	4424	delivery	5	13
16511	2019-12-01 19:17:01	2019-12-01	12	[{"id_menu":1,"count":1}]	71	pick-up	0	12
16512	2019-12-01 19:18:04	2019-12-01	9	[{"id_menu":6,"count":1}]	6231	delivery	5	14
16513	2019-12-01 19:23:39	2019-12-01	8	[{"id_menu":5,"count":1}]	3155	pick-up	0	8
16514	2019-12-01 19:24:05	2019-12-01	8	[{"id_menu":5,"count":1}]	4269	delivery	5	13
16515	2019-12-01 19:37:05	2019-12-01	14	[{"id_menu":2,"count":1}]	2623	delivery	5	19
16516	2019-12-01 19:49:48	2019-12-01	8	[{"id_menu":5,"count":1}]	6163	pick-up	0	8
16517	2019-12-01 19:50:11	2019-12-01	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":3}]	1425	pick-up	0	26
16518	2019-12-01 19:54:37	2019-12-01	9	[{"id_menu":6,"count":1}]	6211	delivery	5	14
16519	2019-12-01 19:56:33	2019-12-01	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3015	pick-up	0	26
16520	2019-12-01 19:59:13	2019-12-01	8	[{"id_menu":5,"count":1}]	6240	delivery	5	13
16521	2019-12-01 20:18:03	2019-12-01	8	[{"id_menu":5,"count":1}]	4994	delivery	5	13
16522	2019-12-01 20:29:39	2019-12-01	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	6218	delivery	5	25
16523	2019-12-01 20:32:53	2019-12-01	17	[{"id_menu":4,"count":1}]	6244	delivery	5	22
16524	2019-12-01 20:40:33	2019-12-01	14	[{"id_menu":2,"count":1}]	6199	pick-up	0	14
16525	2019-12-01 20:49:53	2019-12-01	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6228	delivery	5	43
16526	2019-12-01 20:51:17	2019-12-01	14	[{"id_menu":2,"count":1}]	1329	pick-up	0	14
16527	2019-12-01 20:55:59	2019-12-01	9	[{"id_menu":7,"count":2}]	1166	pick-up	0	9
16528	2019-12-01 20:59:37	2019-12-01	9	[{"id_menu":6,"count":1}]	6197	delivery	5	14
16529	2019-12-01 21:04:58	2019-12-01	8	[{"id_menu":5,"count":1}]	2662	pick-up	0	8
16530	2019-12-01 21:05:30	2019-12-01	12	[{"id_menu":3,"count":1}]	1092	pick-up	0	12
16531	2019-12-01 21:08:36	2019-12-01	9	[{"id_menu":6,"count":1}]	3131	delivery	5	14
16532	2019-12-01 21:13:09	2019-12-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6223	delivery	5	28
16533	2019-12-01 21:13:59	2019-12-01	9	[{"id_menu":7,"count":1}]	6236	delivery	5	14
16534	2019-12-01 21:17:19	2019-12-01	9	[{"id_menu":7,"count":1}]	365	delivery	5	14
16535	2019-12-01 21:20:39	2019-12-01	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6203	delivery	5	43
16536	2019-12-01 21:32:43	2019-12-01	12	[{"id_menu":1,"count":1}]	6230	delivery	5	17
16537	2019-12-01 21:40:16	2019-12-01	8	[{"id_menu":5,"count":1}]	822	pick-up	0	8
16538	2019-12-01 21:45:27	2019-12-01	9	[{"id_menu":7,"count":1}]	6256	delivery	5	14
16539	2019-12-01 21:48:34	2019-12-01	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	5707	delivery	5	46
16540	2019-12-01 21:49:43	2019-12-01	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2850	pick-up	0	21
16541	2019-12-01 21:52:37	2019-12-01	14	[{"id_menu":2,"count":1}]	1373	pick-up	0	14
16542	2019-12-01 21:57:26	2019-12-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4300	pick-up	0	23
16543	2019-12-01 22:11:18	2019-12-01	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	5192	delivery	5	26
16544	2019-12-01 22:12:39	2019-12-01	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2107	pick-up	0	25
16545	2019-12-01 22:35:05	2019-12-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3491	pick-up	0	23
16546	2019-12-01 22:40:06	2019-12-01	9	[{"id_menu":7,"count":1}]	5994	delivery	5	14
16547	2019-12-01 22:50:49	2019-12-01	8	[{"id_menu":5,"count":2}]	4855	delivery	5	13
16548	2019-12-01 23:00:02	2019-12-01	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6227	delivery	5	43
16549	2019-12-01 23:01:27	2019-12-01	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1842	pick-up	0	29
16550	2019-12-01 23:04:14	2019-12-01	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	340	pick-up	0	34
16551	2019-12-01 23:06:19	2019-12-01	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	6253	delivery	5	23
16552	2019-12-01 23:11:32	2019-12-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5638	delivery	5	23
16553	2019-12-01 23:22:26	2019-12-01	17	[{"id_menu":4,"count":1}]	2511	delivery	5	22
16554	2019-12-01 23:43:19	2019-12-01	8	[{"id_menu":5,"count":1}]	6202	pick-up	0	8
16555	2019-12-01 23:47:59	2019-12-01	12	[{"id_menu":1,"count":1}]	6232	pick-up	0	12
16556	2019-12-01 23:51:42	2019-12-01	12	[{"id_menu":3,"count":1}]	2673	delivery	5	17
16557	2019-12-01 23:55:07	2019-12-01	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	399	pick-up	0	24
16558	2019-12-02 00:05:21	2019-12-02	14	[{"id_menu":2,"count":1}]	807	pick-up	0	14
16559	2019-12-02 01:20:17	2019-12-02	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1587	delivery	5	40
16560	2019-12-02 01:20:37	2019-12-02	14	[{"id_menu":2,"count":1}]	6273	delivery	5	19
16561	2019-12-02 02:02:30	2019-12-02	8	[{"id_menu":5,"count":1}]	256	delivery	5	13
16562	2019-12-02 02:06:14	2019-12-02	9	[{"id_menu":6,"count":1}]	5201	pick-up	0	9
16563	2019-12-02 02:08:41	2019-12-02	14	[{"id_menu":2,"count":1}]	6279	pick-up	0	14
16564	2019-12-02 02:10:10	2019-12-02	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	765	delivery	5	39
16565	2019-12-02 02:23:52	2019-12-02	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	6288	delivery	5	26
16566	2019-12-02 02:24:49	2019-12-02	12	[{"id_menu":1,"count":1}]	235	pick-up	0	12
16567	2019-12-02 02:33:57	2019-12-02	12	[{"id_menu":3,"count":1}]	5075	pick-up	0	12
16568	2019-12-02 02:56:43	2019-12-02	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	784	pick-up	0	17
16569	2019-12-02 03:10:19	2019-12-02	9	[{"id_menu":7,"count":1}]	6304	pick-up	0	9
16570	2019-12-02 03:12:59	2019-12-02	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	6277	delivery	5	48
16571	2019-12-02 03:40:31	2019-12-02	12	[{"id_menu":3,"count":1}]	286	pick-up	0	12
16572	2019-12-02 04:03:12	2019-12-02	8	[{"id_menu":5,"count":1}]	6300	delivery	5	13
16573	2019-12-02 04:21:13	2019-12-02	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	6286	delivery	5	38
16574	2019-12-02 04:21:39	2019-12-02	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1866	delivery	5	34
16575	2019-12-02 04:39:06	2019-12-02	12	[{"id_menu":1,"count":1}]	6264	pick-up	0	12
16576	2019-12-02 04:51:46	2019-12-02	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1803	delivery	5	31
16577	2019-12-02 05:10:58	2019-12-02	8	[{"id_menu":5,"count":1}]	2815	pick-up	0	8
16578	2019-12-02 05:21:44	2019-12-02	9	[{"id_menu":7,"count":1}]	6046	pick-up	0	9
16579	2019-12-02 05:25:59	2019-12-02	17	[{"id_menu":4,"count":1}]	2052	pick-up	0	17
16580	2019-12-02 05:40:14	2019-12-02	17	[{"id_menu":4,"count":1}]	1555	pick-up	0	17
16581	2019-12-02 05:43:59	2019-12-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5718	delivery	5	23
16582	2019-12-02 05:55:30	2019-12-02	14	[{"id_menu":2,"count":2}]	2646	pick-up	0	14
16583	2019-12-02 06:07:07	2019-12-02	8	[{"id_menu":5,"count":1}]	302	pick-up	0	8
16584	2019-12-02 06:12:05	2019-12-02	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	189	pick-up	0	31
16585	2019-12-02 06:28:38	2019-12-02	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3343	delivery	5	53
16586	2019-12-02 06:46:25	2019-12-02	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6305	delivery	5	44
16587	2019-12-02 06:47:10	2019-12-02	14	[{"id_menu":2,"count":1}]	6281	delivery	5	19
16588	2019-12-02 08:05:40	2019-12-02	17	[{"id_menu":4,"count":1}]	3863	delivery	5	22
16589	2019-12-02 08:12:30	2019-12-02	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2460	pick-up	0	20
16590	2019-12-02 08:14:07	2019-12-02	12	[{"id_menu":3,"count":1}]	3451	delivery	5	17
16591	2019-12-02 08:52:53	2019-12-02	17	[{"id_menu":4,"count":1}]	5610	delivery	5	22
16592	2019-12-02 09:02:08	2019-12-02	14	[{"id_menu":2,"count":1}]	2217	pick-up	0	14
16593	2019-12-02 09:07:09	2019-12-02	9	[{"id_menu":6,"count":1}]	3168	pick-up	0	9
16594	2019-12-02 09:52:45	2019-12-02	17	[{"id_menu":4,"count":1}]	5354	pick-up	0	17
16595	2019-12-02 10:01:11	2019-12-02	9	[{"id_menu":6,"count":1}]	4034	delivery	5	14
16596	2019-12-02 10:22:43	2019-12-02	9	[{"id_menu":6,"count":1}]	233	pick-up	0	9
16597	2019-12-02 10:55:17	2019-12-02	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	5613	delivery	5	26
16598	2019-12-02 10:57:10	2019-12-02	9	[{"id_menu":7,"count":1}]	4988	pick-up	0	9
16599	2019-12-02 11:09:01	2019-12-02	9	[{"id_menu":7,"count":1}]	2405	delivery	5	14
16600	2019-12-02 11:18:23	2019-12-02	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	6296	delivery	5	25
16601	2019-12-02 11:31:11	2019-12-02	9	[{"id_menu":6,"count":1}]	5756	delivery	5	14
16602	2019-12-02 11:50:32	2019-12-02	14	[{"id_menu":2,"count":1}]	4682	delivery	5	19
16603	2019-12-02 12:03:28	2019-12-02	14	[{"id_menu":2,"count":1}]	3135	delivery	5	19
16604	2019-12-02 12:18:05	2019-12-02	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4258	delivery	5	31
16605	2019-12-02 12:21:36	2019-12-02	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	6269	delivery	5	34
16606	2019-12-02 12:36:27	2019-12-02	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	3756	pick-up	0	20
16607	2019-12-02 12:45:26	2019-12-02	9	[{"id_menu":6,"count":1}]	3570	pick-up	0	9
16608	2019-12-02 13:21:09	2019-12-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3022	delivery	5	31
16609	2019-12-02 13:39:30	2019-12-02	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6292	pick-up	0	26
16610	2019-12-02 14:14:56	2019-12-02	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5824	pick-up	0	39
16611	2019-12-02 14:23:15	2019-12-02	17	[{"id_menu":4,"count":1}]	1314	pick-up	0	17
16612	2019-12-02 14:44:58	2019-12-02	17	[{"id_menu":4,"count":2}]	1106	pick-up	0	17
16613	2019-12-02 14:56:08	2019-12-02	14	[{"id_menu":2,"count":2}]	6265	delivery	5	19
16614	2019-12-02 15:01:01	2019-12-02	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	262	pick-up	0	22
16615	2019-12-02 15:24:43	2019-12-02	12	[{"id_menu":3,"count":1}]	3174	delivery	5	17
16616	2019-12-02 15:42:36	2019-12-02	12	[{"id_menu":3,"count":1}]	1566	pick-up	0	12
16617	2019-12-02 15:46:47	2019-12-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3483	pick-up	0	23
16618	2019-12-02 15:56:55	2019-12-02	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5222	delivery	5	43
16619	2019-12-02 16:00:40	2019-12-02	9	[{"id_menu":7,"count":1}]	1541	pick-up	0	9
16620	2019-12-02 16:01:33	2019-12-02	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2649	delivery	5	51
16621	2019-12-02 16:02:29	2019-12-02	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	24	delivery	5	31
16622	2019-12-02 16:16:37	2019-12-02	12	[{"id_menu":1,"count":1}]	6242	pick-up	0	12
16623	2019-12-02 16:24:26	2019-12-02	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	1495	delivery	5	34
16624	2019-12-02 16:34:58	2019-12-02	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6307	delivery	5	46
16625	2019-12-02 16:36:35	2019-12-02	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":2}]	2885	delivery	5	34
16626	2019-12-02 16:39:24	2019-12-02	8	[{"id_menu":5,"count":1}]	92	pick-up	0	8
16627	2019-12-02 16:42:34	2019-12-02	9	[{"id_menu":7,"count":1}]	6299	pick-up	0	9
16628	2019-12-02 17:14:38	2019-12-02	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	3749	delivery	5	35
16629	2019-12-02 17:24:30	2019-12-02	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	6282	pick-up	0	26
16630	2019-12-02 17:28:27	2019-12-02	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3827	pick-up	0	22
16631	2019-12-02 17:48:01	2019-12-02	9	[{"id_menu":6,"count":1}]	2594	pick-up	0	9
16632	2019-12-02 17:58:04	2019-12-02	9	[{"id_menu":7,"count":1}]	3567	pick-up	0	9
16633	2019-12-02 18:00:24	2019-12-02	17	[{"id_menu":4,"count":1}]	3693	pick-up	0	17
16634	2019-12-02 18:07:40	2019-12-02	8	[{"id_menu":5,"count":1}]	6291	delivery	5	13
16635	2019-12-02 18:30:24	2019-12-02	12	[{"id_menu":1,"count":2}]	586	pick-up	0	12
16636	2019-12-02 19:02:37	2019-12-02	9	[{"id_menu":7,"count":1}]	6297	pick-up	0	9
16637	2019-12-02 19:04:56	2019-12-02	12	[{"id_menu":1,"count":1}]	5154	delivery	5	17
16638	2019-12-02 19:08:37	2019-12-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1654	pick-up	0	23
16639	2019-12-02 19:12:31	2019-12-02	9	[{"id_menu":7,"count":1}]	837	pick-up	0	9
16640	2019-12-02 19:27:40	2019-12-02	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4766	delivery	5	35
16641	2019-12-02 19:33:59	2019-12-02	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	811	pick-up	0	26
16642	2019-12-02 19:36:27	2019-12-02	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2191	pick-up	0	20
16643	2019-12-02 19:50:10	2019-12-02	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5425	delivery	5	22
16644	2019-12-02 19:55:16	2019-12-02	17	[{"id_menu":4,"count":1}]	6278	delivery	5	22
16645	2019-12-02 20:09:48	2019-12-02	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	6263	delivery	5	40
16646	2019-12-02 20:18:03	2019-12-02	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2873	pick-up	0	29
16647	2019-12-02 20:22:41	2019-12-02	14	[{"id_menu":2,"count":2}]	3486	delivery	5	19
16648	2019-12-02 20:46:21	2019-12-02	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2523	pick-up	0	29
16649	2019-12-02 20:59:26	2019-12-02	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1313	delivery	5	31
16650	2019-12-02 21:08:49	2019-12-02	9	[{"id_menu":7,"count":1}]	5873	delivery	5	14
16651	2019-12-02 21:18:01	2019-12-02	14	[{"id_menu":2,"count":1}]	6301	delivery	5	19
16652	2019-12-02 21:22:03	2019-12-02	9	[{"id_menu":6,"count":1}]	5803	delivery	5	14
16653	2019-12-02 22:20:23	2019-12-02	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6298	delivery	5	31
16654	2019-12-02 22:28:00	2019-12-02	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4248	pick-up	0	31
16655	2019-12-02 22:31:24	2019-12-02	9	[{"id_menu":7,"count":1}]	3818	pick-up	0	9
16656	2019-12-02 22:33:07	2019-12-02	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	6309	delivery	5	43
16657	2019-12-02 22:45:50	2019-12-02	9	[{"id_menu":7,"count":1}]	6266	pick-up	0	9
16658	2019-12-02 23:03:00	2019-12-02	12	[{"id_menu":1,"count":1}]	3976	pick-up	0	12
16659	2019-12-02 23:03:28	2019-12-02	9	[{"id_menu":7,"count":1}]	6290	delivery	5	14
16660	2019-12-02 23:30:32	2019-12-02	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	5004	delivery	5	26
16661	2019-12-02 23:53:07	2019-12-02	9	[{"id_menu":6,"count":1}]	6258	delivery	5	14
16662	2019-12-03 00:00:21	2019-12-03	9	[{"id_menu":7,"count":1}]	6353	delivery	5	14
16663	2019-12-03 00:03:19	2019-12-03	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4250	pick-up	0	38
16664	2019-12-03 00:37:58	2019-12-03	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4007	pick-up	0	17
16665	2019-12-03 00:43:35	2019-12-03	9	[{"id_menu":7,"count":1}]	3224	delivery	5	14
16666	2019-12-03 00:45:38	2019-12-03	9	[{"id_menu":7,"count":1}]	6326	delivery	5	14
16667	2019-12-03 00:53:45	2019-12-03	9	[{"id_menu":6,"count":1}]	6336	delivery	5	14
16668	2019-12-03 00:57:25	2019-12-03	9	[{"id_menu":7,"count":1}]	6335	delivery	5	14
16669	2019-12-03 01:09:27	2019-12-03	14	[{"id_menu":2,"count":1}]	6323	delivery	5	19
16670	2019-12-03 01:13:40	2019-12-03	14	[{"id_menu":2,"count":1}]	512	pick-up	0	14
16671	2019-12-03 01:36:00	2019-12-03	9	[{"id_menu":7,"count":1}]	2133	pick-up	0	9
16672	2019-12-03 01:42:44	2019-12-03	12	[{"id_menu":3,"count":1}]	6328	delivery	5	17
16673	2019-12-03 02:09:29	2019-12-03	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	6232	pick-up	0	26
16674	2019-12-03 02:11:50	2019-12-03	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	6342	pick-up	0	24
16675	2019-12-03 02:42:35	2019-12-03	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	536	pick-up	0	17
16676	2019-12-03 02:44:46	2019-12-03	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	6334	delivery	5	23
16677	2019-12-03 02:50:25	2019-12-03	8	[{"id_menu":5,"count":1}]	6317	delivery	5	13
16678	2019-12-03 03:30:11	2019-12-03	9	[{"id_menu":6,"count":1}]	3843	delivery	5	14
16679	2019-12-03 03:46:30	2019-12-03	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6318	delivery	5	22
16680	2019-12-03 03:54:51	2019-12-03	9	[{"id_menu":7,"count":1}]	6000	delivery	5	14
16681	2019-12-03 04:10:23	2019-12-03	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	6362	delivery	5	26
16682	2019-12-03 04:16:26	2019-12-03	17	[{"id_menu":4,"count":1}]	3848	pick-up	0	17
16683	2019-12-03 04:25:36	2019-12-03	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	6090	pick-up	0	20
16684	2019-12-03 04:29:41	2019-12-03	14	[{"id_menu":2,"count":1}]	71	delivery	5	19
16685	2019-12-03 04:34:01	2019-12-03	14	[{"id_menu":2,"count":1}]	6361	delivery	5	19
16686	2019-12-03 04:34:39	2019-12-03	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2308	pick-up	0	23
16687	2019-12-03 04:41:16	2019-12-03	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	5220	delivery	5	35
16688	2019-12-03 04:52:00	2019-12-03	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3456	delivery	5	28
16689	2019-12-03 04:55:09	2019-12-03	8	[{"id_menu":5,"count":1}]	142	pick-up	0	8
16690	2019-12-03 05:05:51	2019-12-03	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5110	delivery	5	23
16691	2019-12-03 05:20:19	2019-12-03	9	[{"id_menu":7,"count":1}]	6331	delivery	5	14
16692	2019-12-03 05:21:20	2019-12-03	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	2638	delivery	5	36
16693	2019-12-03 05:41:05	2019-12-03	14	[{"id_menu":2,"count":1}]	626	pick-up	0	14
16694	2019-12-03 05:51:34	2019-12-03	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	575	delivery	5	53
16695	2019-12-03 06:05:35	2019-12-03	14	[{"id_menu":2,"count":1}]	6316	pick-up	0	14
16696	2019-12-03 06:19:08	2019-12-03	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2237	pick-up	0	31
16697	2019-12-03 06:21:57	2019-12-03	14	[{"id_menu":2,"count":1}]	4223	delivery	5	19
16698	2019-12-03 06:26:02	2019-12-03	12	[{"id_menu":3,"count":1}]	2232	pick-up	0	12
16699	2019-12-03 06:54:11	2019-12-03	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6338	pick-up	0	18
16700	2019-12-03 06:56:01	2019-12-03	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	6320	delivery	5	22
16701	2019-12-03 07:14:33	2019-12-03	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2608	pick-up	0	33
16702	2019-12-03 07:43:51	2019-12-03	12	[{"id_menu":3,"count":1}]	6367	delivery	5	17
16703	2019-12-03 07:46:32	2019-12-03	9	[{"id_menu":7,"count":1}]	4088	delivery	5	14
16704	2019-12-03 08:00:57	2019-12-03	8	[{"id_menu":5,"count":1}]	6315	delivery	5	13
16705	2019-12-03 08:05:10	2019-12-03	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	3459	delivery	5	26
16706	2019-12-03 08:09:59	2019-12-03	9	[{"id_menu":7,"count":1}]	4274	delivery	5	14
16707	2019-12-03 08:11:10	2019-12-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6369	pick-up	0	23
16708	2019-12-03 08:14:13	2019-12-03	17	[{"id_menu":4,"count":1}]	403	delivery	5	22
16709	2019-12-03 08:20:20	2019-12-03	14	[{"id_menu":2,"count":1}]	770	pick-up	0	14
16710	2019-12-03 08:20:40	2019-12-03	17	[{"id_menu":4,"count":1}]	5180	pick-up	0	17
16711	2019-12-03 08:45:26	2019-12-03	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3365	pick-up	0	29
16712	2019-12-03 09:00:44	2019-12-03	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4045	delivery	5	37
16713	2019-12-03 09:14:10	2019-12-03	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1282	delivery	5	26
16714	2019-12-03 09:27:02	2019-12-03	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2021	delivery	5	28
16715	2019-12-03 09:40:39	2019-12-03	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	5174	delivery	5	26
16716	2019-12-03 09:42:14	2019-12-03	9	[{"id_menu":6,"count":1}]	6319	delivery	5	14
16717	2019-12-03 09:58:54	2019-12-03	12	[{"id_menu":1,"count":1}]	6349	delivery	5	17
16718	2019-12-03 10:11:29	2019-12-03	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6350	delivery	5	51
16719	2019-12-03 10:26:13	2019-12-03	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	260	pick-up	0	26
16720	2019-12-03 10:26:19	2019-12-03	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	6345	delivery	5	26
16721	2019-12-03 10:27:59	2019-12-03	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5527	delivery	5	43
16722	2019-12-03 10:42:21	2019-12-03	14	[{"id_menu":2,"count":1}]	3817	delivery	5	19
16723	2019-12-03 10:43:57	2019-12-03	9	[{"id_menu":6,"count":1}]	1813	pick-up	0	9
16724	2019-12-03 10:48:46	2019-12-03	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3575	delivery	5	27
16725	2019-12-03 10:59:11	2019-12-03	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2858	delivery	5	40
16726	2019-12-03 11:07:06	2019-12-03	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	6322	delivery	5	26
16727	2019-12-03 11:26:18	2019-12-03	9	[{"id_menu":7,"count":1}]	2820	pick-up	0	9
16728	2019-12-03 11:34:33	2019-12-03	14	[{"id_menu":2,"count":1}]	2399	pick-up	0	14
16729	2019-12-03 11:47:54	2019-12-03	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	3153	delivery	5	29
16730	2019-12-03 12:15:41	2019-12-03	12	[{"id_menu":1,"count":1}]	6344	delivery	5	17
16731	2019-12-03 12:28:40	2019-12-03	9	[{"id_menu":6,"count":1}]	6360	delivery	5	14
16732	2019-12-03 13:13:47	2019-12-03	9	[{"id_menu":7,"count":1}]	5430	pick-up	0	9
16733	2019-12-03 13:27:57	2019-12-03	9	[{"id_menu":6,"count":1}]	6364	pick-up	0	9
16734	2019-12-03 13:50:12	2019-12-03	9	[{"id_menu":6,"count":1}]	3947	delivery	5	14
16735	2019-12-03 14:11:53	2019-12-03	17	[{"id_menu":4,"count":1}]	4735	pick-up	0	17
16736	2019-12-03 14:33:16	2019-12-03	9	[{"id_menu":7,"count":1}]	6001	delivery	5	14
16737	2019-12-03 14:40:39	2019-12-03	17	[{"id_menu":4,"count":1}]	663	delivery	5	22
16738	2019-12-03 15:00:05	2019-12-03	9	[{"id_menu":7,"count":1}]	6327	delivery	5	14
16806	2019-12-04 05:58:37	2019-12-04	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6421	delivery	5	22
16739	2019-12-03 15:01:16	2019-12-03	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6366	delivery	5	43
16740	2019-12-03 15:41:27	2019-12-03	17	[{"id_menu":4,"count":1}]	4462	delivery	5	22
16741	2019-12-03 15:47:36	2019-12-03	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	257	delivery	5	31
16742	2019-12-03 16:13:22	2019-12-03	12	[{"id_menu":1,"count":1}]	6339	delivery	5	17
16743	2019-12-03 16:18:54	2019-12-03	9	[{"id_menu":6,"count":1}]	3235	delivery	5	14
16744	2019-12-03 16:30:20	2019-12-03	14	[{"id_menu":2,"count":1}]	4922	pick-up	0	14
16745	2019-12-03 16:45:33	2019-12-03	9	[{"id_menu":7,"count":1}]	4658	pick-up	0	9
16746	2019-12-03 16:51:45	2019-12-03	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	33	delivery	5	26
16747	2019-12-03 16:58:26	2019-12-03	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2970	delivery	5	34
16748	2019-12-03 17:03:34	2019-12-03	8	[{"id_menu":5,"count":1}]	6346	delivery	5	13
16749	2019-12-03 17:04:07	2019-12-03	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3502	delivery	5	52
16750	2019-12-03 17:29:47	2019-12-03	9	[{"id_menu":6,"count":1}]	5089	delivery	5	14
16751	2019-12-03 17:44:16	2019-12-03	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	6347	delivery	5	31
16752	2019-12-03 18:20:23	2019-12-03	8	[{"id_menu":5,"count":2}]	6084	delivery	5	13
16753	2019-12-03 18:22:31	2019-12-03	12	[{"id_menu":1,"count":1}]	490	delivery	5	17
16754	2019-12-03 18:26:12	2019-12-03	9	[{"id_menu":6,"count":1}]	6341	delivery	5	14
16755	2019-12-03 18:27:22	2019-12-03	14	[{"id_menu":2,"count":1}]	1183	pick-up	0	14
16756	2019-12-03 18:32:45	2019-12-03	9	[{"id_menu":6,"count":1}]	228	pick-up	0	9
16757	2019-12-03 18:34:47	2019-12-03	14	[{"id_menu":2,"count":1}]	2466	delivery	5	19
16758	2019-12-03 18:55:00	2019-12-03	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	6312	delivery	5	34
16759	2019-12-03 18:59:43	2019-12-03	12	[{"id_menu":1,"count":1}]	4708	delivery	5	17
16760	2019-12-03 19:23:31	2019-12-03	14	[{"id_menu":2,"count":1}]	2570	pick-up	0	14
16761	2019-12-03 19:27:46	2019-12-03	9	[{"id_menu":6,"count":1}]	6333	pick-up	0	9
16762	2019-12-03 19:55:00	2019-12-03	8	[{"id_menu":5,"count":2}]	6330	delivery	5	13
16763	2019-12-03 20:01:34	2019-12-03	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5783	pick-up	0	48
16764	2019-12-03 20:40:01	2019-12-03	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6365	pick-up	0	32
16765	2019-12-03 20:59:56	2019-12-03	17	[{"id_menu":4,"count":1}]	2244	pick-up	0	17
16766	2019-12-03 21:17:07	2019-12-03	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4673	pick-up	0	31
16767	2019-12-03 21:21:03	2019-12-03	9	[{"id_menu":7,"count":1}]	6368	pick-up	0	9
16768	2019-12-03 21:22:13	2019-12-03	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4411	pick-up	0	29
16769	2019-12-03 21:38:27	2019-12-03	9	[{"id_menu":7,"count":1}]	6325	delivery	5	14
16770	2019-12-03 21:53:40	2019-12-03	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	6351	pick-up	0	35
16771	2019-12-03 21:55:41	2019-12-03	17	[{"id_menu":4,"count":1}]	2975	delivery	5	22
16772	2019-12-03 22:08:00	2019-12-03	12	[{"id_menu":3,"count":1}]	6201	delivery	5	17
16773	2019-12-03 22:55:44	2019-12-03	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	6343	delivery	5	26
16774	2019-12-03 23:38:54	2019-12-03	12	[{"id_menu":1,"count":1}]	552	pick-up	0	12
16775	2019-12-03 23:47:57	2019-12-03	17	[{"id_menu":4,"count":1}]	6313	delivery	5	22
16776	2019-12-03 23:57:34	2019-12-03	9	[{"id_menu":6,"count":1}]	6355	pick-up	0	9
16777	2019-12-04 00:20:47	2019-12-04	8	[{"id_menu":5,"count":1}]	4604	delivery	5	13
16778	2019-12-04 00:36:03	2019-12-04	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3155	pick-up	0	17
16779	2019-12-04 00:39:42	2019-12-04	14	[{"id_menu":2,"count":1}]	4744	delivery	5	19
16780	2019-12-04 00:50:38	2019-12-04	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2785	delivery	5	34
16781	2019-12-04 00:57:30	2019-12-04	9	[{"id_menu":7,"count":1}]	6372	delivery	5	14
16782	2019-12-04 01:00:58	2019-12-04	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2602	pick-up	0	26
16783	2019-12-04 01:23:53	2019-12-04	9	[{"id_menu":7,"count":1}]	4594	delivery	5	14
16784	2019-12-04 01:28:34	2019-12-04	17	[{"id_menu":4,"count":1}]	6419	delivery	5	22
16785	2019-12-04 01:40:58	2019-12-04	14	[{"id_menu":2,"count":1}]	6393	delivery	5	19
16786	2019-12-04 02:10:18	2019-12-04	9	[{"id_menu":7,"count":1}]	6412	pick-up	0	9
16787	2019-12-04 02:13:00	2019-12-04	17	[{"id_menu":4,"count":1}]	2497	pick-up	0	17
16788	2019-12-04 02:22:31	2019-12-04	9	[{"id_menu":7,"count":1}]	699	delivery	5	14
16789	2019-12-04 02:25:07	2019-12-04	17	[{"id_menu":4,"count":1}]	6402	pick-up	0	17
16790	2019-12-04 02:28:43	2019-12-04	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	6381	delivery	5	27
16791	2019-12-04 02:44:58	2019-12-04	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	6400	delivery	5	26
16792	2019-12-04 03:05:43	2019-12-04	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	6411	pick-up	0	41
16793	2019-12-04 03:20:04	2019-12-04	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	5461	delivery	5	27
16794	2019-12-04 03:27:06	2019-12-04	8	[{"id_menu":5,"count":1}]	6405	pick-up	0	8
16795	2019-12-04 03:29:40	2019-12-04	9	[{"id_menu":6,"count":1}]	3330	pick-up	0	9
16796	2019-12-04 03:43:43	2019-12-04	8	[{"id_menu":5,"count":1}]	372	delivery	5	13
16797	2019-12-04 03:50:44	2019-12-04	9	[{"id_menu":6,"count":1}]	233	pick-up	0	9
16798	2019-12-04 04:18:54	2019-12-04	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4461	pick-up	0	26
16799	2019-12-04 04:24:24	2019-12-04	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4075	delivery	5	23
16800	2019-12-04 04:25:23	2019-12-04	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	5717	delivery	5	43
16801	2019-12-04 04:39:53	2019-12-04	12	[{"id_menu":3,"count":1}]	3480	pick-up	0	12
16802	2019-12-04 04:44:56	2019-12-04	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	3403	delivery	5	31
16803	2019-12-04 05:00:30	2019-12-04	9	[{"id_menu":7,"count":1}]	1917	pick-up	0	9
16804	2019-12-04 05:10:17	2019-12-04	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":2}]	6414	delivery	5	26
16805	2019-12-04 05:30:31	2019-12-04	12	[{"id_menu":1,"count":1}]	6397	delivery	5	17
16807	2019-12-04 06:17:51	2019-12-04	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	4189	delivery	5	23
16808	2019-12-04 07:01:55	2019-12-04	12	[{"id_menu":3,"count":1}]	2646	delivery	5	17
16809	2019-12-04 07:04:20	2019-12-04	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5188	delivery	5	31
16810	2019-12-04 07:07:56	2019-12-04	8	[{"id_menu":5,"count":1}]	382	pick-up	0	8
16811	2019-12-04 07:42:35	2019-12-04	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	6382	delivery	5	22
16812	2019-12-04 07:44:05	2019-12-04	12	[{"id_menu":1,"count":1}]	4424	delivery	5	17
16813	2019-12-04 07:49:56	2019-12-04	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	5658	delivery	5	40
16814	2019-12-04 07:51:51	2019-12-04	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1988	pick-up	0	25
16815	2019-12-04 08:08:54	2019-12-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":3}]	2993	pick-up	0	23
16816	2019-12-04 08:12:44	2019-12-04	12	[{"id_menu":3,"count":1}]	6398	delivery	5	17
16817	2019-12-04 08:18:12	2019-12-04	12	[{"id_menu":1,"count":1}]	2398	pick-up	0	12
16818	2019-12-04 08:23:19	2019-12-04	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1674	pick-up	0	29
16819	2019-12-04 08:25:25	2019-12-04	9	[{"id_menu":7,"count":1}]	3261	delivery	5	14
16820	2019-12-04 08:26:06	2019-12-04	8	[{"id_menu":5,"count":1}]	6395	delivery	5	13
16821	2019-12-04 08:44:31	2019-12-04	12	[{"id_menu":1,"count":1}]	257	pick-up	0	12
16822	2019-12-04 08:47:57	2019-12-04	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	6390	delivery	5	29
16823	2019-12-04 08:50:38	2019-12-04	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2416	delivery	5	22
16824	2019-12-04 09:03:36	2019-12-04	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	6374	pick-up	0	21
16825	2019-12-04 09:19:13	2019-12-04	8	[{"id_menu":5,"count":1}]	3548	delivery	5	13
16826	2019-12-04 09:35:38	2019-12-04	8	[{"id_menu":5,"count":1}]	3527	pick-up	0	8
16827	2019-12-04 09:50:37	2019-12-04	14	[{"id_menu":2,"count":1}]	3170	delivery	5	19
16828	2019-12-04 09:51:30	2019-12-04	9	[{"id_menu":6,"count":1}]	2379	pick-up	0	9
16829	2019-12-04 10:12:19	2019-12-04	9	[{"id_menu":6,"count":1}]	4056	delivery	5	14
16830	2019-12-04 10:13:08	2019-12-04	14	[{"id_menu":2,"count":1}]	2808	pick-up	0	14
16831	2019-12-04 10:26:57	2019-12-04	9	[{"id_menu":6,"count":1}]	6420	delivery	5	14
16832	2019-12-04 10:31:38	2019-12-04	12	[{"id_menu":1,"count":1}]	2667	pick-up	0	12
16833	2019-12-04 10:51:02	2019-12-04	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6418	delivery	5	48
16834	2019-12-04 10:54:40	2019-12-04	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	6423	delivery	5	26
16835	2019-12-04 11:03:52	2019-12-04	17	[{"id_menu":4,"count":1}]	6385	pick-up	0	17
16836	2019-12-04 11:20:32	2019-12-04	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	3704	pick-up	0	26
16837	2019-12-04 11:24:31	2019-12-04	8	[{"id_menu":5,"count":1}]	6413	delivery	5	13
16838	2019-12-04 11:26:18	2019-12-04	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2833	delivery	5	37
16839	2019-12-04 11:27:00	2019-12-04	9	[{"id_menu":7,"count":1}]	3863	delivery	5	14
16840	2019-12-04 11:29:52	2019-12-04	9	[{"id_menu":7,"count":1}]	6403	delivery	5	14
16841	2019-12-04 11:39:14	2019-12-04	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1227	pick-up	0	29
16842	2019-12-04 12:09:04	2019-12-04	8	[{"id_menu":5,"count":1}]	906	pick-up	0	8
16843	2019-12-04 12:17:06	2019-12-04	12	[{"id_menu":1,"count":1}]	1638	delivery	5	17
16844	2019-12-04 12:18:07	2019-12-04	12	[{"id_menu":3,"count":1}]	71	delivery	5	17
16845	2019-12-04 12:45:23	2019-12-04	9	[{"id_menu":7,"count":1}]	2153	pick-up	0	9
16846	2019-12-04 12:55:54	2019-12-04	17	[{"id_menu":4,"count":1}]	5079	delivery	5	22
16847	2019-12-04 12:58:10	2019-12-04	12	[{"id_menu":1,"count":1}]	3801	pick-up	0	12
16848	2019-12-04 14:10:30	2019-12-04	12	[{"id_menu":1,"count":1}]	6415	delivery	5	17
16849	2019-12-04 14:19:40	2019-12-04	12	[{"id_menu":1,"count":1}]	1285	pick-up	0	12
16850	2019-12-04 14:21:51	2019-12-04	12	[{"id_menu":3,"count":1}]	4634	pick-up	0	12
16851	2019-12-04 14:36:57	2019-12-04	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	6281	delivery	5	34
16852	2019-12-04 14:44:14	2019-12-04	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1334	pick-up	0	26
16853	2019-12-04 14:54:46	2019-12-04	14	[{"id_menu":2,"count":1}]	1739	pick-up	0	14
16854	2019-12-04 15:00:26	2019-12-04	9	[{"id_menu":6,"count":1}]	1566	delivery	5	14
16855	2019-12-04 15:02:04	2019-12-04	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4050	delivery	5	30
16856	2019-12-04 15:14:03	2019-12-04	9	[{"id_menu":6,"count":1}]	4445	delivery	5	14
16857	2019-12-04 15:14:46	2019-12-04	12	[{"id_menu":1,"count":1}]	6408	pick-up	0	12
16858	2019-12-04 15:15:56	2019-12-04	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5540	delivery	5	35
16859	2019-12-04 15:17:00	2019-12-04	17	[{"id_menu":4,"count":1}]	6380	delivery	5	22
16860	2019-12-04 15:20:11	2019-12-04	8	[{"id_menu":5,"count":2}]	5969	delivery	5	13
16861	2019-12-04 15:23:01	2019-12-04	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6401	pick-up	0	23
16862	2019-12-04 15:35:02	2019-12-04	9	[{"id_menu":7,"count":2}]	4139	delivery	5	14
16863	2019-12-04 15:55:11	2019-12-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1565	delivery	5	28
16864	2019-12-04 15:59:49	2019-12-04	9	[{"id_menu":6,"count":1}]	765	pick-up	0	9
16865	2019-12-04 16:10:47	2019-12-04	9	[{"id_menu":7,"count":1}]	4116	delivery	5	14
16866	2019-12-04 16:14:12	2019-12-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1529	pick-up	0	23
16867	2019-12-04 16:15:23	2019-12-04	12	[{"id_menu":1,"count":1}]	6378	delivery	5	17
16868	2019-12-04 16:15:26	2019-12-04	9	[{"id_menu":7,"count":1}]	4664	delivery	5	14
16869	2019-12-04 16:36:59	2019-12-04	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	525	delivery	5	31
16870	2019-12-04 16:41:12	2019-12-04	17	[{"id_menu":4,"count":1}]	3365	pick-up	0	17
16871	2019-12-04 17:03:49	2019-12-04	14	[{"id_menu":2,"count":1}]	2002	pick-up	0	14
16872	2019-12-04 17:04:05	2019-12-04	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3000	delivery	5	26
16873	2019-12-04 17:06:42	2019-12-04	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	3679	delivery	5	25
16874	2019-12-04 17:08:26	2019-12-04	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	6387	delivery	5	27
16875	2019-12-04 17:23:32	2019-12-04	14	[{"id_menu":2,"count":1}]	2483	delivery	5	19
16876	2019-12-04 17:29:10	2019-12-04	17	[{"id_menu":4,"count":1}]	2021	pick-up	0	17
16877	2019-12-04 17:40:50	2019-12-04	17	[{"id_menu":4,"count":2}]	4735	delivery	5	22
16878	2019-12-04 17:53:13	2019-12-04	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	4587	delivery	5	40
16879	2019-12-04 17:55:31	2019-12-04	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6383	delivery	5	36
16880	2019-12-04 17:58:12	2019-12-04	12	[{"id_menu":1,"count":1}]	314	delivery	5	17
16881	2019-12-04 18:17:33	2019-12-04	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4007	delivery	5	27
16882	2019-12-04 18:22:53	2019-12-04	8	[{"id_menu":5,"count":1}]	6377	delivery	5	13
16883	2019-12-04 18:26:09	2019-12-04	17	[{"id_menu":4,"count":1}]	6422	delivery	5	22
16884	2019-12-04 18:32:05	2019-12-04	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6407	delivery	5	34
16885	2019-12-04 18:49:35	2019-12-04	8	[{"id_menu":5,"count":1}]	1754	pick-up	0	8
16886	2019-12-04 19:02:07	2019-12-04	8	[{"id_menu":5,"count":1}]	3788	pick-up	0	8
16887	2019-12-04 19:07:35	2019-12-04	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5972	pick-up	0	41
16888	2019-12-04 19:30:31	2019-12-04	9	[{"id_menu":6,"count":1}]	6410	pick-up	0	9
16889	2019-12-04 19:46:52	2019-12-04	17	[{"id_menu":4,"count":1}]	2086	pick-up	0	17
16890	2019-12-04 19:54:33	2019-12-04	9	[{"id_menu":7,"count":1}]	4652	pick-up	0	9
16891	2019-12-04 20:07:31	2019-12-04	17	[{"id_menu":4,"count":1}]	5449	pick-up	0	17
16892	2019-12-04 20:12:13	2019-12-04	14	[{"id_menu":2,"count":1}]	5839	pick-up	0	14
16893	2019-12-04 20:12:15	2019-12-04	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6399	pick-up	0	31
16894	2019-12-04 20:17:41	2019-12-04	8	[{"id_menu":5,"count":1}]	172	delivery	5	13
16895	2019-12-04 20:21:31	2019-12-04	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	997	pick-up	0	29
16896	2019-12-04 20:33:41	2019-12-04	17	[{"id_menu":4,"count":1}]	6386	delivery	5	22
16897	2019-12-04 20:36:06	2019-12-04	14	[{"id_menu":2,"count":1}]	2835	pick-up	0	14
16898	2019-12-04 20:48:09	2019-12-04	9	[{"id_menu":7,"count":1}]	6416	delivery	5	14
16899	2019-12-04 20:55:28	2019-12-04	8	[{"id_menu":5,"count":1}]	3598	delivery	5	13
16900	2019-12-04 21:07:30	2019-12-04	12	[{"id_menu":3,"count":1}]	6389	delivery	5	17
16901	2019-12-04 21:35:10	2019-12-04	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	6394	delivery	5	34
16902	2019-12-04 21:35:44	2019-12-04	14	[{"id_menu":2,"count":1}]	6376	pick-up	0	14
16903	2019-12-04 21:44:41	2019-12-04	12	[{"id_menu":3,"count":1}]	68	pick-up	0	12
16904	2019-12-04 21:48:50	2019-12-04	9	[{"id_menu":6,"count":1}]	2130	pick-up	0	9
16905	2019-12-04 22:03:45	2019-12-04	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	5858	delivery	5	34
16906	2019-12-04 22:10:15	2019-12-04	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	5201	delivery	5	39
16907	2019-12-04 22:27:08	2019-12-04	12	[{"id_menu":1,"count":1}]	3012	pick-up	0	12
16908	2019-12-04 22:42:42	2019-12-04	14	[{"id_menu":2,"count":1}]	2875	pick-up	0	14
16909	2019-12-04 23:02:58	2019-12-04	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	6370	delivery	5	38
16910	2019-12-04 23:03:09	2019-12-04	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	6392	delivery	5	40
16911	2019-12-04 23:03:11	2019-12-04	8	[{"id_menu":5,"count":1}]	1028	delivery	5	13
16912	2019-12-04 23:08:10	2019-12-04	17	[{"id_menu":4,"count":1}]	4794	delivery	5	22
16913	2019-12-04 23:10:27	2019-12-04	8	[{"id_menu":5,"count":1}]	4704	delivery	5	13
16914	2019-12-04 23:17:49	2019-12-04	9	[{"id_menu":6,"count":1}]	2995	delivery	5	14
16915	2019-12-04 23:18:37	2019-12-04	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	4751	pick-up	0	24
16916	2019-12-04 23:23:07	2019-12-04	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6396	pick-up	0	26
16917	2019-12-04 23:26:14	2019-12-04	12	[{"id_menu":3,"count":1}]	820	delivery	5	17
16918	2019-12-04 23:37:51	2019-12-04	8	[{"id_menu":5,"count":1}]	790	pick-up	0	8
16919	2019-12-04 23:38:09	2019-12-04	9	[{"id_menu":6,"count":1}]	5496	delivery	5	14
16920	2019-12-04 23:38:44	2019-12-04	8	[{"id_menu":5,"count":1}]	6384	delivery	5	13
16921	2019-12-04 23:40:16	2019-12-04	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	170	pick-up	0	35
16922	2019-12-04 23:51:18	2019-12-04	12	[{"id_menu":3,"count":1}]	111	pick-up	0	12
16923	2019-12-04 23:58:36	2019-12-04	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6379	delivery	5	46
16924	2019-12-05 00:14:40	2019-12-05	12	[{"id_menu":1,"count":1}]	583	delivery	5	17
16925	2019-12-05 00:24:40	2019-12-05	8	[{"id_menu":5,"count":1}]	542	delivery	5	13
16926	2019-12-05 00:25:40	2019-12-05	12	[{"id_menu":3,"count":1}]	6436	delivery	5	17
16927	2019-12-05 00:45:27	2019-12-05	9	[{"id_menu":6,"count":1}]	3877	pick-up	0	9
16928	2019-12-05 00:50:43	2019-12-05	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	6450	delivery	5	25
16929	2019-12-05 00:54:25	2019-12-05	14	[{"id_menu":2,"count":1}]	1957	pick-up	0	14
16930	2019-12-05 01:02:55	2019-12-05	9	[{"id_menu":6,"count":1}]	6449	delivery	5	14
16931	2019-12-05 01:05:59	2019-12-05	9	[{"id_menu":7,"count":1}]	2124	delivery	5	14
16932	2019-12-05 01:18:51	2019-12-05	8	[{"id_menu":5,"count":1}]	5027	delivery	5	13
16933	2019-12-05 01:38:22	2019-12-05	8	[{"id_menu":5,"count":1}]	5994	delivery	5	13
16934	2019-12-05 01:53:38	2019-12-05	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	122	pick-up	0	21
16935	2019-12-05 01:57:46	2019-12-05	14	[{"id_menu":2,"count":1}]	1321	pick-up	0	14
16936	2019-12-05 02:00:49	2019-12-05	14	[{"id_menu":2,"count":1}]	5126	delivery	5	19
16937	2019-12-05 02:01:45	2019-12-05	8	[{"id_menu":5,"count":1}]	5701	pick-up	0	8
16938	2019-12-05 02:24:06	2019-12-05	8	[{"id_menu":5,"count":2}]	2729	delivery	5	13
16939	2019-12-05 02:28:17	2019-12-05	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	607	pick-up	0	25
16940	2019-12-05 02:31:24	2019-12-05	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6475	delivery	5	31
16941	2019-12-05 02:33:41	2019-12-05	17	[{"id_menu":4,"count":1}]	6474	delivery	5	22
16942	2019-12-05 03:07:17	2019-12-05	14	[{"id_menu":2,"count":1}]	643	pick-up	0	14
16943	2019-12-05 03:10:22	2019-12-05	8	[{"id_menu":5,"count":1}]	1599	pick-up	0	8
16944	2019-12-05 03:15:44	2019-12-05	8	[{"id_menu":5,"count":1}]	6481	delivery	5	13
16945	2019-12-05 03:17:09	2019-12-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6438	delivery	5	23
16946	2019-12-05 03:31:05	2019-12-05	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6433	delivery	5	56
16947	2019-12-05 03:34:41	2019-12-05	14	[{"id_menu":2,"count":1}]	3219	pick-up	0	14
16948	2019-12-05 03:44:23	2019-12-05	9	[{"id_menu":6,"count":1}]	6462	delivery	5	14
16949	2019-12-05 04:05:15	2019-12-05	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6063	delivery	5	36
16950	2019-12-05 04:28:29	2019-12-05	12	[{"id_menu":3,"count":1}]	6446	pick-up	0	12
16951	2019-12-05 04:38:32	2019-12-05	12	[{"id_menu":1,"count":1}]	1509	pick-up	0	12
16952	2019-12-05 04:45:32	2019-12-05	14	[{"id_menu":2,"count":1}]	2616	pick-up	0	14
16953	2019-12-05 04:50:18	2019-12-05	12	[{"id_menu":1,"count":1}]	3119	delivery	5	17
16954	2019-12-05 05:05:39	2019-12-05	8	[{"id_menu":5,"count":1}]	4242	pick-up	0	8
16955	2019-12-05 05:06:28	2019-12-05	12	[{"id_menu":1,"count":1}]	2214	delivery	5	17
16956	2019-12-05 05:20:58	2019-12-05	9	[{"id_menu":6,"count":1}]	6476	delivery	5	14
16957	2019-12-05 05:33:24	2019-12-05	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	1676	delivery	5	39
16958	2019-12-05 05:43:27	2019-12-05	17	[{"id_menu":4,"count":1}]	5839	pick-up	0	17
16959	2019-12-05 06:08:49	2019-12-05	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	3701	pick-up	0	29
16960	2019-12-05 06:26:26	2019-12-05	8	[{"id_menu":5,"count":1}]	6441	delivery	5	13
16961	2019-12-05 06:31:36	2019-12-05	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	3644	delivery	5	39
16962	2019-12-05 06:46:00	2019-12-05	14	[{"id_menu":2,"count":1}]	3224	delivery	5	19
16963	2019-12-05 06:50:36	2019-12-05	9	[{"id_menu":6,"count":1}]	4716	delivery	5	14
16964	2019-12-05 06:56:59	2019-12-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2065	pick-up	0	26
16965	2019-12-05 07:01:14	2019-12-05	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	173	pick-up	0	26
16966	2019-12-05 07:12:52	2019-12-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6455	delivery	5	23
16967	2019-12-05 07:14:23	2019-12-05	9	[{"id_menu":7,"count":1}]	2928	pick-up	0	9
16968	2019-12-05 07:24:53	2019-12-05	9	[{"id_menu":6,"count":1}]	510	delivery	5	14
16969	2019-12-05 07:29:14	2019-12-05	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	4958	delivery	5	45
16970	2019-12-05 07:33:31	2019-12-05	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3812	delivery	5	34
16971	2019-12-05 07:36:14	2019-12-05	12	[{"id_menu":1,"count":1}]	371	delivery	5	17
16972	2019-12-05 07:43:04	2019-12-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":3}]	4966	delivery	5	28
16973	2019-12-05 07:45:05	2019-12-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6477	delivery	5	23
16974	2019-12-05 08:01:23	2019-12-05	9	[{"id_menu":6,"count":1}]	260	delivery	5	14
16975	2019-12-05 08:01:53	2019-12-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3800	delivery	5	28
16976	2019-12-05 08:03:50	2019-12-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1461	delivery	5	22
16977	2019-12-05 08:09:51	2019-12-05	9	[{"id_menu":6,"count":1}]	6451	delivery	5	14
16978	2019-12-05 08:26:21	2019-12-05	12	[{"id_menu":3,"count":1}]	2333	pick-up	0	12
16979	2019-12-05 08:28:33	2019-12-05	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6463	delivery	5	36
16980	2019-12-05 08:36:35	2019-12-05	17	[{"id_menu":4,"count":1}]	3538	pick-up	0	17
16981	2019-12-05 08:45:44	2019-12-05	9	[{"id_menu":7,"count":1}]	6448	delivery	5	14
16982	2019-12-05 08:46:14	2019-12-05	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2348	delivery	5	40
16983	2019-12-05 08:48:05	2019-12-05	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	6435	delivery	5	36
16984	2019-12-05 08:50:05	2019-12-05	9	[{"id_menu":7,"count":1}]	2338	delivery	5	14
16985	2019-12-05 09:15:01	2019-12-05	14	[{"id_menu":2,"count":1}]	1021	pick-up	0	14
16986	2019-12-05 09:15:23	2019-12-05	14	[{"id_menu":2,"count":1}]	6468	delivery	5	19
16987	2019-12-05 09:23:40	2019-12-05	14	[{"id_menu":2,"count":1}]	4253	pick-up	0	14
16988	2019-12-05 09:28:20	2019-12-05	9	[{"id_menu":7,"count":1}]	153	pick-up	0	9
16989	2019-12-05 09:38:37	2019-12-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6427	delivery	5	31
16990	2019-12-05 09:42:45	2019-12-05	12	[{"id_menu":1,"count":1}]	821	pick-up	0	12
16991	2019-12-05 09:44:47	2019-12-05	12	[{"id_menu":1,"count":1}]	170	pick-up	0	12
16992	2019-12-05 09:56:12	2019-12-05	8	[{"id_menu":5,"count":1}]	5293	pick-up	0	8
16993	2019-12-05 09:58:21	2019-12-05	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	3690	delivery	5	34
16994	2019-12-05 10:09:31	2019-12-05	12	[{"id_menu":3,"count":1}]	6479	pick-up	0	12
16995	2019-12-05 10:23:05	2019-12-05	14	[{"id_menu":2,"count":1}]	5046	delivery	5	19
16996	2019-12-05 10:27:47	2019-12-05	9	[{"id_menu":6,"count":1}]	676	pick-up	0	9
16997	2019-12-05 10:31:58	2019-12-05	9	[{"id_menu":7,"count":1}]	5226	delivery	5	14
16998	2019-12-05 11:04:57	2019-12-05	8	[{"id_menu":5,"count":1}]	3118	pick-up	0	8
16999	2019-12-05 11:08:23	2019-12-05	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	2339	pick-up	0	23
17000	2019-12-05 11:11:04	2019-12-05	9	[{"id_menu":6,"count":1}]	6459	delivery	5	14
17001	2019-12-05 11:13:14	2019-12-05	9	[{"id_menu":6,"count":1}]	1161	delivery	5	14
17002	2019-12-05 11:25:54	2019-12-05	12	[{"id_menu":1,"count":1}]	2416	pick-up	0	12
17003	2019-12-05 11:33:03	2019-12-05	9	[{"id_menu":6,"count":1}]	6458	pick-up	0	9
17004	2019-12-05 11:48:01	2019-12-05	8	[{"id_menu":5,"count":1}]	6442	pick-up	0	8
17005	2019-12-05 12:49:48	2019-12-05	17	[{"id_menu":4,"count":1}]	2052	delivery	5	22
17006	2019-12-05 13:35:25	2019-12-05	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	5113	delivery	5	40
17007	2019-12-05 13:42:48	2019-12-05	12	[{"id_menu":1,"count":1}]	6460	delivery	5	17
17008	2019-12-05 14:01:17	2019-12-05	17	[{"id_menu":4,"count":1}]	1490	pick-up	0	17
17009	2019-12-05 14:11:07	2019-12-05	14	[{"id_menu":2,"count":1}]	5311	delivery	5	19
17010	2019-12-05 14:13:44	2019-12-05	14	[{"id_menu":2,"count":1}]	6469	delivery	5	19
17011	2019-12-05 14:14:49	2019-12-05	12	[{"id_menu":3,"count":1}]	3981	delivery	5	17
17012	2019-12-05 14:50:09	2019-12-05	9	[{"id_menu":6,"count":1}]	1970	pick-up	0	9
17013	2019-12-05 14:55:38	2019-12-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4543	delivery	5	23
17014	2019-12-05 15:17:58	2019-12-05	8	[{"id_menu":5,"count":1}]	3832	delivery	5	13
17015	2019-12-05 15:52:02	2019-12-05	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6432	delivery	5	45
17016	2019-12-05 15:58:09	2019-12-05	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1476	pick-up	0	22
17017	2019-12-05 16:16:55	2019-12-05	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	3887	delivery	5	26
17018	2019-12-05 16:17:35	2019-12-05	9	[{"id_menu":7,"count":1}]	3546	delivery	5	14
17019	2019-12-05 16:35:53	2019-12-05	9	[{"id_menu":6,"count":1}]	6467	delivery	5	14
17020	2019-12-05 16:43:52	2019-12-05	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	563	delivery	5	31
17021	2019-12-05 16:45:05	2019-12-05	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	6430	delivery	5	40
17022	2019-12-05 16:51:23	2019-12-05	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6429	delivery	5	28
17023	2019-12-05 16:54:50	2019-12-05	8	[{"id_menu":5,"count":1}]	6471	pick-up	0	8
17024	2019-12-05 17:14:16	2019-12-05	9	[{"id_menu":7,"count":1}]	4486	delivery	5	14
17025	2019-12-05 17:14:38	2019-12-05	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2373	pick-up	0	29
17026	2019-12-05 17:22:46	2019-12-05	9	[{"id_menu":7,"count":1}]	5735	delivery	5	14
17027	2019-12-05 17:34:41	2019-12-05	9	[{"id_menu":6,"count":1}]	256	pick-up	0	9
17028	2019-12-05 17:59:22	2019-12-05	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6470	pick-up	0	31
17029	2019-12-05 18:03:33	2019-12-05	17	[{"id_menu":4,"count":1}]	609	delivery	5	22
17030	2019-12-05 18:06:54	2019-12-05	9	[{"id_menu":6,"count":1}]	6466	delivery	5	14
17031	2019-12-05 18:18:27	2019-12-05	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6447	delivery	5	53
17032	2019-12-05 18:30:28	2019-12-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	6454	delivery	5	22
17033	2019-12-05 18:31:45	2019-12-05	14	[{"id_menu":2,"count":1}]	6473	delivery	5	19
17034	2019-12-05 18:35:17	2019-12-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6431	delivery	5	31
17035	2019-12-05 18:42:04	2019-12-05	9	[{"id_menu":6,"count":1}]	719	pick-up	0	9
17036	2019-12-05 18:47:47	2019-12-05	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3423	delivery	5	30
17037	2019-12-05 18:49:56	2019-12-05	9	[{"id_menu":7,"count":1}]	6443	delivery	5	14
17038	2019-12-05 18:52:42	2019-12-05	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	5155	delivery	5	26
17039	2019-12-05 19:07:25	2019-12-05	8	[{"id_menu":5,"count":1}]	4593	delivery	5	13
17040	2019-12-05 19:09:22	2019-12-05	12	[{"id_menu":3,"count":1}]	5314	pick-up	0	12
17041	2019-12-05 19:10:50	2019-12-05	17	[{"id_menu":4,"count":1}]	784	pick-up	0	17
17042	2019-12-05 19:18:09	2019-12-05	12	[{"id_menu":1,"count":1}]	1529	pick-up	0	12
17043	2019-12-05 19:19:10	2019-12-05	12	[{"id_menu":1,"count":1}]	3574	delivery	5	17
17044	2019-12-05 19:19:46	2019-12-05	14	[{"id_menu":2,"count":1}]	41	pick-up	0	14
17045	2019-12-05 19:29:15	2019-12-05	8	[{"id_menu":5,"count":1}]	2894	pick-up	0	8
17046	2019-12-05 19:30:25	2019-12-05	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	778	pick-up	0	35
17047	2019-12-05 19:48:40	2019-12-05	9	[{"id_menu":7,"count":1}]	2572	pick-up	0	9
17048	2019-12-05 19:54:50	2019-12-05	8	[{"id_menu":5,"count":1}]	6444	delivery	5	13
17049	2019-12-05 19:55:27	2019-12-05	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	5890	pick-up	0	26
17050	2019-12-05 20:04:33	2019-12-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5337	delivery	5	28
17051	2019-12-05 20:16:55	2019-12-05	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2854	delivery	5	26
17052	2019-12-05 20:40:10	2019-12-05	8	[{"id_menu":5,"count":1}]	639	pick-up	0	8
17053	2019-12-05 20:57:30	2019-12-05	9	[{"id_menu":7,"count":1}]	6456	delivery	5	14
17054	2019-12-05 20:58:10	2019-12-05	14	[{"id_menu":2,"count":1}]	6437	delivery	5	19
17055	2019-12-05 21:04:57	2019-12-05	9	[{"id_menu":6,"count":1}]	1780	pick-up	0	9
17056	2019-12-05 21:33:26	2019-12-05	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6480	delivery	5	40
17057	2019-12-05 21:51:56	2019-12-05	9	[{"id_menu":6,"count":1}]	6439	pick-up	0	9
17058	2019-12-05 21:52:04	2019-12-05	9	[{"id_menu":7,"count":1}]	2618	pick-up	0	9
17059	2019-12-05 21:52:37	2019-12-05	9	[{"id_menu":6,"count":1}]	177	pick-up	0	9
17060	2019-12-05 21:59:23	2019-12-05	9	[{"id_menu":6,"count":1}]	6472	delivery	5	14
17061	2019-12-05 22:02:59	2019-12-05	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6478	delivery	5	42
17062	2019-12-05 22:09:57	2019-12-05	9	[{"id_menu":7,"count":2}]	6453	delivery	5	14
17063	2019-12-05 22:11:09	2019-12-05	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	6457	delivery	5	29
17064	2019-12-05 22:13:27	2019-12-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	900	delivery	5	31
17065	2019-12-05 22:24:29	2019-12-05	9	[{"id_menu":6,"count":1}]	543	pick-up	0	9
17066	2019-12-05 22:28:49	2019-12-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5958	delivery	5	28
17067	2019-12-05 22:35:46	2019-12-05	17	[{"id_menu":4,"count":1}]	4239	delivery	5	22
17068	2019-12-05 22:40:42	2019-12-05	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	287	pick-up	0	33
17069	2019-12-05 22:48:20	2019-12-05	17	[{"id_menu":4,"count":1}]	2709	pick-up	0	17
17070	2019-12-05 22:55:01	2019-12-05	14	[{"id_menu":2,"count":1}]	6425	pick-up	0	14
17071	2019-12-05 22:56:25	2019-12-05	8	[{"id_menu":5,"count":1}]	5461	pick-up	0	8
17072	2019-12-05 23:15:01	2019-12-05	17	[{"id_menu":4,"count":1}]	1155	delivery	5	22
17073	2019-12-05 23:28:44	2019-12-05	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6461	delivery	5	42
17074	2019-12-05 23:35:42	2019-12-05	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	3256	delivery	5	45
17075	2019-12-05 23:40:42	2019-12-05	9	[{"id_menu":7,"count":1}]	6424	delivery	5	14
17076	2019-12-05 23:42:43	2019-12-05	9	[{"id_menu":7,"count":1}]	285	pick-up	0	9
17077	2019-12-06 00:10:36	2019-12-06	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6546	delivery	5	36
17078	2019-12-06 00:16:53	2019-12-06	14	[{"id_menu":2,"count":1}]	6485	delivery	5	19
17079	2019-12-06 00:21:44	2019-12-06	9	[{"id_menu":7,"count":1}]	6502	pick-up	0	9
17080	2019-12-06 00:32:28	2019-12-06	14	[{"id_menu":2,"count":1}]	765	pick-up	0	14
17081	2019-12-06 00:38:25	2019-12-06	9	[{"id_menu":6,"count":1}]	2927	delivery	5	14
17082	2019-12-06 01:02:04	2019-12-06	14	[{"id_menu":2,"count":1}]	5106	delivery	5	19
17083	2019-12-06 01:10:10	2019-12-06	12	[{"id_menu":3,"count":1}]	6516	pick-up	0	12
17084	2019-12-06 01:33:08	2019-12-06	12	[{"id_menu":1,"count":1}]	6500	delivery	5	17
17085	2019-12-06 01:40:10	2019-12-06	17	[{"id_menu":4,"count":1}]	6521	delivery	5	22
17086	2019-12-06 01:48:19	2019-12-06	14	[{"id_menu":2,"count":1}]	6483	delivery	5	19
17087	2019-12-06 01:48:31	2019-12-06	12	[{"id_menu":3,"count":1}]	6369	pick-up	0	12
17088	2019-12-06 01:52:46	2019-12-06	49	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5970	pick-up	0	49
17089	2019-12-06 01:54:22	2019-12-06	17	[{"id_menu":4,"count":1}]	4626	pick-up	0	17
17090	2019-12-06 02:11:11	2019-12-06	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	6506	delivery	5	34
17091	2019-12-06 02:19:23	2019-12-06	12	[{"id_menu":1,"count":2}]	1756	pick-up	0	12
17092	2019-12-06 02:21:03	2019-12-06	9	[{"id_menu":6,"count":1}]	1383	delivery	5	14
17093	2019-12-06 02:25:22	2019-12-06	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6333	pick-up	0	17
17094	2019-12-06 02:33:54	2019-12-06	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6519	delivery	5	22
17095	2019-12-06 03:33:49	2019-12-06	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	1118	pick-up	0	24
17096	2019-12-06 03:43:32	2019-12-06	12	[{"id_menu":3,"count":1}]	6147	delivery	5	17
17097	2019-12-06 03:44:43	2019-12-06	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	6493	delivery	5	34
17098	2019-12-06 03:57:18	2019-12-06	17	[{"id_menu":4,"count":1}]	379	delivery	5	22
17099	2019-12-06 03:58:01	2019-12-06	9	[{"id_menu":6,"count":1}]	6488	delivery	5	14
17100	2019-12-06 03:58:27	2019-12-06	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	2124	delivery	5	31
17101	2019-12-06 04:05:35	2019-12-06	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6491	delivery	5	45
17102	2019-12-06 04:19:35	2019-12-06	14	[{"id_menu":2,"count":1}]	1681	delivery	5	19
17103	2019-12-06 04:23:04	2019-12-06	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	3788	pick-up	0	26
17104	2019-12-06 04:33:22	2019-12-06	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	972	delivery	5	22
17105	2019-12-06 04:59:52	2019-12-06	14	[{"id_menu":2,"count":1}]	5440	delivery	5	19
17106	2019-12-06 05:00:27	2019-12-06	14	[{"id_menu":2,"count":1}]	1263	pick-up	0	14
17107	2019-12-06 05:08:33	2019-12-06	9	[{"id_menu":7,"count":1}]	3871	pick-up	0	9
17108	2019-12-06 05:25:50	2019-12-06	12	[{"id_menu":3,"count":1}]	1526	pick-up	0	12
17109	2019-12-06 05:27:41	2019-12-06	9	[{"id_menu":6,"count":1}]	6548	pick-up	0	9
17110	2019-12-06 05:41:12	2019-12-06	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	6508	delivery	5	40
17111	2019-12-06 05:46:26	2019-12-06	9	[{"id_menu":6,"count":1}]	1708	delivery	5	14
17112	2019-12-06 05:50:31	2019-12-06	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3385	pick-up	0	35
17113	2019-12-06 05:52:48	2019-12-06	14	[{"id_menu":2,"count":1}]	6520	pick-up	0	14
17114	2019-12-06 05:57:16	2019-12-06	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4995	pick-up	0	22
17115	2019-12-06 06:07:15	2019-12-06	12	[{"id_menu":3,"count":1}]	6507	delivery	5	17
17116	2019-12-06 06:14:27	2019-12-06	9	[{"id_menu":6,"count":1}]	6542	delivery	5	14
17117	2019-12-06 06:16:55	2019-12-06	9	[{"id_menu":7,"count":1}]	1125	pick-up	0	9
17118	2019-12-06 06:20:10	2019-12-06	8	[{"id_menu":5,"count":1}]	6514	delivery	5	13
17119	2019-12-06 06:24:34	2019-12-06	8	[{"id_menu":5,"count":1}]	6496	delivery	5	13
17120	2019-12-06 06:26:03	2019-12-06	8	[{"id_menu":5,"count":1}]	6512	pick-up	0	8
17121	2019-12-06 06:51:28	2019-12-06	9	[{"id_menu":7,"count":1}]	6495	pick-up	0	9
17122	2019-12-06 06:57:16	2019-12-06	9	[{"id_menu":6,"count":1}]	5244	delivery	5	14
17123	2019-12-06 07:04:10	2019-12-06	12	[{"id_menu":3,"count":1}]	3542	delivery	5	17
17124	2019-12-06 07:05:06	2019-12-06	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	6530	delivery	5	26
17125	2019-12-06 07:12:16	2019-12-06	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6528	delivery	5	36
17126	2019-12-06 07:35:32	2019-12-06	14	[{"id_menu":2,"count":1}]	3299	pick-up	0	14
17127	2019-12-06 07:45:14	2019-12-06	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	378	delivery	5	34
17128	2019-12-06 07:47:43	2019-12-06	14	[{"id_menu":2,"count":1}]	6484	pick-up	0	14
17129	2019-12-06 08:01:35	2019-12-06	9	[{"id_menu":6,"count":1}]	2132	pick-up	0	9
17130	2019-12-06 08:08:02	2019-12-06	12	[{"id_menu":3,"count":1}]	6486	pick-up	0	12
17131	2019-12-06 08:14:12	2019-12-06	17	[{"id_menu":4,"count":1}]	4054	pick-up	0	17
17132	2019-12-06 08:15:08	2019-12-06	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5910	delivery	5	31
17133	2019-12-06 08:17:38	2019-12-06	14	[{"id_menu":2,"count":1}]	6482	delivery	5	19
17134	2019-12-06 08:18:27	2019-12-06	12	[{"id_menu":3,"count":1}]	1026	delivery	5	17
17135	2019-12-06 08:20:23	2019-12-06	9	[{"id_menu":7,"count":1}]	6443	delivery	5	14
17136	2019-12-06 08:20:36	2019-12-06	9	[{"id_menu":7,"count":1}]	6549	delivery	5	14
17137	2019-12-06 08:34:46	2019-12-06	14	[{"id_menu":2,"count":1}]	6517	delivery	5	19
17138	2019-12-06 08:46:12	2019-12-06	9	[{"id_menu":6,"count":1}]	54	delivery	5	14
17139	2019-12-06 08:46:51	2019-12-06	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1266	pick-up	0	21
17140	2019-12-06 08:49:13	2019-12-06	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5165	delivery	5	22
17141	2019-12-06 08:50:58	2019-12-06	12	[{"id_menu":1,"count":1}]	6525	delivery	5	17
17142	2019-12-06 09:04:50	2019-12-06	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4172	pick-up	0	17
17143	2019-12-06 09:12:06	2019-12-06	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1364	pick-up	0	21
17144	2019-12-06 09:46:36	2019-12-06	12	[{"id_menu":3,"count":1}]	3293	delivery	5	17
17145	2019-12-06 09:58:12	2019-12-06	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3649	delivery	5	30
17146	2019-12-06 09:59:32	2019-12-06	9	[{"id_menu":6,"count":1}]	6535	pick-up	0	9
17147	2019-12-06 10:16:25	2019-12-06	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	3135	pick-up	0	43
17148	2019-12-06 10:50:42	2019-12-06	12	[{"id_menu":1,"count":1}]	4004	delivery	5	17
17149	2019-12-06 10:56:06	2019-12-06	9	[{"id_menu":6,"count":1}]	989	delivery	5	14
17150	2019-12-06 11:06:48	2019-12-06	12	[{"id_menu":3,"count":1}]	1162	pick-up	0	12
17151	2019-12-06 11:16:45	2019-12-06	9	[{"id_menu":6,"count":1}]	6539	pick-up	0	9
17152	2019-12-06 11:29:39	2019-12-06	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2843	delivery	5	34
17153	2019-12-06 11:44:47	2019-12-06	14	[{"id_menu":2,"count":1}]	5461	pick-up	0	14
17154	2019-12-06 12:04:36	2019-12-06	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6498	delivery	5	31
17155	2019-12-06 12:12:44	2019-12-06	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5104	delivery	5	23
17156	2019-12-06 12:32:13	2019-12-06	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	847	pick-up	0	22
17157	2019-12-06 12:33:40	2019-12-06	9	[{"id_menu":7,"count":1}]	6504	delivery	5	14
17158	2019-12-06 12:44:25	2019-12-06	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6510	delivery	5	42
17159	2019-12-06 12:46:04	2019-12-06	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4281	delivery	5	22
17160	2019-12-06 12:46:23	2019-12-06	9	[{"id_menu":6,"count":1}]	6522	delivery	5	14
17161	2019-12-06 12:54:28	2019-12-06	17	[{"id_menu":4,"count":1}]	2847	pick-up	0	17
17162	2019-12-06 12:55:01	2019-12-06	14	[{"id_menu":2,"count":1}]	6492	pick-up	0	14
17163	2019-12-06 12:55:20	2019-12-06	8	[{"id_menu":5,"count":1}]	3536	pick-up	0	8
17164	2019-12-06 13:02:17	2019-12-06	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	6533	pick-up	0	33
17165	2019-12-06 13:34:47	2019-12-06	12	[{"id_menu":3,"count":1}]	3827	pick-up	0	12
17166	2019-12-06 13:50:17	2019-12-06	8	[{"id_menu":5,"count":1}]	6518	delivery	5	13
17167	2019-12-06 13:57:10	2019-12-06	8	[{"id_menu":5,"count":1}]	6511	delivery	5	13
17168	2019-12-06 14:14:39	2019-12-06	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6489	pick-up	0	26
17169	2019-12-06 14:16:38	2019-12-06	14	[{"id_menu":2,"count":1}]	806	delivery	5	19
17170	2019-12-06 14:19:06	2019-12-06	12	[{"id_menu":3,"count":1}]	6487	pick-up	0	12
17171	2019-12-06 14:42:23	2019-12-06	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1713	delivery	5	30
17172	2019-12-06 14:45:52	2019-12-06	17	[{"id_menu":4,"count":1}]	5701	pick-up	0	17
17173	2019-12-06 15:01:53	2019-12-06	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	5545	delivery	5	26
17174	2019-12-06 15:13:57	2019-12-06	17	[{"id_menu":4,"count":1}]	5887	pick-up	0	17
17175	2019-12-06 15:14:38	2019-12-06	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	660	pick-up	0	21
17176	2019-12-06 15:47:44	2019-12-06	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	6497	pick-up	0	29
17177	2019-12-06 15:52:10	2019-12-06	17	[{"id_menu":4,"count":1}]	3785	pick-up	0	17
17178	2019-12-06 16:06:49	2019-12-06	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	6104	delivery	5	48
17179	2019-12-06 16:08:54	2019-12-06	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4912	delivery	5	34
17180	2019-12-06 16:23:07	2019-12-06	14	[{"id_menu":2,"count":2}]	68	pick-up	0	14
17181	2019-12-06 16:24:31	2019-12-06	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3467	delivery	5	31
17182	2019-12-06 16:26:54	2019-12-06	23	[{"id_menu":2,"count":3},{"id_menu":6,"count":1}]	6509	delivery	5	28
17183	2019-12-06 16:34:06	2019-12-06	8	[{"id_menu":5,"count":1}]	6540	delivery	5	13
17184	2019-12-06 16:41:05	2019-12-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	6536	delivery	5	28
17185	2019-12-06 17:14:51	2019-12-06	9	[{"id_menu":6,"count":1}]	6541	delivery	5	14
17186	2019-12-06 17:29:47	2019-12-06	12	[{"id_menu":3,"count":1}]	6349	delivery	5	17
17187	2019-12-06 17:30:00	2019-12-06	12	[{"id_menu":3,"count":1}]	491	pick-up	0	12
17188	2019-12-06 17:44:48	2019-12-06	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	2152	pick-up	0	21
17189	2019-12-06 17:57:26	2019-12-06	12	[{"id_menu":3,"count":1}]	1438	delivery	5	17
17190	2019-12-06 18:09:08	2019-12-06	9	[{"id_menu":6,"count":1}]	5699	delivery	5	14
17191	2019-12-06 18:14:06	2019-12-06	9	[{"id_menu":7,"count":1}]	2050	pick-up	0	9
17192	2019-12-06 18:14:37	2019-12-06	14	[{"id_menu":2,"count":1}]	6524	delivery	5	19
17193	2019-12-06 18:26:16	2019-12-06	12	[{"id_menu":3,"count":1}]	4049	pick-up	0	12
17194	2019-12-06 18:37:09	2019-12-06	9	[{"id_menu":7,"count":1}]	6113	delivery	5	14
17195	2019-12-06 18:53:34	2019-12-06	9	[{"id_menu":7,"count":1}]	640	pick-up	0	9
17196	2019-12-06 18:59:12	2019-12-06	12	[{"id_menu":1,"count":1}]	2231	delivery	5	17
17197	2019-12-06 19:04:44	2019-12-06	12	[{"id_menu":3,"count":1}]	654	delivery	5	17
17198	2019-12-06 19:09:22	2019-12-06	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	6534	delivery	5	22
17199	2019-12-06 19:33:08	2019-12-06	9	[{"id_menu":6,"count":1}]	81	pick-up	0	9
17200	2019-12-06 19:49:07	2019-12-06	14	[{"id_menu":2,"count":1}]	3174	pick-up	0	14
17201	2019-12-06 19:53:00	2019-12-06	9	[{"id_menu":6,"count":3}]	3393	delivery	5	14
17202	2019-12-06 19:53:47	2019-12-06	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	5857	pick-up	0	26
17203	2019-12-06 20:00:28	2019-12-06	17	[{"id_menu":4,"count":1}]	6545	pick-up	0	17
17204	2019-12-06 20:18:47	2019-12-06	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	424	pick-up	0	26
17205	2019-12-06 20:24:22	2019-12-06	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1021	pick-up	0	17
17206	2019-12-06 20:30:07	2019-12-06	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6505	delivery	5	43
17207	2019-12-06 20:39:49	2019-12-06	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	5026	pick-up	0	26
17208	2019-12-06 20:41:54	2019-12-06	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	6499	delivery	5	22
17209	2019-12-06 20:49:34	2019-12-06	9	[{"id_menu":7,"count":1}]	6532	delivery	5	14
17210	2019-12-06 21:01:28	2019-12-06	12	[{"id_menu":1,"count":1}]	6342	delivery	5	17
17211	2019-12-06 21:23:30	2019-12-06	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	6513	delivery	5	26
17212	2019-12-06 21:32:57	2019-12-06	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	6494	delivery	5	26
17213	2019-12-06 21:53:36	2019-12-06	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3063	delivery	5	31
17214	2019-12-06 22:31:28	2019-12-06	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5856	delivery	5	43
17215	2019-12-06 22:35:50	2019-12-06	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	1657	pick-up	0	29
17216	2019-12-06 22:52:09	2019-12-06	12	[{"id_menu":3,"count":1}]	1859	pick-up	0	12
17217	2019-12-06 23:03:19	2019-12-06	14	[{"id_menu":2,"count":1}]	1908	pick-up	0	14
17218	2019-12-06 23:09:16	2019-12-06	9	[{"id_menu":7,"count":1}]	1245	pick-up	0	9
17219	2019-12-06 23:15:07	2019-12-06	12	[{"id_menu":3,"count":1}]	1462	delivery	5	17
17220	2019-12-06 23:47:34	2019-12-06	8	[{"id_menu":5,"count":2}]	48	pick-up	0	8
17221	2019-12-06 23:53:02	2019-12-06	17	[{"id_menu":4,"count":1}]	6543	pick-up	0	17
17222	2019-12-07 00:01:11	2019-12-07	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	4837	delivery	5	29
17223	2019-12-07 00:06:24	2019-12-07	9	[{"id_menu":7,"count":1}]	204	pick-up	0	9
17224	2019-12-07 00:11:49	2019-12-07	12	[{"id_menu":3,"count":2}]	4459	delivery	5	17
17225	2019-12-07 00:15:45	2019-12-07	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1161	pick-up	0	21
17226	2019-12-07 00:24:51	2019-12-07	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5169	pick-up	0	17
17227	2019-12-07 00:36:31	2019-12-07	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1313	pick-up	0	25
17228	2019-12-07 00:39:48	2019-12-07	8	[{"id_menu":5,"count":1}]	6550	delivery	5	13
17229	2019-12-07 00:43:17	2019-12-07	14	[{"id_menu":2,"count":1}]	6604	delivery	5	19
17230	2019-12-07 00:43:47	2019-12-07	9	[{"id_menu":6,"count":1}]	3747	delivery	5	14
17231	2019-12-07 00:50:18	2019-12-07	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	536	pick-up	0	26
17232	2019-12-07 01:00:45	2019-12-07	17	[{"id_menu":4,"count":1}]	4436	pick-up	0	17
17233	2019-12-07 01:05:42	2019-12-07	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	602	delivery	5	36
17234	2019-12-07 01:12:45	2019-12-07	8	[{"id_menu":5,"count":1}]	6574	delivery	5	13
17235	2019-12-07 01:17:58	2019-12-07	14	[{"id_menu":2,"count":2}]	1120	delivery	5	19
17236	2019-12-07 01:20:39	2019-12-07	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1106	pick-up	0	24
17237	2019-12-07 01:33:15	2019-12-07	9	[{"id_menu":7,"count":1}]	4174	delivery	5	14
17238	2019-12-07 01:38:06	2019-12-07	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	6560	delivery	5	31
17239	2019-12-07 01:44:43	2019-12-07	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	4125	delivery	5	28
17240	2019-12-07 01:44:45	2019-12-07	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	5043	delivery	5	35
17241	2019-12-07 01:48:08	2019-12-07	12	[{"id_menu":1,"count":1}]	144	pick-up	0	12
17242	2019-12-07 01:52:48	2019-12-07	9	[{"id_menu":7,"count":1}]	1314	delivery	5	14
17243	2019-12-07 02:12:21	2019-12-07	12	[{"id_menu":1,"count":1}]	1971	delivery	5	17
17244	2019-12-07 02:22:25	2019-12-07	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1931	delivery	5	26
17245	2019-12-07 02:36:04	2019-12-07	9	[{"id_menu":7,"count":1}]	4098	delivery	5	14
17246	2019-12-07 02:39:44	2019-12-07	9	[{"id_menu":7,"count":1}]	6591	pick-up	0	9
17247	2019-12-07 02:50:24	2019-12-07	14	[{"id_menu":2,"count":1}]	360	delivery	5	19
17248	2019-12-07 02:51:13	2019-12-07	9	[{"id_menu":6,"count":1}]	1766	delivery	5	14
17249	2019-12-07 02:51:29	2019-12-07	9	[{"id_menu":6,"count":1}]	2870	pick-up	0	9
17250	2019-12-07 03:09:35	2019-12-07	8	[{"id_menu":5,"count":1}]	1035	pick-up	0	8
17251	2019-12-07 03:11:29	2019-12-07	9	[{"id_menu":7,"count":1}]	5729	pick-up	0	9
17252	2019-12-07 03:22:18	2019-12-07	12	[{"id_menu":1,"count":1}]	1162	pick-up	0	12
17253	2019-12-07 03:30:59	2019-12-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5812	pick-up	0	23
17254	2019-12-07 03:31:32	2019-12-07	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	6581	pick-up	0	21
17255	2019-12-07 03:45:55	2019-12-07	17	[{"id_menu":4,"count":1}]	451	delivery	5	22
17256	2019-12-07 03:51:39	2019-12-07	17	[{"id_menu":4,"count":1}]	6583	pick-up	0	17
17257	2019-12-07 04:01:15	2019-12-07	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	6602	delivery	5	35
17258	2019-12-07 04:03:32	2019-12-07	12	[{"id_menu":3,"count":1}]	337	delivery	5	17
17259	2019-12-07 04:15:46	2019-12-07	9	[{"id_menu":6,"count":1}]	6563	delivery	5	14
17260	2019-12-07 04:17:38	2019-12-07	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	5180	delivery	5	36
17261	2019-12-07 04:27:13	2019-12-07	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":2}]	2585	pick-up	0	23
17262	2019-12-07 04:42:09	2019-12-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	4441	delivery	5	26
17263	2019-12-07 04:47:06	2019-12-07	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	67	pick-up	0	25
17264	2019-12-07 05:14:27	2019-12-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2236	pick-up	0	23
17265	2019-12-07 05:21:40	2019-12-07	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2880	delivery	5	34
17266	2019-12-07 05:30:43	2019-12-07	12	[{"id_menu":1,"count":1}]	4875	delivery	5	17
17267	2019-12-07 05:38:49	2019-12-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1918	pick-up	0	18
17268	2019-12-07 05:39:05	2019-12-07	9	[{"id_menu":6,"count":1}]	1800	delivery	5	14
17269	2019-12-07 05:57:37	2019-12-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	6599	delivery	5	23
17270	2019-12-07 06:15:17	2019-12-07	8	[{"id_menu":5,"count":1}]	6589	pick-up	0	8
17271	2019-12-07 06:19:44	2019-12-07	14	[{"id_menu":2,"count":1}]	6558	delivery	5	19
17272	2019-12-07 06:23:06	2019-12-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	6593	delivery	5	28
17273	2019-12-07 06:23:30	2019-12-07	12	[{"id_menu":3,"count":1}]	2404	pick-up	0	12
17274	2019-12-07 06:33:49	2019-12-07	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2862	pick-up	0	26
17275	2019-12-07 06:36:42	2019-12-07	14	[{"id_menu":2,"count":1}]	6573	pick-up	0	14
17276	2019-12-07 06:36:46	2019-12-07	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	4685	pick-up	0	26
17277	2019-12-07 06:37:52	2019-12-07	9	[{"id_menu":6,"count":1}]	2470	pick-up	0	9
17278	2019-12-07 06:38:38	2019-12-07	9	[{"id_menu":7,"count":1}]	2872	pick-up	0	9
17279	2019-12-07 06:39:04	2019-12-07	9	[{"id_menu":6,"count":1}]	6265	pick-up	0	9
17280	2019-12-07 06:41:05	2019-12-07	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2168	pick-up	0	43
17281	2019-12-07 06:42:59	2019-12-07	12	[{"id_menu":1,"count":1}]	6587	pick-up	0	12
17282	2019-12-07 06:54:58	2019-12-07	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1115	pick-up	0	30
17283	2019-12-07 07:10:50	2019-12-07	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6611	delivery	5	43
17284	2019-12-07 07:11:02	2019-12-07	8	[{"id_menu":5,"count":1}]	4942	pick-up	0	8
17285	2019-12-07 07:21:31	2019-12-07	12	[{"id_menu":3,"count":1}]	988	delivery	5	17
17286	2019-12-07 07:39:22	2019-12-07	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	6564	delivery	5	42
17287	2019-12-07 07:50:09	2019-12-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	6597	delivery	5	22
17288	2019-12-07 07:56:52	2019-12-07	14	[{"id_menu":2,"count":1}]	6576	delivery	5	19
17289	2019-12-07 08:18:59	2019-12-07	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	6569	delivery	5	45
17290	2019-12-07 08:23:01	2019-12-07	8	[{"id_menu":5,"count":1}]	3750	pick-up	0	8
17291	2019-12-07 08:25:24	2019-12-07	17	[{"id_menu":4,"count":1}]	1925	delivery	5	22
17292	2019-12-07 08:43:18	2019-12-07	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5447	delivery	5	39
17293	2019-12-07 08:45:45	2019-12-07	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	6598	delivery	5	26
17294	2019-12-07 08:47:02	2019-12-07	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6606	delivery	5	40
17295	2019-12-07 08:47:31	2019-12-07	9	[{"id_menu":7,"count":1}]	840	pick-up	0	9
17296	2019-12-07 08:52:14	2019-12-07	8	[{"id_menu":5,"count":1}]	5149	delivery	5	13
17297	2019-12-07 08:52:49	2019-12-07	17	[{"id_menu":4,"count":1}]	6228	delivery	5	22
17298	2019-12-07 08:53:47	2019-12-07	8	[{"id_menu":5,"count":1}]	6603	delivery	5	13
17299	2019-12-07 09:03:54	2019-12-07	17	[{"id_menu":4,"count":1}]	1544	pick-up	0	17
17300	2019-12-07 09:20:22	2019-12-07	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6561	pick-up	0	17
17301	2019-12-07 09:22:15	2019-12-07	43	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6579	delivery	5	48
17302	2019-12-07 09:31:01	2019-12-07	14	[{"id_menu":2,"count":1}]	6551	pick-up	0	14
17303	2019-12-07 09:47:24	2019-12-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2023	pick-up	0	23
17304	2019-12-07 10:22:26	2019-12-07	14	[{"id_menu":2,"count":1}]	2706	delivery	5	19
17305	2019-12-07 10:30:04	2019-12-07	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3010	delivery	5	31
17306	2019-12-07 10:39:28	2019-12-07	17	[{"id_menu":4,"count":1}]	2783	pick-up	0	17
17307	2019-12-07 10:43:59	2019-12-07	9	[{"id_menu":7,"count":1}]	5817	delivery	5	14
17308	2019-12-07 10:46:28	2019-12-07	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	2401	pick-up	0	18
17309	2019-12-07 10:58:39	2019-12-07	9	[{"id_menu":6,"count":1}]	6577	delivery	5	14
17310	2019-12-07 11:00:07	2019-12-07	8	[{"id_menu":5,"count":1}]	6565	pick-up	0	8
17311	2019-12-07 11:08:27	2019-12-07	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	6608	delivery	5	27
17312	2019-12-07 11:12:22	2019-12-07	9	[{"id_menu":7,"count":1}]	6601	delivery	5	14
17313	2019-12-07 11:15:04	2019-12-07	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	3125	delivery	5	30
17314	2019-12-07 11:20:39	2019-12-07	14	[{"id_menu":2,"count":1}]	309	pick-up	0	14
17315	2019-12-07 11:24:32	2019-12-07	14	[{"id_menu":2,"count":1}]	6555	delivery	5	19
17316	2019-12-07 11:35:20	2019-12-07	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3903	delivery	5	40
17317	2019-12-07 11:39:40	2019-12-07	12	[{"id_menu":3,"count":1}]	1947	pick-up	0	12
17318	2019-12-07 11:46:00	2019-12-07	14	[{"id_menu":2,"count":1}]	2392	pick-up	0	14
17319	2019-12-07 11:48:48	2019-12-07	14	[{"id_menu":2,"count":1}]	119	delivery	5	19
17320	2019-12-07 11:50:05	2019-12-07	8	[{"id_menu":5,"count":1}]	4151	delivery	5	13
17321	2019-12-07 11:50:11	2019-12-07	17	[{"id_menu":4,"count":1}]	6600	pick-up	0	17
17322	2019-12-07 11:51:48	2019-12-07	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	6590	delivery	5	28
17323	2019-12-07 11:57:11	2019-12-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4804	delivery	5	28
17324	2019-12-07 12:01:53	2019-12-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	6572	delivery	5	26
17325	2019-12-07 12:08:07	2019-12-07	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	6241	delivery	5	40
17326	2019-12-07 12:08:21	2019-12-07	9	[{"id_menu":7,"count":1}]	1640	pick-up	0	9
17327	2019-12-07 12:22:47	2019-12-07	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	6552	pick-up	0	26
17328	2019-12-07 12:24:37	2019-12-07	9	[{"id_menu":7,"count":1}]	5268	delivery	5	14
17329	2019-12-07 12:26:34	2019-12-07	17	[{"id_menu":4,"count":1}]	6607	pick-up	0	17
17330	2019-12-07 12:31:09	2019-12-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6195	delivery	5	28
17331	2019-12-07 12:34:37	2019-12-07	9	[{"id_menu":7,"count":1}]	4183	delivery	5	14
17332	2019-12-07 12:41:52	2019-12-07	14	[{"id_menu":2,"count":1}]	1445	delivery	5	19
17333	2019-12-07 12:53:39	2019-12-07	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6585	delivery	5	39
17334	2019-12-07 12:56:01	2019-12-07	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	6137	delivery	5	40
17335	2019-12-07 12:57:31	2019-12-07	8	[{"id_menu":5,"count":1}]	6469	pick-up	0	8
17336	2019-12-07 13:02:55	2019-12-07	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	6506	delivery	5	34
17337	2019-12-07 13:32:32	2019-12-07	14	[{"id_menu":2,"count":1}]	5127	delivery	5	19
17338	2019-12-07 13:40:15	2019-12-07	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	788	pick-up	0	41
17339	2019-12-07 13:49:26	2019-12-07	14	[{"id_menu":2,"count":1}]	6595	delivery	5	19
17340	2019-12-07 13:53:46	2019-12-07	9	[{"id_menu":6,"count":1}]	2185	pick-up	0	9
17341	2019-12-07 13:57:50	2019-12-07	8	[{"id_menu":5,"count":1}]	3909	pick-up	0	8
17342	2019-12-07 14:12:49	2019-12-07	9	[{"id_menu":7,"count":1}]	6570	delivery	5	14
17343	2019-12-07 14:15:42	2019-12-07	17	[{"id_menu":4,"count":1}]	2515	pick-up	0	17
17344	2019-12-07 14:21:43	2019-12-07	9	[{"id_menu":6,"count":1}]	3972	delivery	5	14
17345	2019-12-07 14:31:58	2019-12-07	8	[{"id_menu":5,"count":1}]	6575	pick-up	0	8
17346	2019-12-07 14:41:05	2019-12-07	12	[{"id_menu":1,"count":1}]	6592	delivery	5	17
17347	2019-12-07 14:58:35	2019-12-07	9	[{"id_menu":7,"count":1}]	1896	pick-up	0	9
17348	2019-12-07 15:07:45	2019-12-07	17	[{"id_menu":4,"count":1}]	3862	pick-up	0	17
17349	2019-12-07 15:11:46	2019-12-07	17	[{"id_menu":4,"count":1}]	694	delivery	5	22
17350	2019-12-07 15:22:09	2019-12-07	9	[{"id_menu":6,"count":2}]	6571	delivery	5	14
17351	2019-12-07 15:33:21	2019-12-07	9	[{"id_menu":6,"count":1}]	2311	delivery	5	14
17352	2019-12-07 15:54:50	2019-12-07	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	6126	delivery	5	25
17353	2019-12-07 15:59:18	2019-12-07	14	[{"id_menu":2,"count":1}]	1453	delivery	5	19
17354	2019-12-07 16:11:00	2019-12-07	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1876	delivery	5	36
17355	2019-12-07 16:15:07	2019-12-07	14	[{"id_menu":2,"count":1}]	6568	delivery	5	19
17356	2019-12-07 16:16:33	2019-12-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6554	delivery	5	23
17357	2019-12-07 16:30:05	2019-12-07	9	[{"id_menu":7,"count":1}]	6119	delivery	5	14
17358	2019-12-07 16:31:26	2019-12-07	9	[{"id_menu":6,"count":1}]	3393	delivery	5	14
17359	2019-12-07 16:37:56	2019-12-07	12	[{"id_menu":1,"count":1}]	6567	delivery	5	17
17360	2019-12-07 16:40:46	2019-12-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1427	pick-up	0	18
17361	2019-12-07 16:49:22	2019-12-07	14	[{"id_menu":2,"count":1}]	249	delivery	5	19
17362	2019-12-07 16:51:44	2019-12-07	8	[{"id_menu":5,"count":1}]	2486	delivery	5	13
17363	2019-12-07 17:09:21	2019-12-07	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	275	pick-up	0	21
17364	2019-12-07 17:17:34	2019-12-07	12	[{"id_menu":3,"count":1}]	1765	pick-up	0	12
17365	2019-12-07 17:19:45	2019-12-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6566	delivery	5	28
17366	2019-12-07 17:27:57	2019-12-07	14	[{"id_menu":2,"count":1}]	6343	delivery	5	19
17367	2019-12-07 17:32:28	2019-12-07	17	[{"id_menu":4,"count":1}]	3703	delivery	5	22
17368	2019-12-07 17:47:50	2019-12-07	14	[{"id_menu":2,"count":1}]	5253	pick-up	0	14
17369	2019-12-07 17:49:19	2019-12-07	17	[{"id_menu":4,"count":1}]	6584	delivery	5	22
17370	2019-12-07 17:58:13	2019-12-07	8	[{"id_menu":5,"count":1}]	6612	delivery	5	13
17371	2019-12-07 18:05:06	2019-12-07	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	171	pick-up	0	29
17372	2019-12-07 18:11:24	2019-12-07	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	1460	delivery	5	28
17373	2019-12-07 18:24:51	2019-12-07	9	[{"id_menu":7,"count":1}]	1107	pick-up	0	9
17374	2019-12-07 18:56:42	2019-12-07	9	[{"id_menu":7,"count":1}]	6610	delivery	5	14
17375	2019-12-07 19:03:02	2019-12-07	9	[{"id_menu":6,"count":1}]	1813	delivery	5	14
17376	2019-12-07 19:04:39	2019-12-07	12	[{"id_menu":1,"count":1}]	92	pick-up	0	12
17377	2019-12-07 19:07:22	2019-12-07	9	[{"id_menu":6,"count":1}]	6562	pick-up	0	9
17378	2019-12-07 19:10:44	2019-12-07	9	[{"id_menu":7,"count":1}]	1729	delivery	5	14
17379	2019-12-07 19:11:37	2019-12-07	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3825	pick-up	0	26
17380	2019-12-07 19:23:34	2019-12-07	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	1208	pick-up	0	17
17381	2019-12-07 19:34:16	2019-12-07	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4792	delivery	5	45
17382	2019-12-07 19:34:42	2019-12-07	8	[{"id_menu":5,"count":1}]	764	delivery	5	13
17383	2019-12-07 19:36:58	2019-12-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2907	pick-up	0	21
17384	2019-12-07 19:40:00	2019-12-07	12	[{"id_menu":1,"count":1}]	2858	delivery	5	17
17385	2019-12-07 19:56:08	2019-12-07	9	[{"id_menu":6,"count":1}]	6605	delivery	5	14
17386	2019-12-07 19:59:40	2019-12-07	17	[{"id_menu":4,"count":1}]	6556	delivery	5	22
17387	2019-12-07 20:07:12	2019-12-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6582	delivery	5	22
17388	2019-12-07 20:09:19	2019-12-07	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6557	delivery	5	22
17389	2019-12-07 20:29:02	2019-12-07	17	[{"id_menu":4,"count":1}]	6232	pick-up	0	17
17390	2019-12-07 20:35:02	2019-12-07	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	6586	delivery	5	22
17391	2019-12-07 20:38:46	2019-12-07	12	[{"id_menu":3,"count":1}]	4170	pick-up	0	12
17392	2019-12-07 21:14:57	2019-12-07	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	5604	delivery	5	29
17393	2019-12-07 21:44:58	2019-12-07	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6594	delivery	5	42
17394	2019-12-07 22:07:25	2019-12-07	14	[{"id_menu":2,"count":1}]	1119	pick-up	0	14
17395	2019-12-07 22:18:33	2019-12-07	9	[{"id_menu":7,"count":1}]	6578	delivery	5	14
17396	2019-12-07 22:19:46	2019-12-07	9	[{"id_menu":6,"count":1}]	3491	pick-up	0	9
17397	2019-12-07 22:29:45	2019-12-07	9	[{"id_menu":6,"count":1}]	3286	delivery	5	14
17398	2019-12-07 22:34:37	2019-12-07	12	[{"id_menu":1,"count":1}]	6588	delivery	5	17
17399	2019-12-07 22:53:14	2019-12-07	14	[{"id_menu":2,"count":1}]	4731	delivery	5	19
17400	2019-12-07 22:54:07	2019-12-07	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	4424	delivery	5	34
17401	2019-12-07 23:00:14	2019-12-07	8	[{"id_menu":5,"count":1}]	4090	pick-up	0	8
17402	2019-12-07 23:07:06	2019-12-07	14	[{"id_menu":2,"count":1}]	6327	pick-up	0	14
17403	2019-12-07 23:07:40	2019-12-07	9	[{"id_menu":7,"count":1}]	2054	delivery	5	14
17404	2019-12-07 23:12:54	2019-12-07	14	[{"id_menu":2,"count":1}]	5094	pick-up	0	14
17405	2019-12-07 23:14:33	2019-12-07	17	[{"id_menu":4,"count":1}]	2101	delivery	5	22
17406	2019-12-07 23:22:01	2019-12-07	9	[{"id_menu":7,"count":1}]	6609	pick-up	0	9
17407	2019-12-07 23:33:35	2019-12-07	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3204	delivery	5	44
17408	2019-12-07 23:43:12	2019-12-07	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	2902	delivery	5	31
17409	2019-12-07 23:53:58	2019-12-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6553	delivery	5	23
17410	2019-12-07 23:55:54	2019-12-07	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6596	delivery	5	43
17411	2019-12-08 00:01:32	2019-12-08	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6652	delivery	5	31
17412	2019-12-08 00:06:43	2019-12-08	17	[{"id_menu":4,"count":1}]	5891	delivery	5	22
17413	2019-12-08 00:09:17	2019-12-08	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1107	pick-up	0	22
17414	2019-12-08 00:41:44	2019-12-08	9	[{"id_menu":6,"count":1}]	3711	pick-up	0	9
17415	2019-12-08 01:14:09	2019-12-08	8	[{"id_menu":5,"count":1}]	4200	delivery	5	13
17416	2019-12-08 01:14:17	2019-12-08	17	[{"id_menu":4,"count":1}]	3609	pick-up	0	17
17417	2019-12-08 01:22:52	2019-12-08	14	[{"id_menu":2,"count":1}]	2737	pick-up	0	14
17418	2019-12-08 01:32:09	2019-12-08	9	[{"id_menu":6,"count":1}]	2616	delivery	5	14
17419	2019-12-08 01:49:04	2019-12-08	17	[{"id_menu":4,"count":1}]	6636	delivery	5	22
17420	2019-12-08 01:52:52	2019-12-08	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	437	delivery	5	31
17421	2019-12-08 01:53:59	2019-12-08	9	[{"id_menu":6,"count":1}]	6631	delivery	5	14
17422	2019-12-08 01:59:00	2019-12-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6650	delivery	5	22
17423	2019-12-08 02:03:38	2019-12-08	14	[{"id_menu":2,"count":1}]	5857	pick-up	0	14
17424	2019-12-08 02:09:43	2019-12-08	17	[{"id_menu":4,"count":1}]	1935	pick-up	0	17
17425	2019-12-08 02:12:40	2019-12-08	9	[{"id_menu":7,"count":1}]	6627	delivery	5	14
17426	2019-12-08 02:20:01	2019-12-08	12	[{"id_menu":1,"count":1}]	6616	delivery	5	17
17427	2019-12-08 02:25:02	2019-12-08	14	[{"id_menu":2,"count":1}]	2043	pick-up	0	14
17428	2019-12-08 02:42:59	2019-12-08	9	[{"id_menu":6,"count":1}]	4387	delivery	5	14
17429	2019-12-08 02:50:39	2019-12-08	9	[{"id_menu":7,"count":1}]	3154	delivery	5	14
17430	2019-12-08 02:57:19	2019-12-08	17	[{"id_menu":4,"count":1}]	6663	delivery	5	22
17431	2019-12-08 02:58:13	2019-12-08	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5503	delivery	5	36
17432	2019-12-08 02:58:52	2019-12-08	14	[{"id_menu":2,"count":1}]	1106	pick-up	0	14
17433	2019-12-08 03:04:28	2019-12-08	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	5332	pick-up	0	17
17434	2019-12-08 03:06:23	2019-12-08	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2593	pick-up	0	26
17435	2019-12-08 03:10:54	2019-12-08	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6626	delivery	5	36
17436	2019-12-08 03:17:54	2019-12-08	12	[{"id_menu":3,"count":1}]	3509	pick-up	0	12
17437	2019-12-08 03:33:07	2019-12-08	17	[{"id_menu":4,"count":1}]	1079	delivery	5	22
17438	2019-12-08 03:51:32	2019-12-08	9	[{"id_menu":6,"count":1}]	6207	delivery	5	14
17439	2019-12-08 03:53:00	2019-12-08	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4453	pick-up	0	40
17440	2019-12-08 03:55:09	2019-12-08	12	[{"id_menu":1,"count":1}]	6655	delivery	5	17
17441	2019-12-08 04:00:53	2019-12-08	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	6263	delivery	5	26
17442	2019-12-08 04:03:07	2019-12-08	9	[{"id_menu":6,"count":1}]	1104	pick-up	0	9
17443	2019-12-08 04:12:26	2019-12-08	9	[{"id_menu":7,"count":1}]	6327	delivery	5	14
17444	2019-12-08 04:15:23	2019-12-08	9	[{"id_menu":7,"count":1}]	1201	delivery	5	14
17445	2019-12-08 04:18:12	2019-12-08	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	3745	pick-up	0	26
17446	2019-12-08 04:26:10	2019-12-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2734	delivery	5	23
17447	2019-12-08 04:27:57	2019-12-08	14	[{"id_menu":2,"count":1}]	717	pick-up	0	14
17448	2019-12-08 04:31:27	2019-12-08	8	[{"id_menu":5,"count":1}]	3312	delivery	5	13
17449	2019-12-08 04:32:22	2019-12-08	9	[{"id_menu":6,"count":2}]	281	delivery	5	14
17450	2019-12-08 04:37:04	2019-12-08	8	[{"id_menu":5,"count":1}]	1085	pick-up	0	8
17451	2019-12-08 04:40:52	2019-12-08	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	6628	delivery	5	23
17452	2019-12-08 04:42:41	2019-12-08	17	[{"id_menu":4,"count":2}]	3604	pick-up	0	17
17453	2019-12-08 04:51:08	2019-12-08	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	2955	delivery	5	39
17454	2019-12-08 05:06:09	2019-12-08	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	5253	delivery	5	26
17455	2019-12-08 05:09:44	2019-12-08	17	[{"id_menu":4,"count":1}]	6648	delivery	5	22
17456	2019-12-08 05:11:00	2019-12-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1379	delivery	5	23
17457	2019-12-08 05:12:17	2019-12-08	9	[{"id_menu":6,"count":1}]	317	pick-up	0	9
17458	2019-12-08 05:14:04	2019-12-08	14	[{"id_menu":2,"count":1}]	3111	pick-up	0	14
17459	2019-12-08 05:18:37	2019-12-08	9	[{"id_menu":6,"count":1}]	2309	pick-up	0	9
17460	2019-12-08 05:27:29	2019-12-08	9	[{"id_menu":6,"count":1}]	2450	delivery	5	14
17461	2019-12-08 05:33:30	2019-12-08	9	[{"id_menu":6,"count":2}]	1468	delivery	5	14
17462	2019-12-08 05:34:54	2019-12-08	14	[{"id_menu":2,"count":1}]	6092	delivery	5	19
17463	2019-12-08 05:43:57	2019-12-08	12	[{"id_menu":3,"count":2}]	4350	pick-up	0	12
17464	2019-12-08 05:49:49	2019-12-08	17	[{"id_menu":4,"count":1}]	6646	delivery	5	22
17465	2019-12-08 05:50:33	2019-12-08	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4008	delivery	5	43
17466	2019-12-08 06:03:20	2019-12-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	5707	delivery	5	23
17467	2019-12-08 06:06:25	2019-12-08	12	[{"id_menu":3,"count":2}]	1640	pick-up	0	12
17468	2019-12-08 06:10:36	2019-12-08	12	[{"id_menu":3,"count":1}]	2252	pick-up	0	12
17469	2019-12-08 06:16:12	2019-12-08	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5935	delivery	5	34
17470	2019-12-08 06:33:31	2019-12-08	12	[{"id_menu":1,"count":2}]	3949	pick-up	0	12
17471	2019-12-08 06:36:00	2019-12-08	9	[{"id_menu":7,"count":1}]	3933	pick-up	0	9
17472	2019-12-08 06:54:12	2019-12-08	14	[{"id_menu":2,"count":1}]	1445	delivery	5	19
17473	2019-12-08 07:04:01	2019-12-08	9	[{"id_menu":7,"count":1}]	2807	delivery	5	14
17474	2019-12-08 07:10:05	2019-12-08	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2592	pick-up	0	25
17475	2019-12-08 07:10:45	2019-12-08	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	1988	pick-up	0	26
17476	2019-12-08 07:11:56	2019-12-08	14	[{"id_menu":2,"count":1}]	1490	pick-up	0	14
17477	2019-12-08 07:24:11	2019-12-08	9	[{"id_menu":7,"count":1}]	861	pick-up	0	9
17478	2019-12-08 07:25:51	2019-12-08	8	[{"id_menu":5,"count":1}]	1968	pick-up	0	8
17479	2019-12-08 07:35:22	2019-12-08	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	5201	pick-up	0	21
17480	2019-12-08 07:39:07	2019-12-08	12	[{"id_menu":3,"count":1}]	3399	pick-up	0	12
17481	2019-12-08 07:45:02	2019-12-08	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2640	delivery	5	43
17482	2019-12-08 07:51:02	2019-12-08	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2300	pick-up	0	35
17483	2019-12-08 07:52:51	2019-12-08	12	[{"id_menu":3,"count":1}]	486	delivery	5	17
17484	2019-12-08 07:56:33	2019-12-08	14	[{"id_menu":2,"count":1}]	4102	pick-up	0	14
17485	2019-12-08 08:27:06	2019-12-08	8	[{"id_menu":5,"count":1}]	337	delivery	5	13
17486	2019-12-08 08:32:31	2019-12-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5022	delivery	5	23
17487	2019-12-08 08:40:44	2019-12-08	14	[{"id_menu":2,"count":1}]	6649	delivery	5	19
17488	2019-12-08 08:41:33	2019-12-08	14	[{"id_menu":2,"count":1}]	223	pick-up	0	14
17489	2019-12-08 08:44:18	2019-12-08	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	6637	pick-up	0	24
17490	2019-12-08 08:47:31	2019-12-08	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	4352	delivery	5	31
17491	2019-12-08 08:48:24	2019-12-08	9	[{"id_menu":6,"count":1}]	29	delivery	5	14
17492	2019-12-08 09:05:05	2019-12-08	12	[{"id_menu":3,"count":1}]	4090	pick-up	0	12
17493	2019-12-08 09:08:03	2019-12-08	12	[{"id_menu":3,"count":1}]	1592	pick-up	0	12
17494	2019-12-08 09:12:15	2019-12-08	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6613	delivery	5	45
17495	2019-12-08 09:15:13	2019-12-08	12	[{"id_menu":3,"count":1}]	5478	pick-up	0	12
17496	2019-12-08 09:16:13	2019-12-08	12	[{"id_menu":3,"count":1}]	1952	pick-up	0	12
17497	2019-12-08 09:19:22	2019-12-08	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	2413	pick-up	0	24
17498	2019-12-08 09:27:31	2019-12-08	8	[{"id_menu":5,"count":1}]	2386	delivery	5	13
17499	2019-12-08 09:42:32	2019-12-08	9	[{"id_menu":6,"count":1}]	1352	pick-up	0	9
17500	2019-12-08 09:44:52	2019-12-08	14	[{"id_menu":2,"count":1}]	6621	pick-up	0	14
17501	2019-12-08 09:47:19	2019-12-08	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	4224	pick-up	0	20
17502	2019-12-08 09:49:34	2019-12-08	14	[{"id_menu":2,"count":1}]	4449	pick-up	0	14
17503	2019-12-08 09:58:44	2019-12-08	14	[{"id_menu":2,"count":1}]	6665	pick-up	0	14
17504	2019-12-08 09:59:39	2019-12-08	12	[{"id_menu":1,"count":1}]	6622	pick-up	0	12
17505	2019-12-08 10:00:23	2019-12-08	14	[{"id_menu":2,"count":1}]	4852	delivery	5	19
17506	2019-12-08 10:05:16	2019-12-08	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6482	delivery	5	37
17507	2019-12-08 10:08:24	2019-12-08	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6657	delivery	5	36
17508	2019-12-08 10:22:59	2019-12-08	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6618	delivery	5	31
17509	2019-12-08 10:33:58	2019-12-08	9	[{"id_menu":6,"count":1}]	3102	pick-up	0	9
17510	2019-12-08 10:33:59	2019-12-08	12	[{"id_menu":3,"count":1}]	5814	delivery	5	17
17511	2019-12-08 10:34:32	2019-12-08	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6478	delivery	5	30
17512	2019-12-08 10:52:31	2019-12-08	14	[{"id_menu":2,"count":1}]	3372	delivery	5	19
17513	2019-12-08 10:53:22	2019-12-08	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	6635	delivery	5	25
17514	2019-12-08 10:54:30	2019-12-08	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	3363	pick-up	0	21
17515	2019-12-08 11:01:05	2019-12-08	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	6619	delivery	5	27
17516	2019-12-08 11:16:08	2019-12-08	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3483	delivery	5	22
17517	2019-12-08 11:27:17	2019-12-08	8	[{"id_menu":5,"count":1}]	6642	delivery	5	13
17518	2019-12-08 11:33:15	2019-12-08	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	6136	delivery	5	23
17519	2019-12-08 11:34:40	2019-12-08	9	[{"id_menu":7,"count":1}]	4141	delivery	5	14
17520	2019-12-08 11:41:05	2019-12-08	14	[{"id_menu":2,"count":1}]	1190	pick-up	0	14
17521	2019-12-08 11:41:30	2019-12-08	23	[{"id_menu":2,"count":3},{"id_menu":7,"count":1}]	286	delivery	5	28
17522	2019-12-08 11:44:15	2019-12-08	9	[{"id_menu":7,"count":1}]	6620	pick-up	0	9
17523	2019-12-08 11:44:38	2019-12-08	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	71	delivery	5	36
17524	2019-12-08 11:46:20	2019-12-08	17	[{"id_menu":4,"count":1}]	4414	delivery	5	22
17525	2019-12-08 11:46:42	2019-12-08	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3848	pick-up	0	49
17526	2019-12-08 11:47:34	2019-12-08	12	[{"id_menu":1,"count":1}]	267	delivery	5	17
17527	2019-12-08 11:51:37	2019-12-08	8	[{"id_menu":5,"count":1}]	1585	pick-up	0	8
17528	2019-12-08 12:07:01	2019-12-08	14	[{"id_menu":2,"count":1}]	6643	delivery	5	19
17529	2019-12-08 12:18:29	2019-12-08	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3293	delivery	5	34
17530	2019-12-08 12:20:15	2019-12-08	14	[{"id_menu":2,"count":1}]	1858	pick-up	0	14
17531	2019-12-08 12:40:53	2019-12-08	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1115	delivery	5	31
17532	2019-12-08 12:43:54	2019-12-08	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6624	delivery	5	31
17533	2019-12-08 12:47:34	2019-12-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6660	delivery	5	22
17534	2019-12-08 12:51:40	2019-12-08	17	[{"id_menu":4,"count":1}]	41	pick-up	0	17
17535	2019-12-08 13:11:34	2019-12-08	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	3106	delivery	5	42
17536	2019-12-08 13:25:55	2019-12-08	14	[{"id_menu":2,"count":1}]	396	pick-up	0	14
17537	2019-12-08 13:30:51	2019-12-08	12	[{"id_menu":3,"count":1}]	4869	pick-up	0	12
17538	2019-12-08 13:35:10	2019-12-08	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6629	delivery	5	36
17539	2019-12-08 13:36:26	2019-12-08	17	[{"id_menu":4,"count":1}]	790	pick-up	0	17
17540	2019-12-08 13:36:52	2019-12-08	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3754	delivery	5	36
17541	2019-12-08 13:45:00	2019-12-08	14	[{"id_menu":2,"count":1}]	270	pick-up	0	14
17542	2019-12-08 13:47:13	2019-12-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2611	delivery	5	28
17543	2019-12-08 13:57:18	2019-12-08	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	5191	delivery	5	48
17544	2019-12-08 14:08:27	2019-12-08	17	[{"id_menu":4,"count":2}]	6062	pick-up	0	17
17545	2019-12-08 14:17:59	2019-12-08	14	[{"id_menu":2,"count":1}]	5768	delivery	5	19
17546	2019-12-08 14:18:01	2019-12-08	14	[{"id_menu":2,"count":1}]	6639	pick-up	0	14
17547	2019-12-08 14:31:32	2019-12-08	9	[{"id_menu":6,"count":1}]	2172	pick-up	0	9
17548	2019-12-08 14:33:14	2019-12-08	17	[{"id_menu":4,"count":1}]	4106	delivery	5	22
17549	2019-12-08 14:48:46	2019-12-08	17	[{"id_menu":4,"count":1}]	6634	pick-up	0	17
17550	2019-12-08 14:49:38	2019-12-08	9	[{"id_menu":7,"count":1}]	1475	delivery	5	14
17551	2019-12-08 15:21:16	2019-12-08	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	6659	delivery	5	22
17552	2019-12-08 15:47:51	2019-12-08	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6334	delivery	5	22
17553	2019-12-08 15:49:34	2019-12-08	8	[{"id_menu":5,"count":1}]	6326	delivery	5	13
17554	2019-12-08 16:05:37	2019-12-08	9	[{"id_menu":6,"count":1}]	5390	pick-up	0	9
17555	2019-12-08 16:29:40	2019-12-08	12	[{"id_menu":1,"count":1}]	3174	delivery	5	17
17556	2019-12-08 16:32:32	2019-12-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2979	delivery	5	28
17557	2019-12-08 16:35:59	2019-12-08	8	[{"id_menu":5,"count":1}]	6654	delivery	5	13
17558	2019-12-08 16:37:41	2019-12-08	33	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	6651	delivery	5	38
17559	2019-12-08 16:40:07	2019-12-08	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	979	pick-up	0	20
17560	2019-12-08 16:40:58	2019-12-08	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	5189	delivery	5	31
17561	2019-12-08 16:49:04	2019-12-08	9	[{"id_menu":7,"count":1}]	708	delivery	5	14
17562	2019-12-08 16:51:17	2019-12-08	8	[{"id_menu":5,"count":1}]	6658	pick-up	0	8
17563	2019-12-08 16:52:44	2019-12-08	9	[{"id_menu":6,"count":1}]	2106	pick-up	0	9
17564	2019-12-08 16:52:52	2019-12-08	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	162	pick-up	0	26
17565	2019-12-08 16:56:28	2019-12-08	8	[{"id_menu":5,"count":1}]	2485	delivery	5	13
17566	2019-12-08 16:57:07	2019-12-08	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4663	delivery	5	35
17567	2019-12-08 17:03:41	2019-12-08	12	[{"id_menu":3,"count":1}]	1956	pick-up	0	12
17568	2019-12-08 17:16:00	2019-12-08	9	[{"id_menu":7,"count":1}]	2507	delivery	5	14
17569	2019-12-08 17:21:27	2019-12-08	9	[{"id_menu":6,"count":1}]	2321	pick-up	0	9
17570	2019-12-08 17:22:52	2019-12-08	12	[{"id_menu":1,"count":1}]	262	pick-up	0	12
17571	2019-12-08 17:25:00	2019-12-08	12	[{"id_menu":1,"count":1}]	6666	delivery	5	17
17572	2019-12-08 17:29:17	2019-12-08	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6661	pick-up	0	25
17573	2019-12-08 17:30:59	2019-12-08	8	[{"id_menu":5,"count":2}]	2596	delivery	5	13
17574	2019-12-08 17:49:51	2019-12-08	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	6104	delivery	5	31
17575	2019-12-08 18:02:43	2019-12-08	12	[{"id_menu":3,"count":1}]	701	pick-up	0	12
17576	2019-12-08 18:05:32	2019-12-08	8	[{"id_menu":5,"count":1}]	1758	delivery	5	13
17577	2019-12-08 18:20:49	2019-12-08	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2415	delivery	5	31
17578	2019-12-08 18:20:53	2019-12-08	8	[{"id_menu":5,"count":1}]	5591	delivery	5	13
17579	2019-12-08 18:21:55	2019-12-08	8	[{"id_menu":5,"count":1}]	2025	pick-up	0	8
17580	2019-12-08 18:25:00	2019-12-08	9	[{"id_menu":6,"count":2}]	6632	delivery	5	14
17581	2019-12-08 18:26:39	2019-12-08	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	6025	delivery	5	39
17582	2019-12-08 18:32:06	2019-12-08	12	[{"id_menu":1,"count":1}]	2445	pick-up	0	12
17583	2019-12-08 18:33:14	2019-12-08	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	6089	pick-up	0	21
17584	2019-12-08 18:41:09	2019-12-08	8	[{"id_menu":5,"count":1}]	6015	delivery	5	13
17585	2019-12-08 18:47:40	2019-12-08	12	[{"id_menu":3,"count":1}]	5783	pick-up	0	12
17586	2019-12-08 18:49:35	2019-12-08	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5777	delivery	5	22
17587	2019-12-08 18:54:27	2019-12-08	12	[{"id_menu":3,"count":1}]	6647	pick-up	0	12
17588	2019-12-08 18:57:07	2019-12-08	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3440	pick-up	0	31
17589	2019-12-08 19:04:09	2019-12-08	17	[{"id_menu":4,"count":1}]	506	pick-up	0	17
17590	2019-12-08 19:07:59	2019-12-08	12	[{"id_menu":1,"count":1}]	1555	pick-up	0	12
17591	2019-12-08 19:14:22	2019-12-08	14	[{"id_menu":2,"count":1}]	3414	delivery	5	19
17592	2019-12-08 19:18:00	2019-12-08	12	[{"id_menu":3,"count":1}]	226	delivery	5	17
17593	2019-12-08 19:23:13	2019-12-08	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	6662	pick-up	0	20
17594	2019-12-08 19:24:06	2019-12-08	12	[{"id_menu":1,"count":1}]	6617	pick-up	0	12
17595	2019-12-08 19:32:20	2019-12-08	12	[{"id_menu":3,"count":1}]	2237	pick-up	0	12
17596	2019-12-08 19:56:59	2019-12-08	17	[{"id_menu":4,"count":1}]	68	pick-up	0	17
17597	2019-12-08 20:13:37	2019-12-08	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	6625	delivery	5	23
17598	2019-12-08 20:16:14	2019-12-08	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3155	pick-up	0	26
17599	2019-12-08 20:33:41	2019-12-08	14	[{"id_menu":2,"count":1}]	1800	pick-up	0	14
17600	2019-12-08 20:34:46	2019-12-08	12	[{"id_menu":3,"count":1}]	6645	pick-up	0	12
17601	2019-12-08 20:35:51	2019-12-08	9	[{"id_menu":7,"count":1}]	6656	delivery	5	14
17602	2019-12-08 20:53:43	2019-12-08	9	[{"id_menu":6,"count":1}]	6653	delivery	5	14
17603	2019-12-08 20:58:28	2019-12-08	14	[{"id_menu":2,"count":1}]	853	pick-up	0	14
17604	2019-12-08 21:00:59	2019-12-08	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6638	delivery	5	22
17605	2019-12-08 21:02:01	2019-12-08	12	[{"id_menu":1,"count":1}]	4870	pick-up	0	12
17606	2019-12-08 21:12:39	2019-12-08	9	[{"id_menu":6,"count":1}]	3227	pick-up	0	9
17607	2019-12-08 21:24:37	2019-12-08	17	[{"id_menu":4,"count":1}]	3054	pick-up	0	17
17608	2019-12-08 21:29:14	2019-12-08	14	[{"id_menu":2,"count":1}]	807	pick-up	0	14
17609	2019-12-08 21:45:55	2019-12-08	14	[{"id_menu":2,"count":1}]	6623	delivery	5	19
17610	2019-12-08 22:11:35	2019-12-08	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	6243	pick-up	0	22
17611	2019-12-08 22:11:56	2019-12-08	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	6633	delivery	5	26
17612	2019-12-08 22:16:42	2019-12-08	9	[{"id_menu":7,"count":1}]	2709	pick-up	0	9
17613	2019-12-08 22:24:07	2019-12-08	9	[{"id_menu":6,"count":1}]	1536	delivery	5	14
17614	2019-12-08 22:26:28	2019-12-08	8	[{"id_menu":5,"count":1}]	1393	delivery	5	13
17615	2019-12-08 22:36:27	2019-12-08	9	[{"id_menu":6,"count":1}]	6664	delivery	5	14
17616	2019-12-08 22:37:19	2019-12-08	12	[{"id_menu":1,"count":1}]	1485	pick-up	0	12
17617	2019-12-08 22:39:29	2019-12-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6640	delivery	5	28
17618	2019-12-08 22:40:38	2019-12-08	14	[{"id_menu":2,"count":1}]	5319	delivery	5	19
17619	2019-12-08 22:45:49	2019-12-08	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	6614	delivery	5	40
17620	2019-12-08 23:03:35	2019-12-08	12	[{"id_menu":1,"count":1}]	5286	delivery	5	17
17621	2019-12-08 23:13:27	2019-12-08	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5194	pick-up	0	17
17622	2019-12-08 23:17:05	2019-12-08	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6615	pick-up	0	35
17623	2019-12-08 23:17:31	2019-12-08	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	6630	delivery	5	26
17624	2019-12-08 23:25:07	2019-12-08	12	[{"id_menu":1,"count":1}]	6641	pick-up	0	12
17625	2019-12-08 23:26:03	2019-12-08	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	3614	delivery	5	27
17626	2019-12-08 23:26:03	2019-12-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	279	delivery	5	22
17627	2019-12-08 23:34:29	2019-12-08	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	950	pick-up	0	49
17628	2019-12-08 23:40:10	2019-12-08	9	[{"id_menu":7,"count":1}]	1259	delivery	5	14
17629	2019-12-08 23:48:04	2019-12-08	17	[{"id_menu":4,"count":1}]	6644	pick-up	0	17
17630	2019-12-08 23:50:44	2019-12-08	9	[{"id_menu":6,"count":1}]	3002	pick-up	0	9
17631	2019-12-08 23:52:22	2019-12-08	14	[{"id_menu":2,"count":1}]	482	delivery	5	19
17632	2019-12-09 00:44:28	2019-12-09	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	3394	delivery	5	31
17633	2019-12-09 01:03:58	2019-12-09	12	[{"id_menu":3,"count":1}]	6680	pick-up	0	12
17634	2019-12-09 01:08:11	2019-12-09	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	6672	pick-up	0	43
17635	2019-12-09 01:15:02	2019-12-09	8	[{"id_menu":5,"count":1}]	1430	pick-up	0	8
17636	2019-12-09 01:18:05	2019-12-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6702	delivery	5	22
17637	2019-12-09 01:19:45	2019-12-09	14	[{"id_menu":2,"count":1}]	6715	pick-up	0	14
17638	2019-12-09 01:34:06	2019-12-09	17	[{"id_menu":4,"count":1}]	4486	delivery	5	22
17639	2019-12-09 02:01:22	2019-12-09	8	[{"id_menu":5,"count":1}]	1813	pick-up	0	8
17640	2019-12-09 02:05:35	2019-12-09	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2599	delivery	5	31
17641	2019-12-09 02:12:42	2019-12-09	9	[{"id_menu":6,"count":1}]	6716	delivery	5	14
17642	2019-12-09 02:25:12	2019-12-09	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	6686	delivery	5	39
17643	2019-12-09 02:27:29	2019-12-09	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	6669	delivery	5	22
17644	2019-12-09 02:30:16	2019-12-09	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	764	delivery	5	36
17645	2019-12-09 02:31:29	2019-12-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6683	delivery	5	22
17646	2019-12-09 02:36:58	2019-12-09	14	[{"id_menu":2,"count":1}]	5679	pick-up	0	14
17647	2019-12-09 02:41:56	2019-12-09	8	[{"id_menu":5,"count":1}]	6671	pick-up	0	8
17648	2019-12-09 02:50:49	2019-12-09	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4034	pick-up	0	35
17649	2019-12-09 03:18:52	2019-12-09	17	[{"id_menu":4,"count":1}]	2806	delivery	5	22
17650	2019-12-09 03:36:04	2019-12-09	8	[{"id_menu":5,"count":1}]	3221	delivery	5	13
17651	2019-12-09 04:05:03	2019-12-09	17	[{"id_menu":4,"count":1}]	6708	pick-up	0	17
17652	2019-12-09 04:12:02	2019-12-09	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	3361	delivery	5	25
17653	2019-12-09 04:45:48	2019-12-09	14	[{"id_menu":2,"count":1}]	4614	delivery	5	19
17654	2019-12-09 04:53:44	2019-12-09	17	[{"id_menu":4,"count":2}]	2455	pick-up	0	17
17655	2019-12-09 05:07:08	2019-12-09	12	[{"id_menu":1,"count":1}]	1765	pick-up	0	12
17656	2019-12-09 05:08:14	2019-12-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6673	pick-up	0	17
17657	2019-12-09 05:08:52	2019-12-09	14	[{"id_menu":2,"count":1}]	6707	delivery	5	19
17658	2019-12-09 05:13:29	2019-12-09	12	[{"id_menu":1,"count":1}]	6694	delivery	5	17
17659	2019-12-09 05:24:40	2019-12-09	17	[{"id_menu":4,"count":1}]	6721	delivery	5	22
17660	2019-12-09 05:25:50	2019-12-09	12	[{"id_menu":3,"count":1}]	6710	delivery	5	17
17661	2019-12-09 05:39:17	2019-12-09	14	[{"id_menu":2,"count":1}]	1882	delivery	5	19
17662	2019-12-09 05:54:46	2019-12-09	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	531	pick-up	0	31
17663	2019-12-09 06:16:39	2019-12-09	9	[{"id_menu":7,"count":1}]	3372	pick-up	0	9
17664	2019-12-09 07:03:31	2019-12-09	12	[{"id_menu":1,"count":1}]	1432	pick-up	0	12
17665	2019-12-09 07:10:58	2019-12-09	8	[{"id_menu":5,"count":1}]	2590	pick-up	0	8
17666	2019-12-09 07:53:35	2019-12-09	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	742	delivery	5	25
17667	2019-12-09 08:26:56	2019-12-09	12	[{"id_menu":1,"count":1}]	1617	delivery	5	17
17668	2019-12-09 08:56:30	2019-12-09	17	[{"id_menu":4,"count":1}]	1423	pick-up	0	17
17669	2019-12-09 09:50:23	2019-12-09	9	[{"id_menu":7,"count":1}]	6711	delivery	5	14
17670	2019-12-09 09:54:05	2019-12-09	9	[{"id_menu":7,"count":1}]	591	delivery	5	14
17671	2019-12-09 10:11:39	2019-12-09	17	[{"id_menu":4,"count":1}]	3852	pick-up	0	17
17672	2019-12-09 10:17:13	2019-12-09	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	6701	delivery	5	34
17673	2019-12-09 10:28:46	2019-12-09	9	[{"id_menu":6,"count":1}]	6723	delivery	5	14
17674	2019-12-09 10:45:01	2019-12-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	203	pick-up	0	23
17675	2019-12-09 10:58:47	2019-12-09	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	2263	delivery	5	31
17676	2019-12-09 11:05:49	2019-12-09	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	6725	delivery	5	27
17677	2019-12-09 11:17:51	2019-12-09	17	[{"id_menu":4,"count":1}]	2615	pick-up	0	17
17678	2019-12-09 11:21:48	2019-12-09	9	[{"id_menu":7,"count":1}]	2916	pick-up	0	9
17679	2019-12-09 11:35:33	2019-12-09	12	[{"id_menu":3,"count":1}]	2427	pick-up	0	12
17680	2019-12-09 11:36:06	2019-12-09	14	[{"id_menu":2,"count":1}]	6703	pick-up	0	14
17681	2019-12-09 11:36:08	2019-12-09	9	[{"id_menu":6,"count":1}]	2552	delivery	5	14
17682	2019-12-09 12:16:55	2019-12-09	14	[{"id_menu":2,"count":1}]	1322	pick-up	0	14
17683	2019-12-09 12:23:19	2019-12-09	9	[{"id_menu":7,"count":1}]	6684	delivery	5	14
17684	2019-12-09 12:31:42	2019-12-09	8	[{"id_menu":5,"count":1}]	4937	pick-up	0	8
17685	2019-12-09 12:40:50	2019-12-09	17	[{"id_menu":4,"count":1}]	4721	pick-up	0	17
17686	2019-12-09 13:05:31	2019-12-09	12	[{"id_menu":1,"count":1}]	6410	pick-up	0	12
17687	2019-12-09 13:19:48	2019-12-09	9	[{"id_menu":6,"count":1}]	6678	delivery	5	14
17688	2019-12-09 13:26:06	2019-12-09	9	[{"id_menu":7,"count":1}]	6709	delivery	5	14
17689	2019-12-09 13:35:11	2019-12-09	12	[{"id_menu":3,"count":1}]	2875	delivery	5	17
17690	2019-12-09 13:59:26	2019-12-09	8	[{"id_menu":5,"count":1}]	6697	pick-up	0	8
17691	2019-12-09 14:19:00	2019-12-09	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1640	delivery	5	27
17692	2019-12-09 14:47:15	2019-12-09	17	[{"id_menu":4,"count":2}]	601	delivery	5	22
17693	2019-12-09 14:54:58	2019-12-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4297	delivery	5	23
17694	2019-12-09 14:58:53	2019-12-09	12	[{"id_menu":1,"count":1}]	6690	delivery	5	17
17695	2019-12-09 15:00:50	2019-12-09	8	[{"id_menu":5,"count":1}]	543	delivery	5	13
17696	2019-12-09 15:04:01	2019-12-09	17	[{"id_menu":4,"count":1}]	2441	pick-up	0	17
17697	2019-12-09 15:19:27	2019-12-09	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	6691	delivery	5	22
17698	2019-12-09 15:25:43	2019-12-09	8	[{"id_menu":5,"count":1}]	6699	delivery	5	13
17699	2019-12-09 15:27:31	2019-12-09	17	[{"id_menu":4,"count":2}]	506	pick-up	0	17
17700	2019-12-09 15:36:37	2019-12-09	12	[{"id_menu":3,"count":1}]	6489	pick-up	0	12
17701	2019-12-09 15:58:05	2019-12-09	12	[{"id_menu":1,"count":1}]	2460	pick-up	0	12
17702	2019-12-09 16:02:06	2019-12-09	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2173	pick-up	0	22
17703	2019-12-09 16:21:48	2019-12-09	9	[{"id_menu":6,"count":1}]	1685	delivery	5	14
17704	2019-12-09 16:26:08	2019-12-09	14	[{"id_menu":2,"count":1}]	5464	delivery	5	19
17705	2019-12-09 16:34:28	2019-12-09	8	[{"id_menu":5,"count":1}]	2245	pick-up	0	8
17706	2019-12-09 17:16:49	2019-12-09	17	[{"id_menu":4,"count":1}]	5922	pick-up	0	17
17707	2019-12-09 17:19:58	2019-12-09	14	[{"id_menu":2,"count":1}]	778	pick-up	0	14
17708	2019-12-09 17:31:25	2019-12-09	9	[{"id_menu":6,"count":1}]	3961	pick-up	0	9
17709	2019-12-09 17:36:20	2019-12-09	9	[{"id_menu":7,"count":1}]	3042	delivery	5	14
17710	2019-12-09 17:40:54	2019-12-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6235	pick-up	0	23
17711	2019-12-09 17:53:53	2019-12-09	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	6728	delivery	5	26
17712	2019-12-09 18:00:34	2019-12-09	9	[{"id_menu":7,"count":1}]	6688	delivery	5	14
17713	2019-12-09 18:07:11	2019-12-09	17	[{"id_menu":4,"count":1}]	2969	pick-up	0	17
17714	2019-12-09 18:18:49	2019-12-09	8	[{"id_menu":5,"count":1}]	3393	delivery	5	13
17715	2019-12-09 18:34:20	2019-12-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6696	delivery	5	28
17716	2019-12-09 18:39:11	2019-12-09	17	[{"id_menu":4,"count":1}]	5610	delivery	5	22
17717	2019-12-09 18:57:27	2019-12-09	17	[{"id_menu":4,"count":1}]	2004	pick-up	0	17
17718	2019-12-09 19:00:49	2019-12-09	8	[{"id_menu":5,"count":1}]	2544	pick-up	0	8
17719	2019-12-09 19:25:29	2019-12-09	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	5195	delivery	5	43
17720	2019-12-09 19:58:39	2019-12-09	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3350	delivery	5	37
17721	2019-12-09 20:07:35	2019-12-09	9	[{"id_menu":7,"count":1}]	3380	pick-up	0	9
17722	2019-12-09 20:16:41	2019-12-09	9	[{"id_menu":7,"count":2}]	3016	delivery	5	14
17723	2019-12-09 20:17:25	2019-12-09	8	[{"id_menu":5,"count":1}]	2873	pick-up	0	8
17724	2019-12-09 20:30:26	2019-12-09	12	[{"id_menu":1,"count":1}]	497	pick-up	0	12
17725	2019-12-09 20:31:39	2019-12-09	8	[{"id_menu":5,"count":1}]	136	pick-up	0	8
17726	2019-12-09 20:57:26	2019-12-09	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	511	delivery	5	45
17727	2019-12-09 20:59:19	2019-12-09	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1557	pick-up	0	24
17728	2019-12-09 20:59:30	2019-12-09	9	[{"id_menu":7,"count":3}]	6674	delivery	5	14
17729	2019-12-09 21:02:56	2019-12-09	9	[{"id_menu":7,"count":2}]	2810	pick-up	0	9
17730	2019-12-09 21:08:53	2019-12-09	9	[{"id_menu":7,"count":1}]	6689	pick-up	0	9
17731	2019-12-09 21:27:43	2019-12-09	12	[{"id_menu":1,"count":1}]	4343	delivery	5	17
17732	2019-12-09 21:37:07	2019-12-09	12	[{"id_menu":1,"count":1}]	6727	delivery	5	17
17733	2019-12-09 22:00:47	2019-12-09	9	[{"id_menu":6,"count":1}]	5172	pick-up	0	9
17734	2019-12-09 22:04:04	2019-12-09	9	[{"id_menu":7,"count":2}]	6677	delivery	5	14
17735	2019-12-09 22:16:01	2019-12-09	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	6722	delivery	5	31
17736	2019-12-09 22:21:35	2019-12-09	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	6181	pick-up	0	24
17737	2019-12-09 22:23:36	2019-12-09	12	[{"id_menu":3,"count":1}]	6718	delivery	5	17
17738	2019-12-09 22:30:48	2019-12-09	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6679	delivery	5	43
17739	2019-12-09 22:37:07	2019-12-09	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	6681	delivery	5	36
17740	2019-12-09 23:01:19	2019-12-09	8	[{"id_menu":5,"count":1}]	5945	pick-up	0	8
17741	2019-12-09 23:07:50	2019-12-09	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	847	pick-up	0	25
17742	2019-12-09 23:16:27	2019-12-09	8	[{"id_menu":5,"count":1}]	6693	delivery	5	13
17743	2019-12-09 23:24:00	2019-12-09	14	[{"id_menu":2,"count":1}]	2980	delivery	5	19
17744	2019-12-09 23:41:05	2019-12-09	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2851	delivery	5	39
17745	2019-12-10 00:07:45	2019-12-10	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	847	pick-up	0	29
17746	2019-12-10 00:14:05	2019-12-10	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1665	delivery	5	34
17747	2019-12-10 00:20:59	2019-12-10	9	[{"id_menu":7,"count":1}]	2071	delivery	5	14
17748	2019-12-10 00:31:03	2019-12-10	9	[{"id_menu":6,"count":1}]	626	delivery	5	14
17749	2019-12-10 00:36:42	2019-12-10	17	[{"id_menu":4,"count":1}]	5118	pick-up	0	17
17750	2019-12-10 00:41:25	2019-12-10	12	[{"id_menu":1,"count":1}]	2054	delivery	5	17
17751	2019-12-10 01:00:11	2019-12-10	14	[{"id_menu":2,"count":1}]	946	pick-up	0	14
17752	2019-12-10 01:10:03	2019-12-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6734	pick-up	0	23
17753	2019-12-10 01:10:41	2019-12-10	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	41	pick-up	0	17
17754	2019-12-10 01:11:22	2019-12-10	14	[{"id_menu":2,"count":1}]	4414	delivery	5	19
17755	2019-12-10 01:11:59	2019-12-10	9	[{"id_menu":6,"count":1}]	27	pick-up	0	9
17756	2019-12-10 01:26:10	2019-12-10	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	659	pick-up	0	22
17757	2019-12-10 01:59:09	2019-12-10	17	[{"id_menu":4,"count":1}]	6774	pick-up	0	17
17758	2019-12-10 02:11:16	2019-12-10	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	6759	delivery	5	25
17759	2019-12-10 02:44:59	2019-12-10	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3805	delivery	5	43
17760	2019-12-10 03:46:48	2019-12-10	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	6793	delivery	5	34
17761	2019-12-10 03:52:00	2019-12-10	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4636	pick-up	0	29
17762	2019-12-10 03:55:03	2019-12-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1995	pick-up	0	23
17763	2019-12-10 04:08:16	2019-12-10	9	[{"id_menu":7,"count":1}]	2415	pick-up	0	9
17764	2019-12-10 04:31:23	2019-12-10	9	[{"id_menu":6,"count":1}]	6778	delivery	5	14
17765	2019-12-10 04:33:43	2019-12-10	9	[{"id_menu":6,"count":1}]	788	delivery	5	14
17766	2019-12-10 04:34:05	2019-12-10	8	[{"id_menu":5,"count":1}]	1269	delivery	5	13
17767	2019-12-10 04:34:56	2019-12-10	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5091	delivery	5	35
17768	2019-12-10 04:57:42	2019-12-10	12	[{"id_menu":3,"count":1}]	1679	pick-up	0	12
17769	2019-12-10 05:01:53	2019-12-10	12	[{"id_menu":1,"count":1}]	153	pick-up	0	12
17770	2019-12-10 05:04:27	2019-12-10	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3065	pick-up	0	29
17771	2019-12-10 05:04:41	2019-12-10	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	6772	delivery	5	31
17772	2019-12-10 05:04:56	2019-12-10	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	4282	delivery	5	40
17773	2019-12-10 05:23:20	2019-12-10	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6776	delivery	5	22
17774	2019-12-10 05:24:01	2019-12-10	12	[{"id_menu":3,"count":1}]	6787	delivery	5	17
17775	2019-12-10 05:29:32	2019-12-10	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6786	delivery	5	35
17776	2019-12-10 05:46:50	2019-12-10	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	6785	delivery	5	23
17777	2019-12-10 05:57:04	2019-12-10	14	[{"id_menu":2,"count":1}]	379	pick-up	0	14
17778	2019-12-10 06:15:48	2019-12-10	17	[{"id_menu":4,"count":1}]	6182	pick-up	0	17
17779	2019-12-10 06:22:33	2019-12-10	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	623	pick-up	0	20
17780	2019-12-10 06:30:37	2019-12-10	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	6768	delivery	5	22
17781	2019-12-10 06:40:20	2019-12-10	12	[{"id_menu":3,"count":1}]	6589	pick-up	0	12
17782	2019-12-10 06:54:24	2019-12-10	14	[{"id_menu":2,"count":1}]	3230	pick-up	0	14
17783	2019-12-10 06:57:44	2019-12-10	12	[{"id_menu":3,"count":1}]	2153	pick-up	0	12
17784	2019-12-10 07:04:42	2019-12-10	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	6794	delivery	5	40
17785	2019-12-10 07:19:00	2019-12-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6749	delivery	5	23
17786	2019-12-10 07:31:06	2019-12-10	12	[{"id_menu":3,"count":1}]	3785	pick-up	0	12
17787	2019-12-10 07:40:44	2019-12-10	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	6746	delivery	5	25
17788	2019-12-10 08:06:15	2019-12-10	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6763	delivery	5	45
17789	2019-12-10 08:06:49	2019-12-10	14	[{"id_menu":2,"count":1}]	3916	delivery	5	19
17790	2019-12-10 08:08:55	2019-12-10	17	[{"id_menu":4,"count":1}]	6790	delivery	5	22
17791	2019-12-10 08:22:02	2019-12-10	12	[{"id_menu":3,"count":1}]	6743	delivery	5	17
17792	2019-12-10 08:22:48	2019-12-10	12	[{"id_menu":1,"count":1}]	599	delivery	5	17
17793	2019-12-10 08:31:01	2019-12-10	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	292	delivery	5	35
17794	2019-12-10 08:32:08	2019-12-10	9	[{"id_menu":7,"count":1}]	331	delivery	5	14
17795	2019-12-10 08:44:18	2019-12-10	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	6644	delivery	5	25
17796	2019-12-10 08:58:03	2019-12-10	12	[{"id_menu":1,"count":1}]	6744	pick-up	0	12
17797	2019-12-10 09:04:19	2019-12-10	8	[{"id_menu":5,"count":1}]	830	pick-up	0	8
17798	2019-12-10 09:18:07	2019-12-10	17	[{"id_menu":4,"count":1}]	4882	delivery	5	22
17799	2019-12-10 09:49:52	2019-12-10	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	6765	delivery	5	28
17800	2019-12-10 09:51:14	2019-12-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	1132	delivery	5	28
17801	2019-12-10 09:51:44	2019-12-10	14	[{"id_menu":2,"count":1}]	3126	delivery	5	19
17802	2019-12-10 10:57:59	2019-12-10	14	[{"id_menu":2,"count":2}]	3573	pick-up	0	14
17803	2019-12-10 11:16:20	2019-12-10	8	[{"id_menu":5,"count":1}]	6739	delivery	5	13
17804	2019-12-10 11:43:06	2019-12-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6761	delivery	5	22
17805	2019-12-10 11:48:56	2019-12-10	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	6773	delivery	5	44
17806	2019-12-10 12:00:03	2019-12-10	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	275	delivery	5	30
17807	2019-12-10 12:00:37	2019-12-10	9	[{"id_menu":7,"count":1}]	1084	delivery	5	14
17808	2019-12-10 12:05:12	2019-12-10	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5304	delivery	5	36
17809	2019-12-10 12:06:14	2019-12-10	12	[{"id_menu":1,"count":1}]	6735	delivery	5	17
17810	2019-12-10 12:24:33	2019-12-10	17	[{"id_menu":4,"count":2}]	6789	delivery	5	22
17811	2019-12-10 13:00:14	2019-12-10	9	[{"id_menu":7,"count":1}]	6173	pick-up	0	9
17812	2019-12-10 13:02:00	2019-12-10	8	[{"id_menu":5,"count":1}]	4370	pick-up	0	8
17813	2019-12-10 13:39:41	2019-12-10	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6296	delivery	5	31
17814	2019-12-10 13:42:18	2019-12-10	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	6752	delivery	5	26
17815	2019-12-10 13:44:53	2019-12-10	17	[{"id_menu":4,"count":2}]	6771	delivery	5	22
17816	2019-12-10 13:48:20	2019-12-10	9	[{"id_menu":7,"count":1}]	4749	delivery	5	14
17817	2019-12-10 13:52:25	2019-12-10	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6764	delivery	5	43
17818	2019-12-10 13:57:03	2019-12-10	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	6741	delivery	5	43
17819	2019-12-10 14:20:00	2019-12-10	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5110	delivery	5	43
17820	2019-12-10 14:46:29	2019-12-10	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	6782	delivery	5	40
17821	2019-12-10 14:50:11	2019-12-10	9	[{"id_menu":6,"count":4}]	6760	delivery	5	14
17822	2019-12-10 15:11:43	2019-12-10	12	[{"id_menu":1,"count":1}]	2264	pick-up	0	12
17823	2019-12-10 15:14:24	2019-12-10	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	6767	delivery	5	25
17824	2019-12-10 15:14:51	2019-12-10	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6751	delivery	5	45
17825	2019-12-10 15:27:37	2019-12-10	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	4363	pick-up	0	29
17826	2019-12-10 15:35:35	2019-12-10	12	[{"id_menu":1,"count":1}]	6766	delivery	5	17
17827	2019-12-10 15:44:00	2019-12-10	8	[{"id_menu":5,"count":1}]	6779	delivery	5	13
17828	2019-12-10 15:59:28	2019-12-10	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	3873	delivery	5	26
17829	2019-12-10 16:20:39	2019-12-10	12	[{"id_menu":1,"count":1}]	6740	delivery	5	17
17830	2019-12-10 16:27:35	2019-12-10	12	[{"id_menu":1,"count":1}]	6780	pick-up	0	12
17831	2019-12-10 17:11:03	2019-12-10	17	[{"id_menu":4,"count":1}]	6074	delivery	5	22
17832	2019-12-10 17:31:54	2019-12-10	14	[{"id_menu":2,"count":1}]	6745	pick-up	0	14
17833	2019-12-10 17:44:07	2019-12-10	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	6737	delivery	5	31
17834	2019-12-10 17:54:08	2019-12-10	12	[{"id_menu":3,"count":1}]	1162	pick-up	0	12
17835	2019-12-10 18:08:51	2019-12-10	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":3}]	367	delivery	5	22
17836	2019-12-10 18:10:15	2019-12-10	17	[{"id_menu":4,"count":1}]	543	delivery	5	22
17837	2019-12-10 18:16:25	2019-12-10	9	[{"id_menu":7,"count":1}]	2551	pick-up	0	9
17838	2019-12-10 18:21:22	2019-12-10	14	[{"id_menu":2,"count":1}]	1055	pick-up	0	14
17839	2019-12-10 18:26:19	2019-12-10	9	[{"id_menu":6,"count":1}]	5496	delivery	5	14
17840	2019-12-10 18:31:38	2019-12-10	17	[{"id_menu":4,"count":1}]	3293	delivery	5	22
17841	2019-12-10 18:40:52	2019-12-10	9	[{"id_menu":6,"count":2}]	4997	pick-up	0	9
17842	2019-12-10 19:08:18	2019-12-10	9	[{"id_menu":7,"count":1}]	1170	delivery	5	14
17843	2019-12-10 19:29:02	2019-12-10	9	[{"id_menu":7,"count":1}]	6756	pick-up	0	9
17844	2019-12-10 19:38:55	2019-12-10	9	[{"id_menu":6,"count":1}]	3227	pick-up	0	9
17845	2019-12-10 19:45:03	2019-12-10	9	[{"id_menu":6,"count":1}]	6732	delivery	5	14
17846	2019-12-10 19:46:49	2019-12-10	9	[{"id_menu":6,"count":1}]	1068	delivery	5	14
17847	2019-12-10 19:48:08	2019-12-10	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2217	pick-up	0	22
17848	2019-12-10 19:55:15	2019-12-10	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	6748	delivery	5	39
17849	2019-12-10 20:05:52	2019-12-10	8	[{"id_menu":5,"count":1}]	944	delivery	5	13
17850	2019-12-10 20:22:49	2019-12-10	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	6755	delivery	5	34
17851	2019-12-10 20:25:36	2019-12-10	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3882	delivery	5	22
17852	2019-12-10 20:28:52	2019-12-10	14	[{"id_menu":2,"count":1}]	136	pick-up	0	14
17853	2019-12-10 20:36:17	2019-12-10	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4262	delivery	5	31
17854	2019-12-10 20:37:53	2019-12-10	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	6736	delivery	5	23
17855	2019-12-10 20:38:17	2019-12-10	12	[{"id_menu":3,"count":1}]	3604	pick-up	0	12
17856	2019-12-10 20:38:33	2019-12-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6742	delivery	5	28
17857	2019-12-10 20:42:51	2019-12-10	9	[{"id_menu":6,"count":1}]	1992	pick-up	0	9
17858	2019-12-10 21:08:26	2019-12-10	9	[{"id_menu":7,"count":1}]	1188	pick-up	0	9
17859	2019-12-10 21:47:48	2019-12-10	12	[{"id_menu":1,"count":1}]	850	pick-up	0	12
17860	2019-12-10 21:58:01	2019-12-10	9	[{"id_menu":6,"count":1}]	4708	delivery	5	14
17861	2019-12-10 22:05:36	2019-12-10	9	[{"id_menu":6,"count":1}]	5109	delivery	5	14
17862	2019-12-10 22:12:35	2019-12-10	55	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	6792	delivery	5	60
17863	2019-12-10 22:21:49	2019-12-10	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6747	delivery	5	39
17864	2019-12-10 22:28:31	2019-12-10	14	[{"id_menu":2,"count":1}]	6769	delivery	5	19
17865	2019-12-10 23:07:22	2019-12-10	9	[{"id_menu":6,"count":1}]	2627	pick-up	0	9
17866	2019-12-10 23:09:39	2019-12-10	12	[{"id_menu":3,"count":1}]	1485	pick-up	0	12
17867	2019-12-10 23:24:46	2019-12-10	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3054	delivery	5	31
17868	2019-12-10 23:29:18	2019-12-10	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5508	delivery	5	22
17869	2019-12-10 23:33:27	2019-12-10	17	[{"id_menu":4,"count":1}]	3755	pick-up	0	17
17870	2019-12-10 23:36:26	2019-12-10	17	[{"id_menu":4,"count":1}]	6758	delivery	5	22
17871	2019-12-10 23:38:25	2019-12-10	8	[{"id_menu":5,"count":1}]	1756	pick-up	0	8
17872	2019-12-10 23:54:43	2019-12-10	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	802	pick-up	0	21
17873	2019-12-11 00:05:47	2019-12-11	14	[{"id_menu":2,"count":1}]	1196	delivery	5	19
17874	2019-12-11 00:07:31	2019-12-11	8	[{"id_menu":5,"count":1}]	624	pick-up	0	8
17875	2019-12-11 00:20:00	2019-12-11	12	[{"id_menu":1,"count":1}]	608	pick-up	0	12
17876	2019-12-11 00:35:47	2019-12-11	9	[{"id_menu":7,"count":1}]	3762	pick-up	0	9
17877	2019-12-11 00:44:24	2019-12-11	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2933	delivery	5	48
17878	2019-12-11 00:47:05	2019-12-11	14	[{"id_menu":2,"count":1}]	1850	delivery	5	19
17879	2019-12-11 00:57:33	2019-12-11	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3384	pick-up	0	34
17880	2019-12-11 01:02:44	2019-12-11	12	[{"id_menu":1,"count":1}]	6852	delivery	5	17
17881	2019-12-11 01:06:47	2019-12-11	8	[{"id_menu":5,"count":1}]	437	delivery	5	13
17882	2019-12-11 01:07:21	2019-12-11	12	[{"id_menu":1,"count":1}]	6818	delivery	5	17
17883	2019-12-11 01:11:44	2019-12-11	9	[{"id_menu":7,"count":1}]	6795	delivery	5	14
17884	2019-12-11 01:16:07	2019-12-11	14	[{"id_menu":2,"count":1}]	6808	delivery	5	19
17885	2019-12-11 01:17:39	2019-12-11	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6857	delivery	5	39
17886	2019-12-11 01:25:34	2019-12-11	14	[{"id_menu":2,"count":1}]	6859	delivery	5	19
17887	2019-12-11 01:26:14	2019-12-11	17	[{"id_menu":4,"count":1}]	2771	pick-up	0	17
17888	2019-12-11 01:26:22	2019-12-11	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	5572	delivery	5	26
17889	2019-12-11 01:46:54	2019-12-11	9	[{"id_menu":7,"count":1}]	4395	pick-up	0	9
17890	2019-12-11 01:47:28	2019-12-11	9	[{"id_menu":6,"count":1}]	2353	pick-up	0	9
17891	2019-12-11 01:49:30	2019-12-11	9	[{"id_menu":6,"count":1}]	1742	pick-up	0	9
17892	2019-12-11 02:02:18	2019-12-11	9	[{"id_menu":7,"count":1}]	6797	delivery	5	14
17893	2019-12-11 02:12:25	2019-12-11	9	[{"id_menu":6,"count":1}]	6861	delivery	5	14
17894	2019-12-11 02:17:38	2019-12-11	14	[{"id_menu":2,"count":1}]	5348	delivery	5	19
17895	2019-12-11 02:27:52	2019-12-11	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5643	pick-up	0	40
17896	2019-12-11 02:36:30	2019-12-11	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6028	delivery	5	31
17897	2019-12-11 02:37:23	2019-12-11	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	5500	delivery	5	34
17898	2019-12-11 02:41:31	2019-12-11	12	[{"id_menu":1,"count":1}]	3494	delivery	5	17
17899	2019-12-11 02:42:55	2019-12-11	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6802	delivery	5	40
17900	2019-12-11 03:01:26	2019-12-11	14	[{"id_menu":2,"count":1}]	6836	delivery	5	19
17901	2019-12-11 03:02:27	2019-12-11	9	[{"id_menu":7,"count":1}]	6464	delivery	5	14
17902	2019-12-11 03:02:46	2019-12-11	14	[{"id_menu":2,"count":1}]	4655	delivery	5	19
17903	2019-12-11 03:10:57	2019-12-11	17	[{"id_menu":4,"count":1}]	2717	pick-up	0	17
17904	2019-12-11 03:11:33	2019-12-11	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6829	delivery	5	31
17905	2019-12-11 03:26:57	2019-12-11	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	1452	pick-up	0	39
17906	2019-12-11 03:27:13	2019-12-11	9	[{"id_menu":6,"count":1}]	4825	pick-up	0	9
17907	2019-12-11 03:44:59	2019-12-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	6799	delivery	5	22
17908	2019-12-11 03:50:03	2019-12-11	9	[{"id_menu":7,"count":1}]	6809	delivery	5	14
17909	2019-12-11 03:51:10	2019-12-11	12	[{"id_menu":1,"count":1}]	6851	pick-up	0	12
17910	2019-12-11 03:57:30	2019-12-11	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1934	delivery	5	37
17911	2019-12-11 04:14:04	2019-12-11	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	253	pick-up	0	26
17912	2019-12-11 04:48:55	2019-12-11	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1074	delivery	5	43
17913	2019-12-11 04:50:21	2019-12-11	12	[{"id_menu":3,"count":1}]	216	delivery	5	17
17914	2019-12-11 04:51:25	2019-12-11	12	[{"id_menu":1,"count":1}]	6545	delivery	5	17
17915	2019-12-11 04:56:04	2019-12-11	17	[{"id_menu":4,"count":1}]	2602	pick-up	0	17
17916	2019-12-11 05:02:05	2019-12-11	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	6827	delivery	5	36
17917	2019-12-11 05:07:52	2019-12-11	17	[{"id_menu":4,"count":1}]	2011	delivery	5	22
17918	2019-12-11 05:15:16	2019-12-11	9	[{"id_menu":6,"count":1}]	6860	delivery	5	14
17919	2019-12-11 05:17:57	2019-12-11	9	[{"id_menu":6,"count":2}]	5479	delivery	5	14
17920	2019-12-11 05:21:08	2019-12-11	12	[{"id_menu":3,"count":1}]	4081	delivery	5	17
17921	2019-12-11 05:29:41	2019-12-11	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6826	delivery	5	34
17922	2019-12-11 05:38:46	2019-12-11	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	6854	delivery	5	31
17923	2019-12-11 05:45:55	2019-12-11	9	[{"id_menu":6,"count":1}]	3916	pick-up	0	9
17924	2019-12-11 05:55:13	2019-12-11	9	[{"id_menu":7,"count":1}]	2540	pick-up	0	9
17925	2019-12-11 05:59:14	2019-12-11	8	[{"id_menu":5,"count":1}]	304	pick-up	0	8
17926	2019-12-11 06:05:21	2019-12-11	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2176	pick-up	0	20
17927	2019-12-11 06:16:07	2019-12-11	8	[{"id_menu":5,"count":1}]	5522	delivery	5	13
17928	2019-12-11 06:20:45	2019-12-11	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6814	delivery	5	34
17929	2019-12-11 06:25:23	2019-12-11	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	6081	delivery	5	27
17930	2019-12-11 06:28:21	2019-12-11	14	[{"id_menu":2,"count":2}]	271	pick-up	0	14
17931	2019-12-11 06:30:38	2019-12-11	17	[{"id_menu":4,"count":1}]	6831	delivery	5	22
17932	2019-12-11 06:35:16	2019-12-11	9	[{"id_menu":6,"count":3}]	6819	delivery	5	14
17933	2019-12-11 06:39:00	2019-12-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	236	pick-up	0	23
17934	2019-12-11 06:43:11	2019-12-11	12	[{"id_menu":1,"count":1}]	1885	delivery	5	17
17935	2019-12-11 06:45:37	2019-12-11	8	[{"id_menu":5,"count":1}]	2787	delivery	5	13
17936	2019-12-11 06:50:07	2019-12-11	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3705	delivery	5	27
17937	2019-12-11 06:51:58	2019-12-11	8	[{"id_menu":5,"count":1}]	6825	pick-up	0	8
17938	2019-12-11 06:52:21	2019-12-11	17	[{"id_menu":4,"count":1}]	3355	pick-up	0	17
17939	2019-12-11 06:53:36	2019-12-11	17	[{"id_menu":4,"count":1}]	6845	pick-up	0	17
17940	2019-12-11 06:56:09	2019-12-11	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	6844	pick-up	0	24
17941	2019-12-11 06:57:01	2019-12-11	8	[{"id_menu":5,"count":1}]	5236	delivery	5	13
17942	2019-12-11 07:14:02	2019-12-11	8	[{"id_menu":5,"count":1}]	6832	delivery	5	13
17943	2019-12-11 07:45:42	2019-12-11	9	[{"id_menu":7,"count":1}]	2827	delivery	5	14
17944	2019-12-11 08:09:33	2019-12-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6835	delivery	5	22
17945	2019-12-11 08:28:05	2019-12-11	9	[{"id_menu":6,"count":1}]	2003	pick-up	0	9
17946	2019-12-11 08:49:55	2019-12-11	17	[{"id_menu":4,"count":1}]	5201	pick-up	0	17
17947	2019-12-11 09:00:24	2019-12-11	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	790	pick-up	0	26
17948	2019-12-11 09:04:16	2019-12-11	9	[{"id_menu":6,"count":1}]	4908	delivery	5	14
17949	2019-12-11 09:18:44	2019-12-11	9	[{"id_menu":7,"count":1}]	2351	pick-up	0	9
17950	2019-12-11 09:29:02	2019-12-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	910	pick-up	0	18
17951	2019-12-11 09:29:43	2019-12-11	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2101	delivery	5	53
17952	2019-12-11 09:39:40	2019-12-11	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3821	delivery	5	48
17953	2019-12-11 09:55:50	2019-12-11	14	[{"id_menu":2,"count":1}]	489	delivery	5	19
17954	2019-12-11 10:14:12	2019-12-11	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2056	pick-up	0	40
17955	2019-12-11 10:21:18	2019-12-11	17	[{"id_menu":4,"count":1}]	1992	pick-up	0	17
17956	2019-12-11 10:22:01	2019-12-11	14	[{"id_menu":2,"count":1}]	834	pick-up	0	14
17957	2019-12-11 10:27:36	2019-12-11	12	[{"id_menu":3,"count":1}]	4091	pick-up	0	12
17958	2019-12-11 10:46:47	2019-12-11	12	[{"id_menu":1,"count":1}]	6817	pick-up	0	12
17959	2019-12-11 11:10:31	2019-12-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1296	delivery	5	28
17960	2019-12-11 11:20:14	2019-12-11	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":2}]	6811	delivery	5	28
17961	2019-12-11 11:24:32	2019-12-11	9	[{"id_menu":6,"count":1}]	2185	delivery	5	14
17962	2019-12-11 11:28:55	2019-12-11	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6820	delivery	5	57
17963	2019-12-11 11:34:31	2019-12-11	14	[{"id_menu":2,"count":1}]	2339	delivery	5	19
17964	2019-12-11 11:50:31	2019-12-11	9	[{"id_menu":6,"count":1}]	2929	delivery	5	14
17965	2019-12-11 12:24:50	2019-12-11	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1563	pick-up	0	21
17966	2019-12-11 12:27:03	2019-12-11	9	[{"id_menu":7,"count":1}]	6535	pick-up	0	9
17967	2019-12-11 12:34:47	2019-12-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	6805	delivery	5	23
17968	2019-12-11 12:43:41	2019-12-11	12	[{"id_menu":1,"count":1}]	3000	pick-up	0	12
17969	2019-12-11 12:52:45	2019-12-11	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6850	delivery	5	22
17970	2019-12-11 13:13:48	2019-12-11	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":2}]	1545	delivery	5	27
17971	2019-12-11 13:20:19	2019-12-11	9	[{"id_menu":7,"count":1}]	1988	pick-up	0	9
17972	2019-12-11 13:23:05	2019-12-11	12	[{"id_menu":1,"count":1}]	6800	delivery	5	17
17973	2019-12-11 13:28:55	2019-12-11	9	[{"id_menu":7,"count":1}]	6841	pick-up	0	9
17974	2019-12-11 13:38:35	2019-12-11	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	6843	pick-up	0	21
17975	2019-12-11 13:40:08	2019-12-11	14	[{"id_menu":2,"count":1}]	6834	delivery	5	19
17976	2019-12-11 13:46:05	2019-12-11	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	3318	pick-up	0	20
17977	2019-12-11 13:55:02	2019-12-11	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6813	delivery	5	56
17978	2019-12-11 13:56:28	2019-12-11	14	[{"id_menu":2,"count":1}]	2982	delivery	5	19
17979	2019-12-11 13:58:19	2019-12-11	9	[{"id_menu":7,"count":1}]	5579	delivery	5	14
17980	2019-12-11 14:12:25	2019-12-11	14	[{"id_menu":2,"count":1}]	601	delivery	5	19
17981	2019-12-11 14:20:30	2019-12-11	9	[{"id_menu":6,"count":1}]	6849	delivery	5	14
17982	2019-12-11 14:36:01	2019-12-11	12	[{"id_menu":1,"count":1}]	2932	pick-up	0	12
17983	2019-12-11 14:43:48	2019-12-11	12	[{"id_menu":1,"count":1}]	1644	pick-up	0	12
17984	2019-12-11 14:43:48	2019-12-11	12	[{"id_menu":1,"count":1}]	6848	pick-up	0	12
17985	2019-12-11 14:50:24	2019-12-11	9	[{"id_menu":7,"count":1}]	4509	delivery	5	14
17986	2019-12-11 15:01:21	2019-12-11	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5642	delivery	5	31
17987	2019-12-11 15:02:06	2019-12-11	9	[{"id_menu":6,"count":1}]	6798	delivery	5	14
17988	2019-12-11 15:02:36	2019-12-11	14	[{"id_menu":2,"count":2}]	6833	pick-up	0	14
17989	2019-12-11 15:03:23	2019-12-11	17	[{"id_menu":4,"count":1}]	150	delivery	5	22
17990	2019-12-11 15:06:37	2019-12-11	14	[{"id_menu":2,"count":3}]	6837	pick-up	0	14
17991	2019-12-11 15:09:49	2019-12-11	12	[{"id_menu":3,"count":1}]	5595	pick-up	0	12
17992	2019-12-11 15:10:55	2019-12-11	17	[{"id_menu":4,"count":1}]	1800	pick-up	0	17
17993	2019-12-11 15:24:33	2019-12-11	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1541	pick-up	0	24
17994	2019-12-11 15:29:19	2019-12-11	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	6846	delivery	5	34
17995	2019-12-11 15:44:29	2019-12-11	12	[{"id_menu":3,"count":1}]	6191	delivery	5	17
17996	2019-12-11 15:44:50	2019-12-11	17	[{"id_menu":4,"count":1}]	6842	pick-up	0	17
17997	2019-12-11 16:09:03	2019-12-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3716	delivery	5	28
17998	2019-12-11 16:13:46	2019-12-11	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	3153	pick-up	0	20
17999	2019-12-11 16:21:53	2019-12-11	9	[{"id_menu":6,"count":3}]	6847	delivery	5	14
18000	2019-12-11 16:32:53	2019-12-11	12	[{"id_menu":1,"count":1}]	5723	delivery	5	17
18001	2019-12-11 16:45:58	2019-12-11	12	[{"id_menu":1,"count":2}]	3908	pick-up	0	12
18002	2019-12-11 17:03:50	2019-12-11	9	[{"id_menu":6,"count":1}]	4952	delivery	5	14
18003	2019-12-11 17:21:58	2019-12-11	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6801	delivery	5	28
18004	2019-12-11 17:24:01	2019-12-11	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	4224	delivery	5	29
18005	2019-12-11 17:25:03	2019-12-11	12	[{"id_menu":3,"count":1}]	3794	delivery	5	17
18006	2019-12-11 17:25:59	2019-12-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	281	pick-up	0	17
18007	2019-12-11 17:27:02	2019-12-11	8	[{"id_menu":5,"count":1}]	135	delivery	5	13
18008	2019-12-11 17:36:55	2019-12-11	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6839	delivery	5	31
18009	2019-12-11 17:39:11	2019-12-11	8	[{"id_menu":5,"count":1}]	2442	delivery	5	13
18010	2019-12-11 17:41:35	2019-12-11	17	[{"id_menu":4,"count":1}]	6815	delivery	5	22
18011	2019-12-11 17:49:09	2019-12-11	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	2124	pick-up	0	31
18012	2019-12-11 17:59:34	2019-12-11	9	[{"id_menu":6,"count":1}]	1053	delivery	5	14
18013	2019-12-11 18:21:22	2019-12-11	12	[{"id_menu":3,"count":1}]	4411	pick-up	0	12
18014	2019-12-11 18:23:35	2019-12-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	4629	pick-up	0	23
18015	2019-12-11 18:28:43	2019-12-11	17	[{"id_menu":4,"count":1}]	6840	delivery	5	22
18016	2019-12-11 18:37:37	2019-12-11	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	6824	delivery	5	26
18017	2019-12-11 18:49:11	2019-12-11	17	[{"id_menu":4,"count":1}]	6807	pick-up	0	17
18018	2019-12-11 18:57:25	2019-12-11	12	[{"id_menu":1,"count":1}]	6855	pick-up	0	12
18019	2019-12-11 19:05:08	2019-12-11	9	[{"id_menu":6,"count":1}]	6853	delivery	5	14
18020	2019-12-11 19:10:54	2019-12-11	12	[{"id_menu":1,"count":1}]	6803	delivery	5	17
18021	2019-12-11 19:37:08	2019-12-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3627	delivery	5	23
18022	2019-12-11 20:09:52	2019-12-11	9	[{"id_menu":7,"count":1}]	4268	pick-up	0	9
18023	2019-12-11 20:10:17	2019-12-11	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1756	pick-up	0	24
18024	2019-12-11 20:34:44	2019-12-11	9	[{"id_menu":6,"count":1}]	6858	delivery	5	14
18025	2019-12-11 20:49:56	2019-12-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2520	pick-up	0	23
18026	2019-12-11 21:02:29	2019-12-11	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":3}]	1528	pick-up	0	25
18027	2019-12-11 21:17:28	2019-12-11	9	[{"id_menu":6,"count":1}]	2939	delivery	5	14
18028	2019-12-11 21:19:53	2019-12-11	9	[{"id_menu":7,"count":1}]	73	pick-up	0	9
18029	2019-12-11 21:20:52	2019-12-11	9	[{"id_menu":7,"count":1}]	6470	pick-up	0	9
18030	2019-12-11 21:25:06	2019-12-11	14	[{"id_menu":2,"count":1}]	1820	pick-up	0	14
18031	2019-12-11 21:51:36	2019-12-11	12	[{"id_menu":1,"count":1}]	376	delivery	5	17
18032	2019-12-11 22:12:48	2019-12-11	14	[{"id_menu":2,"count":1}]	3289	pick-up	0	14
18033	2019-12-11 22:30:58	2019-12-11	14	[{"id_menu":2,"count":2}]	4190	delivery	5	19
18034	2019-12-11 22:37:51	2019-12-11	17	[{"id_menu":4,"count":1}]	6823	delivery	5	22
18035	2019-12-11 22:41:56	2019-12-11	9	[{"id_menu":7,"count":1}]	6816	delivery	5	14
18036	2019-12-11 22:44:40	2019-12-11	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3054	pick-up	0	26
18037	2019-12-11 22:47:17	2019-12-11	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	5098	delivery	5	34
18038	2019-12-11 22:54:30	2019-12-11	12	[{"id_menu":3,"count":1}]	4470	pick-up	0	12
18039	2019-12-11 23:20:44	2019-12-11	8	[{"id_menu":5,"count":1}]	6810	pick-up	0	8
18040	2019-12-11 23:23:49	2019-12-11	14	[{"id_menu":2,"count":1}]	6822	delivery	5	19
18041	2019-12-11 23:26:06	2019-12-11	9	[{"id_menu":6,"count":1}]	5975	delivery	5	14
18042	2019-12-11 23:26:21	2019-12-11	8	[{"id_menu":5,"count":1}]	702	pick-up	0	8
18043	2019-12-11 23:39:51	2019-12-11	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2857	pick-up	0	25
18044	2019-12-11 23:45:43	2019-12-11	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	6856	delivery	5	39
18045	2019-12-11 23:51:11	2019-12-11	9	[{"id_menu":6,"count":2}]	2333	pick-up	0	9
18046	2019-12-12 00:02:16	2019-12-12	14	[{"id_menu":2,"count":1}]	1679	pick-up	0	14
18047	2019-12-12 00:08:11	2019-12-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6921	delivery	5	31
18048	2019-12-12 00:12:02	2019-12-12	8	[{"id_menu":5,"count":1}]	4694	delivery	5	13
18049	2019-12-12 00:14:35	2019-12-12	9	[{"id_menu":7,"count":1}]	6866	delivery	5	14
18050	2019-12-12 00:15:53	2019-12-12	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6875	delivery	5	28
18051	2019-12-12 00:48:13	2019-12-12	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6894	delivery	5	45
18052	2019-12-12 00:50:43	2019-12-12	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2010	delivery	5	28
18053	2019-12-12 01:02:45	2019-12-12	8	[{"id_menu":5,"count":1}]	6916	pick-up	0	8
18054	2019-12-12 01:12:36	2019-12-12	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1582	delivery	5	48
18055	2019-12-12 01:16:23	2019-12-12	29	[{"id_menu":3,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4519	delivery	5	34
18056	2019-12-12 01:29:10	2019-12-12	9	[{"id_menu":7,"count":1}]	5610	delivery	5	14
18057	2019-12-12 01:43:01	2019-12-12	14	[{"id_menu":2,"count":1}]	4890	delivery	5	19
18058	2019-12-12 01:49:38	2019-12-12	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	637	delivery	5	38
18059	2019-12-12 01:58:44	2019-12-12	9	[{"id_menu":7,"count":1}]	2609	pick-up	0	9
18060	2019-12-12 02:05:05	2019-12-12	12	[{"id_menu":1,"count":1}]	6733	delivery	5	17
18061	2019-12-12 02:09:29	2019-12-12	17	[{"id_menu":4,"count":1}]	2798	pick-up	0	17
18062	2019-12-12 02:12:01	2019-12-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	263	delivery	5	23
18063	2019-12-12 02:14:10	2019-12-12	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3000	pick-up	0	31
18064	2019-12-12 02:39:39	2019-12-12	9	[{"id_menu":7,"count":1}]	4451	pick-up	0	9
18065	2019-12-12 02:52:41	2019-12-12	9	[{"id_menu":6,"count":1}]	6900	delivery	5	14
18066	2019-12-12 03:24:57	2019-12-12	14	[{"id_menu":2,"count":1}]	2080	delivery	5	19
18067	2019-12-12 03:27:08	2019-12-12	12	[{"id_menu":3,"count":1}]	3512	pick-up	0	12
18068	2019-12-12 03:29:05	2019-12-12	9	[{"id_menu":7,"count":1}]	6889	delivery	5	14
18069	2019-12-12 03:50:19	2019-12-12	17	[{"id_menu":4,"count":1}]	6912	delivery	5	22
18070	2019-12-12 03:54:34	2019-12-12	8	[{"id_menu":5,"count":1}]	585	delivery	5	13
18071	2019-12-12 03:59:10	2019-12-12	17	[{"id_menu":4,"count":1}]	3982	pick-up	0	17
18072	2019-12-12 04:04:30	2019-12-12	17	[{"id_menu":4,"count":1}]	1317	pick-up	0	17
18073	2019-12-12 04:11:34	2019-12-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6877	delivery	5	28
18074	2019-12-12 04:13:47	2019-12-12	12	[{"id_menu":3,"count":1}]	778	pick-up	0	12
18075	2019-12-12 04:15:18	2019-12-12	17	[{"id_menu":4,"count":1}]	6908	delivery	5	22
18076	2019-12-12 05:09:28	2019-12-12	12	[{"id_menu":3,"count":1}]	3228	pick-up	0	12
18077	2019-12-12 05:14:30	2019-12-12	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	389	delivery	5	27
18078	2019-12-12 05:18:12	2019-12-12	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	6903	delivery	5	25
18079	2019-12-12 05:28:53	2019-12-12	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	313	pick-up	0	37
18080	2019-12-12 05:47:59	2019-12-12	8	[{"id_menu":5,"count":1}]	1548	pick-up	0	8
18081	2019-12-12 05:49:37	2019-12-12	8	[{"id_menu":5,"count":1}]	2221	pick-up	0	8
18082	2019-12-12 06:04:45	2019-12-12	9	[{"id_menu":6,"count":1}]	5491	pick-up	0	9
18083	2019-12-12 06:05:02	2019-12-12	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	1432	delivery	5	27
18084	2019-12-12 06:06:37	2019-12-12	12	[{"id_menu":3,"count":1}]	193	pick-up	0	12
18085	2019-12-12 06:16:45	2019-12-12	12	[{"id_menu":1,"count":1}]	1166	pick-up	0	12
18086	2019-12-12 06:56:43	2019-12-12	8	[{"id_menu":5,"count":1}]	3636	pick-up	0	8
18087	2019-12-12 07:04:00	2019-12-12	12	[{"id_menu":3,"count":1}]	6896	pick-up	0	12
18088	2019-12-12 07:04:17	2019-12-12	12	[{"id_menu":1,"count":1}]	5996	delivery	5	17
18089	2019-12-12 07:14:12	2019-12-12	9	[{"id_menu":6,"count":1}]	6880	delivery	5	14
18090	2019-12-12 07:16:48	2019-12-12	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6893	delivery	5	48
18091	2019-12-12 07:35:54	2019-12-12	8	[{"id_menu":5,"count":1}]	6182	delivery	5	13
18092	2019-12-12 07:57:48	2019-12-12	9	[{"id_menu":7,"count":1}]	3155	pick-up	0	9
18093	2019-12-12 08:00:10	2019-12-12	9	[{"id_menu":6,"count":2}]	6901	pick-up	0	9
18094	2019-12-12 08:14:41	2019-12-12	8	[{"id_menu":5,"count":1}]	6917	pick-up	0	8
18095	2019-12-12 08:19:41	2019-12-12	9	[{"id_menu":7,"count":1}]	1760	pick-up	0	9
18096	2019-12-12 08:21:39	2019-12-12	14	[{"id_menu":2,"count":1}]	6899	pick-up	0	14
18097	2019-12-12 08:23:27	2019-12-12	14	[{"id_menu":2,"count":1}]	3640	delivery	5	19
18098	2019-12-12 08:26:44	2019-12-12	8	[{"id_menu":5,"count":1}]	5111	delivery	5	13
18099	2019-12-12 08:38:13	2019-12-12	14	[{"id_menu":2,"count":1}]	6872	delivery	5	19
18100	2019-12-12 08:48:40	2019-12-12	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1313	pick-up	0	24
18101	2019-12-12 09:04:42	2019-12-12	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2432	pick-up	0	21
18102	2019-12-12 09:07:35	2019-12-12	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	3837	delivery	5	40
18103	2019-12-12 09:29:44	2019-12-12	9	[{"id_menu":6,"count":1}]	4666	delivery	5	14
18104	2019-12-12 09:50:06	2019-12-12	12	[{"id_menu":1,"count":3}]	6862	pick-up	0	12
18105	2019-12-12 09:51:32	2019-12-12	9	[{"id_menu":6,"count":2}]	376	pick-up	0	9
18106	2019-12-12 09:52:58	2019-12-12	9	[{"id_menu":6,"count":1}]	5634	delivery	5	14
18107	2019-12-12 10:10:03	2019-12-12	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	6888	delivery	5	25
18108	2019-12-12 10:14:35	2019-12-12	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	6876	delivery	5	27
18109	2019-12-12 10:22:52	2019-12-12	9	[{"id_menu":7,"count":1}]	1208	pick-up	0	9
18110	2019-12-12 10:30:26	2019-12-12	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":2}]	6864	delivery	5	22
18111	2019-12-12 10:38:15	2019-12-12	8	[{"id_menu":5,"count":1}]	676	pick-up	0	8
18112	2019-12-12 10:44:05	2019-12-12	12	[{"id_menu":1,"count":1}]	6868	delivery	5	17
18113	2019-12-12 10:48:35	2019-12-12	9	[{"id_menu":6,"count":1}]	6927	delivery	5	14
18114	2019-12-12 10:50:56	2019-12-12	9	[{"id_menu":7,"count":1}]	970	delivery	5	14
18115	2019-12-12 10:53:13	2019-12-12	17	[{"id_menu":4,"count":1}]	6873	delivery	5	22
18116	2019-12-12 10:54:37	2019-12-12	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	5970	pick-up	0	43
18117	2019-12-12 10:56:53	2019-12-12	12	[{"id_menu":3,"count":2}]	6915	delivery	5	17
18118	2019-12-12 11:10:49	2019-12-12	9	[{"id_menu":7,"count":1}]	6922	delivery	5	14
18119	2019-12-12 11:41:56	2019-12-12	12	[{"id_menu":1,"count":1}]	6867	delivery	5	17
18120	2019-12-12 11:45:12	2019-12-12	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6913	delivery	5	40
18121	2019-12-12 11:56:36	2019-12-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6919	delivery	5	28
18122	2019-12-12 12:08:02	2019-12-12	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	7	pick-up	0	29
18123	2019-12-12 12:29:12	2019-12-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	925	pick-up	0	18
18124	2019-12-12 12:38:42	2019-12-12	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1244	delivery	5	31
18125	2019-12-12 12:44:50	2019-12-12	17	[{"id_menu":4,"count":1}]	1790	pick-up	0	17
18126	2019-12-12 12:49:55	2019-12-12	14	[{"id_menu":2,"count":2}]	6468	pick-up	0	14
18127	2019-12-12 12:53:58	2019-12-12	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	4301	delivery	5	26
18128	2019-12-12 12:55:41	2019-12-12	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6678	delivery	5	22
18129	2019-12-12 12:56:11	2019-12-12	8	[{"id_menu":5,"count":1}]	6914	delivery	5	13
18130	2019-12-12 12:58:03	2019-12-12	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6885	pick-up	0	31
18131	2019-12-12 13:04:55	2019-12-12	12	[{"id_menu":1,"count":1}]	6796	pick-up	0	12
18132	2019-12-12 13:20:33	2019-12-12	12	[{"id_menu":3,"count":1}]	1819	pick-up	0	12
18133	2019-12-12 13:39:20	2019-12-12	14	[{"id_menu":2,"count":1}]	153	pick-up	0	14
18134	2019-12-12 13:50:55	2019-12-12	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	6729	delivery	5	36
18135	2019-12-12 13:53:22	2019-12-12	8	[{"id_menu":5,"count":1}]	4414	pick-up	0	8
18136	2019-12-12 14:15:41	2019-12-12	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6883	delivery	5	30
18137	2019-12-12 14:24:45	2019-12-12	9	[{"id_menu":6,"count":1}]	6911	delivery	5	14
18138	2019-12-12 14:34:21	2019-12-12	8	[{"id_menu":5,"count":1}]	6925	delivery	5	13
18139	2019-12-12 14:38:36	2019-12-12	9	[{"id_menu":6,"count":1}]	6906	pick-up	0	9
18140	2019-12-12 14:47:10	2019-12-12	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	189	delivery	5	26
18141	2019-12-12 14:47:56	2019-12-12	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	6898	delivery	5	34
18142	2019-12-12 14:52:43	2019-12-12	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5774	delivery	5	35
18143	2019-12-12 15:05:38	2019-12-12	9	[{"id_menu":6,"count":1}]	1254	pick-up	0	9
18144	2019-12-12 15:05:47	2019-12-12	9	[{"id_menu":6,"count":1}]	33	pick-up	0	9
18145	2019-12-12 15:10:44	2019-12-12	9	[{"id_menu":6,"count":1}]	3205	delivery	5	14
18146	2019-12-12 15:36:00	2019-12-12	12	[{"id_menu":3,"count":1}]	4350	pick-up	0	12
18147	2019-12-12 16:17:35	2019-12-12	17	[{"id_menu":4,"count":1}]	2366	pick-up	0	17
18148	2019-12-12 16:27:02	2019-12-12	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2076	pick-up	0	21
18149	2019-12-12 16:41:11	2019-12-12	9	[{"id_menu":7,"count":1}]	5193	delivery	5	14
18150	2019-12-12 16:57:10	2019-12-12	12	[{"id_menu":3,"count":1}]	6865	pick-up	0	12
18151	2019-12-12 17:39:14	2019-12-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1726	delivery	5	28
18152	2019-12-12 17:51:02	2019-12-12	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4347	delivery	5	26
18153	2019-12-12 17:53:37	2019-12-12	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1810	pick-up	0	23
18154	2019-12-12 17:54:14	2019-12-12	12	[{"id_menu":1,"count":1}]	6907	delivery	5	17
18155	2019-12-12 17:58:32	2019-12-12	12	[{"id_menu":1,"count":1}]	4577	pick-up	0	12
18156	2019-12-12 18:06:12	2019-12-12	9	[{"id_menu":6,"count":1}]	1576	pick-up	0	9
18157	2019-12-12 18:06:23	2019-12-12	14	[{"id_menu":2,"count":1}]	3033	pick-up	0	14
18158	2019-12-12 18:23:41	2019-12-12	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":3}]	6891	delivery	5	22
18159	2019-12-12 18:32:13	2019-12-12	9	[{"id_menu":7,"count":1}]	2519	pick-up	0	9
18160	2019-12-12 18:39:26	2019-12-12	9	[{"id_menu":7,"count":1}]	6878	delivery	5	14
18161	2019-12-12 18:39:58	2019-12-12	12	[{"id_menu":3,"count":1}]	6871	delivery	5	17
18162	2019-12-12 18:59:27	2019-12-12	37	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6062	pick-up	0	37
18163	2019-12-12 18:59:30	2019-12-12	17	[{"id_menu":4,"count":1}]	1298	delivery	5	22
18164	2019-12-12 19:07:09	2019-12-12	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3684	delivery	5	45
18165	2019-12-12 19:18:27	2019-12-12	14	[{"id_menu":2,"count":1}]	4242	pick-up	0	14
18166	2019-12-12 19:20:55	2019-12-12	9	[{"id_menu":7,"count":1}]	405	delivery	5	14
18167	2019-12-12 19:53:23	2019-12-12	12	[{"id_menu":1,"count":1}]	5807	delivery	5	17
18168	2019-12-12 19:55:15	2019-12-12	9	[{"id_menu":6,"count":1}]	6910	pick-up	0	9
18169	2019-12-12 20:01:34	2019-12-12	8	[{"id_menu":5,"count":1}]	1223	pick-up	0	8
18170	2019-12-12 20:02:26	2019-12-12	12	[{"id_menu":1,"count":1}]	6887	pick-up	0	12
18171	2019-12-12 20:04:28	2019-12-12	12	[{"id_menu":1,"count":1}]	6902	delivery	5	17
18172	2019-12-12 20:11:21	2019-12-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6904	delivery	5	23
18173	2019-12-12 20:11:48	2019-12-12	14	[{"id_menu":2,"count":1}]	60	pick-up	0	14
18174	2019-12-12 20:15:59	2019-12-12	12	[{"id_menu":3,"count":1}]	5506	pick-up	0	12
18175	2019-12-12 20:25:41	2019-12-12	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4219	delivery	5	40
18176	2019-12-12 20:46:37	2019-12-12	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	6928	delivery	5	25
18177	2019-12-12 21:09:46	2019-12-12	9	[{"id_menu":6,"count":1}]	883	pick-up	0	9
18178	2019-12-12 21:14:19	2019-12-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5125	pick-up	0	17
18179	2019-12-12 21:25:19	2019-12-12	12	[{"id_menu":1,"count":1}]	6923	delivery	5	17
18180	2019-12-12 21:27:46	2019-12-12	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4217	delivery	5	45
18181	2019-12-12 21:45:33	2019-12-12	9	[{"id_menu":7,"count":1}]	6879	delivery	5	14
18182	2019-12-12 21:47:44	2019-12-12	17	[{"id_menu":4,"count":1}]	2050	pick-up	0	17
18183	2019-12-12 22:02:30	2019-12-12	17	[{"id_menu":4,"count":1}]	4825	delivery	5	22
18184	2019-12-12 22:10:18	2019-12-12	9	[{"id_menu":6,"count":1}]	6869	delivery	5	14
18185	2019-12-12 22:21:51	2019-12-12	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	3236	delivery	5	31
18186	2019-12-12 22:28:13	2019-12-12	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	6890	delivery	5	28
18187	2019-12-12 22:34:21	2019-12-12	12	[{"id_menu":3,"count":1}]	3754	pick-up	0	12
18188	2019-12-12 22:38:34	2019-12-12	14	[{"id_menu":2,"count":1}]	6926	pick-up	0	14
18189	2019-12-12 22:41:18	2019-12-12	12	[{"id_menu":1,"count":1}]	623	delivery	5	17
18190	2019-12-12 22:47:47	2019-12-12	14	[{"id_menu":2,"count":1}]	1429	delivery	5	19
18191	2019-12-12 22:50:33	2019-12-12	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	6920	delivery	5	31
18192	2019-12-12 22:53:12	2019-12-12	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6870	delivery	5	35
18193	2019-12-12 22:56:52	2019-12-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6863	delivery	5	22
18194	2019-12-12 23:04:39	2019-12-12	14	[{"id_menu":2,"count":2}]	680	pick-up	0	14
18195	2019-12-12 23:14:21	2019-12-12	9	[{"id_menu":7,"count":1}]	6924	delivery	5	14
18196	2019-12-12 23:21:42	2019-12-12	17	[{"id_menu":4,"count":1}]	1233	delivery	5	22
18197	2019-12-12 23:36:10	2019-12-12	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	6897	delivery	5	26
18198	2019-12-12 23:43:01	2019-12-12	14	[{"id_menu":2,"count":1}]	2885	delivery	5	19
18199	2019-12-13 00:29:59	2019-12-13	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2139	pick-up	0	17
18200	2019-12-13 00:38:11	2019-12-13	17	[{"id_menu":4,"count":1}]	2400	delivery	5	22
18201	2019-12-13 00:39:36	2019-12-13	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6934	delivery	5	45
18202	2019-12-13 00:54:51	2019-12-13	9	[{"id_menu":6,"count":1}]	3420	pick-up	0	9
18203	2019-12-13 00:57:17	2019-12-13	8	[{"id_menu":5,"count":1}]	2513	delivery	5	13
18204	2019-12-13 01:04:55	2019-12-13	9	[{"id_menu":7,"count":1}]	6970	pick-up	0	9
18205	2019-12-13 01:17:22	2019-12-13	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5149	pick-up	0	38
18206	2019-12-13 01:41:10	2019-12-13	12	[{"id_menu":3,"count":1}]	5894	delivery	5	17
18207	2019-12-13 01:53:15	2019-12-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3961	pick-up	0	31
18208	2019-12-13 02:01:56	2019-12-13	9	[{"id_menu":7,"count":1}]	3493	delivery	5	14
18209	2019-12-13 02:04:23	2019-12-13	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	3614	delivery	5	34
18210	2019-12-13 02:05:48	2019-12-13	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4749	delivery	5	40
18211	2019-12-13 02:11:08	2019-12-13	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	41	delivery	5	29
18212	2019-12-13 02:12:24	2019-12-13	17	[{"id_menu":4,"count":1}]	6936	delivery	5	22
18213	2019-12-13 02:12:29	2019-12-13	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6966	delivery	5	28
18214	2019-12-13 02:12:47	2019-12-13	14	[{"id_menu":2,"count":1}]	6965	pick-up	0	14
18215	2019-12-13 02:28:44	2019-12-13	14	[{"id_menu":2,"count":1}]	6954	delivery	5	19
18216	2019-12-13 02:54:56	2019-12-13	17	[{"id_menu":4,"count":1}]	1445	delivery	5	22
18217	2019-12-13 03:24:06	2019-12-13	34	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	4096	pick-up	0	34
18218	2019-12-13 03:53:06	2019-12-13	12	[{"id_menu":3,"count":1}]	6511	pick-up	0	12
18219	2019-12-13 04:01:48	2019-12-13	14	[{"id_menu":2,"count":1}]	3916	pick-up	0	14
18220	2019-12-13 04:06:18	2019-12-13	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	6951	delivery	5	39
18221	2019-12-13 04:13:37	2019-12-13	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2191	pick-up	0	26
18222	2019-12-13 04:16:08	2019-12-13	14	[{"id_menu":2,"count":1}]	4800	pick-up	0	14
18223	2019-12-13 04:32:23	2019-12-13	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6932	delivery	5	45
18224	2019-12-13 04:37:45	2019-12-13	14	[{"id_menu":2,"count":1}]	778	pick-up	0	14
18225	2019-12-13 04:46:01	2019-12-13	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	378	pick-up	0	26
18226	2019-12-13 05:04:33	2019-12-13	8	[{"id_menu":5,"count":1}]	6960	delivery	5	13
18227	2019-12-13 05:17:52	2019-12-13	14	[{"id_menu":2,"count":1}]	5765	pick-up	0	14
18228	2019-12-13 05:32:46	2019-12-13	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	6933	delivery	5	26
18229	2019-12-13 05:34:51	2019-12-13	12	[{"id_menu":3,"count":2}]	993	pick-up	0	12
18230	2019-12-13 05:44:07	2019-12-13	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5718	delivery	5	35
18231	2019-12-13 05:46:48	2019-12-13	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	6841	delivery	5	26
18232	2019-12-13 05:58:53	2019-12-13	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2148	delivery	5	31
18233	2019-12-13 06:07:05	2019-12-13	12	[{"id_menu":3,"count":1}]	3173	delivery	5	17
18234	2019-12-13 06:44:48	2019-12-13	9	[{"id_menu":6,"count":1}]	1597	pick-up	0	9
18235	2019-12-13 06:46:19	2019-12-13	17	[{"id_menu":4,"count":1}]	6975	pick-up	0	17
18236	2019-12-13 07:09:08	2019-12-13	8	[{"id_menu":5,"count":1}]	6974	delivery	5	13
18237	2019-12-13 07:12:35	2019-12-13	9	[{"id_menu":7,"count":1}]	2605	delivery	5	14
18238	2019-12-13 07:35:59	2019-12-13	9	[{"id_menu":6,"count":1}]	1731	delivery	5	14
18239	2019-12-13 07:47:28	2019-12-13	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2264	pick-up	0	40
18240	2019-12-13 07:50:28	2019-12-13	8	[{"id_menu":5,"count":1}]	6948	pick-up	0	8
18241	2019-12-13 07:54:14	2019-12-13	14	[{"id_menu":2,"count":1}]	2850	pick-up	0	14
18242	2019-12-13 08:15:34	2019-12-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6952	pick-up	0	18
18243	2019-12-13 08:16:58	2019-12-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":3}]	3104	pick-up	0	23
18244	2019-12-13 08:27:48	2019-12-13	14	[{"id_menu":2,"count":1}]	6968	pick-up	0	14
18245	2019-12-13 08:37:35	2019-12-13	17	[{"id_menu":4,"count":1}]	488	pick-up	0	17
18246	2019-12-13 08:39:28	2019-12-13	14	[{"id_menu":2,"count":1}]	324	pick-up	0	14
18247	2019-12-13 08:44:39	2019-12-13	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	988	delivery	5	22
18248	2019-12-13 08:54:41	2019-12-13	9	[{"id_menu":7,"count":1}]	6964	delivery	5	14
18249	2019-12-13 08:57:19	2019-12-13	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	176	pick-up	0	23
18250	2019-12-13 08:57:58	2019-12-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6969	delivery	5	36
18251	2019-12-13 09:05:47	2019-12-13	14	[{"id_menu":2,"count":1}]	256	pick-up	0	14
18252	2019-12-13 09:11:31	2019-12-13	12	[{"id_menu":3,"count":1}]	496	delivery	5	17
18253	2019-12-13 09:13:14	2019-12-13	9	[{"id_menu":6,"count":1}]	2826	pick-up	0	9
18254	2019-12-13 09:21:29	2019-12-13	9	[{"id_menu":7,"count":1}]	5805	delivery	5	14
18255	2019-12-13 09:29:06	2019-12-13	12	[{"id_menu":1,"count":1}]	5736	pick-up	0	12
18256	2019-12-13 09:31:19	2019-12-13	12	[{"id_menu":3,"count":1}]	6746	delivery	5	17
18257	2019-12-13 09:43:15	2019-12-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	358	delivery	5	23
18258	2019-12-13 09:50:10	2019-12-13	9	[{"id_menu":6,"count":1}]	640	delivery	5	14
18259	2019-12-13 10:00:33	2019-12-13	9	[{"id_menu":6,"count":1}]	3640	pick-up	0	9
18260	2019-12-13 10:06:47	2019-12-13	14	[{"id_menu":2,"count":1}]	1293	delivery	5	19
18261	2019-12-13 10:08:05	2019-12-13	14	[{"id_menu":2,"count":1}]	106	delivery	5	19
18262	2019-12-13 10:14:26	2019-12-13	9	[{"id_menu":6,"count":1}]	550	delivery	5	14
18263	2019-12-13 10:29:35	2019-12-13	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6953	delivery	5	45
18264	2019-12-13 10:36:29	2019-12-13	9	[{"id_menu":6,"count":1}]	4132	pick-up	0	9
18265	2019-12-13 10:50:21	2019-12-13	12	[{"id_menu":3,"count":1}]	997	pick-up	0	12
18266	2019-12-13 11:04:19	2019-12-13	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6981	delivery	5	34
18267	2019-12-13 11:12:51	2019-12-13	9	[{"id_menu":6,"count":1}]	1934	pick-up	0	9
18268	2019-12-13 11:19:08	2019-12-13	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6941	pick-up	0	26
18269	2019-12-13 11:22:36	2019-12-13	12	[{"id_menu":3,"count":1}]	1649	pick-up	0	12
18270	2019-12-13 11:42:27	2019-12-13	17	[{"id_menu":4,"count":1}]	6957	pick-up	0	17
18271	2019-12-13 11:50:27	2019-12-13	14	[{"id_menu":2,"count":1}]	2979	delivery	5	19
18272	2019-12-13 11:59:18	2019-12-13	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	6947	delivery	5	26
18273	2019-12-13 12:22:06	2019-12-13	12	[{"id_menu":3,"count":1}]	6946	pick-up	0	12
18274	2019-12-13 12:29:26	2019-12-13	14	[{"id_menu":2,"count":2}]	3153	delivery	5	19
18275	2019-12-13 12:52:11	2019-12-13	9	[{"id_menu":7,"count":1}]	3720	delivery	5	14
18276	2019-12-13 13:07:52	2019-12-13	9	[{"id_menu":6,"count":1}]	6593	delivery	5	14
18277	2019-12-13 13:27:13	2019-12-13	12	[{"id_menu":1,"count":1}]	6942	pick-up	0	12
18278	2019-12-13 13:50:14	2019-12-13	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6955	pick-up	0	17
18279	2019-12-13 14:12:24	2019-12-13	9	[{"id_menu":7,"count":1}]	6977	pick-up	0	9
18280	2019-12-13 14:29:35	2019-12-13	8	[{"id_menu":5,"count":1}]	1754	pick-up	0	8
18281	2019-12-13 14:57:11	2019-12-13	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	6979	delivery	5	38
18282	2019-12-13 14:59:50	2019-12-13	8	[{"id_menu":5,"count":1}]	1545	pick-up	0	8
18283	2019-12-13 15:01:44	2019-12-13	8	[{"id_menu":5,"count":1}]	5913	pick-up	0	8
18284	2019-12-13 15:07:09	2019-12-13	12	[{"id_menu":1,"count":1}]	287	pick-up	0	12
18285	2019-12-13 15:10:53	2019-12-13	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	244	delivery	5	40
18286	2019-12-13 15:15:48	2019-12-13	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2618	pick-up	0	26
18287	2019-12-13 15:19:54	2019-12-13	17	[{"id_menu":4,"count":1}]	6959	delivery	5	22
18288	2019-12-13 15:43:44	2019-12-13	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1460	pick-up	0	23
18289	2019-12-13 15:44:44	2019-12-13	12	[{"id_menu":1,"count":1}]	2181	pick-up	0	12
18290	2019-12-13 15:51:50	2019-12-13	14	[{"id_menu":2,"count":1}]	207	delivery	5	19
18291	2019-12-13 16:00:33	2019-12-13	9	[{"id_menu":6,"count":1}]	6956	delivery	5	14
18292	2019-12-13 16:05:06	2019-12-13	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5590	delivery	5	55
18293	2019-12-13 16:07:12	2019-12-13	12	[{"id_menu":1,"count":1}]	6972	pick-up	0	12
18294	2019-12-13 16:28:17	2019-12-13	9	[{"id_menu":7,"count":1}]	6935	delivery	5	14
18295	2019-12-13 16:42:30	2019-12-13	14	[{"id_menu":2,"count":1}]	6000	delivery	5	19
18296	2019-12-13 17:33:35	2019-12-13	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	4013	pick-up	0	24
18297	2019-12-13 17:36:29	2019-12-13	9	[{"id_menu":6,"count":1}]	5268	delivery	5	14
18298	2019-12-13 18:44:45	2019-12-13	12	[{"id_menu":1,"count":1}]	6100	pick-up	0	12
18299	2019-12-13 18:55:47	2019-12-13	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6930	delivery	5	43
18300	2019-12-13 19:07:50	2019-12-13	17	[{"id_menu":4,"count":1}]	6944	delivery	5	22
18301	2019-12-13 19:09:17	2019-12-13	9	[{"id_menu":6,"count":1}]	3463	pick-up	0	9
18302	2019-12-13 19:09:50	2019-12-13	8	[{"id_menu":5,"count":1}]	6940	delivery	5	13
18303	2019-12-13 19:32:40	2019-12-13	14	[{"id_menu":2,"count":1}]	2332	delivery	5	19
18304	2019-12-13 19:33:49	2019-12-13	14	[{"id_menu":2,"count":1}]	4617	pick-up	0	14
18305	2019-12-13 19:45:16	2019-12-13	14	[{"id_menu":2,"count":1}]	2123	pick-up	0	14
18306	2019-12-13 19:46:51	2019-12-13	17	[{"id_menu":4,"count":1}]	6945	delivery	5	22
18307	2019-12-13 20:09:25	2019-12-13	8	[{"id_menu":5,"count":1}]	3367	delivery	5	13
18308	2019-12-13 20:09:37	2019-12-13	38	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	6931	pick-up	0	38
18309	2019-12-13 20:10:49	2019-12-13	12	[{"id_menu":1,"count":1}]	4137	delivery	5	17
18310	2019-12-13 20:27:01	2019-12-13	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	5301	pick-up	0	37
18311	2019-12-13 20:33:21	2019-12-13	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1889	pick-up	0	24
18312	2019-12-13 20:33:46	2019-12-13	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	708	delivery	5	34
18313	2019-12-13 20:35:19	2019-12-13	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4095	delivery	5	37
18314	2019-12-13 21:00:48	2019-12-13	14	[{"id_menu":2,"count":1}]	2594	pick-up	0	14
18315	2019-12-13 21:17:08	2019-12-13	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	4605	delivery	5	26
18316	2019-12-13 21:17:57	2019-12-13	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3132	pick-up	0	21
18317	2019-12-13 21:24:59	2019-12-13	14	[{"id_menu":2,"count":1}]	6967	delivery	5	19
18318	2019-12-13 21:28:44	2019-12-13	17	[{"id_menu":4,"count":1}]	3976	pick-up	0	17
18319	2019-12-13 21:32:19	2019-12-13	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	4161	pick-up	0	29
18320	2019-12-13 21:56:58	2019-12-13	9	[{"id_menu":6,"count":3}]	6938	delivery	5	14
18321	2019-12-13 22:03:08	2019-12-13	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6971	delivery	5	31
18322	2019-12-13 22:08:57	2019-12-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5963	delivery	5	28
18323	2019-12-13 22:17:23	2019-12-13	14	[{"id_menu":2,"count":1}]	2732	pick-up	0	14
18324	2019-12-13 22:24:00	2019-12-13	12	[{"id_menu":1,"count":1}]	3567	delivery	5	17
18325	2019-12-13 22:32:12	2019-12-13	9	[{"id_menu":7,"count":2}]	6937	delivery	5	14
18326	2019-12-13 22:46:56	2019-12-13	14	[{"id_menu":2,"count":1}]	535	delivery	5	19
18327	2019-12-13 22:55:08	2019-12-13	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1970	delivery	5	34
18328	2019-12-13 23:11:19	2019-12-13	12	[{"id_menu":1,"count":1}]	5729	pick-up	0	12
18329	2019-12-13 23:13:50	2019-12-13	9	[{"id_menu":6,"count":1}]	2540	pick-up	0	9
18330	2019-12-13 23:22:13	2019-12-13	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3563	delivery	5	53
18331	2019-12-13 23:35:27	2019-12-13	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5733	pick-up	0	17
18332	2019-12-13 23:39:12	2019-12-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2054	pick-up	0	31
18333	2019-12-13 23:41:23	2019-12-13	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3115	pick-up	0	22
18334	2019-12-14 00:09:35	2019-12-14	9	[{"id_menu":7,"count":1}]	6987	pick-up	0	9
18335	2019-12-14 00:10:30	2019-12-14	17	[{"id_menu":4,"count":1}]	1444	delivery	5	22
18336	2019-12-14 00:17:28	2019-12-14	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	7035	delivery	5	23
18337	2019-12-14 00:29:06	2019-12-14	9	[{"id_menu":6,"count":2}]	3671	pick-up	0	9
18338	2019-12-14 00:29:30	2019-12-14	9	[{"id_menu":6,"count":3}]	7044	delivery	5	14
18339	2019-12-14 00:32:40	2019-12-14	8	[{"id_menu":5,"count":1}]	3280	delivery	5	13
18340	2019-12-14 00:59:35	2019-12-14	17	[{"id_menu":4,"count":1}]	2316	pick-up	0	17
18341	2019-12-14 01:01:06	2019-12-14	8	[{"id_menu":5,"count":1}]	1239	pick-up	0	8
18342	2019-12-14 01:06:07	2019-12-14	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	4652	pick-up	0	20
18343	2019-12-14 01:25:49	2019-12-14	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	7015	delivery	5	31
18344	2019-12-14 01:38:18	2019-12-14	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	7022	delivery	5	34
18345	2019-12-14 01:43:32	2019-12-14	14	[{"id_menu":2,"count":1}]	7012	pick-up	0	14
18346	2019-12-14 01:43:55	2019-12-14	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	7018	delivery	5	23
18347	2019-12-14 01:44:02	2019-12-14	12	[{"id_menu":1,"count":1}]	7042	delivery	5	17
18348	2019-12-14 01:46:41	2019-12-14	12	[{"id_menu":1,"count":1}]	7039	delivery	5	17
18349	2019-12-14 01:53:43	2019-12-14	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1334	pick-up	0	22
18350	2019-12-14 02:11:27	2019-12-14	14	[{"id_menu":2,"count":1}]	6988	delivery	5	19
18351	2019-12-14 02:25:12	2019-12-14	12	[{"id_menu":3,"count":2}]	841	pick-up	0	12
18352	2019-12-14 02:26:55	2019-12-14	9	[{"id_menu":7,"count":1}]	6989	delivery	5	14
18353	2019-12-14 02:29:56	2019-12-14	9	[{"id_menu":6,"count":1}]	1305	pick-up	0	9
18354	2019-12-14 02:34:15	2019-12-14	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	7025	delivery	5	36
18355	2019-12-14 02:50:25	2019-12-14	17	[{"id_menu":4,"count":1}]	7021	delivery	5	22
18356	2019-12-14 03:05:51	2019-12-14	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2672	pick-up	0	35
18357	2019-12-14 03:08:52	2019-12-14	9	[{"id_menu":7,"count":1}]	7016	delivery	5	14
18358	2019-12-14 03:19:16	2019-12-14	17	[{"id_menu":4,"count":1}]	293	delivery	5	22
18359	2019-12-14 03:41:40	2019-12-14	8	[{"id_menu":5,"count":1}]	458	delivery	5	13
18360	2019-12-14 03:49:56	2019-12-14	12	[{"id_menu":3,"count":1}]	7033	pick-up	0	12
18361	2019-12-14 04:01:22	2019-12-14	12	[{"id_menu":3,"count":1}]	4166	pick-up	0	12
18362	2019-12-14 04:05:56	2019-12-14	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2961	pick-up	0	22
18363	2019-12-14 04:06:06	2019-12-14	12	[{"id_menu":3,"count":1}]	3429	delivery	5	17
18364	2019-12-14 04:13:07	2019-12-14	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4960	delivery	5	31
18365	2019-12-14 04:17:58	2019-12-14	9	[{"id_menu":6,"count":1}]	4907	delivery	5	14
18366	2019-12-14 04:25:19	2019-12-14	9	[{"id_menu":6,"count":1}]	2605	delivery	5	14
18367	2019-12-14 04:26:18	2019-12-14	12	[{"id_menu":1,"count":2}]	3238	delivery	5	17
18368	2019-12-14 04:51:57	2019-12-14	12	[{"id_menu":1,"count":2}]	4825	pick-up	0	12
18369	2019-12-14 04:57:20	2019-12-14	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6996	pick-up	0	17
18370	2019-12-14 04:58:44	2019-12-14	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	113	pick-up	0	26
18371	2019-12-14 05:01:01	2019-12-14	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2739	pick-up	0	38
18372	2019-12-14 05:02:26	2019-12-14	9	[{"id_menu":7,"count":1}]	1143	delivery	5	14
18373	2019-12-14 05:03:17	2019-12-14	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3048	delivery	5	45
18374	2019-12-14 05:14:14	2019-12-14	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	7009	delivery	5	26
18375	2019-12-14 05:24:30	2019-12-14	12	[{"id_menu":3,"count":1}]	7008	delivery	5	17
18376	2019-12-14 05:34:44	2019-12-14	14	[{"id_menu":2,"count":1}]	2420	pick-up	0	14
18377	2019-12-14 05:37:40	2019-12-14	8	[{"id_menu":5,"count":1}]	4606	delivery	5	13
18378	2019-12-14 05:42:08	2019-12-14	12	[{"id_menu":1,"count":1}]	6818	delivery	5	17
18379	2019-12-14 05:46:03	2019-12-14	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":3}]	7003	delivery	5	22
18380	2019-12-14 05:51:37	2019-12-14	12	[{"id_menu":3,"count":1}]	3847	pick-up	0	12
18381	2019-12-14 05:51:41	2019-12-14	14	[{"id_menu":2,"count":1}]	4642	pick-up	0	14
18382	2019-12-14 05:59:04	2019-12-14	8	[{"id_menu":5,"count":1}]	7023	delivery	5	13
18383	2019-12-14 05:59:21	2019-12-14	9	[{"id_menu":7,"count":1}]	7027	delivery	5	14
18384	2019-12-14 06:09:08	2019-12-14	8	[{"id_menu":5,"count":1}]	3449	pick-up	0	8
18385	2019-12-14 06:28:31	2019-12-14	12	[{"id_menu":3,"count":1}]	2178	delivery	5	17
18386	2019-12-14 06:41:04	2019-12-14	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1659	pick-up	0	37
18387	2019-12-14 06:47:10	2019-12-14	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6994	pick-up	0	18
18388	2019-12-14 06:51:47	2019-12-14	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2699	delivery	5	26
18389	2019-12-14 06:53:10	2019-12-14	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	7036	delivery	5	26
18390	2019-12-14 07:05:33	2019-12-14	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	6986	delivery	5	26
18391	2019-12-14 07:42:18	2019-12-14	9	[{"id_menu":6,"count":1}]	7013	delivery	5	14
18392	2019-12-14 08:02:36	2019-12-14	9	[{"id_menu":6,"count":1}]	4029	delivery	5	14
18393	2019-12-14 08:04:43	2019-12-14	9	[{"id_menu":7,"count":1}]	2891	pick-up	0	9
18394	2019-12-14 08:05:45	2019-12-14	9	[{"id_menu":7,"count":1}]	4130	delivery	5	14
18395	2019-12-14 08:11:30	2019-12-14	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1313	pick-up	0	18
18396	2019-12-14 08:16:15	2019-12-14	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3895	delivery	5	27
18397	2019-12-14 08:29:14	2019-12-14	14	[{"id_menu":2,"count":1}]	3211	delivery	5	19
18398	2019-12-14 08:40:37	2019-12-14	14	[{"id_menu":2,"count":1}]	7005	delivery	5	19
18399	2019-12-14 08:49:15	2019-12-14	8	[{"id_menu":5,"count":1}]	575	pick-up	0	8
18400	2019-12-14 09:02:19	2019-12-14	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2578	delivery	5	27
18401	2019-12-14 09:07:50	2019-12-14	9	[{"id_menu":6,"count":1}]	264	pick-up	0	9
18402	2019-12-14 09:25:11	2019-12-14	14	[{"id_menu":2,"count":1}]	5027	pick-up	0	14
18403	2019-12-14 09:32:56	2019-12-14	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	5387	delivery	5	27
18404	2019-12-14 09:34:14	2019-12-14	9	[{"id_menu":6,"count":1}]	2398	pick-up	0	9
18405	2019-12-14 09:47:55	2019-12-14	12	[{"id_menu":1,"count":1}]	2384	delivery	5	17
18406	2019-12-14 09:50:46	2019-12-14	8	[{"id_menu":5,"count":1}]	7019	pick-up	0	8
18407	2019-12-14 09:53:38	2019-12-14	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4094	delivery	5	28
18408	2019-12-14 09:53:44	2019-12-14	9	[{"id_menu":7,"count":1}]	7041	delivery	5	14
18409	2019-12-14 09:53:44	2019-12-14	9	[{"id_menu":6,"count":1}]	5961	delivery	5	14
18410	2019-12-14 09:55:34	2019-12-14	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7040	pick-up	0	44
18411	2019-12-14 10:11:25	2019-12-14	9	[{"id_menu":7,"count":1}]	6993	delivery	5	14
18412	2019-12-14 10:15:26	2019-12-14	9	[{"id_menu":7,"count":1}]	5824	delivery	5	14
18413	2019-12-14 10:17:08	2019-12-14	8	[{"id_menu":5,"count":1}]	343	delivery	5	13
18414	2019-12-14 10:25:22	2019-12-14	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6991	delivery	5	40
18415	2019-12-14 10:27:23	2019-12-14	9	[{"id_menu":6,"count":1}]	4521	delivery	5	14
18416	2019-12-14 10:30:04	2019-12-14	12	[{"id_menu":1,"count":1}]	880	delivery	5	17
18417	2019-12-14 10:37:18	2019-12-14	17	[{"id_menu":4,"count":1}]	7045	delivery	5	22
18418	2019-12-14 10:40:26	2019-12-14	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	411	pick-up	0	21
18419	2019-12-14 10:46:33	2019-12-14	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	5094	pick-up	0	22
18420	2019-12-14 10:48:59	2019-12-14	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2139	pick-up	0	26
18421	2019-12-14 10:53:32	2019-12-14	17	[{"id_menu":4,"count":1}]	2735	delivery	5	22
18422	2019-12-14 10:59:57	2019-12-14	8	[{"id_menu":5,"count":1}]	7026	delivery	5	13
18423	2019-12-14 11:01:56	2019-12-14	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	3393	delivery	5	34
18424	2019-12-14 11:13:09	2019-12-14	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	5117	delivery	5	27
18425	2019-12-14 11:23:31	2019-12-14	9	[{"id_menu":7,"count":1}]	7014	delivery	5	14
18426	2019-12-14 11:32:27	2019-12-14	8	[{"id_menu":5,"count":1}]	7034	pick-up	0	8
18427	2019-12-14 11:34:27	2019-12-14	9	[{"id_menu":7,"count":1}]	7030	delivery	5	14
18428	2019-12-14 11:38:54	2019-12-14	9	[{"id_menu":7,"count":1}]	1215	pick-up	0	9
18429	2019-12-14 11:47:32	2019-12-14	14	[{"id_menu":2,"count":1}]	1732	pick-up	0	14
18430	2019-12-14 11:54:47	2019-12-14	12	[{"id_menu":3,"count":1}]	7020	delivery	5	17
18431	2019-12-14 11:55:14	2019-12-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6678	delivery	5	22
18432	2019-12-14 12:05:53	2019-12-14	12	[{"id_menu":1,"count":1}]	7032	delivery	5	17
18433	2019-12-14 12:08:05	2019-12-14	17	[{"id_menu":4,"count":1}]	3244	delivery	5	22
18434	2019-12-14 12:18:51	2019-12-14	12	[{"id_menu":1,"count":1}]	4728	delivery	5	17
18435	2019-12-14 12:23:02	2019-12-14	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2207	pick-up	0	18
18436	2019-12-14 12:28:12	2019-12-14	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	5649	delivery	5	27
18437	2019-12-14 12:29:31	2019-12-14	14	[{"id_menu":2,"count":1}]	1065	pick-up	0	14
18438	2019-12-14 12:30:17	2019-12-14	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	586	delivery	5	29
18439	2019-12-14 12:38:02	2019-12-14	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	68	pick-up	0	18
18440	2019-12-14 12:43:05	2019-12-14	8	[{"id_menu":5,"count":2}]	6116	delivery	5	13
18441	2019-12-14 12:56:08	2019-12-14	17	[{"id_menu":4,"count":1}]	5238	pick-up	0	17
18442	2019-12-14 13:02:38	2019-12-14	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	806	pick-up	0	29
18443	2019-12-14 13:48:18	2019-12-14	12	[{"id_menu":1,"count":2}]	3967	pick-up	0	12
18444	2019-12-14 13:56:40	2019-12-14	9	[{"id_menu":7,"count":1}]	7006	delivery	5	14
18445	2019-12-14 14:02:53	2019-12-14	14	[{"id_menu":2,"count":1}]	7046	pick-up	0	14
18446	2019-12-14 14:03:37	2019-12-14	12	[{"id_menu":1,"count":1}]	7011	delivery	5	17
18447	2019-12-14 14:09:16	2019-12-14	9	[{"id_menu":7,"count":1}]	4132	pick-up	0	9
18448	2019-12-14 14:41:55	2019-12-14	17	[{"id_menu":4,"count":1}]	2447	pick-up	0	17
18449	2019-12-14 14:49:57	2019-12-14	9	[{"id_menu":6,"count":1}]	6999	delivery	5	14
18450	2019-12-14 14:54:25	2019-12-14	17	[{"id_menu":4,"count":1}]	2579	pick-up	0	17
18451	2019-12-14 14:57:50	2019-12-14	12	[{"id_menu":3,"count":1}]	7017	delivery	5	17
18452	2019-12-14 15:03:37	2019-12-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	5663	delivery	5	22
18453	2019-12-14 15:19:27	2019-12-14	17	[{"id_menu":4,"count":1}]	2276	pick-up	0	17
18454	2019-12-14 15:21:11	2019-12-14	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	80	pick-up	0	20
18455	2019-12-14 15:22:52	2019-12-14	9	[{"id_menu":6,"count":1}]	1259	pick-up	0	9
18456	2019-12-14 15:29:37	2019-12-14	9	[{"id_menu":7,"count":1}]	7001	delivery	5	14
18457	2019-12-14 15:46:04	2019-12-14	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	7000	delivery	5	26
18458	2019-12-14 15:48:48	2019-12-14	12	[{"id_menu":1,"count":1}]	4922	pick-up	0	12
18459	2019-12-14 15:57:21	2019-12-14	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2151	pick-up	0	43
18460	2019-12-14 15:59:51	2019-12-14	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6983	delivery	5	34
18461	2019-12-14 16:17:08	2019-12-14	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3084	delivery	5	22
18462	2019-12-14 16:34:07	2019-12-14	14	[{"id_menu":2,"count":1}]	3071	delivery	5	19
18463	2019-12-14 16:41:10	2019-12-14	12	[{"id_menu":1,"count":2}]	146	pick-up	0	12
18464	2019-12-14 17:03:49	2019-12-14	9	[{"id_menu":7,"count":1}]	1943	pick-up	0	9
18465	2019-12-14 17:05:42	2019-12-14	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7050	pick-up	0	38
18466	2019-12-14 17:06:14	2019-12-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	5473	delivery	5	36
18467	2019-12-14 17:14:39	2019-12-14	17	[{"id_menu":4,"count":1}]	6984	pick-up	0	17
18468	2019-12-14 17:18:52	2019-12-14	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7004	delivery	5	39
18469	2019-12-14 17:20:57	2019-12-14	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6982	pick-up	0	35
18470	2019-12-14 17:35:04	2019-12-14	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5582	delivery	5	40
18471	2019-12-14 17:35:16	2019-12-14	9	[{"id_menu":6,"count":1}]	7048	delivery	5	14
18472	2019-12-14 17:40:52	2019-12-14	9	[{"id_menu":6,"count":1}]	7010	pick-up	0	9
18473	2019-12-14 17:44:33	2019-12-14	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	5699	delivery	5	34
18474	2019-12-14 18:15:23	2019-12-14	17	[{"id_menu":4,"count":1}]	2867	delivery	5	22
18475	2019-12-14 18:47:33	2019-12-14	9	[{"id_menu":6,"count":1}]	5708	delivery	5	14
18476	2019-12-14 19:04:23	2019-12-14	14	[{"id_menu":2,"count":1}]	7029	delivery	5	19
18477	2019-12-14 19:04:45	2019-12-14	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	543	pick-up	0	25
18478	2019-12-14 19:08:13	2019-12-14	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	7002	delivery	5	23
18479	2019-12-14 19:15:38	2019-12-14	8	[{"id_menu":5,"count":1}]	5189	delivery	5	13
18480	2019-12-14 19:35:59	2019-12-14	12	[{"id_menu":3,"count":1}]	7007	delivery	5	17
18481	2019-12-14 19:39:48	2019-12-14	17	[{"id_menu":4,"count":1}]	466	delivery	5	22
18482	2019-12-14 19:44:14	2019-12-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1942	delivery	5	22
18483	2019-12-14 19:58:19	2019-12-14	9	[{"id_menu":7,"count":1}]	6995	pick-up	0	9
18484	2019-12-14 19:58:20	2019-12-14	9	[{"id_menu":7,"count":1}]	4946	delivery	5	14
18485	2019-12-14 20:00:53	2019-12-14	17	[{"id_menu":4,"count":1}]	4371	delivery	5	22
18486	2019-12-14 20:04:11	2019-12-14	17	[{"id_menu":4,"count":1}]	4929	delivery	5	22
18487	2019-12-14 20:13:37	2019-12-14	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6971	pick-up	0	39
18488	2019-12-14 20:40:55	2019-12-14	9	[{"id_menu":7,"count":1}]	6990	pick-up	0	9
18489	2019-12-14 20:42:16	2019-12-14	12	[{"id_menu":1,"count":1}]	1885	pick-up	0	12
18490	2019-12-14 20:46:56	2019-12-14	12	[{"id_menu":1,"count":1}]	1745	pick-up	0	12
18491	2019-12-14 20:47:14	2019-12-14	9	[{"id_menu":7,"count":1}]	2780	pick-up	0	9
18492	2019-12-14 20:56:43	2019-12-14	12	[{"id_menu":3,"count":1}]	3065	pick-up	0	12
18493	2019-12-14 20:59:17	2019-12-14	9	[{"id_menu":6,"count":1}]	3444	pick-up	0	9
18494	2019-12-14 21:00:55	2019-12-14	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5197	delivery	5	30
18495	2019-12-14 21:08:18	2019-12-14	14	[{"id_menu":2,"count":1}]	7043	pick-up	0	14
18496	2019-12-14 21:23:13	2019-12-14	14	[{"id_menu":2,"count":1}]	7047	delivery	5	19
18497	2019-12-14 21:27:37	2019-12-14	9	[{"id_menu":6,"count":1}]	6758	pick-up	0	9
18498	2019-12-14 21:30:44	2019-12-14	8	[{"id_menu":5,"count":1}]	6992	delivery	5	13
18499	2019-12-14 21:38:26	2019-12-14	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	3003	pick-up	0	21
18500	2019-12-14 21:38:29	2019-12-14	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	511	pick-up	0	43
18501	2019-12-14 21:49:06	2019-12-14	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	802	delivery	5	26
18502	2019-12-14 22:14:48	2019-12-14	9	[{"id_menu":6,"count":1}]	1685	pick-up	0	9
18503	2019-12-14 22:40:33	2019-12-14	9	[{"id_menu":7,"count":1}]	314	pick-up	0	9
18504	2019-12-14 22:43:46	2019-12-14	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6985	delivery	5	23
18505	2019-12-14 22:56:39	2019-12-14	17	[{"id_menu":4,"count":1}]	1228	pick-up	0	17
18506	2019-12-14 23:02:06	2019-12-14	9	[{"id_menu":7,"count":1}]	1025	delivery	5	14
18507	2019-12-14 23:08:44	2019-12-14	17	[{"id_menu":4,"count":1}]	4486	pick-up	0	17
18508	2019-12-14 23:14:21	2019-12-14	9	[{"id_menu":7,"count":2}]	6998	delivery	5	14
18509	2019-12-14 23:20:57	2019-12-14	12	[{"id_menu":3,"count":2}]	7037	delivery	5	17
18510	2019-12-14 23:35:43	2019-12-14	17	[{"id_menu":4,"count":1}]	2107	delivery	5	22
18511	2019-12-14 23:37:06	2019-12-14	14	[{"id_menu":2,"count":1}]	5558	delivery	5	19
18512	2019-12-14 23:40:18	2019-12-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7038	pick-up	0	17
18513	2019-12-14 23:45:28	2019-12-14	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	6997	delivery	5	25
18514	2019-12-14 23:52:32	2019-12-14	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3494	pick-up	0	43
18515	2019-12-14 23:53:06	2019-12-14	12	[{"id_menu":1,"count":1}]	1537	delivery	5	17
18516	2019-12-14 23:59:53	2019-12-14	9	[{"id_menu":6,"count":1}]	7024	delivery	5	14
18517	2019-12-15 00:02:01	2019-12-15	12	[{"id_menu":1,"count":1}]	7082	delivery	5	17
18518	2019-12-15 00:06:03	2019-12-15	12	[{"id_menu":1,"count":1}]	484	pick-up	0	12
18519	2019-12-15 00:18:36	2019-12-15	17	[{"id_menu":5,"count":3},{"id_menu":6,"count":1}]	7070	delivery	5	22
18520	2019-12-15 00:27:48	2019-12-15	12	[{"id_menu":1,"count":1}]	5654	delivery	5	17
18521	2019-12-15 00:31:11	2019-12-15	17	[{"id_menu":4,"count":1}]	3380	delivery	5	22
18522	2019-12-15 00:32:09	2019-12-15	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4592	delivery	5	48
18523	2019-12-15 00:40:46	2019-12-15	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	5799	delivery	5	29
18524	2019-12-15 00:40:50	2019-12-15	9	[{"id_menu":7,"count":1}]	1360	pick-up	0	9
18525	2019-12-15 00:48:12	2019-12-15	12	[{"id_menu":3,"count":2}]	701	pick-up	0	12
18526	2019-12-15 00:50:29	2019-12-15	8	[{"id_menu":5,"count":1}]	2332	delivery	5	13
18527	2019-12-15 00:52:06	2019-12-15	12	[{"id_menu":3,"count":1}]	3429	delivery	5	17
18528	2019-12-15 01:08:33	2019-12-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7105	pick-up	0	18
18529	2019-12-15 01:09:38	2019-12-15	17	[{"id_menu":4,"count":1}]	1679	pick-up	0	17
18530	2019-12-15 01:11:43	2019-12-15	9	[{"id_menu":6,"count":1}]	1944	pick-up	0	9
18531	2019-12-15 01:26:10	2019-12-15	12	[{"id_menu":1,"count":1}]	1445	pick-up	0	12
18532	2019-12-15 01:27:54	2019-12-15	12	[{"id_menu":1,"count":1}]	4451	pick-up	0	12
18533	2019-12-15 01:37:26	2019-12-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	204	pick-up	0	23
18534	2019-12-15 01:40:34	2019-12-15	9	[{"id_menu":7,"count":1}]	7059	delivery	5	14
18535	2019-12-15 01:41:01	2019-12-15	9	[{"id_menu":7,"count":1}]	7074	pick-up	0	9
18536	2019-12-15 01:42:00	2019-12-15	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2651	pick-up	0	26
18537	2019-12-15 01:43:43	2019-12-15	12	[{"id_menu":1,"count":1}]	2280	delivery	5	17
18538	2019-12-15 01:46:11	2019-12-15	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5645	delivery	5	45
18539	2019-12-15 02:01:01	2019-12-15	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	57	pick-up	0	29
18540	2019-12-15 02:01:45	2019-12-15	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	7102	delivery	5	22
18541	2019-12-15 02:11:03	2019-12-15	9	[{"id_menu":6,"count":1}]	1684	delivery	5	14
18542	2019-12-15 02:18:39	2019-12-15	14	[{"id_menu":2,"count":1}]	6046	delivery	5	19
18543	2019-12-15 02:37:27	2019-12-15	8	[{"id_menu":5,"count":1}]	5024	delivery	5	13
18544	2019-12-15 02:37:48	2019-12-15	14	[{"id_menu":2,"count":1}]	2932	pick-up	0	14
18545	2019-12-15 02:47:49	2019-12-15	9	[{"id_menu":6,"count":1}]	7098	pick-up	0	9
18546	2019-12-15 02:48:23	2019-12-15	12	[{"id_menu":1,"count":1}]	3858	pick-up	0	12
18547	2019-12-15 03:44:11	2019-12-15	17	[{"id_menu":4,"count":1}]	807	pick-up	0	17
18548	2019-12-15 04:00:44	2019-12-15	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7079	pick-up	0	30
18549	2019-12-15 04:17:17	2019-12-15	8	[{"id_menu":5,"count":1}]	4352	delivery	5	13
18550	2019-12-15 04:17:20	2019-12-15	12	[{"id_menu":1,"count":1}]	5787	delivery	5	17
18551	2019-12-15 04:17:42	2019-12-15	8	[{"id_menu":5,"count":1}]	6465	pick-up	0	8
18552	2019-12-15 04:49:45	2019-12-15	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3135	pick-up	0	29
18553	2019-12-15 04:54:08	2019-12-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6193	delivery	5	23
18554	2019-12-15 04:54:56	2019-12-15	12	[{"id_menu":1,"count":1}]	1337	pick-up	0	12
18555	2019-12-15 04:55:14	2019-12-15	12	[{"id_menu":3,"count":1}]	7088	delivery	5	17
18556	2019-12-15 04:57:54	2019-12-15	17	[{"id_menu":4,"count":1}]	428	pick-up	0	17
18557	2019-12-15 04:59:25	2019-12-15	17	[{"id_menu":4,"count":2}]	3459	delivery	5	22
18558	2019-12-15 05:08:33	2019-12-15	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	6495	delivery	5	31
18559	2019-12-15 05:12:18	2019-12-15	17	[{"id_menu":4,"count":1}]	7069	pick-up	0	17
18560	2019-12-15 05:39:59	2019-12-15	9	[{"id_menu":6,"count":1}]	2750	delivery	5	14
18561	2019-12-15 05:40:37	2019-12-15	8	[{"id_menu":5,"count":1}]	4155	pick-up	0	8
18562	2019-12-15 05:42:52	2019-12-15	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	223	pick-up	0	29
18563	2019-12-15 05:56:29	2019-12-15	12	[{"id_menu":1,"count":1}]	7075	delivery	5	17
18564	2019-12-15 05:57:53	2019-12-15	17	[{"id_menu":4,"count":1}]	2410	pick-up	0	17
18565	2019-12-15 06:06:31	2019-12-15	17	[{"id_menu":4,"count":1}]	1400	pick-up	0	17
18566	2019-12-15 06:12:42	2019-12-15	9	[{"id_menu":6,"count":1}]	5571	delivery	5	14
18567	2019-12-15 06:17:15	2019-12-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4264	delivery	5	23
18568	2019-12-15 06:30:05	2019-12-15	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	933	pick-up	0	21
18569	2019-12-15 06:30:29	2019-12-15	14	[{"id_menu":2,"count":1}]	2193	pick-up	0	14
18570	2019-12-15 06:34:35	2019-12-15	8	[{"id_menu":5,"count":1}]	5886	delivery	5	13
18571	2019-12-15 06:38:59	2019-12-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	586	pick-up	0	23
18572	2019-12-15 06:39:48	2019-12-15	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	6901	pick-up	0	26
18573	2019-12-15 06:48:37	2019-12-15	9	[{"id_menu":6,"count":1}]	2413	pick-up	0	9
18574	2019-12-15 06:53:53	2019-12-15	8	[{"id_menu":5,"count":1}]	6648	delivery	5	13
18575	2019-12-15 06:55:03	2019-12-15	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	4300	delivery	5	26
18576	2019-12-15 06:57:13	2019-12-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6820	delivery	5	28
18577	2019-12-15 06:57:17	2019-12-15	12	[{"id_menu":3,"count":1}]	3436	delivery	5	17
18578	2019-12-15 07:02:28	2019-12-15	12	[{"id_menu":3,"count":1}]	4688	pick-up	0	12
18579	2019-12-15 07:04:01	2019-12-15	8	[{"id_menu":5,"count":1}]	1287	pick-up	0	8
18580	2019-12-15 07:10:08	2019-12-15	17	[{"id_menu":4,"count":1}]	2956	pick-up	0	17
18581	2019-12-15 07:13:45	2019-12-15	12	[{"id_menu":3,"count":1}]	4020	delivery	5	17
18582	2019-12-15 07:16:24	2019-12-15	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	874	pick-up	0	38
18583	2019-12-15 07:17:25	2019-12-15	9	[{"id_menu":7,"count":1}]	4739	delivery	5	14
18584	2019-12-15 07:20:53	2019-12-15	9	[{"id_menu":7,"count":2}]	7083	pick-up	0	9
18585	2019-12-15 07:26:40	2019-12-15	9	[{"id_menu":7,"count":1}]	1703	delivery	5	14
18586	2019-12-15 07:27:26	2019-12-15	9	[{"id_menu":6,"count":1}]	6644	delivery	5	14
18587	2019-12-15 07:27:27	2019-12-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7055	delivery	5	31
18588	2019-12-15 07:29:22	2019-12-15	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	7062	delivery	5	26
18589	2019-12-15 07:34:25	2019-12-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7085	delivery	5	28
18590	2019-12-15 07:35:50	2019-12-15	12	[{"id_menu":1,"count":1}]	7065	delivery	5	17
18591	2019-12-15 07:39:47	2019-12-15	9	[{"id_menu":6,"count":1}]	98	pick-up	0	9
18592	2019-12-15 07:55:54	2019-12-15	8	[{"id_menu":5,"count":1}]	7067	pick-up	0	8
18593	2019-12-15 07:57:10	2019-12-15	12	[{"id_menu":1,"count":1}]	1280	pick-up	0	12
18594	2019-12-15 07:58:00	2019-12-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7093	delivery	5	31
18595	2019-12-15 08:00:46	2019-12-15	9	[{"id_menu":7,"count":1}]	4321	delivery	5	14
18596	2019-12-15 08:01:51	2019-12-15	9	[{"id_menu":7,"count":1}]	6519	delivery	5	14
18597	2019-12-15 08:03:06	2019-12-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7072	pick-up	0	23
18598	2019-12-15 08:03:09	2019-12-15	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	7087	delivery	5	31
18599	2019-12-15 08:05:29	2019-12-15	9	[{"id_menu":6,"count":1}]	7106	delivery	5	14
18600	2019-12-15 08:07:01	2019-12-15	9	[{"id_menu":6,"count":1}]	1462	pick-up	0	9
18601	2019-12-15 08:07:28	2019-12-15	9	[{"id_menu":6,"count":1}]	931	pick-up	0	9
18602	2019-12-15 08:15:41	2019-12-15	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	7107	delivery	5	26
18603	2019-12-15 08:16:06	2019-12-15	14	[{"id_menu":2,"count":1}]	772	pick-up	0	14
18604	2019-12-15 08:17:43	2019-12-15	12	[{"id_menu":1,"count":1}]	6789	pick-up	0	12
18605	2019-12-15 08:38:25	2019-12-15	12	[{"id_menu":1,"count":1}]	7058	delivery	5	17
18606	2019-12-15 08:44:29	2019-12-15	9	[{"id_menu":7,"count":1}]	150	pick-up	0	9
18607	2019-12-15 08:45:05	2019-12-15	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7095	delivery	5	48
18608	2019-12-15 08:50:35	2019-12-15	12	[{"id_menu":1,"count":1}]	7094	delivery	5	17
18609	2019-12-15 08:58:43	2019-12-15	14	[{"id_menu":2,"count":1}]	1195	delivery	5	19
18610	2019-12-15 09:03:34	2019-12-15	12	[{"id_menu":1,"count":1}]	1537	pick-up	0	12
18611	2019-12-15 09:04:09	2019-12-15	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	4872	delivery	5	26
18612	2019-12-15 09:13:28	2019-12-15	12	[{"id_menu":1,"count":1}]	3987	delivery	5	17
18613	2019-12-15 09:19:09	2019-12-15	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	6170	delivery	5	35
18614	2019-12-15 09:20:16	2019-12-15	14	[{"id_menu":2,"count":1}]	3287	delivery	5	19
18615	2019-12-15 09:21:09	2019-12-15	9	[{"id_menu":6,"count":1}]	7101	delivery	5	14
18616	2019-12-15 09:26:13	2019-12-15	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7092	delivery	5	53
18617	2019-12-15 09:30:17	2019-12-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7064	delivery	5	28
18618	2019-12-15 09:36:31	2019-12-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4214	delivery	5	28
18619	2019-12-15 09:47:29	2019-12-15	41	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	92	pick-up	0	41
18620	2019-12-15 09:51:02	2019-12-15	9	[{"id_menu":7,"count":1}]	7051	delivery	5	14
18621	2019-12-15 09:59:40	2019-12-15	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	7077	delivery	5	27
18622	2019-12-15 10:01:22	2019-12-15	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	5155	delivery	5	36
18623	2019-12-15 10:24:39	2019-12-15	17	[{"id_menu":4,"count":1}]	7096	delivery	5	22
18624	2019-12-15 10:59:03	2019-12-15	17	[{"id_menu":4,"count":1}]	4316	pick-up	0	17
18625	2019-12-15 11:04:31	2019-12-15	9	[{"id_menu":6,"count":1}]	659	pick-up	0	9
18626	2019-12-15 11:08:01	2019-12-15	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2398	delivery	5	31
18627	2019-12-15 11:17:21	2019-12-15	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	5848	delivery	5	48
18628	2019-12-15 11:19:02	2019-12-15	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7073	delivery	5	36
18629	2019-12-15 11:21:35	2019-12-15	9	[{"id_menu":6,"count":1}]	5693	delivery	5	14
18630	2019-12-15 11:24:08	2019-12-15	9	[{"id_menu":6,"count":1}]	7108	delivery	5	14
18631	2019-12-15 11:40:03	2019-12-15	12	[{"id_menu":3,"count":1}]	7081	delivery	5	17
18632	2019-12-15 11:41:33	2019-12-15	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5691	delivery	5	22
18633	2019-12-15 11:48:13	2019-12-15	12	[{"id_menu":1,"count":1}]	1091	delivery	5	17
18634	2019-12-15 11:56:14	2019-12-15	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3082	pick-up	0	41
18635	2019-12-15 12:14:52	2019-12-15	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	918	pick-up	0	17
18636	2019-12-15 12:41:10	2019-12-15	17	[{"id_menu":4,"count":1}]	7057	pick-up	0	17
18637	2019-12-15 12:58:00	2019-12-15	14	[{"id_menu":2,"count":1}]	1687	delivery	5	19
18638	2019-12-15 13:04:01	2019-12-15	8	[{"id_menu":5,"count":1}]	114	delivery	5	13
18639	2019-12-15 13:10:30	2019-12-15	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1948	delivery	5	36
18640	2019-12-15 13:13:53	2019-12-15	17	[{"id_menu":4,"count":2}]	1545	pick-up	0	17
18641	2019-12-15 13:35:24	2019-12-15	9	[{"id_menu":6,"count":1}]	126	delivery	5	14
18642	2019-12-15 13:43:08	2019-12-15	17	[{"id_menu":4,"count":1}]	1754	pick-up	0	17
18643	2019-12-15 13:43:15	2019-12-15	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	7056	delivery	5	38
18644	2019-12-15 13:43:23	2019-12-15	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2945	delivery	5	40
18645	2019-12-15 13:52:34	2019-12-15	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	6485	delivery	5	37
18646	2019-12-15 13:52:36	2019-12-15	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	7090	delivery	5	23
18647	2019-12-15 14:08:30	2019-12-15	17	[{"id_menu":4,"count":1}]	4871	delivery	5	22
18648	2019-12-15 14:17:40	2019-12-15	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3777	delivery	5	26
18649	2019-12-15 14:21:32	2019-12-15	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2802	delivery	5	34
18650	2019-12-15 14:22:56	2019-12-15	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	3460	delivery	5	31
18651	2019-12-15 14:22:56	2019-12-15	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	408	delivery	5	44
18652	2019-12-15 14:23:36	2019-12-15	14	[{"id_menu":2,"count":1}]	848	delivery	5	19
18653	2019-12-15 14:24:47	2019-12-15	9	[{"id_menu":7,"count":1}]	1905	delivery	5	14
18654	2019-12-15 14:31:57	2019-12-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7111	delivery	5	28
18655	2019-12-15 14:33:09	2019-12-15	14	[{"id_menu":2,"count":1}]	7103	pick-up	0	14
18656	2019-12-15 14:35:19	2019-12-15	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	6064	delivery	5	26
18657	2019-12-15 14:38:27	2019-12-15	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3960	pick-up	0	40
18658	2019-12-15 15:07:07	2019-12-15	9	[{"id_menu":6,"count":1}]	678	pick-up	0	9
18659	2019-12-15 15:10:14	2019-12-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	356	pick-up	0	23
18660	2019-12-15 15:19:21	2019-12-15	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	399	delivery	5	26
18661	2019-12-15 15:24:44	2019-12-15	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	7046	pick-up	0	20
18662	2019-12-15 15:44:32	2019-12-15	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	3772	pick-up	0	24
18663	2019-12-15 15:50:16	2019-12-15	9	[{"id_menu":6,"count":1}]	6448	delivery	5	14
18664	2019-12-15 16:11:13	2019-12-15	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	4453	pick-up	0	26
18665	2019-12-15 16:15:08	2019-12-15	14	[{"id_menu":2,"count":2}]	4712	delivery	5	19
18666	2019-12-15 16:18:28	2019-12-15	12	[{"id_menu":1,"count":1}]	2476	pick-up	0	12
18667	2019-12-15 16:19:33	2019-12-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	6076	delivery	5	31
18668	2019-12-15 16:25:09	2019-12-15	9	[{"id_menu":6,"count":1}]	270	pick-up	0	9
18669	2019-12-15 16:56:01	2019-12-15	8	[{"id_menu":5,"count":1}]	259	delivery	5	13
18670	2019-12-15 16:57:30	2019-12-15	9	[{"id_menu":6,"count":1}]	7068	delivery	5	14
18671	2019-12-15 16:58:26	2019-12-15	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	1312	pick-up	0	21
18672	2019-12-15 17:09:36	2019-12-15	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1908	pick-up	0	24
18673	2019-12-15 17:16:41	2019-12-15	9	[{"id_menu":7,"count":1}]	6990	delivery	5	14
18674	2019-12-15 17:16:42	2019-12-15	12	[{"id_menu":3,"count":1}]	1161	delivery	5	17
18675	2019-12-15 17:21:02	2019-12-15	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7071	delivery	5	39
18676	2019-12-15 17:23:24	2019-12-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5031	delivery	5	23
18677	2019-12-15 17:23:46	2019-12-15	12	[{"id_menu":1,"count":1}]	6543	pick-up	0	12
18678	2019-12-15 17:29:03	2019-12-15	14	[{"id_menu":2,"count":1}]	2083	delivery	5	19
18679	2019-12-15 18:14:19	2019-12-15	9	[{"id_menu":6,"count":1}]	2885	delivery	5	14
18680	2019-12-15 18:19:07	2019-12-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7109	delivery	5	28
18681	2019-12-15 18:22:08	2019-12-15	9	[{"id_menu":7,"count":1}]	7061	pick-up	0	9
18682	2019-12-15 18:22:52	2019-12-15	17	[{"id_menu":4,"count":1}]	7080	pick-up	0	17
18683	2019-12-15 18:26:24	2019-12-15	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	669	pick-up	0	24
18684	2019-12-15 18:31:53	2019-12-15	17	[{"id_menu":4,"count":1}]	7060	delivery	5	22
18685	2019-12-15 18:44:52	2019-12-15	9	[{"id_menu":7,"count":2}]	6941	pick-up	0	9
18686	2019-12-15 18:50:37	2019-12-15	17	[{"id_menu":4,"count":1}]	7100	pick-up	0	17
18687	2019-12-15 18:51:22	2019-12-15	12	[{"id_menu":1,"count":1}]	3634	pick-up	0	12
18688	2019-12-15 18:56:24	2019-12-15	17	[{"id_menu":4,"count":1}]	7036	delivery	5	22
18689	2019-12-15 19:05:32	2019-12-15	17	[{"id_menu":4,"count":1}]	6602	delivery	5	22
18690	2019-12-15 19:12:51	2019-12-15	9	[{"id_menu":7,"count":1}]	3324	delivery	5	14
18691	2019-12-15 19:13:24	2019-12-15	9	[{"id_menu":7,"count":1}]	4042	pick-up	0	9
18692	2019-12-15 19:15:59	2019-12-15	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3065	pick-up	0	43
18693	2019-12-15 19:42:39	2019-12-15	14	[{"id_menu":2,"count":1}]	4353	pick-up	0	14
18694	2019-12-15 19:47:12	2019-12-15	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	7091	delivery	5	28
18695	2019-12-15 19:49:06	2019-12-15	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	6839	delivery	5	39
18696	2019-12-15 19:53:00	2019-12-15	12	[{"id_menu":1,"count":1}]	4297	delivery	5	17
18697	2019-12-15 19:55:59	2019-12-15	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	7089	delivery	5	30
18698	2019-12-15 19:57:32	2019-12-15	8	[{"id_menu":5,"count":1}]	292	delivery	5	13
18699	2019-12-15 19:59:54	2019-12-15	12	[{"id_menu":1,"count":1}]	6591	delivery	5	17
18700	2019-12-15 20:00:25	2019-12-15	12	[{"id_menu":1,"count":1}]	5767	delivery	5	17
18701	2019-12-15 20:32:25	2019-12-15	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	4001	delivery	5	31
18702	2019-12-15 20:38:23	2019-12-15	12	[{"id_menu":1,"count":1}]	7052	delivery	5	17
18703	2019-12-15 20:43:41	2019-12-15	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	7063	delivery	5	25
18704	2019-12-15 20:45:56	2019-12-15	12	[{"id_menu":1,"count":1}]	7066	delivery	5	17
18705	2019-12-15 20:50:56	2019-12-15	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	7099	delivery	5	29
18706	2019-12-15 20:56:16	2019-12-15	14	[{"id_menu":2,"count":1}]	5663	delivery	5	19
18707	2019-12-15 21:04:18	2019-12-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7084	delivery	5	28
18708	2019-12-15 21:18:55	2019-12-15	17	[{"id_menu":4,"count":1}]	7104	delivery	5	22
18709	2019-12-15 21:24:59	2019-12-15	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	7112	delivery	5	34
18710	2019-12-15 21:26:32	2019-12-15	9	[{"id_menu":7,"count":1}]	7053	pick-up	0	9
18711	2019-12-15 21:32:54	2019-12-15	9	[{"id_menu":7,"count":1}]	7076	delivery	5	14
18712	2019-12-15 21:37:44	2019-12-15	12	[{"id_menu":1,"count":1}]	7097	pick-up	0	12
18713	2019-12-15 22:03:14	2019-12-15	12	[{"id_menu":1,"count":1}]	2546	delivery	5	17
18714	2019-12-15 22:05:58	2019-12-15	14	[{"id_menu":2,"count":1}]	3880	delivery	5	19
18715	2019-12-15 22:24:04	2019-12-15	14	[{"id_menu":2,"count":1}]	2448	delivery	5	19
18716	2019-12-15 22:24:22	2019-12-15	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	729	pick-up	0	21
18717	2019-12-15 22:30:35	2019-12-15	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	2256	pick-up	0	24
18718	2019-12-15 22:40:13	2019-12-15	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	3962	delivery	5	22
18719	2019-12-15 22:46:37	2019-12-15	14	[{"id_menu":2,"count":1}]	5318	pick-up	0	14
18720	2019-12-15 22:48:45	2019-12-15	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	209	pick-up	0	20
18721	2019-12-15 23:04:02	2019-12-15	9	[{"id_menu":6,"count":1}]	7086	pick-up	0	9
18722	2019-12-15 23:13:43	2019-12-15	9	[{"id_menu":6,"count":1}]	2752	pick-up	0	9
18723	2019-12-15 23:26:05	2019-12-15	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7054	delivery	5	30
18724	2019-12-15 23:35:23	2019-12-15	12	[{"id_menu":1,"count":1}]	7110	delivery	5	17
18725	2019-12-15 23:42:51	2019-12-15	8	[{"id_menu":5,"count":2}]	3961	pick-up	0	8
18726	2019-12-15 23:47:35	2019-12-15	9	[{"id_menu":7,"count":1}]	4363	pick-up	0	9
18727	2019-12-15 23:53:24	2019-12-15	9	[{"id_menu":7,"count":1}]	5082	pick-up	0	9
18728	2019-12-16 00:06:07	2019-12-16	8	[{"id_menu":5,"count":1}]	7155	pick-up	0	8
18729	2019-12-16 00:51:08	2019-12-16	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6095	delivery	5	48
18730	2019-12-16 02:04:06	2019-12-16	9	[{"id_menu":7,"count":1}]	1486	pick-up	0	9
18731	2019-12-16 02:24:01	2019-12-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	3863	delivery	5	26
18732	2019-12-16 02:32:12	2019-12-16	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7157	delivery	5	40
18733	2019-12-16 02:37:10	2019-12-16	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	5730	delivery	5	29
18734	2019-12-16 02:46:07	2019-12-16	17	[{"id_menu":4,"count":2}]	1266	pick-up	0	17
18735	2019-12-16 03:01:39	2019-12-16	17	[{"id_menu":4,"count":1}]	4546	pick-up	0	17
18736	2019-12-16 03:08:43	2019-12-16	17	[{"id_menu":4,"count":1}]	1387	pick-up	0	17
18737	2019-12-16 03:13:31	2019-12-16	12	[{"id_menu":1,"count":1}]	3723	delivery	5	17
18738	2019-12-16 03:24:14	2019-12-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	260	pick-up	0	23
18739	2019-12-16 03:31:36	2019-12-16	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	6950	delivery	5	31
18740	2019-12-16 04:20:50	2019-12-16	9	[{"id_menu":6,"count":1}]	6794	delivery	5	14
18741	2019-12-16 04:43:18	2019-12-16	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	5094	delivery	5	26
18742	2019-12-16 04:57:00	2019-12-16	14	[{"id_menu":2,"count":2}]	1774	delivery	5	19
18743	2019-12-16 05:17:08	2019-12-16	12	[{"id_menu":1,"count":1}]	3332	pick-up	0	12
18744	2019-12-16 05:32:43	2019-12-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3633	delivery	5	23
18745	2019-12-16 06:02:25	2019-12-16	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	7123	delivery	5	34
18746	2019-12-16 06:02:39	2019-12-16	17	[{"id_menu":4,"count":1}]	4335	pick-up	0	17
18747	2019-12-16 06:05:17	2019-12-16	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	7131	delivery	5	26
18748	2019-12-16 06:18:51	2019-12-16	9	[{"id_menu":7,"count":1}]	4874	pick-up	0	9
18749	2019-12-16 06:25:07	2019-12-16	9	[{"id_menu":7,"count":1}]	4485	delivery	5	14
18750	2019-12-16 06:32:51	2019-12-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	7133	delivery	5	28
18751	2019-12-16 06:41:28	2019-12-16	9	[{"id_menu":6,"count":1}]	7161	delivery	5	14
18752	2019-12-16 06:46:49	2019-12-16	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7162	delivery	5	34
18753	2019-12-16 06:50:36	2019-12-16	17	[{"id_menu":4,"count":1}]	1312	delivery	5	22
18754	2019-12-16 06:53:00	2019-12-16	12	[{"id_menu":3,"count":1}]	2083	pick-up	0	12
18755	2019-12-16 07:57:12	2019-12-16	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7122	delivery	5	40
18756	2019-12-16 08:00:51	2019-12-16	12	[{"id_menu":1,"count":1}]	1979	delivery	5	17
18757	2019-12-16 08:04:08	2019-12-16	8	[{"id_menu":5,"count":1}]	7166	delivery	5	13
18758	2019-12-16 08:15:39	2019-12-16	17	[{"id_menu":4,"count":1}]	7150	pick-up	0	17
18759	2019-12-16 08:35:39	2019-12-16	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2692	delivery	5	27
18760	2019-12-16 08:57:30	2019-12-16	12	[{"id_menu":3,"count":2}]	5758	pick-up	0	12
18761	2019-12-16 09:00:09	2019-12-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1208	pick-up	0	21
18762	2019-12-16 09:02:00	2019-12-16	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	2823	delivery	5	34
18763	2019-12-16 09:05:43	2019-12-16	14	[{"id_menu":2,"count":1}]	2087	delivery	5	19
18764	2019-12-16 09:10:06	2019-12-16	17	[{"id_menu":4,"count":1}]	5526	pick-up	0	17
18765	2019-12-16 09:17:25	2019-12-16	9	[{"id_menu":6,"count":1}]	2396	pick-up	0	9
18766	2019-12-16 09:25:36	2019-12-16	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	7081	pick-up	0	26
18767	2019-12-16 09:38:25	2019-12-16	12	[{"id_menu":3,"count":1}]	5965	pick-up	0	12
18768	2019-12-16 09:44:13	2019-12-16	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4131	delivery	5	30
18769	2019-12-16 09:45:38	2019-12-16	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4029	delivery	5	39
18770	2019-12-16 09:49:23	2019-12-16	9	[{"id_menu":6,"count":1}]	3002	pick-up	0	9
18771	2019-12-16 09:52:14	2019-12-16	12	[{"id_menu":1,"count":1}]	4735	pick-up	0	12
18772	2019-12-16 10:05:10	2019-12-16	14	[{"id_menu":2,"count":1}]	7159	pick-up	0	14
18773	2019-12-16 10:19:34	2019-12-16	12	[{"id_menu":3,"count":1}]	6660	delivery	5	17
18774	2019-12-16 10:25:06	2019-12-16	8	[{"id_menu":5,"count":1}]	5303	pick-up	0	8
18775	2019-12-16 10:30:04	2019-12-16	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1295	pick-up	0	17
18776	2019-12-16 10:33:40	2019-12-16	17	[{"id_menu":4,"count":1}]	7035	delivery	5	22
18777	2019-12-16 11:17:30	2019-12-16	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	7153	delivery	5	34
18778	2019-12-16 11:17:56	2019-12-16	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6235	delivery	5	31
18779	2019-12-16 12:08:02	2019-12-16	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7163	delivery	5	30
18780	2019-12-16 12:17:17	2019-12-16	9	[{"id_menu":7,"count":2}]	2762	pick-up	0	9
18781	2019-12-16 12:27:53	2019-12-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1321	pick-up	0	21
18782	2019-12-16 12:32:17	2019-12-16	17	[{"id_menu":4,"count":1}]	7114	delivery	5	22
18783	2019-12-16 12:35:08	2019-12-16	9	[{"id_menu":7,"count":1}]	1970	delivery	5	14
18784	2019-12-16 13:07:24	2019-12-16	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7152	delivery	5	22
18785	2019-12-16 13:08:08	2019-12-16	14	[{"id_menu":2,"count":1}]	7113	delivery	5	19
18786	2019-12-16 13:20:21	2019-12-16	12	[{"id_menu":3,"count":1}]	5349	delivery	5	17
18787	2019-12-16 13:26:55	2019-12-16	12	[{"id_menu":3,"count":1}]	5272	delivery	5	17
18788	2019-12-16 13:31:29	2019-12-16	12	[{"id_menu":1,"count":1}]	7121	delivery	5	17
18789	2019-12-16 13:34:41	2019-12-16	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	883	pick-up	0	26
18790	2019-12-16 13:37:32	2019-12-16	17	[{"id_menu":4,"count":1}]	1370	pick-up	0	17
18791	2019-12-16 13:56:13	2019-12-16	12	[{"id_menu":1,"count":1}]	882	pick-up	0	12
18792	2019-12-16 14:07:17	2019-12-16	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	638	pick-up	0	21
18793	2019-12-16 14:24:14	2019-12-16	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	873	delivery	5	36
18794	2019-12-16 14:46:24	2019-12-16	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7148	pick-up	0	35
18795	2019-12-16 14:50:17	2019-12-16	17	[{"id_menu":4,"count":1}]	2561	pick-up	0	17
18796	2019-12-16 15:04:44	2019-12-16	9	[{"id_menu":7,"count":1}]	149	pick-up	0	9
18797	2019-12-16 15:10:10	2019-12-16	14	[{"id_menu":2,"count":1}]	3135	pick-up	0	14
18798	2019-12-16 15:36:05	2019-12-16	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	5236	delivery	5	39
18799	2019-12-16 15:36:49	2019-12-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	2081	delivery	5	31
18800	2019-12-16 16:03:02	2019-12-16	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1233	pick-up	0	35
18801	2019-12-16 16:10:01	2019-12-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7142	delivery	5	28
18802	2019-12-16 16:10:29	2019-12-16	14	[{"id_menu":2,"count":2}]	5322	delivery	5	19
18803	2019-12-16 16:11:02	2019-12-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6215	delivery	5	31
18804	2019-12-16 16:22:33	2019-12-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4356	pick-up	0	23
18805	2019-12-16 16:36:56	2019-12-16	9	[{"id_menu":7,"count":1}]	2870	pick-up	0	9
18806	2019-12-16 16:51:20	2019-12-16	14	[{"id_menu":2,"count":1}]	5064	pick-up	0	14
18807	2019-12-16 17:25:05	2019-12-16	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	5180	pick-up	0	21
18808	2019-12-16 17:29:42	2019-12-16	9	[{"id_menu":7,"count":1}]	1075	pick-up	0	9
18809	2019-12-16 18:00:17	2019-12-16	17	[{"id_menu":4,"count":1}]	1928	pick-up	0	17
18810	2019-12-16 18:04:07	2019-12-16	8	[{"id_menu":5,"count":1}]	6907	delivery	5	13
18811	2019-12-16 18:14:46	2019-12-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	7160	delivery	5	26
18812	2019-12-16 18:24:38	2019-12-16	17	[{"id_menu":4,"count":1}]	7124	delivery	5	22
18813	2019-12-16 18:29:36	2019-12-16	9	[{"id_menu":7,"count":1}]	7128	delivery	5	14
18814	2019-12-16 18:32:06	2019-12-16	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	7158	delivery	5	34
18815	2019-12-16 18:35:19	2019-12-16	9	[{"id_menu":6,"count":1}]	2107	delivery	5	14
18816	2019-12-16 18:51:35	2019-12-16	8	[{"id_menu":5,"count":1}]	7129	delivery	5	13
18817	2019-12-16 18:54:10	2019-12-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2605	delivery	5	31
18818	2019-12-16 18:56:40	2019-12-16	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3868	delivery	5	34
18819	2019-12-16 19:08:17	2019-12-16	8	[{"id_menu":5,"count":2}]	7156	pick-up	0	8
18820	2019-12-16 19:14:07	2019-12-16	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6664	delivery	5	36
18821	2019-12-16 19:53:30	2019-12-16	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	506	pick-up	0	24
18822	2019-12-16 19:59:05	2019-12-16	12	[{"id_menu":3,"count":1}]	6608	pick-up	0	12
18823	2019-12-16 20:04:08	2019-12-16	12	[{"id_menu":1,"count":1}]	473	pick-up	0	12
18824	2019-12-16 20:09:56	2019-12-16	12	[{"id_menu":3,"count":1}]	2060	delivery	5	17
18825	2019-12-16 20:19:04	2019-12-16	12	[{"id_menu":3,"count":1}]	554	delivery	5	17
18826	2019-12-16 20:21:20	2019-12-16	9	[{"id_menu":6,"count":1}]	2378	pick-up	0	9
18827	2019-12-16 20:25:25	2019-12-16	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	7118	delivery	5	25
18828	2019-12-16 20:26:24	2019-12-16	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	7165	delivery	5	38
18829	2019-12-16 21:14:07	2019-12-16	17	[{"id_menu":4,"count":1}]	2034	pick-up	0	17
18830	2019-12-16 21:22:50	2019-12-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	748	delivery	5	31
18831	2019-12-16 21:29:23	2019-12-16	12	[{"id_menu":1,"count":1}]	7151	pick-up	0	12
18832	2019-12-16 21:33:53	2019-12-16	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	6139	delivery	5	26
18833	2019-12-16 21:38:59	2019-12-16	8	[{"id_menu":5,"count":2}]	4968	delivery	5	13
18834	2019-12-16 21:46:06	2019-12-16	8	[{"id_menu":5,"count":1}]	1727	delivery	5	13
18835	2019-12-16 22:01:48	2019-12-16	8	[{"id_menu":5,"count":1}]	7144	delivery	5	13
18836	2019-12-16 22:42:47	2019-12-16	9	[{"id_menu":7,"count":1}]	7119	pick-up	0	9
18837	2019-12-16 22:52:42	2019-12-16	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	7146	delivery	5	25
18838	2019-12-16 22:59:22	2019-12-16	9	[{"id_menu":6,"count":1}]	1875	delivery	5	14
18839	2019-12-16 23:09:40	2019-12-16	14	[{"id_menu":2,"count":1}]	3614	pick-up	0	14
18840	2019-12-16 23:11:38	2019-12-16	8	[{"id_menu":5,"count":1}]	1742	pick-up	0	8
18841	2019-12-16 23:26:28	2019-12-16	17	[{"id_menu":4,"count":1}]	4824	delivery	5	22
18842	2019-12-16 23:26:51	2019-12-16	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7138	delivery	5	43
18843	2019-12-16 23:39:31	2019-12-16	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1660	pick-up	0	29
18844	2019-12-16 23:43:05	2019-12-16	17	[{"id_menu":4,"count":1}]	5996	delivery	5	22
18845	2019-12-16 23:50:20	2019-12-16	8	[{"id_menu":5,"count":1}]	5687	delivery	5	13
18846	2019-12-17 00:09:00	2019-12-17	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1536	delivery	5	26
18847	2019-12-17 00:14:26	2019-12-17	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7241	delivery	5	39
18848	2019-12-17 00:17:09	2019-12-17	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	4168	delivery	5	25
18849	2019-12-17 00:29:03	2019-12-17	14	[{"id_menu":2,"count":1}]	2107	pick-up	0	14
18850	2019-12-17 00:30:40	2019-12-17	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	7192	delivery	5	25
18851	2019-12-17 00:34:15	2019-12-17	12	[{"id_menu":1,"count":1}]	7179	pick-up	0	12
18852	2019-12-17 00:39:47	2019-12-17	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	209	delivery	5	44
18853	2019-12-17 00:53:12	2019-12-17	14	[{"id_menu":2,"count":1}]	7200	delivery	5	19
18854	2019-12-17 01:38:11	2019-12-17	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2422	delivery	5	40
18855	2019-12-17 01:45:37	2019-12-17	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7188	delivery	5	49
18856	2019-12-17 01:48:59	2019-12-17	9	[{"id_menu":7,"count":1}]	2933	pick-up	0	9
18857	2019-12-17 02:49:30	2019-12-17	17	[{"id_menu":4,"count":1}]	7193	delivery	5	22
18858	2019-12-17 02:55:16	2019-12-17	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	2030	delivery	5	31
18859	2019-12-17 02:56:27	2019-12-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":3}]	3937	pick-up	0	23
18860	2019-12-17 03:00:05	2019-12-17	9	[{"id_menu":7,"count":1}]	3403	delivery	5	14
18861	2019-12-17 03:02:22	2019-12-17	14	[{"id_menu":2,"count":1}]	3909	pick-up	0	14
18862	2019-12-17 03:32:49	2019-12-17	14	[{"id_menu":2,"count":1}]	113	delivery	5	19
18863	2019-12-17 03:50:01	2019-12-17	14	[{"id_menu":2,"count":1}]	1148	pick-up	0	14
18864	2019-12-17 03:59:22	2019-12-17	9	[{"id_menu":7,"count":1}]	7206	pick-up	0	9
18865	2019-12-17 04:01:05	2019-12-17	17	[{"id_menu":4,"count":1}]	7221	delivery	5	22
18866	2019-12-17 04:16:41	2019-12-17	12	[{"id_menu":3,"count":2}]	7204	delivery	5	17
18867	2019-12-17 04:18:33	2019-12-17	12	[{"id_menu":1,"count":1}]	2354	pick-up	0	12
18868	2019-12-17 04:35:11	2019-12-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6761	delivery	5	28
18869	2019-12-17 04:36:51	2019-12-17	17	[{"id_menu":4,"count":1}]	6998	delivery	5	22
18870	2019-12-17 04:56:52	2019-12-17	8	[{"id_menu":5,"count":1}]	6976	delivery	5	13
18871	2019-12-17 04:59:57	2019-12-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7189	pick-up	0	23
18872	2019-12-17 05:10:18	2019-12-17	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5151	delivery	5	40
18873	2019-12-17 05:27:51	2019-12-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3327	pick-up	0	23
18874	2019-12-17 05:34:02	2019-12-17	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	4947	delivery	5	26
18875	2019-12-17 05:34:52	2019-12-17	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7212	delivery	5	31
18876	2019-12-17 05:40:25	2019-12-17	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	5961	pick-up	0	34
18877	2019-12-17 05:44:38	2019-12-17	8	[{"id_menu":5,"count":1}]	7184	delivery	5	13
18878	2019-12-17 05:48:48	2019-12-17	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	6478	pick-up	0	26
18879	2019-12-17 05:58:32	2019-12-17	9	[{"id_menu":6,"count":1}]	7217	delivery	5	14
18880	2019-12-17 06:15:44	2019-12-17	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	6410	pick-up	0	20
18881	2019-12-17 06:18:19	2019-12-17	17	[{"id_menu":4,"count":2}]	7219	pick-up	0	17
18882	2019-12-17 06:35:12	2019-12-17	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	632	pick-up	0	35
18883	2019-12-17 06:44:01	2019-12-17	12	[{"id_menu":3,"count":1}]	7236	delivery	5	17
18884	2019-12-17 06:52:08	2019-12-17	9	[{"id_menu":6,"count":1}]	6538	delivery	5	14
18885	2019-12-17 06:57:47	2019-12-17	14	[{"id_menu":2,"count":1}]	6725	pick-up	0	14
18886	2019-12-17 07:06:41	2019-12-17	12	[{"id_menu":1,"count":1}]	1460	pick-up	0	12
18887	2019-12-17 07:06:56	2019-12-17	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	7177	delivery	5	40
18888	2019-12-17 07:07:07	2019-12-17	17	[{"id_menu":4,"count":1}]	1659	pick-up	0	17
18889	2019-12-17 07:07:39	2019-12-17	12	[{"id_menu":1,"count":1}]	4425	delivery	5	17
18890	2019-12-17 07:27:56	2019-12-17	8	[{"id_menu":5,"count":1}]	7225	delivery	5	13
18891	2019-12-17 07:27:56	2019-12-17	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7180	delivery	5	39
18892	2019-12-17 07:44:06	2019-12-17	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7226	delivery	5	43
18893	2019-12-17 07:55:10	2019-12-17	12	[{"id_menu":1,"count":1}]	563	pick-up	0	12
18894	2019-12-17 07:56:47	2019-12-17	14	[{"id_menu":2,"count":1}]	6798	delivery	5	19
18895	2019-12-17 08:03:53	2019-12-17	9	[{"id_menu":6,"count":1}]	3124	delivery	5	14
18896	2019-12-17 08:08:59	2019-12-17	17	[{"id_menu":4,"count":1}]	238	pick-up	0	17
18897	2019-12-17 08:09:01	2019-12-17	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7232	delivery	5	36
18898	2019-12-17 08:16:54	2019-12-17	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	7195	delivery	5	26
18899	2019-12-17 08:33:54	2019-12-17	17	[{"id_menu":4,"count":1}]	7234	delivery	5	22
18900	2019-12-17 08:42:25	2019-12-17	9	[{"id_menu":7,"count":1}]	6464	delivery	5	14
18901	2019-12-17 08:56:27	2019-12-17	17	[{"id_menu":4,"count":1}]	7172	delivery	5	22
18902	2019-12-17 09:04:58	2019-12-17	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	4577	delivery	5	26
18903	2019-12-17 09:05:08	2019-12-17	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	4479	delivery	5	34
18904	2019-12-17 09:09:10	2019-12-17	9	[{"id_menu":6,"count":1}]	2902	pick-up	0	9
18905	2019-12-17 09:23:28	2019-12-17	14	[{"id_menu":2,"count":1}]	557	pick-up	0	14
18906	2019-12-17 09:48:09	2019-12-17	9	[{"id_menu":7,"count":1}]	2060	delivery	5	14
18907	2019-12-17 09:52:23	2019-12-17	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	7238	delivery	5	40
18908	2019-12-17 10:27:42	2019-12-17	12	[{"id_menu":1,"count":1}]	5038	pick-up	0	12
18909	2019-12-17 10:29:31	2019-12-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7181	delivery	5	31
18910	2019-12-17 10:31:02	2019-12-17	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	1800	delivery	5	26
18911	2019-12-17 10:32:11	2019-12-17	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7240	delivery	5	22
18912	2019-12-17 10:34:50	2019-12-17	14	[{"id_menu":2,"count":1}]	7197	delivery	5	19
18913	2019-12-17 10:55:22	2019-12-17	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3108	delivery	5	39
18914	2019-12-17 11:08:53	2019-12-17	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	7235	delivery	5	36
18915	2019-12-17 11:16:05	2019-12-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3755	delivery	5	31
18916	2019-12-17 11:16:08	2019-12-17	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	3280	delivery	5	37
18917	2019-12-17 11:17:38	2019-12-17	9	[{"id_menu":7,"count":1}]	5100	pick-up	0	9
18918	2019-12-17 11:19:38	2019-12-17	8	[{"id_menu":5,"count":1}]	7173	pick-up	0	8
18919	2019-12-17 11:33:49	2019-12-17	14	[{"id_menu":2,"count":1}]	4869	pick-up	0	14
18920	2019-12-17 11:47:37	2019-12-17	14	[{"id_menu":2,"count":1}]	7175	delivery	5	19
18921	2019-12-17 11:55:24	2019-12-17	12	[{"id_menu":1,"count":1}]	7190	pick-up	0	12
18922	2019-12-17 11:55:52	2019-12-17	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	7138	delivery	5	27
18923	2019-12-17 12:02:13	2019-12-17	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2819	delivery	5	39
18924	2019-12-17 12:03:15	2019-12-17	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	7210	delivery	5	28
18925	2019-12-17 12:20:42	2019-12-17	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4146	pick-up	0	25
18926	2019-12-17 12:33:15	2019-12-17	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2868	delivery	5	43
18927	2019-12-17 12:34:36	2019-12-17	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	6164	delivery	5	31
18928	2019-12-17 12:53:27	2019-12-17	17	[{"id_menu":4,"count":1}]	7201	pick-up	0	17
18929	2019-12-17 13:27:14	2019-12-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5180	pick-up	0	23
18930	2019-12-17 13:39:12	2019-12-17	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	4728	delivery	5	38
18931	2019-12-17 13:42:55	2019-12-17	9	[{"id_menu":6,"count":1}]	3579	delivery	5	14
18932	2019-12-17 14:12:16	2019-12-17	14	[{"id_menu":2,"count":1}]	4853	delivery	5	19
18933	2019-12-17 14:13:30	2019-12-17	14	[{"id_menu":2,"count":1}]	6	pick-up	0	14
18934	2019-12-17 14:18:56	2019-12-17	9	[{"id_menu":6,"count":1}]	6941	pick-up	0	9
18935	2019-12-17 14:26:39	2019-12-17	12	[{"id_menu":3,"count":2}]	356	delivery	5	17
18936	2019-12-17 14:41:14	2019-12-17	8	[{"id_menu":5,"count":1}]	72	delivery	5	13
18937	2019-12-17 14:54:09	2019-12-17	8	[{"id_menu":5,"count":1}]	7182	delivery	5	13
18938	2019-12-17 14:58:06	2019-12-17	9	[{"id_menu":6,"count":1}]	3237	delivery	5	14
18939	2019-12-17 15:21:50	2019-12-17	8	[{"id_menu":5,"count":1}]	4054	pick-up	0	8
18940	2019-12-17 15:36:26	2019-12-17	12	[{"id_menu":3,"count":1}]	3372	pick-up	0	12
18941	2019-12-17 15:42:12	2019-12-17	12	[{"id_menu":1,"count":2}]	5682	delivery	5	17
18942	2019-12-17 15:53:04	2019-12-17	9	[{"id_menu":6,"count":2}]	2401	pick-up	0	9
18943	2019-12-17 16:18:27	2019-12-17	9	[{"id_menu":6,"count":1}]	7239	delivery	5	14
18944	2019-12-17 16:32:23	2019-12-17	9	[{"id_menu":6,"count":1}]	5041	pick-up	0	9
18945	2019-12-17 17:13:07	2019-12-17	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1766	delivery	5	34
18946	2019-12-17 17:21:33	2019-12-17	9	[{"id_menu":7,"count":1}]	7185	delivery	5	14
18947	2019-12-17 17:27:50	2019-12-17	8	[{"id_menu":5,"count":1}]	7215	delivery	5	13
18948	2019-12-17 17:37:43	2019-12-17	9	[{"id_menu":6,"count":1}]	3645	delivery	5	14
18949	2019-12-17 17:37:51	2019-12-17	12	[{"id_menu":1,"count":1}]	7237	delivery	5	17
18950	2019-12-17 17:48:08	2019-12-17	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2068	delivery	5	36
18951	2019-12-17 17:52:49	2019-12-17	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	527	pick-up	0	29
18952	2019-12-17 17:56:48	2019-12-17	8	[{"id_menu":5,"count":1}]	4395	pick-up	0	8
18953	2019-12-17 18:01:54	2019-12-17	12	[{"id_menu":3,"count":1}]	1513	delivery	5	17
18954	2019-12-17 18:04:56	2019-12-17	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	7222	delivery	5	31
18955	2019-12-17 18:12:23	2019-12-17	14	[{"id_menu":2,"count":1}]	310	pick-up	0	14
18956	2019-12-17 18:28:10	2019-12-17	17	[{"id_menu":4,"count":1}]	993	delivery	5	22
18957	2019-12-17 18:39:06	2019-12-17	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":2}]	6884	delivery	5	22
18958	2019-12-17 18:49:12	2019-12-17	34	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	7224	delivery	5	39
18959	2019-12-17 19:13:25	2019-12-17	9	[{"id_menu":7,"count":1}]	7207	delivery	5	14
18960	2019-12-17 19:13:43	2019-12-17	12	[{"id_menu":3,"count":1}]	1700	pick-up	0	12
18961	2019-12-17 19:17:14	2019-12-17	14	[{"id_menu":2,"count":1}]	369	pick-up	0	14
18962	2019-12-17 19:23:10	2019-12-17	9	[{"id_menu":7,"count":1}]	6518	delivery	5	14
18963	2019-12-17 19:36:48	2019-12-17	9	[{"id_menu":6,"count":1}]	596	pick-up	0	9
18964	2019-12-17 19:42:18	2019-12-17	17	[{"id_menu":4,"count":1}]	2040	pick-up	0	17
18965	2019-12-17 19:59:09	2019-12-17	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	5306	pick-up	0	26
18966	2019-12-17 20:10:24	2019-12-17	9	[{"id_menu":7,"count":1}]	3148	pick-up	0	9
18967	2019-12-17 20:14:30	2019-12-17	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7227	delivery	5	34
18968	2019-12-17 20:15:23	2019-12-17	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7231	delivery	5	31
18969	2019-12-17 20:17:49	2019-12-17	9	[{"id_menu":7,"count":1}]	6212	delivery	5	14
18970	2019-12-17 20:18:42	2019-12-17	9	[{"id_menu":7,"count":1}]	6894	delivery	5	14
18971	2019-12-17 20:28:18	2019-12-17	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3040	delivery	5	30
18972	2019-12-17 20:41:02	2019-12-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5520	pick-up	0	23
18973	2019-12-17 20:53:11	2019-12-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2804	delivery	5	31
18974	2019-12-17 21:13:45	2019-12-17	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	1018	delivery	5	27
18975	2019-12-17 21:32:27	2019-12-17	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	5817	delivery	5	27
18976	2019-12-17 21:38:15	2019-12-17	9	[{"id_menu":7,"count":1}]	3505	delivery	5	14
18977	2019-12-17 21:47:54	2019-12-17	12	[{"id_menu":3,"count":1}]	1181	pick-up	0	12
18978	2019-12-17 21:54:31	2019-12-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2123	pick-up	0	23
18979	2019-12-17 22:10:28	2019-12-17	12	[{"id_menu":1,"count":1}]	7174	delivery	5	17
18980	2019-12-17 22:49:45	2019-12-17	12	[{"id_menu":1,"count":1}]	7194	pick-up	0	12
18981	2019-12-17 22:49:49	2019-12-17	8	[{"id_menu":5,"count":1}]	7183	delivery	5	13
18982	2019-12-17 23:00:13	2019-12-17	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	5215	delivery	5	29
18983	2019-12-17 23:06:07	2019-12-17	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	7019	pick-up	0	21
18984	2019-12-17 23:12:45	2019-12-17	12	[{"id_menu":3,"count":2}]	7209	delivery	5	17
18985	2019-12-17 23:18:29	2019-12-17	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	5170	delivery	5	36
18986	2019-12-17 23:36:46	2019-12-17	17	[{"id_menu":4,"count":1}]	7186	pick-up	0	17
18987	2019-12-17 23:47:02	2019-12-17	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	7220	delivery	5	26
18988	2019-12-17 23:56:17	2019-12-17	14	[{"id_menu":2,"count":2}]	47	delivery	5	19
18989	2019-12-18 00:00:40	2019-12-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	7279	delivery	5	23
18990	2019-12-18 00:26:05	2019-12-18	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	292	delivery	5	45
18991	2019-12-18 00:31:14	2019-12-18	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	3000	delivery	5	26
18992	2019-12-18 00:42:05	2019-12-18	12	[{"id_menu":3,"count":1}]	3363	delivery	5	17
18993	2019-12-18 00:53:51	2019-12-18	17	[{"id_menu":4,"count":1}]	4342	delivery	5	22
18994	2019-12-18 00:57:47	2019-12-18	12	[{"id_menu":3,"count":1}]	2210	delivery	5	17
18995	2019-12-18 01:00:40	2019-12-18	17	[{"id_menu":4,"count":1}]	7301	delivery	5	22
18996	2019-12-18 01:18:01	2019-12-18	9	[{"id_menu":6,"count":2}]	7258	delivery	5	14
18997	2019-12-18 01:21:56	2019-12-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7011	delivery	5	22
18998	2019-12-18 01:26:51	2019-12-18	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7280	delivery	5	43
18999	2019-12-18 01:34:23	2019-12-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2780	delivery	5	28
19000	2019-12-18 01:34:51	2019-12-18	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7291	delivery	5	42
19001	2019-12-18 01:42:22	2019-12-18	17	[{"id_menu":4,"count":1}]	790	delivery	5	22
19002	2019-12-18 01:58:25	2019-12-18	9	[{"id_menu":7,"count":1}]	7296	delivery	5	14
19003	2019-12-18 02:14:33	2019-12-18	9	[{"id_menu":7,"count":1}]	5567	delivery	5	14
19004	2019-12-18 02:47:22	2019-12-18	12	[{"id_menu":3,"count":1}]	566	pick-up	0	12
19005	2019-12-18 02:50:23	2019-12-18	14	[{"id_menu":2,"count":1}]	401	pick-up	0	14
19006	2019-12-18 02:54:29	2019-12-18	12	[{"id_menu":1,"count":1}]	7307	delivery	5	17
19007	2019-12-18 02:55:38	2019-12-18	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6747	delivery	5	57
19008	2019-12-18 03:01:09	2019-12-18	9	[{"id_menu":6,"count":1}]	1076	pick-up	0	9
19009	2019-12-18 03:11:35	2019-12-18	9	[{"id_menu":6,"count":1}]	7309	delivery	5	14
19010	2019-12-18 03:12:55	2019-12-18	8	[{"id_menu":5,"count":1}]	4592	delivery	5	13
19011	2019-12-18 03:15:10	2019-12-18	17	[{"id_menu":4,"count":1}]	7266	delivery	5	22
19012	2019-12-18 03:21:32	2019-12-18	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7259	delivery	5	34
19013	2019-12-18 03:29:01	2019-12-18	12	[{"id_menu":3,"count":1}]	4477	pick-up	0	12
19014	2019-12-18 03:34:45	2019-12-18	8	[{"id_menu":5,"count":1}]	7286	delivery	5	13
19015	2019-12-18 03:40:47	2019-12-18	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7292	delivery	5	35
19016	2019-12-18 03:41:12	2019-12-18	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7265	delivery	5	43
19017	2019-12-18 03:48:16	2019-12-18	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1340	delivery	5	34
19018	2019-12-18 03:48:30	2019-12-18	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	5745	pick-up	0	29
19019	2019-12-18 03:56:34	2019-12-18	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	2432	pick-up	0	43
19020	2019-12-18 04:02:30	2019-12-18	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6949	delivery	5	57
19021	2019-12-18 04:15:53	2019-12-18	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	7254	delivery	5	26
19022	2019-12-18 04:21:35	2019-12-18	17	[{"id_menu":4,"count":1}]	7244	delivery	5	22
19023	2019-12-18 04:25:41	2019-12-18	8	[{"id_menu":5,"count":1}]	1934	pick-up	0	8
19024	2019-12-18 04:31:02	2019-12-18	9	[{"id_menu":7,"count":1}]	7263	delivery	5	14
19025	2019-12-18 04:36:16	2019-12-18	8	[{"id_menu":5,"count":1}]	3091	delivery	5	13
19026	2019-12-18 04:37:30	2019-12-18	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	207	delivery	5	36
19027	2019-12-18 04:50:11	2019-12-18	9	[{"id_menu":7,"count":1}]	7264	delivery	5	14
19028	2019-12-18 05:07:10	2019-12-18	12	[{"id_menu":1,"count":1}]	1524	pick-up	0	12
19029	2019-12-18 05:10:51	2019-12-18	17	[{"id_menu":4,"count":1}]	2652	pick-up	0	17
19030	2019-12-18 05:31:25	2019-12-18	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	673	pick-up	0	35
19031	2019-12-18 05:33:22	2019-12-18	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7294	delivery	5	22
19032	2019-12-18 06:00:20	2019-12-18	12	[{"id_menu":3,"count":2}]	7247	pick-up	0	12
19033	2019-12-18 06:04:23	2019-12-18	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4665	delivery	5	31
19034	2019-12-18 06:11:28	2019-12-18	14	[{"id_menu":2,"count":1}]	4195	pick-up	0	14
19035	2019-12-18 06:28:19	2019-12-18	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7305	delivery	5	22
19036	2019-12-18 06:38:20	2019-12-18	12	[{"id_menu":1,"count":1}]	7255	pick-up	0	12
19037	2019-12-18 06:46:30	2019-12-18	17	[{"id_menu":4,"count":1}]	7260	delivery	5	22
19038	2019-12-18 06:54:26	2019-12-18	9	[{"id_menu":6,"count":1}]	7283	delivery	5	14
19039	2019-12-18 07:15:20	2019-12-18	14	[{"id_menu":2,"count":1}]	5091	delivery	5	19
19040	2019-12-18 07:18:26	2019-12-18	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	6798	pick-up	0	21
19041	2019-12-18 07:21:51	2019-12-18	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	3787	delivery	5	30
19042	2019-12-18 07:23:58	2019-12-18	14	[{"id_menu":2,"count":1}]	3187	delivery	5	19
19043	2019-12-18 07:32:29	2019-12-18	8	[{"id_menu":5,"count":1}]	7251	delivery	5	13
19044	2019-12-18 07:50:22	2019-12-18	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	7245	delivery	5	46
19045	2019-12-18 08:07:05	2019-12-18	17	[{"id_menu":4,"count":1}]	4929	delivery	5	22
19046	2019-12-18 08:16:34	2019-12-18	14	[{"id_menu":2,"count":1}]	4552	pick-up	0	14
19047	2019-12-18 08:23:57	2019-12-18	9	[{"id_menu":6,"count":1}]	7308	delivery	5	14
19048	2019-12-18 08:55:20	2019-12-18	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	3492	delivery	5	31
19049	2019-12-18 09:21:29	2019-12-18	12	[{"id_menu":3,"count":1}]	2558	pick-up	0	12
19050	2019-12-18 10:13:06	2019-12-18	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4022	delivery	5	37
19051	2019-12-18 10:19:27	2019-12-18	17	[{"id_menu":4,"count":1}]	865	pick-up	0	17
19052	2019-12-18 10:31:45	2019-12-18	9	[{"id_menu":7,"count":1}]	2022	delivery	5	14
19053	2019-12-18 10:37:17	2019-12-18	17	[{"id_menu":4,"count":1}]	1729	pick-up	0	17
19054	2019-12-18 10:53:05	2019-12-18	9	[{"id_menu":6,"count":1}]	7276	delivery	5	14
19055	2019-12-18 11:16:06	2019-12-18	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7267	delivery	5	45
19056	2019-12-18 11:19:33	2019-12-18	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	5506	delivery	5	25
19057	2019-12-18 11:21:05	2019-12-18	8	[{"id_menu":5,"count":1}]	5629	delivery	5	13
19058	2019-12-18 12:08:02	2019-12-18	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1581	pick-up	0	21
19059	2019-12-18 12:09:00	2019-12-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6499	delivery	5	23
19060	2019-12-18 12:21:41	2019-12-18	8	[{"id_menu":5,"count":1}]	6916	pick-up	0	8
19061	2019-12-18 12:26:58	2019-12-18	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	2982	delivery	5	34
19062	2019-12-18 12:37:48	2019-12-18	9	[{"id_menu":6,"count":1}]	5218	delivery	5	14
19063	2019-12-18 12:42:38	2019-12-18	14	[{"id_menu":2,"count":1}]	6107	delivery	5	19
19064	2019-12-18 12:44:08	2019-12-18	17	[{"id_menu":4,"count":1}]	506	pick-up	0	17
19065	2019-12-18 12:49:41	2019-12-18	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3040	delivery	5	56
19066	2019-12-18 13:00:16	2019-12-18	9	[{"id_menu":6,"count":1}]	7297	pick-up	0	9
19067	2019-12-18 13:14:10	2019-12-18	9	[{"id_menu":7,"count":2}]	7242	delivery	5	14
19068	2019-12-18 13:41:04	2019-12-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3887	delivery	5	28
19069	2019-12-18 13:42:32	2019-12-18	12	[{"id_menu":1,"count":1}]	4793	pick-up	0	12
19070	2019-12-18 13:45:08	2019-12-18	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	3204	delivery	5	25
19071	2019-12-18 13:53:40	2019-12-18	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	7304	pick-up	0	20
19072	2019-12-18 14:05:39	2019-12-18	12	[{"id_menu":1,"count":1}]	7268	delivery	5	17
19073	2019-12-18 14:22:02	2019-12-18	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7312	delivery	5	22
19074	2019-12-18 14:29:12	2019-12-18	14	[{"id_menu":2,"count":1}]	5012	pick-up	0	14
19075	2019-12-18 14:35:29	2019-12-18	14	[{"id_menu":2,"count":1}]	7246	delivery	5	19
19076	2019-12-18 14:39:16	2019-12-18	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2436	delivery	5	31
19077	2019-12-18 14:40:25	2019-12-18	12	[{"id_menu":1,"count":1}]	7256	delivery	5	17
19078	2019-12-18 14:49:18	2019-12-18	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	7299	delivery	5	31
19079	2019-12-18 14:53:57	2019-12-18	14	[{"id_menu":2,"count":2}]	5725	delivery	5	19
19080	2019-12-18 14:56:29	2019-12-18	8	[{"id_menu":5,"count":1}]	7295	delivery	5	13
19081	2019-12-18 14:56:47	2019-12-18	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2608	pick-up	0	25
19082	2019-12-18 15:06:24	2019-12-18	14	[{"id_menu":2,"count":1}]	379	delivery	5	19
19083	2019-12-18 15:16:40	2019-12-18	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1449	pick-up	0	24
19084	2019-12-18 15:19:52	2019-12-18	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	5730	delivery	5	45
19085	2019-12-18 15:31:50	2019-12-18	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	256	pick-up	0	21
19086	2019-12-18 15:53:36	2019-12-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2983	delivery	5	28
19087	2019-12-18 16:00:34	2019-12-18	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	7288	delivery	5	38
19088	2019-12-18 16:17:48	2019-12-18	14	[{"id_menu":2,"count":2}]	4486	pick-up	0	14
19089	2019-12-18 16:21:02	2019-12-18	14	[{"id_menu":2,"count":1}]	2351	pick-up	0	14
19090	2019-12-18 16:29:37	2019-12-18	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1813	pick-up	0	40
19091	2019-12-18 16:49:38	2019-12-18	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":2}]	7293	delivery	5	28
19092	2019-12-18 16:49:50	2019-12-18	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	4432	delivery	5	22
19093	2019-12-18 16:55:49	2019-12-18	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7281	delivery	5	45
19094	2019-12-18 17:04:32	2019-12-18	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	582	pick-up	0	29
19095	2019-12-18 17:13:17	2019-12-18	9	[{"id_menu":7,"count":1}]	7243	pick-up	0	9
19096	2019-12-18 17:14:13	2019-12-18	9	[{"id_menu":6,"count":1}]	1174	pick-up	0	9
19097	2019-12-18 17:17:56	2019-12-18	17	[{"id_menu":4,"count":1}]	7303	delivery	5	22
19098	2019-12-18 17:38:13	2019-12-18	14	[{"id_menu":2,"count":1}]	7311	delivery	5	19
19099	2019-12-18 17:44:16	2019-12-18	14	[{"id_menu":2,"count":1}]	3048	pick-up	0	14
19100	2019-12-18 18:18:01	2019-12-18	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7262	delivery	5	34
19101	2019-12-18 18:20:36	2019-12-18	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":2}]	4225	delivery	5	22
19102	2019-12-18 18:28:20	2019-12-18	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5106	delivery	5	40
19103	2019-12-18 18:37:21	2019-12-18	14	[{"id_menu":2,"count":1}]	7270	delivery	5	19
19104	2019-12-18 18:38:04	2019-12-18	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7277	delivery	5	31
19105	2019-12-18 18:43:56	2019-12-18	9	[{"id_menu":6,"count":1}]	1711	pick-up	0	9
19106	2019-12-18 18:55:53	2019-12-18	12	[{"id_menu":3,"count":1}]	3129	delivery	5	17
19107	2019-12-18 19:11:48	2019-12-18	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2193	delivery	5	31
19108	2019-12-18 19:40:16	2019-12-18	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1140	pick-up	0	26
19109	2019-12-18 19:42:58	2019-12-18	8	[{"id_menu":5,"count":1}]	3039	pick-up	0	8
19110	2019-12-18 19:54:57	2019-12-18	12	[{"id_menu":1,"count":1}]	7250	pick-up	0	12
19111	2019-12-18 20:07:04	2019-12-18	14	[{"id_menu":2,"count":1}]	7248	pick-up	0	14
19112	2019-12-18 20:07:05	2019-12-18	9	[{"id_menu":6,"count":1}]	7088	delivery	5	14
19113	2019-12-18 20:19:58	2019-12-18	17	[{"id_menu":4,"count":1}]	3294	delivery	5	22
19114	2019-12-18 20:23:42	2019-12-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	7253	delivery	5	23
19115	2019-12-18 20:25:35	2019-12-18	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	7269	delivery	5	40
19116	2019-12-18 20:33:15	2019-12-18	12	[{"id_menu":1,"count":1}]	7289	delivery	5	17
19117	2019-12-18 20:40:54	2019-12-18	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7287	delivery	5	36
19118	2019-12-18 20:52:16	2019-12-18	12	[{"id_menu":3,"count":1}]	7273	delivery	5	17
19119	2019-12-18 20:56:20	2019-12-18	9	[{"id_menu":6,"count":1}]	7285	delivery	5	14
19120	2019-12-18 21:08:28	2019-12-18	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	5699	delivery	5	26
19121	2019-12-18 21:08:31	2019-12-18	9	[{"id_menu":7,"count":1}]	7272	delivery	5	14
19122	2019-12-18 21:20:47	2019-12-18	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	5329	delivery	5	36
19123	2019-12-18 21:27:23	2019-12-18	14	[{"id_menu":2,"count":1}]	7306	pick-up	0	14
19124	2019-12-18 21:40:14	2019-12-18	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7298	delivery	5	36
19125	2019-12-18 22:08:55	2019-12-18	17	[{"id_menu":4,"count":1}]	6257	delivery	5	22
19126	2019-12-18 22:18:46	2019-12-18	8	[{"id_menu":5,"count":1}]	7282	pick-up	0	8
19127	2019-12-18 22:34:06	2019-12-18	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6238	delivery	5	37
19128	2019-12-18 22:36:29	2019-12-18	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	6480	delivery	5	23
19129	2019-12-18 22:41:50	2019-12-18	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	2482	delivery	5	31
19130	2019-12-18 23:04:27	2019-12-18	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":3}]	7257	delivery	5	26
19131	2019-12-18 23:11:07	2019-12-18	9	[{"id_menu":7,"count":1}]	7290	delivery	5	14
19132	2019-12-18 23:17:39	2019-12-18	12	[{"id_menu":3,"count":1}]	579	pick-up	0	12
19133	2019-12-18 23:22:14	2019-12-18	8	[{"id_menu":5,"count":1}]	6836	delivery	5	13
19134	2019-12-18 23:32:45	2019-12-18	12	[{"id_menu":3,"count":1}]	477	pick-up	0	12
19135	2019-12-18 23:35:52	2019-12-18	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2806	delivery	5	48
19136	2019-12-18 23:36:36	2019-12-18	17	[{"id_menu":4,"count":1}]	7252	delivery	5	22
19137	2019-12-18 23:48:41	2019-12-18	17	[{"id_menu":4,"count":1}]	5642	delivery	5	22
19138	2019-12-18 23:57:35	2019-12-18	9	[{"id_menu":6,"count":1}]	3539	pick-up	0	9
19139	2019-12-18 23:58:46	2019-12-18	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	7249	delivery	5	26
19140	2019-12-19 00:03:50	2019-12-19	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	5110	delivery	5	36
19141	2019-12-19 00:13:33	2019-12-19	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4734	pick-up	0	29
19142	2019-12-19 00:19:37	2019-12-19	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	2564	pick-up	0	24
19143	2019-12-19 00:28:00	2019-12-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7355	delivery	5	22
19144	2019-12-19 00:40:54	2019-12-19	8	[{"id_menu":5,"count":1}]	2807	delivery	5	13
19145	2019-12-19 00:51:18	2019-12-19	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5309	delivery	5	30
19146	2019-12-19 01:02:14	2019-12-19	8	[{"id_menu":5,"count":1}]	2363	delivery	5	13
19147	2019-12-19 01:06:11	2019-12-19	17	[{"id_menu":4,"count":1}]	6301	delivery	5	22
19148	2019-12-19 01:11:53	2019-12-19	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3318	pick-up	0	35
19149	2019-12-19 01:20:35	2019-12-19	9	[{"id_menu":7,"count":1}]	6056	delivery	5	14
19150	2019-12-19 01:22:31	2019-12-19	8	[{"id_menu":5,"count":1}]	6590	delivery	5	13
19151	2019-12-19 01:24:19	2019-12-19	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	2392	pick-up	0	34
19152	2019-12-19 01:51:04	2019-12-19	14	[{"id_menu":2,"count":1}]	5048	pick-up	0	14
19153	2019-12-19 01:52:49	2019-12-19	9	[{"id_menu":7,"count":2}]	3968	pick-up	0	9
19154	2019-12-19 01:53:38	2019-12-19	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	4920	pick-up	0	29
19155	2019-12-19 01:54:49	2019-12-19	14	[{"id_menu":2,"count":1}]	2604	pick-up	0	14
19156	2019-12-19 01:56:24	2019-12-19	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	320	pick-up	0	21
19157	2019-12-19 01:57:38	2019-12-19	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7353	delivery	5	36
19158	2019-12-19 01:59:34	2019-12-19	14	[{"id_menu":2,"count":1}]	7321	delivery	5	19
19159	2019-12-19 02:02:52	2019-12-19	12	[{"id_menu":1,"count":1}]	986	pick-up	0	12
19160	2019-12-19 02:16:53	2019-12-19	12	[{"id_menu":3,"count":1}]	7368	delivery	5	17
19161	2019-12-19 02:52:34	2019-12-19	12	[{"id_menu":1,"count":1}]	7316	delivery	5	17
19162	2019-12-19 03:00:18	2019-12-19	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3823	delivery	5	42
19163	2019-12-19 03:01:22	2019-12-19	9	[{"id_menu":6,"count":1}]	1044	pick-up	0	9
19164	2019-12-19 03:05:10	2019-12-19	14	[{"id_menu":2,"count":1}]	7369	delivery	5	19
19165	2019-12-19 03:09:42	2019-12-19	14	[{"id_menu":2,"count":1}]	4486	pick-up	0	14
19166	2019-12-19 03:13:56	2019-12-19	17	[{"id_menu":4,"count":1}]	7046	pick-up	0	17
19167	2019-12-19 03:15:25	2019-12-19	9	[{"id_menu":6,"count":1}]	820	delivery	5	14
19168	2019-12-19 03:37:56	2019-12-19	17	[{"id_menu":4,"count":1}]	73	pick-up	0	17
19169	2019-12-19 03:38:44	2019-12-19	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	6540	delivery	5	31
19170	2019-12-19 03:58:26	2019-12-19	8	[{"id_menu":5,"count":1}]	4818	delivery	5	13
19171	2019-12-19 04:02:18	2019-12-19	9	[{"id_menu":6,"count":2}]	7373	delivery	5	14
19172	2019-12-19 04:09:39	2019-12-19	9	[{"id_menu":7,"count":1}]	4452	delivery	5	14
19173	2019-12-19 04:15:47	2019-12-19	12	[{"id_menu":1,"count":1}]	3636	pick-up	0	12
19174	2019-12-19 04:18:44	2019-12-19	9	[{"id_menu":6,"count":1}]	6273	delivery	5	14
19175	2019-12-19 04:27:50	2019-12-19	17	[{"id_menu":4,"count":1}]	7351	delivery	5	22
19176	2019-12-19 04:51:57	2019-12-19	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4960	pick-up	0	25
19177	2019-12-19 04:52:43	2019-12-19	14	[{"id_menu":2,"count":1}]	2189	pick-up	0	14
19178	2019-12-19 05:09:38	2019-12-19	17	[{"id_menu":4,"count":1}]	7313	pick-up	0	17
19179	2019-12-19 05:18:39	2019-12-19	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	7358	delivery	5	31
19180	2019-12-19 05:26:12	2019-12-19	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2916	delivery	5	27
19181	2019-12-19 05:34:23	2019-12-19	9	[{"id_menu":7,"count":1}]	3211	delivery	5	14
19182	2019-12-19 05:45:00	2019-12-19	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	7372	delivery	5	34
19183	2019-12-19 05:48:13	2019-12-19	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	7327	delivery	5	26
19184	2019-12-19 06:04:19	2019-12-19	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	7319	pick-up	0	29
19185	2019-12-19 06:12:28	2019-12-19	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	7365	delivery	5	39
19186	2019-12-19 06:17:47	2019-12-19	14	[{"id_menu":2,"count":1}]	7361	pick-up	0	14
19187	2019-12-19 06:31:12	2019-12-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2928	pick-up	0	23
19188	2019-12-19 06:33:04	2019-12-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	504	pick-up	0	23
19189	2019-12-19 06:33:53	2019-12-19	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	177	delivery	5	31
19190	2019-12-19 06:34:10	2019-12-19	17	[{"id_menu":4,"count":1}]	729	pick-up	0	17
19191	2019-12-19 06:37:58	2019-12-19	14	[{"id_menu":2,"count":1}]	6950	delivery	5	19
19192	2019-12-19 07:00:24	2019-12-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	7333	delivery	5	36
19193	2019-12-19 07:10:58	2019-12-19	9	[{"id_menu":7,"count":1}]	5509	delivery	5	14
19194	2019-12-19 07:40:08	2019-12-19	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2418	delivery	5	26
19195	2019-12-19 07:46:38	2019-12-19	9	[{"id_menu":6,"count":1}]	7337	delivery	5	14
19196	2019-12-19 07:49:52	2019-12-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	1380	delivery	5	28
19197	2019-12-19 07:51:25	2019-12-19	12	[{"id_menu":1,"count":1}]	34	pick-up	0	12
19198	2019-12-19 08:15:10	2019-12-19	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2543	pick-up	0	29
19199	2019-12-19 08:17:38	2019-12-19	12	[{"id_menu":3,"count":1}]	7363	delivery	5	17
19200	2019-12-19 08:19:41	2019-12-19	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1736	delivery	5	26
19201	2019-12-19 08:27:00	2019-12-19	9	[{"id_menu":7,"count":1}]	4704	delivery	5	14
19202	2019-12-19 08:28:17	2019-12-19	14	[{"id_menu":2,"count":2}]	1828	pick-up	0	14
19203	2019-12-19 08:29:01	2019-12-19	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5711	pick-up	0	38
19204	2019-12-19 08:32:01	2019-12-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6038	delivery	5	36
19205	2019-12-19 08:46:45	2019-12-19	9	[{"id_menu":6,"count":1}]	3619	pick-up	0	9
19206	2019-12-19 08:59:33	2019-12-19	12	[{"id_menu":3,"count":1}]	7352	delivery	5	17
19207	2019-12-19 09:09:31	2019-12-19	17	[{"id_menu":4,"count":1}]	2618	pick-up	0	17
19208	2019-12-19 09:12:57	2019-12-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3708	delivery	5	28
19209	2019-12-19 09:20:44	2019-12-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1439	pick-up	0	31
19210	2019-12-19 09:25:05	2019-12-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7322	delivery	5	22
19211	2019-12-19 09:32:26	2019-12-19	9	[{"id_menu":7,"count":1}]	7354	pick-up	0	9
19212	2019-12-19 09:38:31	2019-12-19	14	[{"id_menu":2,"count":1}]	1282	pick-up	0	14
19213	2019-12-19 09:56:56	2019-12-19	17	[{"id_menu":4,"count":1}]	7342	delivery	5	22
19214	2019-12-19 09:57:00	2019-12-19	17	[{"id_menu":4,"count":1}]	284	delivery	5	22
19215	2019-12-19 10:00:52	2019-12-19	14	[{"id_menu":2,"count":1}]	7357	delivery	5	19
19216	2019-12-19 10:12:02	2019-12-19	9	[{"id_menu":7,"count":1}]	7347	delivery	5	14
19217	2019-12-19 10:26:22	2019-12-19	12	[{"id_menu":3,"count":1}]	3629	delivery	5	17
19218	2019-12-19 10:39:06	2019-12-19	8	[{"id_menu":5,"count":1}]	5306	pick-up	0	8
19219	2019-12-19 10:45:10	2019-12-19	12	[{"id_menu":1,"count":1}]	2993	pick-up	0	12
19220	2019-12-19 11:02:44	2019-12-19	9	[{"id_menu":6,"count":1}]	4564	delivery	5	14
19221	2019-12-19 11:06:49	2019-12-19	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	3164	delivery	5	26
19222	2019-12-19 11:09:09	2019-12-19	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	7156	pick-up	0	21
19223	2019-12-19 11:22:03	2019-12-19	14	[{"id_menu":2,"count":1}]	3907	pick-up	0	14
19224	2019-12-19 11:23:01	2019-12-19	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1708	pick-up	0	26
19225	2019-12-19 11:23:38	2019-12-19	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1427	delivery	5	27
19226	2019-12-19 11:31:03	2019-12-19	17	[{"id_menu":4,"count":1}]	7186	pick-up	0	17
19227	2019-12-19 11:48:12	2019-12-19	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7371	delivery	5	34
19228	2019-12-19 11:48:39	2019-12-19	8	[{"id_menu":5,"count":1}]	973	pick-up	0	8
19229	2019-12-19 11:59:21	2019-12-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1472	pick-up	0	23
19230	2019-12-19 12:15:09	2019-12-19	17	[{"id_menu":4,"count":1}]	7349	delivery	5	22
19231	2019-12-19 12:29:27	2019-12-19	12	[{"id_menu":1,"count":1}]	2230	pick-up	0	12
19232	2019-12-19 13:06:47	2019-12-19	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5699	delivery	5	40
19233	2019-12-19 13:07:47	2019-12-19	8	[{"id_menu":5,"count":1}]	7370	delivery	5	13
19234	2019-12-19 13:08:41	2019-12-19	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7341	pick-up	0	38
19235	2019-12-19 13:15:55	2019-12-19	12	[{"id_menu":3,"count":1}]	3006	delivery	5	17
19236	2019-12-19 13:31:30	2019-12-19	12	[{"id_menu":1,"count":1}]	7320	pick-up	0	12
19237	2019-12-19 13:52:39	2019-12-19	9	[{"id_menu":7,"count":2}]	6147	pick-up	0	9
19238	2019-12-19 14:04:22	2019-12-19	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2837	delivery	5	54
19239	2019-12-19 14:12:38	2019-12-19	8	[{"id_menu":5,"count":1}]	4995	delivery	5	13
19240	2019-12-19 14:16:33	2019-12-19	9	[{"id_menu":6,"count":1}]	7329	delivery	5	14
19241	2019-12-19 14:31:57	2019-12-19	17	[{"id_menu":4,"count":2}]	1597	pick-up	0	17
19242	2019-12-19 14:35:36	2019-12-19	9	[{"id_menu":6,"count":1}]	4495	delivery	5	14
19243	2019-12-19 14:36:14	2019-12-19	17	[{"id_menu":4,"count":1}]	1842	delivery	5	22
19244	2019-12-19 14:41:32	2019-12-19	8	[{"id_menu":5,"count":1}]	4873	delivery	5	13
19245	2019-12-19 14:43:02	2019-12-19	9	[{"id_menu":7,"count":1}]	7326	delivery	5	14
19246	2019-12-19 14:45:26	2019-12-19	8	[{"id_menu":5,"count":1}]	81	pick-up	0	8
19247	2019-12-19 14:46:53	2019-12-19	12	[{"id_menu":3,"count":1}]	2885	delivery	5	17
19248	2019-12-19 14:54:25	2019-12-19	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	519	pick-up	0	31
19249	2019-12-19 14:58:06	2019-12-19	17	[{"id_menu":4,"count":1}]	970	pick-up	0	17
19250	2019-12-19 14:58:46	2019-12-19	12	[{"id_menu":1,"count":1}]	788	pick-up	0	12
19251	2019-12-19 15:01:14	2019-12-19	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7324	delivery	5	35
19252	2019-12-19 15:05:49	2019-12-19	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":2}]	4368	pick-up	0	23
19253	2019-12-19 15:11:02	2019-12-19	14	[{"id_menu":2,"count":2}]	1174	pick-up	0	14
19254	2019-12-19 15:13:24	2019-12-19	17	[{"id_menu":4,"count":1}]	7084	pick-up	0	17
19255	2019-12-19 15:20:30	2019-12-19	14	[{"id_menu":2,"count":1}]	7356	delivery	5	19
19256	2019-12-19 15:35:13	2019-12-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5455	delivery	5	23
19257	2019-12-19 15:39:21	2019-12-19	12	[{"id_menu":1,"count":1}]	7317	pick-up	0	12
19258	2019-12-19 15:39:22	2019-12-19	12	[{"id_menu":3,"count":1}]	2401	pick-up	0	12
19259	2019-12-19 15:41:18	2019-12-19	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	346	pick-up	0	26
19260	2019-12-19 15:46:12	2019-12-19	8	[{"id_menu":5,"count":1}]	1399	pick-up	0	8
19261	2019-12-19 16:32:39	2019-12-19	9	[{"id_menu":6,"count":1}]	5594	delivery	5	14
19262	2019-12-19 16:36:08	2019-12-19	12	[{"id_menu":1,"count":1}]	2200	pick-up	0	12
19263	2019-12-19 16:49:34	2019-12-19	17	[{"id_menu":4,"count":1}]	7350	delivery	5	22
19264	2019-12-19 16:52:40	2019-12-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7364	delivery	5	36
19265	2019-12-19 16:55:46	2019-12-19	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	7332	delivery	5	26
19266	2019-12-19 16:57:07	2019-12-19	12	[{"id_menu":3,"count":1}]	281	pick-up	0	12
19267	2019-12-19 17:15:29	2019-12-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2511	pick-up	0	23
19268	2019-12-19 17:21:38	2019-12-19	9	[{"id_menu":6,"count":1}]	5570	delivery	5	14
19269	2019-12-19 17:27:13	2019-12-19	14	[{"id_menu":2,"count":1}]	2045	pick-up	0	14
19270	2019-12-19 17:56:03	2019-12-19	8	[{"id_menu":5,"count":1}]	7367	pick-up	0	8
19271	2019-12-19 17:58:13	2019-12-19	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4867	pick-up	0	25
19272	2019-12-19 18:02:55	2019-12-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5050	pick-up	0	26
19273	2019-12-19 18:10:15	2019-12-19	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	7345	delivery	5	31
19274	2019-12-19 18:20:54	2019-12-19	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2332	delivery	5	26
19275	2019-12-19 18:22:26	2019-12-19	9	[{"id_menu":6,"count":1}]	6398	delivery	5	14
19276	2019-12-19 18:23:51	2019-12-19	14	[{"id_menu":2,"count":1}]	3785	pick-up	0	14
19277	2019-12-19 18:27:00	2019-12-19	12	[{"id_menu":1,"count":1}]	4874	pick-up	0	12
19278	2019-12-19 18:40:07	2019-12-19	12	[{"id_menu":3,"count":1}]	3307	pick-up	0	12
19279	2019-12-19 18:57:49	2019-12-19	14	[{"id_menu":2,"count":1}]	5142	delivery	5	19
19280	2019-12-19 19:14:17	2019-12-19	9	[{"id_menu":7,"count":1}]	7334	delivery	5	14
19281	2019-12-19 19:29:33	2019-12-19	12	[{"id_menu":1,"count":1}]	5708	delivery	5	17
19282	2019-12-19 19:41:27	2019-12-19	9	[{"id_menu":6,"count":2}]	5109	delivery	5	14
19283	2019-12-19 19:47:36	2019-12-19	17	[{"id_menu":4,"count":1}]	786	pick-up	0	17
19284	2019-12-19 19:53:25	2019-12-19	14	[{"id_menu":2,"count":1}]	4418	delivery	5	19
19285	2019-12-19 19:55:55	2019-12-19	9	[{"id_menu":7,"count":1}]	7375	delivery	5	14
19286	2019-12-19 20:13:32	2019-12-19	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7330	delivery	5	31
19287	2019-12-19 20:15:06	2019-12-19	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	7359	delivery	5	34
19288	2019-12-19 20:17:32	2019-12-19	17	[{"id_menu":4,"count":1}]	7344	pick-up	0	17
19289	2019-12-19 20:19:59	2019-12-19	9	[{"id_menu":7,"count":1}]	7314	delivery	5	14
19290	2019-12-19 20:27:31	2019-12-19	9	[{"id_menu":7,"count":1}]	7325	delivery	5	14
19291	2019-12-19 20:39:34	2019-12-19	8	[{"id_menu":5,"count":1}]	2042	delivery	5	13
19292	2019-12-19 21:26:16	2019-12-19	8	[{"id_menu":5,"count":1}]	683	pick-up	0	8
19293	2019-12-19 21:27:13	2019-12-19	17	[{"id_menu":4,"count":1}]	4964	delivery	5	22
19294	2019-12-19 21:31:23	2019-12-19	9	[{"id_menu":6,"count":1}]	7366	delivery	5	14
19295	2019-12-19 21:36:43	2019-12-19	9	[{"id_menu":6,"count":2}]	7328	pick-up	0	9
19296	2019-12-19 21:40:06	2019-12-19	12	[{"id_menu":1,"count":1}]	7376	pick-up	0	12
19297	2019-12-19 21:41:45	2019-12-19	17	[{"id_menu":4,"count":2}]	932	pick-up	0	17
19298	2019-12-19 21:42:56	2019-12-19	9	[{"id_menu":7,"count":1}]	7315	delivery	5	14
19299	2019-12-19 21:45:32	2019-12-19	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1370	pick-up	0	29
19300	2019-12-19 21:49:54	2019-12-19	12	[{"id_menu":1,"count":1}]	1902	pick-up	0	12
19301	2019-12-19 22:05:18	2019-12-19	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	7360	delivery	5	34
19302	2019-12-19 22:12:27	2019-12-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3867	delivery	5	22
19303	2019-12-19 22:21:52	2019-12-19	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	6156	delivery	5	26
19304	2019-12-19 22:40:50	2019-12-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7338	delivery	5	28
19305	2019-12-19 22:45:38	2019-12-19	12	[{"id_menu":1,"count":1}]	7346	delivery	5	17
19306	2019-12-19 22:49:01	2019-12-19	14	[{"id_menu":2,"count":1}]	5114	pick-up	0	14
19307	2019-12-19 22:50:56	2019-12-19	14	[{"id_menu":2,"count":1}]	2507	delivery	5	19
19308	2019-12-19 23:03:57	2019-12-19	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	1352	pick-up	0	31
19309	2019-12-19 23:16:36	2019-12-19	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5476	delivery	5	31
19310	2019-12-19 23:19:30	2019-12-19	12	[{"id_menu":1,"count":1}]	2366	delivery	5	17
19311	2019-12-19 23:22:26	2019-12-19	12	[{"id_menu":1,"count":1}]	7331	pick-up	0	12
19312	2019-12-19 23:27:46	2019-12-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	52	delivery	5	28
19313	2019-12-19 23:29:58	2019-12-19	8	[{"id_menu":5,"count":1}]	324	pick-up	0	8
19314	2019-12-19 23:33:17	2019-12-19	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4912	delivery	5	40
19315	2019-12-19 23:41:38	2019-12-19	9	[{"id_menu":6,"count":1}]	4594	delivery	5	14
19316	2019-12-19 23:48:24	2019-12-19	12	[{"id_menu":3,"count":1}]	285	pick-up	0	12
19317	2019-12-19 23:50:36	2019-12-19	12	[{"id_menu":1,"count":1}]	4685	pick-up	0	12
19318	2019-12-20 00:04:57	2019-12-20	17	[{"id_menu":4,"count":1}]	4197	pick-up	0	17
19319	2019-12-20 00:06:19	2019-12-20	9	[{"id_menu":6,"count":1}]	376	delivery	5	14
19320	2019-12-20 00:08:56	2019-12-20	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3332	delivery	5	31
19321	2019-12-20 00:09:26	2019-12-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2018	pick-up	0	23
19322	2019-12-20 00:11:43	2019-12-20	9	[{"id_menu":6,"count":1}]	7416	delivery	5	14
19323	2019-12-20 00:13:26	2019-12-20	17	[{"id_menu":4,"count":1}]	541	delivery	5	22
19324	2019-12-20 00:29:39	2019-12-20	14	[{"id_menu":2,"count":1}]	6250	pick-up	0	14
19325	2019-12-20 00:33:23	2019-12-20	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7049	delivery	5	22
19326	2019-12-20 00:38:45	2019-12-20	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	7381	delivery	5	48
19327	2019-12-20 00:40:01	2019-12-20	12	[{"id_menu":1,"count":1}]	3227	delivery	5	17
19328	2019-12-20 00:40:37	2019-12-20	14	[{"id_menu":2,"count":1}]	5226	delivery	5	19
19329	2019-12-20 00:49:08	2019-12-20	8	[{"id_menu":5,"count":1}]	1868	delivery	5	13
19330	2019-12-20 01:02:37	2019-12-20	12	[{"id_menu":1,"count":1}]	7397	pick-up	0	12
19331	2019-12-20 01:25:54	2019-12-20	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7421	delivery	5	31
19332	2019-12-20 01:26:02	2019-12-20	14	[{"id_menu":2,"count":1}]	7388	delivery	5	19
19333	2019-12-20 01:36:25	2019-12-20	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7383	pick-up	0	26
19334	2019-12-20 01:37:52	2019-12-20	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	675	delivery	5	34
19335	2019-12-20 01:56:50	2019-12-20	12	[{"id_menu":1,"count":1}]	3116	pick-up	0	12
19336	2019-12-20 02:15:24	2019-12-20	9	[{"id_menu":6,"count":1}]	209	delivery	5	14
19337	2019-12-20 02:20:07	2019-12-20	12	[{"id_menu":3,"count":1}]	7405	pick-up	0	12
19338	2019-12-20 02:28:52	2019-12-20	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7379	delivery	5	37
19339	2019-12-20 02:34:20	2019-12-20	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7428	delivery	5	39
19340	2019-12-20 02:52:21	2019-12-20	12	[{"id_menu":1,"count":1}]	3419	pick-up	0	12
19341	2019-12-20 02:59:14	2019-12-20	9	[{"id_menu":6,"count":1}]	173	delivery	5	14
19342	2019-12-20 03:08:11	2019-12-20	9	[{"id_menu":6,"count":1}]	6466	delivery	5	14
19343	2019-12-20 03:08:16	2019-12-20	12	[{"id_menu":3,"count":1}]	111	pick-up	0	12
19344	2019-12-20 03:09:06	2019-12-20	17	[{"id_menu":4,"count":1}]	5427	pick-up	0	17
19345	2019-12-20 03:11:37	2019-12-20	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	6869	delivery	5	25
19346	2019-12-20 03:16:23	2019-12-20	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4533	pick-up	0	31
19347	2019-12-20 03:17:21	2019-12-20	8	[{"id_menu":5,"count":1}]	4100	delivery	5	13
19348	2019-12-20 03:33:22	2019-12-20	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6080	delivery	5	34
19349	2019-12-20 03:33:27	2019-12-20	9	[{"id_menu":6,"count":1}]	7395	delivery	5	14
19350	2019-12-20 03:39:51	2019-12-20	12	[{"id_menu":3,"count":1}]	7390	delivery	5	17
19351	2019-12-20 03:41:14	2019-12-20	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6277	pick-up	0	35
19352	2019-12-20 03:59:16	2019-12-20	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5152	delivery	5	22
19353	2019-12-20 04:12:03	2019-12-20	17	[{"id_menu":4,"count":1}]	7431	delivery	5	22
19354	2019-12-20 04:17:03	2019-12-20	17	[{"id_menu":4,"count":1}]	5483	pick-up	0	17
19355	2019-12-20 04:36:20	2019-12-20	9	[{"id_menu":6,"count":1}]	7386	delivery	5	14
19356	2019-12-20 04:38:08	2019-12-20	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	623	pick-up	0	34
19357	2019-12-20 04:56:12	2019-12-20	9	[{"id_menu":7,"count":1}]	7380	delivery	5	14
19358	2019-12-20 05:20:13	2019-12-20	14	[{"id_menu":2,"count":1}]	7418	delivery	5	19
19359	2019-12-20 05:28:51	2019-12-20	12	[{"id_menu":3,"count":1}]	7430	pick-up	0	12
19360	2019-12-20 05:56:55	2019-12-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7377	delivery	5	28
19361	2019-12-20 06:03:35	2019-12-20	12	[{"id_menu":1,"count":1}]	4595	pick-up	0	12
19362	2019-12-20 06:07:24	2019-12-20	17	[{"id_menu":4,"count":1}]	2935	pick-up	0	17
19363	2019-12-20 06:39:02	2019-12-20	8	[{"id_menu":5,"count":1}]	3064	delivery	5	13
19364	2019-12-20 06:50:22	2019-12-20	12	[{"id_menu":1,"count":1}]	7435	pick-up	0	12
19365	2019-12-20 06:57:29	2019-12-20	12	[{"id_menu":1,"count":1}]	7410	pick-up	0	12
19366	2019-12-20 07:06:43	2019-12-20	17	[{"id_menu":4,"count":1}]	763	pick-up	0	17
19367	2019-12-20 07:11:56	2019-12-20	9	[{"id_menu":7,"count":1}]	6797	delivery	5	14
19368	2019-12-20 07:23:18	2019-12-20	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	4481	delivery	5	45
19369	2019-12-20 07:36:42	2019-12-20	12	[{"id_menu":3,"count":1}]	7293	delivery	5	17
19370	2019-12-20 07:39:43	2019-12-20	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	2298	delivery	5	25
19371	2019-12-20 07:54:11	2019-12-20	8	[{"id_menu":5,"count":1}]	7406	delivery	5	13
19372	2019-12-20 08:02:08	2019-12-20	17	[{"id_menu":5,"count":3},{"id_menu":7,"count":1}]	4982	delivery	5	22
19373	2019-12-20 08:04:19	2019-12-20	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1272	delivery	5	39
19374	2019-12-20 08:07:42	2019-12-20	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3368	delivery	5	27
19375	2019-12-20 08:33:17	2019-12-20	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3311	delivery	5	31
19376	2019-12-20 08:55:36	2019-12-20	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	7086	delivery	5	29
19377	2019-12-20 08:55:58	2019-12-20	9	[{"id_menu":6,"count":1}]	7440	delivery	5	14
19378	2019-12-20 08:58:08	2019-12-20	9	[{"id_menu":6,"count":1}]	7399	delivery	5	14
19379	2019-12-20 09:11:58	2019-12-20	12	[{"id_menu":1,"count":1}]	6265	pick-up	0	12
19380	2019-12-20 09:15:24	2019-12-20	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7420	delivery	5	44
19381	2019-12-20 09:28:31	2019-12-20	14	[{"id_menu":2,"count":1}]	2339	pick-up	0	14
19382	2019-12-20 09:46:49	2019-12-20	9	[{"id_menu":6,"count":1}]	6595	delivery	5	14
19383	2019-12-20 09:50:25	2019-12-20	8	[{"id_menu":5,"count":1}]	96	delivery	5	13
19384	2019-12-20 10:24:34	2019-12-20	9	[{"id_menu":7,"count":1}]	4804	pick-up	0	9
19385	2019-12-20 10:29:11	2019-12-20	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	3570	pick-up	0	29
19386	2019-12-20 10:29:40	2019-12-20	9	[{"id_menu":7,"count":1}]	2534	pick-up	0	9
19387	2019-12-20 10:34:33	2019-12-20	17	[{"id_menu":4,"count":1}]	4531	delivery	5	22
19388	2019-12-20 10:38:57	2019-12-20	8	[{"id_menu":5,"count":1}]	7414	pick-up	0	8
19389	2019-12-20 11:02:41	2019-12-20	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	7402	delivery	5	43
19390	2019-12-20 11:05:20	2019-12-20	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3399	pick-up	0	31
19391	2019-12-20 11:20:37	2019-12-20	9	[{"id_menu":7,"count":1}]	7423	pick-up	0	9
19392	2019-12-20 11:44:03	2019-12-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3400	delivery	5	23
19393	2019-12-20 11:44:54	2019-12-20	17	[{"id_menu":4,"count":1}]	4130	pick-up	0	17
19394	2019-12-20 12:05:12	2019-12-20	9	[{"id_menu":6,"count":1}]	7411	delivery	5	14
19395	2019-12-20 12:05:38	2019-12-20	9	[{"id_menu":6,"count":1}]	743	pick-up	0	9
19396	2019-12-20 12:06:55	2019-12-20	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	528	delivery	5	26
19397	2019-12-20 12:18:17	2019-12-20	9	[{"id_menu":6,"count":1}]	4644	pick-up	0	9
19398	2019-12-20 12:22:37	2019-12-20	12	[{"id_menu":3,"count":1}]	5386	pick-up	0	12
19399	2019-12-20 12:27:20	2019-12-20	9	[{"id_menu":6,"count":1}]	4363	pick-up	0	9
19400	2019-12-20 12:53:46	2019-12-20	9	[{"id_menu":7,"count":1}]	7393	delivery	5	14
19401	2019-12-20 13:05:25	2019-12-20	12	[{"id_menu":1,"count":1}]	4332	delivery	5	17
19402	2019-12-20 13:12:20	2019-12-20	17	[{"id_menu":4,"count":1}]	6902	delivery	5	22
19403	2019-12-20 13:14:45	2019-12-20	17	[{"id_menu":4,"count":1}]	472	pick-up	0	17
19404	2019-12-20 13:40:17	2019-12-20	9	[{"id_menu":7,"count":1}]	4138	pick-up	0	9
19405	2019-12-20 13:41:36	2019-12-20	9	[{"id_menu":7,"count":1}]	3827	pick-up	0	9
19406	2019-12-20 14:02:48	2019-12-20	12	[{"id_menu":1,"count":2}]	7385	pick-up	0	12
19407	2019-12-20 14:07:22	2019-12-20	14	[{"id_menu":2,"count":1}]	2300	delivery	5	19
19408	2019-12-20 14:57:36	2019-12-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7384	delivery	5	22
19409	2019-12-20 15:01:26	2019-12-20	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	7441	delivery	5	25
19410	2019-12-20 15:07:43	2019-12-20	17	[{"id_menu":4,"count":1}]	7401	delivery	5	22
19411	2019-12-20 15:23:09	2019-12-20	17	[{"id_menu":4,"count":1}]	2556	pick-up	0	17
19412	2019-12-20 15:46:38	2019-12-20	8	[{"id_menu":5,"count":1}]	4793	pick-up	0	8
19413	2019-12-20 16:42:34	2019-12-20	12	[{"id_menu":3,"count":1}]	5930	delivery	5	17
19414	2019-12-20 16:53:31	2019-12-20	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	664	delivery	5	40
19415	2019-12-20 16:54:05	2019-12-20	14	[{"id_menu":2,"count":1}]	7407	pick-up	0	14
19416	2019-12-20 17:09:06	2019-12-20	8	[{"id_menu":5,"count":1}]	7378	delivery	5	13
19417	2019-12-20 17:21:48	2019-12-20	17	[{"id_menu":4,"count":1}]	7424	pick-up	0	17
19418	2019-12-20 17:25:55	2019-12-20	9	[{"id_menu":6,"count":2}]	265	delivery	5	14
19419	2019-12-20 17:29:53	2019-12-20	9	[{"id_menu":7,"count":1}]	6998	delivery	5	14
19420	2019-12-20 17:59:41	2019-12-20	9	[{"id_menu":7,"count":1}]	3728	pick-up	0	9
19421	2019-12-20 18:04:14	2019-12-20	9	[{"id_menu":7,"count":2}]	7413	delivery	5	14
19422	2019-12-20 18:08:54	2019-12-20	9	[{"id_menu":6,"count":1}]	7432	pick-up	0	9
19423	2019-12-20 18:19:26	2019-12-20	9	[{"id_menu":6,"count":1}]	3883	delivery	5	14
19424	2019-12-20 18:20:37	2019-12-20	12	[{"id_menu":3,"count":1}]	5283	pick-up	0	12
19425	2019-12-20 18:55:15	2019-12-20	14	[{"id_menu":2,"count":1}]	396	pick-up	0	14
19426	2019-12-20 19:07:47	2019-12-20	9	[{"id_menu":6,"count":1}]	7417	delivery	5	14
19427	2019-12-20 19:14:20	2019-12-20	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7355	delivery	5	39
19428	2019-12-20 19:21:51	2019-12-20	17	[{"id_menu":4,"count":1}]	1233	pick-up	0	17
19429	2019-12-20 19:34:22	2019-12-20	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	7427	delivery	5	23
19430	2019-12-20 19:35:31	2019-12-20	17	[{"id_menu":4,"count":1}]	7050	pick-up	0	17
19431	2019-12-20 19:39:35	2019-12-20	9	[{"id_menu":6,"count":1}]	2902	pick-up	0	9
19432	2019-12-20 19:39:58	2019-12-20	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7387	delivery	5	45
19433	2019-12-20 20:14:08	2019-12-20	14	[{"id_menu":2,"count":1}]	2176	pick-up	0	14
19434	2019-12-20 20:15:46	2019-12-20	14	[{"id_menu":2,"count":1}]	790	pick-up	0	14
19435	2019-12-20 20:16:26	2019-12-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1158	pick-up	0	23
19436	2019-12-20 20:25:50	2019-12-20	9	[{"id_menu":7,"count":1}]	4912	delivery	5	14
19437	2019-12-20 20:25:54	2019-12-20	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	7439	delivery	5	31
19438	2019-12-20 20:35:39	2019-12-20	17	[{"id_menu":4,"count":1}]	5099	delivery	5	22
19439	2019-12-20 20:50:57	2019-12-20	9	[{"id_menu":7,"count":1}]	3224	pick-up	0	9
19440	2019-12-20 20:55:43	2019-12-20	9	[{"id_menu":7,"count":1}]	7433	delivery	5	14
19441	2019-12-20 20:58:38	2019-12-20	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3398	delivery	5	34
19442	2019-12-20 21:32:28	2019-12-20	9	[{"id_menu":7,"count":1}]	7429	pick-up	0	9
19443	2019-12-20 21:54:55	2019-12-20	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5886	delivery	5	39
19444	2019-12-20 22:04:00	2019-12-20	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	654	pick-up	0	29
19445	2019-12-20 22:16:21	2019-12-20	12	[{"id_menu":3,"count":1}]	7128	pick-up	0	12
19446	2019-12-20 22:22:38	2019-12-20	9	[{"id_menu":6,"count":1}]	7398	delivery	5	14
19447	2019-12-20 22:30:09	2019-12-20	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	7408	pick-up	0	21
19448	2019-12-20 22:50:21	2019-12-20	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4395	delivery	5	45
19449	2019-12-20 23:09:31	2019-12-20	8	[{"id_menu":5,"count":1}]	3149	delivery	5	13
19450	2019-12-20 23:29:43	2019-12-20	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1731	delivery	5	31
19451	2019-12-20 23:43:44	2019-12-20	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	626	pick-up	0	26
19452	2019-12-20 23:55:09	2019-12-20	12	[{"id_menu":3,"count":1}]	7412	delivery	5	17
19453	2019-12-21 00:02:36	2019-12-21	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7489	delivery	5	39
19454	2019-12-21 00:04:25	2019-12-21	12	[{"id_menu":1,"count":1}]	2447	pick-up	0	12
19455	2019-12-21 00:14:07	2019-12-21	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	894	pick-up	0	34
19456	2019-12-21 00:23:08	2019-12-21	8	[{"id_menu":5,"count":1}]	4869	pick-up	0	8
19457	2019-12-21 00:35:58	2019-12-21	12	[{"id_menu":3,"count":1}]	5110	delivery	5	17
19458	2019-12-21 00:35:59	2019-12-21	14	[{"id_menu":2,"count":1}]	1760	pick-up	0	14
19459	2019-12-21 00:42:03	2019-12-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1557	pick-up	0	26
19460	2019-12-21 00:43:00	2019-12-21	14	[{"id_menu":2,"count":1}]	7454	delivery	5	19
19461	2019-12-21 00:53:35	2019-12-21	17	[{"id_menu":4,"count":1}]	7452	delivery	5	22
19462	2019-12-21 01:00:28	2019-12-21	8	[{"id_menu":5,"count":1}]	1678	delivery	5	13
19463	2019-12-21 01:00:46	2019-12-21	14	[{"id_menu":2,"count":1}]	6617	pick-up	0	14
19464	2019-12-21 01:21:25	2019-12-21	8	[{"id_menu":5,"count":1}]	7501	pick-up	0	8
19465	2019-12-21 01:22:20	2019-12-21	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2857	pick-up	0	21
19466	2019-12-21 01:23:47	2019-12-21	9	[{"id_menu":6,"count":1}]	7518	delivery	5	14
19467	2019-12-21 01:25:16	2019-12-21	12	[{"id_menu":3,"count":1}]	1745	pick-up	0	12
19468	2019-12-21 01:28:21	2019-12-21	14	[{"id_menu":2,"count":1}]	7446	delivery	5	19
19469	2019-12-21 01:31:46	2019-12-21	8	[{"id_menu":5,"count":1}]	7498	delivery	5	13
19470	2019-12-21 01:40:58	2019-12-21	14	[{"id_menu":2,"count":1}]	6235	delivery	5	19
19471	2019-12-21 01:42:21	2019-12-21	9	[{"id_menu":6,"count":2}]	5546	delivery	5	14
19472	2019-12-21 02:03:15	2019-12-21	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	209	delivery	5	48
19473	2019-12-21 02:24:10	2019-12-21	14	[{"id_menu":2,"count":1}]	7475	delivery	5	19
19474	2019-12-21 02:40:33	2019-12-21	17	[{"id_menu":4,"count":1}]	381	pick-up	0	17
19475	2019-12-21 02:55:25	2019-12-21	12	[{"id_menu":3,"count":1}]	7523	delivery	5	17
19476	2019-12-21 03:10:07	2019-12-21	12	[{"id_menu":1,"count":1}]	7084	pick-up	0	12
19477	2019-12-21 03:12:27	2019-12-21	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7469	delivery	5	35
19478	2019-12-21 03:29:53	2019-12-21	17	[{"id_menu":4,"count":1}]	2752	pick-up	0	17
19479	2019-12-21 03:37:15	2019-12-21	9	[{"id_menu":6,"count":1}]	6296	delivery	5	14
19480	2019-12-21 03:38:17	2019-12-21	14	[{"id_menu":2,"count":1}]	7517	pick-up	0	14
19481	2019-12-21 03:42:36	2019-12-21	14	[{"id_menu":2,"count":1}]	1061	pick-up	0	14
19482	2019-12-21 03:46:21	2019-12-21	12	[{"id_menu":3,"count":1}]	7459	delivery	5	17
19483	2019-12-21 03:46:59	2019-12-21	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	3268	delivery	5	37
19484	2019-12-21 03:49:27	2019-12-21	12	[{"id_menu":3,"count":1}]	6961	delivery	5	17
19485	2019-12-21 04:09:08	2019-12-21	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7511	delivery	5	44
19486	2019-12-21 04:23:00	2019-12-21	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	6778	delivery	5	26
19487	2019-12-21 04:43:27	2019-12-21	8	[{"id_menu":5,"count":1}]	7460	delivery	5	13
19488	2019-12-21 04:44:57	2019-12-21	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	7528	delivery	5	27
19489	2019-12-21 04:47:20	2019-12-21	12	[{"id_menu":3,"count":1}]	2798	delivery	5	17
19490	2019-12-21 05:04:24	2019-12-21	9	[{"id_menu":7,"count":1}]	7463	pick-up	0	9
19491	2019-12-21 05:09:59	2019-12-21	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7444	delivery	5	43
19492	2019-12-21 05:10:49	2019-12-21	12	[{"id_menu":1,"count":1}]	7491	delivery	5	17
19493	2019-12-21 05:29:02	2019-12-21	9	[{"id_menu":6,"count":1}]	5872	delivery	5	14
19494	2019-12-21 05:35:21	2019-12-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	7503	delivery	5	22
19495	2019-12-21 05:41:04	2019-12-21	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7485	delivery	5	42
19496	2019-12-21 05:52:04	2019-12-21	9	[{"id_menu":7,"count":1}]	7455	delivery	5	14
19497	2019-12-21 06:00:45	2019-12-21	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	3052	pick-up	0	22
19498	2019-12-21 06:07:19	2019-12-21	9	[{"id_menu":7,"count":1}]	1592	pick-up	0	9
19499	2019-12-21 06:08:25	2019-12-21	9	[{"id_menu":7,"count":1}]	7474	delivery	5	14
19500	2019-12-21 06:11:40	2019-12-21	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	7442	delivery	5	30
19501	2019-12-21 06:14:12	2019-12-21	14	[{"id_menu":2,"count":1}]	5866	delivery	5	19
19502	2019-12-21 06:37:34	2019-12-21	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	7500	delivery	5	25
19503	2019-12-21 06:50:04	2019-12-21	17	[{"id_menu":4,"count":1}]	6410	pick-up	0	17
19504	2019-12-21 07:00:23	2019-12-21	14	[{"id_menu":2,"count":1}]	5799	delivery	5	19
19505	2019-12-21 07:03:18	2019-12-21	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1954	delivery	5	39
19506	2019-12-21 07:05:51	2019-12-21	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6954	delivery	5	35
19507	2019-12-21 07:06:43	2019-12-21	9	[{"id_menu":6,"count":1}]	485	delivery	5	14
19508	2019-12-21 07:13:49	2019-12-21	9	[{"id_menu":6,"count":1}]	2573	delivery	5	14
19509	2019-12-21 07:21:37	2019-12-21	12	[{"id_menu":3,"count":1}]	4872	pick-up	0	12
19510	2019-12-21 07:26:58	2019-12-21	9	[{"id_menu":6,"count":1}]	304	delivery	5	14
19511	2019-12-21 07:28:28	2019-12-21	8	[{"id_menu":5,"count":1}]	5189	pick-up	0	8
19512	2019-12-21 07:38:35	2019-12-21	9	[{"id_menu":7,"count":1}]	6482	delivery	5	14
19513	2019-12-21 08:00:04	2019-12-21	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	7514	delivery	5	31
19514	2019-12-21 08:03:41	2019-12-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7478	pick-up	0	17
19515	2019-12-21 08:08:20	2019-12-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3568	delivery	5	28
19516	2019-12-21 08:12:23	2019-12-21	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2592	pick-up	0	26
19517	2019-12-21 08:24:10	2019-12-21	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	7477	delivery	5	43
19518	2019-12-21 08:27:14	2019-12-21	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	7457	delivery	5	26
19519	2019-12-21 08:28:46	2019-12-21	9	[{"id_menu":7,"count":1}]	7449	delivery	5	14
19520	2019-12-21 08:30:58	2019-12-21	12	[{"id_menu":1,"count":1}]	2113	pick-up	0	12
19521	2019-12-21 08:32:12	2019-12-21	14	[{"id_menu":2,"count":1}]	2076	pick-up	0	14
19522	2019-12-21 08:41:57	2019-12-21	12	[{"id_menu":3,"count":1}]	2173	delivery	5	17
19523	2019-12-21 08:51:54	2019-12-21	8	[{"id_menu":5,"count":1}]	5643	pick-up	0	8
19524	2019-12-21 08:55:36	2019-12-21	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2190	pick-up	0	35
19525	2019-12-21 09:01:38	2019-12-21	9	[{"id_menu":6,"count":1}]	7496	pick-up	0	9
19526	2019-12-21 09:02:30	2019-12-21	12	[{"id_menu":1,"count":1}]	7502	pick-up	0	12
19527	2019-12-21 09:08:34	2019-12-21	17	[{"id_menu":4,"count":1}]	5942	delivery	5	22
19528	2019-12-21 09:19:11	2019-12-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":3}]	3726	delivery	5	31
19529	2019-12-21 09:21:17	2019-12-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	865	pick-up	0	26
19530	2019-12-21 09:28:04	2019-12-21	12	[{"id_menu":1,"count":1}]	5901	delivery	5	17
19531	2019-12-21 09:34:34	2019-12-21	9	[{"id_menu":6,"count":1}]	6565	pick-up	0	9
19532	2019-12-21 09:47:31	2019-12-21	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7520	delivery	5	34
19533	2019-12-21 10:03:52	2019-12-21	12	[{"id_menu":1,"count":1}]	7524	delivery	5	17
19534	2019-12-21 10:04:40	2019-12-21	9	[{"id_menu":7,"count":1}]	7476	delivery	5	14
19535	2019-12-21 10:09:40	2019-12-21	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	5811	pick-up	0	31
19536	2019-12-21 10:12:49	2019-12-21	9	[{"id_menu":6,"count":1}]	7462	delivery	5	14
19537	2019-12-21 10:19:15	2019-12-21	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7211	delivery	5	34
19538	2019-12-21 10:21:12	2019-12-21	9	[{"id_menu":6,"count":1}]	7451	delivery	5	14
19539	2019-12-21 10:28:14	2019-12-21	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2183	delivery	5	26
19540	2019-12-21 10:40:06	2019-12-21	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1316	pick-up	0	34
19541	2019-12-21 10:44:35	2019-12-21	9	[{"id_menu":7,"count":1}]	7494	delivery	5	14
19542	2019-12-21 10:52:16	2019-12-21	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	7482	delivery	5	40
19543	2019-12-21 10:52:38	2019-12-21	8	[{"id_menu":5,"count":1}]	7465	pick-up	0	8
19544	2019-12-21 10:52:45	2019-12-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	401	pick-up	0	26
19545	2019-12-21 10:54:20	2019-12-21	12	[{"id_menu":3,"count":1}]	7510	pick-up	0	12
19546	2019-12-21 11:02:19	2019-12-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6536	delivery	5	31
19547	2019-12-21 11:17:56	2019-12-21	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7483	delivery	5	37
19548	2019-12-21 11:22:25	2019-12-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	151	pick-up	0	26
19549	2019-12-21 11:24:14	2019-12-21	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7223	delivery	5	40
19550	2019-12-21 11:37:47	2019-12-21	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	4527	delivery	5	25
19551	2019-12-21 11:39:26	2019-12-21	9	[{"id_menu":6,"count":1}]	7506	delivery	5	14
19552	2019-12-21 11:39:32	2019-12-21	12	[{"id_menu":3,"count":1}]	5824	pick-up	0	12
19553	2019-12-21 11:47:14	2019-12-21	12	[{"id_menu":1,"count":1}]	1862	pick-up	0	12
19554	2019-12-21 11:47:33	2019-12-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7507	pick-up	0	18
19555	2019-12-21 11:50:26	2019-12-21	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	7490	delivery	5	34
19556	2019-12-21 12:10:56	2019-12-21	8	[{"id_menu":5,"count":1}]	2951	delivery	5	13
19557	2019-12-21 12:11:55	2019-12-21	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7509	delivery	5	39
19558	2019-12-21 12:35:11	2019-12-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	7471	delivery	5	22
19559	2019-12-21 12:48:59	2019-12-21	12	[{"id_menu":3,"count":1}]	4161	delivery	5	17
19560	2019-12-21 12:52:33	2019-12-21	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":2}]	7470	delivery	5	31
19561	2019-12-21 12:52:33	2019-12-21	12	[{"id_menu":3,"count":1}]	7516	pick-up	0	12
19562	2019-12-21 13:01:11	2019-12-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5596	delivery	5	23
19563	2019-12-21 13:11:04	2019-12-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1269	pick-up	0	23
19564	2019-12-21 13:11:40	2019-12-21	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	2743	delivery	5	36
19565	2019-12-21 13:16:12	2019-12-21	9	[{"id_menu":6,"count":1}]	7448	delivery	5	14
19566	2019-12-21 13:21:35	2019-12-21	17	[{"id_menu":4,"count":1}]	5941	pick-up	0	17
19567	2019-12-21 13:27:45	2019-12-21	12	[{"id_menu":3,"count":1}]	2282	delivery	5	17
19568	2019-12-21 13:29:27	2019-12-21	12	[{"id_menu":1,"count":1}]	7128	pick-up	0	12
19569	2019-12-21 13:33:48	2019-12-21	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7499	delivery	5	49
19570	2019-12-21 13:35:27	2019-12-21	9	[{"id_menu":6,"count":1}]	2572	pick-up	0	9
19571	2019-12-21 13:39:15	2019-12-21	14	[{"id_menu":2,"count":1}]	92	pick-up	0	14
19572	2019-12-21 13:44:27	2019-12-21	12	[{"id_menu":1,"count":1}]	2894	delivery	5	17
19573	2019-12-21 13:46:41	2019-12-21	9	[{"id_menu":6,"count":1}]	7515	delivery	5	14
19574	2019-12-21 13:49:48	2019-12-21	12	[{"id_menu":1,"count":1}]	1682	pick-up	0	12
19575	2019-12-21 14:03:44	2019-12-21	14	[{"id_menu":2,"count":1}]	3859	delivery	5	19
19576	2019-12-21 14:07:16	2019-12-21	12	[{"id_menu":1,"count":1}]	1526	pick-up	0	12
19577	2019-12-21 14:39:33	2019-12-21	8	[{"id_menu":5,"count":1}]	6901	pick-up	0	8
19578	2019-12-21 14:53:19	2019-12-21	8	[{"id_menu":5,"count":1}]	7488	delivery	5	13
19579	2019-12-21 14:57:38	2019-12-21	12	[{"id_menu":1,"count":1}]	7480	pick-up	0	12
19580	2019-12-21 15:00:11	2019-12-21	9	[{"id_menu":7,"count":1}]	6202	pick-up	0	9
19581	2019-12-21 15:29:31	2019-12-21	9	[{"id_menu":6,"count":1}]	7519	delivery	5	14
19582	2019-12-21 15:31:14	2019-12-21	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7464	delivery	5	43
19583	2019-12-21 15:31:37	2019-12-21	8	[{"id_menu":5,"count":1}]	7486	delivery	5	13
19584	2019-12-21 15:41:44	2019-12-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7525	delivery	5	22
19585	2019-12-21 15:45:39	2019-12-21	9	[{"id_menu":7,"count":2}]	2739	pick-up	0	9
19586	2019-12-21 15:57:29	2019-12-21	9	[{"id_menu":6,"count":2}]	3436	delivery	5	14
19587	2019-12-21 16:03:26	2019-12-21	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	173	pick-up	0	41
19588	2019-12-21 16:25:14	2019-12-21	9	[{"id_menu":7,"count":1}]	7189	delivery	5	14
19589	2019-12-21 16:30:15	2019-12-21	9	[{"id_menu":7,"count":1}]	7445	pick-up	0	9
19590	2019-12-21 16:37:45	2019-12-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7513	delivery	5	23
19591	2019-12-21 16:53:45	2019-12-21	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6219	delivery	5	51
19592	2019-12-21 17:09:02	2019-12-21	14	[{"id_menu":2,"count":1}]	7522	delivery	5	19
19593	2019-12-21 17:23:49	2019-12-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	7484	delivery	5	22
19594	2019-12-21 17:32:26	2019-12-21	12	[{"id_menu":1,"count":1}]	2386	delivery	5	17
19595	2019-12-21 17:34:31	2019-12-21	12	[{"id_menu":3,"count":1}]	6950	delivery	5	17
19596	2019-12-21 17:44:26	2019-12-21	14	[{"id_menu":2,"count":1}]	2897	delivery	5	19
19597	2019-12-21 18:07:14	2019-12-21	39	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4429	delivery	5	44
19598	2019-12-21 18:07:22	2019-12-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	7453	delivery	5	28
19599	2019-12-21 18:08:41	2019-12-21	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1627	delivery	5	31
19600	2019-12-21 18:28:46	2019-12-21	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	7447	delivery	5	38
19601	2019-12-21 18:45:44	2019-12-21	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	7467	delivery	5	34
19602	2019-12-21 18:45:49	2019-12-21	9	[{"id_menu":7,"count":1}]	7458	delivery	5	14
19603	2019-12-21 18:46:25	2019-12-21	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	7468	delivery	5	26
19604	2019-12-21 18:53:13	2019-12-21	12	[{"id_menu":1,"count":1}]	5839	pick-up	0	12
19605	2019-12-21 18:58:19	2019-12-21	12	[{"id_menu":1,"count":1}]	3902	delivery	5	17
19606	2019-12-21 18:59:05	2019-12-21	12	[{"id_menu":1,"count":1}]	2556	pick-up	0	12
19607	2019-12-21 19:00:53	2019-12-21	12	[{"id_menu":1,"count":1}]	7521	delivery	5	17
19608	2019-12-21 19:02:11	2019-12-21	8	[{"id_menu":5,"count":1}]	7450	delivery	5	13
19609	2019-12-21 19:02:39	2019-12-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7508	delivery	5	22
19610	2019-12-21 19:16:15	2019-12-21	12	[{"id_menu":1,"count":1}]	7512	delivery	5	17
19611	2019-12-21 19:17:14	2019-12-21	9	[{"id_menu":6,"count":1}]	1260	delivery	5	14
19612	2019-12-21 19:26:36	2019-12-21	12	[{"id_menu":1,"count":1}]	7083	pick-up	0	12
19613	2019-12-21 19:26:46	2019-12-21	17	[{"id_menu":4,"count":1}]	7527	pick-up	0	17
19614	2019-12-21 19:26:52	2019-12-21	9	[{"id_menu":7,"count":1}]	4671	delivery	5	14
19615	2019-12-21 19:32:35	2019-12-21	12	[{"id_menu":3,"count":1}]	7493	pick-up	0	12
19616	2019-12-21 19:34:36	2019-12-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1010	pick-up	0	18
19617	2019-12-21 19:36:21	2019-12-21	12	[{"id_menu":1,"count":1}]	6173	pick-up	0	12
19618	2019-12-21 19:39:06	2019-12-21	9	[{"id_menu":7,"count":1}]	7456	delivery	5	14
19619	2019-12-21 19:51:14	2019-12-21	9	[{"id_menu":6,"count":1}]	4138	delivery	5	14
19620	2019-12-21 20:07:27	2019-12-21	9	[{"id_menu":6,"count":1}]	1529	pick-up	0	9
19621	2019-12-21 20:08:35	2019-12-21	9	[{"id_menu":7,"count":2}]	7529	delivery	5	14
19622	2019-12-21 20:25:01	2019-12-21	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5928	delivery	5	57
19623	2019-12-21 20:26:12	2019-12-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	227	delivery	5	22
19624	2019-12-21 20:32:06	2019-12-21	9	[{"id_menu":6,"count":1}]	7497	delivery	5	14
19625	2019-12-21 20:48:40	2019-12-21	9	[{"id_menu":7,"count":1}]	3180	pick-up	0	9
19626	2019-12-21 20:55:30	2019-12-21	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4714	pick-up	0	48
19627	2019-12-21 21:00:25	2019-12-21	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	7472	delivery	5	34
19628	2019-12-21 21:03:44	2019-12-21	9	[{"id_menu":7,"count":1}]	7466	delivery	5	14
19629	2019-12-21 21:05:12	2019-12-21	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	993	pick-up	0	21
19630	2019-12-21 21:09:08	2019-12-21	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1788	pick-up	0	26
19631	2019-12-21 21:18:23	2019-12-21	12	[{"id_menu":1,"count":1}]	491	delivery	5	17
19632	2019-12-21 21:26:09	2019-12-21	12	[{"id_menu":3,"count":1}]	7505	pick-up	0	12
19633	2019-12-21 21:29:12	2019-12-21	9	[{"id_menu":7,"count":1}]	640	delivery	5	14
19634	2019-12-21 21:40:41	2019-12-21	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3502	delivery	5	54
19768	2019-12-22 12:02:05	2019-12-22	12	[{"id_menu":3,"count":1}]	7537	pick-up	0	12
19635	2019-12-21 21:46:51	2019-12-21	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	4824	delivery	5	35
19636	2019-12-21 21:54:12	2019-12-21	14	[{"id_menu":2,"count":1}]	5310	pick-up	0	14
19637	2019-12-21 22:01:58	2019-12-21	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2526	pick-up	0	29
19638	2019-12-21 22:04:05	2019-12-21	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":2}]	7338	delivery	5	28
19639	2019-12-21 22:10:04	2019-12-21	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	7492	delivery	5	26
19640	2019-12-21 22:32:08	2019-12-21	12	[{"id_menu":1,"count":1}]	2651	delivery	5	17
19641	2019-12-21 22:56:07	2019-12-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7134	delivery	5	22
19642	2019-12-21 23:03:31	2019-12-21	12	[{"id_menu":1,"count":1}]	357	delivery	5	17
19643	2019-12-21 23:07:06	2019-12-21	8	[{"id_menu":5,"count":1}]	1329	pick-up	0	8
19644	2019-12-21 23:17:17	2019-12-21	17	[{"id_menu":4,"count":1}]	7443	delivery	5	22
19645	2019-12-21 23:26:01	2019-12-21	17	[{"id_menu":4,"count":1}]	7504	pick-up	0	17
19646	2019-12-21 23:38:30	2019-12-21	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	3444	pick-up	0	26
19647	2019-12-21 23:40:13	2019-12-21	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	7495	pick-up	0	21
19648	2019-12-21 23:41:04	2019-12-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7481	pick-up	0	17
19649	2019-12-21 23:41:14	2019-12-21	12	[{"id_menu":3,"count":1}]	5558	delivery	5	17
19650	2019-12-21 23:45:47	2019-12-21	9	[{"id_menu":7,"count":1}]	7479	delivery	5	14
19651	2019-12-21 23:48:03	2019-12-21	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":2}]	7526	delivery	5	25
19652	2019-12-22 00:00:13	2019-12-22	12	[{"id_menu":3,"count":1}]	1810	pick-up	0	12
19653	2019-12-22 00:04:29	2019-12-22	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2252	pick-up	0	17
19654	2019-12-22 00:08:55	2019-12-22	9	[{"id_menu":7,"count":1}]	7533	delivery	5	14
19655	2019-12-22 00:11:04	2019-12-22	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3343	delivery	5	45
19656	2019-12-22 00:11:36	2019-12-22	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	903	pick-up	0	29
19657	2019-12-22 00:11:40	2019-12-22	9	[{"id_menu":7,"count":1}]	7557	delivery	5	14
19658	2019-12-22 00:17:39	2019-12-22	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3073	pick-up	0	26
19659	2019-12-22 00:27:28	2019-12-22	17	[{"id_menu":4,"count":1}]	7587	delivery	5	22
19660	2019-12-22 00:34:29	2019-12-22	12	[{"id_menu":1,"count":1}]	1374	delivery	5	17
19661	2019-12-22 00:45:51	2019-12-22	12	[{"id_menu":3,"count":1}]	3931	pick-up	0	12
19662	2019-12-22 00:50:16	2019-12-22	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6802	delivery	5	22
19663	2019-12-22 00:51:31	2019-12-22	9	[{"id_menu":7,"count":1}]	5909	delivery	5	14
19664	2019-12-22 00:54:38	2019-12-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	117	pick-up	0	23
19665	2019-12-22 00:58:01	2019-12-22	9	[{"id_menu":6,"count":1}]	7553	delivery	5	14
19666	2019-12-22 01:00:16	2019-12-22	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6377	delivery	5	31
19667	2019-12-22 01:03:34	2019-12-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6878	delivery	5	36
19668	2019-12-22 01:07:18	2019-12-22	12	[{"id_menu":1,"count":1}]	7551	delivery	5	17
19669	2019-12-22 01:17:36	2019-12-22	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7597	delivery	5	37
19670	2019-12-22 01:25:19	2019-12-22	12	[{"id_menu":3,"count":1}]	7598	delivery	5	17
19671	2019-12-22 01:31:22	2019-12-22	12	[{"id_menu":1,"count":1}]	2434	pick-up	0	12
19672	2019-12-22 01:33:28	2019-12-22	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	6769	pick-up	0	39
19673	2019-12-22 01:35:23	2019-12-22	17	[{"id_menu":4,"count":1}]	3647	pick-up	0	17
19674	2019-12-22 01:38:46	2019-12-22	12	[{"id_menu":1,"count":1}]	2928	pick-up	0	12
19675	2019-12-22 01:42:13	2019-12-22	17	[{"id_menu":4,"count":1}]	1526	pick-up	0	17
19676	2019-12-22 01:54:26	2019-12-22	17	[{"id_menu":4,"count":1}]	3072	pick-up	0	17
19677	2019-12-22 01:58:02	2019-12-22	8	[{"id_menu":5,"count":1}]	4935	delivery	5	13
19678	2019-12-22 02:08:38	2019-12-22	43	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3883	delivery	5	48
19679	2019-12-22 02:09:40	2019-12-22	9	[{"id_menu":7,"count":1}]	6092	pick-up	0	9
19680	2019-12-22 02:24:55	2019-12-22	8	[{"id_menu":5,"count":1}]	4818	delivery	5	13
19681	2019-12-22 02:26:32	2019-12-22	12	[{"id_menu":1,"count":1}]	6182	delivery	5	17
19682	2019-12-22 02:40:19	2019-12-22	17	[{"id_menu":4,"count":1}]	7159	delivery	5	22
19683	2019-12-22 02:43:44	2019-12-22	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7567	delivery	5	43
19684	2019-12-22 02:47:54	2019-12-22	17	[{"id_menu":4,"count":1}]	204	delivery	5	22
19685	2019-12-22 02:48:27	2019-12-22	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	7541	delivery	5	34
19686	2019-12-22 02:56:44	2019-12-22	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	4425	delivery	5	31
19687	2019-12-22 02:59:07	2019-12-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1118	delivery	5	28
19688	2019-12-22 03:03:04	2019-12-22	14	[{"id_menu":2,"count":1}]	236	pick-up	0	14
19689	2019-12-22 03:18:55	2019-12-22	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":2}]	7564	delivery	5	28
19690	2019-12-22 03:30:24	2019-12-22	9	[{"id_menu":7,"count":1}]	2217	pick-up	0	9
19691	2019-12-22 03:35:44	2019-12-22	14	[{"id_menu":2,"count":1}]	818	delivery	5	19
19692	2019-12-22 03:36:14	2019-12-22	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	7568	delivery	5	40
19693	2019-12-22 03:37:06	2019-12-22	9	[{"id_menu":6,"count":1}]	709	pick-up	0	9
19694	2019-12-22 03:39:31	2019-12-22	14	[{"id_menu":2,"count":1}]	7596	delivery	5	19
19695	2019-12-22 03:44:49	2019-12-22	8	[{"id_menu":5,"count":1}]	7571	pick-up	0	8
19696	2019-12-22 03:58:54	2019-12-22	9	[{"id_menu":6,"count":1}]	7595	pick-up	0	9
19697	2019-12-22 04:00:33	2019-12-22	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	5234	delivery	5	34
19698	2019-12-22 04:07:54	2019-12-22	9	[{"id_menu":6,"count":1}]	7560	delivery	5	14
19699	2019-12-22 04:08:14	2019-12-22	8	[{"id_menu":5,"count":1}]	5648	pick-up	0	8
19700	2019-12-22 04:11:30	2019-12-22	12	[{"id_menu":1,"count":1}]	7554	pick-up	0	12
19701	2019-12-22 04:27:29	2019-12-22	12	[{"id_menu":3,"count":1}]	7177	pick-up	0	12
19702	2019-12-22 04:28:30	2019-12-22	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2326	pick-up	0	32
19703	2019-12-22 04:37:43	2019-12-22	14	[{"id_menu":2,"count":1}]	2523	pick-up	0	14
19704	2019-12-22 04:41:07	2019-12-22	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	7590	pick-up	0	20
19705	2019-12-22 05:30:40	2019-12-22	12	[{"id_menu":3,"count":1}]	1926	pick-up	0	12
19706	2019-12-22 05:31:57	2019-12-22	9	[{"id_menu":7,"count":1}]	2994	delivery	5	14
19707	2019-12-22 05:35:39	2019-12-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6232	pick-up	0	23
19708	2019-12-22 05:37:15	2019-12-22	12	[{"id_menu":3,"count":1}]	7574	pick-up	0	12
19709	2019-12-22 05:43:00	2019-12-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7600	delivery	5	22
19710	2019-12-22 05:45:20	2019-12-22	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	4320	delivery	5	26
19711	2019-12-22 05:46:48	2019-12-22	8	[{"id_menu":5,"count":1}]	7577	delivery	5	13
19712	2019-12-22 05:55:56	2019-12-22	9	[{"id_menu":6,"count":1}]	1523	delivery	5	14
19713	2019-12-22 05:58:03	2019-12-22	14	[{"id_menu":2,"count":1}]	2956	pick-up	0	14
19714	2019-12-22 06:12:45	2019-12-22	9	[{"id_menu":6,"count":1}]	7580	delivery	5	14
19715	2019-12-22 06:15:22	2019-12-22	17	[{"id_menu":4,"count":1}]	5423	delivery	5	22
19716	2019-12-22 06:24:10	2019-12-22	14	[{"id_menu":2,"count":1}]	2561	pick-up	0	14
19717	2019-12-22 06:24:44	2019-12-22	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7570	delivery	5	43
19718	2019-12-22 06:41:52	2019-12-22	9	[{"id_menu":6,"count":1}]	7581	delivery	5	14
19719	2019-12-22 06:44:10	2019-12-22	17	[{"id_menu":4,"count":1}]	1053	pick-up	0	17
19720	2019-12-22 06:54:44	2019-12-22	9	[{"id_menu":7,"count":1}]	7561	delivery	5	14
19721	2019-12-22 06:55:31	2019-12-22	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1781	pick-up	0	32
19722	2019-12-22 07:00:33	2019-12-22	17	[{"id_menu":4,"count":1}]	1697	pick-up	0	17
19723	2019-12-22 07:15:41	2019-12-22	8	[{"id_menu":5,"count":1}]	7602	delivery	5	13
19724	2019-12-22 07:34:56	2019-12-22	12	[{"id_menu":1,"count":1}]	7549	delivery	5	17
19725	2019-12-22 07:55:29	2019-12-22	9	[{"id_menu":7,"count":1}]	5149	pick-up	0	9
19726	2019-12-22 07:58:39	2019-12-22	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5877	delivery	5	42
19727	2019-12-22 07:59:39	2019-12-22	12	[{"id_menu":1,"count":2}]	6933	delivery	5	17
19728	2019-12-22 08:02:55	2019-12-22	17	[{"id_menu":5,"count":3},{"id_menu":6,"count":1}]	7592	delivery	5	22
19729	2019-12-22 08:20:30	2019-12-22	9	[{"id_menu":6,"count":1}]	7315	delivery	5	14
19730	2019-12-22 08:27:40	2019-12-22	8	[{"id_menu":5,"count":2}]	3119	delivery	5	13
19731	2019-12-22 08:32:10	2019-12-22	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7594	delivery	5	31
19732	2019-12-22 08:32:34	2019-12-22	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3332	pick-up	0	43
19733	2019-12-22 08:35:35	2019-12-22	12	[{"id_menu":3,"count":1}]	5402	delivery	5	17
19734	2019-12-22 08:40:28	2019-12-22	9	[{"id_menu":6,"count":1}]	7200	pick-up	0	9
19735	2019-12-22 08:52:34	2019-12-22	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	5924	delivery	5	26
19736	2019-12-22 08:57:11	2019-12-22	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	5192	delivery	5	34
19737	2019-12-22 09:19:38	2019-12-22	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	184	pick-up	0	35
19738	2019-12-22 09:22:13	2019-12-22	8	[{"id_menu":5,"count":1}]	3170	delivery	5	13
19739	2019-12-22 09:22:47	2019-12-22	41	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	6711	pick-up	0	41
19740	2019-12-22 09:33:41	2019-12-22	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	3005	pick-up	0	38
19741	2019-12-22 09:36:14	2019-12-22	9	[{"id_menu":7,"count":1}]	7556	pick-up	0	9
19742	2019-12-22 09:38:08	2019-12-22	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2455	pick-up	0	44
19743	2019-12-22 09:42:27	2019-12-22	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	7572	pick-up	0	20
19744	2019-12-22 09:48:41	2019-12-22	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	5738	delivery	5	31
19745	2019-12-22 09:51:01	2019-12-22	8	[{"id_menu":5,"count":2}]	511	delivery	5	13
19746	2019-12-22 10:00:00	2019-12-22	9	[{"id_menu":7,"count":1}]	1462	pick-up	0	9
19747	2019-12-22 10:06:43	2019-12-22	9	[{"id_menu":6,"count":1}]	3968	delivery	5	14
19748	2019-12-22 10:23:16	2019-12-22	14	[{"id_menu":2,"count":1}]	270	pick-up	0	14
19749	2019-12-22 10:30:48	2019-12-22	12	[{"id_menu":1,"count":1}]	437	delivery	5	17
19750	2019-12-22 10:34:56	2019-12-22	12	[{"id_menu":3,"count":1}]	1563	delivery	5	17
19751	2019-12-22 10:39:49	2019-12-22	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	7593	pick-up	0	21
19752	2019-12-22 10:42:17	2019-12-22	14	[{"id_menu":2,"count":1}]	208	pick-up	0	14
19753	2019-12-22 11:02:12	2019-12-22	9	[{"id_menu":6,"count":1}]	2951	delivery	5	14
19754	2019-12-22 11:03:13	2019-12-22	12	[{"id_menu":3,"count":1}]	5322	delivery	5	17
19755	2019-12-22 11:09:27	2019-12-22	9	[{"id_menu":7,"count":1}]	2627	pick-up	0	9
19756	2019-12-22 11:14:42	2019-12-22	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	7532	delivery	5	31
19757	2019-12-22 11:20:48	2019-12-22	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	7579	delivery	5	25
19758	2019-12-22 11:23:22	2019-12-22	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1834	pick-up	0	29
19759	2019-12-22 11:31:22	2019-12-22	8	[{"id_menu":5,"count":1}]	252	pick-up	0	8
19760	2019-12-22 11:35:30	2019-12-22	12	[{"id_menu":3,"count":2}]	7540	delivery	5	17
19761	2019-12-22 11:42:26	2019-12-22	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3898	delivery	5	57
19762	2019-12-22 11:42:30	2019-12-22	12	[{"id_menu":3,"count":2}]	1681	pick-up	0	12
19763	2019-12-22 11:43:27	2019-12-22	9	[{"id_menu":6,"count":1}]	6115	delivery	5	14
19764	2019-12-22 11:45:29	2019-12-22	14	[{"id_menu":2,"count":1}]	2562	pick-up	0	14
19765	2019-12-22 11:48:06	2019-12-22	17	[{"id_menu":4,"count":1}]	856	delivery	5	22
19766	2019-12-22 11:59:38	2019-12-22	12	[{"id_menu":3,"count":1}]	7538	delivery	5	17
19767	2019-12-22 12:00:12	2019-12-22	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	7545	delivery	5	31
19769	2019-12-22 12:06:15	2019-12-22	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	6385	pick-up	0	35
19770	2019-12-22 12:29:28	2019-12-22	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	3026	delivery	5	30
19771	2019-12-22 12:34:42	2019-12-22	12	[{"id_menu":1,"count":1}]	7539	pick-up	0	12
19772	2019-12-22 12:39:08	2019-12-22	9	[{"id_menu":7,"count":1}]	5259	pick-up	0	9
19773	2019-12-22 12:39:44	2019-12-22	12	[{"id_menu":1,"count":1}]	1271	pick-up	0	12
19774	2019-12-22 12:42:01	2019-12-22	9	[{"id_menu":6,"count":1}]	197	pick-up	0	9
19775	2019-12-22 12:47:40	2019-12-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4981	pick-up	0	23
19776	2019-12-22 13:07:05	2019-12-22	9	[{"id_menu":7,"count":1}]	352	pick-up	0	9
19777	2019-12-22 13:15:02	2019-12-22	14	[{"id_menu":2,"count":1}]	7565	delivery	5	19
19778	2019-12-22 13:17:46	2019-12-22	9	[{"id_menu":7,"count":2}]	3851	pick-up	0	9
19779	2019-12-22 13:18:08	2019-12-22	9	[{"id_menu":6,"count":1}]	7483	delivery	5	14
19780	2019-12-22 13:24:06	2019-12-22	8	[{"id_menu":5,"count":1}]	7569	delivery	5	13
19781	2019-12-22 13:36:12	2019-12-22	9	[{"id_menu":7,"count":1}]	2519	pick-up	0	9
19782	2019-12-22 13:55:10	2019-12-22	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	7547	delivery	5	31
19783	2019-12-22 13:56:33	2019-12-22	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7585	delivery	5	31
19784	2019-12-22 13:58:29	2019-12-22	14	[{"id_menu":2,"count":1}]	4114	delivery	5	19
19785	2019-12-22 14:10:26	2019-12-22	9	[{"id_menu":7,"count":1}]	7546	pick-up	0	9
19786	2019-12-22 14:12:13	2019-12-22	14	[{"id_menu":2,"count":1}]	3948	pick-up	0	14
19787	2019-12-22 14:16:10	2019-12-22	9	[{"id_menu":6,"count":1}]	3509	pick-up	0	9
19788	2019-12-22 14:20:54	2019-12-22	8	[{"id_menu":5,"count":1}]	5952	delivery	5	13
19789	2019-12-22 14:24:58	2019-12-22	9	[{"id_menu":7,"count":1}]	6194	delivery	5	14
19790	2019-12-22 14:32:08	2019-12-22	9	[{"id_menu":7,"count":1}]	2311	pick-up	0	9
19791	2019-12-22 14:44:30	2019-12-22	14	[{"id_menu":2,"count":1}]	5128	pick-up	0	14
19792	2019-12-22 14:44:50	2019-12-22	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	2083	pick-up	0	30
19793	2019-12-22 14:49:11	2019-12-22	9	[{"id_menu":6,"count":1}]	211	pick-up	0	9
19794	2019-12-22 14:51:00	2019-12-22	12	[{"id_menu":3,"count":1}]	4782	pick-up	0	12
19795	2019-12-22 15:03:54	2019-12-22	12	[{"id_menu":3,"count":1}]	5048	delivery	5	17
19796	2019-12-22 15:05:51	2019-12-22	9	[{"id_menu":7,"count":1}]	4986	pick-up	0	9
19797	2019-12-22 15:13:22	2019-12-22	12	[{"id_menu":3,"count":1}]	7543	delivery	5	17
19798	2019-12-22 15:14:39	2019-12-22	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	7559	delivery	5	35
19799	2019-12-22 15:17:24	2019-12-22	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	6283	delivery	5	26
19800	2019-12-22 15:27:14	2019-12-22	9	[{"id_menu":7,"count":1}]	7575	delivery	5	14
19801	2019-12-22 15:27:36	2019-12-22	9	[{"id_menu":7,"count":1}]	5526	delivery	5	14
19802	2019-12-22 15:28:51	2019-12-22	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	6150	delivery	5	40
19803	2019-12-22 15:29:30	2019-12-22	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	835	pick-up	0	25
19804	2019-12-22 15:29:48	2019-12-22	8	[{"id_menu":5,"count":1}]	2615	delivery	5	13
19805	2019-12-22 15:38:25	2019-12-22	9	[{"id_menu":7,"count":2}]	6296	delivery	5	14
19806	2019-12-22 15:42:33	2019-12-22	9	[{"id_menu":7,"count":1}]	7576	delivery	5	14
19807	2019-12-22 15:44:40	2019-12-22	8	[{"id_menu":5,"count":1}]	7582	delivery	5	13
19808	2019-12-22 16:09:34	2019-12-22	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7491	delivery	5	39
19809	2019-12-22 16:11:12	2019-12-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2244	pick-up	0	17
19810	2019-12-22 16:11:36	2019-12-22	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	601	pick-up	0	40
19811	2019-12-22 16:14:56	2019-12-22	8	[{"id_menu":5,"count":1}]	2050	pick-up	0	8
19812	2019-12-22 16:18:51	2019-12-22	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6009	delivery	5	43
19813	2019-12-22 16:19:05	2019-12-22	12	[{"id_menu":3,"count":1}]	5293	delivery	5	17
19814	2019-12-22 16:49:27	2019-12-22	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	5552	delivery	5	28
19815	2019-12-22 16:53:49	2019-12-22	9	[{"id_menu":6,"count":1}]	7535	delivery	5	14
19816	2019-12-22 17:07:42	2019-12-22	12	[{"id_menu":3,"count":1}]	5943	pick-up	0	12
19817	2019-12-22 17:13:10	2019-12-22	9	[{"id_menu":7,"count":1}]	1015	delivery	5	14
19818	2019-12-22 17:20:34	2019-12-22	12	[{"id_menu":1,"count":1}]	2228	delivery	5	17
19819	2019-12-22 17:23:49	2019-12-22	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7024	delivery	5	45
19820	2019-12-22 17:29:32	2019-12-22	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7534	delivery	5	43
19821	2019-12-22 17:31:28	2019-12-22	17	[{"id_menu":4,"count":1}]	3868	pick-up	0	17
19822	2019-12-22 17:32:04	2019-12-22	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	7211	delivery	5	43
19823	2019-12-22 17:32:53	2019-12-22	12	[{"id_menu":1,"count":1}]	2761	delivery	5	17
19824	2019-12-22 17:37:33	2019-12-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3102	delivery	5	28
19825	2019-12-22 17:38:54	2019-12-22	17	[{"id_menu":4,"count":1}]	2588	delivery	5	22
19826	2019-12-22 17:39:59	2019-12-22	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	3403	pick-up	0	26
19827	2019-12-22 17:42:24	2019-12-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	4072	pick-up	0	18
19828	2019-12-22 17:52:46	2019-12-22	17	[{"id_menu":4,"count":1}]	2004	pick-up	0	17
19829	2019-12-22 17:54:29	2019-12-22	17	[{"id_menu":4,"count":1}]	7558	delivery	5	22
19830	2019-12-22 18:00:01	2019-12-22	12	[{"id_menu":1,"count":1}]	1343	delivery	5	17
19831	2019-12-22 18:00:38	2019-12-22	17	[{"id_menu":4,"count":1}]	3884	delivery	5	22
19832	2019-12-22 18:07:43	2019-12-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7530	delivery	5	28
19833	2019-12-22 18:13:23	2019-12-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7583	delivery	5	28
19834	2019-12-22 18:15:26	2019-12-22	8	[{"id_menu":5,"count":1}]	7555	delivery	5	13
19835	2019-12-22 18:18:18	2019-12-22	9	[{"id_menu":6,"count":1}]	310	pick-up	0	9
19836	2019-12-22 18:18:37	2019-12-22	12	[{"id_menu":1,"count":1}]	1026	pick-up	0	12
19837	2019-12-22 18:30:22	2019-12-22	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7562	delivery	5	30
19838	2019-12-22 18:36:29	2019-12-22	9	[{"id_menu":6,"count":1}]	5818	delivery	5	14
19839	2019-12-22 18:39:32	2019-12-22	9	[{"id_menu":7,"count":1}]	7599	delivery	5	14
19840	2019-12-22 18:42:44	2019-12-22	17	[{"id_menu":4,"count":1}]	7531	delivery	5	22
19841	2019-12-22 18:52:39	2019-12-22	14	[{"id_menu":2,"count":1}]	1138	delivery	5	19
19842	2019-12-22 18:53:42	2019-12-22	12	[{"id_menu":3,"count":1}]	3382	delivery	5	17
19843	2019-12-22 18:56:08	2019-12-22	17	[{"id_menu":4,"count":1}]	629	pick-up	0	17
19844	2019-12-22 19:01:02	2019-12-22	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	719	pick-up	0	39
19845	2019-12-22 19:09:57	2019-12-22	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5384	pick-up	0	26
19846	2019-12-22 19:09:57	2019-12-22	9	[{"id_menu":6,"count":1}]	3537	delivery	5	14
19847	2019-12-22 19:22:00	2019-12-22	8	[{"id_menu":5,"count":2}]	260	delivery	5	13
19848	2019-12-22 19:26:11	2019-12-22	9	[{"id_menu":7,"count":1}]	7589	pick-up	0	9
19849	2019-12-22 19:37:19	2019-12-22	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	740	delivery	5	34
19850	2019-12-22 19:40:45	2019-12-22	9	[{"id_menu":6,"count":1}]	2920	pick-up	0	9
19851	2019-12-22 19:45:48	2019-12-22	14	[{"id_menu":2,"count":1}]	7552	pick-up	0	14
19852	2019-12-22 19:57:23	2019-12-22	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	2232	pick-up	0	23
19853	2019-12-22 19:58:38	2019-12-22	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	7548	delivery	5	23
19854	2019-12-22 20:00:44	2019-12-22	12	[{"id_menu":1,"count":1}]	149	delivery	5	17
19855	2019-12-22 20:19:19	2019-12-22	9	[{"id_menu":6,"count":1}]	6622	pick-up	0	9
19856	2019-12-22 20:20:43	2019-12-22	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7584	delivery	5	36
19857	2019-12-22 20:24:35	2019-12-22	9	[{"id_menu":7,"count":1}]	337	delivery	5	14
19858	2019-12-22 20:28:37	2019-12-22	17	[{"id_menu":4,"count":1}]	5772	delivery	5	22
19859	2019-12-22 20:38:57	2019-12-22	14	[{"id_menu":2,"count":1}]	7542	delivery	5	19
19860	2019-12-22 20:39:53	2019-12-22	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	7563	delivery	5	27
19861	2019-12-22 20:46:35	2019-12-22	9	[{"id_menu":6,"count":1}]	4959	pick-up	0	9
19862	2019-12-22 20:47:59	2019-12-22	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7544	delivery	5	31
19863	2019-12-22 21:06:37	2019-12-22	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7025	delivery	5	35
19864	2019-12-22 21:09:40	2019-12-22	9	[{"id_menu":7,"count":1}]	4561	delivery	5	14
19865	2019-12-22 21:10:07	2019-12-22	17	[{"id_menu":4,"count":1}]	7601	delivery	5	22
19866	2019-12-22 21:18:27	2019-12-22	12	[{"id_menu":1,"count":1}]	7550	pick-up	0	12
19867	2019-12-22 21:18:44	2019-12-22	12	[{"id_menu":1,"count":1}]	2954	pick-up	0	12
19868	2019-12-22 21:21:35	2019-12-22	9	[{"id_menu":6,"count":1}]	6255	delivery	5	14
19869	2019-12-22 21:25:43	2019-12-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	7536	delivery	5	23
19870	2019-12-22 21:40:55	2019-12-22	12	[{"id_menu":1,"count":1}]	5473	pick-up	0	12
19871	2019-12-22 21:56:22	2019-12-22	9	[{"id_menu":6,"count":1}]	7603	delivery	5	14
19872	2019-12-22 21:57:53	2019-12-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7586	delivery	5	36
19873	2019-12-22 22:10:31	2019-12-22	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4983	delivery	5	43
19874	2019-12-22 22:22:28	2019-12-22	9	[{"id_menu":6,"count":1}]	6600	pick-up	0	9
19875	2019-12-22 22:32:12	2019-12-22	9	[{"id_menu":6,"count":1}]	1659	pick-up	0	9
19876	2019-12-22 22:35:52	2019-12-22	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7306	pick-up	0	32
19877	2019-12-22 22:36:01	2019-12-22	12	[{"id_menu":1,"count":1}]	2534	pick-up	0	12
19878	2019-12-22 22:39:00	2019-12-22	12	[{"id_menu":1,"count":1}]	2572	pick-up	0	12
19879	2019-12-22 22:49:43	2019-12-22	9	[{"id_menu":7,"count":1}]	6634	pick-up	0	9
19880	2019-12-22 23:18:26	2019-12-22	14	[{"id_menu":2,"count":2}]	3609	pick-up	0	14
19881	2019-12-22 23:18:39	2019-12-22	12	[{"id_menu":3,"count":1}]	7588	delivery	5	17
19882	2019-12-22 23:19:44	2019-12-22	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7578	delivery	5	44
19883	2019-12-22 23:27:41	2019-12-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	2546	delivery	5	28
19884	2019-12-22 23:28:44	2019-12-22	9	[{"id_menu":7,"count":1}]	7591	delivery	5	14
19885	2019-12-22 23:34:11	2019-12-22	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5189	delivery	5	48
19886	2019-12-22 23:36:40	2019-12-22	9	[{"id_menu":6,"count":1}]	7566	pick-up	0	9
19887	2019-12-22 23:37:14	2019-12-22	9	[{"id_menu":6,"count":1}]	5221	delivery	5	14
19888	2019-12-22 23:41:16	2019-12-22	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	7041	delivery	5	26
19889	2019-12-22 23:44:37	2019-12-22	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7573	delivery	5	40
19890	2019-12-23 00:25:50	2019-12-23	12	[{"id_menu":1,"count":1}]	5279	pick-up	0	12
19891	2019-12-23 00:30:00	2019-12-23	12	[{"id_menu":3,"count":1}]	1729	pick-up	0	12
19892	2019-12-23 00:33:01	2019-12-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	7646	delivery	5	31
19893	2019-12-23 00:35:17	2019-12-23	17	[{"id_menu":4,"count":1}]	394	pick-up	0	17
19894	2019-12-23 01:10:01	2019-12-23	17	[{"id_menu":4,"count":1}]	841	pick-up	0	17
19895	2019-12-23 01:27:43	2019-12-23	14	[{"id_menu":2,"count":1}]	7651	delivery	5	19
19896	2019-12-23 02:09:36	2019-12-23	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1163	delivery	5	37
19897	2019-12-23 02:39:01	2019-12-23	9	[{"id_menu":7,"count":1}]	1158	delivery	5	14
19898	2019-12-23 02:44:53	2019-12-23	8	[{"id_menu":5,"count":1}]	4268	pick-up	0	8
19899	2019-12-23 03:01:33	2019-12-23	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	7668	delivery	5	27
19900	2019-12-23 03:12:27	2019-12-23	14	[{"id_menu":2,"count":1}]	7657	delivery	5	19
19901	2019-12-23 03:31:04	2019-12-23	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	7633	delivery	5	31
19902	2019-12-23 03:38:23	2019-12-23	9	[{"id_menu":7,"count":1}]	7640	delivery	5	14
19903	2019-12-23 03:42:13	2019-12-23	9	[{"id_menu":6,"count":1}]	2485	pick-up	0	9
19904	2019-12-23 04:18:09	2019-12-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6439	delivery	5	36
19905	2019-12-23 04:28:24	2019-12-23	12	[{"id_menu":3,"count":1}]	802	delivery	5	17
19906	2019-12-23 04:42:16	2019-12-23	14	[{"id_menu":2,"count":1}]	5462	delivery	5	19
19907	2019-12-23 04:56:14	2019-12-23	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2594	pick-up	0	29
19908	2019-12-23 05:02:25	2019-12-23	12	[{"id_menu":1,"count":1}]	7606	delivery	5	17
19909	2019-12-23 05:08:56	2019-12-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7658	delivery	5	28
19910	2019-12-23 05:17:11	2019-12-23	17	[{"id_menu":4,"count":1}]	3048	delivery	5	22
19911	2019-12-23 05:21:02	2019-12-23	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	7648	delivery	5	23
19912	2019-12-23 05:23:08	2019-12-23	17	[{"id_menu":4,"count":1}]	7647	delivery	5	22
19913	2019-12-23 05:35:59	2019-12-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4682	pick-up	0	31
19914	2019-12-23 06:25:53	2019-12-23	12	[{"id_menu":1,"count":1}]	1592	pick-up	0	12
19915	2019-12-23 07:11:16	2019-12-23	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	7527	pick-up	0	29
19916	2019-12-23 07:24:49	2019-12-23	17	[{"id_menu":4,"count":1}]	789	delivery	5	22
19917	2019-12-23 07:52:05	2019-12-23	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	7661	delivery	5	31
19918	2019-12-23 07:58:40	2019-12-23	12	[{"id_menu":1,"count":1}]	1095	pick-up	0	12
19919	2019-12-23 08:00:22	2019-12-23	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3460	delivery	5	34
19920	2019-12-23 08:03:27	2019-12-23	8	[{"id_menu":5,"count":1}]	2000	pick-up	0	8
19921	2019-12-23 08:22:21	2019-12-23	12	[{"id_menu":3,"count":1}]	669	pick-up	0	12
19922	2019-12-23 08:23:46	2019-12-23	9	[{"id_menu":7,"count":1}]	3314	delivery	5	14
19923	2019-12-23 08:29:29	2019-12-23	12	[{"id_menu":1,"count":1}]	4894	delivery	5	17
19924	2019-12-23 08:30:14	2019-12-23	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4746	delivery	5	22
19925	2019-12-23 08:42:48	2019-12-23	8	[{"id_menu":5,"count":1}]	886	delivery	5	13
19926	2019-12-23 09:08:53	2019-12-23	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	7656	delivery	5	40
19927	2019-12-23 09:34:27	2019-12-23	12	[{"id_menu":3,"count":1}]	6235	pick-up	0	12
19928	2019-12-23 09:47:08	2019-12-23	14	[{"id_menu":2,"count":1}]	6957	pick-up	0	14
19929	2019-12-23 09:48:51	2019-12-23	14	[{"id_menu":2,"count":1}]	6247	delivery	5	19
19930	2019-12-23 09:59:17	2019-12-23	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	7624	delivery	5	26
19931	2019-12-23 10:07:56	2019-12-23	12	[{"id_menu":1,"count":1}]	2119	pick-up	0	12
19932	2019-12-23 10:10:20	2019-12-23	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	7625	delivery	5	37
19933	2019-12-23 10:19:14	2019-12-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3412	delivery	5	31
19934	2019-12-23 10:38:35	2019-12-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7644	pick-up	0	18
19935	2019-12-23 10:45:56	2019-12-23	8	[{"id_menu":5,"count":1}]	627	delivery	5	13
19936	2019-12-23 10:47:34	2019-12-23	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7666	delivery	5	51
19937	2019-12-23 10:56:07	2019-12-23	9	[{"id_menu":6,"count":1}]	3527	delivery	5	14
19938	2019-12-23 10:58:37	2019-12-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":3}]	3280	delivery	5	28
19939	2019-12-23 11:03:20	2019-12-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7629	delivery	5	28
19940	2019-12-23 11:29:04	2019-12-23	8	[{"id_menu":5,"count":1}]	7632	delivery	5	13
19941	2019-12-23 11:51:33	2019-12-23	14	[{"id_menu":2,"count":1}]	7631	delivery	5	19
19942	2019-12-23 12:17:06	2019-12-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	740	pick-up	0	26
19943	2019-12-23 12:38:47	2019-12-23	9	[{"id_menu":7,"count":1}]	1085	pick-up	0	9
19944	2019-12-23 12:43:49	2019-12-23	12	[{"id_menu":1,"count":1}]	7637	delivery	5	17
19945	2019-12-23 12:53:51	2019-12-23	17	[{"id_menu":4,"count":1}]	5526	delivery	5	22
19946	2019-12-23 13:10:25	2019-12-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7626	pick-up	0	26
19947	2019-12-23 13:13:03	2019-12-23	9	[{"id_menu":7,"count":1}]	628	delivery	5	14
19948	2019-12-23 13:34:37	2019-12-23	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	7627	pick-up	0	21
19949	2019-12-23 13:37:01	2019-12-23	12	[{"id_menu":3,"count":1}]	643	pick-up	0	12
19950	2019-12-23 13:54:09	2019-12-23	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	7634	delivery	5	34
19951	2019-12-23 14:28:12	2019-12-23	12	[{"id_menu":1,"count":1}]	1654	pick-up	0	12
19952	2019-12-23 14:32:59	2019-12-23	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2903	pick-up	0	21
19953	2019-12-23 15:10:51	2019-12-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	585	delivery	5	28
19954	2019-12-23 15:37:37	2019-12-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	7620	delivery	5	28
19955	2019-12-23 15:44:30	2019-12-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4131	delivery	5	23
19956	2019-12-23 15:50:01	2019-12-23	9	[{"id_menu":7,"count":1}]	5786	delivery	5	14
19957	2019-12-23 15:52:20	2019-12-23	8	[{"id_menu":5,"count":1}]	2881	pick-up	0	8
19958	2019-12-23 16:16:48	2019-12-23	12	[{"id_menu":1,"count":1}]	4370	delivery	5	17
19959	2019-12-23 16:33:07	2019-12-23	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	7545	delivery	5	29
19960	2019-12-23 17:01:56	2019-12-23	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6953	delivery	5	22
19961	2019-12-23 17:09:26	2019-12-23	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	7636	delivery	5	27
19962	2019-12-23 17:25:00	2019-12-23	9	[{"id_menu":6,"count":1}]	4342	delivery	5	14
19963	2019-12-23 17:37:00	2019-12-23	9	[{"id_menu":7,"count":1}]	511	pick-up	0	9
19964	2019-12-23 17:38:08	2019-12-23	9	[{"id_menu":6,"count":1}]	299	pick-up	0	9
19965	2019-12-23 17:45:33	2019-12-23	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2290	delivery	5	30
19966	2019-12-23 17:54:45	2019-12-23	14	[{"id_menu":2,"count":1}]	7476	delivery	5	19
19967	2019-12-23 17:55:13	2019-12-23	9	[{"id_menu":7,"count":1}]	271	delivery	5	14
19968	2019-12-23 18:20:20	2019-12-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7604	delivery	5	36
19969	2019-12-23 18:43:51	2019-12-23	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":2}]	7641	delivery	5	31
19970	2019-12-23 18:49:04	2019-12-23	9	[{"id_menu":7,"count":1}]	7645	delivery	5	14
19971	2019-12-23 19:29:58	2019-12-23	9	[{"id_menu":7,"count":1}]	7650	delivery	5	14
19972	2019-12-23 19:31:37	2019-12-23	17	[{"id_menu":4,"count":1}]	4509	delivery	5	22
19973	2019-12-23 19:36:10	2019-12-23	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	2897	pick-up	0	20
19974	2019-12-23 19:39:49	2019-12-23	8	[{"id_menu":5,"count":1}]	21	pick-up	0	8
19975	2019-12-23 19:58:07	2019-12-23	9	[{"id_menu":7,"count":1}]	4166	pick-up	0	9
19976	2019-12-23 20:03:16	2019-12-23	12	[{"id_menu":3,"count":1}]	4945	delivery	5	17
19977	2019-12-23 20:14:18	2019-12-23	14	[{"id_menu":2,"count":1}]	3399	pick-up	0	14
19978	2019-12-23 20:37:38	2019-12-23	14	[{"id_menu":2,"count":1}]	7618	pick-up	0	14
19979	2019-12-23 20:41:29	2019-12-23	9	[{"id_menu":7,"count":2}]	6992	delivery	5	14
19980	2019-12-23 20:46:43	2019-12-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	806	pick-up	0	21
19981	2019-12-23 20:49:44	2019-12-23	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	7665	delivery	5	39
19982	2019-12-23 20:57:51	2019-12-23	12	[{"id_menu":3,"count":2}]	4929	pick-up	0	12
19983	2019-12-23 21:02:20	2019-12-23	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3597	delivery	5	36
19984	2019-12-23 21:16:26	2019-12-23	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	2472	pick-up	0	24
19985	2019-12-23 21:34:50	2019-12-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3480	pick-up	0	23
19986	2019-12-23 21:44:53	2019-12-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7610	delivery	5	22
19987	2019-12-23 22:01:57	2019-12-23	17	[{"id_menu":4,"count":1}]	2030	pick-up	0	17
19988	2019-12-23 22:18:28	2019-12-23	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	7609	pick-up	0	29
19989	2019-12-23 22:35:39	2019-12-23	9	[{"id_menu":6,"count":1}]	6717	delivery	5	14
19990	2019-12-23 22:36:10	2019-12-23	17	[{"id_menu":4,"count":1}]	5508	pick-up	0	17
19991	2019-12-23 23:00:26	2019-12-23	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	482	delivery	5	27
19992	2019-12-23 23:25:06	2019-12-23	14	[{"id_menu":2,"count":2}]	489	pick-up	0	14
19993	2019-12-23 23:33:29	2019-12-23	8	[{"id_menu":5,"count":1}]	7605	pick-up	0	8
19994	2019-12-23 23:37:07	2019-12-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	5486	delivery	5	28
19995	2019-12-24 00:04:11	2019-12-24	9	[{"id_menu":7,"count":1}]	7711	delivery	5	14
19996	2019-12-24 00:17:00	2019-12-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7683	delivery	5	28
19997	2019-12-24 00:32:58	2019-12-24	14	[{"id_menu":2,"count":2}]	140	delivery	5	19
19998	2019-12-24 00:39:28	2019-12-24	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7700	pick-up	0	25
19999	2019-12-24 00:55:33	2019-12-24	17	[{"id_menu":4,"count":1}]	5099	pick-up	0	17
20000	2019-12-24 01:05:32	2019-12-24	14	[{"id_menu":2,"count":1}]	3940	delivery	5	19
20001	2019-12-24 01:16:26	2019-12-24	14	[{"id_menu":2,"count":1}]	3058	delivery	5	19
20002	2019-12-24 01:21:06	2019-12-24	9	[{"id_menu":7,"count":1}]	381	delivery	5	14
20003	2019-12-24 01:29:54	2019-12-24	8	[{"id_menu":5,"count":1}]	5416	pick-up	0	8
20004	2019-12-24 01:40:07	2019-12-24	17	[{"id_menu":4,"count":1}]	7698	delivery	5	22
20005	2019-12-24 01:54:29	2019-12-24	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7723	delivery	5	40
20006	2019-12-24 02:15:41	2019-12-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6727	delivery	5	22
20007	2019-12-24 02:23:11	2019-12-24	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	3851	delivery	5	25
20008	2019-12-24 02:30:03	2019-12-24	14	[{"id_menu":2,"count":1}]	512	pick-up	0	14
20009	2019-12-24 02:45:21	2019-12-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7703	delivery	5	23
20010	2019-12-24 02:47:34	2019-12-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	7141	delivery	5	23
20011	2019-12-24 02:50:24	2019-12-24	12	[{"id_menu":3,"count":1}]	6149	delivery	5	17
20012	2019-12-24 02:54:20	2019-12-24	17	[{"id_menu":4,"count":2}]	5303	delivery	5	22
20013	2019-12-24 03:01:43	2019-12-24	8	[{"id_menu":5,"count":1}]	66	pick-up	0	8
20014	2019-12-24 03:09:20	2019-12-24	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3835	delivery	5	40
20015	2019-12-24 03:22:03	2019-12-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1944	pick-up	0	26
20016	2019-12-24 03:27:15	2019-12-24	12	[{"id_menu":3,"count":2}]	985	delivery	5	17
20017	2019-12-24 03:40:47	2019-12-24	17	[{"id_menu":4,"count":1}]	1557	delivery	5	22
20018	2019-12-24 03:50:45	2019-12-24	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7717	delivery	5	36
20019	2019-12-24 04:15:18	2019-12-24	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7728	delivery	5	31
20020	2019-12-24 04:50:36	2019-12-24	9	[{"id_menu":7,"count":1}]	7721	pick-up	0	9
20021	2019-12-24 05:07:11	2019-12-24	9	[{"id_menu":7,"count":1}]	7127	delivery	5	14
20022	2019-12-24 05:20:29	2019-12-24	9	[{"id_menu":6,"count":1}]	4834	pick-up	0	9
20023	2019-12-24 05:21:43	2019-12-24	12	[{"id_menu":3,"count":1}]	7689	pick-up	0	12
20024	2019-12-24 05:35:10	2019-12-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1170	pick-up	0	23
20025	2019-12-24 05:45:03	2019-12-24	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2101	pick-up	0	20
20026	2019-12-24 06:02:39	2019-12-24	12	[{"id_menu":1,"count":1}]	4460	delivery	5	17
20027	2019-12-24 06:22:46	2019-12-24	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2752	delivery	5	30
20028	2019-12-24 06:35:23	2019-12-24	12	[{"id_menu":3,"count":1}]	500	pick-up	0	12
20029	2019-12-24 06:45:46	2019-12-24	14	[{"id_menu":2,"count":1}]	7709	delivery	5	19
20030	2019-12-24 07:08:24	2019-12-24	17	[{"id_menu":4,"count":1}]	7465	pick-up	0	17
20031	2019-12-24 07:10:41	2019-12-24	8	[{"id_menu":5,"count":1}]	2472	delivery	5	13
20032	2019-12-24 07:11:55	2019-12-24	9	[{"id_menu":7,"count":1}]	2551	pick-up	0	9
20033	2019-12-24 07:27:40	2019-12-24	9	[{"id_menu":6,"count":1}]	7704	delivery	5	14
20034	2019-12-24 07:50:31	2019-12-24	9	[{"id_menu":6,"count":1}]	3971	pick-up	0	9
20035	2019-12-24 07:51:21	2019-12-24	14	[{"id_menu":2,"count":1}]	2455	pick-up	0	14
20036	2019-12-24 07:57:34	2019-12-24	12	[{"id_menu":3,"count":1}]	7279	delivery	5	17
20037	2019-12-24 08:00:03	2019-12-24	9	[{"id_menu":7,"count":1}]	5359	delivery	5	14
20038	2019-12-24 08:16:05	2019-12-24	9	[{"id_menu":6,"count":1}]	2080	pick-up	0	9
20039	2019-12-24 08:26:58	2019-12-24	17	[{"id_menu":4,"count":1}]	6956	delivery	5	22
20040	2019-12-24 08:45:16	2019-12-24	9	[{"id_menu":7,"count":1}]	7691	pick-up	0	9
20041	2019-12-24 08:56:03	2019-12-24	12	[{"id_menu":1,"count":1}]	7669	delivery	5	17
20042	2019-12-24 08:59:09	2019-12-24	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	7679	delivery	5	27
20043	2019-12-24 10:00:42	2019-12-24	9	[{"id_menu":7,"count":1}]	2731	pick-up	0	9
20044	2019-12-24 10:04:58	2019-12-24	8	[{"id_menu":5,"count":1}]	1830	delivery	5	13
20045	2019-12-24 10:09:01	2019-12-24	14	[{"id_menu":2,"count":1}]	3636	pick-up	0	14
20046	2019-12-24 10:10:10	2019-12-24	9	[{"id_menu":7,"count":1}]	2130	delivery	5	14
20047	2019-12-24 10:14:20	2019-12-24	9	[{"id_menu":6,"count":1}]	7705	pick-up	0	9
20048	2019-12-24 10:15:17	2019-12-24	9	[{"id_menu":7,"count":1}]	7563	delivery	5	14
20049	2019-12-24 10:41:13	2019-12-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7702	delivery	5	23
20050	2019-12-24 10:50:10	2019-12-24	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7412	delivery	5	31
20051	2019-12-24 10:59:21	2019-12-24	9	[{"id_menu":6,"count":1}]	2440	delivery	5	14
20052	2019-12-24 11:06:38	2019-12-24	9	[{"id_menu":6,"count":1}]	7680	delivery	5	14
20053	2019-12-24 11:08:09	2019-12-24	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6496	delivery	5	31
20054	2019-12-24 11:14:18	2019-12-24	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4348	pick-up	0	21
20055	2019-12-24 11:16:02	2019-12-24	9	[{"id_menu":7,"count":1}]	7086	pick-up	0	9
20056	2019-12-24 11:43:51	2019-12-24	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	938	pick-up	0	21
20057	2019-12-24 11:46:52	2019-12-24	17	[{"id_menu":4,"count":1}]	1611	delivery	5	22
20058	2019-12-24 11:48:25	2019-12-24	43	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6152	pick-up	0	43
20059	2019-12-24 12:03:53	2019-12-24	9	[{"id_menu":7,"count":1}]	2153	pick-up	0	9
20060	2019-12-24 12:10:22	2019-12-24	9	[{"id_menu":6,"count":1}]	4782	pick-up	0	9
20061	2019-12-24 12:14:29	2019-12-24	9	[{"id_menu":7,"count":1}]	7729	pick-up	0	9
20062	2019-12-24 12:20:59	2019-12-24	12	[{"id_menu":1,"count":1}]	1436	delivery	5	17
20063	2019-12-24 12:23:51	2019-12-24	14	[{"id_menu":2,"count":1}]	2125	pick-up	0	14
20064	2019-12-24 12:52:28	2019-12-24	9	[{"id_menu":6,"count":2}]	5273	delivery	5	14
20065	2019-12-24 13:11:32	2019-12-24	12	[{"id_menu":3,"count":1}]	2450	pick-up	0	12
20066	2019-12-24 13:13:59	2019-12-24	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	486	pick-up	0	20
20067	2019-12-24 13:33:22	2019-12-24	14	[{"id_menu":2,"count":1}]	96	pick-up	0	14
20068	2019-12-24 13:33:48	2019-12-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2827	pick-up	0	23
20069	2019-12-24 13:35:12	2019-12-24	9	[{"id_menu":6,"count":1}]	5761	pick-up	0	9
20070	2019-12-24 13:37:45	2019-12-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6214	delivery	5	31
20071	2019-12-24 13:39:13	2019-12-24	9	[{"id_menu":6,"count":1}]	7274	delivery	5	14
20072	2019-12-24 13:40:11	2019-12-24	9	[{"id_menu":6,"count":2}]	7724	pick-up	0	9
20073	2019-12-24 13:59:55	2019-12-24	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2771	pick-up	0	31
20074	2019-12-24 14:13:07	2019-12-24	14	[{"id_menu":2,"count":1}]	7710	pick-up	0	14
20075	2019-12-24 14:15:06	2019-12-24	12	[{"id_menu":1,"count":1}]	7708	delivery	5	17
20076	2019-12-24 14:21:03	2019-12-24	17	[{"id_menu":4,"count":1}]	7695	delivery	5	22
20077	2019-12-24 14:22:32	2019-12-24	12	[{"id_menu":1,"count":1}]	7676	delivery	5	17
20078	2019-12-24 14:24:48	2019-12-24	12	[{"id_menu":3,"count":1}]	4054	pick-up	0	12
20079	2019-12-24 14:35:54	2019-12-24	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1104	delivery	5	25
20080	2019-12-24 14:38:23	2019-12-24	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	6705	delivery	5	39
20081	2019-12-24 14:38:50	2019-12-24	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	7718	pick-up	0	22
20082	2019-12-24 14:41:31	2019-12-24	17	[{"id_menu":4,"count":1}]	1592	pick-up	0	17
20083	2019-12-24 14:48:47	2019-12-24	12	[{"id_menu":3,"count":1}]	4260	pick-up	0	12
20084	2019-12-24 14:57:45	2019-12-24	9	[{"id_menu":7,"count":1}]	7727	delivery	5	14
20085	2019-12-24 15:02:36	2019-12-24	17	[{"id_menu":4,"count":1}]	5354	pick-up	0	17
20086	2019-12-24 15:09:39	2019-12-24	17	[{"id_menu":4,"count":1}]	2651	delivery	5	22
20087	2019-12-24 15:13:12	2019-12-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2704	delivery	5	28
20088	2019-12-24 15:14:06	2019-12-24	17	[{"id_menu":4,"count":1}]	7615	delivery	5	22
20089	2019-12-24 15:36:04	2019-12-24	9	[{"id_menu":6,"count":1}]	2443	pick-up	0	9
20090	2019-12-24 15:39:51	2019-12-24	8	[{"id_menu":5,"count":1}]	7690	pick-up	0	8
20091	2019-12-24 15:41:16	2019-12-24	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7699	delivery	5	54
20092	2019-12-24 15:47:32	2019-12-24	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	84	delivery	5	26
20093	2019-12-24 15:52:36	2019-12-24	9	[{"id_menu":7,"count":1}]	7677	delivery	5	14
20094	2019-12-24 15:59:45	2019-12-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	547	pick-up	0	26
20095	2019-12-24 16:09:58	2019-12-24	12	[{"id_menu":1,"count":1}]	7688	pick-up	0	12
20096	2019-12-24 16:17:05	2019-12-24	17	[{"id_menu":4,"count":1}]	7722	delivery	5	22
20097	2019-12-24 16:22:37	2019-12-24	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	7715	delivery	5	27
20098	2019-12-24 16:27:20	2019-12-24	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	1301	pick-up	0	35
20099	2019-12-24 17:03:22	2019-12-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7712	delivery	5	22
20100	2019-12-24 17:14:33	2019-12-24	17	[{"id_menu":4,"count":1}]	7692	delivery	5	22
20101	2019-12-24 17:22:51	2019-12-24	8	[{"id_menu":5,"count":1}]	1406	pick-up	0	8
20102	2019-12-24 17:34:45	2019-12-24	9	[{"id_menu":7,"count":1}]	5633	delivery	5	14
20103	2019-12-24 17:36:12	2019-12-24	14	[{"id_menu":2,"count":1}]	6820	delivery	5	19
20104	2019-12-24 17:54:17	2019-12-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7696	delivery	5	28
20105	2019-12-24 17:55:40	2019-12-24	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	5961	pick-up	0	22
20106	2019-12-24 18:10:03	2019-12-24	14	[{"id_menu":2,"count":1}]	6163	delivery	5	19
20107	2019-12-24 18:12:17	2019-12-24	14	[{"id_menu":2,"count":1}]	3265	pick-up	0	14
20108	2019-12-24 18:22:31	2019-12-24	17	[{"id_menu":4,"count":1}]	6597	delivery	5	22
20109	2019-12-24 18:43:06	2019-12-24	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7122	delivery	5	39
20110	2019-12-24 18:44:30	2019-12-24	8	[{"id_menu":5,"count":1}]	7537	delivery	5	13
20111	2019-12-24 19:07:13	2019-12-24	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	7673	delivery	5	22
20112	2019-12-24 19:24:08	2019-12-24	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7164	delivery	5	42
20113	2019-12-24 19:29:12	2019-12-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7706	pick-up	0	23
20114	2019-12-24 19:30:50	2019-12-24	17	[{"id_menu":4,"count":1}]	3394	delivery	5	22
20115	2019-12-24 19:40:21	2019-12-24	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	6736	delivery	5	39
20116	2019-12-24 19:44:05	2019-12-24	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7684	delivery	5	35
20117	2019-12-24 20:02:43	2019-12-24	9	[{"id_menu":7,"count":1}]	1810	pick-up	0	9
20118	2019-12-24 20:20:38	2019-12-24	12	[{"id_menu":3,"count":1}]	1329	pick-up	0	12
20119	2019-12-24 20:25:28	2019-12-24	17	[{"id_menu":4,"count":1}]	1411	pick-up	0	17
20120	2019-12-24 20:29:51	2019-12-24	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1537	pick-up	0	26
20121	2019-12-24 20:45:13	2019-12-24	14	[{"id_menu":2,"count":1}]	1919	delivery	5	19
20122	2019-12-24 20:55:13	2019-12-24	12	[{"id_menu":1,"count":1}]	7674	delivery	5	17
20123	2019-12-24 21:18:47	2019-12-24	14	[{"id_menu":2,"count":1}]	1850	delivery	5	19
20124	2019-12-24 21:42:42	2019-12-24	9	[{"id_menu":7,"count":1}]	6622	pick-up	0	9
20125	2019-12-24 21:42:53	2019-12-24	9	[{"id_menu":6,"count":1}]	1581	pick-up	0	9
20126	2019-12-24 21:45:44	2019-12-24	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	599	delivery	5	31
20127	2019-12-24 21:49:39	2019-12-24	9	[{"id_menu":6,"count":2}]	3527	pick-up	0	9
20128	2019-12-24 22:04:54	2019-12-24	8	[{"id_menu":5,"count":1}]	575	pick-up	0	8
20129	2019-12-24 22:28:41	2019-12-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	701	delivery	5	28
20130	2019-12-24 22:35:12	2019-12-24	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	6600	delivery	5	38
20131	2019-12-24 22:36:19	2019-12-24	12	[{"id_menu":1,"count":1}]	7725	delivery	5	17
20132	2019-12-24 22:40:31	2019-12-24	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	6556	delivery	5	40
20133	2019-12-24 22:44:32	2019-12-24	9	[{"id_menu":7,"count":1}]	3380	delivery	5	14
20134	2019-12-24 23:02:26	2019-12-24	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1485	pick-up	0	46
20135	2019-12-24 23:07:21	2019-12-24	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7726	pick-up	0	47
20136	2019-12-24 23:14:55	2019-12-24	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6791	delivery	5	35
20137	2019-12-24 23:15:56	2019-12-24	8	[{"id_menu":5,"count":1}]	3742	delivery	5	13
20138	2019-12-24 23:20:03	2019-12-24	17	[{"id_menu":4,"count":1}]	2735	pick-up	0	17
20139	2019-12-24 23:27:37	2019-12-24	12	[{"id_menu":1,"count":1}]	6873	delivery	5	17
20140	2019-12-24 23:34:09	2019-12-24	9	[{"id_menu":6,"count":2}]	2428	delivery	5	14
20141	2019-12-24 23:34:49	2019-12-24	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	3616	pick-up	0	26
20142	2019-12-24 23:36:27	2019-12-24	12	[{"id_menu":3,"count":1}]	379	pick-up	0	12
20143	2019-12-24 23:41:45	2019-12-24	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5004	delivery	5	30
20144	2019-12-25 00:22:36	2019-12-25	14	[{"id_menu":2,"count":1}]	356	pick-up	0	14
20145	2019-12-25 00:25:25	2019-12-25	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	3076	delivery	5	40
20146	2019-12-25 00:26:34	2019-12-25	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	6055	delivery	5	26
20147	2019-12-25 00:29:10	2019-12-25	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7761	delivery	5	48
20148	2019-12-25 00:31:17	2019-12-25	8	[{"id_menu":5,"count":1}]	6168	delivery	5	13
20149	2019-12-25 00:31:30	2019-12-25	8	[{"id_menu":5,"count":1}]	7752	delivery	5	13
20150	2019-12-25 00:37:35	2019-12-25	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2305	delivery	5	28
20151	2019-12-25 00:52:41	2019-12-25	12	[{"id_menu":3,"count":1}]	7785	delivery	5	17
20152	2019-12-25 00:57:06	2019-12-25	17	[{"id_menu":4,"count":1}]	2134	pick-up	0	17
20153	2019-12-25 00:59:30	2019-12-25	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	7751	delivery	5	35
20154	2019-12-25 01:00:26	2019-12-25	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	7796	delivery	5	38
20155	2019-12-25 01:04:15	2019-12-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4705	pick-up	0	18
20156	2019-12-25 01:04:39	2019-12-25	14	[{"id_menu":2,"count":1}]	6591	pick-up	0	14
20157	2019-12-25 01:11:45	2019-12-25	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2588	pick-up	0	20
20158	2019-12-25 01:12:37	2019-12-25	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	3452	delivery	5	31
20159	2019-12-25 01:27:28	2019-12-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7766	pick-up	0	23
20160	2019-12-25 01:47:40	2019-12-25	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	677	pick-up	0	26
20161	2019-12-25 01:51:53	2019-12-25	12	[{"id_menu":1,"count":1}]	7451	delivery	5	17
20162	2019-12-25 01:55:09	2019-12-25	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3730	pick-up	0	21
20163	2019-12-25 02:02:09	2019-12-25	9	[{"id_menu":7,"count":1}]	1418	delivery	5	14
20164	2019-12-25 02:08:30	2019-12-25	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6203	delivery	5	34
20165	2019-12-25 02:13:51	2019-12-25	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	82	pick-up	0	38
20166	2019-12-25 02:24:50	2019-12-25	14	[{"id_menu":2,"count":1}]	232	pick-up	0	14
20167	2019-12-25 02:27:25	2019-12-25	14	[{"id_menu":2,"count":1}]	7776	pick-up	0	14
20168	2019-12-25 02:32:20	2019-12-25	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7730	delivery	5	22
20169	2019-12-25 02:32:41	2019-12-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	7750	delivery	5	31
20170	2019-12-25 02:42:52	2019-12-25	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2185	pick-up	0	43
20171	2019-12-25 02:43:01	2019-12-25	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5903	delivery	5	34
20172	2019-12-25 02:47:53	2019-12-25	41	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	599	pick-up	0	41
20173	2019-12-25 03:27:45	2019-12-25	8	[{"id_menu":5,"count":1}]	7747	pick-up	0	8
20174	2019-12-25 03:31:23	2019-12-25	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7780	delivery	5	40
20175	2019-12-25 03:32:48	2019-12-25	9	[{"id_menu":6,"count":1}]	7797	delivery	5	14
20176	2019-12-25 03:37:00	2019-12-25	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	2391	delivery	5	26
20177	2019-12-25 03:51:38	2019-12-25	8	[{"id_menu":5,"count":1}]	4736	delivery	5	13
20178	2019-12-25 03:57:23	2019-12-25	12	[{"id_menu":1,"count":1}]	958	pick-up	0	12
20179	2019-12-25 04:30:27	2019-12-25	12	[{"id_menu":1,"count":1}]	7745	pick-up	0	12
20180	2019-12-25 04:50:34	2019-12-25	9	[{"id_menu":7,"count":1}]	7759	delivery	5	14
20181	2019-12-25 04:52:35	2019-12-25	14	[{"id_menu":2,"count":1}]	1390	delivery	5	19
20182	2019-12-25 05:05:20	2019-12-25	12	[{"id_menu":3,"count":1}]	3313	pick-up	0	12
20183	2019-12-25 05:09:29	2019-12-25	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	4034	pick-up	0	21
20184	2019-12-25 05:13:19	2019-12-25	17	[{"id_menu":4,"count":1}]	4740	delivery	5	22
20185	2019-12-25 05:32:16	2019-12-25	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7774	delivery	5	45
20186	2019-12-25 05:37:15	2019-12-25	8	[{"id_menu":5,"count":1}]	6247	delivery	5	13
20187	2019-12-25 05:51:09	2019-12-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7799	delivery	5	28
20188	2019-12-25 06:00:40	2019-12-25	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1579	delivery	5	45
20189	2019-12-25 06:09:13	2019-12-25	17	[{"id_menu":4,"count":1}]	425	delivery	5	22
20190	2019-12-25 06:14:32	2019-12-25	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	6238	delivery	5	25
20191	2019-12-25 06:32:25	2019-12-25	14	[{"id_menu":2,"count":1}]	4378	delivery	5	19
20192	2019-12-25 07:05:13	2019-12-25	12	[{"id_menu":1,"count":1}]	7772	pick-up	0	12
20193	2019-12-25 07:08:34	2019-12-25	9	[{"id_menu":7,"count":1}]	2759	delivery	5	14
20194	2019-12-25 07:26:21	2019-12-25	9	[{"id_menu":7,"count":1}]	7786	delivery	5	14
20195	2019-12-25 07:29:17	2019-12-25	17	[{"id_menu":4,"count":1}]	2078	delivery	5	22
20196	2019-12-25 07:33:59	2019-12-25	17	[{"id_menu":4,"count":2}]	7726	delivery	5	22
20197	2019-12-25 07:45:56	2019-12-25	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	3611	delivery	5	25
20198	2019-12-25 08:01:21	2019-12-25	9	[{"id_menu":6,"count":2}]	7778	delivery	5	14
20199	2019-12-25 08:04:36	2019-12-25	17	[{"id_menu":4,"count":1}]	4206	pick-up	0	17
20200	2019-12-25 08:15:41	2019-12-25	14	[{"id_menu":2,"count":1}]	1569	pick-up	0	14
20201	2019-12-25 08:24:39	2019-12-25	14	[{"id_menu":2,"count":1}]	7741	delivery	5	19
20202	2019-12-25 08:32:05	2019-12-25	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	5292	delivery	5	26
20203	2019-12-25 08:34:48	2019-12-25	17	[{"id_menu":4,"count":1}]	4411	delivery	5	22
20204	2019-12-25 08:36:33	2019-12-25	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	7791	delivery	5	28
20205	2019-12-25 08:44:11	2019-12-25	9	[{"id_menu":7,"count":1}]	2310	delivery	5	14
20206	2019-12-25 08:54:34	2019-12-25	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7779	delivery	5	31
20207	2019-12-25 09:22:29	2019-12-25	9	[{"id_menu":7,"count":1}]	7765	delivery	5	14
20208	2019-12-25 09:22:57	2019-12-25	9	[{"id_menu":6,"count":1}]	3788	pick-up	0	9
20209	2019-12-25 09:23:36	2019-12-25	9	[{"id_menu":7,"count":1}]	7734	delivery	5	14
20210	2019-12-25 09:26:55	2019-12-25	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7737	delivery	5	40
20211	2019-12-25 09:36:40	2019-12-25	9	[{"id_menu":6,"count":1}]	5105	delivery	5	14
20212	2019-12-25 09:40:03	2019-12-25	12	[{"id_menu":3,"count":1}]	7782	pick-up	0	12
20213	2019-12-25 09:43:29	2019-12-25	14	[{"id_menu":2,"count":1}]	4895	delivery	5	19
20214	2019-12-25 09:45:43	2019-12-25	12	[{"id_menu":3,"count":1}]	1170	delivery	5	17
20215	2019-12-25 09:48:51	2019-12-25	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1657	pick-up	0	23
20216	2019-12-25 09:52:06	2019-12-25	17	[{"id_menu":4,"count":1}]	5790	delivery	5	22
20217	2019-12-25 10:05:50	2019-12-25	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4342	pick-up	0	26
20218	2019-12-25 10:27:26	2019-12-25	9	[{"id_menu":7,"count":1}]	7742	delivery	5	14
20219	2019-12-25 10:28:39	2019-12-25	12	[{"id_menu":1,"count":1}]	1282	delivery	5	17
20220	2019-12-25 10:38:22	2019-12-25	14	[{"id_menu":2,"count":1}]	6800	delivery	5	19
20221	2019-12-25 10:42:56	2019-12-25	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6722	delivery	5	31
20222	2019-12-25 10:45:07	2019-12-25	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3971	delivery	5	48
20223	2019-12-25 10:59:02	2019-12-25	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	7748	delivery	5	29
20224	2019-12-25 11:01:47	2019-12-25	9	[{"id_menu":7,"count":1}]	2552	pick-up	0	9
20225	2019-12-25 11:03:59	2019-12-25	9	[{"id_menu":6,"count":1}]	3324	pick-up	0	9
20226	2019-12-25 11:32:22	2019-12-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	6949	delivery	5	22
20227	2019-12-25 11:53:42	2019-12-25	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1068	delivery	5	46
20228	2019-12-25 12:09:57	2019-12-25	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	7758	pick-up	0	21
20229	2019-12-25 12:15:09	2019-12-25	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7790	delivery	5	36
20230	2019-12-25 12:16:14	2019-12-25	9	[{"id_menu":6,"count":1}]	625	pick-up	0	9
20231	2019-12-25 13:08:44	2019-12-25	12	[{"id_menu":3,"count":1}]	7769	pick-up	0	12
20232	2019-12-25 13:14:05	2019-12-25	8	[{"id_menu":5,"count":1}]	7775	delivery	5	13
20233	2019-12-25 13:17:04	2019-12-25	9	[{"id_menu":6,"count":1}]	295	pick-up	0	9
20234	2019-12-25 13:24:48	2019-12-25	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	7177	pick-up	0	43
20235	2019-12-25 13:36:09	2019-12-25	12	[{"id_menu":1,"count":1}]	2130	delivery	5	17
20236	2019-12-25 14:13:48	2019-12-25	8	[{"id_menu":5,"count":1}]	7777	delivery	5	13
20237	2019-12-25 14:18:51	2019-12-25	8	[{"id_menu":5,"count":1}]	7792	delivery	5	13
20238	2019-12-25 14:19:55	2019-12-25	9	[{"id_menu":7,"count":1}]	5485	delivery	5	14
20239	2019-12-25 14:24:36	2019-12-25	9	[{"id_menu":6,"count":1}]	7731	delivery	5	14
20240	2019-12-25 14:32:00	2019-12-25	12	[{"id_menu":3,"count":1}]	7789	delivery	5	17
20241	2019-12-25 14:32:28	2019-12-25	14	[{"id_menu":2,"count":1}]	7787	pick-up	0	14
20242	2019-12-25 14:33:35	2019-12-25	8	[{"id_menu":5,"count":1}]	7754	delivery	5	13
20243	2019-12-25 14:35:09	2019-12-25	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	7329	delivery	5	31
20244	2019-12-25 14:40:17	2019-12-25	14	[{"id_menu":2,"count":1}]	6624	delivery	5	19
20245	2019-12-25 14:43:54	2019-12-25	9	[{"id_menu":6,"count":1}]	1387	delivery	5	14
20246	2019-12-25 14:52:11	2019-12-25	8	[{"id_menu":5,"count":1}]	6907	delivery	5	13
20247	2019-12-25 15:05:17	2019-12-25	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7773	delivery	5	53
20248	2019-12-25 15:19:43	2019-12-25	14	[{"id_menu":2,"count":1}]	7788	delivery	5	19
20249	2019-12-25 15:24:42	2019-12-25	9	[{"id_menu":7,"count":1}]	1453	delivery	5	14
20250	2019-12-25 15:27:29	2019-12-25	9	[{"id_menu":7,"count":1}]	5099	pick-up	0	9
20251	2019-12-25 15:35:36	2019-12-25	8	[{"id_menu":5,"count":1}]	7732	delivery	5	13
20252	2019-12-25 15:47:30	2019-12-25	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1754	pick-up	0	25
20253	2019-12-25 15:48:42	2019-12-25	9	[{"id_menu":7,"count":1}]	7497	delivery	5	14
20254	2019-12-25 15:51:16	2019-12-25	14	[{"id_menu":2,"count":1}]	2583	delivery	5	19
20255	2019-12-25 15:51:46	2019-12-25	14	[{"id_menu":2,"count":1}]	3135	pick-up	0	14
20256	2019-12-25 15:55:33	2019-12-25	9	[{"id_menu":7,"count":1}]	5778	delivery	5	14
20257	2019-12-25 16:09:34	2019-12-25	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	7798	delivery	5	26
20258	2019-12-25 16:16:53	2019-12-25	9	[{"id_menu":7,"count":1}]	3577	pick-up	0	9
20259	2019-12-25 16:19:44	2019-12-25	12	[{"id_menu":3,"count":1}]	7749	delivery	5	17
20260	2019-12-25 16:21:31	2019-12-25	9	[{"id_menu":6,"count":1}]	7783	pick-up	0	9
20261	2019-12-25 16:24:01	2019-12-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":3}]	3129	delivery	5	23
20262	2019-12-25 16:36:35	2019-12-25	12	[{"id_menu":1,"count":1}]	2605	delivery	5	17
20263	2019-12-25 16:38:44	2019-12-25	9	[{"id_menu":7,"count":1}]	1393	delivery	5	14
20264	2019-12-25 16:52:13	2019-12-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6096	delivery	5	22
20265	2019-12-25 17:03:55	2019-12-25	17	[{"id_menu":4,"count":1}]	6032	delivery	5	22
20266	2019-12-25 17:10:20	2019-12-25	12	[{"id_menu":3,"count":1}]	4721	pick-up	0	12
20267	2019-12-25 17:25:01	2019-12-25	17	[{"id_menu":4,"count":1}]	1513	pick-up	0	17
20268	2019-12-25 17:31:28	2019-12-25	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	184	pick-up	0	35
20269	2019-12-25 17:32:41	2019-12-25	8	[{"id_menu":5,"count":1}]	4100	delivery	5	13
20270	2019-12-25 17:33:35	2019-12-25	8	[{"id_menu":5,"count":1}]	1920	delivery	5	13
20271	2019-12-25 17:34:23	2019-12-25	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	1457	delivery	5	48
20272	2019-12-25 17:39:03	2019-12-25	12	[{"id_menu":3,"count":1}]	660	pick-up	0	12
20273	2019-12-25 17:49:57	2019-12-25	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6163	pick-up	0	17
20274	2019-12-25 17:54:14	2019-12-25	9	[{"id_menu":7,"count":1}]	2699	delivery	5	14
20275	2019-12-25 17:59:59	2019-12-25	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	7743	delivery	5	26
20276	2019-12-25 18:03:33	2019-12-25	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3812	pick-up	0	29
20277	2019-12-25 18:21:22	2019-12-25	9	[{"id_menu":7,"count":1}]	5018	delivery	5	14
20278	2019-12-25 18:24:25	2019-12-25	14	[{"id_menu":2,"count":1}]	7738	delivery	5	19
20279	2019-12-25 18:30:50	2019-12-25	12	[{"id_menu":3,"count":1}]	1947	pick-up	0	12
20280	2019-12-25 18:33:51	2019-12-25	9	[{"id_menu":6,"count":1}]	5560	pick-up	0	9
20281	2019-12-25 18:37:55	2019-12-25	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	7763	delivery	5	25
20282	2019-12-25 18:40:22	2019-12-25	12	[{"id_menu":3,"count":1}]	3638	delivery	5	17
20283	2019-12-25 18:55:21	2019-12-25	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3784	delivery	5	34
20284	2019-12-25 19:16:24	2019-12-25	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7784	delivery	5	30
20285	2019-12-25 19:23:33	2019-12-25	12	[{"id_menu":3,"count":1}]	7767	delivery	5	17
20286	2019-12-25 19:28:29	2019-12-25	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7794	delivery	5	53
20287	2019-12-25 19:34:26	2019-12-25	14	[{"id_menu":2,"count":1}]	6077	delivery	5	19
20288	2019-12-25 19:45:05	2019-12-25	8	[{"id_menu":5,"count":1}]	7795	delivery	5	13
20289	2019-12-25 19:53:01	2019-12-25	17	[{"id_menu":4,"count":1}]	1000	pick-up	0	17
20290	2019-12-25 19:56:54	2019-12-25	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	7756	delivery	5	29
20291	2019-12-25 20:38:30	2019-12-25	17	[{"id_menu":4,"count":1}]	1568	pick-up	0	17
20292	2019-12-25 20:50:30	2019-12-25	9	[{"id_menu":7,"count":1}]	7753	delivery	5	14
20293	2019-12-25 20:52:22	2019-12-25	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	4498	delivery	5	23
20294	2019-12-25 20:56:56	2019-12-25	9	[{"id_menu":7,"count":1}]	456	delivery	5	14
20295	2019-12-25 20:59:08	2019-12-25	9	[{"id_menu":6,"count":1}]	7757	delivery	5	14
20296	2019-12-25 21:03:33	2019-12-25	12	[{"id_menu":3,"count":2}]	6046	pick-up	0	12
20297	2019-12-25 21:11:51	2019-12-25	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	788	pick-up	0	26
20298	2019-12-25 21:17:20	2019-12-25	12	[{"id_menu":1,"count":1}]	151	delivery	5	17
20299	2019-12-25 21:20:43	2019-12-25	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	6000	delivery	5	31
20300	2019-12-25 21:28:10	2019-12-25	9	[{"id_menu":7,"count":2}]	3393	delivery	5	14
20301	2019-12-25 21:30:23	2019-12-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":3}]	7643	delivery	5	31
20302	2019-12-25 21:31:12	2019-12-25	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	4220	delivery	5	26
20303	2019-12-25 21:32:37	2019-12-25	8	[{"id_menu":5,"count":1}]	6092	delivery	5	13
20304	2019-12-25 21:59:31	2019-12-25	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7746	pick-up	0	26
20305	2019-12-25 22:12:00	2019-12-25	12	[{"id_menu":3,"count":1}]	7793	delivery	5	17
20306	2019-12-25 22:12:23	2019-12-25	14	[{"id_menu":2,"count":1}]	7084	delivery	5	19
20307	2019-12-25 22:35:01	2019-12-25	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1107	pick-up	0	31
20308	2019-12-25 22:41:47	2019-12-25	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	7770	delivery	5	34
20309	2019-12-25 22:46:57	2019-12-25	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	310	delivery	5	25
20310	2019-12-25 22:50:03	2019-12-25	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	7768	delivery	5	23
20311	2019-12-25 23:09:08	2019-12-25	17	[{"id_menu":4,"count":1}]	4033	pick-up	0	17
20312	2019-12-25 23:16:28	2019-12-25	8	[{"id_menu":5,"count":1}]	7760	pick-up	0	8
20313	2019-12-25 23:16:51	2019-12-25	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	444	delivery	5	43
20314	2019-12-25 23:23:36	2019-12-25	14	[{"id_menu":2,"count":1}]	372	pick-up	0	14
20315	2019-12-25 23:47:51	2019-12-25	12	[{"id_menu":3,"count":1}]	7771	delivery	5	17
20316	2019-12-25 23:51:55	2019-12-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7739	delivery	5	22
20317	2019-12-26 00:07:06	2019-12-26	14	[{"id_menu":2,"count":1}]	7809	delivery	5	19
20318	2019-12-26 00:12:10	2019-12-26	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	7802	delivery	5	40
20319	2019-12-26 00:36:00	2019-12-26	9	[{"id_menu":6,"count":1}]	7861	delivery	5	14
20320	2019-12-26 00:38:10	2019-12-26	14	[{"id_menu":2,"count":1}]	6885	pick-up	0	14
20321	2019-12-26 00:47:11	2019-12-26	12	[{"id_menu":3,"count":1}]	2197	pick-up	0	12
20322	2019-12-26 00:48:42	2019-12-26	12	[{"id_menu":1,"count":1}]	2631	pick-up	0	12
20323	2019-12-26 00:48:43	2019-12-26	9	[{"id_menu":6,"count":1}]	7012	delivery	5	14
20324	2019-12-26 00:51:11	2019-12-26	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	1736	delivery	5	34
20325	2019-12-26 01:18:02	2019-12-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	7869	delivery	5	23
20326	2019-12-26 01:38:54	2019-12-26	12	[{"id_menu":1,"count":1}]	6913	delivery	5	17
20327	2019-12-26 01:44:25	2019-12-26	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7801	delivery	5	30
20328	2019-12-26 02:02:07	2019-12-26	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	1005	delivery	5	26
20329	2019-12-26 02:15:34	2019-12-26	12	[{"id_menu":1,"count":1}]	7818	delivery	5	17
20330	2019-12-26 02:21:34	2019-12-26	17	[{"id_menu":4,"count":1}]	7858	delivery	5	22
20331	2019-12-26 02:27:22	2019-12-26	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3493	delivery	5	39
20332	2019-12-26 02:30:08	2019-12-26	17	[{"id_menu":4,"count":1}]	7834	pick-up	0	17
20333	2019-12-26 02:47:31	2019-12-26	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	5520	pick-up	0	20
20334	2019-12-26 02:49:06	2019-12-26	9	[{"id_menu":7,"count":2}]	7820	pick-up	0	9
20335	2019-12-26 02:49:23	2019-12-26	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	6914	delivery	5	26
20336	2019-12-26 02:59:45	2019-12-26	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	2670	delivery	5	26
20337	2019-12-26 03:05:24	2019-12-26	8	[{"id_menu":5,"count":1}]	6471	pick-up	0	8
20338	2019-12-26 03:06:55	2019-12-26	9	[{"id_menu":6,"count":1}]	6399	pick-up	0	9
20339	2019-12-26 03:08:53	2019-12-26	12	[{"id_menu":3,"count":1}]	6265	pick-up	0	12
20340	2019-12-26 03:16:05	2019-12-26	14	[{"id_menu":2,"count":1}]	1414	pick-up	0	14
20341	2019-12-26 03:25:15	2019-12-26	12	[{"id_menu":3,"count":1}]	7845	pick-up	0	12
20342	2019-12-26 03:31:34	2019-12-26	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	281	pick-up	0	20
20343	2019-12-26 03:41:53	2019-12-26	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	7620	delivery	5	31
20344	2019-12-26 03:58:55	2019-12-26	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1228	pick-up	0	29
20345	2019-12-26 04:02:17	2019-12-26	14	[{"id_menu":2,"count":1}]	1375	delivery	5	19
20346	2019-12-26 04:05:35	2019-12-26	9	[{"id_menu":6,"count":1}]	4434	delivery	5	14
20347	2019-12-26 04:12:49	2019-12-26	9	[{"id_menu":6,"count":1}]	2228	pick-up	0	9
20348	2019-12-26 04:16:11	2019-12-26	9	[{"id_menu":7,"count":1}]	7863	delivery	5	14
20349	2019-12-26 04:19:58	2019-12-26	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7838	delivery	5	37
20350	2019-12-26 04:38:10	2019-12-26	8	[{"id_menu":5,"count":1}]	7841	pick-up	0	8
20351	2019-12-26 04:49:36	2019-12-26	9	[{"id_menu":7,"count":1}]	1306	pick-up	0	9
20352	2019-12-26 04:54:00	2019-12-26	17	[{"id_menu":4,"count":1}]	7856	delivery	5	22
20353	2019-12-26 04:59:42	2019-12-26	9	[{"id_menu":7,"count":1}]	7839	delivery	5	14
20354	2019-12-26 04:59:43	2019-12-26	17	[{"id_menu":4,"count":1}]	2309	delivery	5	22
20355	2019-12-26 05:01:31	2019-12-26	17	[{"id_menu":4,"count":1}]	7828	delivery	5	22
20356	2019-12-26 05:13:22	2019-12-26	9	[{"id_menu":6,"count":1}]	1280	pick-up	0	9
20357	2019-12-26 05:19:31	2019-12-26	12	[{"id_menu":1,"count":1}]	4899	delivery	5	17
20358	2019-12-26 05:23:18	2019-12-26	9	[{"id_menu":6,"count":1}]	287	pick-up	0	9
20359	2019-12-26 05:26:55	2019-12-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3125	delivery	5	23
20360	2019-12-26 05:39:20	2019-12-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	6341	delivery	5	26
20361	2019-12-26 05:40:34	2019-12-26	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1316	delivery	5	48
20362	2019-12-26 05:52:06	2019-12-26	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	7846	delivery	5	45
20363	2019-12-26 05:58:43	2019-12-26	8	[{"id_menu":5,"count":1}]	7	delivery	5	13
20364	2019-12-26 05:59:14	2019-12-26	17	[{"id_menu":4,"count":1}]	483	delivery	5	22
20365	2019-12-26 06:05:53	2019-12-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	7866	pick-up	0	21
20366	2019-12-26 06:07:18	2019-12-26	9	[{"id_menu":7,"count":1}]	7811	delivery	5	14
20367	2019-12-26 06:07:53	2019-12-26	12	[{"id_menu":1,"count":1}]	2771	pick-up	0	12
20368	2019-12-26 06:17:51	2019-12-26	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	7800	pick-up	0	29
20369	2019-12-26 06:27:25	2019-12-26	14	[{"id_menu":2,"count":1}]	2445	pick-up	0	14
20370	2019-12-26 06:34:19	2019-12-26	9	[{"id_menu":6,"count":1}]	821	pick-up	0	9
20371	2019-12-26 06:35:12	2019-12-26	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	7826	delivery	5	26
20372	2019-12-26 06:53:25	2019-12-26	9	[{"id_menu":6,"count":1}]	3530	delivery	5	14
20373	2019-12-26 06:54:53	2019-12-26	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	5004	delivery	5	26
20374	2019-12-26 07:03:48	2019-12-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4737	delivery	5	31
20375	2019-12-26 07:25:15	2019-12-26	9	[{"id_menu":7,"count":1}]	3202	delivery	5	14
20376	2019-12-26 07:27:37	2019-12-26	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	7808	delivery	5	31
20377	2019-12-26 07:29:58	2019-12-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3187	delivery	5	28
20378	2019-12-26 07:46:44	2019-12-26	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1897	delivery	5	34
20379	2019-12-26 08:33:20	2019-12-26	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	3399	pick-up	0	31
20380	2019-12-26 08:36:12	2019-12-26	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1810	pick-up	0	31
20381	2019-12-26 08:44:14	2019-12-26	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	2055	delivery	5	29
20382	2019-12-26 08:53:16	2019-12-26	9	[{"id_menu":6,"count":1}]	7829	delivery	5	14
20383	2019-12-26 08:55:43	2019-12-26	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	7865	delivery	5	31
20384	2019-12-26 08:59:59	2019-12-26	14	[{"id_menu":2,"count":2}]	5406	pick-up	0	14
20385	2019-12-26 09:18:19	2019-12-26	9	[{"id_menu":6,"count":1}]	1618	pick-up	0	9
20386	2019-12-26 09:20:48	2019-12-26	14	[{"id_menu":2,"count":1}]	1901	delivery	5	19
20387	2019-12-26 09:22:13	2019-12-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	7814	delivery	5	28
20388	2019-12-26 09:23:13	2019-12-26	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	7851	delivery	5	27
20389	2019-12-26 09:30:53	2019-12-26	17	[{"id_menu":4,"count":1}]	617	delivery	5	22
20390	2019-12-26 09:34:03	2019-12-26	14	[{"id_menu":2,"count":1}]	5726	delivery	5	19
20391	2019-12-26 09:43:54	2019-12-26	9	[{"id_menu":6,"count":1}]	7837	delivery	5	14
20392	2019-12-26 09:46:49	2019-12-26	14	[{"id_menu":2,"count":1}]	4862	pick-up	0	14
20393	2019-12-26 09:49:58	2019-12-26	17	[{"id_menu":4,"count":1}]	6561	pick-up	0	17
20394	2019-12-26 09:54:29	2019-12-26	9	[{"id_menu":6,"count":1}]	2559	delivery	5	14
20395	2019-12-26 10:03:43	2019-12-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	7830	delivery	5	28
20396	2019-12-26 10:09:29	2019-12-26	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	5141	pick-up	0	26
20397	2019-12-26 10:25:42	2019-12-26	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3135	delivery	5	31
20398	2019-12-26 10:45:50	2019-12-26	14	[{"id_menu":2,"count":1}]	7803	delivery	5	19
20399	2019-12-26 10:50:19	2019-12-26	17	[{"id_menu":4,"count":1}]	5943	pick-up	0	17
20400	2019-12-26 10:59:24	2019-12-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7807	delivery	5	23
20401	2019-12-26 11:18:10	2019-12-26	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4621	delivery	5	48
20402	2019-12-26 11:18:44	2019-12-26	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	4235	pick-up	0	31
20403	2019-12-26 11:21:46	2019-12-26	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	73	pick-up	0	29
20404	2019-12-26 11:39:54	2019-12-26	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7853	delivery	5	34
20405	2019-12-26 12:06:13	2019-12-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5945	pick-up	0	23
20406	2019-12-26 12:09:08	2019-12-26	9	[{"id_menu":6,"count":1}]	2698	pick-up	0	9
20407	2019-12-26 12:42:57	2019-12-26	14	[{"id_menu":2,"count":1}]	5144	pick-up	0	14
20408	2019-12-26 12:56:44	2019-12-26	12	[{"id_menu":3,"count":1}]	7007	delivery	5	17
20409	2019-12-26 12:58:14	2019-12-26	9	[{"id_menu":7,"count":1}]	7806	pick-up	0	9
20410	2019-12-26 13:13:52	2019-12-26	9	[{"id_menu":6,"count":1}]	5538	delivery	5	14
20411	2019-12-26 13:30:00	2019-12-26	17	[{"id_menu":4,"count":1}]	1194	delivery	5	22
20412	2019-12-26 13:50:19	2019-12-26	12	[{"id_menu":1,"count":1}]	4020	pick-up	0	12
20413	2019-12-26 14:08:10	2019-12-26	9	[{"id_menu":7,"count":1}]	317	pick-up	0	9
20414	2019-12-26 14:14:57	2019-12-26	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	7862	pick-up	0	26
20415	2019-12-26 14:23:58	2019-12-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7852	delivery	5	31
20416	2019-12-26 14:45:39	2019-12-26	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	15	delivery	5	31
20417	2019-12-26 15:01:40	2019-12-26	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	7816	delivery	5	31
20418	2019-12-26 15:07:51	2019-12-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7868	delivery	5	28
20419	2019-12-26 15:19:53	2019-12-26	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	136	pick-up	0	26
20420	2019-12-26 15:25:06	2019-12-26	14	[{"id_menu":2,"count":1}]	7832	pick-up	0	14
20421	2019-12-26 15:35:59	2019-12-26	17	[{"id_menu":4,"count":1}]	4607	delivery	5	22
20422	2019-12-26 15:40:25	2019-12-26	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	265	pick-up	0	35
20423	2019-12-26 15:42:08	2019-12-26	9	[{"id_menu":6,"count":1}]	7566	delivery	5	14
20424	2019-12-26 15:53:37	2019-12-26	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":2}]	7390	delivery	5	28
20425	2019-12-26 16:00:16	2019-12-26	9	[{"id_menu":6,"count":1}]	7849	delivery	5	14
20426	2019-12-26 16:03:14	2019-12-26	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":3}]	7842	delivery	5	25
20427	2019-12-26 16:06:52	2019-12-26	9	[{"id_menu":6,"count":1}]	143	pick-up	0	9
20428	2019-12-26 16:12:32	2019-12-26	9	[{"id_menu":6,"count":1}]	7824	delivery	5	14
20429	2019-12-26 16:18:59	2019-12-26	9	[{"id_menu":6,"count":1}]	3625	delivery	5	14
20430	2019-12-26 16:23:12	2019-12-26	9	[{"id_menu":6,"count":1}]	932	pick-up	0	9
20431	2019-12-26 16:24:33	2019-12-26	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7833	delivery	5	43
20432	2019-12-26 16:38:44	2019-12-26	9	[{"id_menu":7,"count":1}]	7825	delivery	5	14
20433	2019-12-26 16:43:25	2019-12-26	8	[{"id_menu":5,"count":2}]	7857	delivery	5	13
20434	2019-12-26 16:45:28	2019-12-26	12	[{"id_menu":3,"count":1}]	4411	pick-up	0	12
20435	2019-12-26 16:50:37	2019-12-26	9	[{"id_menu":6,"count":1}]	3990	delivery	5	14
20436	2019-12-26 16:57:35	2019-12-26	17	[{"id_menu":4,"count":1}]	2093	delivery	5	22
20437	2019-12-26 17:07:08	2019-12-26	8	[{"id_menu":5,"count":1}]	7831	pick-up	0	8
20438	2019-12-26 17:33:14	2019-12-26	9	[{"id_menu":6,"count":2}]	3684	delivery	5	14
20439	2019-12-26 17:36:50	2019-12-26	9	[{"id_menu":7,"count":1}]	2116	delivery	5	14
20440	2019-12-26 17:38:59	2019-12-26	9	[{"id_menu":7,"count":1}]	3324	pick-up	0	9
20441	2019-12-26 17:41:40	2019-12-26	17	[{"id_menu":4,"count":1}]	7805	delivery	5	22
20442	2019-12-26 17:51:56	2019-12-26	12	[{"id_menu":1,"count":1}]	1772	pick-up	0	12
20443	2019-12-26 17:58:17	2019-12-26	9	[{"id_menu":6,"count":1}]	3361	pick-up	0	9
20444	2019-12-26 18:03:29	2019-12-26	9	[{"id_menu":6,"count":1}]	1885	delivery	5	14
20445	2019-12-26 18:09:39	2019-12-26	17	[{"id_menu":4,"count":1}]	6511	pick-up	0	17
20446	2019-12-26 18:14:58	2019-12-26	14	[{"id_menu":2,"count":1}]	6673	delivery	5	19
20447	2019-12-26 18:15:44	2019-12-26	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2081	delivery	5	34
20448	2019-12-26 18:25:00	2019-12-26	8	[{"id_menu":5,"count":1}]	3788	delivery	5	13
20449	2019-12-26 18:36:38	2019-12-26	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7860	delivery	5	37
20450	2019-12-26 18:37:02	2019-12-26	8	[{"id_menu":5,"count":1}]	7823	delivery	5	13
20451	2019-12-26 19:15:55	2019-12-26	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1317	pick-up	0	47
20452	2019-12-26 19:21:17	2019-12-26	12	[{"id_menu":3,"count":1}]	5142	delivery	5	17
20453	2019-12-26 19:21:46	2019-12-26	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4860	delivery	5	43
20454	2019-12-26 19:26:16	2019-12-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7840	delivery	5	22
20455	2019-12-26 19:29:43	2019-12-26	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	7864	delivery	5	27
20456	2019-12-26 19:34:06	2019-12-26	9	[{"id_menu":6,"count":1}]	7812	delivery	5	14
20457	2019-12-26 19:44:58	2019-12-26	9	[{"id_menu":6,"count":1}]	7855	delivery	5	14
20458	2019-12-26 20:05:57	2019-12-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4735	pick-up	0	23
20459	2019-12-26 20:22:33	2019-12-26	9	[{"id_menu":6,"count":1}]	7595	delivery	5	14
20460	2019-12-26 20:43:15	2019-12-26	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	5792	delivery	5	27
20461	2019-12-26 20:45:01	2019-12-26	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7836	delivery	5	40
20462	2019-12-26 20:51:30	2019-12-26	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2970	delivery	5	43
20463	2019-12-26 21:18:29	2019-12-26	17	[{"id_menu":4,"count":1}]	7848	pick-up	0	17
20464	2019-12-26 21:19:44	2019-12-26	14	[{"id_menu":2,"count":1}]	2546	pick-up	0	14
20465	2019-12-26 21:21:26	2019-12-26	12	[{"id_menu":3,"count":1}]	1701	pick-up	0	12
20466	2019-12-26 21:32:12	2019-12-26	14	[{"id_menu":2,"count":2}]	458	pick-up	0	14
20467	2019-12-26 21:34:14	2019-12-26	12	[{"id_menu":1,"count":1}]	7813	delivery	5	17
20468	2019-12-26 22:00:14	2019-12-26	14	[{"id_menu":2,"count":1}]	7827	pick-up	0	14
20469	2019-12-26 22:10:38	2019-12-26	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7859	delivery	5	45
20470	2019-12-26 22:15:10	2019-12-26	17	[{"id_menu":4,"count":1}]	394	delivery	5	22
20471	2019-12-26 22:18:47	2019-12-26	12	[{"id_menu":1,"count":1}]	4081	delivery	5	17
20472	2019-12-26 22:39:50	2019-12-26	8	[{"id_menu":5,"count":1}]	7850	delivery	5	13
20473	2019-12-26 22:42:02	2019-12-26	9	[{"id_menu":7,"count":1}]	3153	pick-up	0	9
20474	2019-12-26 22:45:50	2019-12-26	9	[{"id_menu":7,"count":2}]	7847	delivery	5	14
20475	2019-12-26 22:48:08	2019-12-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	4577	pick-up	0	21
20476	2019-12-26 22:51:38	2019-12-26	9	[{"id_menu":6,"count":1}]	5430	pick-up	0	9
20477	2019-12-26 22:52:34	2019-12-26	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3251	delivery	5	38
20478	2019-12-26 22:54:21	2019-12-26	14	[{"id_menu":2,"count":1}]	7821	delivery	5	19
20479	2019-12-26 23:04:03	2019-12-26	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5743	delivery	5	44
20480	2019-12-26 23:22:51	2019-12-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	7854	pick-up	0	21
20481	2019-12-26 23:34:07	2019-12-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7819	delivery	5	23
20482	2019-12-26 23:34:49	2019-12-26	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2662	pick-up	0	26
20483	2019-12-26 23:37:20	2019-12-26	9	[{"id_menu":6,"count":1}]	41	pick-up	0	9
20484	2019-12-26 23:37:47	2019-12-26	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	1929	delivery	5	39
20485	2019-12-26 23:59:36	2019-12-26	9	[{"id_menu":7,"count":1}]	2392	delivery	5	14
20486	2019-12-27 00:07:21	2019-12-27	14	[{"id_menu":2,"count":1}]	1460	pick-up	0	14
20487	2019-12-27 00:14:58	2019-12-27	14	[{"id_menu":2,"count":1}]	143	pick-up	0	14
20488	2019-12-27 00:20:23	2019-12-27	12	[{"id_menu":1,"count":1}]	214	pick-up	0	12
20489	2019-12-27 00:28:12	2019-12-27	8	[{"id_menu":5,"count":1}]	6221	delivery	5	13
20490	2019-12-27 00:34:51	2019-12-27	9	[{"id_menu":6,"count":1}]	87	delivery	5	14
20491	2019-12-27 00:42:24	2019-12-27	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7891	pick-up	0	37
20492	2019-12-27 00:57:39	2019-12-27	17	[{"id_menu":4,"count":1}]	7905	pick-up	0	17
20493	2019-12-27 01:24:37	2019-12-27	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	7895	delivery	5	26
20494	2019-12-27 01:36:08	2019-12-27	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	7198	delivery	5	30
20495	2019-12-27 01:41:14	2019-12-27	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2426	pick-up	0	26
20496	2019-12-27 01:52:36	2019-12-27	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	7902	delivery	5	39
20497	2019-12-27 02:01:52	2019-12-27	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	7925	delivery	5	40
20498	2019-12-27 02:20:10	2019-12-27	9	[{"id_menu":7,"count":1}]	7916	delivery	5	14
20499	2019-12-27 02:41:17	2019-12-27	17	[{"id_menu":4,"count":1}]	7904	pick-up	0	17
20500	2019-12-27 02:44:12	2019-12-27	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	4193	pick-up	0	23
20501	2019-12-27 03:11:17	2019-12-27	9	[{"id_menu":6,"count":1}]	6462	delivery	5	14
20502	2019-12-27 03:16:26	2019-12-27	12	[{"id_menu":3,"count":1}]	7934	delivery	5	17
20503	2019-12-27 03:17:13	2019-12-27	9	[{"id_menu":7,"count":1}]	2857	pick-up	0	9
20504	2019-12-27 03:27:16	2019-12-27	9	[{"id_menu":7,"count":1}]	7879	delivery	5	14
20505	2019-12-27 03:37:56	2019-12-27	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	7899	delivery	5	31
20506	2019-12-27 03:39:04	2019-12-27	9	[{"id_menu":6,"count":1}]	7909	delivery	5	14
20507	2019-12-27 03:43:31	2019-12-27	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	3445	delivery	5	31
20508	2019-12-27 03:47:18	2019-12-27	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7935	delivery	5	22
20509	2019-12-27 03:49:50	2019-12-27	14	[{"id_menu":2,"count":1}]	5426	pick-up	0	14
20510	2019-12-27 03:54:46	2019-12-27	17	[{"id_menu":4,"count":2}]	5758	pick-up	0	17
20511	2019-12-27 03:57:27	2019-12-27	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7920	delivery	5	28
20512	2019-12-27 04:02:21	2019-12-27	12	[{"id_menu":1,"count":1}]	2809	pick-up	0	12
20513	2019-12-27 04:04:21	2019-12-27	9	[{"id_menu":7,"count":1}]	7876	delivery	5	14
20514	2019-12-27 04:13:07	2019-12-27	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7888	delivery	5	36
20515	2019-12-27 04:18:52	2019-12-27	9	[{"id_menu":6,"count":1}]	7901	delivery	5	14
20516	2019-12-27 04:45:03	2019-12-27	9	[{"id_menu":6,"count":1}]	1224	delivery	5	14
20517	2019-12-27 04:53:20	2019-12-27	17	[{"id_menu":4,"count":1}]	6926	delivery	5	22
20518	2019-12-27 04:58:37	2019-12-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	544	delivery	5	23
20519	2019-12-27 04:58:46	2019-12-27	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2838	pick-up	0	26
20520	2019-12-27 04:59:31	2019-12-27	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	3996	delivery	5	46
20521	2019-12-27 05:08:16	2019-12-27	12	[{"id_menu":3,"count":1}]	7907	delivery	5	17
20522	2019-12-27 05:11:34	2019-12-27	14	[{"id_menu":2,"count":1}]	7567	delivery	5	19
20523	2019-12-27 05:16:08	2019-12-27	14	[{"id_menu":2,"count":1}]	994	pick-up	0	14
20524	2019-12-27 05:33:40	2019-12-27	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	931	pick-up	0	35
20525	2019-12-27 05:38:06	2019-12-27	17	[{"id_menu":4,"count":1}]	7814	pick-up	0	17
20526	2019-12-27 05:51:11	2019-12-27	17	[{"id_menu":4,"count":1}]	5875	delivery	5	22
20527	2019-12-27 06:06:31	2019-12-27	8	[{"id_menu":5,"count":1}]	6837	pick-up	0	8
20528	2019-12-27 06:15:18	2019-12-27	12	[{"id_menu":1,"count":1}]	4479	pick-up	0	12
20529	2019-12-27 06:24:24	2019-12-27	9	[{"id_menu":7,"count":1}]	1813	delivery	5	14
20530	2019-12-27 07:12:02	2019-12-27	9	[{"id_menu":7,"count":2}]	7877	delivery	5	14
20531	2019-12-27 07:13:26	2019-12-27	9	[{"id_menu":7,"count":1}]	7890	delivery	5	14
20532	2019-12-27 07:18:01	2019-12-27	12	[{"id_menu":3,"count":1}]	7774	delivery	5	17
20533	2019-12-27 07:21:34	2019-12-27	8	[{"id_menu":5,"count":1}]	2172	pick-up	0	8
20534	2019-12-27 07:28:54	2019-12-27	8	[{"id_menu":5,"count":1}]	4038	pick-up	0	8
20535	2019-12-27 07:56:49	2019-12-27	9	[{"id_menu":6,"count":1}]	6040	pick-up	0	9
20536	2019-12-27 08:08:34	2019-12-27	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	730	pick-up	0	17
20537	2019-12-27 08:21:01	2019-12-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	7903	delivery	5	23
20538	2019-12-27 08:41:01	2019-12-27	12	[{"id_menu":3,"count":1}]	4658	delivery	5	17
20539	2019-12-27 08:45:20	2019-12-27	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	386	delivery	5	35
20540	2019-12-27 08:45:46	2019-12-27	9	[{"id_menu":6,"count":1}]	5447	pick-up	0	9
20541	2019-12-27 09:30:04	2019-12-27	9	[{"id_menu":7,"count":1}]	7927	pick-up	0	9
20542	2019-12-27 09:39:15	2019-12-27	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7880	pick-up	0	35
20543	2019-12-27 09:56:42	2019-12-27	12	[{"id_menu":3,"count":1}]	2447	delivery	5	17
20544	2019-12-27 10:09:30	2019-12-27	17	[{"id_menu":4,"count":1}]	2627	pick-up	0	17
20545	2019-12-27 10:13:01	2019-12-27	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	7906	delivery	5	39
20546	2019-12-27 10:18:13	2019-12-27	14	[{"id_menu":2,"count":1}]	2806	delivery	5	19
20547	2019-12-27 10:35:39	2019-12-27	8	[{"id_menu":5,"count":1}]	7882	delivery	5	13
20548	2019-12-27 10:40:29	2019-12-27	14	[{"id_menu":2,"count":1}]	7919	pick-up	0	14
20549	2019-12-27 10:50:04	2019-12-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	7892	delivery	5	36
20550	2019-12-27 11:28:05	2019-12-27	12	[{"id_menu":1,"count":1}]	5180	delivery	5	17
20551	2019-12-27 11:28:36	2019-12-27	9	[{"id_menu":6,"count":1}]	7941	pick-up	0	9
20552	2019-12-27 11:35:52	2019-12-27	17	[{"id_menu":4,"count":1}]	6181	delivery	5	22
20553	2019-12-27 11:36:57	2019-12-27	12	[{"id_menu":3,"count":1}]	1760	delivery	5	17
20554	2019-12-27 11:46:36	2019-12-27	9	[{"id_menu":6,"count":1}]	3824	delivery	5	14
20555	2019-12-27 11:46:49	2019-12-27	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	7874	delivery	5	27
20556	2019-12-27 11:51:35	2019-12-27	12	[{"id_menu":1,"count":1}]	6544	delivery	5	17
20557	2019-12-27 12:01:38	2019-12-27	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7884	delivery	5	36
20558	2019-12-27 12:05:12	2019-12-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7887	delivery	5	22
20559	2019-12-27 12:09:34	2019-12-27	12	[{"id_menu":1,"count":1}]	7937	delivery	5	17
20560	2019-12-27 12:18:13	2019-12-27	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3126	pick-up	0	26
20561	2019-12-27 12:35:26	2019-12-27	9	[{"id_menu":6,"count":1}]	5483	delivery	5	14
20562	2019-12-27 12:46:01	2019-12-27	9	[{"id_menu":7,"count":1}]	7933	delivery	5	14
20563	2019-12-27 12:48:02	2019-12-27	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":2}]	2130	pick-up	0	25
20564	2019-12-27 12:48:31	2019-12-27	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	7341	pick-up	0	26
20565	2019-12-27 12:48:32	2019-12-27	8	[{"id_menu":5,"count":2}]	5862	pick-up	0	8
20566	2019-12-27 12:51:15	2019-12-27	12	[{"id_menu":1,"count":1}]	7247	delivery	5	17
20567	2019-12-27 13:13:46	2019-12-27	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":2}]	7936	delivery	5	27
20568	2019-12-27 13:16:29	2019-12-27	9	[{"id_menu":7,"count":1}]	1468	pick-up	0	9
20569	2019-12-27 13:24:32	2019-12-27	9	[{"id_menu":7,"count":1}]	232	pick-up	0	9
20570	2019-12-27 13:43:06	2019-12-27	8	[{"id_menu":5,"count":1}]	5945	delivery	5	13
20571	2019-12-27 13:51:06	2019-12-27	9	[{"id_menu":7,"count":1}]	6893	delivery	5	14
20572	2019-12-27 13:51:21	2019-12-27	49	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6168	delivery	5	54
20573	2019-12-27 14:02:29	2019-12-27	9	[{"id_menu":6,"count":1}]	7931	pick-up	0	9
20574	2019-12-27 14:05:06	2019-12-27	12	[{"id_menu":3,"count":1}]	1747	delivery	5	17
20575	2019-12-27 14:16:15	2019-12-27	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	7932	delivery	5	23
20576	2019-12-27 14:43:21	2019-12-27	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	7881	delivery	5	31
20577	2019-12-27 14:47:22	2019-12-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3871	delivery	5	28
20578	2019-12-27 15:10:38	2019-12-27	12	[{"id_menu":1,"count":1}]	1592	delivery	5	17
20579	2019-12-27 15:19:44	2019-12-27	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	7871	delivery	5	27
20580	2019-12-27 15:27:07	2019-12-27	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7938	delivery	5	34
20581	2019-12-27 15:30:30	2019-12-27	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3340	delivery	5	31
20582	2019-12-27 15:35:43	2019-12-27	9	[{"id_menu":6,"count":1}]	3268	delivery	5	14
20583	2019-12-27 15:48:50	2019-12-27	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3429	delivery	5	35
20584	2019-12-27 16:00:37	2019-12-27	8	[{"id_menu":5,"count":1}]	7939	delivery	5	13
20585	2019-12-27 16:01:22	2019-12-27	9	[{"id_menu":7,"count":1}]	7913	pick-up	0	9
20586	2019-12-27 16:05:14	2019-12-27	8	[{"id_menu":5,"count":1}]	5642	delivery	5	13
20587	2019-12-27 16:05:19	2019-12-27	12	[{"id_menu":1,"count":1}]	7024	delivery	5	17
20588	2019-12-27 16:05:32	2019-12-27	9	[{"id_menu":6,"count":1}]	5955	delivery	5	14
20589	2019-12-27 16:06:30	2019-12-27	9	[{"id_menu":6,"count":1}]	7883	delivery	5	14
20590	2019-12-27 16:10:20	2019-12-27	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	7280	delivery	5	25
20591	2019-12-27 16:11:47	2019-12-27	9	[{"id_menu":6,"count":1}]	7878	delivery	5	14
20592	2019-12-27 16:46:26	2019-12-27	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7921	pick-up	0	43
20593	2019-12-27 16:52:47	2019-12-27	9	[{"id_menu":7,"count":1}]	7875	delivery	5	14
20594	2019-12-27 16:54:07	2019-12-27	9	[{"id_menu":7,"count":3}]	7914	delivery	5	14
20595	2019-12-27 17:10:42	2019-12-27	9	[{"id_menu":7,"count":1}]	807	delivery	5	14
20596	2019-12-27 17:16:03	2019-12-27	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2932	delivery	5	22
20597	2019-12-27 17:40:39	2019-12-27	9	[{"id_menu":7,"count":1}]	5225	delivery	5	14
20598	2019-12-27 18:03:54	2019-12-27	9	[{"id_menu":7,"count":1}]	1160	pick-up	0	9
20599	2019-12-27 18:14:34	2019-12-27	17	[{"id_menu":4,"count":1}]	799	delivery	5	22
20600	2019-12-27 18:39:02	2019-12-27	8	[{"id_menu":5,"count":1}]	2098	delivery	5	13
20601	2019-12-27 18:40:59	2019-12-27	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1525	delivery	5	51
20602	2019-12-27 18:42:11	2019-12-27	9	[{"id_menu":6,"count":1}]	2243	pick-up	0	9
20603	2019-12-27 18:57:33	2019-12-27	9	[{"id_menu":7,"count":1}]	1996	delivery	5	14
20604	2019-12-27 18:58:11	2019-12-27	17	[{"id_menu":4,"count":1}]	1	pick-up	0	17
20605	2019-12-27 18:58:52	2019-12-27	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	7872	delivery	5	27
20606	2019-12-27 19:03:56	2019-12-27	14	[{"id_menu":2,"count":1}]	2678	pick-up	0	14
20607	2019-12-27 19:07:09	2019-12-27	17	[{"id_menu":4,"count":2}]	1470	delivery	5	22
20608	2019-12-27 19:09:02	2019-12-27	14	[{"id_menu":2,"count":1}]	3115	delivery	5	19
20609	2019-12-27 19:20:26	2019-12-27	9	[{"id_menu":7,"count":1}]	7053	pick-up	0	9
20610	2019-12-27 19:22:20	2019-12-27	9	[{"id_menu":6,"count":1}]	7603	pick-up	0	9
20611	2019-12-27 19:23:23	2019-12-27	9	[{"id_menu":7,"count":1}]	5879	pick-up	0	9
20612	2019-12-27 19:25:51	2019-12-27	8	[{"id_menu":5,"count":1}]	222	pick-up	0	8
20613	2019-12-27 19:27:05	2019-12-27	9	[{"id_menu":6,"count":2}]	1674	delivery	5	14
20614	2019-12-27 19:28:28	2019-12-27	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	7928	delivery	5	40
20615	2019-12-27 19:40:15	2019-12-27	9	[{"id_menu":7,"count":1}]	154	pick-up	0	9
20616	2019-12-27 19:48:25	2019-12-27	12	[{"id_menu":1,"count":1}]	2075	pick-up	0	12
20617	2019-12-27 20:02:14	2019-12-27	9	[{"id_menu":6,"count":1}]	5372	pick-up	0	9
20618	2019-12-27 20:35:26	2019-12-27	9	[{"id_menu":7,"count":1}]	2449	pick-up	0	9
20619	2019-12-27 20:39:54	2019-12-27	12	[{"id_menu":1,"count":1}]	7915	delivery	5	17
20620	2019-12-27 20:41:44	2019-12-27	12	[{"id_menu":3,"count":1}]	7917	delivery	5	17
20621	2019-12-27 20:58:43	2019-12-27	17	[{"id_menu":4,"count":1}]	1722	pick-up	0	17
20622	2019-12-27 21:00:25	2019-12-27	12	[{"id_menu":1,"count":1}]	2921	pick-up	0	12
20623	2019-12-27 21:04:05	2019-12-27	17	[{"id_menu":4,"count":1}]	5350	pick-up	0	17
20624	2019-12-27 21:04:18	2019-12-27	14	[{"id_menu":2,"count":1}]	6067	pick-up	0	14
20625	2019-12-27 21:14:56	2019-12-27	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	6330	delivery	5	40
20626	2019-12-27 21:22:19	2019-12-27	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6176	pick-up	0	23
20627	2019-12-27 21:33:49	2019-12-27	14	[{"id_menu":2,"count":1}]	4640	pick-up	0	14
20628	2019-12-27 21:34:05	2019-12-27	9	[{"id_menu":6,"count":1}]	1993	pick-up	0	9
20629	2019-12-27 21:41:19	2019-12-27	9	[{"id_menu":6,"count":1}]	2660	pick-up	0	9
20630	2019-12-27 21:48:14	2019-12-27	14	[{"id_menu":2,"count":2}]	3241	pick-up	0	14
20631	2019-12-27 21:49:46	2019-12-27	17	[{"id_menu":4,"count":1}]	7929	delivery	5	22
20632	2019-12-27 21:52:38	2019-12-27	9	[{"id_menu":6,"count":1}]	7873	delivery	5	14
20633	2019-12-27 22:05:43	2019-12-27	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	7918	delivery	5	27
20634	2019-12-27 22:26:16	2019-12-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7041	delivery	5	36
20635	2019-12-27 22:34:08	2019-12-27	17	[{"id_menu":4,"count":1}]	5930	delivery	5	22
20636	2019-12-27 22:34:42	2019-12-27	17	[{"id_menu":4,"count":1}]	4993	pick-up	0	17
20637	2019-12-27 22:42:57	2019-12-27	9	[{"id_menu":7,"count":1}]	2757	delivery	5	14
20638	2019-12-27 22:53:57	2019-12-27	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7910	delivery	5	46
20639	2019-12-27 23:14:56	2019-12-27	12	[{"id_menu":3,"count":1}]	4101	pick-up	0	12
20640	2019-12-27 23:16:23	2019-12-27	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	6254	pick-up	0	35
20641	2019-12-27 23:19:46	2019-12-27	12	[{"id_menu":3,"count":1}]	7896	delivery	5	17
20642	2019-12-27 23:31:41	2019-12-27	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1508	delivery	5	28
20643	2019-12-27 23:43:14	2019-12-27	17	[{"id_menu":4,"count":1}]	7924	delivery	5	22
20644	2019-12-27 23:51:57	2019-12-27	12	[{"id_menu":3,"count":1}]	5014	pick-up	0	12
20645	2019-12-28 00:00:06	2019-12-28	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	7965	delivery	5	34
20646	2019-12-28 00:08:36	2019-12-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	187	pick-up	0	26
20647	2019-12-28 00:12:02	2019-12-28	9	[{"id_menu":6,"count":1}]	7957	pick-up	0	9
20648	2019-12-28 00:26:53	2019-12-28	8	[{"id_menu":5,"count":1}]	7985	delivery	5	13
20649	2019-12-28 00:36:04	2019-12-28	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7975	delivery	5	43
20650	2019-12-28 00:46:36	2019-12-28	9	[{"id_menu":7,"count":1}]	7981	delivery	5	14
20651	2019-12-28 01:13:03	2019-12-28	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5387	pick-up	0	30
20652	2019-12-28 01:19:57	2019-12-28	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2068	pick-up	0	22
20653	2019-12-28 01:26:57	2019-12-28	8	[{"id_menu":5,"count":1}]	8019	pick-up	0	8
20654	2019-12-28 01:27:17	2019-12-28	9	[{"id_menu":7,"count":1}]	7982	delivery	5	14
20655	2019-12-28 01:29:47	2019-12-28	14	[{"id_menu":2,"count":1}]	7968	delivery	5	19
20656	2019-12-28 01:32:18	2019-12-28	12	[{"id_menu":3,"count":1}]	8025	pick-up	0	12
20657	2019-12-28 01:36:26	2019-12-28	12	[{"id_menu":1,"count":1}]	7991	delivery	5	17
20658	2019-12-28 01:45:30	2019-12-28	8	[{"id_menu":5,"count":1}]	4166	delivery	5	13
20659	2019-12-28 01:45:52	2019-12-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3086	delivery	5	22
20660	2019-12-28 01:52:23	2019-12-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7912	delivery	5	22
20661	2019-12-28 01:53:27	2019-12-28	9	[{"id_menu":6,"count":1}]	8012	delivery	5	14
20662	2019-12-28 01:55:12	2019-12-28	14	[{"id_menu":2,"count":1}]	3819	delivery	5	19
20663	2019-12-28 01:58:17	2019-12-28	17	[{"id_menu":4,"count":1}]	1248	pick-up	0	17
20664	2019-12-28 01:59:17	2019-12-28	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6044	delivery	5	40
20665	2019-12-28 02:03:47	2019-12-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7954	delivery	5	22
20666	2019-12-28 02:07:49	2019-12-28	12	[{"id_menu":1,"count":1}]	7969	delivery	5	17
20667	2019-12-28 02:11:37	2019-12-28	14	[{"id_menu":2,"count":1}]	126	pick-up	0	14
20668	2019-12-28 02:11:58	2019-12-28	14	[{"id_menu":2,"count":1}]	6511	pick-up	0	14
20669	2019-12-28 02:14:42	2019-12-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6301	delivery	5	28
20670	2019-12-28 02:24:42	2019-12-28	12	[{"id_menu":1,"count":1}]	4973	pick-up	0	12
20671	2019-12-28 02:30:33	2019-12-28	12	[{"id_menu":3,"count":1}]	7998	delivery	5	17
20672	2019-12-28 02:31:39	2019-12-28	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	7972	delivery	5	36
20673	2019-12-28 02:31:45	2019-12-28	12	[{"id_menu":1,"count":1}]	3570	delivery	5	17
20674	2019-12-28 02:35:01	2019-12-28	8	[{"id_menu":5,"count":1}]	8021	delivery	5	13
20675	2019-12-28 02:35:45	2019-12-28	12	[{"id_menu":1,"count":1}]	7974	pick-up	0	12
20676	2019-12-28 02:45:06	2019-12-28	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	49	delivery	5	34
20677	2019-12-28 02:49:14	2019-12-28	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4458	pick-up	0	21
20678	2019-12-28 02:53:24	2019-12-28	14	[{"id_menu":2,"count":1}]	7586	delivery	5	19
20679	2019-12-28 02:57:09	2019-12-28	9	[{"id_menu":7,"count":1}]	2	pick-up	0	9
20680	2019-12-28 03:09:19	2019-12-28	17	[{"id_menu":4,"count":1}]	7834	pick-up	0	17
20681	2019-12-28 03:15:42	2019-12-28	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3616	pick-up	0	31
20682	2019-12-28 03:41:07	2019-12-28	9	[{"id_menu":7,"count":1}]	229	pick-up	0	9
20683	2019-12-28 03:44:57	2019-12-28	8	[{"id_menu":5,"count":1}]	6097	pick-up	0	8
20684	2019-12-28 03:52:55	2019-12-28	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	7130	delivery	5	26
20685	2019-12-28 03:54:42	2019-12-28	12	[{"id_menu":3,"count":1}]	245	delivery	5	17
20686	2019-12-28 03:58:50	2019-12-28	9	[{"id_menu":6,"count":1}]	528	delivery	5	14
20687	2019-12-28 04:09:53	2019-12-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8010	delivery	5	31
20688	2019-12-28 04:11:49	2019-12-28	9	[{"id_menu":6,"count":1}]	8004	pick-up	0	9
20689	2019-12-28 04:18:14	2019-12-28	9	[{"id_menu":7,"count":1}]	2982	delivery	5	14
20690	2019-12-28 04:32:17	2019-12-28	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	802	delivery	5	44
20691	2019-12-28 04:40:15	2019-12-28	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	6125	delivery	5	26
20692	2019-12-28 04:40:16	2019-12-28	8	[{"id_menu":5,"count":1}]	1404	delivery	5	13
20693	2019-12-28 04:48:17	2019-12-28	12	[{"id_menu":3,"count":1}]	3656	pick-up	0	12
20694	2019-12-28 04:48:39	2019-12-28	9	[{"id_menu":6,"count":1}]	7999	pick-up	0	9
20695	2019-12-28 04:50:01	2019-12-28	9	[{"id_menu":6,"count":1}]	7963	pick-up	0	9
20696	2019-12-28 04:57:52	2019-12-28	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	7363	delivery	5	34
20697	2019-12-28 05:14:20	2019-12-28	14	[{"id_menu":2,"count":1}]	8011	delivery	5	19
20698	2019-12-28 05:18:52	2019-12-28	12	[{"id_menu":3,"count":1}]	8007	delivery	5	17
20699	2019-12-28 05:25:46	2019-12-28	9	[{"id_menu":7,"count":1}]	3842	delivery	5	14
20700	2019-12-28 05:33:23	2019-12-28	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	8016	delivery	5	34
20701	2019-12-28 05:37:02	2019-12-28	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6058	delivery	5	34
20702	2019-12-28 05:40:06	2019-12-28	9	[{"id_menu":7,"count":1}]	932	pick-up	0	9
20703	2019-12-28 05:41:40	2019-12-28	9	[{"id_menu":7,"count":3}]	8000	delivery	5	14
20704	2019-12-28 05:45:53	2019-12-28	17	[{"id_menu":4,"count":1}]	1175	pick-up	0	17
20705	2019-12-28 05:55:50	2019-12-28	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	585	delivery	5	26
20706	2019-12-28 05:56:58	2019-12-28	12	[{"id_menu":1,"count":1}]	236	pick-up	0	12
20707	2019-12-28 06:05:12	2019-12-28	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	7994	delivery	5	25
20708	2019-12-28 06:08:19	2019-12-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5854	delivery	5	31
20709	2019-12-28 06:09:25	2019-12-28	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4996	delivery	5	43
20710	2019-12-28 06:22:20	2019-12-28	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	8005	delivery	5	26
20711	2019-12-28 06:23:43	2019-12-28	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	4591	delivery	5	29
20712	2019-12-28 06:27:47	2019-12-28	12	[{"id_menu":1,"count":1}]	8028	pick-up	0	12
20713	2019-12-28 06:32:25	2019-12-28	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	8013	delivery	5	22
20714	2019-12-28 06:47:45	2019-12-28	9	[{"id_menu":7,"count":1}]	7993	delivery	5	14
20715	2019-12-28 06:48:11	2019-12-28	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	1084	delivery	5	23
20716	2019-12-28 06:51:57	2019-12-28	17	[{"id_menu":4,"count":1}]	4256	pick-up	0	17
20717	2019-12-28 06:55:32	2019-12-28	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4655	delivery	5	38
20718	2019-12-28 07:03:15	2019-12-28	9	[{"id_menu":6,"count":1}]	5570	delivery	5	14
20719	2019-12-28 07:14:16	2019-12-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2570	delivery	5	31
20720	2019-12-28 07:20:21	2019-12-28	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1724	delivery	5	25
20721	2019-12-28 07:43:09	2019-12-28	12	[{"id_menu":3,"count":1}]	7571	pick-up	0	12
20722	2019-12-28 07:43:37	2019-12-28	17	[{"id_menu":4,"count":1}]	2912	pick-up	0	17
20723	2019-12-28 07:51:58	2019-12-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	8032	delivery	5	28
20724	2019-12-28 08:07:37	2019-12-28	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	8029	delivery	5	31
20725	2019-12-28 08:25:55	2019-12-28	9	[{"id_menu":7,"count":1}]	7435	pick-up	0	9
20726	2019-12-28 08:45:03	2019-12-28	14	[{"id_menu":2,"count":1}]	7983	delivery	5	19
20727	2019-12-28 08:46:47	2019-12-28	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1053	pick-up	0	21
20728	2019-12-28 09:00:57	2019-12-28	12	[{"id_menu":3,"count":1}]	3893	delivery	5	17
20729	2019-12-28 09:05:06	2019-12-28	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	8015	delivery	5	39
20730	2019-12-28 09:05:40	2019-12-28	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	4436	pick-up	0	21
20731	2019-12-28 09:06:21	2019-12-28	12	[{"id_menu":1,"count":1}]	438	pick-up	0	12
20732	2019-12-28 09:07:56	2019-12-28	9	[{"id_menu":6,"count":1}]	8033	delivery	5	14
20733	2019-12-28 09:19:25	2019-12-28	12	[{"id_menu":3,"count":2}]	7947	delivery	5	17
20734	2019-12-28 09:20:21	2019-12-28	14	[{"id_menu":2,"count":1}]	2153	delivery	5	19
20735	2019-12-28 09:27:45	2019-12-28	9	[{"id_menu":7,"count":1}]	4492	delivery	5	14
20736	2019-12-28 09:28:54	2019-12-28	8	[{"id_menu":5,"count":1}]	1503	pick-up	0	8
20737	2019-12-28 09:32:24	2019-12-28	8	[{"id_menu":5,"count":1}]	3102	pick-up	0	8
20738	2019-12-28 09:39:11	2019-12-28	9	[{"id_menu":6,"count":1}]	7955	delivery	5	14
20739	2019-12-28 09:48:46	2019-12-28	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	2520	pick-up	0	29
20740	2019-12-28 09:54:05	2019-12-28	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4658	delivery	5	28
20741	2019-12-28 09:54:23	2019-12-28	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	7943	delivery	5	40
20742	2019-12-28 10:10:22	2019-12-28	14	[{"id_menu":2,"count":1}]	941	delivery	5	19
20743	2019-12-28 10:18:37	2019-12-28	17	[{"id_menu":4,"count":1}]	6924	pick-up	0	17
20744	2019-12-28 10:22:33	2019-12-28	12	[{"id_menu":1,"count":1}]	2417	delivery	5	17
20745	2019-12-28 10:38:48	2019-12-28	12	[{"id_menu":1,"count":1}]	7961	delivery	5	17
20746	2019-12-28 10:42:18	2019-12-28	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	7953	delivery	5	31
20747	2019-12-28 10:48:17	2019-12-28	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	5024	delivery	5	52
20748	2019-12-28 10:56:59	2019-12-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7987	delivery	5	28
20749	2019-12-28 11:14:55	2019-12-28	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	2596	delivery	5	48
20750	2019-12-28 11:18:01	2019-12-28	14	[{"id_menu":2,"count":1}]	175	pick-up	0	14
20751	2019-12-28 11:21:46	2019-12-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	7971	delivery	5	23
20752	2019-12-28 11:23:47	2019-12-28	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	788	pick-up	0	29
20753	2019-12-28 11:47:03	2019-12-28	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	8009	delivery	5	25
20754	2019-12-28 11:47:14	2019-12-28	12	[{"id_menu":3,"count":1}]	7050	pick-up	0	12
20755	2019-12-28 11:47:18	2019-12-28	9	[{"id_menu":6,"count":1}]	7976	delivery	5	14
20756	2019-12-28 11:47:32	2019-12-28	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	8014	pick-up	0	24
20757	2019-12-28 11:50:34	2019-12-28	46	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	4222	delivery	5	51
20758	2019-12-28 11:51:04	2019-12-28	14	[{"id_menu":2,"count":1}]	8026	delivery	5	19
20759	2019-12-28 11:51:28	2019-12-28	14	[{"id_menu":2,"count":1}]	5469	delivery	5	19
20760	2019-12-28 11:57:05	2019-12-28	9	[{"id_menu":6,"count":1}]	7988	pick-up	0	9
20761	2019-12-28 12:03:29	2019-12-28	9	[{"id_menu":6,"count":1}]	5245	delivery	5	14
20762	2019-12-28 12:05:53	2019-12-28	9	[{"id_menu":6,"count":1}]	7949	delivery	5	14
20763	2019-12-28 12:06:26	2019-12-28	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	7997	delivery	5	29
20764	2019-12-28 12:09:13	2019-12-28	14	[{"id_menu":2,"count":1}]	5146	delivery	5	19
20765	2019-12-28 12:18:14	2019-12-28	12	[{"id_menu":1,"count":1}]	7942	delivery	5	17
20766	2019-12-28 12:21:59	2019-12-28	9	[{"id_menu":6,"count":1}]	3116	pick-up	0	9
20767	2019-12-28 12:27:01	2019-12-28	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7106	delivery	5	51
20768	2019-12-28 12:30:36	2019-12-28	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	7977	pick-up	0	22
20769	2019-12-28 12:31:03	2019-12-28	9	[{"id_menu":6,"count":1}]	3909	pick-up	0	9
20770	2019-12-28 12:36:35	2019-12-28	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3443	delivery	5	31
20771	2019-12-28 12:38:34	2019-12-28	9	[{"id_menu":7,"count":1}]	7989	delivery	5	14
20772	2019-12-28 12:38:36	2019-12-28	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1470	delivery	5	39
20773	2019-12-28 12:40:21	2019-12-28	9	[{"id_menu":7,"count":2}]	7946	delivery	5	14
20774	2019-12-28 12:40:48	2019-12-28	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	6282	delivery	5	31
20775	2019-12-28 12:41:07	2019-12-28	8	[{"id_menu":5,"count":1}]	7792	delivery	5	13
20776	2019-12-28 12:44:16	2019-12-28	14	[{"id_menu":2,"count":1}]	1176	pick-up	0	14
20777	2019-12-28 12:51:55	2019-12-28	17	[{"id_menu":4,"count":1}]	3968	pick-up	0	17
20778	2019-12-28 12:52:56	2019-12-28	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7959	delivery	5	55
20779	2019-12-28 12:53:52	2019-12-28	12	[{"id_menu":3,"count":1}]	7951	delivery	5	17
20780	2019-12-28 12:58:09	2019-12-28	12	[{"id_menu":1,"count":1}]	8003	pick-up	0	12
20781	2019-12-28 13:02:17	2019-12-28	17	[{"id_menu":4,"count":1}]	7503	delivery	5	22
20782	2019-12-28 13:06:00	2019-12-28	14	[{"id_menu":2,"count":1}]	3007	delivery	5	19
20783	2019-12-28 13:25:49	2019-12-28	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	6790	pick-up	0	21
20784	2019-12-28 13:33:29	2019-12-28	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2821	pick-up	0	25
20785	2019-12-28 13:38:17	2019-12-28	9	[{"id_menu":6,"count":2}]	4279	pick-up	0	9
20786	2019-12-28 13:53:05	2019-12-28	8	[{"id_menu":5,"count":1}]	7956	delivery	5	13
20787	2019-12-28 14:03:04	2019-12-28	8	[{"id_menu":5,"count":1}]	7996	delivery	5	13
20788	2019-12-28 14:08:26	2019-12-28	9	[{"id_menu":6,"count":1}]	2119	pick-up	0	9
20789	2019-12-28 14:11:24	2019-12-28	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	32	pick-up	0	21
20790	2019-12-28 14:19:50	2019-12-28	14	[{"id_menu":2,"count":1}]	7992	pick-up	0	14
20791	2019-12-28 14:20:03	2019-12-28	8	[{"id_menu":5,"count":1}]	314	delivery	5	13
20792	2019-12-28 14:24:52	2019-12-28	9	[{"id_menu":7,"count":1}]	5484	delivery	5	14
20793	2019-12-28 14:42:24	2019-12-28	12	[{"id_menu":1,"count":1}]	6470	delivery	5	17
20794	2019-12-28 14:42:59	2019-12-28	17	[{"id_menu":4,"count":1}]	3015	pick-up	0	17
20795	2019-12-28 14:46:54	2019-12-28	17	[{"id_menu":4,"count":1}]	7978	delivery	5	22
20796	2019-12-28 14:52:33	2019-12-28	12	[{"id_menu":3,"count":1}]	286	pick-up	0	12
20797	2019-12-28 15:05:16	2019-12-28	9	[{"id_menu":7,"count":1}]	7995	delivery	5	14
20798	2019-12-28 15:10:52	2019-12-28	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	7962	delivery	5	34
20799	2019-12-28 15:21:15	2019-12-28	8	[{"id_menu":5,"count":1}]	597	delivery	5	13
20800	2019-12-28 15:29:53	2019-12-28	9	[{"id_menu":6,"count":1}]	7944	delivery	5	14
20801	2019-12-28 15:30:38	2019-12-28	9	[{"id_menu":7,"count":1}]	4350	pick-up	0	9
20802	2019-12-28 15:52:09	2019-12-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5244	delivery	5	22
20803	2019-12-28 16:12:39	2019-12-28	8	[{"id_menu":5,"count":1}]	8023	delivery	5	13
20804	2019-12-28 16:19:28	2019-12-28	9	[{"id_menu":7,"count":1}]	7973	delivery	5	14
20805	2019-12-28 16:20:15	2019-12-28	14	[{"id_menu":2,"count":1}]	8022	delivery	5	19
20806	2019-12-28 16:25:19	2019-12-28	12	[{"id_menu":3,"count":1}]	7967	pick-up	0	12
20807	2019-12-28 16:27:12	2019-12-28	9	[{"id_menu":6,"count":1}]	3820	pick-up	0	9
20808	2019-12-28 16:33:57	2019-12-28	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6134	delivery	5	39
20809	2019-12-28 16:34:21	2019-12-28	17	[{"id_menu":4,"count":1}]	3334	delivery	5	22
20810	2019-12-28 16:46:50	2019-12-28	8	[{"id_menu":5,"count":1}]	2677	delivery	5	13
20811	2019-12-28 16:49:37	2019-12-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6533	pick-up	0	26
20812	2019-12-28 16:50:36	2019-12-28	17	[{"id_menu":4,"count":1}]	389	pick-up	0	17
20813	2019-12-28 17:29:09	2019-12-28	9	[{"id_menu":7,"count":1}]	7353	delivery	5	14
20814	2019-12-28 17:43:47	2019-12-28	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2978	delivery	5	40
20815	2019-12-28 17:45:03	2019-12-28	14	[{"id_menu":2,"count":1}]	5372	pick-up	0	14
20816	2019-12-28 17:50:03	2019-12-28	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	4937	pick-up	0	21
20817	2019-12-28 17:51:33	2019-12-28	12	[{"id_menu":1,"count":1}]	5215	pick-up	0	12
20818	2019-12-28 18:28:34	2019-12-28	12	[{"id_menu":3,"count":1}]	4986	pick-up	0	12
20819	2019-12-28 18:41:03	2019-12-28	12	[{"id_menu":3,"count":1}]	78	pick-up	0	12
20820	2019-12-28 18:44:47	2019-12-28	9	[{"id_menu":6,"count":1}]	8031	delivery	5	14
20821	2019-12-28 18:48:12	2019-12-28	9	[{"id_menu":7,"count":1}]	1233	delivery	5	14
20822	2019-12-28 18:49:14	2019-12-28	8	[{"id_menu":5,"count":1}]	6678	delivery	5	13
20823	2019-12-28 18:51:13	2019-12-28	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	7986	delivery	5	23
20824	2019-12-28 18:51:45	2019-12-28	9	[{"id_menu":7,"count":1}]	7952	delivery	5	14
20825	2019-12-28 19:03:00	2019-12-28	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7948	delivery	5	45
20826	2019-12-28 19:05:20	2019-12-28	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1244	pick-up	0	29
20827	2019-12-28 19:46:16	2019-12-28	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	7980	delivery	5	28
20828	2019-12-28 19:56:40	2019-12-28	9	[{"id_menu":6,"count":1}]	1934	pick-up	0	9
20829	2019-12-28 19:59:04	2019-12-28	17	[{"id_menu":4,"count":1}]	7270	pick-up	0	17
20830	2019-12-28 20:00:08	2019-12-28	12	[{"id_menu":1,"count":2}]	7950	delivery	5	17
20831	2019-12-28 20:11:48	2019-12-28	12	[{"id_menu":3,"count":1}]	7342	delivery	5	17
20832	2019-12-28 20:22:18	2019-12-28	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	832	pick-up	0	35
20833	2019-12-28 20:30:06	2019-12-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8006	delivery	5	22
20834	2019-12-28 20:31:38	2019-12-28	12	[{"id_menu":3,"count":1}]	6497	pick-up	0	12
20835	2019-12-28 20:42:45	2019-12-28	17	[{"id_menu":4,"count":1}]	8030	delivery	5	22
20836	2019-12-28 20:47:02	2019-12-28	12	[{"id_menu":3,"count":1}]	7958	delivery	5	17
20837	2019-12-28 20:53:13	2019-12-28	8	[{"id_menu":5,"count":1}]	7984	delivery	5	13
20838	2019-12-28 21:00:40	2019-12-28	9	[{"id_menu":7,"count":1}]	274	pick-up	0	9
20839	2019-12-28 21:00:48	2019-12-28	9	[{"id_menu":6,"count":1}]	1245	pick-up	0	9
20840	2019-12-28 21:22:25	2019-12-28	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	7960	pick-up	0	21
20841	2019-12-28 21:29:02	2019-12-28	9	[{"id_menu":7,"count":1}]	7966	delivery	5	14
20842	2019-12-28 21:29:21	2019-12-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2633	pick-up	0	17
20843	2019-12-28 21:36:52	2019-12-28	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2492	delivery	5	31
20844	2019-12-28 21:44:01	2019-12-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	8018	pick-up	0	23
20845	2019-12-28 21:48:04	2019-12-28	12	[{"id_menu":3,"count":1}]	4874	delivery	5	17
20846	2019-12-28 21:51:39	2019-12-28	9	[{"id_menu":6,"count":1}]	7964	delivery	5	14
20847	2019-12-28 21:58:11	2019-12-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5575	delivery	5	23
20848	2019-12-28 21:59:33	2019-12-28	9	[{"id_menu":6,"count":1}]	5668	pick-up	0	9
20849	2019-12-28 22:02:35	2019-12-28	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	8017	delivery	5	26
20850	2019-12-28 22:06:01	2019-12-28	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	7990	delivery	5	23
20851	2019-12-28 22:21:23	2019-12-28	12	[{"id_menu":1,"count":1}]	1771	delivery	5	17
20852	2019-12-28 22:32:32	2019-12-28	17	[{"id_menu":4,"count":1}]	413	pick-up	0	17
20853	2019-12-28 22:42:53	2019-12-28	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1076	pick-up	0	26
20854	2019-12-28 22:43:45	2019-12-28	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	8024	delivery	5	25
20855	2019-12-28 22:46:07	2019-12-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6641	pick-up	0	26
20856	2019-12-28 22:55:13	2019-12-28	14	[{"id_menu":2,"count":1}]	8002	delivery	5	19
20857	2019-12-28 22:56:38	2019-12-28	9	[{"id_menu":7,"count":1}]	3360	delivery	5	14
20858	2019-12-28 23:02:57	2019-12-28	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8034	delivery	5	36
20859	2019-12-28 23:23:51	2019-12-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	5356	delivery	5	22
20860	2019-12-28 23:27:26	2019-12-28	14	[{"id_menu":2,"count":1}]	5292	pick-up	0	14
20861	2019-12-28 23:29:03	2019-12-28	17	[{"id_menu":4,"count":1}]	8027	delivery	5	22
20862	2019-12-28 23:33:41	2019-12-28	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7979	delivery	5	36
20863	2019-12-28 23:36:46	2019-12-28	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	7945	pick-up	0	21
20864	2019-12-28 23:45:48	2019-12-28	14	[{"id_menu":2,"count":1}]	1523	pick-up	0	14
20865	2019-12-29 00:10:17	2019-12-29	12	[{"id_menu":1,"count":1}]	2911	pick-up	0	12
20866	2019-12-29 00:16:56	2019-12-29	12	[{"id_menu":3,"count":2}]	396	delivery	5	17
20867	2019-12-29 00:18:39	2019-12-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3863	delivery	5	23
20868	2019-12-29 00:21:10	2019-12-29	12	[{"id_menu":3,"count":1}]	8074	delivery	5	17
20869	2019-12-29 00:25:59	2019-12-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8082	delivery	5	28
20870	2019-12-29 00:34:30	2019-12-29	8	[{"id_menu":5,"count":1}]	8098	delivery	5	13
20871	2019-12-29 00:38:43	2019-12-29	9	[{"id_menu":6,"count":1}]	2458	delivery	5	14
20872	2019-12-29 00:48:04	2019-12-29	8	[{"id_menu":5,"count":1}]	6873	delivery	5	13
20873	2019-12-29 01:01:14	2019-12-29	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8069	delivery	5	42
20874	2019-12-29 01:01:24	2019-12-29	9	[{"id_menu":7,"count":1}]	8039	pick-up	0	9
20875	2019-12-29 01:04:36	2019-12-29	14	[{"id_menu":2,"count":1}]	8063	delivery	5	19
20876	2019-12-29 01:14:50	2019-12-29	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	187	pick-up	0	29
20877	2019-12-29 01:17:46	2019-12-29	9	[{"id_menu":6,"count":1}]	1811	pick-up	0	9
20878	2019-12-29 01:29:04	2019-12-29	14	[{"id_menu":2,"count":1}]	2189	pick-up	0	14
20879	2019-12-29 01:30:18	2019-12-29	9	[{"id_menu":7,"count":1}]	1119	pick-up	0	9
20880	2019-12-29 01:43:55	2019-12-29	8	[{"id_menu":5,"count":1}]	8062	delivery	5	13
20881	2019-12-29 02:00:20	2019-12-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	6515	delivery	5	26
20882	2019-12-29 02:02:17	2019-12-29	17	[{"id_menu":4,"count":1}]	5072	delivery	5	22
20883	2019-12-29 02:04:16	2019-12-29	17	[{"id_menu":4,"count":1}]	6511	pick-up	0	17
20884	2019-12-29 02:18:03	2019-12-29	9	[{"id_menu":7,"count":1}]	32	pick-up	0	9
20885	2019-12-29 02:35:40	2019-12-29	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	5994	delivery	5	48
20886	2019-12-29 02:36:31	2019-12-29	8	[{"id_menu":5,"count":1}]	898	delivery	5	13
20887	2019-12-29 02:38:33	2019-12-29	12	[{"id_menu":1,"count":1}]	2627	pick-up	0	12
20888	2019-12-29 03:02:26	2019-12-29	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	4566	pick-up	0	31
20889	2019-12-29 03:06:35	2019-12-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3759	delivery	5	27
20890	2019-12-29 03:13:35	2019-12-29	14	[{"id_menu":2,"count":1}]	932	delivery	5	19
20891	2019-12-29 03:14:25	2019-12-29	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4060	delivery	5	35
20892	2019-12-29 03:17:48	2019-12-29	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7529	delivery	5	40
20893	2019-12-29 03:24:13	2019-12-29	14	[{"id_menu":2,"count":1}]	1206	delivery	5	19
20894	2019-12-29 03:24:26	2019-12-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	5500	delivery	5	26
20895	2019-12-29 03:25:43	2019-12-29	9	[{"id_menu":7,"count":1}]	8071	delivery	5	14
20896	2019-12-29 03:29:11	2019-12-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	4636	pick-up	0	21
20897	2019-12-29 03:31:50	2019-12-29	12	[{"id_menu":3,"count":1}]	281	pick-up	0	12
20898	2019-12-29 03:48:01	2019-12-29	9	[{"id_menu":7,"count":2}]	431	pick-up	0	9
20899	2019-12-29 03:54:23	2019-12-29	9	[{"id_menu":6,"count":1}]	8047	delivery	5	14
20900	2019-12-29 03:55:14	2019-12-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	496	delivery	5	22
20901	2019-12-29 04:07:03	2019-12-29	17	[{"id_menu":4,"count":1}]	2522	pick-up	0	17
20902	2019-12-29 04:09:31	2019-12-29	12	[{"id_menu":1,"count":1}]	5099	pick-up	0	12
20903	2019-12-29 04:10:48	2019-12-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	8095	delivery	5	27
20904	2019-12-29 04:11:59	2019-12-29	8	[{"id_menu":5,"count":1}]	8099	delivery	5	13
20905	2019-12-29 04:19:41	2019-12-29	17	[{"id_menu":4,"count":1}]	8088	pick-up	0	17
20906	2019-12-29 04:25:41	2019-12-29	8	[{"id_menu":5,"count":1}]	8104	pick-up	0	8
20907	2019-12-29 04:35:48	2019-12-29	14	[{"id_menu":2,"count":1}]	2989	delivery	5	19
20908	2019-12-29 04:36:13	2019-12-29	9	[{"id_menu":6,"count":1}]	4874	pick-up	0	9
20909	2019-12-29 04:37:36	2019-12-29	12	[{"id_menu":1,"count":1}]	5935	delivery	5	17
20910	2019-12-29 04:38:14	2019-12-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	8094	delivery	5	28
20911	2019-12-29 04:40:50	2019-12-29	17	[{"id_menu":4,"count":2}]	8090	pick-up	0	17
20912	2019-12-29 04:43:24	2019-12-29	12	[{"id_menu":3,"count":1}]	7854	delivery	5	17
20913	2019-12-29 04:43:39	2019-12-29	9	[{"id_menu":7,"count":1}]	8105	delivery	5	14
20914	2019-12-29 04:48:17	2019-12-29	12	[{"id_menu":3,"count":1}]	8056	delivery	5	17
20915	2019-12-29 05:05:09	2019-12-29	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	7587	delivery	5	22
20916	2019-12-29 05:08:30	2019-12-29	9	[{"id_menu":7,"count":1}]	2320	pick-up	0	9
20917	2019-12-29 05:14:14	2019-12-29	9	[{"id_menu":7,"count":1}]	3805	delivery	5	14
20918	2019-12-29 05:15:40	2019-12-29	17	[{"id_menu":4,"count":1}]	8078	pick-up	0	17
20919	2019-12-29 05:27:35	2019-12-29	14	[{"id_menu":2,"count":1}]	878	delivery	5	19
20920	2019-12-29 05:32:09	2019-12-29	9	[{"id_menu":7,"count":1}]	8040	delivery	5	14
20921	2019-12-29 05:37:11	2019-12-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	4262	delivery	5	22
20922	2019-12-29 05:37:43	2019-12-29	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	8044	delivery	5	42
20923	2019-12-29 05:42:00	2019-12-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3614	delivery	5	36
20924	2019-12-29 05:51:13	2019-12-29	12	[{"id_menu":1,"count":1}]	4721	pick-up	0	12
20925	2019-12-29 05:56:19	2019-12-29	12	[{"id_menu":3,"count":1}]	173	pick-up	0	12
20926	2019-12-29 06:01:59	2019-12-29	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6202	pick-up	0	40
20927	2019-12-29 06:03:46	2019-12-29	17	[{"id_menu":4,"count":1}]	2180	delivery	5	22
20928	2019-12-29 06:18:31	2019-12-29	12	[{"id_menu":3,"count":1}]	378	pick-up	0	12
20929	2019-12-29 06:19:28	2019-12-29	9	[{"id_menu":6,"count":1}]	3146	pick-up	0	9
20930	2019-12-29 06:21:04	2019-12-29	14	[{"id_menu":2,"count":2}]	2107	pick-up	0	14
20931	2019-12-29 06:38:20	2019-12-29	17	[{"id_menu":4,"count":1}]	8081	delivery	5	22
20932	2019-12-29 06:41:06	2019-12-29	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	8042	delivery	5	26
20933	2019-12-29 06:41:19	2019-12-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8058	pick-up	0	18
20934	2019-12-29 06:41:23	2019-12-29	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	8065	delivery	5	31
20935	2019-12-29 06:56:30	2019-12-29	9	[{"id_menu":6,"count":2}]	850	pick-up	0	9
20936	2019-12-29 07:00:26	2019-12-29	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	8060	delivery	5	26
20937	2019-12-29 07:05:44	2019-12-29	14	[{"id_menu":2,"count":1}]	7156	delivery	5	19
20938	2019-12-29 07:15:00	2019-12-29	9	[{"id_menu":7,"count":1}]	2863	pick-up	0	9
20939	2019-12-29 07:28:44	2019-12-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8038	delivery	5	31
20940	2019-12-29 07:39:22	2019-12-29	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	7906	delivery	5	22
20941	2019-12-29 07:39:59	2019-12-29	9	[{"id_menu":6,"count":1}]	2227	pick-up	0	9
20942	2019-12-29 07:46:01	2019-12-29	14	[{"id_menu":2,"count":1}]	8061	delivery	5	19
20943	2019-12-29 07:46:27	2019-12-29	9	[{"id_menu":6,"count":1}]	4943	delivery	5	14
20944	2019-12-29 08:06:56	2019-12-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8076	delivery	5	23
20945	2019-12-29 08:08:31	2019-12-29	9	[{"id_menu":7,"count":1}]	1999	pick-up	0	9
20946	2019-12-29 08:15:55	2019-12-29	17	[{"id_menu":4,"count":1}]	2413	pick-up	0	17
20947	2019-12-29 08:22:52	2019-12-29	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	4186	delivery	5	39
20948	2019-12-29 08:23:57	2019-12-29	9	[{"id_menu":6,"count":1}]	8055	delivery	5	14
20949	2019-12-29 08:35:34	2019-12-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7249	delivery	5	22
20950	2019-12-29 08:36:20	2019-12-29	12	[{"id_menu":1,"count":1}]	5064	delivery	5	17
20951	2019-12-29 08:47:24	2019-12-29	9	[{"id_menu":6,"count":1}]	4498	delivery	5	14
20952	2019-12-29 08:49:01	2019-12-29	9	[{"id_menu":6,"count":1}]	8101	delivery	5	14
20953	2019-12-29 08:49:44	2019-12-29	9	[{"id_menu":7,"count":1}]	8092	delivery	5	14
20954	2019-12-29 09:11:11	2019-12-29	9	[{"id_menu":7,"count":1}]	4264	delivery	5	14
20955	2019-12-29 09:14:20	2019-12-29	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4256	pick-up	0	31
20956	2019-12-29 09:26:19	2019-12-29	17	[{"id_menu":4,"count":1}]	8075	pick-up	0	17
20957	2019-12-29 09:34:56	2019-12-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3817	pick-up	0	23
20958	2019-12-29 09:38:37	2019-12-29	12	[{"id_menu":3,"count":1}]	628	delivery	5	17
20959	2019-12-29 09:42:02	2019-12-29	8	[{"id_menu":5,"count":1}]	8085	delivery	5	13
20960	2019-12-29 09:43:14	2019-12-29	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	8041	delivery	5	36
20961	2019-12-29 09:55:03	2019-12-29	12	[{"id_menu":1,"count":1}]	5728	pick-up	0	12
20962	2019-12-29 09:56:51	2019-12-29	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	239	pick-up	0	26
20963	2019-12-29 10:00:43	2019-12-29	17	[{"id_menu":4,"count":1}]	1337	pick-up	0	17
20964	2019-12-29 10:08:10	2019-12-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	8053	delivery	5	26
20965	2019-12-29 10:10:14	2019-12-29	8	[{"id_menu":5,"count":1}]	8106	delivery	5	13
20966	2019-12-29 10:12:01	2019-12-29	9	[{"id_menu":7,"count":1}]	8051	delivery	5	14
20967	2019-12-29 10:14:52	2019-12-29	9	[{"id_menu":6,"count":2}]	143	delivery	5	14
20968	2019-12-29 10:17:15	2019-12-29	9	[{"id_menu":7,"count":1}]	6869	pick-up	0	9
20969	2019-12-29 10:20:46	2019-12-29	12	[{"id_menu":3,"count":1}]	709	delivery	5	17
20970	2019-12-29 10:23:40	2019-12-29	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	959	pick-up	0	29
20971	2019-12-29 10:28:14	2019-12-29	14	[{"id_menu":2,"count":2}]	7745	pick-up	0	14
20972	2019-12-29 10:49:05	2019-12-29	12	[{"id_menu":3,"count":1}]	8109	pick-up	0	12
20973	2019-12-29 10:50:41	2019-12-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8087	delivery	5	36
20974	2019-12-29 11:00:07	2019-12-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	8059	delivery	5	22
20975	2019-12-29 11:01:02	2019-12-29	9	[{"id_menu":6,"count":1}]	4700	delivery	5	14
20976	2019-12-29 11:04:44	2019-12-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	8080	delivery	5	31
20977	2019-12-29 11:25:13	2019-12-29	14	[{"id_menu":2,"count":1}]	543	delivery	5	19
20978	2019-12-29 11:35:53	2019-12-29	9	[{"id_menu":7,"count":1}]	5379	delivery	5	14
20979	2019-12-29 11:45:59	2019-12-29	9	[{"id_menu":6,"count":1}]	8045	delivery	5	14
20980	2019-12-29 11:48:50	2019-12-29	9	[{"id_menu":7,"count":1}]	66	pick-up	0	9
20981	2019-12-29 11:51:03	2019-12-29	17	[{"id_menu":4,"count":1}]	2804	pick-up	0	17
20982	2019-12-29 11:51:18	2019-12-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	8103	delivery	5	22
20983	2019-12-29 11:56:49	2019-12-29	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	8067	delivery	5	40
20984	2019-12-29 12:10:11	2019-12-29	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	5484	delivery	5	40
20985	2019-12-29 12:19:07	2019-12-29	12	[{"id_menu":1,"count":1}]	3393	delivery	5	17
20986	2019-12-29 12:21:56	2019-12-29	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8048	pick-up	0	43
20987	2019-12-29 12:28:47	2019-12-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	7229	delivery	5	26
20988	2019-12-29 12:37:59	2019-12-29	8	[{"id_menu":5,"count":1}]	2755	delivery	5	13
20989	2019-12-29 12:54:56	2019-12-29	12	[{"id_menu":3,"count":1}]	5639	pick-up	0	12
20990	2019-12-29 13:03:13	2019-12-29	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1415	delivery	5	34
20991	2019-12-29 13:08:28	2019-12-29	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	8049	delivery	5	31
20992	2019-12-29 13:21:04	2019-12-29	9	[{"id_menu":7,"count":1}]	4533	pick-up	0	9
20993	2019-12-29 13:24:13	2019-12-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	8070	delivery	5	26
20994	2019-12-29 13:35:21	2019-12-29	9	[{"id_menu":7,"count":1}]	2004	delivery	5	14
20995	2019-12-29 13:44:52	2019-12-29	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	8036	delivery	5	38
20996	2019-12-29 14:00:25	2019-12-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8043	delivery	5	31
20997	2019-12-29 14:09:04	2019-12-29	9	[{"id_menu":6,"count":1}]	3651	delivery	5	14
20998	2019-12-29 14:13:20	2019-12-29	14	[{"id_menu":2,"count":1}]	832	pick-up	0	14
20999	2019-12-29 14:13:46	2019-12-29	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3919	pick-up	0	31
21000	2019-12-29 14:15:13	2019-12-29	12	[{"id_menu":1,"count":1}]	8096	delivery	5	17
21001	2019-12-29 14:16:22	2019-12-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2980	delivery	5	31
21002	2019-12-29 14:16:40	2019-12-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1078	delivery	5	28
21003	2019-12-29 14:17:48	2019-12-29	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	8066	delivery	5	26
21004	2019-12-29 14:19:20	2019-12-29	17	[{"id_menu":4,"count":1}]	138	delivery	5	22
21005	2019-12-29 14:20:53	2019-12-29	14	[{"id_menu":2,"count":2}]	4416	pick-up	0	14
21006	2019-12-29 14:27:01	2019-12-29	12	[{"id_menu":1,"count":2}]	4690	pick-up	0	12
21007	2019-12-29 14:28:12	2019-12-29	12	[{"id_menu":1,"count":1}]	1127	pick-up	0	12
21008	2019-12-29 14:34:48	2019-12-29	9	[{"id_menu":6,"count":1}]	165	delivery	5	14
21009	2019-12-29 14:36:51	2019-12-29	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3289	delivery	5	39
21010	2019-12-29 14:40:45	2019-12-29	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	4593	delivery	5	23
21011	2019-12-29 14:53:38	2019-12-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8107	delivery	5	22
21012	2019-12-29 14:53:55	2019-12-29	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	466	delivery	5	36
21013	2019-12-29 14:56:58	2019-12-29	8	[{"id_menu":5,"count":1}]	1021	delivery	5	13
21014	2019-12-29 14:57:06	2019-12-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4287	delivery	5	23
21015	2019-12-29 15:11:51	2019-12-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	6164	delivery	5	26
21016	2019-12-29 15:15:34	2019-12-29	8	[{"id_menu":5,"count":1}]	3125	delivery	5	13
21017	2019-12-29 15:16:30	2019-12-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1263	pick-up	0	17
21018	2019-12-29 15:17:45	2019-12-29	9	[{"id_menu":6,"count":1}]	1735	pick-up	0	9
21019	2019-12-29 15:32:39	2019-12-29	12	[{"id_menu":3,"count":1}]	600	delivery	5	17
21020	2019-12-29 15:38:56	2019-12-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	5006	delivery	5	26
21021	2019-12-29 15:43:44	2019-12-29	9	[{"id_menu":7,"count":1}]	7466	delivery	5	14
21022	2019-12-29 15:44:36	2019-12-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	3002	delivery	5	26
21023	2019-12-29 15:45:14	2019-12-29	9	[{"id_menu":7,"count":1}]	2081	delivery	5	14
21024	2019-12-29 15:46:15	2019-12-29	9	[{"id_menu":7,"count":1}]	8052	delivery	5	14
21025	2019-12-29 15:57:15	2019-12-29	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8073	delivery	5	40
21026	2019-12-29 16:04:58	2019-12-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	461	delivery	5	36
21027	2019-12-29 16:09:11	2019-12-29	9	[{"id_menu":7,"count":1}]	8077	pick-up	0	9
21028	2019-12-29 16:09:34	2019-12-29	9	[{"id_menu":7,"count":1}]	1762	delivery	5	14
21029	2019-12-29 16:12:35	2019-12-29	12	[{"id_menu":1,"count":1}]	207	pick-up	0	12
21030	2019-12-29 16:14:24	2019-12-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	5345	delivery	5	36
21031	2019-12-29 16:17:07	2019-12-29	14	[{"id_menu":2,"count":1}]	2083	pick-up	0	14
21032	2019-12-29 16:22:26	2019-12-29	14	[{"id_menu":2,"count":1}]	1615	delivery	5	19
21033	2019-12-29 16:26:18	2019-12-29	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	8046	pick-up	0	31
21034	2019-12-29 16:27:04	2019-12-29	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	8100	delivery	5	38
21035	2019-12-29 16:29:32	2019-12-29	9	[{"id_menu":6,"count":1}]	2089	pick-up	0	9
21036	2019-12-29 16:30:43	2019-12-29	14	[{"id_menu":2,"count":1}]	3909	pick-up	0	14
21037	2019-12-29 16:31:26	2019-12-29	9	[{"id_menu":6,"count":1}]	6807	pick-up	0	9
21038	2019-12-29 16:52:13	2019-12-29	17	[{"id_menu":4,"count":1}]	8068	pick-up	0	17
21039	2019-12-29 16:58:10	2019-12-29	12	[{"id_menu":3,"count":1}]	3478	pick-up	0	12
21040	2019-12-29 17:01:16	2019-12-29	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	424	pick-up	0	31
21041	2019-12-29 17:26:25	2019-12-29	17	[{"id_menu":4,"count":1}]	2065	pick-up	0	17
21042	2019-12-29 17:28:47	2019-12-29	14	[{"id_menu":2,"count":1}]	7768	delivery	5	19
21043	2019-12-29 17:39:13	2019-12-29	12	[{"id_menu":1,"count":1}]	4995	pick-up	0	12
21044	2019-12-29 17:51:48	2019-12-29	9	[{"id_menu":7,"count":1}]	722	pick-up	0	9
21045	2019-12-29 17:55:04	2019-12-29	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	944	delivery	5	45
21046	2019-12-29 17:55:46	2019-12-29	8	[{"id_menu":5,"count":1}]	8079	delivery	5	13
21047	2019-12-29 17:59:23	2019-12-29	14	[{"id_menu":2,"count":1}]	2519	pick-up	0	14
21048	2019-12-29 18:02:00	2019-12-29	17	[{"id_menu":4,"count":1}]	2294	pick-up	0	17
21049	2019-12-29 18:06:43	2019-12-29	9	[{"id_menu":6,"count":1}]	5406	pick-up	0	9
21050	2019-12-29 18:07:32	2019-12-29	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3705	delivery	5	26
21051	2019-12-29 18:10:17	2019-12-29	9	[{"id_menu":7,"count":1}]	7122	delivery	5	14
21052	2019-12-29 18:12:28	2019-12-29	17	[{"id_menu":4,"count":1}]	8064	delivery	5	22
21053	2019-12-29 18:15:17	2019-12-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8035	delivery	5	23
21054	2019-12-29 18:22:38	2019-12-29	17	[{"id_menu":4,"count":1}]	8089	delivery	5	22
21055	2019-12-29 18:22:56	2019-12-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4445	delivery	5	23
21056	2019-12-29 18:32:13	2019-12-29	8	[{"id_menu":5,"count":1}]	1618	pick-up	0	8
21057	2019-12-29 18:45:55	2019-12-29	14	[{"id_menu":2,"count":1}]	8037	delivery	5	19
21058	2019-12-29 18:52:52	2019-12-29	17	[{"id_menu":4,"count":1}]	2442	delivery	5	22
21059	2019-12-29 18:54:27	2019-12-29	17	[{"id_menu":4,"count":2}]	704	pick-up	0	17
21060	2019-12-29 18:56:45	2019-12-29	14	[{"id_menu":2,"count":1}]	6635	delivery	5	19
21061	2019-12-29 18:59:16	2019-12-29	9	[{"id_menu":7,"count":1}]	8084	delivery	5	14
21062	2019-12-29 19:24:12	2019-12-29	12	[{"id_menu":3,"count":1}]	8057	delivery	5	17
21063	2019-12-29 19:25:40	2019-12-29	12	[{"id_menu":3,"count":1}]	4543	delivery	5	17
21064	2019-12-29 19:49:37	2019-12-29	8	[{"id_menu":5,"count":1}]	322	delivery	5	13
21065	2019-12-29 20:14:55	2019-12-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	8097	delivery	5	28
21066	2019-12-29 20:21:00	2019-12-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4932	delivery	5	23
21067	2019-12-29 20:30:30	2019-12-29	9	[{"id_menu":6,"count":1}]	3636	pick-up	0	9
21068	2019-12-29 20:35:47	2019-12-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	536	delivery	5	23
21069	2019-12-29 20:39:41	2019-12-29	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2416	pick-up	0	43
21070	2019-12-29 20:46:14	2019-12-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	6154	delivery	5	22
21071	2019-12-29 20:49:21	2019-12-29	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8091	delivery	5	35
21072	2019-12-29 20:51:04	2019-12-29	12	[{"id_menu":1,"count":1}]	8086	pick-up	0	12
21073	2019-12-29 20:55:02	2019-12-29	14	[{"id_menu":2,"count":1}]	2608	delivery	5	19
21074	2019-12-29 21:01:46	2019-12-29	14	[{"id_menu":2,"count":1}]	1126	pick-up	0	14
21075	2019-12-29 21:07:56	2019-12-29	14	[{"id_menu":2,"count":1}]	1174	pick-up	0	14
21076	2019-12-29 21:18:39	2019-12-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5338	delivery	5	31
21077	2019-12-29 21:22:48	2019-12-29	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8093	delivery	5	43
21078	2019-12-29 21:28:46	2019-12-29	12	[{"id_menu":1,"count":1}]	8083	delivery	5	17
21079	2019-12-29 21:36:01	2019-12-29	9	[{"id_menu":6,"count":1}]	4902	delivery	5	14
21080	2019-12-29 21:43:28	2019-12-29	9	[{"id_menu":6,"count":1}]	4163	delivery	5	14
21081	2019-12-29 21:47:55	2019-12-29	14	[{"id_menu":2,"count":1}]	6283	delivery	5	19
21082	2019-12-29 21:50:28	2019-12-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1406	pick-up	0	17
21083	2019-12-29 21:52:04	2019-12-29	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	8054	delivery	5	31
21084	2019-12-29 21:55:44	2019-12-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	8050	delivery	5	28
21085	2019-12-29 21:56:43	2019-12-29	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3153	pick-up	0	43
21086	2019-12-29 22:05:27	2019-12-29	22	[{"id_menu":2,"count":3},{"id_menu":5,"count":1}]	55	pick-up	0	22
21087	2019-12-29 22:07:37	2019-12-29	14	[{"id_menu":2,"count":1}]	3996	delivery	5	19
21088	2019-12-29 22:08:24	2019-12-29	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	8072	delivery	5	31
21089	2019-12-29 22:19:29	2019-12-29	12	[{"id_menu":3,"count":1}]	2112	pick-up	0	12
21090	2019-12-29 22:20:01	2019-12-29	9	[{"id_menu":6,"count":1}]	6260	delivery	5	14
21091	2019-12-29 22:28:02	2019-12-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3686	pick-up	0	26
21092	2019-12-29 22:50:20	2019-12-29	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8108	delivery	5	37
21093	2019-12-29 22:57:10	2019-12-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	4311	delivery	5	22
21094	2019-12-29 23:02:20	2019-12-29	8	[{"id_menu":5,"count":1}]	1996	delivery	5	13
21095	2019-12-29 23:10:24	2019-12-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	1549	delivery	5	31
21096	2019-12-29 23:12:41	2019-12-29	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	676	delivery	5	37
21097	2019-12-29 23:15:05	2019-12-29	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	7361	pick-up	0	34
21098	2019-12-29 23:19:14	2019-12-29	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	4149	delivery	5	22
21099	2019-12-29 23:22:11	2019-12-29	12	[{"id_menu":1,"count":1}]	3864	pick-up	0	12
21100	2019-12-29 23:44:31	2019-12-29	14	[{"id_menu":2,"count":1}]	4685	pick-up	0	14
21101	2019-12-29 23:45:16	2019-12-29	9	[{"id_menu":6,"count":1}]	1352	pick-up	0	9
21102	2019-12-29 23:46:32	2019-12-29	8	[{"id_menu":5,"count":1}]	4628	pick-up	0	8
21103	2019-12-29 23:50:31	2019-12-29	12	[{"id_menu":3,"count":1}]	7849	delivery	5	17
21104	2019-12-29 23:51:10	2019-12-29	12	[{"id_menu":1,"count":2}]	3343	delivery	5	17
21105	2019-12-30 00:03:41	2019-12-30	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	7525	delivery	5	35
21106	2019-12-30 00:05:49	2019-12-30	12	[{"id_menu":3,"count":1}]	8112	delivery	5	17
21107	2019-12-30 00:06:29	2019-12-30	9	[{"id_menu":7,"count":2}]	8126	delivery	5	14
21108	2019-12-30 00:23:41	2019-12-30	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	3065	pick-up	0	26
21109	2019-12-30 00:45:37	2019-12-30	8	[{"id_menu":5,"count":1}]	7389	delivery	5	13
21110	2019-12-30 01:19:57	2019-12-30	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	4325	delivery	5	37
21111	2019-12-30 01:43:29	2019-12-30	14	[{"id_menu":2,"count":2}]	8169	pick-up	0	14
21112	2019-12-30 01:55:55	2019-12-30	12	[{"id_menu":1,"count":1}]	6689	delivery	5	17
21113	2019-12-30 02:02:55	2019-12-30	9	[{"id_menu":7,"count":1}]	5648	pick-up	0	9
21114	2019-12-30 02:34:25	2019-12-30	14	[{"id_menu":2,"count":1}]	2604	pick-up	0	14
21115	2019-12-30 02:37:38	2019-12-30	9	[{"id_menu":6,"count":1}]	8165	delivery	5	14
21116	2019-12-30 02:41:45	2019-12-30	9	[{"id_menu":6,"count":1}]	8181	delivery	5	14
21117	2019-12-30 02:54:56	2019-12-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3536	pick-up	0	26
21118	2019-12-30 02:58:24	2019-12-30	17	[{"id_menu":4,"count":1}]	1107	pick-up	0	17
21119	2019-12-30 03:03:27	2019-12-30	8	[{"id_menu":5,"count":1}]	7558	delivery	5	13
21120	2019-12-30 03:04:57	2019-12-30	9	[{"id_menu":6,"count":1}]	6289	delivery	5	14
21121	2019-12-30 03:12:24	2019-12-30	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	8185	pick-up	0	29
21122	2019-12-30 03:48:29	2019-12-30	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3540	delivery	5	51
21123	2019-12-30 03:49:32	2019-12-30	9	[{"id_menu":7,"count":1}]	5594	delivery	5	14
21124	2019-12-30 03:56:11	2019-12-30	9	[{"id_menu":7,"count":1}]	4274	delivery	5	14
21125	2019-12-30 04:10:36	2019-12-30	9	[{"id_menu":7,"count":1}]	8128	delivery	5	14
21126	2019-12-30 04:12:08	2019-12-30	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3684	delivery	5	40
21127	2019-12-30 04:17:23	2019-12-30	8	[{"id_menu":5,"count":1}]	8125	delivery	5	13
21128	2019-12-30 04:36:30	2019-12-30	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8129	delivery	5	36
21129	2019-12-30 04:37:14	2019-12-30	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	3567	pick-up	0	20
21130	2019-12-30 04:50:16	2019-12-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7383	pick-up	0	23
21131	2019-12-30 04:53:37	2019-12-30	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	8164	delivery	5	31
21132	2019-12-30 05:02:50	2019-12-30	12	[{"id_menu":1,"count":1}]	356	pick-up	0	12
21133	2019-12-30 05:07:19	2019-12-30	12	[{"id_menu":3,"count":1}]	5347	delivery	5	17
21134	2019-12-30 05:16:11	2019-12-30	9	[{"id_menu":6,"count":1}]	8187	delivery	5	14
21135	2019-12-30 05:23:02	2019-12-30	12	[{"id_menu":3,"count":1}]	8177	delivery	5	17
21136	2019-12-30 06:21:16	2019-12-30	8	[{"id_menu":5,"count":1}]	2450	pick-up	0	8
21137	2019-12-30 06:37:07	2019-12-30	17	[{"id_menu":4,"count":1}]	4193	pick-up	0	17
21138	2019-12-30 06:49:21	2019-12-30	8	[{"id_menu":5,"count":1}]	3847	pick-up	0	8
21139	2019-12-30 06:49:56	2019-12-30	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	340	pick-up	0	26
21140	2019-12-30 07:01:45	2019-12-30	17	[{"id_menu":4,"count":1}]	6446	delivery	5	22
21141	2019-12-30 07:07:09	2019-12-30	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	8157	delivery	5	28
21142	2019-12-30 07:19:14	2019-12-30	14	[{"id_menu":2,"count":1}]	3666	delivery	5	19
21143	2019-12-30 07:26:29	2019-12-30	8	[{"id_menu":5,"count":1}]	8113	delivery	5	13
21144	2019-12-30 07:29:52	2019-12-30	9	[{"id_menu":6,"count":1}]	4931	delivery	5	14
21145	2019-12-30 07:58:57	2019-12-30	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2312	delivery	5	40
21146	2019-12-30 08:01:41	2019-12-30	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	6901	pick-up	0	29
21147	2019-12-30 08:11:05	2019-12-30	9	[{"id_menu":6,"count":1}]	871	delivery	5	14
21148	2019-12-30 08:14:41	2019-12-30	17	[{"id_menu":4,"count":1}]	8182	delivery	5	22
21149	2019-12-30 08:17:39	2019-12-30	12	[{"id_menu":1,"count":1}]	2076	delivery	5	17
21150	2019-12-30 08:32:08	2019-12-30	9	[{"id_menu":6,"count":1}]	8122	delivery	5	14
21151	2019-12-30 08:41:11	2019-12-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8132	delivery	5	23
21152	2019-12-30 08:54:58	2019-12-30	12	[{"id_menu":1,"count":1}]	3224	delivery	5	17
21153	2019-12-30 08:59:47	2019-12-30	9	[{"id_menu":7,"count":1}]	788	pick-up	0	9
21154	2019-12-30 09:20:45	2019-12-30	17	[{"id_menu":4,"count":1}]	6552	pick-up	0	17
21155	2019-12-30 09:23:24	2019-12-30	12	[{"id_menu":1,"count":1}]	8127	pick-up	0	12
21156	2019-12-30 09:54:38	2019-12-30	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	1321	pick-up	0	29
21157	2019-12-30 10:08:49	2019-12-30	14	[{"id_menu":2,"count":1}]	8114	delivery	5	19
21158	2019-12-30 10:27:31	2019-12-30	8	[{"id_menu":5,"count":1}]	8172	delivery	5	13
21159	2019-12-30 10:29:59	2019-12-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2740	delivery	5	27
21160	2019-12-30 10:54:58	2019-12-30	8	[{"id_menu":5,"count":1}]	8162	delivery	5	13
21161	2019-12-30 10:58:05	2019-12-30	9	[{"id_menu":6,"count":1}]	8151	delivery	5	14
21162	2019-12-30 11:08:55	2019-12-30	14	[{"id_menu":2,"count":1}]	2862	pick-up	0	14
21163	2019-12-30 11:09:46	2019-12-30	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	8120	delivery	5	31
21164	2019-12-30 11:16:22	2019-12-30	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4601	delivery	5	43
21165	2019-12-30 11:22:43	2019-12-30	14	[{"id_menu":2,"count":1}]	1055	delivery	5	19
21166	2019-12-30 11:28:20	2019-12-30	9	[{"id_menu":6,"count":1}]	2374	pick-up	0	9
21167	2019-12-30 11:53:36	2019-12-30	9	[{"id_menu":6,"count":1}]	8184	delivery	5	14
21168	2019-12-30 12:36:02	2019-12-30	8	[{"id_menu":5,"count":1}]	8124	delivery	5	13
21169	2019-12-30 12:54:24	2019-12-30	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	5326	pick-up	0	21
21170	2019-12-30 13:49:17	2019-12-30	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	6579	delivery	5	28
21171	2019-12-30 13:50:32	2019-12-30	12	[{"id_menu":1,"count":1}]	8145	pick-up	0	12
21172	2019-12-30 14:03:05	2019-12-30	9	[{"id_menu":6,"count":1}]	8176	delivery	5	14
21173	2019-12-30 14:09:22	2019-12-30	9	[{"id_menu":7,"count":2}]	8178	delivery	5	14
21174	2019-12-30 14:11:09	2019-12-30	17	[{"id_menu":4,"count":1}]	1342	delivery	5	22
21175	2019-12-30 14:14:42	2019-12-30	12	[{"id_menu":3,"count":1}]	2780	pick-up	0	12
21176	2019-12-30 14:16:26	2019-12-30	14	[{"id_menu":2,"count":1}]	719	pick-up	0	14
21177	2019-12-30 14:35:33	2019-12-30	14	[{"id_menu":2,"count":2}]	8158	delivery	5	19
21178	2019-12-30 14:38:20	2019-12-30	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	8138	delivery	5	39
21179	2019-12-30 14:53:50	2019-12-30	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	1146	delivery	5	48
21180	2019-12-30 15:13:10	2019-12-30	8	[{"id_menu":5,"count":1}]	7125	delivery	5	13
21181	2019-12-30 15:27:58	2019-12-30	12	[{"id_menu":3,"count":1}]	1883	pick-up	0	12
21182	2019-12-30 16:03:12	2019-12-30	12	[{"id_menu":3,"count":1}]	8167	delivery	5	17
21183	2019-12-30 16:04:29	2019-12-30	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8160	delivery	5	31
21184	2019-12-30 16:04:42	2019-12-30	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	8024	delivery	5	34
21185	2019-12-30 16:11:34	2019-12-30	9	[{"id_menu":6,"count":1}]	4793	delivery	5	14
21186	2019-12-30 16:45:04	2019-12-30	14	[{"id_menu":2,"count":1}]	8153	pick-up	0	14
21187	2019-12-30 17:01:12	2019-12-30	17	[{"id_menu":4,"count":1}]	8137	pick-up	0	17
21188	2019-12-30 17:21:19	2019-12-30	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8147	delivery	5	34
21189	2019-12-30 17:24:17	2019-12-30	14	[{"id_menu":2,"count":3}]	8163	delivery	5	19
21190	2019-12-30 17:27:35	2019-12-30	9	[{"id_menu":7,"count":2}]	6922	delivery	5	14
21191	2019-12-30 17:32:39	2019-12-30	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8186	delivery	5	30
21192	2019-12-30 17:39:21	2019-12-30	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	8179	delivery	5	39
21193	2019-12-30 17:42:38	2019-12-30	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5808	pick-up	0	40
21194	2019-12-30 17:46:36	2019-12-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	8115	pick-up	0	23
21195	2019-12-30 17:51:37	2019-12-30	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	8045	delivery	5	40
21196	2019-12-30 18:03:42	2019-12-30	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	6467	delivery	5	22
21197	2019-12-30 18:17:29	2019-12-30	17	[{"id_menu":4,"count":1}]	5489	delivery	5	22
21198	2019-12-30 18:25:21	2019-12-30	9	[{"id_menu":7,"count":1}]	6185	delivery	5	14
21199	2019-12-30 18:43:23	2019-12-30	17	[{"id_menu":4,"count":1}]	5667	delivery	5	22
21200	2019-12-30 18:51:27	2019-12-30	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8139	delivery	5	43
21201	2019-12-30 18:57:46	2019-12-30	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	6074	pick-up	0	21
21202	2019-12-30 19:01:49	2019-12-30	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	8175	delivery	5	22
21203	2019-12-30 19:39:42	2019-12-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8142	delivery	5	28
21204	2019-12-30 19:57:53	2019-12-30	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	7582	pick-up	0	21
21205	2019-12-30 20:26:03	2019-12-30	12	[{"id_menu":1,"count":1}]	6586	delivery	5	17
21206	2019-12-30 20:58:08	2019-12-30	9	[{"id_menu":6,"count":1}]	8152	pick-up	0	9
21207	2019-12-30 21:03:34	2019-12-30	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8146	pick-up	0	25
21208	2019-12-30 21:11:35	2019-12-30	8	[{"id_menu":5,"count":1}]	6248	delivery	5	13
21209	2019-12-30 21:16:01	2019-12-30	9	[{"id_menu":6,"count":2}]	6710	delivery	5	14
21210	2019-12-30 21:18:14	2019-12-30	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	585	delivery	5	39
21211	2019-12-30 21:34:33	2019-12-30	9	[{"id_menu":6,"count":1}]	8155	delivery	5	14
21212	2019-12-30 21:50:33	2019-12-30	12	[{"id_menu":3,"count":1}]	7097	delivery	5	17
21213	2019-12-30 21:53:16	2019-12-30	12	[{"id_menu":1,"count":1}]	6121	delivery	5	17
21214	2019-12-30 22:17:12	2019-12-30	12	[{"id_menu":1,"count":1}]	5387	delivery	5	17
21215	2019-12-30 22:23:49	2019-12-30	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	8130	delivery	5	40
21216	2019-12-30 22:30:18	2019-12-30	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8180	delivery	5	37
21217	2019-12-30 22:31:09	2019-12-30	17	[{"id_menu":4,"count":1}]	4143	delivery	5	22
21218	2019-12-30 23:04:57	2019-12-30	8	[{"id_menu":5,"count":1}]	8166	delivery	5	13
21219	2019-12-30 23:26:09	2019-12-30	12	[{"id_menu":3,"count":1}]	1627	pick-up	0	12
21220	2019-12-30 23:35:31	2019-12-30	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1293	delivery	5	26
21221	2019-12-30 23:51:31	2019-12-30	8	[{"id_menu":5,"count":1}]	5839	delivery	5	13
21222	2019-12-30 23:53:36	2019-12-30	14	[{"id_menu":2,"count":1}]	2968	pick-up	0	14
21223	2019-12-30 23:56:29	2019-12-30	9	[{"id_menu":7,"count":1}]	8135	delivery	5	14
21224	2019-12-30 23:58:48	2019-12-30	9	[{"id_menu":6,"count":2}]	7633	delivery	5	14
21225	2019-12-31 00:07:22	2019-12-31	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1200	delivery	5	22
21226	2019-12-31 00:13:15	2019-12-31	17	[{"id_menu":4,"count":1}]	7533	delivery	5	22
21227	2019-12-31 00:38:42	2019-12-31	9	[{"id_menu":7,"count":1}]	8242	delivery	5	14
21228	2019-12-31 01:03:31	2019-12-31	9	[{"id_menu":7,"count":1}]	8193	delivery	5	14
21229	2019-12-31 01:39:46	2019-12-31	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7156	pick-up	0	26
21230	2019-12-31 01:44:16	2019-12-31	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4929	delivery	5	31
21231	2019-12-31 01:49:59	2019-12-31	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1994	delivery	5	43
21232	2019-12-31 01:50:10	2019-12-31	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	8231	delivery	5	28
21233	2019-12-31 02:10:16	2019-12-31	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	3380	pick-up	0	26
21234	2019-12-31 02:10:30	2019-12-31	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	8247	delivery	5	36
21235	2019-12-31 02:25:37	2019-12-31	17	[{"id_menu":4,"count":1}]	3948	delivery	5	22
21236	2019-12-31 02:27:24	2019-12-31	12	[{"id_menu":1,"count":1}]	7834	pick-up	0	12
21237	2019-12-31 02:33:20	2019-12-31	12	[{"id_menu":3,"count":1}]	1314	pick-up	0	12
21238	2019-12-31 02:46:54	2019-12-31	9	[{"id_menu":7,"count":1}]	8232	pick-up	0	9
21239	2019-12-31 02:57:55	2019-12-31	14	[{"id_menu":2,"count":1}]	2855	pick-up	0	14
21240	2019-12-31 03:02:38	2019-12-31	9	[{"id_menu":6,"count":1}]	4850	pick-up	0	9
21241	2019-12-31 03:11:04	2019-12-31	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	8084	delivery	5	26
21242	2019-12-31 03:13:59	2019-12-31	14	[{"id_menu":2,"count":1}]	2507	delivery	5	19
21243	2019-12-31 03:14:28	2019-12-31	12	[{"id_menu":1,"count":1}]	5019	pick-up	0	12
21244	2019-12-31 03:18:51	2019-12-31	12	[{"id_menu":1,"count":1}]	1181	pick-up	0	12
21245	2019-12-31 03:36:00	2019-12-31	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	381	delivery	5	31
21246	2019-12-31 04:05:16	2019-12-31	12	[{"id_menu":1,"count":1}]	2390	delivery	5	17
21247	2019-12-31 04:15:36	2019-12-31	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	5066	delivery	5	36
21248	2019-12-31 04:17:35	2019-12-31	12	[{"id_menu":3,"count":1}]	8257	delivery	5	17
21249	2019-12-31 04:26:36	2019-12-31	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1833	delivery	5	30
21250	2019-12-31 04:28:29	2019-12-31	9	[{"id_menu":7,"count":1}]	2313	pick-up	0	9
21251	2019-12-31 04:28:45	2019-12-31	17	[{"id_menu":4,"count":3}]	6764	delivery	5	22
21252	2019-12-31 04:34:16	2019-12-31	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8266	delivery	5	31
21253	2019-12-31 04:37:47	2019-12-31	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	8206	delivery	5	26
21254	2019-12-31 04:44:38	2019-12-31	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	1893	delivery	5	30
21255	2019-12-31 04:50:27	2019-12-31	17	[{"id_menu":4,"count":1}]	7616	delivery	5	22
21256	2019-12-31 04:56:15	2019-12-31	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6053	delivery	5	28
21257	2019-12-31 04:57:46	2019-12-31	12	[{"id_menu":3,"count":1}]	7591	pick-up	0	12
21258	2019-12-31 05:07:28	2019-12-31	17	[{"id_menu":4,"count":1}]	1863	delivery	5	22
21259	2019-12-31 05:21:32	2019-12-31	8	[{"id_menu":5,"count":1}]	8217	delivery	5	13
21260	2019-12-31 05:57:44	2019-12-31	8	[{"id_menu":5,"count":1}]	8244	delivery	5	13
21261	2019-12-31 06:05:12	2019-12-31	12	[{"id_menu":3,"count":1}]	2976	delivery	5	17
21262	2019-12-31 06:09:30	2019-12-31	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	8254	delivery	5	26
21263	2019-12-31 06:14:04	2019-12-31	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7131	delivery	5	43
21264	2019-12-31 06:44:16	2019-12-31	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	8196	delivery	5	26
21265	2019-12-31 06:48:49	2019-12-31	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1213	pick-up	0	38
21266	2019-12-31 07:04:50	2019-12-31	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8197	delivery	5	42
21267	2019-12-31 07:16:45	2019-12-31	12	[{"id_menu":1,"count":1}]	2144	delivery	5	17
21268	2019-12-31 07:17:32	2019-12-31	17	[{"id_menu":4,"count":1}]	6197	delivery	5	22
21269	2019-12-31 07:18:48	2019-12-31	12	[{"id_menu":3,"count":1}]	1674	delivery	5	17
21270	2019-12-31 07:21:10	2019-12-31	9	[{"id_menu":6,"count":1}]	8236	delivery	5	14
21271	2019-12-31 07:32:09	2019-12-31	12	[{"id_menu":1,"count":1}]	8263	delivery	5	17
21272	2019-12-31 07:40:27	2019-12-31	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4622	delivery	5	27
21273	2019-12-31 07:45:38	2019-12-31	17	[{"id_menu":4,"count":1}]	7796	delivery	5	22
21274	2019-12-31 07:59:39	2019-12-31	17	[{"id_menu":4,"count":1}]	8224	pick-up	0	17
21275	2019-12-31 08:05:26	2019-12-31	9	[{"id_menu":7,"count":1}]	5397	delivery	5	14
21276	2019-12-31 08:07:41	2019-12-31	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6342	pick-up	0	39
21277	2019-12-31 08:10:25	2019-12-31	8	[{"id_menu":5,"count":1}]	4054	delivery	5	13
21278	2019-12-31 08:13:26	2019-12-31	14	[{"id_menu":2,"count":2}]	1481	pick-up	0	14
21279	2019-12-31 08:51:19	2019-12-31	9	[{"id_menu":6,"count":1}]	6129	delivery	5	14
21280	2019-12-31 09:13:45	2019-12-31	14	[{"id_menu":2,"count":1}]	8199	delivery	5	19
21281	2019-12-31 09:44:02	2019-12-31	14	[{"id_menu":2,"count":1}]	8233	delivery	5	19
21282	2019-12-31 09:49:14	2019-12-31	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8237	pick-up	0	17
21283	2019-12-31 09:54:24	2019-12-31	9	[{"id_menu":7,"count":1}]	8200	delivery	5	14
21284	2019-12-31 09:55:04	2019-12-31	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	8208	pick-up	0	29
21285	2019-12-31 10:03:14	2019-12-31	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8191	delivery	5	22
21286	2019-12-31 10:07:54	2019-12-31	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1989	pick-up	0	29
21287	2019-12-31 10:08:01	2019-12-31	8	[{"id_menu":5,"count":2}]	8201	delivery	5	13
21288	2019-12-31 10:08:43	2019-12-31	14	[{"id_menu":2,"count":1}]	135	delivery	5	19
21289	2019-12-31 10:30:52	2019-12-31	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4996	pick-up	0	25
21290	2019-12-31 10:31:00	2019-12-31	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	4495	delivery	5	36
21291	2019-12-31 10:44:05	2019-12-31	14	[{"id_menu":2,"count":1}]	8251	pick-up	0	14
21292	2019-12-31 10:44:34	2019-12-31	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	8219	delivery	5	31
21293	2019-12-31 10:46:07	2019-12-31	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7918	pick-up	0	17
21294	2019-12-31 10:52:25	2019-12-31	9	[{"id_menu":7,"count":1}]	7054	delivery	5	14
21295	2019-12-31 11:19:47	2019-12-31	12	[{"id_menu":3,"count":1}]	37	pick-up	0	12
21296	2019-12-31 11:23:50	2019-12-31	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8205	pick-up	0	18
21297	2019-12-31 11:25:01	2019-12-31	9	[{"id_menu":7,"count":1}]	8229	pick-up	0	9
21298	2019-12-31 11:28:29	2019-12-31	12	[{"id_menu":3,"count":1}]	1370	pick-up	0	12
21299	2019-12-31 11:43:08	2019-12-31	17	[{"id_menu":4,"count":1}]	8192	delivery	5	22
21300	2019-12-31 11:54:14	2019-12-31	14	[{"id_menu":2,"count":1}]	8241	delivery	5	19
21301	2019-12-31 12:10:53	2019-12-31	9	[{"id_menu":7,"count":1}]	8258	delivery	5	14
21302	2019-12-31 12:13:27	2019-12-31	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2434	pick-up	0	41
21303	2019-12-31 12:22:20	2019-12-31	12	[{"id_menu":3,"count":1}]	8213	delivery	5	17
21304	2019-12-31 12:37:50	2019-12-31	8	[{"id_menu":5,"count":1}]	8222	pick-up	0	8
21305	2019-12-31 13:09:55	2019-12-31	12	[{"id_menu":1,"count":1}]	3634	delivery	5	17
21306	2019-12-31 13:12:33	2019-12-31	9	[{"id_menu":6,"count":1}]	1143	pick-up	0	9
21307	2019-12-31 13:13:31	2019-12-31	17	[{"id_menu":4,"count":1}]	8221	delivery	5	22
21308	2019-12-31 13:16:25	2019-12-31	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	8195	delivery	5	26
21309	2019-12-31 13:31:48	2019-12-31	17	[{"id_menu":4,"count":1}]	227	pick-up	0	17
21310	2019-12-31 13:45:30	2019-12-31	9	[{"id_menu":6,"count":1}]	6732	delivery	5	14
21311	2019-12-31 13:53:41	2019-12-31	14	[{"id_menu":2,"count":1}]	8226	delivery	5	19
21312	2019-12-31 14:09:43	2019-12-31	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1269	pick-up	0	35
21313	2019-12-31 14:10:00	2019-12-31	8	[{"id_menu":5,"count":1}]	4640	delivery	5	13
21314	2019-12-31 14:13:42	2019-12-31	9	[{"id_menu":6,"count":1}]	7960	delivery	5	14
21315	2019-12-31 14:21:14	2019-12-31	9	[{"id_menu":6,"count":1}]	3480	pick-up	0	9
21316	2019-12-31 14:21:37	2019-12-31	14	[{"id_menu":2,"count":1}]	1914	pick-up	0	14
21317	2019-12-31 14:26:56	2019-12-31	12	[{"id_menu":1,"count":1}]	8240	pick-up	0	12
21318	2019-12-31 14:39:03	2019-12-31	14	[{"id_menu":2,"count":1}]	7074	pick-up	0	14
21319	2019-12-31 14:42:20	2019-12-31	8	[{"id_menu":5,"count":1}]	2616	pick-up	0	8
21320	2019-12-31 14:45:45	2019-12-31	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	8210	delivery	5	23
21321	2019-12-31 14:45:59	2019-12-31	12	[{"id_menu":3,"count":1}]	8253	delivery	5	17
21322	2019-12-31 14:55:41	2019-12-31	8	[{"id_menu":5,"count":2}]	3641	delivery	5	13
21323	2019-12-31 14:57:31	2019-12-31	14	[{"id_menu":2,"count":1}]	5970	pick-up	0	14
21324	2019-12-31 14:57:48	2019-12-31	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2265	delivery	5	40
21325	2019-12-31 15:17:49	2019-12-31	14	[{"id_menu":2,"count":1}]	8260	delivery	5	19
21326	2019-12-31 15:18:54	2019-12-31	9	[{"id_menu":6,"count":1}]	8207	delivery	5	14
21327	2019-12-31 15:25:33	2019-12-31	9	[{"id_menu":6,"count":1}]	1068	pick-up	0	9
21328	2019-12-31 15:30:00	2019-12-31	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":2}]	8220	delivery	5	31
21329	2019-12-31 15:32:16	2019-12-31	9	[{"id_menu":7,"count":1}]	8243	delivery	5	14
21330	2019-12-31 15:33:59	2019-12-31	9	[{"id_menu":7,"count":1}]	8264	delivery	5	14
21331	2019-12-31 15:41:08	2019-12-31	14	[{"id_menu":2,"count":1}]	5534	delivery	5	19
21332	2019-12-31 15:46:26	2019-12-31	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8246	delivery	5	28
21333	2019-12-31 16:35:48	2019-12-31	9	[{"id_menu":6,"count":1}]	2107	delivery	5	14
21334	2019-12-31 16:44:50	2019-12-31	17	[{"id_menu":4,"count":1}]	8204	delivery	5	22
21335	2019-12-31 16:45:49	2019-12-31	14	[{"id_menu":2,"count":1}]	1169	pick-up	0	14
21336	2019-12-31 16:54:03	2019-12-31	12	[{"id_menu":3,"count":2}]	8262	delivery	5	17
21337	2019-12-31 16:58:12	2019-12-31	9	[{"id_menu":7,"count":1}]	29	pick-up	0	9
21338	2019-12-31 17:09:01	2019-12-31	14	[{"id_menu":2,"count":1}]	120	delivery	5	19
21339	2019-12-31 17:17:42	2019-12-31	14	[{"id_menu":2,"count":1}]	6372	delivery	5	19
21340	2019-12-31 17:22:37	2019-12-31	14	[{"id_menu":2,"count":1}]	8212	delivery	5	19
21341	2019-12-31 17:23:11	2019-12-31	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	8248	delivery	5	40
21342	2019-12-31 17:34:41	2019-12-31	12	[{"id_menu":1,"count":1}]	439	delivery	5	17
21343	2019-12-31 18:00:39	2019-12-31	9	[{"id_menu":6,"count":1}]	5144	delivery	5	14
21344	2019-12-31 18:13:11	2019-12-31	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8256	delivery	5	39
21345	2019-12-31 18:26:35	2019-12-31	9	[{"id_menu":7,"count":1}]	6851	pick-up	0	9
21346	2019-12-31 18:40:59	2019-12-31	12	[{"id_menu":1,"count":1}]	6885	delivery	5	17
21347	2019-12-31 18:49:56	2019-12-31	12	[{"id_menu":1,"count":1}]	4782	pick-up	0	12
21348	2019-12-31 18:56:50	2019-12-31	12	[{"id_menu":3,"count":1}]	6174	delivery	5	17
21349	2019-12-31 18:58:23	2019-12-31	8	[{"id_menu":5,"count":1}]	3192	pick-up	0	8
21350	2019-12-31 19:06:31	2019-12-31	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7387	delivery	5	53
21351	2019-12-31 19:08:19	2019-12-31	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	3820	pick-up	0	21
21352	2019-12-31 19:12:44	2019-12-31	14	[{"id_menu":2,"count":1}]	1070	pick-up	0	14
21353	2019-12-31 19:15:01	2019-12-31	9	[{"id_menu":6,"count":1}]	6090	delivery	5	14
21354	2019-12-31 19:19:58	2019-12-31	12	[{"id_menu":3,"count":1}]	8095	delivery	5	17
21355	2019-12-31 19:20:45	2019-12-31	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	8245	delivery	5	52
21356	2019-12-31 19:33:05	2019-12-31	12	[{"id_menu":3,"count":1}]	7766	pick-up	0	12
21357	2019-12-31 20:07:13	2019-12-31	12	[{"id_menu":1,"count":1}]	5604	delivery	5	17
21358	2019-12-31 20:09:57	2019-12-31	12	[{"id_menu":3,"count":1}]	6666	pick-up	0	12
21359	2019-12-31 20:16:02	2019-12-31	9	[{"id_menu":7,"count":1}]	8215	delivery	5	14
21360	2019-12-31 20:32:51	2019-12-31	8	[{"id_menu":5,"count":1}]	8211	delivery	5	13
21361	2019-12-31 20:53:11	2019-12-31	8	[{"id_menu":5,"count":1}]	5649	delivery	5	13
21362	2019-12-31 20:56:18	2019-12-31	9	[{"id_menu":7,"count":1}]	7358	delivery	5	14
21363	2019-12-31 21:05:43	2019-12-31	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8225	delivery	5	30
21364	2019-12-31 21:31:00	2019-12-31	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7480	pick-up	0	23
21365	2019-12-31 21:47:53	2019-12-31	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2491	delivery	5	23
21366	2019-12-31 21:58:21	2019-12-31	14	[{"id_menu":2,"count":1}]	3260	pick-up	0	14
21367	2019-12-31 21:59:46	2019-12-31	12	[{"id_menu":3,"count":1}]	1468	pick-up	0	12
21368	2019-12-31 22:19:16	2019-12-31	9	[{"id_menu":6,"count":1}]	1097	delivery	5	14
21369	2019-12-31 22:29:03	2019-12-31	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	436	pick-up	0	29
21370	2019-12-31 22:31:46	2019-12-31	9	[{"id_menu":7,"count":1}]	983	delivery	5	14
21371	2019-12-31 22:37:24	2019-12-31	17	[{"id_menu":4,"count":1}]	8218	delivery	5	22
21372	2019-12-31 22:37:46	2019-12-31	17	[{"id_menu":4,"count":1}]	2943	pick-up	0	17
21373	2019-12-31 22:41:30	2019-12-31	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1329	pick-up	0	51
21374	2019-12-31 22:46:39	2019-12-31	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1311	pick-up	0	26
21375	2019-12-31 22:55:19	2019-12-31	12	[{"id_menu":1,"count":1}]	745	delivery	5	17
21376	2019-12-31 23:11:24	2019-12-31	9	[{"id_menu":7,"count":1}]	8227	pick-up	0	9
21377	2019-12-31 23:13:43	2019-12-31	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	8234	delivery	5	27
21378	2019-12-31 23:47:30	2019-12-31	12	[{"id_menu":1,"count":1}]	8239	delivery	5	17
21379	2019-12-31 23:48:38	2019-12-31	9	[{"id_menu":6,"count":1}]	8202	delivery	5	14
21380	2019-12-31 23:52:10	2019-12-31	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7690	delivery	5	28
21381	2020-01-01 00:06:18	2020-01-01	8	[{"id_menu":5,"count":1}]	7049	delivery	5	13
21382	2020-01-01 00:18:24	2020-01-01	17	[{"id_menu":4,"count":1}]	8320	delivery	5	22
21383	2020-01-01 00:20:29	2020-01-01	17	[{"id_menu":4,"count":1}]	627	pick-up	0	17
21384	2020-01-01 00:22:56	2020-01-01	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	5758	pick-up	0	21
21385	2020-01-01 00:31:37	2020-01-01	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	6347	delivery	5	38
21386	2020-01-01 00:48:29	2020-01-01	9	[{"id_menu":6,"count":2}]	8325	delivery	5	14
21387	2020-01-01 00:58:39	2020-01-01	17	[{"id_menu":4,"count":1}]	4428	delivery	5	22
21388	2020-01-01 01:02:24	2020-01-01	17	[{"id_menu":4,"count":1}]	6462	delivery	5	22
21389	2020-01-01 01:05:36	2020-01-01	9	[{"id_menu":6,"count":1}]	8338	pick-up	0	9
21390	2020-01-01 01:12:09	2020-01-01	17	[{"id_menu":4,"count":1}]	5388	delivery	5	22
21391	2020-01-01 01:15:41	2020-01-01	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	8324	delivery	5	31
21392	2020-01-01 01:16:46	2020-01-01	12	[{"id_menu":1,"count":1}]	2691	delivery	5	17
21393	2020-01-01 01:17:11	2020-01-01	14	[{"id_menu":2,"count":1}]	1531	pick-up	0	14
21394	2020-01-01 01:28:25	2020-01-01	14	[{"id_menu":2,"count":3}]	8273	delivery	5	19
21395	2020-01-01 01:28:38	2020-01-01	17	[{"id_menu":4,"count":1}]	378	pick-up	0	17
21396	2020-01-01 01:46:56	2020-01-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	8323	delivery	5	31
21397	2020-01-01 01:51:48	2020-01-01	14	[{"id_menu":2,"count":1}]	6511	delivery	5	19
21398	2020-01-01 01:54:51	2020-01-01	9	[{"id_menu":7,"count":1}]	5318	pick-up	0	9
21399	2020-01-01 01:55:02	2020-01-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	622	delivery	5	22
21400	2020-01-01 01:59:35	2020-01-01	14	[{"id_menu":2,"count":1}]	8286	pick-up	0	14
21401	2020-01-01 02:01:25	2020-01-01	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2783	delivery	5	39
21402	2020-01-01 02:01:38	2020-01-01	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	1846	delivery	5	39
21403	2020-01-01 02:09:41	2020-01-01	9	[{"id_menu":7,"count":1}]	3746	delivery	5	14
21404	2020-01-01 02:15:11	2020-01-01	12	[{"id_menu":3,"count":1}]	293	pick-up	0	12
21405	2020-01-01 02:16:04	2020-01-01	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8317	delivery	5	35
21406	2020-01-01 02:16:39	2020-01-01	17	[{"id_menu":4,"count":1}]	6079	delivery	5	22
21407	2020-01-01 02:24:43	2020-01-01	9	[{"id_menu":6,"count":1}]	868	pick-up	0	9
21408	2020-01-01 02:32:11	2020-01-01	17	[{"id_menu":4,"count":1}]	811	delivery	5	22
21409	2020-01-01 02:34:10	2020-01-01	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	709	delivery	5	30
21410	2020-01-01 02:42:27	2020-01-01	9	[{"id_menu":6,"count":1}]	1033	pick-up	0	9
21411	2020-01-01 03:04:49	2020-01-01	9	[{"id_menu":7,"count":1}]	6546	delivery	5	14
21412	2020-01-01 03:05:51	2020-01-01	12	[{"id_menu":3,"count":1}]	2179	delivery	5	17
21413	2020-01-01 03:11:17	2020-01-01	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	8314	delivery	5	30
21414	2020-01-01 03:12:33	2020-01-01	17	[{"id_menu":4,"count":1}]	4	pick-up	0	17
21415	2020-01-01 03:13:31	2020-01-01	9	[{"id_menu":6,"count":1}]	8298	pick-up	0	9
21416	2020-01-01 03:15:00	2020-01-01	8	[{"id_menu":5,"count":1}]	8272	delivery	5	13
21417	2020-01-01 03:15:24	2020-01-01	8	[{"id_menu":5,"count":1}]	3511	pick-up	0	8
21418	2020-01-01 03:20:45	2020-01-01	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7975	delivery	5	30
21419	2020-01-01 03:32:45	2020-01-01	14	[{"id_menu":2,"count":1}]	8326	pick-up	0	14
21420	2020-01-01 03:40:31	2020-01-01	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4120	delivery	5	31
21421	2020-01-01 03:54:32	2020-01-01	12	[{"id_menu":3,"count":1}]	1679	delivery	5	17
21422	2020-01-01 04:00:11	2020-01-01	17	[{"id_menu":4,"count":1}]	1204	delivery	5	22
21423	2020-01-01 04:07:09	2020-01-01	12	[{"id_menu":1,"count":1}]	3447	pick-up	0	12
21424	2020-01-01 04:12:27	2020-01-01	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8291	delivery	5	45
21425	2020-01-01 04:21:01	2020-01-01	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	29	delivery	5	48
21426	2020-01-01 04:31:14	2020-01-01	14	[{"id_menu":2,"count":1}]	6140	delivery	5	19
21427	2020-01-01 04:33:57	2020-01-01	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	8283	delivery	5	31
21428	2020-01-01 04:34:08	2020-01-01	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	6201	delivery	5	31
21429	2020-01-01 04:37:39	2020-01-01	9	[{"id_menu":6,"count":1}]	32	delivery	5	14
21430	2020-01-01 04:41:12	2020-01-01	9	[{"id_menu":7,"count":1}]	8275	delivery	5	14
21431	2020-01-01 04:42:17	2020-01-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	3705	delivery	5	22
21432	2020-01-01 04:51:19	2020-01-01	8	[{"id_menu":5,"count":1}]	7741	pick-up	0	8
21433	2020-01-01 05:04:11	2020-01-01	14	[{"id_menu":2,"count":1}]	431	pick-up	0	14
21434	2020-01-01 05:35:18	2020-01-01	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	8302	delivery	5	36
21435	2020-01-01 05:36:36	2020-01-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	8307	delivery	5	28
21436	2020-01-01 05:46:48	2020-01-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8303	pick-up	0	17
21437	2020-01-01 06:13:38	2020-01-01	9	[{"id_menu":6,"count":1}]	6421	delivery	5	14
21438	2020-01-01 06:31:31	2020-01-01	9	[{"id_menu":6,"count":1}]	3129	delivery	5	14
21439	2020-01-01 06:32:24	2020-01-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	788	pick-up	0	23
21440	2020-01-01 06:36:45	2020-01-01	12	[{"id_menu":1,"count":1}]	2093	pick-up	0	12
21441	2020-01-01 06:41:35	2020-01-01	12	[{"id_menu":1,"count":1}]	6486	pick-up	0	12
21442	2020-01-01 06:56:30	2020-01-01	9	[{"id_menu":7,"count":3}]	3541	delivery	5	14
21443	2020-01-01 07:07:29	2020-01-01	12	[{"id_menu":1,"count":2}]	8333	delivery	5	17
21444	2020-01-01 07:07:55	2020-01-01	14	[{"id_menu":2,"count":1}]	4139	delivery	5	19
21445	2020-01-01 07:15:25	2020-01-01	14	[{"id_menu":2,"count":1}]	376	pick-up	0	14
21446	2020-01-01 08:06:53	2020-01-01	14	[{"id_menu":2,"count":1}]	1537	pick-up	0	14
21447	2020-01-01 08:13:57	2020-01-01	9	[{"id_menu":6,"count":2}]	8319	delivery	5	14
21448	2020-01-01 08:15:32	2020-01-01	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	8304	delivery	5	34
21449	2020-01-01 08:28:34	2020-01-01	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	4744	delivery	5	26
21450	2020-01-01 08:36:52	2020-01-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":3}]	1969	pick-up	0	17
21451	2020-01-01 08:51:43	2020-01-01	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	8339	delivery	5	27
21452	2020-01-01 08:59:44	2020-01-01	8	[{"id_menu":5,"count":1}]	2969	pick-up	0	8
21453	2020-01-01 08:59:51	2020-01-01	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8293	delivery	5	40
21454	2020-01-01 09:08:02	2020-01-01	9	[{"id_menu":7,"count":1}]	1122	delivery	5	14
21455	2020-01-01 09:16:34	2020-01-01	12	[{"id_menu":3,"count":1}]	8289	delivery	5	17
21456	2020-01-01 09:26:26	2020-01-01	17	[{"id_menu":4,"count":1}]	1055	pick-up	0	17
21457	2020-01-01 09:44:11	2020-01-01	9	[{"id_menu":7,"count":1}]	3333	delivery	5	14
21458	2020-01-01 09:44:36	2020-01-01	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8313	delivery	5	45
21459	2020-01-01 09:47:41	2020-01-01	14	[{"id_menu":2,"count":1}]	2042	delivery	5	19
21460	2020-01-01 09:54:50	2020-01-01	17	[{"id_menu":4,"count":1}]	5101	delivery	5	22
21461	2020-01-01 09:58:59	2020-01-01	8	[{"id_menu":5,"count":2}]	8271	pick-up	0	8
21462	2020-01-01 10:12:28	2020-01-01	14	[{"id_menu":2,"count":1}]	2123	pick-up	0	14
21463	2020-01-01 10:28:37	2020-01-01	9	[{"id_menu":7,"count":1}]	8000	delivery	5	14
21464	2020-01-01 10:29:41	2020-01-01	12	[{"id_menu":3,"count":1}]	2056	pick-up	0	12
21465	2020-01-01 10:29:48	2020-01-01	9	[{"id_menu":6,"count":1}]	8334	delivery	5	14
21466	2020-01-01 10:31:17	2020-01-01	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	477	pick-up	0	21
21467	2020-01-01 10:31:42	2020-01-01	14	[{"id_menu":2,"count":1}]	3054	pick-up	0	14
21468	2020-01-01 10:38:49	2020-01-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8274	delivery	5	23
21469	2020-01-01 10:57:17	2020-01-01	12	[{"id_menu":3,"count":1}]	2959	delivery	5	17
21470	2020-01-01 10:57:35	2020-01-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	3212	delivery	5	26
21471	2020-01-01 11:30:29	2020-01-01	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8269	delivery	5	31
21472	2020-01-01 11:35:33	2020-01-01	14	[{"id_menu":2,"count":1}]	6322	delivery	5	19
21473	2020-01-01 11:53:35	2020-01-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	511	pick-up	0	23
21474	2020-01-01 11:56:23	2020-01-01	8	[{"id_menu":5,"count":1}]	5917	pick-up	0	8
21475	2020-01-01 12:01:23	2020-01-01	12	[{"id_menu":3,"count":2}]	8341	pick-up	0	12
21476	2020-01-01 12:04:07	2020-01-01	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	3083	delivery	5	34
21477	2020-01-01 12:10:15	2020-01-01	9	[{"id_menu":6,"count":1}]	3113	pick-up	0	9
21478	2020-01-01 12:14:58	2020-01-01	9	[{"id_menu":6,"count":1}]	3472	delivery	5	14
21479	2020-01-01 12:15:25	2020-01-01	9	[{"id_menu":6,"count":1}]	3016	delivery	5	14
21480	2020-01-01 12:16:49	2020-01-01	8	[{"id_menu":5,"count":1}]	8309	delivery	5	13
21481	2020-01-01 12:25:15	2020-01-01	17	[{"id_menu":4,"count":1}]	2287	pick-up	0	17
21482	2020-01-01 12:42:57	2020-01-01	17	[{"id_menu":4,"count":1}]	3656	pick-up	0	17
21483	2020-01-01 12:43:01	2020-01-01	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	8294	delivery	5	26
21484	2020-01-01 12:58:25	2020-01-01	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4927	delivery	5	27
21485	2020-01-01 13:19:28	2020-01-01	14	[{"id_menu":2,"count":1}]	8295	delivery	5	19
21486	2020-01-01 13:25:42	2020-01-01	17	[{"id_menu":4,"count":1}]	4912	delivery	5	22
21487	2020-01-01 13:35:45	2020-01-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	122	delivery	5	22
21488	2020-01-01 13:41:05	2020-01-01	14	[{"id_menu":2,"count":1}]	4153	delivery	5	19
21489	2020-01-01 13:51:04	2020-01-01	8	[{"id_menu":5,"count":1}]	3302	delivery	5	13
21490	2020-01-01 14:00:39	2020-01-01	9	[{"id_menu":6,"count":1}]	6160	delivery	5	14
21491	2020-01-01 14:07:32	2020-01-01	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	7773	delivery	5	36
21492	2020-01-01 14:08:43	2020-01-01	8	[{"id_menu":5,"count":1}]	4888	delivery	5	13
21493	2020-01-01 14:10:10	2020-01-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	8284	pick-up	0	31
21494	2020-01-01 14:10:54	2020-01-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	7211	delivery	5	22
21495	2020-01-01 14:12:50	2020-01-01	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4442	delivery	5	39
21496	2020-01-01 14:34:18	2020-01-01	14	[{"id_menu":2,"count":1}]	5151	delivery	5	19
21497	2020-01-01 14:56:12	2020-01-01	17	[{"id_menu":4,"count":1}]	1233	pick-up	0	17
21498	2020-01-01 14:56:27	2020-01-01	17	[{"id_menu":4,"count":1}]	8300	pick-up	0	17
21499	2020-01-01 15:03:26	2020-01-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	8281	delivery	5	28
21500	2020-01-01 15:05:53	2020-01-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	8277	delivery	5	26
21501	2020-01-01 15:24:04	2020-01-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	8290	delivery	5	36
21502	2020-01-01 15:26:30	2020-01-01	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8306	delivery	5	43
21503	2020-01-01 15:28:49	2020-01-01	14	[{"id_menu":2,"count":1}]	2838	pick-up	0	14
21504	2020-01-01 15:29:19	2020-01-01	14	[{"id_menu":2,"count":1}]	8278	delivery	5	19
21505	2020-01-01 15:33:49	2020-01-01	9	[{"id_menu":6,"count":1}]	221	delivery	5	14
21506	2020-01-01 15:36:05	2020-01-01	17	[{"id_menu":4,"count":1}]	3459	pick-up	0	17
21507	2020-01-01 15:40:26	2020-01-01	8	[{"id_menu":5,"count":1}]	601	pick-up	0	8
21508	2020-01-01 15:47:52	2020-01-01	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	902	delivery	5	26
21509	2020-01-01 15:55:13	2020-01-01	17	[{"id_menu":4,"count":1}]	828	delivery	5	22
21510	2020-01-01 16:06:06	2020-01-01	9	[{"id_menu":7,"count":2}]	8276	delivery	5	14
21511	2020-01-01 16:21:38	2020-01-01	9	[{"id_menu":6,"count":1}]	6433	delivery	5	14
21512	2020-01-01 16:34:05	2020-01-01	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	8335	delivery	5	25
21513	2020-01-01 16:37:30	2020-01-01	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	48	pick-up	0	29
21514	2020-01-01 16:44:56	2020-01-01	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	6195	delivery	5	29
21515	2020-01-01 16:47:09	2020-01-01	12	[{"id_menu":1,"count":1}]	7094	delivery	5	17
21516	2020-01-01 16:55:11	2020-01-01	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	4624	pick-up	0	29
21517	2020-01-01 16:57:47	2020-01-01	9	[{"id_menu":6,"count":1}]	567	delivery	5	14
21518	2020-01-01 16:59:07	2020-01-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8288	delivery	5	23
21519	2020-01-01 16:59:24	2020-01-01	9	[{"id_menu":6,"count":3}]	8337	delivery	5	14
21520	2020-01-01 17:06:17	2020-01-01	8	[{"id_menu":5,"count":1}]	1757	delivery	5	13
21521	2020-01-01 17:23:31	2020-01-01	9	[{"id_menu":6,"count":1}]	5535	delivery	5	14
21522	2020-01-01 17:30:06	2020-01-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8297	pick-up	0	26
21523	2020-01-01 17:53:43	2020-01-01	14	[{"id_menu":2,"count":1}]	5278	delivery	5	19
21524	2020-01-01 17:56:04	2020-01-01	9	[{"id_menu":7,"count":1}]	2845	delivery	5	14
21525	2020-01-01 18:14:49	2020-01-01	9	[{"id_menu":7,"count":1}]	4422	delivery	5	14
21526	2020-01-01 18:22:27	2020-01-01	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	2823	delivery	5	43
21527	2020-01-01 18:32:45	2020-01-01	9	[{"id_menu":7,"count":1}]	5042	delivery	5	14
21528	2020-01-01 18:35:09	2020-01-01	9	[{"id_menu":6,"count":1}]	6234	delivery	5	14
21529	2020-01-01 18:37:02	2020-01-01	12	[{"id_menu":1,"count":1}]	8332	delivery	5	17
21530	2020-01-01 18:46:19	2020-01-01	12	[{"id_menu":3,"count":1}]	8336	delivery	5	17
21531	2020-01-01 18:57:03	2020-01-01	9	[{"id_menu":6,"count":1}]	8265	pick-up	0	9
21532	2020-01-01 18:58:31	2020-01-01	9	[{"id_menu":6,"count":1}]	8321	delivery	5	14
21533	2020-01-01 19:00:00	2020-01-01	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	8296	delivery	5	26
21534	2020-01-01 19:02:02	2020-01-01	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	5808	pick-up	0	24
21535	2020-01-01 19:22:38	2020-01-01	17	[{"id_menu":4,"count":1}]	6645	delivery	5	22
21536	2020-01-01 19:34:37	2020-01-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7486	delivery	5	22
21537	2020-01-01 19:37:52	2020-01-01	8	[{"id_menu":5,"count":1}]	8268	delivery	5	13
21538	2020-01-01 19:50:53	2020-01-01	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8340	delivery	5	37
21539	2020-01-01 20:03:44	2020-01-01	9	[{"id_menu":6,"count":1}]	8327	delivery	5	14
21540	2020-01-01 20:04:11	2020-01-01	12	[{"id_menu":1,"count":1}]	3752	pick-up	0	12
21541	2020-01-01 20:07:56	2020-01-01	14	[{"id_menu":2,"count":1}]	371	pick-up	0	14
21542	2020-01-01 20:07:57	2020-01-01	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	8311	delivery	5	31
21543	2020-01-01 20:25:01	2020-01-01	43	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2061	pick-up	0	43
21544	2020-01-01 20:32:20	2020-01-01	9	[{"id_menu":6,"count":1}]	8310	pick-up	0	9
21545	2020-01-01 20:33:49	2020-01-01	17	[{"id_menu":4,"count":1}]	8312	delivery	5	22
21546	2020-01-01 20:38:20	2020-01-01	12	[{"id_menu":1,"count":1}]	1038	delivery	5	17
21547	2020-01-01 20:39:25	2020-01-01	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5359	delivery	5	46
21548	2020-01-01 21:08:08	2020-01-01	8	[{"id_menu":5,"count":1}]	5654	delivery	5	13
21549	2020-01-01 21:16:22	2020-01-01	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4284	delivery	5	30
21550	2020-01-01 21:30:44	2020-01-01	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1624	pick-up	0	26
21551	2020-01-01 21:37:18	2020-01-01	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1407	pick-up	0	29
21552	2020-01-01 21:38:00	2020-01-01	12	[{"id_menu":1,"count":1}]	6975	pick-up	0	12
21553	2020-01-01 21:40:04	2020-01-01	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":3}]	8316	delivery	5	31
21554	2020-01-01 21:45:20	2020-01-01	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	8282	delivery	5	25
21555	2020-01-01 21:47:20	2020-01-01	14	[{"id_menu":2,"count":1}]	2025	pick-up	0	14
21556	2020-01-01 22:01:45	2020-01-01	17	[{"id_menu":4,"count":1}]	5826	pick-up	0	17
21557	2020-01-01 22:11:31	2020-01-01	12	[{"id_menu":3,"count":1}]	4986	pick-up	0	12
21558	2020-01-01 22:16:15	2020-01-01	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	8285	pick-up	0	24
21559	2020-01-01 22:26:35	2020-01-01	14	[{"id_menu":2,"count":1}]	8328	delivery	5	19
21560	2020-01-01 22:27:08	2020-01-01	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	8315	delivery	5	31
21561	2020-01-01 22:30:33	2020-01-01	9	[{"id_menu":6,"count":1}]	8280	pick-up	0	9
21562	2020-01-01 22:36:24	2020-01-01	9	[{"id_menu":7,"count":1}]	7479	delivery	5	14
21563	2020-01-01 22:49:38	2020-01-01	8	[{"id_menu":5,"count":1}]	559	delivery	5	13
21564	2020-01-01 22:51:46	2020-01-01	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	6886	delivery	5	25
21565	2020-01-01 22:53:46	2020-01-01	8	[{"id_menu":5,"count":1}]	8287	delivery	5	13
21566	2020-01-01 23:04:07	2020-01-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7706	pick-up	0	23
21567	2020-01-01 23:08:26	2020-01-01	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6190	delivery	5	31
21568	2020-01-01 23:11:14	2020-01-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4862	delivery	5	23
21569	2020-01-01 23:12:32	2020-01-01	17	[{"id_menu":4,"count":1}]	8318	pick-up	0	17
21570	2020-01-01 23:18:42	2020-01-01	12	[{"id_menu":1,"count":1}]	3205	pick-up	0	12
21571	2020-01-01 23:20:33	2020-01-01	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3997	delivery	5	39
21572	2020-01-01 23:43:42	2020-01-01	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1322	delivery	5	34
21573	2020-01-01 23:44:44	2020-01-01	17	[{"id_menu":4,"count":1}]	2018	pick-up	0	17
21574	2020-01-01 23:54:12	2020-01-01	9	[{"id_menu":6,"count":1}]	6470	pick-up	0	9
21575	2020-01-01 23:54:57	2020-01-01	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	8305	delivery	5	34
21576	2020-01-02 00:00:04	2020-01-02	14	[{"id_menu":2,"count":1}]	2572	pick-up	0	14
21577	2020-01-02 00:09:22	2020-01-02	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1947	delivery	5	30
21578	2020-01-02 00:12:32	2020-01-02	9	[{"id_menu":6,"count":1}]	2621	delivery	5	14
21579	2020-01-02 00:28:51	2020-01-02	12	[{"id_menu":3,"count":1}]	1613	pick-up	0	12
21580	2020-01-02 00:33:50	2020-01-02	8	[{"id_menu":5,"count":1}]	3451	pick-up	0	8
21581	2020-01-02 00:51:36	2020-01-02	17	[{"id_menu":4,"count":1}]	8393	delivery	5	22
21582	2020-01-02 00:54:16	2020-01-02	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7041	delivery	5	40
21583	2020-01-02 01:04:01	2020-01-02	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1233	pick-up	0	31
21584	2020-01-02 01:09:28	2020-01-02	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2604	delivery	5	26
21585	2020-01-02 01:28:59	2020-01-02	12	[{"id_menu":3,"count":1}]	6055	delivery	5	17
21586	2020-01-02 01:31:29	2020-01-02	9	[{"id_menu":6,"count":1}]	8358	pick-up	0	9
21587	2020-01-02 01:56:06	2020-01-02	9	[{"id_menu":7,"count":1}]	76	pick-up	0	9
21588	2020-01-02 01:59:34	2020-01-02	9	[{"id_menu":6,"count":1}]	4445	pick-up	0	9
21589	2020-01-02 02:03:46	2020-01-02	8	[{"id_menu":5,"count":1}]	2894	delivery	5	13
21590	2020-01-02 02:05:02	2020-01-02	14	[{"id_menu":2,"count":1}]	5215	delivery	5	19
21591	2020-01-02 02:21:15	2020-01-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5633	delivery	5	23
21592	2020-01-02 02:34:12	2020-01-02	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	8371	delivery	5	26
21593	2020-01-02 02:42:37	2020-01-02	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8394	pick-up	0	25
21594	2020-01-02 02:54:21	2020-01-02	14	[{"id_menu":2,"count":1}]	8392	delivery	5	19
21595	2020-01-02 03:02:45	2020-01-02	12	[{"id_menu":1,"count":1}]	160	pick-up	0	12
21596	2020-01-02 03:05:03	2020-01-02	8	[{"id_menu":5,"count":1}]	1442	pick-up	0	8
21597	2020-01-02 03:06:36	2020-01-02	17	[{"id_menu":4,"count":2}]	7835	delivery	5	22
21598	2020-01-02 03:19:50	2020-01-02	9	[{"id_menu":7,"count":1}]	8353	delivery	5	14
21599	2020-01-02 03:23:43	2020-01-02	17	[{"id_menu":4,"count":1}]	7101	delivery	5	22
21600	2020-01-02 03:27:01	2020-01-02	17	[{"id_menu":4,"count":2}]	2244	pick-up	0	17
21601	2020-01-02 03:28:33	2020-01-02	9	[{"id_menu":6,"count":1}]	8385	delivery	5	14
21602	2020-01-02 03:36:03	2020-01-02	17	[{"id_menu":4,"count":1}]	8345	delivery	5	22
21603	2020-01-02 03:41:37	2020-01-02	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	8368	delivery	5	26
21604	2020-01-02 03:46:30	2020-01-02	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	8351	pick-up	0	21
21605	2020-01-02 03:48:14	2020-01-02	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8375	pick-up	0	26
21606	2020-01-02 04:08:08	2020-01-02	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	8370	delivery	5	26
21607	2020-01-02 04:09:39	2020-01-02	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	7007	delivery	5	22
21608	2020-01-02 04:24:35	2020-01-02	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2552	pick-up	0	40
21609	2020-01-02 04:46:14	2020-01-02	9	[{"id_menu":7,"count":1}]	5201	pick-up	0	9
21610	2020-01-02 04:50:45	2020-01-02	9	[{"id_menu":6,"count":1}]	21	pick-up	0	9
21611	2020-01-02 04:55:27	2020-01-02	12	[{"id_menu":1,"count":1}]	7430	pick-up	0	12
21612	2020-01-02 05:05:14	2020-01-02	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	519	pick-up	0	21
21613	2020-01-02 05:13:43	2020-01-02	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2561	pick-up	0	31
21614	2020-01-02 05:16:46	2020-01-02	17	[{"id_menu":4,"count":1}]	1721	pick-up	0	17
21615	2020-01-02 05:26:05	2020-01-02	9	[{"id_menu":6,"count":1}]	6916	pick-up	0	9
21616	2020-01-02 05:29:17	2020-01-02	8	[{"id_menu":5,"count":2}]	4646	delivery	5	13
21617	2020-01-02 05:31:19	2020-01-02	8	[{"id_menu":5,"count":1}]	2366	pick-up	0	8
21618	2020-01-02 05:39:00	2020-01-02	14	[{"id_menu":2,"count":1}]	36	pick-up	0	14
21619	2020-01-02 05:44:09	2020-01-02	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1087	pick-up	0	30
21620	2020-01-02 05:44:43	2020-01-02	17	[{"id_menu":4,"count":1}]	2254	delivery	5	22
21621	2020-01-02 05:54:48	2020-01-02	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4604	delivery	5	40
21622	2020-01-02 06:02:05	2020-01-02	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	8399	delivery	5	48
21623	2020-01-02 06:07:53	2020-01-02	9	[{"id_menu":6,"count":1}]	569	pick-up	0	9
21624	2020-01-02 06:16:53	2020-01-02	12	[{"id_menu":3,"count":2}]	8363	delivery	5	17
21625	2020-01-02 06:39:21	2020-01-02	17	[{"id_menu":4,"count":1}]	8403	delivery	5	22
21626	2020-01-02 06:50:47	2020-01-02	12	[{"id_menu":3,"count":1}]	2185	pick-up	0	12
21627	2020-01-02 06:57:24	2020-01-02	9	[{"id_menu":6,"count":1}]	2000	delivery	5	14
21628	2020-01-02 07:36:53	2020-01-02	9	[{"id_menu":6,"count":1}]	3731	delivery	5	14
21629	2020-01-02 07:40:09	2020-01-02	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8348	delivery	5	45
21630	2020-01-02 07:55:38	2020-01-02	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	420	pick-up	0	43
21631	2020-01-02 07:58:21	2020-01-02	9	[{"id_menu":7,"count":1}]	3659	pick-up	0	9
21632	2020-01-02 08:12:29	2020-01-02	12	[{"id_menu":1,"count":1}]	7182	pick-up	0	12
21633	2020-01-02 08:24:32	2020-01-02	12	[{"id_menu":1,"count":1}]	8343	delivery	5	17
21634	2020-01-02 08:27:49	2020-01-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7158	delivery	5	31
21635	2020-01-02 08:28:25	2020-01-02	14	[{"id_menu":2,"count":1}]	7599	delivery	5	19
21636	2020-01-02 08:32:12	2020-01-02	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	245	pick-up	0	26
21637	2020-01-02 08:39:45	2020-01-02	9	[{"id_menu":7,"count":1}]	3007	delivery	5	14
21638	2020-01-02 08:44:20	2020-01-02	12	[{"id_menu":3,"count":1}]	3868	pick-up	0	12
21639	2020-01-02 08:58:16	2020-01-02	8	[{"id_menu":5,"count":1}]	8335	pick-up	0	8
21640	2020-01-02 09:01:59	2020-01-02	17	[{"id_menu":4,"count":1}]	886	delivery	5	22
21641	2020-01-02 09:06:30	2020-01-02	17	[{"id_menu":4,"count":1}]	2619	delivery	5	22
21642	2020-01-02 09:06:51	2020-01-02	9	[{"id_menu":7,"count":1}]	8361	delivery	5	14
21643	2020-01-02 09:09:16	2020-01-02	14	[{"id_menu":2,"count":1}]	8364	delivery	5	19
21644	2020-01-02 09:13:11	2020-01-02	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8397	delivery	5	28
21645	2020-01-02 09:24:20	2020-01-02	12	[{"id_menu":3,"count":1}]	748	delivery	5	17
21646	2020-01-02 09:26:02	2020-01-02	12	[{"id_menu":1,"count":1}]	3782	delivery	5	17
21647	2020-01-02 09:29:36	2020-01-02	12	[{"id_menu":1,"count":1}]	4798	delivery	5	17
21648	2020-01-02 09:29:43	2020-01-02	9	[{"id_menu":7,"count":1}]	8354	pick-up	0	9
21649	2020-01-02 09:43:15	2020-01-02	14	[{"id_menu":2,"count":1}]	8404	delivery	5	19
21650	2020-01-02 09:43:21	2020-01-02	9	[{"id_menu":7,"count":1}]	3143	delivery	5	14
21651	2020-01-02 09:52:51	2020-01-02	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3173	delivery	5	34
21652	2020-01-02 10:01:37	2020-01-02	14	[{"id_menu":2,"count":1}]	7891	pick-up	0	14
21653	2020-01-02 10:08:39	2020-01-02	9	[{"id_menu":6,"count":1}]	8398	delivery	5	14
21654	2020-01-02 10:21:41	2020-01-02	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7293	delivery	5	28
21655	2020-01-02 10:36:05	2020-01-02	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	80	pick-up	0	29
21656	2020-01-02 10:36:18	2020-01-02	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	5935	delivery	5	25
21657	2020-01-02 10:40:37	2020-01-02	9	[{"id_menu":7,"count":1}]	8344	delivery	5	14
21658	2020-01-02 10:42:23	2020-01-02	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	8350	pick-up	0	21
21659	2020-01-02 10:47:15	2020-01-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8384	pick-up	0	17
21660	2020-01-02 10:57:41	2020-01-02	14	[{"id_menu":2,"count":1}]	8352	delivery	5	19
21661	2020-01-02 11:15:25	2020-01-02	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2551	delivery	5	36
21662	2020-01-02 11:15:31	2020-01-02	9	[{"id_menu":7,"count":1}]	4579	delivery	5	14
21663	2020-01-02 11:23:10	2020-01-02	9	[{"id_menu":7,"count":1}]	623	pick-up	0	9
21664	2020-01-02 11:56:03	2020-01-02	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	8381	delivery	5	26
21665	2020-01-02 12:08:54	2020-01-02	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6544	delivery	5	36
21666	2020-01-02 12:16:00	2020-01-02	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	378	delivery	5	34
21667	2020-01-02 12:40:48	2020-01-02	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	8406	pick-up	0	20
21668	2020-01-02 12:46:33	2020-01-02	8	[{"id_menu":5,"count":1}]	8365	delivery	5	13
21669	2020-01-02 12:48:45	2020-01-02	9	[{"id_menu":6,"count":1}]	8372	delivery	5	14
21670	2020-01-02 12:57:01	2020-01-02	12	[{"id_menu":3,"count":1}]	2139	pick-up	0	12
21671	2020-01-02 12:57:58	2020-01-02	8	[{"id_menu":5,"count":1}]	8229	delivery	5	13
21672	2020-01-02 13:00:01	2020-01-02	12	[{"id_menu":3,"count":1}]	8408	delivery	5	17
21673	2020-01-02 13:09:23	2020-01-02	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	506	pick-up	0	20
21674	2020-01-02 13:17:43	2020-01-02	17	[{"id_menu":4,"count":1}]	1528	delivery	5	22
21675	2020-01-02 13:19:28	2020-01-02	12	[{"id_menu":1,"count":1}]	4973	pick-up	0	12
21676	2020-01-02 13:20:26	2020-01-02	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	8377	delivery	5	26
21677	2020-01-02 13:25:37	2020-01-02	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2264	pick-up	0	29
21678	2020-01-02 13:35:36	2020-01-02	12	[{"id_menu":3,"count":1}]	8388	delivery	5	17
21679	2020-01-02 13:50:38	2020-01-02	9	[{"id_menu":7,"count":1}]	4907	delivery	5	14
21680	2020-01-02 13:54:11	2020-01-02	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1949	pick-up	0	21
21681	2020-01-02 13:59:46	2020-01-02	17	[{"id_menu":4,"count":1}]	4274	pick-up	0	17
21682	2020-01-02 14:00:54	2020-01-02	12	[{"id_menu":3,"count":1}]	381	pick-up	0	12
21683	2020-01-02 14:12:23	2020-01-02	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8386	delivery	5	40
21684	2020-01-02 14:27:04	2020-01-02	8	[{"id_menu":5,"count":1}]	7123	delivery	5	13
21685	2020-01-02 14:43:20	2020-01-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	62	delivery	5	28
21686	2020-01-02 14:47:36	2020-01-02	8	[{"id_menu":5,"count":1}]	4206	delivery	5	13
21687	2020-01-02 15:04:05	2020-01-02	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	5627	delivery	5	26
21688	2020-01-02 15:23:33	2020-01-02	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	464	pick-up	0	23
21689	2020-01-02 15:47:52	2020-01-02	12	[{"id_menu":3,"count":1}]	8342	delivery	5	17
21690	2020-01-02 15:53:36	2020-01-02	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	8390	delivery	5	26
21691	2020-01-02 15:56:41	2020-01-02	17	[{"id_menu":4,"count":1}]	113	pick-up	0	17
21692	2020-01-02 16:15:51	2020-01-02	12	[{"id_menu":3,"count":1}]	8347	delivery	5	17
21693	2020-01-02 16:16:37	2020-01-02	9	[{"id_menu":7,"count":1}]	8355	delivery	5	14
21694	2020-01-02 16:17:58	2020-01-02	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6733	pick-up	0	31
21695	2020-01-02 16:19:33	2020-01-02	12	[{"id_menu":1,"count":1}]	1645	pick-up	0	12
21696	2020-01-02 16:22:44	2020-01-02	30	[{"id_menu":3,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8362	delivery	5	35
21697	2020-01-02 16:34:15	2020-01-02	12	[{"id_menu":1,"count":1}]	254	delivery	5	17
21698	2020-01-02 16:51:08	2020-01-02	9	[{"id_menu":6,"count":1}]	8400	delivery	5	14
21699	2020-01-02 16:53:05	2020-01-02	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	826	pick-up	0	26
21700	2020-01-02 16:58:33	2020-01-02	9	[{"id_menu":6,"count":1}]	2386	delivery	5	14
21701	2020-01-02 17:03:18	2020-01-02	14	[{"id_menu":2,"count":2}]	1742	pick-up	0	14
21702	2020-01-02 17:11:37	2020-01-02	17	[{"id_menu":4,"count":1}]	8405	delivery	5	22
21703	2020-01-02 17:20:21	2020-01-02	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	27	pick-up	0	20
21704	2020-01-02 17:22:44	2020-01-02	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	8366	delivery	5	35
21705	2020-01-02 17:25:31	2020-01-02	9	[{"id_menu":6,"count":1}]	8382	delivery	5	14
21706	2020-01-02 17:26:38	2020-01-02	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3997	delivery	5	40
21707	2020-01-02 17:38:32	2020-01-02	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	8378	delivery	5	34
21708	2020-01-02 17:47:56	2020-01-02	9	[{"id_menu":6,"count":1}]	8359	delivery	5	14
21709	2020-01-02 17:51:34	2020-01-02	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8409	delivery	5	39
21710	2020-01-02 17:59:46	2020-01-02	14	[{"id_menu":2,"count":1}]	8356	delivery	5	19
21711	2020-01-02 18:00:09	2020-01-02	9	[{"id_menu":6,"count":1}]	7279	delivery	5	14
21712	2020-01-02 18:01:04	2020-01-02	14	[{"id_menu":2,"count":1}]	4242	pick-up	0	14
21713	2020-01-02 18:14:39	2020-01-02	14	[{"id_menu":2,"count":1}]	6015	delivery	5	19
21714	2020-01-02 18:29:34	2020-01-02	8	[{"id_menu":5,"count":1}]	8360	delivery	5	13
21715	2020-01-02 18:29:47	2020-01-02	14	[{"id_menu":2,"count":1}]	8387	delivery	5	19
21716	2020-01-02 18:34:58	2020-01-02	14	[{"id_menu":2,"count":1}]	3689	delivery	5	19
21717	2020-01-02 18:48:32	2020-01-02	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	376	delivery	5	34
21718	2020-01-02 18:57:13	2020-01-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	8389	delivery	5	22
21719	2020-01-02 19:04:07	2020-01-02	14	[{"id_menu":2,"count":1}]	8402	pick-up	0	14
21720	2020-01-02 19:08:49	2020-01-02	9	[{"id_menu":7,"count":1}]	7910	delivery	5	14
21721	2020-01-02 19:32:29	2020-01-02	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	8374	pick-up	0	29
21722	2020-01-02 19:54:48	2020-01-02	14	[{"id_menu":2,"count":1}]	1266	pick-up	0	14
21723	2020-01-02 19:55:23	2020-01-02	17	[{"id_menu":4,"count":1}]	4996	pick-up	0	17
21724	2020-01-02 19:55:50	2020-01-02	8	[{"id_menu":5,"count":1}]	8135	delivery	5	13
21725	2020-01-02 20:13:48	2020-01-02	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1214	delivery	5	31
21726	2020-01-02 20:32:09	2020-01-02	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	4800	pick-up	0	38
21727	2020-01-02 20:50:01	2020-01-02	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1376	pick-up	0	23
21728	2020-01-02 20:59:18	2020-01-02	12	[{"id_menu":3,"count":1}]	8401	delivery	5	17
21729	2020-01-02 21:16:54	2020-01-02	12	[{"id_menu":1,"count":1}]	8396	delivery	5	17
21730	2020-01-02 21:29:19	2020-01-02	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	2951	delivery	5	39
21731	2020-01-02 21:38:39	2020-01-02	14	[{"id_menu":2,"count":1}]	2217	delivery	5	19
21732	2020-01-02 21:48:25	2020-01-02	9	[{"id_menu":7,"count":1}]	7634	delivery	5	14
21733	2020-01-02 21:55:32	2020-01-02	9	[{"id_menu":6,"count":1}]	4339	delivery	5	14
21734	2020-01-02 22:19:27	2020-01-02	9	[{"id_menu":7,"count":1}]	6341	delivery	5	14
21735	2020-01-02 22:57:39	2020-01-02	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	970	pick-up	0	22
21736	2020-01-02 23:09:59	2020-01-02	12	[{"id_menu":1,"count":1}]	7590	pick-up	0	12
21737	2020-01-02 23:10:39	2020-01-02	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	6248	pick-up	0	24
21738	2020-01-02 23:13:13	2020-01-02	17	[{"id_menu":4,"count":1}]	3012	pick-up	0	17
21739	2020-01-02 23:28:03	2020-01-02	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	8346	delivery	5	30
21740	2020-01-02 23:29:42	2020-01-02	9	[{"id_menu":6,"count":1}]	8379	delivery	5	14
21741	2020-01-03 00:06:27	2020-01-03	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	3449	pick-up	0	26
21742	2020-01-03 00:18:28	2020-01-03	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	8427	delivery	5	26
21743	2020-01-03 00:28:01	2020-01-03	14	[{"id_menu":2,"count":1}]	4281	delivery	5	19
21744	2020-01-03 00:38:41	2020-01-03	14	[{"id_menu":2,"count":1}]	3025	pick-up	0	14
21745	2020-01-03 00:45:01	2020-01-03	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	8412	delivery	5	34
21746	2020-01-03 00:52:37	2020-01-03	9	[{"id_menu":6,"count":1}]	8430	delivery	5	14
21747	2020-01-03 00:56:07	2020-01-03	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3886	delivery	5	22
21748	2020-01-03 00:57:18	2020-01-03	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	6496	delivery	5	29
21749	2020-01-03 01:16:53	2020-01-03	8	[{"id_menu":5,"count":1}]	8473	delivery	5	13
21750	2020-01-03 01:17:35	2020-01-03	9	[{"id_menu":6,"count":1}]	4562	pick-up	0	9
21751	2020-01-03 01:19:33	2020-01-03	9	[{"id_menu":6,"count":1}]	5272	delivery	5	14
21752	2020-01-03 01:19:54	2020-01-03	17	[{"id_menu":4,"count":1}]	2897	pick-up	0	17
21753	2020-01-03 01:27:19	2020-01-03	9	[{"id_menu":6,"count":1}]	8413	delivery	5	14
21754	2020-01-03 01:27:29	2020-01-03	9	[{"id_menu":6,"count":2}]	4803	delivery	5	14
21755	2020-01-03 01:28:19	2020-01-03	9	[{"id_menu":7,"count":1}]	8033	delivery	5	14
21756	2020-01-03 01:28:41	2020-01-03	9	[{"id_menu":7,"count":1}]	4342	pick-up	0	9
21757	2020-01-03 01:31:53	2020-01-03	17	[{"id_menu":4,"count":1}]	1032	pick-up	0	17
21758	2020-01-03 01:48:50	2020-01-03	9	[{"id_menu":7,"count":1}]	2119	pick-up	0	9
21759	2020-01-03 02:05:23	2020-01-03	8	[{"id_menu":5,"count":1}]	480	delivery	5	13
21760	2020-01-03 02:17:22	2020-01-03	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6959	delivery	5	49
21761	2020-01-03 02:19:43	2020-01-03	12	[{"id_menu":1,"count":1}]	8454	delivery	5	17
21762	2020-01-03 02:25:46	2020-01-03	9	[{"id_menu":7,"count":1}]	7444	delivery	5	14
21763	2020-01-03 02:31:49	2020-01-03	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	803	delivery	5	22
21764	2020-01-03 02:34:14	2020-01-03	9	[{"id_menu":6,"count":1}]	5087	delivery	5	14
21765	2020-01-03 02:44:23	2020-01-03	12	[{"id_menu":3,"count":1}]	8429	pick-up	0	12
21766	2020-01-03 02:46:13	2020-01-03	14	[{"id_menu":2,"count":1}]	8468	delivery	5	19
21767	2020-01-03 02:51:44	2020-01-03	8	[{"id_menu":5,"count":1}]	92	pick-up	0	8
21768	2020-01-03 03:15:40	2020-01-03	9	[{"id_menu":6,"count":1}]	2105	pick-up	0	9
21769	2020-01-03 03:32:18	2020-01-03	8	[{"id_menu":5,"count":1}]	2845	delivery	5	13
21770	2020-01-03 03:32:28	2020-01-03	12	[{"id_menu":1,"count":1}]	1485	pick-up	0	12
21771	2020-01-03 03:50:10	2020-01-03	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	8439	pick-up	0	22
21772	2020-01-03 03:57:25	2020-01-03	9	[{"id_menu":6,"count":2}]	1633	pick-up	0	9
21773	2020-01-03 04:00:43	2020-01-03	9	[{"id_menu":6,"count":1}]	8458	pick-up	0	9
21774	2020-01-03 04:01:45	2020-01-03	9	[{"id_menu":7,"count":1}]	5811	pick-up	0	9
21775	2020-01-03 04:02:55	2020-01-03	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1239	delivery	5	22
21776	2020-01-03 04:29:25	2020-01-03	17	[{"id_menu":4,"count":1}]	8478	delivery	5	22
21777	2020-01-03 04:36:29	2020-01-03	9	[{"id_menu":7,"count":1}]	8443	delivery	5	14
21778	2020-01-03 04:44:15	2020-01-03	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4439	delivery	5	22
21779	2020-01-03 04:44:27	2020-01-03	9	[{"id_menu":6,"count":1}]	7205	pick-up	0	9
21780	2020-01-03 04:45:58	2020-01-03	9	[{"id_menu":6,"count":1}]	2860	pick-up	0	9
21781	2020-01-03 05:08:44	2020-01-03	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	3268	pick-up	0	17
21782	2020-01-03 05:18:49	2020-01-03	9	[{"id_menu":6,"count":1}]	8265	pick-up	0	9
21783	2020-01-03 05:44:48	2020-01-03	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3870	pick-up	0	43
21784	2020-01-03 05:51:47	2020-01-03	17	[{"id_menu":4,"count":1}]	2902	delivery	5	22
21785	2020-01-03 06:02:49	2020-01-03	9	[{"id_menu":7,"count":1}]	2943	delivery	5	14
21786	2020-01-03 06:13:26	2020-01-03	12	[{"id_menu":3,"count":1}]	2306	delivery	5	17
21787	2020-01-03 06:16:31	2020-01-03	9	[{"id_menu":6,"count":1}]	1259	pick-up	0	9
21788	2020-01-03 06:17:48	2020-01-03	12	[{"id_menu":3,"count":1}]	8471	pick-up	0	12
21789	2020-01-03 06:35:48	2020-01-03	17	[{"id_menu":4,"count":1}]	8434	delivery	5	22
21790	2020-01-03 06:52:15	2020-01-03	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	8453	delivery	5	27
21791	2020-01-03 07:03:32	2020-01-03	12	[{"id_menu":1,"count":2}]	8446	pick-up	0	12
21792	2020-01-03 07:08:47	2020-01-03	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2440	delivery	5	26
21793	2020-01-03 07:29:54	2020-01-03	17	[{"id_menu":4,"count":1}]	1567	delivery	5	22
21794	2020-01-03 07:33:33	2020-01-03	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	8481	delivery	5	23
21795	2020-01-03 07:41:07	2020-01-03	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	4132	pick-up	0	29
21796	2020-01-03 07:48:03	2020-01-03	9	[{"id_menu":6,"count":1}]	5643	delivery	5	14
21797	2020-01-03 07:58:05	2020-01-03	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8304	delivery	5	22
21798	2020-01-03 08:06:55	2020-01-03	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4035	delivery	5	22
21799	2020-01-03 08:14:19	2020-01-03	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	7431	delivery	5	23
21800	2020-01-03 08:19:21	2020-01-03	9	[{"id_menu":7,"count":1}]	4224	pick-up	0	9
21801	2020-01-03 08:19:27	2020-01-03	14	[{"id_menu":2,"count":1}]	8463	delivery	5	19
21802	2020-01-03 08:45:37	2020-01-03	12	[{"id_menu":3,"count":1}]	2959	pick-up	0	12
21803	2020-01-03 09:00:41	2020-01-03	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7491	delivery	5	39
21804	2020-01-03 09:06:32	2020-01-03	9	[{"id_menu":6,"count":1}]	5308	delivery	5	14
21805	2020-01-03 09:07:27	2020-01-03	9	[{"id_menu":6,"count":2}]	3539	delivery	5	14
21806	2020-01-03 09:12:58	2020-01-03	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":2}]	5265	delivery	5	31
21807	2020-01-03 09:15:28	2020-01-03	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1245	pick-up	0	23
21808	2020-01-03 09:26:55	2020-01-03	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	2521	pick-up	0	35
21809	2020-01-03 09:42:14	2020-01-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3461	delivery	5	28
21810	2020-01-03 09:52:37	2020-01-03	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8444	delivery	5	40
21811	2020-01-03 10:00:28	2020-01-03	14	[{"id_menu":2,"count":1}]	6116	delivery	5	19
21812	2020-01-03 10:01:10	2020-01-03	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7667	delivery	5	34
21813	2020-01-03 10:03:32	2020-01-03	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	8470	delivery	5	26
21814	2020-01-03 10:12:11	2020-01-03	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	704	delivery	5	34
21815	2020-01-03 10:15:31	2020-01-03	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	8475	delivery	5	26
21816	2020-01-03 10:15:48	2020-01-03	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8421	delivery	5	31
21817	2020-01-03 10:22:53	2020-01-03	14	[{"id_menu":2,"count":1}]	2671	delivery	5	19
21818	2020-01-03 10:36:34	2020-01-03	9	[{"id_menu":7,"count":1}]	6055	delivery	5	14
21819	2020-01-03 10:43:59	2020-01-03	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3497	delivery	5	37
21820	2020-01-03 10:46:06	2020-01-03	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	8465	delivery	5	36
21821	2020-01-03 10:55:38	2020-01-03	9	[{"id_menu":6,"count":1}]	8417	delivery	5	14
21822	2020-01-03 11:11:22	2020-01-03	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":2}]	8455	delivery	5	30
21823	2020-01-03 11:15:32	2020-01-03	17	[{"id_menu":4,"count":1}]	8355	delivery	5	22
21824	2020-01-03 11:19:45	2020-01-03	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	6957	pick-up	0	18
21825	2020-01-03 11:21:12	2020-01-03	9	[{"id_menu":6,"count":1}]	3174	pick-up	0	9
21826	2020-01-03 11:22:24	2020-01-03	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	846	delivery	5	26
21827	2020-01-03 11:24:41	2020-01-03	12	[{"id_menu":3,"count":1}]	1744	delivery	5	17
21828	2020-01-03 11:26:10	2020-01-03	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1247	delivery	5	22
21829	2020-01-03 11:26:26	2020-01-03	9	[{"id_menu":7,"count":1}]	1931	pick-up	0	9
21830	2020-01-03 11:32:18	2020-01-03	9	[{"id_menu":7,"count":1}]	8420	delivery	5	14
21831	2020-01-03 12:01:10	2020-01-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	2420	pick-up	0	26
21832	2020-01-03 12:10:50	2020-01-03	9	[{"id_menu":6,"count":2}]	8469	delivery	5	14
21833	2020-01-03 12:13:41	2020-01-03	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2739	pick-up	0	21
21834	2020-01-03 12:14:43	2020-01-03	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	3512	pick-up	0	20
21835	2020-01-03 12:32:32	2020-01-03	9	[{"id_menu":7,"count":1}]	8477	delivery	5	14
21836	2020-01-03 12:33:02	2020-01-03	9	[{"id_menu":7,"count":1}]	1970	pick-up	0	9
21837	2020-01-03 12:35:13	2020-01-03	14	[{"id_menu":2,"count":1}]	1003	pick-up	0	14
21838	2020-01-03 12:50:24	2020-01-03	9	[{"id_menu":6,"count":1}]	6088	delivery	5	14
21839	2020-01-03 12:53:27	2020-01-03	9	[{"id_menu":6,"count":1}]	8461	delivery	5	14
21840	2020-01-03 13:14:44	2020-01-03	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6708	pick-up	0	46
21841	2020-01-03 13:33:10	2020-01-03	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	7397	pick-up	0	24
21842	2020-01-03 13:36:16	2020-01-03	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	7651	pick-up	0	26
21843	2020-01-03 13:41:19	2020-01-03	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	709	pick-up	0	31
21844	2020-01-03 13:47:45	2020-01-03	12	[{"id_menu":3,"count":1}]	8432	delivery	5	17
21845	2020-01-03 13:56:48	2020-01-03	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3336	delivery	5	26
21846	2020-01-03 14:23:43	2020-01-03	9	[{"id_menu":6,"count":1}]	8415	delivery	5	14
21847	2020-01-03 14:48:39	2020-01-03	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6814	delivery	5	35
21848	2020-01-03 15:00:47	2020-01-03	12	[{"id_menu":3,"count":1}]	3701	pick-up	0	12
21849	2020-01-03 15:03:38	2020-01-03	9	[{"id_menu":7,"count":1}]	8422	delivery	5	14
21850	2020-01-03 15:03:46	2020-01-03	8	[{"id_menu":5,"count":1}]	4193	pick-up	0	8
21851	2020-01-03 15:11:23	2020-01-03	9	[{"id_menu":6,"count":1}]	3048	pick-up	0	9
21852	2020-01-03 15:21:12	2020-01-03	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8436	delivery	5	23
21853	2020-01-03 15:22:12	2020-01-03	8	[{"id_menu":5,"count":1}]	5253	delivery	5	13
21854	2020-01-03 15:39:54	2020-01-03	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8411	delivery	5	30
21855	2020-01-03 15:40:26	2020-01-03	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8425	delivery	5	22
21856	2020-01-03 15:50:55	2020-01-03	8	[{"id_menu":5,"count":1}]	5353	delivery	5	13
21857	2020-01-03 15:52:55	2020-01-03	9	[{"id_menu":6,"count":1}]	8410	delivery	5	14
21858	2020-01-03 16:05:17	2020-01-03	17	[{"id_menu":4,"count":1}]	8424	delivery	5	22
21859	2020-01-03 16:13:27	2020-01-03	9	[{"id_menu":7,"count":1}]	7426	delivery	5	14
21860	2020-01-03 16:29:23	2020-01-03	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8451	delivery	5	40
21861	2020-01-03 16:31:33	2020-01-03	9	[{"id_menu":7,"count":1}]	917	delivery	5	14
21862	2020-01-03 16:36:20	2020-01-03	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5483	pick-up	0	25
21863	2020-01-03 17:01:02	2020-01-03	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2552	delivery	5	26
21864	2020-01-03 17:05:38	2020-01-03	12	[{"id_menu":1,"count":1}]	2442	pick-up	0	12
21865	2020-01-03 17:17:21	2020-01-03	12	[{"id_menu":1,"count":1}]	762	pick-up	0	12
21866	2020-01-03 17:24:42	2020-01-03	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	415	delivery	5	37
21867	2020-01-03 17:42:46	2020-01-03	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8467	delivery	5	40
21868	2020-01-03 17:44:03	2020-01-03	17	[{"id_menu":4,"count":1}]	8456	delivery	5	22
21869	2020-01-03 17:50:34	2020-01-03	14	[{"id_menu":2,"count":1}]	1143	pick-up	0	14
21870	2020-01-03 17:59:02	2020-01-03	9	[{"id_menu":7,"count":1}]	3243	delivery	5	14
21871	2020-01-03 18:01:51	2020-01-03	12	[{"id_menu":1,"count":1}]	2434	pick-up	0	12
21872	2020-01-03 18:16:57	2020-01-03	9	[{"id_menu":6,"count":1}]	6037	pick-up	0	9
21873	2020-01-03 18:17:29	2020-01-03	12	[{"id_menu":3,"count":1}]	3012	pick-up	0	12
21874	2020-01-03 18:21:32	2020-01-03	12	[{"id_menu":3,"count":1}]	6291	delivery	5	17
21875	2020-01-03 18:44:27	2020-01-03	9	[{"id_menu":6,"count":1}]	6285	delivery	5	14
21876	2020-01-03 18:55:45	2020-01-03	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	8462	delivery	5	23
21877	2020-01-03 18:56:00	2020-01-03	9	[{"id_menu":7,"count":1}]	2015	delivery	5	14
21878	2020-01-03 18:57:50	2020-01-03	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	8295	delivery	5	22
21879	2020-01-03 19:02:50	2020-01-03	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	8419	pick-up	0	20
21880	2020-01-03 19:24:47	2020-01-03	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	5071	delivery	5	28
21881	2020-01-03 19:26:11	2020-01-03	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8426	pick-up	0	23
21882	2020-01-03 19:26:11	2020-01-03	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	5440	pick-up	0	31
21883	2020-01-03 19:29:41	2020-01-03	14	[{"id_menu":2,"count":3}]	4104	delivery	5	19
21884	2020-01-03 19:31:32	2020-01-03	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5986	delivery	5	48
21885	2020-01-03 19:37:06	2020-01-03	12	[{"id_menu":3,"count":1}]	4758	pick-up	0	12
21886	2020-01-03 19:41:05	2020-01-03	9	[{"id_menu":6,"count":1}]	2078	pick-up	0	9
21887	2020-01-03 19:46:04	2020-01-03	43	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1059	delivery	5	48
21888	2020-01-03 19:47:27	2020-01-03	14	[{"id_menu":2,"count":1}]	6972	pick-up	0	14
21889	2020-01-03 19:57:41	2020-01-03	14	[{"id_menu":2,"count":1}]	1406	pick-up	0	14
21890	2020-01-03 20:25:41	2020-01-03	9	[{"id_menu":7,"count":1}]	8442	pick-up	0	9
21891	2020-01-03 20:26:24	2020-01-03	12	[{"id_menu":1,"count":1}]	8466	delivery	5	17
21892	2020-01-03 20:31:19	2020-01-03	14	[{"id_menu":2,"count":1}]	8416	delivery	5	19
21893	2020-01-03 20:32:29	2020-01-03	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	8435	delivery	5	36
21894	2020-01-03 20:34:38	2020-01-03	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	2789	delivery	5	31
21895	2020-01-03 20:38:37	2020-01-03	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	7019	pick-up	0	29
21896	2020-01-03 20:57:10	2020-01-03	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	1597	delivery	5	31
21897	2020-01-03 20:57:27	2020-01-03	9	[{"id_menu":7,"count":1}]	6318	delivery	5	14
21898	2020-01-03 21:00:26	2020-01-03	9	[{"id_menu":6,"count":1}]	8447	delivery	5	14
21899	2020-01-03 21:01:16	2020-01-03	14	[{"id_menu":2,"count":1}]	1390	delivery	5	19
21900	2020-01-03 21:23:09	2020-01-03	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	8452	delivery	5	28
21901	2020-01-03 21:40:44	2020-01-03	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1436	delivery	5	37
21902	2020-01-03 21:57:16	2020-01-03	9	[{"id_menu":7,"count":3}]	8445	delivery	5	14
21903	2020-01-03 22:21:56	2020-01-03	12	[{"id_menu":3,"count":1}]	1559	pick-up	0	12
21904	2020-01-03 22:29:26	2020-01-03	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5516	pick-up	0	46
21905	2020-01-03 22:38:46	2020-01-03	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	8433	delivery	5	27
21906	2020-01-03 22:42:17	2020-01-03	12	[{"id_menu":3,"count":1}]	722	delivery	5	17
21907	2020-01-03 22:49:36	2020-01-03	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7559	delivery	5	22
21908	2020-01-03 22:52:02	2020-01-03	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8440	delivery	5	22
21909	2020-01-03 22:58:18	2020-01-03	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8472	delivery	5	45
21910	2020-01-03 23:00:42	2020-01-03	9	[{"id_menu":6,"count":1}]	5970	pick-up	0	9
21911	2020-01-03 23:03:13	2020-01-03	8	[{"id_menu":5,"count":1}]	8438	delivery	5	13
21912	2020-01-03 23:23:17	2020-01-03	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4943	delivery	5	48
21913	2020-01-03 23:25:38	2020-01-03	9	[{"id_menu":7,"count":1}]	8381	delivery	5	14
21914	2020-01-03 23:27:09	2020-01-03	9	[{"id_menu":6,"count":1}]	1087	pick-up	0	9
21915	2020-01-03 23:35:35	2020-01-03	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	5740	delivery	5	43
21916	2020-01-03 23:38:52	2020-01-03	9	[{"id_menu":7,"count":1}]	8474	pick-up	0	9
21917	2020-01-03 23:51:13	2020-01-03	9	[{"id_menu":7,"count":1}]	6916	delivery	5	14
21918	2020-01-03 23:54:28	2020-01-03	9	[{"id_menu":6,"count":1}]	5639	delivery	5	14
21919	2020-01-04 00:03:12	2020-01-04	14	[{"id_menu":2,"count":1}]	4395	pick-up	0	14
21920	2020-01-04 00:15:25	2020-01-04	8	[{"id_menu":5,"count":1}]	5303	pick-up	0	8
21921	2020-01-04 00:23:46	2020-01-04	9	[{"id_menu":7,"count":1}]	7772	pick-up	0	9
21922	2020-01-04 00:31:41	2020-01-04	12	[{"id_menu":3,"count":1}]	3755	pick-up	0	12
21923	2020-01-04 00:38:13	2020-01-04	8	[{"id_menu":5,"count":1}]	8511	delivery	5	13
21924	2020-01-04 00:40:55	2020-01-04	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8504	delivery	5	39
21925	2020-01-04 00:40:55	2020-01-04	14	[{"id_menu":2,"count":1}]	63	pick-up	0	14
21926	2020-01-04 00:41:22	2020-01-04	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	8553	delivery	5	35
21927	2020-01-04 00:50:26	2020-01-04	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	3437	pick-up	0	21
21928	2020-01-04 00:55:35	2020-01-04	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8543	pick-up	0	29
21929	2020-01-04 01:05:44	2020-01-04	12	[{"id_menu":3,"count":1}]	2897	delivery	5	17
21930	2020-01-04 01:17:51	2020-01-04	9	[{"id_menu":6,"count":1}]	5409	pick-up	0	9
21931	2020-01-04 01:43:16	2020-01-04	8	[{"id_menu":5,"count":1}]	154	pick-up	0	8
21932	2020-01-04 01:53:54	2020-01-04	8	[{"id_menu":5,"count":1}]	819	pick-up	0	8
21933	2020-01-04 01:55:14	2020-01-04	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8535	delivery	5	43
21934	2020-01-04 01:58:37	2020-01-04	14	[{"id_menu":2,"count":1}]	957	pick-up	0	14
21935	2020-01-04 02:14:07	2020-01-04	17	[{"id_menu":4,"count":1}]	8567	pick-up	0	17
21936	2020-01-04 02:18:53	2020-01-04	9	[{"id_menu":6,"count":1}]	372	pick-up	0	9
21937	2020-01-04 02:25:30	2020-01-04	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4558	delivery	5	22
21938	2020-01-04 02:26:18	2020-01-04	14	[{"id_menu":2,"count":1}]	2477	delivery	5	19
21939	2020-01-04 02:29:48	2020-01-04	39	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3836	delivery	5	44
21940	2020-01-04 02:31:34	2020-01-04	9	[{"id_menu":6,"count":1}]	8493	pick-up	0	9
21941	2020-01-04 02:36:53	2020-01-04	9	[{"id_menu":6,"count":1}]	7746	delivery	5	14
21942	2020-01-04 02:40:11	2020-01-04	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3619	delivery	5	31
21943	2020-01-04 02:45:12	2020-01-04	9	[{"id_menu":7,"count":1}]	2208	delivery	5	14
21944	2020-01-04 02:54:41	2020-01-04	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1053	delivery	5	31
21945	2020-01-04 02:59:28	2020-01-04	8	[{"id_menu":5,"count":1}]	5556	delivery	5	13
21946	2020-01-04 03:01:31	2020-01-04	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	5050	pick-up	0	20
21947	2020-01-04 03:05:46	2020-01-04	9	[{"id_menu":6,"count":1}]	6820	delivery	5	14
21948	2020-01-04 03:09:43	2020-01-04	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	8568	delivery	5	22
21949	2020-01-04 03:10:21	2020-01-04	9	[{"id_menu":6,"count":1}]	8484	delivery	5	14
21950	2020-01-04 03:23:17	2020-01-04	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	8570	delivery	5	27
21951	2020-01-04 03:27:01	2020-01-04	12	[{"id_menu":3,"count":1}]	1696	delivery	5	17
21952	2020-01-04 03:35:47	2020-01-04	8	[{"id_menu":5,"count":1}]	2176	pick-up	0	8
21953	2020-01-04 03:39:47	2020-01-04	9	[{"id_menu":6,"count":1}]	5640	delivery	5	14
21954	2020-01-04 03:46:30	2020-01-04	8	[{"id_menu":5,"count":1}]	8561	pick-up	0	8
21955	2020-01-04 03:47:22	2020-01-04	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	8554	delivery	5	31
21956	2020-01-04 03:54:41	2020-01-04	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8508	delivery	5	45
21957	2020-01-04 03:55:06	2020-01-04	17	[{"id_menu":4,"count":1}]	8559	delivery	5	22
21958	2020-01-04 04:00:32	2020-01-04	14	[{"id_menu":2,"count":1}]	6580	delivery	5	19
21959	2020-01-04 04:03:04	2020-01-04	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	8505	pick-up	0	21
21960	2020-01-04 04:24:06	2020-01-04	14	[{"id_menu":2,"count":1}]	256	pick-up	0	14
21961	2020-01-04 04:29:41	2020-01-04	17	[{"id_menu":4,"count":1}]	1723	delivery	5	22
21962	2020-01-04 04:31:35	2020-01-04	17	[{"id_menu":4,"count":1}]	8500	delivery	5	22
21963	2020-01-04 04:31:45	2020-01-04	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8516	pick-up	0	48
21964	2020-01-04 04:35:51	2020-01-04	17	[{"id_menu":4,"count":1}]	2059	pick-up	0	17
21965	2020-01-04 04:36:16	2020-01-04	9	[{"id_menu":6,"count":1}]	8530	delivery	5	14
21966	2020-01-04 04:41:09	2020-01-04	12	[{"id_menu":1,"count":1}]	7912	delivery	5	17
21967	2020-01-04 04:48:48	2020-01-04	9	[{"id_menu":7,"count":1}]	2331	delivery	5	14
21968	2020-01-04 04:49:45	2020-01-04	9	[{"id_menu":6,"count":1}]	3040	delivery	5	14
21969	2020-01-04 04:50:59	2020-01-04	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	8575	pick-up	0	29
21970	2020-01-04 04:55:00	2020-01-04	12	[{"id_menu":3,"count":1}]	3646	delivery	5	17
21971	2020-01-04 04:57:47	2020-01-04	14	[{"id_menu":2,"count":1}]	6688	delivery	5	19
21972	2020-01-04 04:58:35	2020-01-04	17	[{"id_menu":4,"count":1}]	8181	delivery	5	22
21973	2020-01-04 05:00:45	2020-01-04	9	[{"id_menu":7,"count":1}]	1354	pick-up	0	9
21974	2020-01-04 05:05:51	2020-01-04	12	[{"id_menu":1,"count":1}]	8519	pick-up	0	12
21975	2020-01-04 05:12:08	2020-01-04	9	[{"id_menu":7,"count":1}]	8533	delivery	5	14
21976	2020-01-04 05:13:37	2020-01-04	12	[{"id_menu":1,"count":1}]	3236	delivery	5	17
21977	2020-01-04 05:14:26	2020-01-04	9	[{"id_menu":6,"count":1}]	8482	delivery	5	14
21978	2020-01-04 05:17:45	2020-01-04	9	[{"id_menu":7,"count":1}]	1667	pick-up	0	9
21979	2020-01-04 05:34:39	2020-01-04	9	[{"id_menu":7,"count":1}]	7178	delivery	5	14
21980	2020-01-04 05:45:22	2020-01-04	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3480	delivery	5	45
21981	2020-01-04 05:51:13	2020-01-04	14	[{"id_menu":2,"count":1}]	5875	pick-up	0	14
21982	2020-01-04 06:05:34	2020-01-04	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8311	delivery	5	23
21983	2020-01-04 06:30:38	2020-01-04	9	[{"id_menu":7,"count":1}]	3539	pick-up	0	9
21984	2020-01-04 06:35:58	2020-01-04	17	[{"id_menu":4,"count":1}]	3537	delivery	5	22
21985	2020-01-04 06:52:42	2020-01-04	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	8542	delivery	5	29
21986	2020-01-04 06:54:27	2020-01-04	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	2821	pick-up	0	32
21987	2020-01-04 06:59:40	2020-01-04	12	[{"id_menu":3,"count":1}]	1404	pick-up	0	12
21988	2020-01-04 07:09:20	2020-01-04	17	[{"id_menu":4,"count":1}]	1638	delivery	5	22
21989	2020-01-04 07:11:31	2020-01-04	9	[{"id_menu":6,"count":2}]	7141	delivery	5	14
21990	2020-01-04 07:12:14	2020-01-04	17	[{"id_menu":4,"count":1}]	8496	delivery	5	22
21991	2020-01-04 07:18:04	2020-01-04	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2768	delivery	5	36
21992	2020-01-04 07:20:31	2020-01-04	14	[{"id_menu":2,"count":1}]	4695	pick-up	0	14
21993	2020-01-04 07:29:37	2020-01-04	17	[{"id_menu":4,"count":2}]	8573	delivery	5	22
21994	2020-01-04 07:34:43	2020-01-04	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	691	pick-up	0	20
21995	2020-01-04 08:00:43	2020-01-04	12	[{"id_menu":3,"count":1}]	1627	pick-up	0	12
21996	2020-01-04 08:06:35	2020-01-04	14	[{"id_menu":2,"count":1}]	5352	delivery	5	19
21997	2020-01-04 08:16:55	2020-01-04	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8492	delivery	5	40
21998	2020-01-04 08:31:18	2020-01-04	12	[{"id_menu":3,"count":1}]	1369	pick-up	0	12
21999	2020-01-04 08:31:41	2020-01-04	14	[{"id_menu":2,"count":1}]	8571	delivery	5	19
22000	2020-01-04 08:39:28	2020-01-04	12	[{"id_menu":1,"count":1}]	8549	delivery	5	17
22001	2020-01-04 08:41:14	2020-01-04	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8056	delivery	5	22
22002	2020-01-04 08:44:31	2020-01-04	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	5097	delivery	5	28
22003	2020-01-04 09:04:06	2020-01-04	8	[{"id_menu":5,"count":1}]	8526	delivery	5	13
22004	2020-01-04 09:06:11	2020-01-04	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	8471	pick-up	0	23
22005	2020-01-04 09:17:43	2020-01-04	14	[{"id_menu":2,"count":1}]	3267	delivery	5	19
22006	2020-01-04 09:23:19	2020-01-04	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5880	delivery	5	45
22007	2020-01-04 09:26:03	2020-01-04	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	7726	pick-up	0	24
22008	2020-01-04 09:27:44	2020-01-04	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	8576	delivery	5	45
22009	2020-01-04 09:38:34	2020-01-04	9	[{"id_menu":7,"count":1}]	7710	pick-up	0	9
22010	2020-01-04 09:41:11	2020-01-04	9	[{"id_menu":6,"count":1}]	7051	pick-up	0	9
22011	2020-01-04 09:47:06	2020-01-04	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8539	delivery	5	30
22012	2020-01-04 09:59:33	2020-01-04	12	[{"id_menu":1,"count":1}]	8521	pick-up	0	12
22013	2020-01-04 10:08:30	2020-01-04	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5154	pick-up	0	31
22014	2020-01-04 10:15:19	2020-01-04	9	[{"id_menu":6,"count":1}]	355	pick-up	0	9
22015	2020-01-04 10:15:43	2020-01-04	8	[{"id_menu":5,"count":1}]	2962	pick-up	0	8
22016	2020-01-04 10:18:36	2020-01-04	9	[{"id_menu":6,"count":3}]	635	delivery	5	14
22017	2020-01-04 10:21:12	2020-01-04	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	8550	pick-up	0	29
22018	2020-01-04 10:23:24	2020-01-04	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2216	pick-up	0	38
22019	2020-01-04 10:40:15	2020-01-04	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":3}]	2791	delivery	5	25
22020	2020-01-04 10:46:24	2020-01-04	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	924	pick-up	0	41
22021	2020-01-04 10:46:45	2020-01-04	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8483	delivery	5	39
22022	2020-01-04 10:47:37	2020-01-04	8	[{"id_menu":5,"count":1}]	6439	pick-up	0	8
22023	2020-01-04 10:48:46	2020-01-04	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2332	delivery	5	31
22024	2020-01-04 10:49:03	2020-01-04	9	[{"id_menu":6,"count":1}]	6560	pick-up	0	9
22025	2020-01-04 10:49:42	2020-01-04	14	[{"id_menu":2,"count":1}]	8234	delivery	5	19
22026	2020-01-04 10:53:07	2020-01-04	9	[{"id_menu":7,"count":1}]	171	delivery	5	14
22027	2020-01-04 10:56:05	2020-01-04	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2728	pick-up	0	25
22028	2020-01-04 10:58:04	2020-01-04	14	[{"id_menu":2,"count":1}]	8572	pick-up	0	14
22029	2020-01-04 10:59:01	2020-01-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6788	delivery	5	28
22030	2020-01-04 11:01:07	2020-01-04	9	[{"id_menu":6,"count":1}]	8534	delivery	5	14
22031	2020-01-04 11:06:30	2020-01-04	9	[{"id_menu":6,"count":1}]	8518	delivery	5	14
22032	2020-01-04 11:11:07	2020-01-04	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	8577	pick-up	0	34
22033	2020-01-04 11:14:03	2020-01-04	9	[{"id_menu":7,"count":1}]	573	pick-up	0	9
22034	2020-01-04 11:15:12	2020-01-04	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4171	delivery	5	46
22035	2020-01-04 11:19:27	2020-01-04	8	[{"id_menu":5,"count":1}]	8514	delivery	5	13
22036	2020-01-04 11:32:13	2020-01-04	9	[{"id_menu":6,"count":1}]	8498	delivery	5	14
22037	2020-01-04 11:49:04	2020-01-04	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":3}]	8517	delivery	5	22
22038	2020-01-04 12:00:05	2020-01-04	8	[{"id_menu":5,"count":1}]	8532	delivery	5	13
22039	2020-01-04 12:00:40	2020-01-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	8548	delivery	5	28
22040	2020-01-04 12:12:32	2020-01-04	17	[{"id_menu":4,"count":1}]	7318	delivery	5	22
22041	2020-01-04 12:17:36	2020-01-04	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8563	delivery	5	34
22042	2020-01-04 12:23:14	2020-01-04	9	[{"id_menu":6,"count":1}]	8299	delivery	5	14
22043	2020-01-04 12:27:43	2020-01-04	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	8574	pick-up	0	24
22044	2020-01-04 12:39:10	2020-01-04	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4798	delivery	5	35
22045	2020-01-04 12:42:48	2020-01-04	17	[{"id_menu":4,"count":1}]	1810	delivery	5	22
22046	2020-01-04 12:46:42	2020-01-04	9	[{"id_menu":6,"count":1}]	8497	delivery	5	14
22047	2020-01-04 12:49:43	2020-01-04	12	[{"id_menu":3,"count":1}]	3350	delivery	5	17
22048	2020-01-04 12:50:15	2020-01-04	12	[{"id_menu":3,"count":1}]	7808	pick-up	0	12
22049	2020-01-04 12:56:13	2020-01-04	12	[{"id_menu":3,"count":1}]	906	pick-up	0	12
22050	2020-01-04 12:57:33	2020-01-04	14	[{"id_menu":2,"count":1}]	5427	delivery	5	19
22051	2020-01-04 13:02:53	2020-01-04	12	[{"id_menu":1,"count":1}]	8556	delivery	5	17
22052	2020-01-04 13:03:26	2020-01-04	8	[{"id_menu":5,"count":1}]	8524	delivery	5	13
22053	2020-01-04 13:06:18	2020-01-04	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2848	delivery	5	26
22054	2020-01-04 13:07:03	2020-01-04	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2526	delivery	5	31
22055	2020-01-04 13:07:14	2020-01-04	17	[{"id_menu":4,"count":1}]	2505	pick-up	0	17
22056	2020-01-04 13:22:56	2020-01-04	14	[{"id_menu":2,"count":1}]	729	pick-up	0	14
22057	2020-01-04 13:26:32	2020-01-04	12	[{"id_menu":1,"count":1}]	8544	delivery	5	17
22058	2020-01-04 13:29:47	2020-01-04	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8512	delivery	5	30
22059	2020-01-04 13:33:31	2020-01-04	14	[{"id_menu":2,"count":2}]	1254	delivery	5	19
22060	2020-01-04 13:38:24	2020-01-04	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	7888	delivery	5	25
22061	2020-01-04 13:47:45	2020-01-04	14	[{"id_menu":2,"count":1}]	2590	pick-up	0	14
22062	2020-01-04 13:49:33	2020-01-04	8	[{"id_menu":5,"count":1}]	8536	delivery	5	13
22063	2020-01-04 13:50:31	2020-01-04	14	[{"id_menu":2,"count":1}]	8501	delivery	5	19
22064	2020-01-04 13:52:52	2020-01-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	376	pick-up	0	23
22065	2020-01-04 14:01:54	2020-01-04	17	[{"id_menu":4,"count":1}]	6243	pick-up	0	17
22066	2020-01-04 14:06:36	2020-01-04	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8503	delivery	5	36
22067	2020-01-04 14:13:13	2020-01-04	9	[{"id_menu":6,"count":1}]	96	pick-up	0	9
22068	2020-01-04 14:19:08	2020-01-04	8	[{"id_menu":5,"count":1}]	378	delivery	5	13
22069	2020-01-04 14:27:52	2020-01-04	12	[{"id_menu":1,"count":1}]	6589	delivery	5	17
22070	2020-01-04 14:32:30	2020-01-04	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5473	pick-up	0	46
22071	2020-01-04 14:37:51	2020-01-04	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	6930	delivery	5	31
22072	2020-01-04 14:43:30	2020-01-04	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7069	pick-up	0	37
22073	2020-01-04 14:46:18	2020-01-04	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	7007	delivery	5	43
22074	2020-01-04 14:57:52	2020-01-04	9	[{"id_menu":7,"count":1}]	3158	pick-up	0	9
22075	2020-01-04 15:05:07	2020-01-04	12	[{"id_menu":3,"count":1}]	8506	delivery	5	17
22076	2020-01-04 15:06:03	2020-01-04	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7885	delivery	5	28
22077	2020-01-04 15:09:12	2020-01-04	9	[{"id_menu":7,"count":2}]	8558	delivery	5	14
22078	2020-01-04 15:11:08	2020-01-04	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6505	delivery	5	36
22079	2020-01-04 15:11:53	2020-01-04	12	[{"id_menu":1,"count":1}]	8545	delivery	5	17
22080	2020-01-04 15:13:27	2020-01-04	17	[{"id_menu":4,"count":1}]	8488	pick-up	0	17
22081	2020-01-04 15:20:05	2020-01-04	8	[{"id_menu":5,"count":1}]	5332	pick-up	0	8
22082	2020-01-04 15:32:12	2020-01-04	12	[{"id_menu":1,"count":1}]	6399	delivery	5	17
22083	2020-01-04 15:33:52	2020-01-04	14	[{"id_menu":2,"count":2}]	8569	delivery	5	19
22084	2020-01-04 15:34:14	2020-01-04	17	[{"id_menu":4,"count":1}]	8565	delivery	5	22
22085	2020-01-04 15:37:09	2020-01-04	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8564	delivery	5	51
22086	2020-01-04 15:39:08	2020-01-04	9	[{"id_menu":6,"count":1}]	6349	delivery	5	14
22087	2020-01-04 15:44:35	2020-01-04	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6729	delivery	5	30
22088	2020-01-04 15:48:05	2020-01-04	9	[{"id_menu":6,"count":1}]	7557	delivery	5	14
22089	2020-01-04 15:48:21	2020-01-04	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	5194	delivery	5	26
22090	2020-01-04 15:50:27	2020-01-04	8	[{"id_menu":5,"count":1}]	1756	delivery	5	13
22091	2020-01-04 15:51:18	2020-01-04	12	[{"id_menu":3,"count":1}]	5961	pick-up	0	12
22092	2020-01-04 15:56:42	2020-01-04	9	[{"id_menu":6,"count":1}]	7491	delivery	5	14
22093	2020-01-04 15:56:54	2020-01-04	9	[{"id_menu":7,"count":1}]	5183	delivery	5	14
22094	2020-01-04 15:58:09	2020-01-04	8	[{"id_menu":5,"count":1}]	8562	delivery	5	13
22095	2020-01-04 16:01:53	2020-01-04	9	[{"id_menu":6,"count":1}]	4506	pick-up	0	9
22096	2020-01-04 16:04:31	2020-01-04	9	[{"id_menu":6,"count":1}]	7675	delivery	5	14
22097	2020-01-04 16:13:53	2020-01-04	9	[{"id_menu":6,"count":1}]	2900	delivery	5	14
22098	2020-01-04 16:18:26	2020-01-04	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3718	delivery	5	26
22099	2020-01-04 16:23:26	2020-01-04	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8557	delivery	5	31
22100	2020-01-04 16:23:41	2020-01-04	8	[{"id_menu":5,"count":1}]	4882	delivery	5	13
22101	2020-01-04 16:26:24	2020-01-04	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2698	delivery	5	31
22102	2020-01-04 16:34:52	2020-01-04	9	[{"id_menu":6,"count":1}]	8538	delivery	5	14
22103	2020-01-04 16:35:39	2020-01-04	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5865	delivery	5	36
22104	2020-01-04 16:38:21	2020-01-04	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7190	delivery	5	51
22105	2020-01-04 16:43:05	2020-01-04	9	[{"id_menu":7,"count":1}]	8515	delivery	5	14
22106	2020-01-04 17:04:38	2020-01-04	9	[{"id_menu":6,"count":1}]	3268	delivery	5	14
22107	2020-01-04 17:05:45	2020-01-04	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	5360	delivery	5	39
22108	2020-01-04 17:08:40	2020-01-04	9	[{"id_menu":6,"count":2}]	2520	pick-up	0	9
22109	2020-01-04 17:11:05	2020-01-04	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2191	delivery	5	36
22110	2020-01-04 17:15:33	2020-01-04	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7186	delivery	5	22
22111	2020-01-04 17:20:11	2020-01-04	12	[{"id_menu":3,"count":1}]	3444	pick-up	0	12
22112	2020-01-04 17:22:13	2020-01-04	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	8552	delivery	5	46
22113	2020-01-04 17:29:41	2020-01-04	8	[{"id_menu":5,"count":1}]	3651	pick-up	0	8
22114	2020-01-04 17:38:52	2020-01-04	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	3399	pick-up	0	21
22115	2020-01-04 17:42:16	2020-01-04	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1134	pick-up	0	23
22116	2020-01-04 17:43:20	2020-01-04	12	[{"id_menu":1,"count":1}]	4685	delivery	5	17
22117	2020-01-04 17:46:02	2020-01-04	17	[{"id_menu":4,"count":1}]	5193	delivery	5	22
22118	2020-01-04 17:53:07	2020-01-04	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	7446	delivery	5	28
22119	2020-01-04 17:57:31	2020-01-04	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	506	pick-up	0	29
22120	2020-01-04 18:00:31	2020-01-04	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	8507	delivery	5	36
22121	2020-01-04 18:03:43	2020-01-04	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8486	delivery	5	45
22122	2020-01-04 18:05:43	2020-01-04	9	[{"id_menu":7,"count":1}]	8540	delivery	5	14
22123	2020-01-04 18:07:03	2020-01-04	14	[{"id_menu":2,"count":1}]	1247	delivery	5	19
22124	2020-01-04 18:36:50	2020-01-04	14	[{"id_menu":2,"count":1}]	3864	delivery	5	19
22125	2020-01-04 18:41:43	2020-01-04	8	[{"id_menu":5,"count":1}]	5889	delivery	5	13
22126	2020-01-04 18:48:37	2020-01-04	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8527	delivery	5	37
22127	2020-01-04 18:57:10	2020-01-04	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	8487	delivery	5	22
22128	2020-01-04 18:58:27	2020-01-04	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	5913	delivery	5	29
22129	2020-01-04 18:59:43	2020-01-04	9	[{"id_menu":7,"count":1}]	7050	delivery	5	14
22130	2020-01-04 19:02:13	2020-01-04	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	8520	delivery	5	40
22131	2020-01-04 19:11:49	2020-01-04	12	[{"id_menu":1,"count":1}]	8566	pick-up	0	12
22132	2020-01-04 19:22:38	2020-01-04	9	[{"id_menu":6,"count":1}]	7373	delivery	5	14
22133	2020-01-04 19:23:00	2020-01-04	12	[{"id_menu":3,"count":1}]	8495	delivery	5	17
22134	2020-01-04 19:34:10	2020-01-04	14	[{"id_menu":2,"count":1}]	1907	pick-up	0	14
22135	2020-01-04 19:46:27	2020-01-04	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4478	delivery	5	39
22136	2020-01-04 20:00:07	2020-01-04	17	[{"id_menu":4,"count":1}]	8546	delivery	5	22
22137	2020-01-04 20:01:58	2020-01-04	9	[{"id_menu":6,"count":1}]	4860	delivery	5	14
22138	2020-01-04 20:12:41	2020-01-04	8	[{"id_menu":5,"count":1}]	3701	pick-up	0	8
22139	2020-01-04 20:18:43	2020-01-04	12	[{"id_menu":1,"count":1}]	8525	delivery	5	17
22140	2020-01-04 20:24:17	2020-01-04	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	8523	delivery	5	31
22141	2020-01-04 20:27:11	2020-01-04	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	8490	delivery	5	37
22142	2020-01-04 20:27:25	2020-01-04	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	8502	delivery	5	31
22143	2020-01-04 20:31:49	2020-01-04	9	[{"id_menu":7,"count":1}]	5047	delivery	5	14
22144	2020-01-04 20:46:31	2020-01-04	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":2}]	7368	delivery	5	22
22145	2020-01-04 20:52:16	2020-01-04	12	[{"id_menu":3,"count":1}]	2653	pick-up	0	12
22146	2020-01-04 20:55:58	2020-01-04	14	[{"id_menu":2,"count":1}]	5311	pick-up	0	14
22147	2020-01-04 20:56:19	2020-01-04	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	8509	delivery	5	34
22148	2020-01-04 21:02:32	2020-01-04	9	[{"id_menu":6,"count":1}]	8541	delivery	5	14
22149	2020-01-04 21:05:29	2020-01-04	14	[{"id_menu":2,"count":1}]	1722	delivery	5	19
22150	2020-01-04 21:07:19	2020-01-04	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5453	delivery	5	39
22151	2020-01-04 21:16:45	2020-01-04	14	[{"id_menu":2,"count":1}]	2870	delivery	5	19
22152	2020-01-04 21:23:17	2020-01-04	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	8528	delivery	5	36
22153	2020-01-04 21:36:01	2020-01-04	17	[{"id_menu":4,"count":1}]	4648	delivery	5	22
22154	2020-01-04 21:38:11	2020-01-04	17	[{"id_menu":4,"count":1}]	3005	delivery	5	22
22155	2020-01-04 21:38:33	2020-01-04	8	[{"id_menu":5,"count":1}]	8491	delivery	5	13
22156	2020-01-04 21:40:52	2020-01-04	9	[{"id_menu":7,"count":1}]	4495	delivery	5	14
22157	2020-01-04 21:53:43	2020-01-04	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	8510	delivery	5	28
22158	2020-01-04 21:57:27	2020-01-04	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1328	pick-up	0	26
22159	2020-01-04 22:02:05	2020-01-04	12	[{"id_menu":1,"count":2}]	8494	delivery	5	17
22160	2020-01-04 22:02:09	2020-01-04	14	[{"id_menu":2,"count":1}]	226	pick-up	0	14
22161	2020-01-04 22:06:37	2020-01-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8499	delivery	5	28
22162	2020-01-04 22:07:41	2020-01-04	14	[{"id_menu":2,"count":1}]	437	delivery	5	19
22163	2020-01-04 22:21:16	2020-01-04	17	[{"id_menu":4,"count":1}]	3347	pick-up	0	17
22164	2020-01-04 22:26:52	2020-01-04	9	[{"id_menu":7,"count":1}]	7197	delivery	5	14
22165	2020-01-04 22:51:40	2020-01-04	9	[{"id_menu":6,"count":1}]	8560	delivery	5	14
22166	2020-01-04 22:55:13	2020-01-04	17	[{"id_menu":4,"count":1}]	8578	delivery	5	22
22167	2020-01-04 22:55:18	2020-01-04	8	[{"id_menu":5,"count":1}]	8402	delivery	5	13
22168	2020-01-04 23:03:08	2020-01-04	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	7638	delivery	5	22
22169	2020-01-04 23:04:39	2020-01-04	12	[{"id_menu":1,"count":1}]	8555	delivery	5	17
22170	2020-01-04 23:04:50	2020-01-04	8	[{"id_menu":5,"count":1}]	6984	delivery	5	13
22171	2020-01-04 23:07:00	2020-01-04	12	[{"id_menu":1,"count":1}]	688	pick-up	0	12
22172	2020-01-04 23:09:07	2020-01-04	9	[{"id_menu":7,"count":1}]	8537	delivery	5	14
22173	2020-01-04 23:14:05	2020-01-04	9	[{"id_menu":6,"count":1}]	8522	delivery	5	14
22174	2020-01-04 23:15:40	2020-01-04	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3414	delivery	5	28
22175	2020-01-04 23:18:11	2020-01-04	14	[{"id_menu":2,"count":1}]	3996	delivery	5	19
22176	2020-01-04 23:24:26	2020-01-04	14	[{"id_menu":2,"count":1}]	3090	delivery	5	19
22177	2020-01-04 23:24:45	2020-01-04	12	[{"id_menu":1,"count":1}]	5082	pick-up	0	12
22178	2020-01-04 23:27:25	2020-01-04	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	4731	pick-up	0	26
22179	2020-01-04 23:27:59	2020-01-04	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1363	pick-up	0	29
22180	2020-01-04 23:41:13	2020-01-04	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	8485	pick-up	0	21
22181	2020-01-04 23:46:02	2020-01-04	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	585	delivery	5	45
22182	2020-01-04 23:50:14	2020-01-04	14	[{"id_menu":2,"count":2}]	8531	delivery	5	19
22183	2020-01-04 23:51:18	2020-01-04	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8489	pick-up	0	38
22184	2020-01-05 00:09:07	2020-01-05	14	[{"id_menu":2,"count":1}]	3661	delivery	5	19
22185	2020-01-05 00:16:57	2020-01-05	12	[{"id_menu":1,"count":1}]	2443	delivery	5	17
22186	2020-01-05 00:23:06	2020-01-05	9	[{"id_menu":6,"count":1}]	8456	delivery	5	14
22187	2020-01-05 00:24:48	2020-01-05	12	[{"id_menu":3,"count":1}]	4967	pick-up	0	12
22188	2020-01-05 00:27:29	2020-01-05	12	[{"id_menu":3,"count":1}]	8627	delivery	5	17
22189	2020-01-05 00:33:36	2020-01-05	17	[{"id_menu":4,"count":1}]	1402	pick-up	0	17
22190	2020-01-05 00:36:21	2020-01-05	12	[{"id_menu":3,"count":1}]	8085	delivery	5	17
22191	2020-01-05 00:40:50	2020-01-05	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1548	pick-up	0	31
22192	2020-01-05 00:42:12	2020-01-05	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	4783	pick-up	0	29
22193	2020-01-05 00:45:29	2020-01-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5958	delivery	5	31
22194	2020-01-05 01:12:17	2020-01-05	9	[{"id_menu":6,"count":1}]	8630	delivery	5	14
22195	2020-01-05 01:13:26	2020-01-05	12	[{"id_menu":1,"count":1}]	8666	pick-up	0	12
22196	2020-01-05 01:24:56	2020-01-05	14	[{"id_menu":2,"count":1}]	2552	pick-up	0	14
22197	2020-01-05 01:28:16	2020-01-05	9	[{"id_menu":6,"count":1}]	7383	pick-up	0	9
22198	2020-01-05 01:41:10	2020-01-05	8	[{"id_menu":5,"count":1}]	8582	delivery	5	13
22199	2020-01-05 01:47:20	2020-01-05	9	[{"id_menu":6,"count":1}]	8616	delivery	5	14
22200	2020-01-05 01:50:11	2020-01-05	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5069	delivery	5	45
22201	2020-01-05 02:16:46	2020-01-05	12	[{"id_menu":1,"count":1}]	6798	delivery	5	17
22202	2020-01-05 02:17:44	2020-01-05	9	[{"id_menu":7,"count":1}]	3106	delivery	5	14
22203	2020-01-05 02:18:03	2020-01-05	9	[{"id_menu":6,"count":1}]	7730	delivery	5	14
22204	2020-01-05 02:18:11	2020-01-05	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	5479	delivery	5	28
22205	2020-01-05 02:19:46	2020-01-05	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	8641	delivery	5	40
22206	2020-01-05 02:22:11	2020-01-05	12	[{"id_menu":1,"count":1}]	1992	pick-up	0	12
22207	2020-01-05 02:37:49	2020-01-05	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2662	pick-up	0	23
22208	2020-01-05 02:42:37	2020-01-05	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	749	pick-up	0	32
22209	2020-01-05 02:42:46	2020-01-05	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5526	pick-up	0	25
22210	2020-01-05 02:45:44	2020-01-05	9	[{"id_menu":6,"count":1}]	8664	delivery	5	14
22211	2020-01-05 02:52:17	2020-01-05	8	[{"id_menu":5,"count":1}]	8637	pick-up	0	8
22212	2020-01-05 02:58:54	2020-01-05	12	[{"id_menu":1,"count":1}]	2097	pick-up	0	12
22213	2020-01-05 03:00:05	2020-01-05	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2817	delivery	5	43
22214	2020-01-05 03:02:51	2020-01-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	154	pick-up	0	17
22215	2020-01-05 03:07:00	2020-01-05	14	[{"id_menu":2,"count":1}]	8642	delivery	5	19
22216	2020-01-05 03:08:02	2020-01-05	17	[{"id_menu":4,"count":1}]	1419	pick-up	0	17
22217	2020-01-05 03:14:05	2020-01-05	17	[{"id_menu":4,"count":1}]	5286	pick-up	0	17
22218	2020-01-05 03:14:29	2020-01-05	12	[{"id_menu":3,"count":1}]	2897	pick-up	0	12
22219	2020-01-05 03:21:14	2020-01-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2257	delivery	5	23
22220	2020-01-05 03:21:46	2020-01-05	12	[{"id_menu":3,"count":1}]	8590	delivery	5	17
22221	2020-01-05 03:27:48	2020-01-05	12	[{"id_menu":3,"count":1}]	8604	delivery	5	17
22222	2020-01-05 03:27:50	2020-01-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6792	delivery	5	22
22223	2020-01-05 03:33:59	2020-01-05	12	[{"id_menu":1,"count":1}]	6666	pick-up	0	12
22224	2020-01-05 03:38:14	2020-01-05	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3365	pick-up	0	26
22225	2020-01-05 03:42:48	2020-01-05	17	[{"id_menu":4,"count":1}]	4130	pick-up	0	17
22226	2020-01-05 03:46:13	2020-01-05	9	[{"id_menu":7,"count":1}]	8662	delivery	5	14
22227	2020-01-05 03:59:00	2020-01-05	12	[{"id_menu":1,"count":1}]	5232	pick-up	0	12
22228	2020-01-05 04:00:57	2020-01-05	8	[{"id_menu":5,"count":1}]	6535	delivery	5	13
22229	2020-01-05 04:03:05	2020-01-05	14	[{"id_menu":2,"count":1}]	6238	pick-up	0	14
22230	2020-01-05 04:12:02	2020-01-05	9	[{"id_menu":6,"count":1}]	5881	delivery	5	14
22231	2020-01-05 04:19:49	2020-01-05	8	[{"id_menu":5,"count":1}]	352	delivery	5	13
22232	2020-01-05 04:20:32	2020-01-05	14	[{"id_menu":2,"count":1}]	5041	delivery	5	19
22233	2020-01-05 04:24:17	2020-01-05	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1862	pick-up	0	21
22234	2020-01-05 04:24:33	2020-01-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	8596	delivery	5	28
22235	2020-01-05 04:32:52	2020-01-05	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	4347	delivery	5	37
22236	2020-01-05 04:39:51	2020-01-05	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8656	delivery	5	44
22237	2020-01-05 04:40:47	2020-01-05	12	[{"id_menu":3,"count":1}]	8647	pick-up	0	12
22238	2020-01-05 04:59:38	2020-01-05	14	[{"id_menu":2,"count":1}]	300	delivery	5	19
22239	2020-01-05 05:02:12	2020-01-05	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8660	delivery	5	34
22240	2020-01-05 05:18:05	2020-01-05	12	[{"id_menu":3,"count":1}]	5729	pick-up	0	12
22241	2020-01-05 05:18:35	2020-01-05	17	[{"id_menu":4,"count":1}]	8612	delivery	5	22
22242	2020-01-05 05:22:53	2020-01-05	9	[{"id_menu":7,"count":1}]	1387	pick-up	0	9
22243	2020-01-05 05:25:28	2020-01-05	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2517	pick-up	0	29
22244	2020-01-05 05:26:15	2020-01-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1163	delivery	5	28
22245	2020-01-05 05:27:56	2020-01-05	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	8623	delivery	5	34
22246	2020-01-05 05:29:29	2020-01-05	14	[{"id_menu":2,"count":1}]	5692	pick-up	0	14
22247	2020-01-05 05:32:13	2020-01-05	12	[{"id_menu":1,"count":1}]	4067	delivery	5	17
22248	2020-01-05 05:35:01	2020-01-05	9	[{"id_menu":6,"count":1}]	1645	pick-up	0	9
22249	2020-01-05 05:35:07	2020-01-05	17	[{"id_menu":4,"count":1}]	8606	delivery	5	22
22250	2020-01-05 05:36:05	2020-01-05	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5006	delivery	5	42
22251	2020-01-05 05:43:37	2020-01-05	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4730	delivery	5	45
22252	2020-01-05 05:52:36	2020-01-05	17	[{"id_menu":4,"count":1}]	1795	pick-up	0	17
22253	2020-01-05 06:01:17	2020-01-05	9	[{"id_menu":7,"count":1}]	209	pick-up	0	9
22254	2020-01-05 06:05:33	2020-01-05	9	[{"id_menu":7,"count":1}]	2287	pick-up	0	9
22255	2020-01-05 06:17:08	2020-01-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2706	pick-up	0	26
22256	2020-01-05 06:19:22	2020-01-05	17	[{"id_menu":4,"count":1}]	4565	delivery	5	22
22257	2020-01-05 06:25:09	2020-01-05	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3449	pick-up	0	38
22258	2020-01-05 06:30:08	2020-01-05	12	[{"id_menu":1,"count":1}]	4296	pick-up	0	12
22259	2020-01-05 06:30:13	2020-01-05	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6526	delivery	5	35
22260	2020-01-05 06:33:22	2020-01-05	9	[{"id_menu":6,"count":1}]	8617	delivery	5	14
22261	2020-01-05 06:35:22	2020-01-05	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	8587	delivery	5	26
22262	2020-01-05 06:35:53	2020-01-05	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8593	delivery	5	39
22263	2020-01-05 06:46:33	2020-01-05	8	[{"id_menu":5,"count":1}]	203	pick-up	0	8
22264	2020-01-05 06:56:47	2020-01-05	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	8654	delivery	5	22
22265	2020-01-05 07:06:09	2020-01-05	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	8619	delivery	5	36
22266	2020-01-05 07:07:07	2020-01-05	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2590	delivery	5	36
22267	2020-01-05 07:23:22	2020-01-05	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	7538	delivery	5	31
22268	2020-01-05 07:25:52	2020-01-05	14	[{"id_menu":2,"count":1}]	6996	delivery	5	19
22269	2020-01-05 07:27:25	2020-01-05	8	[{"id_menu":5,"count":1}]	275	delivery	5	13
22270	2020-01-05 07:35:20	2020-01-05	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	8665	delivery	5	31
22271	2020-01-05 07:35:45	2020-01-05	14	[{"id_menu":2,"count":1}]	5574	delivery	5	19
22272	2020-01-05 07:41:39	2020-01-05	17	[{"id_menu":4,"count":1}]	8603	delivery	5	22
22273	2020-01-05 07:45:13	2020-01-05	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8668	pick-up	0	31
22274	2020-01-05 07:48:22	2020-01-05	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	486	pick-up	0	22
22275	2020-01-05 07:49:21	2020-01-05	9	[{"id_menu":6,"count":1}]	6515	delivery	5	14
22276	2020-01-05 07:50:14	2020-01-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	6483	delivery	5	23
22277	2020-01-05 07:51:11	2020-01-05	12	[{"id_menu":1,"count":1}]	8653	delivery	5	17
22278	2020-01-05 08:00:02	2020-01-05	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8581	delivery	5	28
22279	2020-01-05 08:12:59	2020-01-05	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	8655	pick-up	0	22
22280	2020-01-05 08:29:12	2020-01-05	9	[{"id_menu":6,"count":1}]	7878	delivery	5	14
22281	2020-01-05 08:29:53	2020-01-05	9	[{"id_menu":6,"count":1}]	8579	delivery	5	14
22282	2020-01-05 08:33:36	2020-01-05	9	[{"id_menu":6,"count":1}]	2227	pick-up	0	9
22283	2020-01-05 08:35:00	2020-01-05	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8599	delivery	5	46
22284	2020-01-05 08:35:43	2020-01-05	17	[{"id_menu":4,"count":1}]	343	pick-up	0	17
22285	2020-01-05 08:44:11	2020-01-05	12	[{"id_menu":1,"count":1}]	2439	pick-up	0	12
22286	2020-01-05 08:45:12	2020-01-05	9	[{"id_menu":7,"count":1}]	4044	delivery	5	14
22287	2020-01-05 08:58:32	2020-01-05	17	[{"id_menu":4,"count":1}]	8611	delivery	5	22
22288	2020-01-05 09:00:08	2020-01-05	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5337	delivery	5	45
22289	2020-01-05 09:01:01	2020-01-05	8	[{"id_menu":5,"count":1}]	4587	delivery	5	13
22290	2020-01-05 09:05:21	2020-01-05	12	[{"id_menu":1,"count":1}]	2426	pick-up	0	12
22291	2020-01-05 09:08:12	2020-01-05	8	[{"id_menu":5,"count":1}]	638	pick-up	0	8
22292	2020-01-05 09:13:57	2020-01-05	9	[{"id_menu":6,"count":1}]	837	pick-up	0	9
22293	2020-01-05 09:24:10	2020-01-05	12	[{"id_menu":1,"count":1}]	8635	delivery	5	17
22294	2020-01-05 09:25:04	2020-01-05	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	8643	delivery	5	28
22295	2020-01-05 09:26:41	2020-01-05	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	8633	delivery	5	25
22296	2020-01-05 09:31:05	2020-01-05	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	4688	pick-up	0	29
22297	2020-01-05 09:44:51	2020-01-05	17	[{"id_menu":4,"count":1}]	540	delivery	5	22
22298	2020-01-05 09:46:18	2020-01-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8636	delivery	5	23
22299	2020-01-05 09:47:47	2020-01-05	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	790	pick-up	0	26
22300	2020-01-05 09:51:41	2020-01-05	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1495	delivery	5	49
22301	2020-01-05 09:56:37	2020-01-05	8	[{"id_menu":5,"count":1}]	5155	delivery	5	13
22302	2020-01-05 09:57:52	2020-01-05	9	[{"id_menu":6,"count":1}]	8625	pick-up	0	9
22303	2020-01-05 10:01:45	2020-01-05	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3916	pick-up	0	26
22304	2020-01-05 10:24:45	2020-01-05	9	[{"id_menu":6,"count":1}]	8479	delivery	5	14
22305	2020-01-05 10:31:31	2020-01-05	8	[{"id_menu":5,"count":1}]	7983	pick-up	0	8
22306	2020-01-05 10:33:42	2020-01-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5091	delivery	5	23
22307	2020-01-05 10:41:03	2020-01-05	12	[{"id_menu":1,"count":1}]	356	delivery	5	17
22308	2020-01-05 10:45:27	2020-01-05	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8615	delivery	5	52
22309	2020-01-05 10:54:48	2020-01-05	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1255	delivery	5	26
22310	2020-01-05 11:00:13	2020-01-05	9	[{"id_menu":6,"count":1}]	8658	pick-up	0	9
22311	2020-01-05 11:07:56	2020-01-05	12	[{"id_menu":1,"count":1}]	3507	delivery	5	17
22312	2020-01-05 11:12:40	2020-01-05	14	[{"id_menu":2,"count":1}]	8638	pick-up	0	14
22313	2020-01-05 11:14:25	2020-01-05	8	[{"id_menu":5,"count":1}]	5416	pick-up	0	8
22314	2020-01-05 11:34:07	2020-01-05	12	[{"id_menu":1,"count":1}]	7595	delivery	5	17
22315	2020-01-05 11:39:06	2020-01-05	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	8583	delivery	5	36
22316	2020-01-05 11:42:02	2020-01-05	14	[{"id_menu":2,"count":1}]	8613	delivery	5	19
22317	2020-01-05 11:49:33	2020-01-05	14	[{"id_menu":2,"count":1}]	340	pick-up	0	14
22318	2020-01-05 11:53:24	2020-01-05	29	[{"id_menu":3,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3168	pick-up	0	29
22319	2020-01-05 11:53:31	2020-01-05	14	[{"id_menu":2,"count":2}]	2018	pick-up	0	14
22320	2020-01-05 12:01:46	2020-01-05	14	[{"id_menu":2,"count":1}]	8474	pick-up	0	14
22321	2020-01-05 12:06:20	2020-01-05	12	[{"id_menu":1,"count":1}]	6039	pick-up	0	12
22322	2020-01-05 12:07:35	2020-01-05	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8645	delivery	5	37
22323	2020-01-05 12:14:39	2020-01-05	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	8659	delivery	5	36
22324	2020-01-05 12:15:05	2020-01-05	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1457	delivery	5	29
22325	2020-01-05 12:17:43	2020-01-05	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	8174	delivery	5	36
22326	2020-01-05 12:30:00	2020-01-05	14	[{"id_menu":2,"count":2}]	7094	pick-up	0	14
22327	2020-01-05 12:30:31	2020-01-05	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3534	delivery	5	46
22328	2020-01-05 12:31:05	2020-01-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4400	pick-up	0	18
22329	2020-01-05 12:37:33	2020-01-05	12	[{"id_menu":1,"count":1}]	7321	delivery	5	17
22330	2020-01-05 12:40:42	2020-01-05	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	8594	delivery	5	23
22331	2020-01-05 12:47:17	2020-01-05	14	[{"id_menu":2,"count":1}]	8234	delivery	5	19
22332	2020-01-05 12:49:53	2020-01-05	9	[{"id_menu":7,"count":1}]	5643	pick-up	0	9
22333	2020-01-05 12:54:25	2020-01-05	12	[{"id_menu":1,"count":1}]	8621	delivery	5	17
22334	2020-01-05 13:02:02	2020-01-05	8	[{"id_menu":5,"count":1}]	3067	delivery	5	13
22335	2020-01-05 13:02:22	2020-01-05	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5023	delivery	5	55
22336	2020-01-05 13:03:09	2020-01-05	8	[{"id_menu":5,"count":2}]	6057	delivery	5	13
22337	2020-01-05 13:03:47	2020-01-05	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	7110	delivery	5	26
22338	2020-01-05 13:07:07	2020-01-05	14	[{"id_menu":2,"count":1}]	3160	delivery	5	19
22339	2020-01-05 13:09:56	2020-01-05	12	[{"id_menu":1,"count":1}]	8618	pick-up	0	12
22340	2020-01-05 13:10:19	2020-01-05	9	[{"id_menu":7,"count":1}]	3148	delivery	5	14
22341	2020-01-05 13:17:20	2020-01-05	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8313	delivery	5	45
22342	2020-01-05 13:17:38	2020-01-05	9	[{"id_menu":7,"count":1}]	4773	delivery	5	14
22343	2020-01-05 13:20:31	2020-01-05	9	[{"id_menu":7,"count":1}]	6232	pick-up	0	9
22344	2020-01-05 13:26:46	2020-01-05	12	[{"id_menu":3,"count":1}]	4333	delivery	5	17
22345	2020-01-05 13:27:12	2020-01-05	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1860	pick-up	0	24
22346	2020-01-05 13:29:51	2020-01-05	17	[{"id_menu":4,"count":1}]	5509	delivery	5	22
22347	2020-01-05 13:31:13	2020-01-05	9	[{"id_menu":6,"count":1}]	8640	pick-up	0	9
22348	2020-01-05 13:33:23	2020-01-05	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	8588	delivery	5	26
22349	2020-01-05 13:50:09	2020-01-05	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	7200	delivery	5	34
22350	2020-01-05 13:57:33	2020-01-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	5681	delivery	5	31
22351	2020-01-05 14:04:39	2020-01-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8605	delivery	5	23
22352	2020-01-05 14:14:35	2020-01-05	14	[{"id_menu":2,"count":1}]	8649	delivery	5	19
22353	2020-01-05 14:15:19	2020-01-05	9	[{"id_menu":6,"count":1}]	5019	pick-up	0	9
22354	2020-01-05 14:19:44	2020-01-05	12	[{"id_menu":3,"count":1}]	2827	delivery	5	17
22355	2020-01-05 14:22:52	2020-01-05	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8584	delivery	5	45
22356	2020-01-05 14:24:03	2020-01-05	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8622	delivery	5	28
22357	2020-01-05 14:24:44	2020-01-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7186	pick-up	0	26
22358	2020-01-05 14:24:51	2020-01-05	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	361	pick-up	0	31
22359	2020-01-05 14:25:26	2020-01-05	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1044	delivery	5	31
22360	2020-01-05 14:37:33	2020-01-05	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3260	delivery	5	27
22361	2020-01-05 14:42:12	2020-01-05	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	5193	delivery	5	26
22362	2020-01-05 14:55:10	2020-01-05	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	8600	delivery	5	39
22363	2020-01-05 15:07:35	2020-01-05	8	[{"id_menu":5,"count":1}]	7919	delivery	5	13
22364	2020-01-05 15:26:37	2020-01-05	9	[{"id_menu":7,"count":1}]	973	pick-up	0	9
22365	2020-01-05 15:34:19	2020-01-05	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3730	pick-up	0	21
22366	2020-01-05 15:39:21	2020-01-05	9	[{"id_menu":6,"count":1}]	265	delivery	5	14
22367	2020-01-05 15:51:59	2020-01-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	734	pick-up	0	23
22368	2020-01-05 15:55:43	2020-01-05	9	[{"id_menu":7,"count":1}]	8595	pick-up	0	9
22369	2020-01-05 15:56:55	2020-01-05	12	[{"id_menu":3,"count":1}]	2050	delivery	5	17
22370	2020-01-05 16:07:02	2020-01-05	9	[{"id_menu":6,"count":1}]	3002	delivery	5	14
22371	2020-01-05 16:07:27	2020-01-05	9	[{"id_menu":6,"count":1}]	8610	pick-up	0	9
22372	2020-01-05 16:08:08	2020-01-05	12	[{"id_menu":1,"count":1}]	8607	delivery	5	17
22373	2020-01-05 16:09:07	2020-01-05	9	[{"id_menu":6,"count":1}]	4942	pick-up	0	9
22374	2020-01-05 16:09:47	2020-01-05	14	[{"id_menu":2,"count":2}]	640	pick-up	0	14
22375	2020-01-05 16:12:12	2020-01-05	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	4992	delivery	5	22
22376	2020-01-05 16:20:06	2020-01-05	12	[{"id_menu":1,"count":1}]	2140	pick-up	0	12
22377	2020-01-05 16:21:58	2020-01-05	17	[{"id_menu":4,"count":1}]	8657	pick-up	0	17
22378	2020-01-05 16:23:14	2020-01-05	12	[{"id_menu":1,"count":1}]	6673	delivery	5	17
22379	2020-01-05 16:28:29	2020-01-05	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	4887	delivery	5	26
22380	2020-01-05 16:30:51	2020-01-05	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	3965	delivery	5	39
22381	2020-01-05 16:33:39	2020-01-05	9	[{"id_menu":6,"count":1}]	8626	delivery	5	14
22382	2020-01-05 16:39:56	2020-01-05	14	[{"id_menu":2,"count":1}]	2962	pick-up	0	14
22383	2020-01-05 16:43:15	2020-01-05	12	[{"id_menu":3,"count":1}]	491	delivery	5	17
22384	2020-01-05 16:46:15	2020-01-05	9	[{"id_menu":6,"count":1}]	7367	pick-up	0	9
22385	2020-01-05 16:47:03	2020-01-05	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	6651	delivery	5	31
22386	2020-01-05 16:50:39	2020-01-05	9	[{"id_menu":6,"count":1}]	8580	delivery	5	14
22387	2020-01-05 16:53:28	2020-01-05	12	[{"id_menu":3,"count":1}]	3372	pick-up	0	12
22388	2020-01-05 17:05:49	2020-01-05	9	[{"id_menu":6,"count":1}]	799	delivery	5	14
22389	2020-01-05 17:09:15	2020-01-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4196	delivery	5	22
22390	2020-01-05 17:11:02	2020-01-05	9	[{"id_menu":6,"count":1}]	3867	delivery	5	14
22391	2020-01-05 17:14:48	2020-01-05	14	[{"id_menu":2,"count":1}]	8591	delivery	5	19
22392	2020-01-05 17:18:59	2020-01-05	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	5361	delivery	5	34
22393	2020-01-05 17:19:05	2020-01-05	12	[{"id_menu":1,"count":1}]	6152	pick-up	0	12
22394	2020-01-05 17:20:00	2020-01-05	12	[{"id_menu":1,"count":1}]	192	pick-up	0	12
22395	2020-01-05 17:23:57	2020-01-05	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6565	pick-up	0	38
22396	2020-01-05 17:29:43	2020-01-05	9	[{"id_menu":7,"count":2}]	3494	pick-up	0	9
22397	2020-01-05 17:30:26	2020-01-05	8	[{"id_menu":5,"count":1}]	8624	delivery	5	13
22398	2020-01-05 17:32:16	2020-01-05	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1375	pick-up	0	29
22399	2020-01-05 17:33:03	2020-01-05	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4116	delivery	5	43
22400	2020-01-05 17:33:10	2020-01-05	12	[{"id_menu":1,"count":1}]	7297	delivery	5	17
22401	2020-01-05 17:37:17	2020-01-05	12	[{"id_menu":1,"count":1}]	8597	delivery	5	17
22402	2020-01-05 17:37:45	2020-01-05	8	[{"id_menu":5,"count":1}]	4232	delivery	5	13
22403	2020-01-05 17:39:50	2020-01-05	9	[{"id_menu":6,"count":2}]	320	pick-up	0	9
22404	2020-01-05 17:43:56	2020-01-05	17	[{"id_menu":4,"count":1}]	5508	pick-up	0	17
22405	2020-01-05 17:44:25	2020-01-05	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8586	delivery	5	39
22406	2020-01-05 18:10:07	2020-01-05	12	[{"id_menu":1,"count":1}]	1289	pick-up	0	12
22407	2020-01-05 18:29:28	2020-01-05	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8661	delivery	5	51
22408	2020-01-05 18:31:28	2020-01-05	14	[{"id_menu":2,"count":1}]	8202	delivery	5	19
22409	2020-01-05 18:36:24	2020-01-05	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	5630	delivery	5	23
22410	2020-01-05 18:38:37	2020-01-05	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	5667	delivery	5	26
22411	2020-01-05 18:55:50	2020-01-05	17	[{"id_menu":4,"count":1}]	688	delivery	5	22
22412	2020-01-05 18:58:44	2020-01-05	17	[{"id_menu":4,"count":1}]	1059	delivery	5	22
22413	2020-01-05 19:02:15	2020-01-05	12	[{"id_menu":1,"count":1}]	2228	pick-up	0	12
22414	2020-01-05 19:31:45	2020-01-05	12	[{"id_menu":1,"count":1}]	8589	delivery	5	17
22415	2020-01-05 19:41:29	2020-01-05	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8650	delivery	5	36
22416	2020-01-05 19:44:31	2020-01-05	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8644	delivery	5	36
22417	2020-01-05 19:48:27	2020-01-05	17	[{"id_menu":4,"count":1}]	5831	delivery	5	22
22418	2020-01-05 19:53:10	2020-01-05	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	8663	delivery	5	31
22419	2020-01-05 19:53:27	2020-01-05	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1174	delivery	5	26
22420	2020-01-05 19:59:45	2020-01-05	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	8614	delivery	5	31
22421	2020-01-05 20:04:19	2020-01-05	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2524	pick-up	0	17
22422	2020-01-05 20:08:35	2020-01-05	12	[{"id_menu":1,"count":1}]	3271	pick-up	0	12
22423	2020-01-05 20:10:43	2020-01-05	9	[{"id_menu":6,"count":1}]	2000	delivery	5	14
22424	2020-01-05 20:17:23	2020-01-05	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	7125	delivery	5	26
22425	2020-01-05 20:21:14	2020-01-05	14	[{"id_menu":2,"count":1}]	8629	pick-up	0	14
22426	2020-01-05 20:21:21	2020-01-05	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8648	delivery	5	51
22427	2020-01-05 20:28:46	2020-01-05	17	[{"id_menu":4,"count":1}]	8609	delivery	5	22
22428	2020-01-05 20:34:04	2020-01-05	12	[{"id_menu":3,"count":1}]	8200	delivery	5	17
22429	2020-01-05 20:42:24	2020-01-05	8	[{"id_menu":5,"count":1}]	8667	delivery	5	13
22430	2020-01-05 20:47:34	2020-01-05	9	[{"id_menu":6,"count":2}]	8652	delivery	5	14
22431	2020-01-05 20:49:31	2020-01-05	14	[{"id_menu":2,"count":1}]	700	delivery	5	19
22432	2020-01-05 20:56:44	2020-01-05	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	3358	delivery	5	22
22433	2020-01-05 21:00:19	2020-01-05	17	[{"id_menu":4,"count":1}]	3512	pick-up	0	17
22434	2020-01-05 21:11:49	2020-01-05	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1075	delivery	5	26
22435	2020-01-05 21:15:15	2020-01-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	880	delivery	5	22
22436	2020-01-05 21:18:58	2020-01-05	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5822	delivery	5	31
22437	2020-01-05 21:19:01	2020-01-05	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8620	pick-up	0	32
22438	2020-01-05 21:22:41	2020-01-05	9	[{"id_menu":6,"count":2}]	1647	delivery	5	14
22439	2020-01-05 21:25:29	2020-01-05	9	[{"id_menu":7,"count":1}]	8628	delivery	5	14
22440	2020-01-05 21:30:14	2020-01-05	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	8651	delivery	5	26
22441	2020-01-05 21:35:38	2020-01-05	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3558	delivery	5	36
22442	2020-01-05 21:48:42	2020-01-05	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8608	delivery	5	34
22443	2020-01-05 21:50:10	2020-01-05	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	588	delivery	5	55
22444	2020-01-05 21:59:02	2020-01-05	14	[{"id_menu":2,"count":1}]	3511	pick-up	0	14
22445	2020-01-05 22:02:00	2020-01-05	17	[{"id_menu":4,"count":1}]	6344	delivery	5	22
22446	2020-01-05 22:10:04	2020-01-05	17	[{"id_menu":4,"count":1}]	3701	delivery	5	22
22447	2020-01-05 22:10:27	2020-01-05	17	[{"id_menu":4,"count":1}]	8098	pick-up	0	17
22448	2020-01-05 22:12:29	2020-01-05	9	[{"id_menu":6,"count":1}]	7689	delivery	5	14
22449	2020-01-05 22:12:29	2020-01-05	17	[{"id_menu":4,"count":1}]	7283	delivery	5	22
22450	2020-01-05 22:36:30	2020-01-05	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	8602	delivery	5	34
22451	2020-01-05 22:42:13	2020-01-05	9	[{"id_menu":7,"count":1}]	1025	pick-up	0	9
22452	2020-01-05 22:48:22	2020-01-05	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4246	pick-up	0	26
22453	2020-01-05 22:49:25	2020-01-05	12	[{"id_menu":3,"count":1}]	8646	delivery	5	17
22454	2020-01-05 22:51:24	2020-01-05	9	[{"id_menu":6,"count":1}]	3195	delivery	5	14
22455	2020-01-05 22:54:02	2020-01-05	14	[{"id_menu":2,"count":1}]	8598	delivery	5	19
22456	2020-01-05 23:03:30	2020-01-05	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4921	delivery	5	27
22457	2020-01-05 23:06:42	2020-01-05	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	8601	delivery	5	42
22458	2020-01-05 23:26:04	2020-01-05	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	8634	delivery	5	31
22459	2020-01-05 23:27:38	2020-01-05	12	[{"id_menu":3,"count":1}]	8592	pick-up	0	12
22460	2020-01-05 23:31:21	2020-01-05	9	[{"id_menu":6,"count":1}]	4717	pick-up	0	9
22461	2020-01-05 23:31:48	2020-01-05	14	[{"id_menu":2,"count":2}]	5080	pick-up	0	14
22462	2020-01-05 23:33:07	2020-01-05	8	[{"id_menu":5,"count":1}]	4077	delivery	5	13
22463	2020-01-05 23:34:18	2020-01-05	12	[{"id_menu":1,"count":1}]	6894	delivery	5	17
22464	2020-01-05 23:36:20	2020-01-05	14	[{"id_menu":2,"count":1}]	8632	delivery	5	19
22465	2020-01-05 23:39:55	2020-01-05	14	[{"id_menu":2,"count":1}]	7280	delivery	5	19
22466	2020-01-05 23:45:30	2020-01-05	14	[{"id_menu":2,"count":1}]	807	pick-up	0	14
22467	2020-01-05 23:46:04	2020-01-05	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	8631	delivery	5	31
22468	2020-01-05 23:50:18	2020-01-05	12	[{"id_menu":1,"count":1}]	3949	pick-up	0	12
22469	2020-01-05 23:51:03	2020-01-05	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7137	delivery	5	22
22470	2020-01-05 23:52:42	2020-01-05	14	[{"id_menu":2,"count":1}]	669	delivery	5	19
22471	2020-01-05 23:54:35	2020-01-05	8	[{"id_menu":5,"count":1}]	5329	delivery	5	13
22472	2020-01-05 23:55:48	2020-01-05	17	[{"id_menu":4,"count":1}]	6621	delivery	5	22
22473	2020-01-06 00:14:46	2020-01-06	9	[{"id_menu":6,"count":1}]	5708	delivery	5	14
22474	2020-01-06 00:20:30	2020-01-06	14	[{"id_menu":2,"count":1}]	1528	delivery	5	19
22475	2020-01-06 00:30:13	2020-01-06	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8687	delivery	5	40
22476	2020-01-06 00:37:59	2020-01-06	14	[{"id_menu":2,"count":2}]	8743	pick-up	0	14
22477	2020-01-06 00:42:02	2020-01-06	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6754	pick-up	0	26
22478	2020-01-06 00:45:02	2020-01-06	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	2023	pick-up	0	26
22479	2020-01-06 01:02:24	2020-01-06	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	2841	pick-up	0	40
22480	2020-01-06 01:11:32	2020-01-06	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	8685	delivery	5	38
22481	2020-01-06 01:11:48	2020-01-06	8	[{"id_menu":5,"count":1}]	6759	delivery	5	13
22482	2020-01-06 01:18:59	2020-01-06	14	[{"id_menu":2,"count":1}]	1309	pick-up	0	14
22483	2020-01-06 01:30:08	2020-01-06	9	[{"id_menu":7,"count":1}]	8712	pick-up	0	9
22484	2020-01-06 01:32:09	2020-01-06	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2439	delivery	5	26
22485	2020-01-06 01:33:20	2020-01-06	14	[{"id_menu":2,"count":1}]	8673	pick-up	0	14
22486	2020-01-06 01:44:11	2020-01-06	12	[{"id_menu":1,"count":1}]	5926	delivery	5	17
22487	2020-01-06 01:52:48	2020-01-06	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8682	delivery	5	34
22488	2020-01-06 02:10:33	2020-01-06	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	776	delivery	5	39
22489	2020-01-06 02:34:12	2020-01-06	26	[{"id_menu":4,"count":3},{"id_menu":7,"count":1}]	1445	pick-up	0	26
22490	2020-01-06 02:39:23	2020-01-06	17	[{"id_menu":4,"count":2}]	8684	delivery	5	22
22491	2020-01-06 02:39:55	2020-01-06	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8688	pick-up	0	25
22492	2020-01-06 02:47:47	2020-01-06	14	[{"id_menu":2,"count":1}]	2181	pick-up	0	14
22493	2020-01-06 03:07:39	2020-01-06	9	[{"id_menu":7,"count":1}]	3858	delivery	5	14
22494	2020-01-06 03:09:45	2020-01-06	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	4986	pick-up	0	20
22495	2020-01-06 03:12:33	2020-01-06	9	[{"id_menu":6,"count":1}]	5514	pick-up	0	9
22496	2020-01-06 03:18:16	2020-01-06	8	[{"id_menu":5,"count":1}]	8136	delivery	5	13
22497	2020-01-06 03:34:14	2020-01-06	8	[{"id_menu":5,"count":1}]	993	pick-up	0	8
22498	2020-01-06 03:48:12	2020-01-06	14	[{"id_menu":2,"count":1}]	952	pick-up	0	14
22499	2020-01-06 04:10:41	2020-01-06	14	[{"id_menu":2,"count":1}]	337	delivery	5	19
22500	2020-01-06 04:35:51	2020-01-06	9	[{"id_menu":7,"count":1}]	8707	delivery	5	14
22501	2020-01-06 04:50:26	2020-01-06	12	[{"id_menu":3,"count":1}]	8732	pick-up	0	12
22502	2020-01-06 04:50:33	2020-01-06	17	[{"id_menu":4,"count":1}]	4869	delivery	5	22
22503	2020-01-06 04:54:41	2020-01-06	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":2}]	4570	delivery	5	22
22504	2020-01-06 04:57:06	2020-01-06	9	[{"id_menu":6,"count":1}]	8734	delivery	5	14
22505	2020-01-06 05:07:32	2020-01-06	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	8693	pick-up	0	22
22506	2020-01-06 05:30:20	2020-01-06	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	68	delivery	5	26
22507	2020-01-06 05:36:05	2020-01-06	12	[{"id_menu":3,"count":1}]	8702	delivery	5	17
22508	2020-01-06 05:38:11	2020-01-06	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	7522	pick-up	0	24
22509	2020-01-06 05:55:32	2020-01-06	9	[{"id_menu":7,"count":1}]	8705	delivery	5	14
22510	2020-01-06 05:57:44	2020-01-06	17	[{"id_menu":4,"count":1}]	8689	delivery	5	22
22511	2020-01-06 06:10:33	2020-01-06	9	[{"id_menu":7,"count":1}]	8711	delivery	5	14
22512	2020-01-06 06:18:41	2020-01-06	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	7374	delivery	5	34
22513	2020-01-06 06:30:36	2020-01-06	14	[{"id_menu":2,"count":1}]	6798	delivery	5	19
22514	2020-01-06 06:32:59	2020-01-06	12	[{"id_menu":3,"count":1}]	4701	delivery	5	17
22515	2020-01-06 06:34:15	2020-01-06	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8701	delivery	5	42
22516	2020-01-06 07:01:37	2020-01-06	17	[{"id_menu":4,"count":1}]	6996	delivery	5	22
22517	2020-01-06 07:01:38	2020-01-06	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2509	delivery	5	31
22518	2020-01-06 07:41:40	2020-01-06	14	[{"id_menu":2,"count":1}]	4060	delivery	5	19
22519	2020-01-06 07:45:02	2020-01-06	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8715	delivery	5	23
22520	2020-01-06 08:02:15	2020-01-06	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6042	delivery	5	22
22521	2020-01-06 08:16:01	2020-01-06	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6163	delivery	5	22
22522	2020-01-06 08:20:27	2020-01-06	14	[{"id_menu":2,"count":2}]	1099	pick-up	0	14
22523	2020-01-06 08:21:55	2020-01-06	12	[{"id_menu":1,"count":1}]	593	pick-up	0	12
22524	2020-01-06 08:27:56	2020-01-06	14	[{"id_menu":2,"count":1}]	915	pick-up	0	14
22525	2020-01-06 08:29:53	2020-01-06	12	[{"id_menu":1,"count":1}]	8727	delivery	5	17
22526	2020-01-06 08:37:05	2020-01-06	12	[{"id_menu":3,"count":1}]	1679	delivery	5	17
22527	2020-01-06 10:09:27	2020-01-06	9	[{"id_menu":6,"count":1}]	8704	delivery	5	14
22528	2020-01-06 10:35:12	2020-01-06	12	[{"id_menu":3,"count":1}]	4132	pick-up	0	12
22529	2020-01-06 10:43:23	2020-01-06	14	[{"id_menu":2,"count":1}]	691	pick-up	0	14
22530	2020-01-06 11:04:55	2020-01-06	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8731	delivery	5	28
22531	2020-01-06 11:11:16	2020-01-06	8	[{"id_menu":5,"count":1}]	3205	pick-up	0	8
22532	2020-01-06 11:18:29	2020-01-06	17	[{"id_menu":4,"count":1}]	8700	pick-up	0	17
22533	2020-01-06 11:21:38	2020-01-06	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6153	delivery	5	40
22534	2020-01-06 11:27:33	2020-01-06	14	[{"id_menu":2,"count":1}]	8744	delivery	5	19
22535	2020-01-06 11:29:57	2020-01-06	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8095	delivery	5	28
22536	2020-01-06 11:40:54	2020-01-06	17	[{"id_menu":4,"count":1}]	1245	pick-up	0	17
22537	2020-01-06 11:59:22	2020-01-06	9	[{"id_menu":6,"count":1}]	8728	delivery	5	14
22538	2020-01-06 12:01:45	2020-01-06	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2627	delivery	5	26
22539	2020-01-06 12:15:06	2020-01-06	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8699	delivery	5	31
22540	2020-01-06 12:27:15	2020-01-06	12	[{"id_menu":1,"count":1}]	8738	delivery	5	17
22541	2020-01-06 12:49:47	2020-01-06	9	[{"id_menu":6,"count":1}]	8716	pick-up	0	9
22542	2020-01-06 12:52:27	2020-01-06	17	[{"id_menu":4,"count":1}]	8745	delivery	5	22
22543	2020-01-06 12:58:02	2020-01-06	14	[{"id_menu":2,"count":1}]	1931	pick-up	0	14
22544	2020-01-06 13:00:21	2020-01-06	12	[{"id_menu":1,"count":1}]	6539	pick-up	0	12
22545	2020-01-06 13:01:46	2020-01-06	14	[{"id_menu":2,"count":1}]	6965	pick-up	0	14
22546	2020-01-06 13:07:15	2020-01-06	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1843	delivery	5	23
22547	2020-01-06 13:10:08	2020-01-06	9	[{"id_menu":7,"count":1}]	2513	delivery	5	14
22548	2020-01-06 13:14:46	2020-01-06	14	[{"id_menu":2,"count":1}]	3491	pick-up	0	14
22549	2020-01-06 13:20:07	2020-01-06	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3910	delivery	5	34
22550	2020-01-06 13:47:41	2020-01-06	9	[{"id_menu":6,"count":1}]	8750	delivery	5	14
22551	2020-01-06 13:48:51	2020-01-06	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7891	delivery	5	36
22552	2020-01-06 14:10:47	2020-01-06	9	[{"id_menu":7,"count":1}]	8695	delivery	5	14
22553	2020-01-06 14:16:53	2020-01-06	9	[{"id_menu":7,"count":1}]	4605	delivery	5	14
22554	2020-01-06 14:29:50	2020-01-06	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	466	delivery	5	36
22555	2020-01-06 14:39:14	2020-01-06	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8723	delivery	5	45
22556	2020-01-06 15:16:11	2020-01-06	17	[{"id_menu":4,"count":1}]	6117	delivery	5	22
22557	2020-01-06 15:21:01	2020-01-06	12	[{"id_menu":3,"count":1}]	8706	delivery	5	17
22558	2020-01-06 15:23:21	2020-01-06	9	[{"id_menu":6,"count":1}]	3736	delivery	5	14
22559	2020-01-06 15:34:21	2020-01-06	9	[{"id_menu":7,"count":1}]	7734	delivery	5	14
22560	2020-01-06 16:23:27	2020-01-06	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	8677	delivery	5	23
22561	2020-01-06 16:35:24	2020-01-06	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	8696	delivery	5	39
22562	2020-01-06 16:36:02	2020-01-06	17	[{"id_menu":4,"count":1}]	626	pick-up	0	17
22563	2020-01-06 16:37:45	2020-01-06	9	[{"id_menu":6,"count":1}]	2672	delivery	5	14
22564	2020-01-06 16:44:31	2020-01-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3784	delivery	5	28
22565	2020-01-06 16:54:37	2020-01-06	9	[{"id_menu":7,"count":1}]	5100	pick-up	0	9
22566	2020-01-06 17:10:51	2020-01-06	17	[{"id_menu":4,"count":1}]	3204	delivery	5	22
22567	2020-01-06 17:52:50	2020-01-06	17	[{"id_menu":4,"count":1}]	8698	delivery	5	22
22568	2020-01-06 18:06:52	2020-01-06	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	4592	delivery	5	28
22569	2020-01-06 18:10:38	2020-01-06	14	[{"id_menu":2,"count":1}]	8656	pick-up	0	14
22570	2020-01-06 18:45:00	2020-01-06	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3948	pick-up	0	26
22571	2020-01-06 18:56:34	2020-01-06	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	8676	delivery	5	37
22572	2020-01-06 19:05:31	2020-01-06	17	[{"id_menu":4,"count":1}]	8710	delivery	5	22
22573	2020-01-06 19:40:36	2020-01-06	14	[{"id_menu":2,"count":1}]	1280	pick-up	0	14
22574	2020-01-06 20:00:51	2020-01-06	9	[{"id_menu":7,"count":1}]	8679	pick-up	0	9
22575	2020-01-06 20:20:02	2020-01-06	9	[{"id_menu":7,"count":1}]	5073	delivery	5	14
22576	2020-01-06 20:38:19	2020-01-06	17	[{"id_menu":4,"count":1}]	178	pick-up	0	17
22577	2020-01-06 20:53:22	2020-01-06	17	[{"id_menu":4,"count":1}]	1922	pick-up	0	17
22578	2020-01-06 20:54:54	2020-01-06	17	[{"id_menu":4,"count":2}]	1292	delivery	5	22
22579	2020-01-06 21:11:31	2020-01-06	17	[{"id_menu":4,"count":1}]	7156	delivery	5	22
22580	2020-01-06 21:13:33	2020-01-06	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	4292	pick-up	0	26
22581	2020-01-06 21:20:14	2020-01-06	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	482	delivery	5	35
22582	2020-01-06 21:27:53	2020-01-06	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	8719	delivery	5	26
22583	2020-01-06 21:45:05	2020-01-06	14	[{"id_menu":2,"count":1}]	2107	pick-up	0	14
22584	2020-01-06 21:47:28	2020-01-06	17	[{"id_menu":4,"count":1}]	8691	delivery	5	22
22585	2020-01-06 22:10:29	2020-01-06	9	[{"id_menu":6,"count":1}]	8690	delivery	5	14
22586	2020-01-06 22:12:11	2020-01-06	14	[{"id_menu":2,"count":1}]	8739	pick-up	0	14
22587	2020-01-06 22:14:47	2020-01-06	14	[{"id_menu":2,"count":1}]	8681	pick-up	0	14
22588	2020-01-06 22:21:35	2020-01-06	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1638	delivery	5	40
22589	2020-01-06 22:46:32	2020-01-06	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	8747	pick-up	0	31
22590	2020-01-06 23:05:43	2020-01-06	17	[{"id_menu":4,"count":1}]	2076	pick-up	0	17
22591	2020-01-06 23:11:14	2020-01-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	5270	delivery	5	28
22592	2020-01-06 23:16:55	2020-01-06	8	[{"id_menu":5,"count":1}]	8718	delivery	5	13
22593	2020-01-06 23:29:51	2020-01-06	12	[{"id_menu":1,"count":1}]	7894	pick-up	0	12
22594	2020-01-06 23:52:26	2020-01-06	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	972	delivery	5	22
22595	2020-01-06 23:58:40	2020-01-06	9	[{"id_menu":6,"count":1}]	8741	delivery	5	14
22596	2020-01-07 00:06:47	2020-01-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2520	pick-up	0	23
22597	2020-01-07 00:24:17	2020-01-07	17	[{"id_menu":4,"count":2}]	154	delivery	5	22
22598	2020-01-07 00:24:24	2020-01-07	14	[{"id_menu":2,"count":1}]	943	delivery	5	19
22599	2020-01-07 00:30:55	2020-01-07	12	[{"id_menu":1,"count":1}]	907	delivery	5	17
22600	2020-01-07 00:45:26	2020-01-07	17	[{"id_menu":4,"count":1}]	5739	delivery	5	22
22601	2020-01-07 00:59:57	2020-01-07	14	[{"id_menu":2,"count":1}]	8816	pick-up	0	14
22602	2020-01-07 01:05:53	2020-01-07	12	[{"id_menu":1,"count":1}]	8811	pick-up	0	12
22603	2020-01-07 01:06:27	2020-01-07	9	[{"id_menu":6,"count":1}]	997	pick-up	0	9
22604	2020-01-07 01:25:34	2020-01-07	9	[{"id_menu":7,"count":1}]	8789	pick-up	0	9
22605	2020-01-07 01:26:15	2020-01-07	17	[{"id_menu":4,"count":1}]	8806	pick-up	0	17
22606	2020-01-07 01:33:51	2020-01-07	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	6631	pick-up	0	21
22607	2020-01-07 01:41:32	2020-01-07	9	[{"id_menu":7,"count":1}]	1685	delivery	5	14
22608	2020-01-07 01:41:50	2020-01-07	12	[{"id_menu":1,"count":1}]	8793	delivery	5	17
22609	2020-01-07 01:45:37	2020-01-07	9	[{"id_menu":7,"count":1}]	7301	pick-up	0	9
22610	2020-01-07 01:46:39	2020-01-07	9	[{"id_menu":7,"count":1}]	3512	delivery	5	14
22611	2020-01-07 01:47:03	2020-01-07	12	[{"id_menu":3,"count":1}]	8754	delivery	5	17
22612	2020-01-07 02:01:56	2020-01-07	9	[{"id_menu":7,"count":1}]	8819	delivery	5	14
22613	2020-01-07 02:16:18	2020-01-07	14	[{"id_menu":2,"count":1}]	6600	pick-up	0	14
22614	2020-01-07 02:32:54	2020-01-07	14	[{"id_menu":2,"count":1}]	1306	pick-up	0	14
22615	2020-01-07 02:35:22	2020-01-07	9	[{"id_menu":6,"count":1}]	4418	delivery	5	14
22616	2020-01-07 02:44:49	2020-01-07	9	[{"id_menu":6,"count":1}]	5596	delivery	5	14
22617	2020-01-07 02:59:14	2020-01-07	9	[{"id_menu":6,"count":1}]	977	delivery	5	14
22618	2020-01-07 03:37:32	2020-01-07	8	[{"id_menu":5,"count":1}]	8814	delivery	5	13
22619	2020-01-07 03:39:11	2020-01-07	9	[{"id_menu":6,"count":1}]	7568	delivery	5	14
22620	2020-01-07 03:49:19	2020-01-07	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8762	delivery	5	43
22621	2020-01-07 03:54:53	2020-01-07	12	[{"id_menu":1,"count":2}]	5886	delivery	5	17
22622	2020-01-07 03:55:28	2020-01-07	9	[{"id_menu":7,"count":1}]	5889	delivery	5	14
22623	2020-01-07 04:07:26	2020-01-07	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7622	delivery	5	45
22624	2020-01-07 04:11:21	2020-01-07	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2383	pick-up	0	31
22625	2020-01-07 04:13:03	2020-01-07	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	8323	pick-up	0	26
22626	2020-01-07 04:15:14	2020-01-07	9	[{"id_menu":7,"count":1}]	6938	delivery	5	14
22627	2020-01-07 04:31:06	2020-01-07	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	3006	delivery	5	38
22628	2020-01-07 04:31:56	2020-01-07	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	7415	pick-up	0	29
22629	2020-01-07 04:36:51	2020-01-07	9	[{"id_menu":7,"count":1}]	8815	pick-up	0	9
22630	2020-01-07 04:43:24	2020-01-07	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	640	pick-up	0	23
22631	2020-01-07 05:15:22	2020-01-07	14	[{"id_menu":2,"count":1}]	8781	delivery	5	19
22632	2020-01-07 05:16:58	2020-01-07	14	[{"id_menu":2,"count":1}]	8756	delivery	5	19
22633	2020-01-07 05:27:03	2020-01-07	8	[{"id_menu":5,"count":1}]	3268	pick-up	0	8
22634	2020-01-07 05:38:43	2020-01-07	9	[{"id_menu":6,"count":1}]	2415	pick-up	0	9
22635	2020-01-07 05:50:28	2020-01-07	9	[{"id_menu":7,"count":1}]	8809	delivery	5	14
22636	2020-01-07 05:56:44	2020-01-07	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	5293	pick-up	0	21
22637	2020-01-07 06:08:10	2020-01-07	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	753	delivery	5	27
22638	2020-01-07 06:11:07	2020-01-07	9	[{"id_menu":6,"count":1}]	8145	pick-up	0	9
22639	2020-01-07 06:18:28	2020-01-07	14	[{"id_menu":2,"count":1}]	8775	pick-up	0	14
22640	2020-01-07 06:22:44	2020-01-07	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	8755	pick-up	0	17
22641	2020-01-07 06:23:30	2020-01-07	14	[{"id_menu":2,"count":1}]	3433	pick-up	0	14
22642	2020-01-07 06:30:36	2020-01-07	9	[{"id_menu":6,"count":1}]	8751	delivery	5	14
22643	2020-01-07 07:02:55	2020-01-07	12	[{"id_menu":3,"count":1}]	883	pick-up	0	12
22644	2020-01-07 07:10:15	2020-01-07	9	[{"id_menu":6,"count":1}]	7893	delivery	5	14
22645	2020-01-07 07:47:40	2020-01-07	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":3}]	8765	delivery	5	26
22646	2020-01-07 08:04:33	2020-01-07	9	[{"id_menu":6,"count":1}]	1202	pick-up	0	9
22647	2020-01-07 08:23:25	2020-01-07	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8776	delivery	5	35
22648	2020-01-07 08:40:00	2020-01-07	9	[{"id_menu":6,"count":2}]	8777	delivery	5	14
22649	2020-01-07 08:47:18	2020-01-07	17	[{"id_menu":4,"count":2}]	1765	pick-up	0	17
22650	2020-01-07 09:20:48	2020-01-07	8	[{"id_menu":5,"count":1}]	1914	delivery	5	13
22651	2020-01-07 10:00:38	2020-01-07	8	[{"id_menu":5,"count":1}]	8757	delivery	5	13
22652	2020-01-07 10:02:29	2020-01-07	12	[{"id_menu":3,"count":1}]	8794	delivery	5	17
22653	2020-01-07 10:06:35	2020-01-07	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4223	pick-up	0	31
22654	2020-01-07 10:17:11	2020-01-07	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	4539	delivery	5	36
22655	2020-01-07 10:24:00	2020-01-07	9	[{"id_menu":7,"count":1}]	5461	pick-up	0	9
22656	2020-01-07 10:31:55	2020-01-07	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6034	delivery	5	40
22657	2020-01-07 10:46:14	2020-01-07	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1314	pick-up	0	20
22658	2020-01-07 10:53:32	2020-01-07	17	[{"id_menu":4,"count":1}]	8778	delivery	5	22
22659	2020-01-07 11:03:02	2020-01-07	17	[{"id_menu":4,"count":1}]	2188	delivery	5	22
22660	2020-01-07 11:06:08	2020-01-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3579	delivery	5	22
22661	2020-01-07 11:09:00	2020-01-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8825	delivery	5	23
22662	2020-01-07 11:10:50	2020-01-07	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2189	pick-up	0	26
22663	2020-01-07 11:50:18	2020-01-07	12	[{"id_menu":3,"count":1}]	7207	delivery	5	17
22664	2020-01-07 12:04:42	2020-01-07	14	[{"id_menu":2,"count":1}]	1168	pick-up	0	14
22665	2020-01-07 12:16:48	2020-01-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1580	pick-up	0	23
22666	2020-01-07 12:18:00	2020-01-07	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	8758	pick-up	0	22
22667	2020-01-07 12:28:19	2020-01-07	12	[{"id_menu":1,"count":1}]	7200	pick-up	0	12
22668	2020-01-07 12:46:34	2020-01-07	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8768	delivery	5	34
22669	2020-01-07 13:01:21	2020-01-07	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5318	delivery	5	43
22670	2020-01-07 13:03:47	2020-01-07	9	[{"id_menu":6,"count":1}]	877	pick-up	0	9
22671	2020-01-07 13:11:35	2020-01-07	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	7379	delivery	5	40
22672	2020-01-07 13:43:15	2020-01-07	17	[{"id_menu":4,"count":1}]	4846	pick-up	0	17
22673	2020-01-07 13:52:52	2020-01-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8609	pick-up	0	18
22674	2020-01-07 14:16:09	2020-01-07	14	[{"id_menu":2,"count":1}]	1970	pick-up	0	14
22675	2020-01-07 14:16:19	2020-01-07	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8791	delivery	5	31
22676	2020-01-07 14:20:18	2020-01-07	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	76	pick-up	0	24
22677	2020-01-07 14:43:07	2020-01-07	12	[{"id_menu":1,"count":1}]	3382	delivery	5	17
22678	2020-01-07 14:55:09	2020-01-07	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	8824	delivery	5	35
22679	2020-01-07 15:14:39	2020-01-07	8	[{"id_menu":5,"count":1}]	8782	delivery	5	13
22680	2020-01-07 15:16:22	2020-01-07	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8753	delivery	5	39
22681	2020-01-07 15:46:37	2020-01-07	14	[{"id_menu":2,"count":1}]	8803	delivery	5	19
22682	2020-01-07 16:01:06	2020-01-07	14	[{"id_menu":2,"count":1}]	5803	delivery	5	19
22683	2020-01-07 16:26:01	2020-01-07	12	[{"id_menu":1,"count":2}]	8798	delivery	5	17
22684	2020-01-07 16:31:32	2020-01-07	14	[{"id_menu":2,"count":1}]	8774	pick-up	0	14
22685	2020-01-07 16:40:03	2020-01-07	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	6247	pick-up	0	20
22686	2020-01-07 16:47:01	2020-01-07	9	[{"id_menu":7,"count":1}]	340	delivery	5	14
22687	2020-01-07 16:54:39	2020-01-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	4323	delivery	5	26
22688	2020-01-07 17:02:16	2020-01-07	12	[{"id_menu":1,"count":1}]	8810	delivery	5	17
22689	2020-01-07 17:27:49	2020-01-07	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8802	pick-up	0	38
22690	2020-01-07 17:35:08	2020-01-07	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8305	delivery	5	39
22691	2020-01-07 17:52:43	2020-01-07	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5947	pick-up	0	26
22692	2020-01-07 17:56:07	2020-01-07	14	[{"id_menu":2,"count":1}]	7273	delivery	5	19
22693	2020-01-07 18:12:38	2020-01-07	12	[{"id_menu":1,"count":2}]	8799	pick-up	0	12
22694	2020-01-07 18:21:48	2020-01-07	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2360	delivery	5	31
22695	2020-01-07 18:28:09	2020-01-07	14	[{"id_menu":2,"count":1}]	2854	delivery	5	19
22696	2020-01-07 18:35:25	2020-01-07	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3817	delivery	5	36
22697	2020-01-07 18:47:43	2020-01-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	5236	delivery	5	28
22698	2020-01-07 19:10:15	2020-01-07	12	[{"id_menu":1,"count":1}]	8808	delivery	5	17
22699	2020-01-07 19:10:22	2020-01-07	8	[{"id_menu":5,"count":1}]	5409	pick-up	0	8
22700	2020-01-07 19:12:59	2020-01-07	12	[{"id_menu":3,"count":1}]	2731	pick-up	0	12
22701	2020-01-07 19:16:00	2020-01-07	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8804	delivery	5	35
22702	2020-01-07 19:17:42	2020-01-07	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	2608	delivery	5	26
22703	2020-01-07 19:28:41	2020-01-07	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8779	delivery	5	36
22704	2020-01-07 19:49:15	2020-01-07	12	[{"id_menu":1,"count":1}]	8771	delivery	5	17
22705	2020-01-07 19:50:22	2020-01-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8788	delivery	5	23
22706	2020-01-07 20:03:01	2020-01-07	9	[{"id_menu":7,"count":1}]	3611	delivery	5	14
22707	2020-01-07 20:41:27	2020-01-07	17	[{"id_menu":4,"count":2}]	8463	delivery	5	22
22708	2020-01-07 20:41:54	2020-01-07	9	[{"id_menu":7,"count":1}]	1979	delivery	5	14
22709	2020-01-07 20:42:14	2020-01-07	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1656	pick-up	0	26
22710	2020-01-07 20:59:19	2020-01-07	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7691	pick-up	0	38
22711	2020-01-07 21:12:34	2020-01-07	9	[{"id_menu":6,"count":1}]	2902	delivery	5	14
22712	2020-01-07 21:16:50	2020-01-07	17	[{"id_menu":4,"count":1}]	8770	delivery	5	22
22713	2020-01-07 21:28:12	2020-01-07	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	3459	pick-up	0	29
22714	2020-01-07 21:30:56	2020-01-07	17	[{"id_menu":4,"count":1}]	5970	pick-up	0	17
22715	2020-01-07 21:44:41	2020-01-07	12	[{"id_menu":1,"count":1}]	6168	delivery	5	17
22716	2020-01-07 21:45:12	2020-01-07	14	[{"id_menu":2,"count":1}]	6275	pick-up	0	14
22717	2020-01-07 22:04:22	2020-01-07	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	8826	pick-up	0	31
22718	2020-01-07 22:36:48	2020-01-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	8784	delivery	5	26
22719	2020-01-07 22:46:30	2020-01-07	14	[{"id_menu":2,"count":1}]	1280	pick-up	0	14
22720	2020-01-07 22:50:01	2020-01-07	17	[{"id_menu":4,"count":1}]	8769	delivery	5	22
22721	2020-01-07 23:10:14	2020-01-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8669	delivery	5	23
22722	2020-01-07 23:17:58	2020-01-07	9	[{"id_menu":7,"count":1}]	8752	delivery	5	14
22723	2020-01-07 23:23:38	2020-01-07	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	3990	delivery	5	31
22724	2020-01-07 23:53:30	2020-01-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8795	delivery	5	23
22725	2020-01-08 00:01:45	2020-01-08	14	[{"id_menu":2,"count":1}]	8286	pick-up	0	14
22726	2020-01-08 00:02:19	2020-01-08	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	787	delivery	5	38
22727	2020-01-08 00:10:59	2020-01-08	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2932	delivery	5	31
22728	2020-01-08 00:13:18	2020-01-08	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8898	delivery	5	40
22729	2020-01-08 00:16:18	2020-01-08	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	8850	delivery	5	25
22730	2020-01-08 01:00:36	2020-01-08	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	8841	delivery	5	26
22731	2020-01-08 01:03:31	2020-01-08	12	[{"id_menu":3,"count":1}]	3403	pick-up	0	12
22732	2020-01-08 01:10:13	2020-01-08	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	4060	delivery	5	34
22733	2020-01-08 01:19:06	2020-01-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8871	delivery	5	28
22734	2020-01-08 01:20:12	2020-01-08	9	[{"id_menu":6,"count":1}]	8829	delivery	5	14
22735	2020-01-08 01:20:43	2020-01-08	12	[{"id_menu":3,"count":1}]	5303	pick-up	0	12
22736	2020-01-08 01:25:39	2020-01-08	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	8835	delivery	5	28
22737	2020-01-08 01:43:10	2020-01-08	17	[{"id_menu":4,"count":1}]	530	pick-up	0	17
22738	2020-01-08 01:47:44	2020-01-08	14	[{"id_menu":2,"count":1}]	8872	delivery	5	19
22739	2020-01-08 01:47:46	2020-01-08	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1087	pick-up	0	24
22740	2020-01-08 02:14:57	2020-01-08	9	[{"id_menu":7,"count":1}]	8862	delivery	5	14
22741	2020-01-08 02:24:02	2020-01-08	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6015	delivery	5	45
22742	2020-01-08 02:50:41	2020-01-08	12	[{"id_menu":1,"count":1}]	8846	delivery	5	17
22743	2020-01-08 03:04:37	2020-01-08	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3248	pick-up	0	25
22744	2020-01-08 03:12:04	2020-01-08	8	[{"id_menu":5,"count":1}]	8874	delivery	5	13
22745	2020-01-08 03:13:38	2020-01-08	17	[{"id_menu":4,"count":1}]	3898	delivery	5	22
22746	2020-01-08 03:13:48	2020-01-08	9	[{"id_menu":7,"count":1}]	2217	pick-up	0	9
22747	2020-01-08 03:14:04	2020-01-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4833	pick-up	0	17
22748	2020-01-08 03:19:05	2020-01-08	9	[{"id_menu":7,"count":1}]	8886	delivery	5	14
22749	2020-01-08 03:21:29	2020-01-08	8	[{"id_menu":5,"count":1}]	6331	pick-up	0	8
22750	2020-01-08 03:24:17	2020-01-08	12	[{"id_menu":3,"count":1}]	4515	delivery	5	17
22751	2020-01-08 03:33:58	2020-01-08	9	[{"id_menu":6,"count":1}]	1944	delivery	5	14
22752	2020-01-08 03:40:07	2020-01-08	12	[{"id_menu":1,"count":1}]	6711	pick-up	0	12
22753	2020-01-08 03:44:54	2020-01-08	17	[{"id_menu":4,"count":1}]	8574	pick-up	0	17
22754	2020-01-08 03:45:42	2020-01-08	9	[{"id_menu":7,"count":1}]	3990	delivery	5	14
22755	2020-01-08 03:50:10	2020-01-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6282	delivery	5	22
22756	2020-01-08 04:00:24	2020-01-08	9	[{"id_menu":7,"count":1}]	3716	pick-up	0	9
22757	2020-01-08 04:09:29	2020-01-08	14	[{"id_menu":2,"count":1}]	7983	delivery	5	19
22758	2020-01-08 04:14:09	2020-01-08	9	[{"id_menu":6,"count":1}]	3848	pick-up	0	9
22759	2020-01-08 04:30:40	2020-01-08	12	[{"id_menu":1,"count":1}]	1172	delivery	5	17
22760	2020-01-08 04:46:39	2020-01-08	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	5878	delivery	5	40
22761	2020-01-08 05:00:07	2020-01-08	14	[{"id_menu":2,"count":1}]	5109	delivery	5	19
22762	2020-01-08 05:10:46	2020-01-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2140	pick-up	0	23
22763	2020-01-08 05:26:19	2020-01-08	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1679	pick-up	0	24
22764	2020-01-08 05:30:48	2020-01-08	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2776	pick-up	0	29
22765	2020-01-08 05:37:59	2020-01-08	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5113	delivery	5	48
22766	2020-01-08 05:53:12	2020-01-08	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3139	pick-up	0	46
22767	2020-01-08 05:53:34	2020-01-08	8	[{"id_menu":5,"count":1}]	1245	pick-up	0	8
22768	2020-01-08 05:56:21	2020-01-08	17	[{"id_menu":4,"count":1}]	360	pick-up	0	17
22769	2020-01-08 06:11:08	2020-01-08	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	8840	delivery	5	34
22770	2020-01-08 06:14:39	2020-01-08	14	[{"id_menu":2,"count":1}]	2737	delivery	5	19
22771	2020-01-08 06:18:42	2020-01-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2052	pick-up	0	18
22772	2020-01-08 06:23:39	2020-01-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3008	delivery	5	22
22773	2020-01-08 06:25:06	2020-01-08	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3127	delivery	5	39
22774	2020-01-08 06:34:25	2020-01-08	9	[{"id_menu":6,"count":1}]	5509	delivery	5	14
22775	2020-01-08 06:34:28	2020-01-08	12	[{"id_menu":1,"count":1}]	8889	delivery	5	17
22776	2020-01-08 06:46:16	2020-01-08	14	[{"id_menu":2,"count":1}]	8860	pick-up	0	14
22777	2020-01-08 06:48:28	2020-01-08	14	[{"id_menu":2,"count":1}]	8855	pick-up	0	14
22778	2020-01-08 06:49:36	2020-01-08	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1228	delivery	5	29
22779	2020-01-08 07:03:31	2020-01-08	8	[{"id_menu":5,"count":1}]	2110	pick-up	0	8
22780	2020-01-08 07:07:44	2020-01-08	12	[{"id_menu":1,"count":1}]	1106	delivery	5	17
22781	2020-01-08 07:15:11	2020-01-08	12	[{"id_menu":3,"count":1}]	2641	pick-up	0	12
22782	2020-01-08 07:23:33	2020-01-08	8	[{"id_menu":5,"count":1}]	8893	delivery	5	13
22783	2020-01-08 07:26:16	2020-01-08	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	8891	delivery	5	35
22784	2020-01-08 07:27:24	2020-01-08	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	8148	pick-up	0	21
22785	2020-01-08 07:34:46	2020-01-08	14	[{"id_menu":2,"count":1}]	6202	delivery	5	19
22786	2020-01-08 07:38:05	2020-01-08	9	[{"id_menu":6,"count":1}]	4281	delivery	5	14
22787	2020-01-08 07:38:43	2020-01-08	12	[{"id_menu":1,"count":1}]	8895	pick-up	0	12
22788	2020-01-08 07:45:26	2020-01-08	9	[{"id_menu":6,"count":1}]	611	delivery	5	14
22789	2020-01-08 08:05:26	2020-01-08	12	[{"id_menu":3,"count":1}]	8881	delivery	5	17
22790	2020-01-08 08:14:27	2020-01-08	8	[{"id_menu":5,"count":1}]	8832	delivery	5	13
22791	2020-01-08 08:15:07	2020-01-08	14	[{"id_menu":2,"count":1}]	7907	delivery	5	19
22792	2020-01-08 08:31:22	2020-01-08	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	8896	delivery	5	40
22793	2020-01-08 08:40:22	2020-01-08	8	[{"id_menu":5,"count":1}]	3230	delivery	5	13
22794	2020-01-08 08:44:54	2020-01-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8852	delivery	5	22
22795	2020-01-08 08:45:09	2020-01-08	12	[{"id_menu":1,"count":1}]	3420	pick-up	0	12
22796	2020-01-08 09:02:04	2020-01-08	9	[{"id_menu":6,"count":1}]	8894	delivery	5	14
22797	2020-01-08 09:05:24	2020-01-08	17	[{"id_menu":4,"count":1}]	3708	delivery	5	22
22798	2020-01-08 09:06:04	2020-01-08	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2941	pick-up	0	29
22799	2020-01-08 09:12:51	2020-01-08	9	[{"id_menu":6,"count":1}]	8902	delivery	5	14
22800	2020-01-08 09:23:17	2020-01-08	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	5050	pick-up	0	24
22801	2020-01-08 09:24:02	2020-01-08	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8834	delivery	5	22
22802	2020-01-08 09:24:30	2020-01-08	9	[{"id_menu":6,"count":1}]	8887	pick-up	0	9
22803	2020-01-08 09:31:35	2020-01-08	17	[{"id_menu":4,"count":2}]	2116	pick-up	0	17
22804	2020-01-08 09:39:24	2020-01-08	17	[{"id_menu":4,"count":1}]	754	pick-up	0	17
22805	2020-01-08 09:40:03	2020-01-08	14	[{"id_menu":2,"count":1}]	8883	pick-up	0	14
22806	2020-01-08 09:44:53	2020-01-08	8	[{"id_menu":5,"count":1}]	4605	delivery	5	13
22807	2020-01-08 09:45:19	2020-01-08	17	[{"id_menu":4,"count":1}]	8866	delivery	5	22
22808	2020-01-08 09:47:08	2020-01-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8879	pick-up	0	18
22809	2020-01-08 09:53:42	2020-01-08	12	[{"id_menu":1,"count":1}]	8900	pick-up	0	12
22810	2020-01-08 10:06:49	2020-01-08	14	[{"id_menu":2,"count":1}]	8899	pick-up	0	14
22811	2020-01-08 10:21:18	2020-01-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8884	delivery	5	23
22812	2020-01-08 10:29:14	2020-01-08	12	[{"id_menu":3,"count":1}]	788	pick-up	0	12
22813	2020-01-08 10:41:43	2020-01-08	14	[{"id_menu":2,"count":3}]	4248	delivery	5	19
22814	2020-01-08 10:45:59	2020-01-08	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	4949	delivery	5	36
22815	2020-01-08 11:01:43	2020-01-08	14	[{"id_menu":2,"count":1}]	5336	pick-up	0	14
22816	2020-01-08 11:10:02	2020-01-08	17	[{"id_menu":4,"count":1}]	2719	delivery	5	22
22817	2020-01-08 11:10:19	2020-01-08	14	[{"id_menu":2,"count":1}]	8833	pick-up	0	14
22818	2020-01-08 11:50:19	2020-01-08	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1140	pick-up	0	30
22819	2020-01-08 12:54:55	2020-01-08	12	[{"id_menu":1,"count":1}]	3838	delivery	5	17
22820	2020-01-08 13:02:48	2020-01-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4072	pick-up	0	18
22821	2020-01-08 13:19:08	2020-01-08	9	[{"id_menu":7,"count":1}]	4996	pick-up	0	9
22822	2020-01-08 13:35:19	2020-01-08	9	[{"id_menu":6,"count":2}]	8861	delivery	5	14
22823	2020-01-08 13:43:38	2020-01-08	9	[{"id_menu":7,"count":1}]	6569	delivery	5	14
22824	2020-01-08 13:50:29	2020-01-08	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2857	pick-up	0	38
22825	2020-01-08 13:58:50	2020-01-08	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8140	delivery	5	36
22826	2020-01-08 13:59:17	2020-01-08	14	[{"id_menu":2,"count":1}]	8897	delivery	5	19
22827	2020-01-08 14:05:13	2020-01-08	9	[{"id_menu":7,"count":1}]	8857	delivery	5	14
22828	2020-01-08 14:17:46	2020-01-08	14	[{"id_menu":2,"count":1}]	8847	delivery	5	19
22829	2020-01-08 14:22:35	2020-01-08	17	[{"id_menu":4,"count":1}]	1657	pick-up	0	17
22830	2020-01-08 14:24:44	2020-01-08	17	[{"id_menu":4,"count":1}]	8885	pick-up	0	17
22831	2020-01-08 14:53:36	2020-01-08	12	[{"id_menu":1,"count":1}]	8813	delivery	5	17
22832	2020-01-08 14:55:21	2020-01-08	8	[{"id_menu":5,"count":1}]	8000	delivery	5	13
22833	2020-01-08 15:01:22	2020-01-08	9	[{"id_menu":6,"count":1}]	2263	delivery	5	14
22834	2020-01-08 15:06:30	2020-01-08	14	[{"id_menu":2,"count":1}]	6965	pick-up	0	14
22835	2020-01-08 15:14:22	2020-01-08	12	[{"id_menu":3,"count":1}]	7834	pick-up	0	12
22836	2020-01-08 15:15:57	2020-01-08	14	[{"id_menu":2,"count":1}]	1896	pick-up	0	14
22837	2020-01-08 15:22:45	2020-01-08	17	[{"id_menu":4,"count":1}]	405	pick-up	0	17
22838	2020-01-08 15:27:50	2020-01-08	8	[{"id_menu":5,"count":1}]	257	pick-up	0	8
22839	2020-01-08 15:29:20	2020-01-08	14	[{"id_menu":2,"count":2}]	4368	pick-up	0	14
22840	2020-01-08 15:35:25	2020-01-08	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	8842	delivery	5	23
22841	2020-01-08 15:46:20	2020-01-08	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7334	delivery	5	34
22842	2020-01-08 15:50:35	2020-01-08	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1174	pick-up	0	43
22843	2020-01-08 15:53:36	2020-01-08	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	8865	delivery	5	36
22844	2020-01-08 16:19:37	2020-01-08	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8828	delivery	5	35
22845	2020-01-08 16:20:25	2020-01-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6347	delivery	5	28
22846	2020-01-08 16:24:50	2020-01-08	12	[{"id_menu":3,"count":1}]	7317	pick-up	0	12
22847	2020-01-08 16:27:11	2020-01-08	12	[{"id_menu":1,"count":1}]	8827	pick-up	0	12
22848	2020-01-08 16:34:14	2020-01-08	17	[{"id_menu":4,"count":1}]	7211	delivery	5	22
22849	2020-01-08 16:49:19	2020-01-08	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	5546	delivery	5	27
22850	2020-01-08 17:24:53	2020-01-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6182	pick-up	0	18
22851	2020-01-08 17:25:23	2020-01-08	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	8878	pick-up	0	20
22852	2020-01-08 17:27:12	2020-01-08	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4110	delivery	5	45
22853	2020-01-08 17:42:33	2020-01-08	12	[{"id_menu":1,"count":1}]	8880	delivery	5	17
22854	2020-01-08 18:00:48	2020-01-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5723	delivery	5	22
22855	2020-01-08 18:14:01	2020-01-08	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8836	pick-up	0	17
22856	2020-01-08 18:44:08	2020-01-08	14	[{"id_menu":2,"count":1}]	8868	delivery	5	19
22857	2020-01-08 18:45:42	2020-01-08	12	[{"id_menu":1,"count":1}]	8854	delivery	5	17
22858	2020-01-08 18:49:14	2020-01-08	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	8844	delivery	5	43
22859	2020-01-08 18:54:42	2020-01-08	12	[{"id_menu":3,"count":1}]	8873	pick-up	0	12
22860	2020-01-08 18:57:05	2020-01-08	14	[{"id_menu":2,"count":1}]	8839	pick-up	0	14
22861	2020-01-08 19:02:43	2020-01-08	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1685	pick-up	0	29
22862	2020-01-08 19:03:20	2020-01-08	17	[{"id_menu":4,"count":1}]	541	pick-up	0	17
22863	2020-01-08 19:11:02	2020-01-08	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	337	pick-up	0	31
22864	2020-01-08 19:42:47	2020-01-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4983	delivery	5	22
22865	2020-01-08 19:50:43	2020-01-08	9	[{"id_menu":7,"count":1}]	8867	delivery	5	14
22866	2020-01-08 19:55:02	2020-01-08	12	[{"id_menu":1,"count":1}]	8830	delivery	5	17
22867	2020-01-08 20:01:04	2020-01-08	14	[{"id_menu":2,"count":1}]	4834	pick-up	0	14
22868	2020-01-08 20:18:03	2020-01-08	9	[{"id_menu":7,"count":1}]	6659	delivery	5	14
22869	2020-01-08 20:24:05	2020-01-08	12	[{"id_menu":3,"count":1}]	8863	pick-up	0	12
22870	2020-01-08 20:36:41	2020-01-08	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	5325	delivery	5	27
22871	2020-01-08 20:43:12	2020-01-08	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	7916	delivery	5	31
22872	2020-01-08 20:50:00	2020-01-08	12	[{"id_menu":3,"count":1}]	8837	delivery	5	17
22873	2020-01-08 21:00:22	2020-01-08	12	[{"id_menu":3,"count":1}]	8901	delivery	5	17
22874	2020-01-08 21:00:51	2020-01-08	14	[{"id_menu":2,"count":1}]	1055	pick-up	0	14
22875	2020-01-08 21:02:58	2020-01-08	14	[{"id_menu":2,"count":1}]	7891	delivery	5	19
22876	2020-01-08 21:07:11	2020-01-08	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	8851	delivery	5	31
22877	2020-01-08 21:09:15	2020-01-08	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1334	pick-up	0	21
22878	2020-01-08 21:16:18	2020-01-08	12	[{"id_menu":3,"count":1}]	4923	delivery	5	17
22879	2020-01-08 21:23:25	2020-01-08	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	8888	delivery	5	39
22880	2020-01-08 21:25:00	2020-01-08	17	[{"id_menu":4,"count":1}]	8853	pick-up	0	17
22881	2020-01-08 21:28:06	2020-01-08	14	[{"id_menu":2,"count":1}]	8859	delivery	5	19
22882	2020-01-08 21:28:31	2020-01-08	14	[{"id_menu":2,"count":1}]	3601	pick-up	0	14
22883	2020-01-08 21:34:03	2020-01-08	9	[{"id_menu":7,"count":1}]	2024	delivery	5	14
22884	2020-01-08 21:40:08	2020-01-08	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8876	delivery	5	45
22885	2020-01-08 21:46:50	2020-01-08	8	[{"id_menu":5,"count":1}]	8849	pick-up	0	8
22886	2020-01-08 21:51:45	2020-01-08	30	[{"id_menu":3,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	549	pick-up	0	30
22887	2020-01-08 21:52:55	2020-01-08	12	[{"id_menu":1,"count":1}]	8145	pick-up	0	12
22888	2020-01-08 21:54:13	2020-01-08	12	[{"id_menu":3,"count":1}]	8471	pick-up	0	12
22889	2020-01-08 22:01:44	2020-01-08	9	[{"id_menu":7,"count":1}]	813	pick-up	0	9
22890	2020-01-08 22:06:46	2020-01-08	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	4704	delivery	5	31
22891	2020-01-08 22:08:45	2020-01-08	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	8903	delivery	5	26
22892	2020-01-08 22:12:21	2020-01-08	9	[{"id_menu":6,"count":1}]	8870	delivery	5	14
22893	2020-01-08 22:19:44	2020-01-08	9	[{"id_menu":6,"count":1}]	4594	delivery	5	14
22894	2020-01-08 22:50:19	2020-01-08	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	8640	pick-up	0	29
22895	2020-01-08 23:01:42	2020-01-08	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	292	delivery	5	26
22896	2020-01-08 23:07:39	2020-01-08	12	[{"id_menu":3,"count":1}]	4590	pick-up	0	12
22897	2020-01-08 23:09:05	2020-01-08	9	[{"id_menu":7,"count":1}]	2103	pick-up	0	9
22898	2020-01-08 23:17:16	2020-01-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8856	delivery	5	22
22899	2020-01-08 23:39:37	2020-01-08	17	[{"id_menu":4,"count":1}]	2358	pick-up	0	17
22900	2020-01-08 23:56:39	2020-01-08	9	[{"id_menu":7,"count":1}]	7814	pick-up	0	9
22901	2020-01-09 00:02:37	2020-01-09	17	[{"id_menu":4,"count":2}]	8906	pick-up	0	17
22902	2020-01-09 00:06:33	2020-01-09	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1581	delivery	5	26
22903	2020-01-09 00:08:06	2020-01-09	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	491	delivery	5	25
22904	2020-01-09 00:11:05	2020-01-09	14	[{"id_menu":2,"count":1}]	8943	delivery	5	19
22905	2020-01-09 00:12:32	2020-01-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	3166	delivery	5	22
22906	2020-01-09 00:14:15	2020-01-09	14	[{"id_menu":2,"count":1}]	1463	pick-up	0	14
22907	2020-01-09 00:28:36	2020-01-09	8	[{"id_menu":5,"count":1}]	8244	delivery	5	13
22908	2020-01-09 00:33:04	2020-01-09	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8954	delivery	5	44
22909	2020-01-09 00:52:45	2020-01-09	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	8924	delivery	5	26
22910	2020-01-09 00:55:23	2020-01-09	17	[{"id_menu":4,"count":2}]	3125	delivery	5	22
22911	2020-01-09 01:05:43	2020-01-09	9	[{"id_menu":6,"count":1}]	8946	delivery	5	14
22912	2020-01-09 01:08:51	2020-01-09	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	8938	pick-up	0	21
22913	2020-01-09 01:09:09	2020-01-09	14	[{"id_menu":2,"count":1}]	1314	delivery	5	19
22914	2020-01-09 01:17:34	2020-01-09	9	[{"id_menu":6,"count":1}]	8970	delivery	5	14
22915	2020-01-09 01:42:14	2020-01-09	12	[{"id_menu":3,"count":1}]	6296	delivery	5	17
22916	2020-01-09 01:56:01	2020-01-09	14	[{"id_menu":2,"count":1}]	3289	delivery	5	19
22917	2020-01-09 02:05:49	2020-01-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8941	delivery	5	23
22918	2020-01-09 02:10:47	2020-01-09	9	[{"id_menu":6,"count":1}]	8934	delivery	5	14
22919	2020-01-09 02:12:41	2020-01-09	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1070	pick-up	0	26
22920	2020-01-09 02:15:30	2020-01-09	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	8976	delivery	5	34
22921	2020-01-09 02:19:16	2020-01-09	8	[{"id_menu":5,"count":1}]	8936	delivery	5	13
22922	2020-01-09 02:40:46	2020-01-09	9	[{"id_menu":7,"count":1}]	8959	delivery	5	14
22923	2020-01-09 02:53:23	2020-01-09	17	[{"id_menu":4,"count":2}]	6609	delivery	5	22
22924	2020-01-09 03:01:07	2020-01-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8939	delivery	5	22
22925	2020-01-09 03:10:55	2020-01-09	14	[{"id_menu":2,"count":2}]	2052	pick-up	0	14
22926	2020-01-09 03:17:25	2020-01-09	9	[{"id_menu":7,"count":1}]	3040	delivery	5	14
22927	2020-01-09 03:35:04	2020-01-09	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4819	delivery	5	40
22928	2020-01-09 03:35:04	2020-01-09	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5768	delivery	5	39
22929	2020-01-09 03:36:24	2020-01-09	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	8922	delivery	5	26
22930	2020-01-09 03:44:52	2020-01-09	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	8947	delivery	5	48
22931	2020-01-09 03:56:30	2020-01-09	14	[{"id_menu":2,"count":2}]	8928	pick-up	0	14
22932	2020-01-09 04:00:54	2020-01-09	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	8975	pick-up	0	21
22933	2020-01-09 04:01:07	2020-01-09	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	2595	pick-up	0	25
22934	2020-01-09 04:09:16	2020-01-09	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	4409	pick-up	0	24
22935	2020-01-09 04:09:51	2020-01-09	17	[{"id_menu":4,"count":1}]	8912	delivery	5	22
22936	2020-01-09 04:12:08	2020-01-09	17	[{"id_menu":4,"count":1}]	2651	delivery	5	22
22937	2020-01-09 04:40:14	2020-01-09	12	[{"id_menu":3,"count":1}]	3361	pick-up	0	12
22938	2020-01-09 04:48:23	2020-01-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1517	delivery	5	23
22939	2020-01-09 04:50:38	2020-01-09	9	[{"id_menu":6,"count":1}]	8962	delivery	5	14
22940	2020-01-09 05:21:52	2020-01-09	17	[{"id_menu":4,"count":1}]	5232	pick-up	0	17
22941	2020-01-09 05:23:00	2020-01-09	9	[{"id_menu":7,"count":1}]	6572	delivery	5	14
22942	2020-01-09 05:27:03	2020-01-09	8	[{"id_menu":5,"count":1}]	627	pick-up	0	8
22943	2020-01-09 05:27:06	2020-01-09	8	[{"id_menu":5,"count":1}]	8958	delivery	5	13
22944	2020-01-09 05:27:18	2020-01-09	9	[{"id_menu":6,"count":1}]	8910	delivery	5	14
22945	2020-01-09 05:55:45	2020-01-09	12	[{"id_menu":3,"count":1}]	7655	delivery	5	17
22946	2020-01-09 05:57:39	2020-01-09	12	[{"id_menu":1,"count":1}]	2286	pick-up	0	12
22947	2020-01-09 06:03:10	2020-01-09	12	[{"id_menu":3,"count":1}]	6800	delivery	5	17
22948	2020-01-09 06:04:14	2020-01-09	8	[{"id_menu":5,"count":1}]	4054	pick-up	0	8
22949	2020-01-09 06:25:43	2020-01-09	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8528	delivery	5	40
22950	2020-01-09 06:26:12	2020-01-09	17	[{"id_menu":4,"count":1}]	1893	pick-up	0	17
22951	2020-01-09 06:31:02	2020-01-09	9	[{"id_menu":6,"count":2}]	7746	pick-up	0	9
22952	2020-01-09 06:33:55	2020-01-09	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4585	pick-up	0	26
22953	2020-01-09 06:34:13	2020-01-09	12	[{"id_menu":1,"count":1}]	27	pick-up	0	12
22954	2020-01-09 06:37:30	2020-01-09	12	[{"id_menu":3,"count":1}]	233	delivery	5	17
22955	2020-01-09 06:51:24	2020-01-09	17	[{"id_menu":4,"count":1}]	5421	pick-up	0	17
22956	2020-01-09 07:04:33	2020-01-09	8	[{"id_menu":5,"count":2}]	3981	delivery	5	13
22957	2020-01-09 07:04:49	2020-01-09	14	[{"id_menu":2,"count":1}]	1563	pick-up	0	14
22958	2020-01-09 07:07:15	2020-01-09	12	[{"id_menu":3,"count":1}]	7122	delivery	5	17
22959	2020-01-09 07:09:17	2020-01-09	9	[{"id_menu":6,"count":1}]	573	pick-up	0	9
22960	2020-01-09 07:10:20	2020-01-09	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	5750	delivery	5	39
22961	2020-01-09 07:13:30	2020-01-09	8	[{"id_menu":5,"count":1}]	931	delivery	5	13
22962	2020-01-09 07:16:45	2020-01-09	12	[{"id_menu":3,"count":1}]	4492	delivery	5	17
22963	2020-01-09 07:20:24	2020-01-09	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8913	delivery	5	31
22964	2020-01-09 07:30:24	2020-01-09	14	[{"id_menu":2,"count":1}]	8925	delivery	5	19
22965	2020-01-09 07:32:19	2020-01-09	12	[{"id_menu":3,"count":1}]	2343	pick-up	0	12
22966	2020-01-09 07:36:27	2020-01-09	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1282	pick-up	0	35
22967	2020-01-09 07:49:10	2020-01-09	9	[{"id_menu":7,"count":1}]	8953	delivery	5	14
22968	2020-01-09 07:56:55	2020-01-09	17	[{"id_menu":4,"count":1}]	2317	delivery	5	22
22969	2020-01-09 08:06:26	2020-01-09	14	[{"id_menu":2,"count":1}]	5471	pick-up	0	14
22970	2020-01-09 08:13:51	2020-01-09	14	[{"id_menu":2,"count":1}]	8501	pick-up	0	14
22971	2020-01-09 08:21:48	2020-01-09	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3621	pick-up	0	25
22972	2020-01-09 08:59:05	2020-01-09	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	5683	pick-up	0	24
22973	2020-01-09 09:12:59	2020-01-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	5456	delivery	5	23
22974	2020-01-09 09:59:28	2020-01-09	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5058	delivery	5	31
22975	2020-01-09 10:00:06	2020-01-09	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2190	pick-up	0	21
22976	2020-01-09 10:00:54	2020-01-09	9	[{"id_menu":6,"count":1}]	8955	delivery	5	14
22977	2020-01-09 10:03:57	2020-01-09	14	[{"id_menu":2,"count":1}]	8949	delivery	5	19
22978	2020-01-09 10:06:20	2020-01-09	9	[{"id_menu":7,"count":1}]	2994	delivery	5	14
22979	2020-01-09 10:17:14	2020-01-09	9	[{"id_menu":6,"count":1}]	8948	delivery	5	14
22980	2020-01-09 10:24:31	2020-01-09	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6460	delivery	5	34
22981	2020-01-09 10:26:33	2020-01-09	17	[{"id_menu":4,"count":1}]	8748	pick-up	0	17
22982	2020-01-09 10:26:51	2020-01-09	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1257	pick-up	0	25
22983	2020-01-09 10:42:16	2020-01-09	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1445	pick-up	0	21
22984	2020-01-09 10:43:02	2020-01-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	128	delivery	5	28
22985	2020-01-09 10:59:12	2020-01-09	9	[{"id_menu":6,"count":2}]	4991	delivery	5	14
22986	2020-01-09 11:02:11	2020-01-09	9	[{"id_menu":6,"count":1}]	946	pick-up	0	9
22987	2020-01-09 11:03:02	2020-01-09	14	[{"id_menu":2,"count":1}]	4849	delivery	5	19
22988	2020-01-09 11:05:49	2020-01-09	17	[{"id_menu":4,"count":2}]	351	pick-up	0	17
22989	2020-01-09 11:12:47	2020-01-09	8	[{"id_menu":5,"count":1}]	3254	delivery	5	13
22990	2020-01-09 11:40:00	2020-01-09	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6012	delivery	5	49
22991	2020-01-09 11:48:01	2020-01-09	9	[{"id_menu":6,"count":1}]	2353	pick-up	0	9
22992	2020-01-09 11:55:06	2020-01-09	9	[{"id_menu":7,"count":1}]	8974	delivery	5	14
22993	2020-01-09 11:57:29	2020-01-09	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1755	delivery	5	25
22994	2020-01-09 11:58:21	2020-01-09	9	[{"id_menu":6,"count":1}]	3604	delivery	5	14
22995	2020-01-09 12:10:06	2020-01-09	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1984	delivery	5	29
22996	2020-01-09 12:27:16	2020-01-09	17	[{"id_menu":4,"count":1}]	1756	delivery	5	22
22997	2020-01-09 12:29:04	2020-01-09	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	8972	delivery	5	26
22998	2020-01-09 12:32:17	2020-01-09	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4081	delivery	5	31
22999	2020-01-09 12:37:34	2020-01-09	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	8942	delivery	5	45
23000	2020-01-09 12:43:15	2020-01-09	9	[{"id_menu":6,"count":1}]	8950	delivery	5	14
23001	2020-01-09 12:44:22	2020-01-09	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	8966	delivery	5	25
23002	2020-01-09 12:53:17	2020-01-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8951	delivery	5	28
23003	2020-01-09 12:57:55	2020-01-09	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	5322	delivery	5	25
23004	2020-01-09 13:01:52	2020-01-09	12	[{"id_menu":1,"count":1}]	6206	delivery	5	17
23005	2020-01-09 13:04:42	2020-01-09	14	[{"id_menu":2,"count":1}]	925	pick-up	0	14
23006	2020-01-09 13:11:57	2020-01-09	9	[{"id_menu":6,"count":1}]	8952	delivery	5	14
23007	2020-01-09 13:22:27	2020-01-09	14	[{"id_menu":2,"count":1}]	8911	delivery	5	19
23008	2020-01-09 13:24:13	2020-01-09	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3858	delivery	5	34
23009	2020-01-09 13:37:47	2020-01-09	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1727	pick-up	0	35
23010	2020-01-09 13:59:22	2020-01-09	9	[{"id_menu":7,"count":1}]	8963	delivery	5	14
23011	2020-01-09 14:04:01	2020-01-09	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	4094	delivery	5	25
23012	2020-01-09 14:10:42	2020-01-09	12	[{"id_menu":1,"count":1}]	8915	pick-up	0	12
23013	2020-01-09 14:40:16	2020-01-09	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	6848	pick-up	0	21
23014	2020-01-09 14:44:07	2020-01-09	9	[{"id_menu":6,"count":1}]	1681	pick-up	0	9
23015	2020-01-09 14:55:00	2020-01-09	17	[{"id_menu":4,"count":1}]	1280	pick-up	0	17
23016	2020-01-09 14:58:52	2020-01-09	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8973	delivery	5	53
23017	2020-01-09 15:04:31	2020-01-09	17	[{"id_menu":4,"count":1}]	8919	delivery	5	22
23018	2020-01-09 15:19:59	2020-01-09	9	[{"id_menu":6,"count":1}]	7638	delivery	5	14
23019	2020-01-09 15:22:04	2020-01-09	9	[{"id_menu":6,"count":1}]	7195	delivery	5	14
23020	2020-01-09 15:24:40	2020-01-09	12	[{"id_menu":3,"count":2}]	8139	delivery	5	17
23021	2020-01-09 15:30:10	2020-01-09	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8918	delivery	5	40
23022	2020-01-09 15:33:54	2020-01-09	14	[{"id_menu":2,"count":1}]	6062	delivery	5	19
23023	2020-01-09 15:36:08	2020-01-09	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	3835	delivery	5	37
23024	2020-01-09 15:39:08	2020-01-09	12	[{"id_menu":1,"count":1}]	8909	pick-up	0	12
23025	2020-01-09 15:45:42	2020-01-09	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6444	delivery	5	54
23026	2020-01-09 15:50:02	2020-01-09	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2172	pick-up	0	21
23027	2020-01-09 15:59:32	2020-01-09	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	8904	pick-up	0	24
23028	2020-01-09 16:02:55	2020-01-09	17	[{"id_menu":4,"count":2}]	6222	delivery	5	22
23029	2020-01-09 16:28:22	2020-01-09	9	[{"id_menu":7,"count":1}]	1140	pick-up	0	9
23030	2020-01-09 16:33:53	2020-01-09	14	[{"id_menu":2,"count":1}]	8916	pick-up	0	14
23031	2020-01-09 16:47:26	2020-01-09	9	[{"id_menu":7,"count":1}]	6996	delivery	5	14
23032	2020-01-09 16:49:17	2020-01-09	17	[{"id_menu":4,"count":1}]	5520	pick-up	0	17
23033	2020-01-09 16:57:43	2020-01-09	8	[{"id_menu":5,"count":1}]	8957	delivery	5	13
23034	2020-01-09 17:02:36	2020-01-09	9	[{"id_menu":7,"count":1}]	3148	delivery	5	14
23035	2020-01-09 17:04:50	2020-01-09	9	[{"id_menu":6,"count":1}]	2320	pick-up	0	9
23036	2020-01-09 17:05:16	2020-01-09	9	[{"id_menu":7,"count":1}]	8965	delivery	5	14
23037	2020-01-09 17:10:11	2020-01-09	17	[{"id_menu":4,"count":1}]	841	delivery	5	22
23038	2020-01-09 17:23:02	2020-01-09	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2845	delivery	5	27
23039	2020-01-09 18:03:00	2020-01-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8921	delivery	5	22
23040	2020-01-09 18:04:01	2020-01-09	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	8929	delivery	5	34
23041	2020-01-09 18:09:25	2020-01-09	8	[{"id_menu":5,"count":1}]	586	pick-up	0	8
23042	2020-01-09 18:31:14	2020-01-09	8	[{"id_menu":5,"count":2}]	2197	pick-up	0	8
23043	2020-01-09 18:33:40	2020-01-09	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1119	pick-up	0	29
23044	2020-01-09 18:43:29	2020-01-09	9	[{"id_menu":6,"count":1}]	1532	delivery	5	14
23045	2020-01-09 18:46:13	2020-01-09	14	[{"id_menu":2,"count":1}]	2490	delivery	5	19
23046	2020-01-09 18:46:54	2020-01-09	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	8907	delivery	5	26
23047	2020-01-09 18:50:52	2020-01-09	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	3115	delivery	5	31
23048	2020-01-09 19:00:48	2020-01-09	14	[{"id_menu":2,"count":1}]	293	pick-up	0	14
23049	2020-01-09 19:08:03	2020-01-09	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	8237	pick-up	0	21
23050	2020-01-09 19:30:25	2020-01-09	17	[{"id_menu":4,"count":1}]	8940	pick-up	0	17
23051	2020-01-09 19:42:22	2020-01-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3965	delivery	5	22
23052	2020-01-09 19:43:30	2020-01-09	14	[{"id_menu":2,"count":1}]	8920	delivery	5	19
23053	2020-01-09 19:44:25	2020-01-09	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1985	delivery	5	39
23054	2020-01-09 19:46:10	2020-01-09	9	[{"id_menu":7,"count":1}]	8964	delivery	5	14
23055	2020-01-09 20:06:48	2020-01-09	9	[{"id_menu":7,"count":1}]	2264	pick-up	0	9
23056	2020-01-09 20:28:22	2020-01-09	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	799	pick-up	0	31
23057	2020-01-09 20:32:44	2020-01-09	9	[{"id_menu":6,"count":1}]	8969	delivery	5	14
23058	2020-01-09 20:33:59	2020-01-09	8	[{"id_menu":5,"count":1}]	1390	pick-up	0	8
23059	2020-01-09 20:36:47	2020-01-09	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4251	delivery	5	27
23060	2020-01-09 20:45:56	2020-01-09	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	8908	delivery	5	39
23061	2020-01-09 20:50:37	2020-01-09	8	[{"id_menu":5,"count":1}]	2764	pick-up	0	8
23062	2020-01-09 20:52:36	2020-01-09	14	[{"id_menu":2,"count":1}]	8935	delivery	5	19
23063	2020-01-09 20:52:46	2020-01-09	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	3449	pick-up	0	21
23064	2020-01-09 21:08:19	2020-01-09	8	[{"id_menu":5,"count":1}]	8937	delivery	5	13
23065	2020-01-09 21:16:46	2020-01-09	12	[{"id_menu":3,"count":1}]	1461	pick-up	0	12
23066	2020-01-09 21:23:32	2020-01-09	12	[{"id_menu":3,"count":1}]	1166	pick-up	0	12
23067	2020-01-09 21:33:02	2020-01-09	9	[{"id_menu":7,"count":1}]	5376	delivery	5	14
23068	2020-01-09 21:35:25	2020-01-09	14	[{"id_menu":2,"count":1}]	2613	pick-up	0	14
23069	2020-01-09 21:44:45	2020-01-09	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	8933	pick-up	0	24
23070	2020-01-09 21:51:54	2020-01-09	12	[{"id_menu":3,"count":1}]	4995	pick-up	0	12
23071	2020-01-09 21:53:06	2020-01-09	14	[{"id_menu":2,"count":1}]	8945	delivery	5	19
23072	2020-01-09 22:29:04	2020-01-09	8	[{"id_menu":5,"count":1}]	260	pick-up	0	8
23073	2020-01-09 22:31:50	2020-01-09	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6787	delivery	5	54
23074	2020-01-09 22:33:00	2020-01-09	14	[{"id_menu":2,"count":1}]	44	delivery	5	19
23075	2020-01-09 22:36:11	2020-01-09	9	[{"id_menu":6,"count":1}]	2193	pick-up	0	9
23076	2020-01-09 22:36:38	2020-01-09	14	[{"id_menu":2,"count":1}]	2207	pick-up	0	14
23077	2020-01-09 22:46:19	2020-01-09	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8927	delivery	5	43
23078	2020-01-09 22:53:19	2020-01-09	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	8605	delivery	5	34
23079	2020-01-09 23:09:18	2020-01-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7165	delivery	5	22
23080	2020-01-09 23:23:13	2020-01-09	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1228	pick-up	0	31
23081	2020-01-09 23:29:09	2020-01-09	9	[{"id_menu":7,"count":1}]	8705	delivery	5	14
23082	2020-01-09 23:39:12	2020-01-09	17	[{"id_menu":4,"count":1}]	2995	delivery	5	22
23083	2020-01-09 23:44:27	2020-01-09	9	[{"id_menu":6,"count":1}]	8926	pick-up	0	9
23084	2020-01-09 23:44:55	2020-01-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8917	delivery	5	22
23085	2020-01-09 23:48:32	2020-01-09	12	[{"id_menu":1,"count":1}]	4007	delivery	5	17
23086	2020-01-09 23:48:50	2020-01-09	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	3198	delivery	5	29
23087	2020-01-09 23:56:06	2020-01-09	17	[{"id_menu":4,"count":1}]	8905	pick-up	0	17
23088	2020-01-10 00:06:47	2020-01-10	9	[{"id_menu":6,"count":1}]	8977	delivery	5	14
23089	2020-01-10 00:12:32	2020-01-10	14	[{"id_menu":2,"count":1}]	6264	delivery	5	19
23090	2020-01-10 00:29:10	2020-01-10	9	[{"id_menu":7,"count":1}]	4556	delivery	5	14
23091	2020-01-10 00:36:06	2020-01-10	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	9037	pick-up	0	20
23092	2020-01-10 00:42:20	2020-01-10	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2358	pick-up	0	41
23093	2020-01-10 00:51:06	2020-01-10	12	[{"id_menu":3,"count":1}]	2918	pick-up	0	12
23094	2020-01-10 00:51:06	2020-01-10	8	[{"id_menu":5,"count":1}]	158	delivery	5	13
23095	2020-01-10 01:16:45	2020-01-10	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	7084	pick-up	0	24
23096	2020-01-10 01:18:31	2020-01-10	14	[{"id_menu":2,"count":2}]	660	pick-up	0	14
23097	2020-01-10 01:32:32	2020-01-10	14	[{"id_menu":2,"count":1}]	9045	delivery	5	19
23098	2020-01-10 01:39:46	2020-01-10	9	[{"id_menu":6,"count":1}]	4451	pick-up	0	9
23099	2020-01-10 02:02:58	2020-01-10	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4818	delivery	5	27
23100	2020-01-10 02:07:56	2020-01-10	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	2124	pick-up	0	40
23101	2020-01-10 02:13:16	2020-01-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9029	delivery	5	22
23102	2020-01-10 02:15:46	2020-01-10	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8204	delivery	5	22
23103	2020-01-10 02:19:36	2020-01-10	9	[{"id_menu":7,"count":2}]	5817	delivery	5	14
23104	2020-01-10 02:21:07	2020-01-10	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3445	delivery	5	31
23105	2020-01-10 02:47:08	2020-01-10	17	[{"id_menu":4,"count":1}]	630	delivery	5	22
23106	2020-01-10 02:47:33	2020-01-10	17	[{"id_menu":4,"count":1}]	3948	pick-up	0	17
23107	2020-01-10 03:11:13	2020-01-10	12	[{"id_menu":1,"count":1}]	9053	delivery	5	17
23108	2020-01-10 03:16:19	2020-01-10	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8984	delivery	5	22
23109	2020-01-10 03:22:36	2020-01-10	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	8985	pick-up	0	20
23110	2020-01-10 03:30:52	2020-01-10	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	9048	delivery	5	34
23111	2020-01-10 03:30:59	2020-01-10	9	[{"id_menu":7,"count":2}]	2901	pick-up	0	9
23112	2020-01-10 03:46:43	2020-01-10	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3316	delivery	5	39
23113	2020-01-10 03:47:40	2020-01-10	9	[{"id_menu":6,"count":1}]	9013	delivery	5	14
23114	2020-01-10 04:01:55	2020-01-10	9	[{"id_menu":7,"count":1}]	5170	delivery	5	14
23115	2020-01-10 04:07:41	2020-01-10	9	[{"id_menu":6,"count":1}]	546	delivery	5	14
23116	2020-01-10 04:18:00	2020-01-10	12	[{"id_menu":1,"count":1}]	3361	delivery	5	17
23117	2020-01-10 04:28:45	2020-01-10	9	[{"id_menu":7,"count":1}]	6093	pick-up	0	9
23118	2020-01-10 04:31:25	2020-01-10	12	[{"id_menu":1,"count":1}]	9014	delivery	5	17
23119	2020-01-10 04:38:01	2020-01-10	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8601	delivery	5	52
23120	2020-01-10 04:38:27	2020-01-10	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	9019	pick-up	0	20
23121	2020-01-10 04:40:40	2020-01-10	12	[{"id_menu":1,"count":1}]	552	pick-up	0	12
23122	2020-01-10 04:41:44	2020-01-10	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9022	delivery	5	36
23123	2020-01-10 04:43:05	2020-01-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9016	delivery	5	23
23124	2020-01-10 04:46:11	2020-01-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9059	pick-up	0	17
23125	2020-01-10 04:50:30	2020-01-10	12	[{"id_menu":3,"count":1}]	1715	delivery	5	17
23126	2020-01-10 05:07:57	2020-01-10	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	9003	delivery	5	43
23127	2020-01-10 05:08:28	2020-01-10	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	9006	delivery	5	25
23128	2020-01-10 05:11:17	2020-01-10	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	677	pick-up	0	26
23129	2020-01-10 05:30:41	2020-01-10	9	[{"id_menu":6,"count":1}]	1186	delivery	5	14
23130	2020-01-10 05:37:17	2020-01-10	8	[{"id_menu":5,"count":1}]	5994	delivery	5	13
23131	2020-01-10 05:44:13	2020-01-10	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2585	pick-up	0	26
23132	2020-01-10 05:51:54	2020-01-10	8	[{"id_menu":5,"count":1}]	8982	delivery	5	13
23133	2020-01-10 05:55:53	2020-01-10	14	[{"id_menu":2,"count":1}]	5520	pick-up	0	14
23134	2020-01-10 05:57:54	2020-01-10	12	[{"id_menu":3,"count":1}]	9047	pick-up	0	12
23135	2020-01-10 05:58:38	2020-01-10	8	[{"id_menu":5,"count":1}]	8406	pick-up	0	8
23136	2020-01-10 06:06:05	2020-01-10	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8994	delivery	5	43
23137	2020-01-10 06:12:11	2020-01-10	8	[{"id_menu":5,"count":1}]	9011	delivery	5	13
23138	2020-01-10 06:31:17	2020-01-10	17	[{"id_menu":4,"count":1}]	4728	delivery	5	22
23139	2020-01-10 06:33:08	2020-01-10	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	8885	pick-up	0	31
23140	2020-01-10 06:34:44	2020-01-10	12	[{"id_menu":1,"count":2}]	1667	pick-up	0	12
23141	2020-01-10 06:38:08	2020-01-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2447	pick-up	0	17
23142	2020-01-10 06:39:13	2020-01-10	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	6516	delivery	5	31
23143	2020-01-10 06:41:55	2020-01-10	17	[{"id_menu":4,"count":1}]	2441	pick-up	0	17
23144	2020-01-10 06:49:00	2020-01-10	9	[{"id_menu":7,"count":1}]	481	pick-up	0	9
23145	2020-01-10 06:53:04	2020-01-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9009	delivery	5	28
23146	2020-01-10 06:57:43	2020-01-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	8988	delivery	5	23
23147	2020-01-10 07:05:27	2020-01-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2806	delivery	5	22
23148	2020-01-10 07:10:42	2020-01-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1700	delivery	5	22
23149	2020-01-10 07:11:18	2020-01-10	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	8998	pick-up	0	20
23150	2020-01-10 07:36:19	2020-01-10	9	[{"id_menu":6,"count":1}]	9050	pick-up	0	9
23151	2020-01-10 07:37:29	2020-01-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1212	pick-up	0	18
23152	2020-01-10 07:46:27	2020-01-10	12	[{"id_menu":1,"count":1}]	5466	pick-up	0	12
23153	2020-01-10 08:08:30	2020-01-10	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	8980	delivery	5	28
23154	2020-01-10 08:22:49	2020-01-10	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5078	delivery	5	39
23155	2020-01-10 08:26:38	2020-01-10	12	[{"id_menu":1,"count":1}]	946	pick-up	0	12
23156	2020-01-10 08:34:09	2020-01-10	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	5447	pick-up	0	21
23157	2020-01-10 08:40:31	2020-01-10	12	[{"id_menu":3,"count":1}]	9054	delivery	5	17
23158	2020-01-10 08:53:10	2020-01-10	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	143	pick-up	0	21
23159	2020-01-10 08:56:17	2020-01-10	14	[{"id_menu":2,"count":1}]	2799	pick-up	0	14
23160	2020-01-10 09:15:45	2020-01-10	8	[{"id_menu":5,"count":1}]	2025	pick-up	0	8
23161	2020-01-10 10:09:10	2020-01-10	8	[{"id_menu":5,"count":1}]	4867	pick-up	0	8
23162	2020-01-10 10:23:37	2020-01-10	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1073	delivery	5	31
23163	2020-01-10 10:31:55	2020-01-10	12	[{"id_menu":3,"count":1}]	6993	delivery	5	17
23164	2020-01-10 10:41:51	2020-01-10	12	[{"id_menu":3,"count":1}]	6622	pick-up	0	12
23165	2020-01-10 11:07:53	2020-01-10	14	[{"id_menu":2,"count":1}]	2546	delivery	5	19
23166	2020-01-10 11:15:40	2020-01-10	8	[{"id_menu":5,"count":1}]	189	pick-up	0	8
23167	2020-01-10 11:16:58	2020-01-10	9	[{"id_menu":6,"count":1}]	4871	delivery	5	14
23168	2020-01-10 11:24:02	2020-01-10	12	[{"id_menu":1,"count":1}]	9007	delivery	5	17
23169	2020-01-10 11:24:22	2020-01-10	9	[{"id_menu":6,"count":1}]	8441	delivery	5	14
23170	2020-01-10 11:34:20	2020-01-10	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9012	delivery	5	39
23171	2020-01-10 11:37:20	2020-01-10	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8981	pick-up	0	17
23172	2020-01-10 11:53:56	2020-01-10	14	[{"id_menu":2,"count":1}]	9032	pick-up	0	14
23173	2020-01-10 11:54:22	2020-01-10	12	[{"id_menu":1,"count":1}]	3858	pick-up	0	12
23174	2020-01-10 11:56:52	2020-01-10	38	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6097	pick-up	0	38
23175	2020-01-10 11:58:15	2020-01-10	8	[{"id_menu":5,"count":1}]	9021	delivery	5	13
23176	2020-01-10 11:58:37	2020-01-10	9	[{"id_menu":7,"count":1}]	8852	delivery	5	14
23177	2020-01-10 12:05:44	2020-01-10	14	[{"id_menu":2,"count":1}]	9010	pick-up	0	14
23178	2020-01-10 12:06:56	2020-01-10	8	[{"id_menu":5,"count":1}]	3133	delivery	5	13
23179	2020-01-10 12:07:23	2020-01-10	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2089	pick-up	0	22
23180	2020-01-10 12:25:32	2020-01-10	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9026	delivery	5	48
23181	2020-01-10 12:33:10	2020-01-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4980	delivery	5	28
23182	2020-01-10 12:41:18	2020-01-10	17	[{"id_menu":4,"count":1}]	1306	delivery	5	22
23183	2020-01-10 12:43:33	2020-01-10	12	[{"id_menu":3,"count":1}]	4465	pick-up	0	12
23184	2020-01-10 12:58:25	2020-01-10	14	[{"id_menu":2,"count":1}]	5933	delivery	5	19
23185	2020-01-10 12:59:20	2020-01-10	14	[{"id_menu":2,"count":1}]	8163	pick-up	0	14
23186	2020-01-10 13:00:38	2020-01-10	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9049	delivery	5	35
23187	2020-01-10 13:06:34	2020-01-10	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	9056	delivery	5	26
23188	2020-01-10 13:21:52	2020-01-10	12	[{"id_menu":1,"count":1}]	232	pick-up	0	12
23189	2020-01-10 13:22:26	2020-01-10	17	[{"id_menu":4,"count":1}]	8873	pick-up	0	17
23190	2020-01-10 13:31:13	2020-01-10	9	[{"id_menu":6,"count":1}]	8265	pick-up	0	9
23191	2020-01-10 13:34:25	2020-01-10	9	[{"id_menu":7,"count":1}]	9023	pick-up	0	9
23192	2020-01-10 13:39:19	2020-01-10	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9020	pick-up	0	31
23193	2020-01-10 13:40:41	2020-01-10	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	6364	pick-up	0	26
23194	2020-01-10 13:43:58	2020-01-10	14	[{"id_menu":2,"count":1}]	8139	delivery	5	19
23195	2020-01-10 13:52:30	2020-01-10	9	[{"id_menu":6,"count":1}]	837	pick-up	0	9
23196	2020-01-10 13:58:29	2020-01-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	8978	delivery	5	28
23197	2020-01-10 14:08:40	2020-01-10	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	9035	pick-up	0	21
23198	2020-01-10 14:40:26	2020-01-10	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	6357	delivery	5	26
23199	2020-01-10 14:53:30	2020-01-10	14	[{"id_menu":2,"count":1}]	6885	pick-up	0	14
23200	2020-01-10 14:53:44	2020-01-10	9	[{"id_menu":7,"count":1}]	9027	delivery	5	14
23201	2020-01-10 14:57:14	2020-01-10	12	[{"id_menu":1,"count":1}]	5438	delivery	5	17
23202	2020-01-10 15:19:33	2020-01-10	9	[{"id_menu":7,"count":1}]	4592	delivery	5	14
23203	2020-01-10 15:19:49	2020-01-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9005	delivery	5	23
23204	2020-01-10 15:23:57	2020-01-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7596	delivery	5	22
23205	2020-01-10 15:28:15	2020-01-10	9	[{"id_menu":7,"count":2}]	1581	pick-up	0	9
23206	2020-01-10 15:31:07	2020-01-10	12	[{"id_menu":3,"count":1}]	5955	delivery	5	17
23207	2020-01-10 15:35:30	2020-01-10	17	[{"id_menu":4,"count":1}]	9001	delivery	5	22
23208	2020-01-10 16:00:19	2020-01-10	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4502	pick-up	0	21
23209	2020-01-10 16:16:14	2020-01-10	8	[{"id_menu":5,"count":1}]	8979	delivery	5	13
23210	2020-01-10 16:23:38	2020-01-10	9	[{"id_menu":7,"count":1}]	9008	delivery	5	14
23211	2020-01-10 16:27:47	2020-01-10	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	8990	delivery	5	46
23212	2020-01-10 16:51:02	2020-01-10	9	[{"id_menu":7,"count":1}]	3224	delivery	5	14
23213	2020-01-10 17:02:04	2020-01-10	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	997	delivery	5	34
23214	2020-01-10 17:09:33	2020-01-10	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9058	delivery	5	43
23215	2020-01-10 17:21:08	2020-01-10	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	8101	delivery	5	26
23216	2020-01-10 17:35:50	2020-01-10	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	2669	delivery	5	40
23217	2020-01-10 17:38:14	2020-01-10	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7792	delivery	5	44
23218	2020-01-10 17:45:11	2020-01-10	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	8995	pick-up	0	29
23219	2020-01-10 17:46:44	2020-01-10	8	[{"id_menu":5,"count":1}]	384	delivery	5	13
23220	2020-01-10 17:47:28	2020-01-10	9	[{"id_menu":6,"count":1}]	2605	delivery	5	14
23221	2020-01-10 17:48:45	2020-01-10	14	[{"id_menu":2,"count":1}]	5707	delivery	5	19
23222	2020-01-10 18:15:35	2020-01-10	14	[{"id_menu":2,"count":1}]	9043	pick-up	0	14
23223	2020-01-10 18:37:56	2020-01-10	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3624	pick-up	0	25
23224	2020-01-10 18:43:49	2020-01-10	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1119	pick-up	0	22
23225	2020-01-10 18:52:29	2020-01-10	9	[{"id_menu":7,"count":2}]	1280	delivery	5	14
23226	2020-01-10 18:53:24	2020-01-10	14	[{"id_menu":2,"count":2}]	9046	delivery	5	19
23227	2020-01-10 18:59:19	2020-01-10	8	[{"id_menu":5,"count":1}]	8680	delivery	5	13
23228	2020-01-10 19:04:21	2020-01-10	12	[{"id_menu":1,"count":1}]	9017	delivery	5	17
23229	2020-01-10 19:08:33	2020-01-10	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7827	delivery	5	31
23230	2020-01-10 19:09:49	2020-01-10	9	[{"id_menu":6,"count":1}]	9042	delivery	5	14
23231	2020-01-10 19:10:03	2020-01-10	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	519	delivery	5	25
23232	2020-01-10 19:16:40	2020-01-10	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":3}]	8991	delivery	5	22
23233	2020-01-10 19:21:59	2020-01-10	8	[{"id_menu":5,"count":1}]	2021	pick-up	0	8
23234	2020-01-10 19:38:01	2020-01-10	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	2902	pick-up	0	25
23235	2020-01-10 19:42:12	2020-01-10	12	[{"id_menu":1,"count":1}]	1937	delivery	5	17
23236	2020-01-10 19:43:22	2020-01-10	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7183	delivery	5	53
23237	2020-01-10 19:51:27	2020-01-10	9	[{"id_menu":6,"count":3}]	5781	delivery	5	14
23238	2020-01-10 20:18:24	2020-01-10	9	[{"id_menu":7,"count":1}]	8983	delivery	5	14
23239	2020-01-10 20:21:37	2020-01-10	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	7282	pick-up	0	29
23240	2020-01-10 20:24:23	2020-01-10	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8997	delivery	5	22
23241	2020-01-10 20:29:14	2020-01-10	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	6341	delivery	5	34
23242	2020-01-10 20:35:53	2020-01-10	8	[{"id_menu":5,"count":1}]	7460	delivery	5	13
23243	2020-01-10 20:49:24	2020-01-10	9	[{"id_menu":7,"count":1}]	1773	delivery	5	14
23244	2020-01-10 20:53:50	2020-01-10	9	[{"id_menu":7,"count":2}]	1457	delivery	5	14
23245	2020-01-10 21:08:17	2020-01-10	9	[{"id_menu":7,"count":1}]	2627	delivery	5	14
23246	2020-01-10 21:17:43	2020-01-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2723	delivery	5	22
23247	2020-01-10 21:47:01	2020-01-10	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	9041	delivery	5	35
23248	2020-01-10 21:49:58	2020-01-10	12	[{"id_menu":1,"count":1}]	5311	pick-up	0	12
23249	2020-01-10 21:53:07	2020-01-10	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7112	delivery	5	45
23250	2020-01-10 22:17:13	2020-01-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4245	pick-up	0	23
23251	2020-01-10 22:29:40	2020-01-10	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8989	delivery	5	48
23252	2020-01-10 22:38:36	2020-01-10	12	[{"id_menu":1,"count":2}]	4522	delivery	5	17
23253	2020-01-10 22:52:21	2020-01-10	9	[{"id_menu":6,"count":1}]	2951	delivery	5	14
23254	2020-01-10 22:53:34	2020-01-10	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	8987	delivery	5	48
23255	2020-01-10 22:58:50	2020-01-10	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2077	pick-up	0	26
23256	2020-01-10 23:02:10	2020-01-10	9	[{"id_menu":7,"count":1}]	4682	delivery	5	14
23257	2020-01-10 23:09:04	2020-01-10	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8797	delivery	5	31
23258	2020-01-10 23:50:52	2020-01-10	8	[{"id_menu":5,"count":1}]	7767	delivery	5	13
23259	2020-01-10 23:51:40	2020-01-10	12	[{"id_menu":1,"count":1}]	1713	pick-up	0	12
23260	2020-01-10 23:53:27	2020-01-10	8	[{"id_menu":5,"count":1}]	9000	delivery	5	13
23261	2020-01-11 00:06:00	2020-01-11	17	[{"id_menu":4,"count":2}]	3320	delivery	5	22
23262	2020-01-11 00:11:28	2020-01-11	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2374	pick-up	0	21
23263	2020-01-11 00:12:42	2020-01-11	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	9068	delivery	5	38
23264	2020-01-11 00:13:15	2020-01-11	9	[{"id_menu":7,"count":1}]	2085	pick-up	0	9
23265	2020-01-11 00:23:50	2020-01-11	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9088	delivery	5	31
23266	2020-01-11 00:24:56	2020-01-11	8	[{"id_menu":5,"count":1}]	9132	delivery	5	13
23267	2020-01-11 00:26:27	2020-01-11	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	9078	pick-up	0	34
23268	2020-01-11 00:33:12	2020-01-11	17	[{"id_menu":4,"count":1}]	9080	delivery	5	22
23269	2020-01-11 00:41:28	2020-01-11	17	[{"id_menu":4,"count":1}]	8139	delivery	5	22
23270	2020-01-11 00:43:38	2020-01-11	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	9089	delivery	5	23
23271	2020-01-11 00:45:24	2020-01-11	9	[{"id_menu":6,"count":1}]	3823	delivery	5	14
23272	2020-01-11 00:50:53	2020-01-11	17	[{"id_menu":4,"count":2}]	2452	delivery	5	22
23273	2020-01-11 00:52:23	2020-01-11	9	[{"id_menu":7,"count":1}]	3851	pick-up	0	9
23274	2020-01-11 00:57:46	2020-01-11	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	4970	delivery	5	28
23275	2020-01-11 01:08:37	2020-01-11	8	[{"id_menu":5,"count":1}]	7211	delivery	5	13
23276	2020-01-11 01:09:25	2020-01-11	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	9069	delivery	5	31
23277	2020-01-11 01:27:02	2020-01-11	14	[{"id_menu":2,"count":1}]	6516	delivery	5	19
23278	2020-01-11 01:30:04	2020-01-11	12	[{"id_menu":3,"count":1}]	9114	delivery	5	17
23279	2020-01-11 01:32:54	2020-01-11	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	239	pick-up	0	31
23280	2020-01-11 01:34:33	2020-01-11	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	9131	delivery	5	38
23281	2020-01-11 01:42:57	2020-01-11	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	9113	delivery	5	26
23282	2020-01-11 01:46:26	2020-01-11	14	[{"id_menu":2,"count":1}]	3578	pick-up	0	14
23283	2020-01-11 01:49:24	2020-01-11	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	925	delivery	5	25
23284	2020-01-11 01:55:49	2020-01-11	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	981	pick-up	0	21
23285	2020-01-11 02:11:50	2020-01-11	17	[{"id_menu":4,"count":1}]	9105	delivery	5	22
23286	2020-01-11 02:23:53	2020-01-11	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1545	pick-up	0	17
23287	2020-01-11 02:24:23	2020-01-11	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4206	pick-up	0	29
23288	2020-01-11 02:31:56	2020-01-11	9	[{"id_menu":6,"count":1}]	4931	delivery	5	14
23289	2020-01-11 02:32:39	2020-01-11	12	[{"id_menu":1,"count":1}]	1896	delivery	5	17
23290	2020-01-11 02:34:49	2020-01-11	9	[{"id_menu":6,"count":1}]	489	pick-up	0	9
23291	2020-01-11 02:35:52	2020-01-11	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8654	delivery	5	31
23292	2020-01-11 02:39:53	2020-01-11	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	9136	delivery	5	25
23293	2020-01-11 02:56:47	2020-01-11	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	4428	pick-up	0	29
23294	2020-01-11 03:05:12	2020-01-11	9	[{"id_menu":6,"count":1}]	408	delivery	5	14
23295	2020-01-11 03:11:25	2020-01-11	12	[{"id_menu":1,"count":1}]	7577	delivery	5	17
23296	2020-01-11 03:18:31	2020-01-11	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	312	pick-up	0	23
23297	2020-01-11 03:24:39	2020-01-11	17	[{"id_menu":4,"count":1}]	9086	pick-up	0	17
23298	2020-01-11 03:30:31	2020-01-11	9	[{"id_menu":7,"count":1}]	787	pick-up	0	9
23299	2020-01-11 03:36:28	2020-01-11	12	[{"id_menu":3,"count":1}]	1095	delivery	5	17
23300	2020-01-11 03:42:08	2020-01-11	8	[{"id_menu":5,"count":3}]	1780	pick-up	0	8
23301	2020-01-11 03:42:59	2020-01-11	9	[{"id_menu":7,"count":1}]	9127	delivery	5	14
23302	2020-01-11 03:59:25	2020-01-11	9	[{"id_menu":6,"count":1}]	6015	delivery	5	14
23303	2020-01-11 04:00:20	2020-01-11	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	9109	delivery	5	26
23304	2020-01-11 04:11:59	2020-01-11	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":3}]	3902	delivery	5	26
23305	2020-01-11 04:21:03	2020-01-11	9	[{"id_menu":7,"count":1}]	7086	pick-up	0	9
23306	2020-01-11 04:26:02	2020-01-11	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	9142	delivery	5	31
23307	2020-01-11 04:41:42	2020-01-11	9	[{"id_menu":6,"count":1}]	8563	delivery	5	14
23308	2020-01-11 04:53:50	2020-01-11	8	[{"id_menu":5,"count":2}]	456	delivery	5	13
23309	2020-01-11 04:57:29	2020-01-11	14	[{"id_menu":2,"count":1}]	9071	delivery	5	19
23310	2020-01-11 05:21:53	2020-01-11	12	[{"id_menu":1,"count":1}]	6202	pick-up	0	12
23311	2020-01-11 05:27:14	2020-01-11	17	[{"id_menu":4,"count":1}]	9097	pick-up	0	17
23312	2020-01-11 05:52:38	2020-01-11	12	[{"id_menu":1,"count":1}]	7815	pick-up	0	12
23313	2020-01-11 06:05:11	2020-01-11	9	[{"id_menu":7,"count":1}]	2012	delivery	5	14
23314	2020-01-11 06:09:06	2020-01-11	9	[{"id_menu":7,"count":1}]	5111	delivery	5	14
23315	2020-01-11 06:14:54	2020-01-11	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6429	delivery	5	45
23316	2020-01-11 06:21:48	2020-01-11	9	[{"id_menu":7,"count":1}]	9133	delivery	5	14
23317	2020-01-11 06:24:11	2020-01-11	14	[{"id_menu":2,"count":1}]	9116	pick-up	0	14
23318	2020-01-11 06:30:01	2020-01-11	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	9079	delivery	5	34
23319	2020-01-11 06:37:56	2020-01-11	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	4373	delivery	5	25
23320	2020-01-11 06:56:52	2020-01-11	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	191	delivery	5	22
23321	2020-01-11 07:15:07	2020-01-11	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	4469	delivery	5	22
23322	2020-01-11 07:38:24	2020-01-11	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5189	pick-up	0	26
23323	2020-01-11 07:53:28	2020-01-11	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	5265	delivery	5	31
23324	2020-01-11 07:53:51	2020-01-11	12	[{"id_menu":3,"count":1}]	4274	delivery	5	17
23325	2020-01-11 07:56:26	2020-01-11	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	9130	delivery	5	28
23326	2020-01-11 08:00:26	2020-01-11	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":2}]	9110	delivery	5	25
23327	2020-01-11 08:00:43	2020-01-11	14	[{"id_menu":2,"count":1}]	5937	pick-up	0	14
23328	2020-01-11 08:02:56	2020-01-11	8	[{"id_menu":5,"count":1}]	6062	delivery	5	13
23329	2020-01-11 08:05:17	2020-01-11	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3323	delivery	5	31
23330	2020-01-11 08:11:00	2020-01-11	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	826	pick-up	0	23
23331	2020-01-11 08:12:29	2020-01-11	12	[{"id_menu":1,"count":1}]	8462	delivery	5	17
23332	2020-01-11 08:17:43	2020-01-11	17	[{"id_menu":4,"count":1}]	9120	delivery	5	22
23333	2020-01-11 08:19:53	2020-01-11	17	[{"id_menu":4,"count":1}]	7005	delivery	5	22
23334	2020-01-11 08:20:31	2020-01-11	12	[{"id_menu":3,"count":1}]	4109	delivery	5	17
23335	2020-01-11 08:23:38	2020-01-11	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7530	delivery	5	37
23336	2020-01-11 08:32:02	2020-01-11	9	[{"id_menu":6,"count":1}]	9139	delivery	5	14
23337	2020-01-11 08:39:27	2020-01-11	17	[{"id_menu":4,"count":1}]	9073	pick-up	0	17
23338	2020-01-11 08:54:24	2020-01-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":3}]	9102	delivery	5	22
23339	2020-01-11 09:04:11	2020-01-11	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	9119	delivery	5	26
23340	2020-01-11 09:07:30	2020-01-11	9	[{"id_menu":6,"count":1}]	9095	delivery	5	14
23341	2020-01-11 09:10:44	2020-01-11	9	[{"id_menu":7,"count":1}]	5591	delivery	5	14
23342	2020-01-11 09:13:00	2020-01-11	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8980	delivery	5	35
23343	2020-01-11 09:14:24	2020-01-11	12	[{"id_menu":1,"count":1}]	2368	pick-up	0	12
23344	2020-01-11 09:17:03	2020-01-11	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9101	delivery	5	39
23345	2020-01-11 09:20:32	2020-01-11	14	[{"id_menu":2,"count":1}]	8700	delivery	5	19
23346	2020-01-11 09:24:24	2020-01-11	9	[{"id_menu":7,"count":1}]	3679	delivery	5	14
23347	2020-01-11 09:26:56	2020-01-11	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	7574	pick-up	0	21
23348	2020-01-11 09:33:29	2020-01-11	14	[{"id_menu":2,"count":2}]	4124	delivery	5	19
23349	2020-01-11 09:47:36	2020-01-11	8	[{"id_menu":5,"count":1}]	4674	delivery	5	13
23350	2020-01-11 09:58:54	2020-01-11	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	1568	pick-up	0	21
23351	2020-01-11 10:01:36	2020-01-11	12	[{"id_menu":3,"count":1}]	9100	delivery	5	17
23352	2020-01-11 10:06:26	2020-01-11	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3045	pick-up	0	38
23353	2020-01-11 10:06:27	2020-01-11	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7518	delivery	5	31
23354	2020-01-11 10:08:08	2020-01-11	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	9125	delivery	5	36
23355	2020-01-11 10:08:48	2020-01-11	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	9077	delivery	5	31
23356	2020-01-11 10:15:12	2020-01-11	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	9128	pick-up	0	52
23357	2020-01-11 10:20:33	2020-01-11	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9098	delivery	5	51
23358	2020-01-11 10:20:55	2020-01-11	43	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	9123	delivery	5	48
23359	2020-01-11 10:21:35	2020-01-11	12	[{"id_menu":3,"count":1}]	4463	pick-up	0	12
23360	2020-01-11 10:39:34	2020-01-11	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3006	delivery	5	54
23361	2020-01-11 10:53:11	2020-01-11	12	[{"id_menu":3,"count":1}]	9087	delivery	5	17
23362	2020-01-11 11:02:23	2020-01-11	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9140	delivery	5	37
23363	2020-01-11 11:04:21	2020-01-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7092	delivery	5	22
23364	2020-01-11 11:07:48	2020-01-11	9	[{"id_menu":7,"count":1}]	9144	delivery	5	14
23365	2020-01-11 11:18:08	2020-01-11	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1880	delivery	5	29
23366	2020-01-11 11:20:01	2020-01-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9075	delivery	5	28
23367	2020-01-11 11:35:58	2020-01-11	14	[{"id_menu":2,"count":1}]	1243	pick-up	0	14
23368	2020-01-11 11:37:27	2020-01-11	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9137	pick-up	0	32
23369	2020-01-11 11:38:11	2020-01-11	17	[{"id_menu":4,"count":2}]	5806	delivery	5	22
23370	2020-01-11 11:49:27	2020-01-11	9	[{"id_menu":7,"count":1}]	5558	delivery	5	14
23371	2020-01-11 11:57:44	2020-01-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3129	delivery	5	22
23372	2020-01-11 11:58:25	2020-01-11	14	[{"id_menu":2,"count":1}]	9115	pick-up	0	14
23373	2020-01-11 12:08:48	2020-01-11	9	[{"id_menu":7,"count":1}]	6591	pick-up	0	9
23374	2020-01-11 12:08:51	2020-01-11	17	[{"id_menu":4,"count":1}]	7186	delivery	5	22
23375	2020-01-11 12:11:04	2020-01-11	9	[{"id_menu":6,"count":1}]	9082	delivery	5	14
23376	2020-01-11 12:17:01	2020-01-11	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4294	delivery	5	22
23377	2020-01-11 12:17:56	2020-01-11	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3964	delivery	5	30
23378	2020-01-11 12:25:40	2020-01-11	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1076	pick-up	0	26
23379	2020-01-11 12:50:40	2020-01-11	9	[{"id_menu":7,"count":1}]	9141	delivery	5	14
23380	2020-01-11 12:50:50	2020-01-11	12	[{"id_menu":3,"count":1}]	9076	delivery	5	17
23381	2020-01-11 12:51:59	2020-01-11	9	[{"id_menu":6,"count":1}]	6511	delivery	5	14
23382	2020-01-11 13:01:13	2020-01-11	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	5984	delivery	5	34
23383	2020-01-11 13:07:30	2020-01-11	14	[{"id_menu":2,"count":1}]	3529	delivery	5	19
23384	2020-01-11 13:21:55	2020-01-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7465	delivery	5	22
23385	2020-01-11 13:25:10	2020-01-11	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4054	pick-up	0	31
23386	2020-01-11 13:28:42	2020-01-11	12	[{"id_menu":1,"count":1}]	6586	delivery	5	17
23387	2020-01-11 13:37:12	2020-01-11	12	[{"id_menu":3,"count":1}]	9117	delivery	5	17
23388	2020-01-11 13:37:59	2020-01-11	9	[{"id_menu":7,"count":1}]	9067	delivery	5	14
23389	2020-01-11 13:41:22	2020-01-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9124	delivery	5	23
23390	2020-01-11 13:41:38	2020-01-11	17	[{"id_menu":4,"count":1}]	420	pick-up	0	17
23391	2020-01-11 13:46:04	2020-01-11	14	[{"id_menu":2,"count":1}]	2333	pick-up	0	14
23392	2020-01-11 13:51:54	2020-01-11	9	[{"id_menu":6,"count":1}]	9091	delivery	5	14
23393	2020-01-11 13:55:11	2020-01-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	9074	pick-up	0	23
23394	2020-01-11 14:31:38	2020-01-11	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	9135	delivery	5	26
23395	2020-01-11 14:37:58	2020-01-11	12	[{"id_menu":3,"count":1}]	3447	delivery	5	17
23396	2020-01-11 14:42:55	2020-01-11	17	[{"id_menu":4,"count":1}]	701	pick-up	0	17
23397	2020-01-11 14:43:48	2020-01-11	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	586	pick-up	0	26
23398	2020-01-11 14:54:53	2020-01-11	9	[{"id_menu":6,"count":1}]	9112	delivery	5	14
23399	2020-01-11 15:03:59	2020-01-11	9	[{"id_menu":6,"count":1}]	7038	pick-up	0	9
23400	2020-01-11 15:13:36	2020-01-11	8	[{"id_menu":5,"count":1}]	6035	pick-up	0	8
23401	2020-01-11 15:30:29	2020-01-11	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	9064	delivery	5	40
23402	2020-01-11 15:31:19	2020-01-11	9	[{"id_menu":6,"count":1}]	8548	delivery	5	14
23403	2020-01-11 15:37:53	2020-01-11	9	[{"id_menu":6,"count":1}]	7613	delivery	5	14
23404	2020-01-11 15:39:26	2020-01-11	12	[{"id_menu":3,"count":1}]	71	pick-up	0	12
23405	2020-01-11 15:47:44	2020-01-11	9	[{"id_menu":6,"count":1}]	9106	pick-up	0	9
23406	2020-01-11 15:48:48	2020-01-11	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	9103	delivery	5	31
23407	2020-01-11 15:49:24	2020-01-11	8	[{"id_menu":5,"count":1}]	9108	delivery	5	13
23408	2020-01-11 15:59:44	2020-01-11	8	[{"id_menu":5,"count":1}]	9107	delivery	5	13
23409	2020-01-11 16:02:02	2020-01-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3268	delivery	5	22
23410	2020-01-11 16:08:29	2020-01-11	9	[{"id_menu":7,"count":1}]	170	pick-up	0	9
23411	2020-01-11 16:09:49	2020-01-11	9	[{"id_menu":6,"count":1}]	9121	delivery	5	14
23412	2020-01-11 16:17:30	2020-01-11	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	2691	pick-up	0	24
23413	2020-01-11 16:20:56	2020-01-11	12	[{"id_menu":1,"count":1}]	6550	delivery	5	17
23414	2020-01-11 16:26:29	2020-01-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	5146	delivery	5	22
23415	2020-01-11 16:27:25	2020-01-11	9	[{"id_menu":6,"count":1}]	5125	pick-up	0	9
23416	2020-01-11 16:29:51	2020-01-11	9	[{"id_menu":7,"count":1}]	6647	pick-up	0	9
23417	2020-01-11 16:32:12	2020-01-11	8	[{"id_menu":5,"count":1}]	6639	pick-up	0	8
23418	2020-01-11 16:38:54	2020-01-11	12	[{"id_menu":1,"count":1}]	9093	pick-up	0	12
23419	2020-01-11 16:42:18	2020-01-11	17	[{"id_menu":4,"count":1}]	1085	pick-up	0	17
23420	2020-01-11 16:43:49	2020-01-11	8	[{"id_menu":5,"count":1}]	6678	delivery	5	13
23421	2020-01-11 16:51:07	2020-01-11	8	[{"id_menu":5,"count":1}]	9094	delivery	5	13
23422	2020-01-11 17:00:32	2020-01-11	14	[{"id_menu":2,"count":1}]	7912	delivery	5	19
23423	2020-01-11 17:02:14	2020-01-11	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	9143	delivery	5	31
23424	2020-01-11 17:08:17	2020-01-11	12	[{"id_menu":1,"count":1}]	9061	delivery	5	17
23425	2020-01-11 17:11:05	2020-01-11	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	5935	delivery	5	27
23426	2020-01-11 17:11:40	2020-01-11	9	[{"id_menu":7,"count":1}]	5044	delivery	5	14
23427	2020-01-11 17:12:54	2020-01-11	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3442	pick-up	0	29
23428	2020-01-11 17:13:51	2020-01-11	9	[{"id_menu":6,"count":1}]	3240	delivery	5	14
23429	2020-01-11 17:14:42	2020-01-11	9	[{"id_menu":6,"count":1}]	2658	delivery	5	14
23430	2020-01-11 17:25:13	2020-01-11	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	7098	pick-up	0	22
23431	2020-01-11 17:27:15	2020-01-11	9	[{"id_menu":7,"count":1}]	3778	delivery	5	14
23432	2020-01-11 17:31:11	2020-01-11	9	[{"id_menu":7,"count":1}]	6496	delivery	5	14
23433	2020-01-11 17:31:56	2020-01-11	12	[{"id_menu":3,"count":1}]	8123	pick-up	0	12
23434	2020-01-11 17:40:53	2020-01-11	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	76	delivery	5	29
23435	2020-01-11 18:04:25	2020-01-11	14	[{"id_menu":2,"count":1}]	1317	delivery	5	19
23436	2020-01-11 18:07:58	2020-01-11	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9065	pick-up	0	34
23437	2020-01-11 18:09:53	2020-01-11	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	5272	delivery	5	22
23438	2020-01-11 18:21:34	2020-01-11	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4902	delivery	5	31
23439	2020-01-11 18:26:45	2020-01-11	9	[{"id_menu":6,"count":1}]	6512	pick-up	0	9
23440	2020-01-11 18:31:59	2020-01-11	12	[{"id_menu":3,"count":1}]	5006	delivery	5	17
23441	2020-01-11 18:35:23	2020-01-11	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4050	pick-up	0	37
23442	2020-01-11 18:52:15	2020-01-11	9	[{"id_menu":6,"count":1}]	8574	pick-up	0	9
23443	2020-01-11 19:07:24	2020-01-11	12	[{"id_menu":3,"count":1}]	2631	pick-up	0	12
23444	2020-01-11 19:08:36	2020-01-11	9	[{"id_menu":7,"count":2}]	4529	pick-up	0	9
23445	2020-01-11 19:13:59	2020-01-11	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	9081	delivery	5	34
23446	2020-01-11 19:20:41	2020-01-11	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2032	pick-up	0	17
23447	2020-01-11 19:42:37	2020-01-11	8	[{"id_menu":5,"count":1}]	7204	delivery	5	13
23448	2020-01-11 19:43:31	2020-01-11	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	5892	delivery	5	25
23449	2020-01-11 19:47:56	2020-01-11	12	[{"id_menu":1,"count":1}]	2065	pick-up	0	12
23450	2020-01-11 19:51:54	2020-01-11	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9063	delivery	5	39
23451	2020-01-11 19:53:40	2020-01-11	17	[{"id_menu":4,"count":1}]	6630	delivery	5	22
23452	2020-01-11 19:58:11	2020-01-11	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9092	delivery	5	30
23453	2020-01-11 20:06:18	2020-01-11	14	[{"id_menu":2,"count":1}]	231	delivery	5	19
23454	2020-01-11 20:06:30	2020-01-11	12	[{"id_menu":3,"count":1}]	8448	delivery	5	17
23455	2020-01-11 20:25:53	2020-01-11	9	[{"id_menu":6,"count":1}]	2592	delivery	5	14
23456	2020-01-11 20:28:12	2020-01-11	9	[{"id_menu":6,"count":1}]	9122	delivery	5	14
23457	2020-01-11 20:28:29	2020-01-11	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	9111	pick-up	0	22
23458	2020-01-11 20:35:06	2020-01-11	8	[{"id_menu":5,"count":1}]	9134	delivery	5	13
23459	2020-01-11 20:38:21	2020-01-11	12	[{"id_menu":1,"count":1}]	5160	pick-up	0	12
23460	2020-01-11 20:40:53	2020-01-11	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1938	pick-up	0	29
23461	2020-01-11 20:41:27	2020-01-11	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6857	delivery	5	36
23462	2020-01-11 20:43:00	2020-01-11	9	[{"id_menu":6,"count":1}]	3705	delivery	5	14
23463	2020-01-11 20:44:09	2020-01-11	17	[{"id_menu":4,"count":1}]	9085	pick-up	0	17
23464	2020-01-11 20:52:46	2020-01-11	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	8016	delivery	5	31
23465	2020-01-11 20:53:06	2020-01-11	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8332	delivery	5	40
23466	2020-01-11 20:58:17	2020-01-11	9	[{"id_menu":6,"count":1}]	3688	delivery	5	14
23467	2020-01-11 20:59:19	2020-01-11	9	[{"id_menu":7,"count":1}]	8543	delivery	5	14
23468	2020-01-11 21:00:44	2020-01-11	14	[{"id_menu":2,"count":1}]	9062	delivery	5	19
23469	2020-01-11 21:16:29	2020-01-11	14	[{"id_menu":2,"count":1}]	9096	delivery	5	19
23470	2020-01-11 21:28:29	2020-01-11	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4154	delivery	5	35
23471	2020-01-11 21:29:52	2020-01-11	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7679	delivery	5	31
23472	2020-01-11 21:37:09	2020-01-11	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	4966	delivery	5	26
23473	2020-01-11 22:00:50	2020-01-11	9	[{"id_menu":6,"count":1}]	9138	pick-up	0	9
23474	2020-01-11 22:01:58	2020-01-11	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3629	delivery	5	39
23475	2020-01-11 22:10:28	2020-01-11	12	[{"id_menu":3,"count":1}]	3117	delivery	5	17
23476	2020-01-11 22:11:30	2020-01-11	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	356	delivery	5	26
23477	2020-01-11 22:12:39	2020-01-11	9	[{"id_menu":6,"count":1}]	1800	pick-up	0	9
23478	2020-01-11 22:18:33	2020-01-11	9	[{"id_menu":6,"count":1}]	9129	delivery	5	14
23479	2020-01-11 22:28:20	2020-01-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9099	delivery	5	28
23480	2020-01-11 22:31:48	2020-01-11	17	[{"id_menu":4,"count":1}]	9126	delivery	5	22
23481	2020-01-11 22:49:27	2020-01-11	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	4190	delivery	5	40
23482	2020-01-11 22:50:24	2020-01-11	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1582	pick-up	0	23
23483	2020-01-11 22:51:13	2020-01-11	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	9072	delivery	5	40
23484	2020-01-11 23:05:14	2020-01-11	9	[{"id_menu":6,"count":1}]	166	pick-up	0	9
23485	2020-01-11 23:06:22	2020-01-11	9	[{"id_menu":7,"count":1}]	8081	pick-up	0	9
23486	2020-01-11 23:08:42	2020-01-11	9	[{"id_menu":6,"count":1}]	8062	delivery	5	14
23487	2020-01-11 23:24:24	2020-01-11	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4682	delivery	5	26
23488	2020-01-11 23:37:19	2020-01-11	9	[{"id_menu":6,"count":1}]	3883	delivery	5	14
23489	2020-01-11 23:41:22	2020-01-11	9	[{"id_menu":7,"count":1}]	6721	pick-up	0	9
23490	2020-01-11 23:52:22	2020-01-11	9	[{"id_menu":6,"count":1}]	7688	pick-up	0	9
23491	2020-01-11 23:52:35	2020-01-11	14	[{"id_menu":2,"count":1}]	9084	delivery	5	19
23492	2020-01-11 23:56:58	2020-01-11	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9118	delivery	5	22
23493	2020-01-11 23:58:23	2020-01-11	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	9090	delivery	5	25
23494	2020-01-11 23:59:02	2020-01-11	8	[{"id_menu":5,"count":1}]	3956	delivery	5	13
23495	2020-01-12 00:00:14	2020-01-12	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	9178	pick-up	0	26
23496	2020-01-12 00:04:15	2020-01-12	9	[{"id_menu":7,"count":1}]	9197	delivery	5	14
23497	2020-01-12 00:04:26	2020-01-12	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1255	pick-up	0	43
23498	2020-01-12 00:11:29	2020-01-12	12	[{"id_menu":3,"count":1}]	5558	delivery	5	17
23499	2020-01-12 00:26:47	2020-01-12	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9146	delivery	5	36
23500	2020-01-12 00:29:42	2020-01-12	8	[{"id_menu":5,"count":1}]	184	delivery	5	13
23501	2020-01-12 00:30:34	2020-01-12	12	[{"id_menu":1,"count":1}]	27	delivery	5	17
23502	2020-01-12 00:31:40	2020-01-12	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9222	delivery	5	36
23503	2020-01-12 00:44:47	2020-01-12	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2276	pick-up	0	31
23504	2020-01-12 00:46:08	2020-01-12	8	[{"id_menu":5,"count":1}]	9195	delivery	5	13
23505	2020-01-12 01:09:25	2020-01-12	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	9181	delivery	5	25
23506	2020-01-12 01:17:42	2020-01-12	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	5795	pick-up	0	22
23507	2020-01-12 01:19:48	2020-01-12	9	[{"id_menu":7,"count":1}]	7736	delivery	5	14
23508	2020-01-12 01:22:56	2020-01-12	14	[{"id_menu":2,"count":1}]	911	pick-up	0	14
23509	2020-01-12 01:23:25	2020-01-12	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4347	delivery	5	36
23510	2020-01-12 01:24:25	2020-01-12	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9179	delivery	5	39
23511	2020-01-12 01:24:27	2020-01-12	38	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9213	delivery	5	43
23512	2020-01-12 01:27:42	2020-01-12	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	9155	delivery	5	30
23513	2020-01-12 01:33:17	2020-01-12	9	[{"id_menu":7,"count":1}]	1263	pick-up	0	9
23514	2020-01-12 01:47:16	2020-01-12	12	[{"id_menu":1,"count":1}]	9151	delivery	5	17
23515	2020-01-12 01:49:50	2020-01-12	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9163	delivery	5	31
23516	2020-01-12 02:01:58	2020-01-12	9	[{"id_menu":6,"count":1}]	5642	pick-up	0	9
23517	2020-01-12 02:03:47	2020-01-12	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9162	delivery	5	31
23518	2020-01-12 02:04:37	2020-01-12	17	[{"id_menu":4,"count":1}]	9147	delivery	5	22
23519	2020-01-12 02:09:15	2020-01-12	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	654	pick-up	0	26
23520	2020-01-12 02:18:35	2020-01-12	14	[{"id_menu":2,"count":1}]	6987	pick-up	0	14
23521	2020-01-12 02:18:37	2020-01-12	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	3241	pick-up	0	29
23522	2020-01-12 02:23:56	2020-01-12	12	[{"id_menu":3,"count":1}]	5561	delivery	5	17
23523	2020-01-12 02:24:48	2020-01-12	17	[{"id_menu":4,"count":2}]	2054	pick-up	0	17
23524	2020-01-12 02:34:29	2020-01-12	12	[{"id_menu":3,"count":1}]	9235	delivery	5	17
23525	2020-01-12 02:42:41	2020-01-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4120	pick-up	0	23
23526	2020-01-12 02:45:40	2020-01-12	14	[{"id_menu":2,"count":1}]	9191	pick-up	0	14
23527	2020-01-12 02:47:44	2020-01-12	8	[{"id_menu":5,"count":1}]	1626	delivery	5	13
23528	2020-01-12 02:49:22	2020-01-12	14	[{"id_menu":2,"count":1}]	2885	delivery	5	19
23529	2020-01-12 02:57:05	2020-01-12	9	[{"id_menu":7,"count":1}]	3403	delivery	5	14
23530	2020-01-12 03:08:25	2020-01-12	17	[{"id_menu":4,"count":1}]	9200	pick-up	0	17
23531	2020-01-12 03:10:11	2020-01-12	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	2404	delivery	5	28
23532	2020-01-12 03:17:02	2020-01-12	9	[{"id_menu":6,"count":2}]	6737	delivery	5	14
23533	2020-01-12 03:21:39	2020-01-12	9	[{"id_menu":7,"count":2}]	9201	delivery	5	14
23534	2020-01-12 03:21:57	2020-01-12	12	[{"id_menu":3,"count":1}]	9188	delivery	5	17
23535	2020-01-12 03:34:15	2020-01-12	12	[{"id_menu":3,"count":1}]	3021	delivery	5	17
23536	2020-01-12 03:35:19	2020-01-12	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	5891	delivery	5	36
23537	2020-01-12 03:37:21	2020-01-12	9	[{"id_menu":6,"count":1}]	9174	delivery	5	14
23538	2020-01-12 03:41:45	2020-01-12	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	9152	delivery	5	31
23539	2020-01-12 03:41:50	2020-01-12	17	[{"id_menu":4,"count":1}]	9215	delivery	5	22
23540	2020-01-12 03:43:17	2020-01-12	8	[{"id_menu":5,"count":1}]	3659	pick-up	0	8
23541	2020-01-12 03:44:12	2020-01-12	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	517	pick-up	0	21
23542	2020-01-12 03:45:54	2020-01-12	9	[{"id_menu":6,"count":1}]	9220	pick-up	0	9
23543	2020-01-12 03:50:17	2020-01-12	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	9198	pick-up	0	20
23544	2020-01-12 03:50:17	2020-01-12	9	[{"id_menu":7,"count":1}]	4887	delivery	5	14
23545	2020-01-12 03:51:56	2020-01-12	9	[{"id_menu":6,"count":1}]	2473	delivery	5	14
23546	2020-01-12 03:54:31	2020-01-12	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	9218	delivery	5	25
23547	2020-01-12 03:55:32	2020-01-12	9	[{"id_menu":6,"count":1}]	9160	delivery	5	14
23548	2020-01-12 03:58:17	2020-01-12	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1306	pick-up	0	29
23549	2020-01-12 04:04:12	2020-01-12	8	[{"id_menu":5,"count":1}]	9223	delivery	5	13
23550	2020-01-12 04:08:44	2020-01-12	14	[{"id_menu":2,"count":1}]	9238	delivery	5	19
23551	2020-01-12 04:10:11	2020-01-12	14	[{"id_menu":2,"count":1}]	9187	delivery	5	19
23552	2020-01-12 04:40:20	2020-01-12	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	5134	pick-up	0	21
23553	2020-01-12 04:42:27	2020-01-12	12	[{"id_menu":1,"count":1}]	3925	pick-up	0	12
23554	2020-01-12 04:45:18	2020-01-12	8	[{"id_menu":5,"count":1}]	4831	delivery	5	13
23555	2020-01-12 04:47:51	2020-01-12	12	[{"id_menu":3,"count":1}]	2980	delivery	5	17
23556	2020-01-12 04:54:31	2020-01-12	9	[{"id_menu":7,"count":1}]	66	pick-up	0	9
23557	2020-01-12 04:56:15	2020-01-12	12	[{"id_menu":3,"count":1}]	9175	delivery	5	17
23558	2020-01-12 05:03:15	2020-01-12	9	[{"id_menu":7,"count":1}]	868	delivery	5	14
23559	2020-01-12 05:03:15	2020-01-12	12	[{"id_menu":3,"count":1}]	2745	delivery	5	17
23560	2020-01-12 05:23:40	2020-01-12	8	[{"id_menu":5,"count":1}]	9193	pick-up	0	8
23561	2020-01-12 05:28:18	2020-01-12	9	[{"id_menu":6,"count":1}]	6950	delivery	5	14
23562	2020-01-12 05:32:48	2020-01-12	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	4069	delivery	5	39
23563	2020-01-12 05:33:24	2020-01-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8813	delivery	5	22
23564	2020-01-12 05:43:02	2020-01-12	9	[{"id_menu":7,"count":1}]	7051	pick-up	0	9
23565	2020-01-12 05:47:31	2020-01-12	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	9168	delivery	5	40
23566	2020-01-12 05:48:25	2020-01-12	8	[{"id_menu":5,"count":1}]	1258	pick-up	0	8
23567	2020-01-12 05:58:46	2020-01-12	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	9204	pick-up	0	26
23568	2020-01-12 06:15:46	2020-01-12	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	8397	delivery	5	31
23569	2020-01-12 06:19:10	2020-01-12	14	[{"id_menu":2,"count":1}]	2799	pick-up	0	14
23570	2020-01-12 06:31:12	2020-01-12	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	931	pick-up	0	25
23571	2020-01-12 06:32:44	2020-01-12	17	[{"id_menu":4,"count":1}]	678	delivery	5	22
23572	2020-01-12 06:40:19	2020-01-12	17	[{"id_menu":4,"count":1}]	9177	pick-up	0	17
23573	2020-01-12 06:40:48	2020-01-12	12	[{"id_menu":1,"count":1}]	122	delivery	5	17
23574	2020-01-12 06:45:19	2020-01-12	9	[{"id_menu":7,"count":1}]	6536	delivery	5	14
23575	2020-01-12 06:47:25	2020-01-12	12	[{"id_menu":3,"count":1}]	9225	pick-up	0	12
23576	2020-01-12 06:49:43	2020-01-12	9	[{"id_menu":6,"count":1}]	4655	delivery	5	14
23577	2020-01-12 06:52:47	2020-01-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9232	delivery	5	22
23578	2020-01-12 06:53:27	2020-01-12	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	9212	delivery	5	43
23579	2020-01-12 06:58:24	2020-01-12	9	[{"id_menu":6,"count":1}]	9185	delivery	5	14
23580	2020-01-12 07:04:33	2020-01-12	12	[{"id_menu":1,"count":1}]	482	delivery	5	17
23581	2020-01-12 07:06:57	2020-01-12	8	[{"id_menu":5,"count":1}]	126	pick-up	0	8
23582	2020-01-12 07:20:33	2020-01-12	8	[{"id_menu":5,"count":1}]	4918	pick-up	0	8
23583	2020-01-12 07:22:21	2020-01-12	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2317	delivery	5	31
23584	2020-01-12 07:27:20	2020-01-12	14	[{"id_menu":2,"count":1}]	5538	pick-up	0	14
23585	2020-01-12 07:37:35	2020-01-12	17	[{"id_menu":4,"count":1}]	9227	delivery	5	22
23586	2020-01-12 07:42:48	2020-01-12	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	9221	delivery	5	25
23587	2020-01-12 07:47:43	2020-01-12	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2783	pick-up	0	29
23588	2020-01-12 07:54:39	2020-01-12	14	[{"id_menu":2,"count":1}]	3106	delivery	5	19
23589	2020-01-12 07:56:49	2020-01-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9207	delivery	5	22
23590	2020-01-12 07:56:56	2020-01-12	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7458	delivery	5	36
23591	2020-01-12 08:11:01	2020-01-12	12	[{"id_menu":3,"count":1}]	9180	delivery	5	17
23592	2020-01-12 08:16:03	2020-01-12	12	[{"id_menu":3,"count":1}]	9158	delivery	5	17
23593	2020-01-12 08:16:37	2020-01-12	14	[{"id_menu":2,"count":1}]	2771	delivery	5	19
23594	2020-01-12 08:16:53	2020-01-12	9	[{"id_menu":6,"count":1}]	466	delivery	5	14
23595	2020-01-12 08:31:49	2020-01-12	14	[{"id_menu":2,"count":1}]	9237	delivery	5	19
23596	2020-01-12 08:46:59	2020-01-12	9	[{"id_menu":7,"count":1}]	932	delivery	5	14
23597	2020-01-12 08:47:07	2020-01-12	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	9186	delivery	5	28
23598	2020-01-12 08:50:59	2020-01-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3744	delivery	5	28
23599	2020-01-12 08:54:47	2020-01-12	9	[{"id_menu":6,"count":1}]	9190	delivery	5	14
23600	2020-01-12 09:10:26	2020-01-12	12	[{"id_menu":1,"count":1}]	2401	pick-up	0	12
23601	2020-01-12 09:17:08	2020-01-12	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	440	delivery	5	40
23602	2020-01-12 09:23:52	2020-01-12	8	[{"id_menu":5,"count":1}]	1562	pick-up	0	8
23603	2020-01-12 09:28:10	2020-01-12	17	[{"id_menu":4,"count":1}]	4929	pick-up	0	17
23604	2020-01-12 09:29:58	2020-01-12	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	585	delivery	5	22
23605	2020-01-12 09:33:23	2020-01-12	8	[{"id_menu":5,"count":1}]	5786	delivery	5	13
23606	2020-01-12 09:37:02	2020-01-12	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	5099	pick-up	0	31
23607	2020-01-12 09:38:11	2020-01-12	14	[{"id_menu":2,"count":1}]	9239	delivery	5	19
23608	2020-01-12 09:47:37	2020-01-12	9	[{"id_menu":6,"count":1}]	9243	delivery	5	14
23609	2020-01-12 10:03:16	2020-01-12	17	[{"id_menu":4,"count":1}]	7118	delivery	5	22
23610	2020-01-12 10:25:07	2020-01-12	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	360	pick-up	0	35
23611	2020-01-12 10:28:47	2020-01-12	9	[{"id_menu":6,"count":1}]	9216	pick-up	0	9
23612	2020-01-12 10:33:18	2020-01-12	9	[{"id_menu":6,"count":1}]	6959	delivery	5	14
23613	2020-01-12 10:33:51	2020-01-12	12	[{"id_menu":1,"count":1}]	9214	delivery	5	17
23614	2020-01-12 10:34:25	2020-01-12	8	[{"id_menu":5,"count":1}]	9153	delivery	5	13
23615	2020-01-12 10:48:07	2020-01-12	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	5237	delivery	5	26
23616	2020-01-12 10:49:54	2020-01-12	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	9219	delivery	5	43
23617	2020-01-12 10:50:24	2020-01-12	9	[{"id_menu":6,"count":1}]	2906	delivery	5	14
23618	2020-01-12 10:52:40	2020-01-12	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	9196	delivery	5	26
23619	2020-01-12 10:56:08	2020-01-12	9	[{"id_menu":6,"count":1}]	1867	pick-up	0	9
23620	2020-01-12 10:57:45	2020-01-12	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	9161	delivery	5	40
23621	2020-01-12 10:58:30	2020-01-12	9	[{"id_menu":6,"count":1}]	1060	pick-up	0	9
23622	2020-01-12 10:59:08	2020-01-12	17	[{"id_menu":4,"count":1}]	2310	pick-up	0	17
23623	2020-01-12 11:03:43	2020-01-12	9	[{"id_menu":6,"count":1}]	1221	pick-up	0	9
23624	2020-01-12 11:18:17	2020-01-12	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7742	delivery	5	45
23625	2020-01-12 11:22:43	2020-01-12	9	[{"id_menu":7,"count":1}]	6221	delivery	5	14
23626	2020-01-12 11:30:46	2020-01-12	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	150	pick-up	0	21
23627	2020-01-12 11:41:00	2020-01-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9154	pick-up	0	17
23628	2020-01-12 11:46:18	2020-01-12	9	[{"id_menu":7,"count":1}]	9176	delivery	5	14
23629	2020-01-12 11:49:33	2020-01-12	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	8660	delivery	5	38
23630	2020-01-12 11:51:22	2020-01-12	12	[{"id_menu":3,"count":1}]	3529	pick-up	0	12
23631	2020-01-12 11:59:43	2020-01-12	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9203	delivery	5	54
23632	2020-01-12 12:03:25	2020-01-12	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5724	delivery	5	36
23633	2020-01-12 12:06:45	2020-01-12	17	[{"id_menu":4,"count":1}]	1537	pick-up	0	17
23634	2020-01-12 12:11:54	2020-01-12	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":2}]	9208	delivery	5	28
23635	2020-01-12 12:13:55	2020-01-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1387	pick-up	0	23
23636	2020-01-12 12:14:13	2020-01-12	12	[{"id_menu":1,"count":1}]	9240	delivery	5	17
23637	2020-01-12 12:15:54	2020-01-12	9	[{"id_menu":7,"count":1}]	2107	delivery	5	14
23638	2020-01-12 12:22:16	2020-01-12	9	[{"id_menu":7,"count":1}]	7633	delivery	5	14
23639	2020-01-12 12:28:24	2020-01-12	8	[{"id_menu":5,"count":1}]	3968	pick-up	0	8
23640	2020-01-12 12:31:19	2020-01-12	8	[{"id_menu":5,"count":1}]	9231	pick-up	0	8
23641	2020-01-12 13:05:14	2020-01-12	12	[{"id_menu":3,"count":1}]	9226	delivery	5	17
23642	2020-01-12 13:16:12	2020-01-12	9	[{"id_menu":7,"count":2}]	4484	pick-up	0	9
23643	2020-01-12 13:20:15	2020-01-12	8	[{"id_menu":5,"count":1}]	9169	delivery	5	13
23644	2020-01-12 13:22:00	2020-01-12	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3811	delivery	5	31
23645	2020-01-12 13:30:26	2020-01-12	9	[{"id_menu":6,"count":1}]	1205	pick-up	0	9
23646	2020-01-12 13:34:26	2020-01-12	9	[{"id_menu":6,"count":1}]	7261	delivery	5	14
23647	2020-01-12 13:39:17	2020-01-12	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	7537	delivery	5	31
23648	2020-01-12 13:39:58	2020-01-12	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	9206	delivery	5	43
23649	2020-01-12 13:42:52	2020-01-12	9	[{"id_menu":6,"count":1}]	2127	delivery	5	14
23650	2020-01-12 14:16:14	2020-01-12	17	[{"id_menu":4,"count":1}]	3250	delivery	5	22
23651	2020-01-12 14:25:27	2020-01-12	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	9171	pick-up	0	31
23652	2020-01-12 14:25:49	2020-01-12	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	9217	delivery	5	43
23653	2020-01-12 14:36:29	2020-01-12	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9150	delivery	5	42
23654	2020-01-12 14:37:06	2020-01-12	12	[{"id_menu":3,"count":1}]	9182	delivery	5	17
23655	2020-01-12 14:53:31	2020-01-12	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9194	delivery	5	54
23656	2020-01-12 15:14:54	2020-01-12	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6705	delivery	5	22
23657	2020-01-12 15:37:58	2020-01-12	9	[{"id_menu":7,"count":1}]	3711	delivery	5	14
23658	2020-01-12 15:52:53	2020-01-12	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9210	delivery	5	51
23659	2020-01-12 15:52:55	2020-01-12	9	[{"id_menu":6,"count":1}]	9236	delivery	5	14
23660	2020-01-12 15:54:19	2020-01-12	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	8570	delivery	5	26
23661	2020-01-12 15:59:33	2020-01-12	17	[{"id_menu":4,"count":1}]	1627	pick-up	0	17
23662	2020-01-12 16:02:41	2020-01-12	17	[{"id_menu":4,"count":1}]	9233	delivery	5	22
23663	2020-01-12 16:09:07	2020-01-12	14	[{"id_menu":2,"count":1}]	9156	delivery	5	19
23664	2020-01-12 16:32:09	2020-01-12	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	8375	delivery	5	26
23665	2020-01-12 16:43:02	2020-01-12	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	7747	delivery	5	27
23666	2020-01-12 16:45:15	2020-01-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	143	pick-up	0	23
23667	2020-01-12 16:47:58	2020-01-12	9	[{"id_menu":7,"count":1}]	9166	delivery	5	14
23668	2020-01-12 16:54:48	2020-01-12	14	[{"id_menu":2,"count":1}]	9205	delivery	5	19
23669	2020-01-12 17:06:30	2020-01-12	8	[{"id_menu":5,"count":1}]	4166	pick-up	0	8
23670	2020-01-12 17:13:55	2020-01-12	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	381	pick-up	0	38
23671	2020-01-12 17:14:42	2020-01-12	9	[{"id_menu":6,"count":1}]	4464	delivery	5	14
23672	2020-01-12 17:26:29	2020-01-12	12	[{"id_menu":3,"count":2}]	9202	pick-up	0	12
23673	2020-01-12 17:27:07	2020-01-12	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	3062	delivery	5	25
23674	2020-01-12 17:28:29	2020-01-12	14	[{"id_menu":2,"count":1}]	1677	pick-up	0	14
23675	2020-01-12 17:38:07	2020-01-12	9	[{"id_menu":7,"count":1}]	9189	delivery	5	14
23676	2020-01-12 17:41:15	2020-01-12	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	9242	delivery	5	26
23677	2020-01-12 17:42:11	2020-01-12	8	[{"id_menu":5,"count":1}]	7084	pick-up	0	8
23678	2020-01-12 17:42:26	2020-01-12	12	[{"id_menu":1,"count":1}]	5489	delivery	5	17
23679	2020-01-12 17:42:51	2020-01-12	14	[{"id_menu":2,"count":1}]	599	pick-up	0	14
23680	2020-01-12 17:45:00	2020-01-12	9	[{"id_menu":7,"count":1}]	8224	pick-up	0	9
23681	2020-01-12 17:48:07	2020-01-12	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2076	pick-up	0	31
23682	2020-01-12 17:51:25	2020-01-12	17	[{"id_menu":4,"count":1}]	9157	delivery	5	22
23683	2020-01-12 17:51:38	2020-01-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9173	pick-up	0	23
23684	2020-01-12 17:52:16	2020-01-12	14	[{"id_menu":2,"count":1}]	9192	delivery	5	19
23685	2020-01-12 17:57:12	2020-01-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9165	delivery	5	28
23686	2020-01-12 18:02:25	2020-01-12	12	[{"id_menu":3,"count":1}]	7651	pick-up	0	12
23687	2020-01-12 18:06:23	2020-01-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5903	delivery	5	28
23688	2020-01-12 18:12:51	2020-01-12	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	4034	pick-up	0	26
23689	2020-01-12 18:14:30	2020-01-12	9	[{"id_menu":7,"count":1}]	2189	delivery	5	14
23690	2020-01-12 18:28:37	2020-01-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	6769	delivery	5	31
23691	2020-01-12 18:31:44	2020-01-12	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	4523	delivery	5	28
23692	2020-01-12 18:38:24	2020-01-12	9	[{"id_menu":7,"count":1}]	9145	delivery	5	14
23693	2020-01-12 18:42:00	2020-01-12	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7358	delivery	5	42
23694	2020-01-12 18:55:01	2020-01-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4342	pick-up	0	18
23695	2020-01-12 18:56:57	2020-01-12	17	[{"id_menu":4,"count":1}]	1119	pick-up	0	17
23696	2020-01-12 18:58:56	2020-01-12	9	[{"id_menu":7,"count":1}]	9241	pick-up	0	9
23697	2020-01-12 19:05:15	2020-01-12	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	4432	delivery	5	38
23698	2020-01-12 19:09:56	2020-01-12	12	[{"id_menu":3,"count":1}]	6494	delivery	5	17
23699	2020-01-12 19:13:28	2020-01-12	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	2540	pick-up	0	21
23700	2020-01-12 19:16:26	2020-01-12	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	35	pick-up	0	26
23701	2020-01-12 19:16:49	2020-01-12	14	[{"id_menu":2,"count":1}]	9211	delivery	5	19
23702	2020-01-12 19:17:45	2020-01-12	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9184	delivery	5	42
23703	2020-01-12 19:23:09	2020-01-12	9	[{"id_menu":7,"count":2}]	9167	delivery	5	14
23704	2020-01-12 19:26:33	2020-01-12	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	9183	delivery	5	34
23705	2020-01-12 19:37:10	2020-01-12	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	4185	delivery	5	34
23706	2020-01-12 19:37:14	2020-01-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	5210	delivery	5	31
23707	2020-01-12 19:39:21	2020-01-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4646	delivery	5	31
23708	2020-01-12 19:42:01	2020-01-12	17	[{"id_menu":4,"count":1}]	4684	pick-up	0	17
23709	2020-01-12 19:45:08	2020-01-12	9	[{"id_menu":7,"count":1}]	6511	pick-up	0	9
23710	2020-01-12 19:46:06	2020-01-12	14	[{"id_menu":2,"count":1}]	3002	delivery	5	19
23711	2020-01-12 19:49:52	2020-01-12	17	[{"id_menu":4,"count":1}]	6994	delivery	5	22
23712	2020-01-12 19:56:09	2020-01-12	14	[{"id_menu":2,"count":1}]	6177	pick-up	0	14
23713	2020-01-12 19:58:04	2020-01-12	17	[{"id_menu":4,"count":1}]	3616	pick-up	0	17
23714	2020-01-12 20:06:09	2020-01-12	17	[{"id_menu":4,"count":1}]	754	delivery	5	22
23715	2020-01-12 20:08:11	2020-01-12	14	[{"id_menu":2,"count":1}]	3914	pick-up	0	14
23716	2020-01-12 20:11:20	2020-01-12	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	736	delivery	5	25
23717	2020-01-12 20:20:31	2020-01-12	17	[{"id_menu":4,"count":1}]	1934	pick-up	0	17
23718	2020-01-12 20:20:50	2020-01-12	12	[{"id_menu":1,"count":1}]	6083	pick-up	0	12
23719	2020-01-12 20:21:58	2020-01-12	12	[{"id_menu":3,"count":1}]	2725	delivery	5	17
23720	2020-01-12 20:28:12	2020-01-12	9	[{"id_menu":7,"count":1}]	9209	delivery	5	14
23721	2020-01-12 20:28:15	2020-01-12	14	[{"id_menu":2,"count":1}]	7510	pick-up	0	14
23722	2020-01-12 20:31:16	2020-01-12	8	[{"id_menu":5,"count":1}]	9148	delivery	5	13
23723	2020-01-12 20:35:20	2020-01-12	12	[{"id_menu":1,"count":1}]	3123	pick-up	0	12
23724	2020-01-12 20:37:58	2020-01-12	9	[{"id_menu":6,"count":1}]	442	pick-up	0	9
23725	2020-01-12 20:50:39	2020-01-12	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9234	delivery	5	30
23726	2020-01-12 20:59:16	2020-01-12	17	[{"id_menu":4,"count":1}]	1810	pick-up	0	17
23727	2020-01-12 21:02:50	2020-01-12	8	[{"id_menu":5,"count":1}]	5794	delivery	5	13
23728	2020-01-12 21:17:05	2020-01-12	9	[{"id_menu":7,"count":1}]	9229	delivery	5	14
23729	2020-01-12 21:24:48	2020-01-12	12	[{"id_menu":1,"count":1}]	6848	delivery	5	17
23730	2020-01-12 21:33:03	2020-01-12	12	[{"id_menu":3,"count":1}]	2197	pick-up	0	12
23731	2020-01-12 21:37:42	2020-01-12	12	[{"id_menu":3,"count":1}]	8582	delivery	5	17
23732	2020-01-12 21:48:21	2020-01-12	9	[{"id_menu":6,"count":1}]	758	delivery	5	14
23733	2020-01-12 21:49:12	2020-01-12	9	[{"id_menu":7,"count":1}]	9164	delivery	5	14
23734	2020-01-12 21:58:07	2020-01-12	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3734	delivery	5	42
23735	2020-01-12 22:17:30	2020-01-12	9	[{"id_menu":6,"count":2}]	9230	delivery	5	14
23736	2020-01-12 22:22:40	2020-01-12	9	[{"id_menu":6,"count":1}]	9228	delivery	5	14
23737	2020-01-12 22:31:40	2020-01-12	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4490	delivery	5	26
23738	2020-01-12 22:32:25	2020-01-12	9	[{"id_menu":7,"count":1}]	9	delivery	5	14
23739	2020-01-12 22:36:53	2020-01-12	9	[{"id_menu":6,"count":1}]	6469	delivery	5	14
23740	2020-01-12 22:37:01	2020-01-12	14	[{"id_menu":2,"count":1}]	5183	delivery	5	19
23741	2020-01-12 22:41:28	2020-01-12	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	5361	delivery	5	34
23742	2020-01-12 22:53:00	2020-01-12	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	9199	delivery	5	45
23743	2020-01-12 22:55:30	2020-01-12	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	5253	pick-up	0	20
23744	2020-01-12 22:58:58	2020-01-12	9	[{"id_menu":6,"count":1}]	9172	delivery	5	14
23745	2020-01-12 23:01:06	2020-01-12	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	9159	pick-up	0	20
23746	2020-01-12 23:02:15	2020-01-12	12	[{"id_menu":1,"count":1}]	772	delivery	5	17
23747	2020-01-12 23:09:05	2020-01-12	8	[{"id_menu":5,"count":1}]	321	pick-up	0	8
23748	2020-01-12 23:09:33	2020-01-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2369	delivery	5	31
23749	2020-01-12 23:13:44	2020-01-12	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	9149	delivery	5	29
23750	2020-01-12 23:15:52	2020-01-12	9	[{"id_menu":6,"count":1}]	4038	delivery	5	14
23751	2020-01-12 23:15:52	2020-01-12	14	[{"id_menu":2,"count":1}]	7190	delivery	5	19
23752	2020-01-12 23:19:01	2020-01-12	9	[{"id_menu":7,"count":3}]	8400	delivery	5	14
23753	2020-01-12 23:21:02	2020-01-12	9	[{"id_menu":6,"count":1}]	3335	pick-up	0	9
23754	2020-01-12 23:25:23	2020-01-12	17	[{"id_menu":4,"count":1}]	5953	delivery	5	22
23755	2020-01-12 23:30:50	2020-01-12	9	[{"id_menu":6,"count":1}]	3788	delivery	5	14
23756	2020-01-12 23:35:00	2020-01-12	9	[{"id_menu":6,"count":1}]	4229	delivery	5	14
23757	2020-01-12 23:36:39	2020-01-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4850	pick-up	0	18
23758	2020-01-12 23:45:02	2020-01-12	8	[{"id_menu":5,"count":1}]	1563	delivery	5	13
23759	2020-01-12 23:47:40	2020-01-12	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9170	delivery	5	48
23760	2020-01-12 23:51:30	2020-01-12	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	7624	delivery	5	34
23761	2020-01-12 23:52:28	2020-01-12	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9224	delivery	5	53
23762	2020-01-12 23:59:12	2020-01-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8108	delivery	5	23
23763	2020-01-13 00:13:44	2020-01-13	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1626	delivery	5	36
23764	2020-01-13 00:16:40	2020-01-13	12	[{"id_menu":3,"count":1}]	2954	pick-up	0	12
23765	2020-01-13 00:17:11	2020-01-13	12	[{"id_menu":3,"count":1}]	4502	delivery	5	17
23766	2020-01-13 00:29:43	2020-01-13	9	[{"id_menu":6,"count":1}]	383	delivery	5	14
23767	2020-01-13 00:36:41	2020-01-13	17	[{"id_menu":4,"count":1}]	1485	pick-up	0	17
23768	2020-01-13 00:39:30	2020-01-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2044	delivery	5	36
23769	2020-01-13 00:50:33	2020-01-13	8	[{"id_menu":5,"count":1}]	9248	delivery	5	13
23770	2020-01-13 01:18:09	2020-01-13	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3281	delivery	5	22
23771	2020-01-13 01:34:28	2020-01-13	14	[{"id_menu":2,"count":1}]	8609	delivery	5	19
23772	2020-01-13 01:57:48	2020-01-13	9	[{"id_menu":7,"count":1}]	7293	delivery	5	14
23773	2020-01-13 02:44:44	2020-01-13	21	[{"id_menu":3,"count":3},{"id_menu":7,"count":1}]	9274	delivery	5	26
23774	2020-01-13 02:48:42	2020-01-13	17	[{"id_menu":4,"count":1}]	5169	delivery	5	22
23775	2020-01-13 02:55:56	2020-01-13	12	[{"id_menu":3,"count":1}]	3494	pick-up	0	12
23776	2020-01-13 02:59:09	2020-01-13	8	[{"id_menu":5,"count":1}]	4139	delivery	5	13
23777	2020-01-13 03:22:32	2020-01-13	12	[{"id_menu":3,"count":1}]	9264	delivery	5	17
23778	2020-01-13 03:41:06	2020-01-13	8	[{"id_menu":5,"count":1}]	1321	pick-up	0	8
23779	2020-01-13 03:42:46	2020-01-13	9	[{"id_menu":7,"count":1}]	9249	delivery	5	14
23780	2020-01-13 03:47:01	2020-01-13	9	[{"id_menu":7,"count":1}]	5988	pick-up	0	9
23781	2020-01-13 04:13:08	2020-01-13	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9318	delivery	5	35
23782	2020-01-13 04:13:48	2020-01-13	9	[{"id_menu":7,"count":1}]	3640	pick-up	0	9
23783	2020-01-13 04:15:07	2020-01-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	519	pick-up	0	23
23784	2020-01-13 04:19:42	2020-01-13	14	[{"id_menu":2,"count":2}]	1510	delivery	5	19
23785	2020-01-13 04:22:57	2020-01-13	12	[{"id_menu":1,"count":1}]	1924	pick-up	0	12
23786	2020-01-13 04:28:21	2020-01-13	12	[{"id_menu":1,"count":1}]	697	pick-up	0	12
23787	2020-01-13 04:55:17	2020-01-13	9	[{"id_menu":7,"count":1}]	600	pick-up	0	9
23788	2020-01-13 04:57:51	2020-01-13	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2845	delivery	5	28
23789	2020-01-13 05:05:02	2020-01-13	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	9306	delivery	5	22
23790	2020-01-13 05:25:06	2020-01-13	9	[{"id_menu":6,"count":1}]	7804	delivery	5	14
23791	2020-01-13 05:45:19	2020-01-13	17	[{"id_menu":4,"count":1}]	1170	pick-up	0	17
23792	2020-01-13 05:52:45	2020-01-13	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	9263	delivery	5	31
23793	2020-01-13 05:53:25	2020-01-13	9	[{"id_menu":6,"count":1}]	9299	delivery	5	14
23794	2020-01-13 06:14:12	2020-01-13	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	9284	delivery	5	31
23795	2020-01-13 06:16:18	2020-01-13	9	[{"id_menu":6,"count":1}]	9246	delivery	5	14
23796	2020-01-13 06:17:12	2020-01-13	12	[{"id_menu":1,"count":1}]	2789	delivery	5	17
23797	2020-01-13 06:24:46	2020-01-13	14	[{"id_menu":2,"count":1}]	5332	pick-up	0	14
23798	2020-01-13 06:33:23	2020-01-13	8	[{"id_menu":5,"count":1}]	9269	pick-up	0	8
23799	2020-01-13 06:45:56	2020-01-13	9	[{"id_menu":6,"count":1}]	9287	delivery	5	14
23800	2020-01-13 06:52:49	2020-01-13	9	[{"id_menu":6,"count":1}]	4417	delivery	5	14
23801	2020-01-13 06:55:13	2020-01-13	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4624	pick-up	0	26
23802	2020-01-13 07:01:27	2020-01-13	8	[{"id_menu":5,"count":1}]	736	delivery	5	13
23803	2020-01-13 07:11:11	2020-01-13	17	[{"id_menu":4,"count":1}]	35	pick-up	0	17
23804	2020-01-13 07:18:45	2020-01-13	12	[{"id_menu":3,"count":1}]	3609	pick-up	0	12
23805	2020-01-13 07:19:45	2020-01-13	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	761	delivery	5	44
23806	2020-01-13 07:21:49	2020-01-13	12	[{"id_menu":1,"count":1}]	1981	delivery	5	17
23807	2020-01-13 07:22:56	2020-01-13	9	[{"id_menu":6,"count":1}]	2420	delivery	5	14
23808	2020-01-13 07:29:37	2020-01-13	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2041	pick-up	0	29
23809	2020-01-13 08:07:24	2020-01-13	12	[{"id_menu":1,"count":1}]	3703	delivery	5	17
23810	2020-01-13 08:18:40	2020-01-13	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	9290	delivery	5	26
23811	2020-01-13 08:20:02	2020-01-13	9	[{"id_menu":6,"count":1}]	9315	delivery	5	14
23812	2020-01-13 08:27:45	2020-01-13	12	[{"id_menu":3,"count":1}]	9244	delivery	5	17
23813	2020-01-13 08:48:06	2020-01-13	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	9313	delivery	5	31
23814	2020-01-13 08:49:18	2020-01-13	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	9270	delivery	5	34
23815	2020-01-13 08:55:12	2020-01-13	9	[{"id_menu":7,"count":1}]	7428	delivery	5	14
23816	2020-01-13 08:59:10	2020-01-13	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	9281	delivery	5	45
23817	2020-01-13 09:09:26	2020-01-13	17	[{"id_menu":4,"count":1}]	1092	pick-up	0	17
23818	2020-01-13 09:22:30	2020-01-13	9	[{"id_menu":7,"count":1}]	2995	delivery	5	14
23819	2020-01-13 09:28:53	2020-01-13	14	[{"id_menu":2,"count":1}]	9302	delivery	5	19
23820	2020-01-13 09:29:43	2020-01-13	12	[{"id_menu":1,"count":1}]	6470	pick-up	0	12
23821	2020-01-13 09:39:14	2020-01-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	8149	delivery	5	28
23822	2020-01-13 09:40:03	2020-01-13	8	[{"id_menu":5,"count":1}]	9122	delivery	5	13
23823	2020-01-13 10:12:43	2020-01-13	17	[{"id_menu":4,"count":1}]	9265	pick-up	0	17
23824	2020-01-13 10:15:41	2020-01-13	9	[{"id_menu":6,"count":1}]	5426	pick-up	0	9
23825	2020-01-13 10:33:13	2020-01-13	8	[{"id_menu":5,"count":1}]	5734	delivery	5	13
23826	2020-01-13 10:33:58	2020-01-13	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7378	delivery	5	22
23827	2020-01-13 10:49:44	2020-01-13	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3380	delivery	5	26
23828	2020-01-13 10:55:56	2020-01-13	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	9304	pick-up	0	24
23829	2020-01-13 11:08:33	2020-01-13	8	[{"id_menu":5,"count":1}]	7569	delivery	5	13
23830	2020-01-13 11:16:38	2020-01-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	7717	delivery	5	28
23831	2020-01-13 11:30:42	2020-01-13	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2477	pick-up	0	26
23832	2020-01-13 11:32:10	2020-01-13	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9261	delivery	5	52
23833	2020-01-13 11:32:50	2020-01-13	12	[{"id_menu":3,"count":1}]	8561	pick-up	0	12
23834	2020-01-13 11:34:56	2020-01-13	17	[{"id_menu":4,"count":1}]	5483	pick-up	0	17
23835	2020-01-13 11:49:15	2020-01-13	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	9292	delivery	5	31
23836	2020-01-13 11:49:41	2020-01-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	964	delivery	5	23
23837	2020-01-13 11:56:40	2020-01-13	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4912	delivery	5	34
23838	2020-01-13 12:03:20	2020-01-13	8	[{"id_menu":5,"count":1}]	6338	delivery	5	13
23839	2020-01-13 12:05:10	2020-01-13	9	[{"id_menu":6,"count":1}]	9256	pick-up	0	9
23840	2020-01-13 12:20:27	2020-01-13	9	[{"id_menu":6,"count":1}]	330	delivery	5	14
23841	2020-01-13 12:36:17	2020-01-13	14	[{"id_menu":2,"count":1}]	543	pick-up	0	14
23842	2020-01-13 12:44:06	2020-01-13	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9294	delivery	5	42
23843	2020-01-13 13:00:45	2020-01-13	14	[{"id_menu":2,"count":1}]	9252	pick-up	0	14
23844	2020-01-13 13:19:20	2020-01-13	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	4370	delivery	5	31
23845	2020-01-13 13:27:41	2020-01-13	17	[{"id_menu":4,"count":1}]	1528	pick-up	0	17
23846	2020-01-13 13:38:01	2020-01-13	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2442	pick-up	0	38
23847	2020-01-13 13:51:10	2020-01-13	8	[{"id_menu":5,"count":1}]	2160	pick-up	0	8
23848	2020-01-13 14:09:40	2020-01-13	9	[{"id_menu":7,"count":1}]	4584	delivery	5	14
23849	2020-01-13 14:10:00	2020-01-13	9	[{"id_menu":6,"count":1}]	9288	pick-up	0	9
23850	2020-01-13 14:12:24	2020-01-13	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9272	delivery	5	43
23851	2020-01-13 14:15:36	2020-01-13	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2871	delivery	5	38
23852	2020-01-13 14:18:56	2020-01-13	14	[{"id_menu":2,"count":1}]	524	delivery	5	19
23853	2020-01-13 14:43:35	2020-01-13	12	[{"id_menu":1,"count":1}]	3946	pick-up	0	12
23854	2020-01-13 14:47:27	2020-01-13	12	[{"id_menu":3,"count":1}]	2307	pick-up	0	12
23855	2020-01-13 14:51:22	2020-01-13	9	[{"id_menu":6,"count":2}]	9305	delivery	5	14
23856	2020-01-13 15:20:01	2020-01-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9245	pick-up	0	18
23857	2020-01-13 15:25:26	2020-01-13	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7253	delivery	5	36
23858	2020-01-13 15:38:46	2020-01-13	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	4249	delivery	5	22
23859	2020-01-13 16:27:44	2020-01-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5094	pick-up	0	18
23860	2020-01-13 16:45:22	2020-01-13	14	[{"id_menu":2,"count":1}]	8355	delivery	5	19
23861	2020-01-13 17:13:50	2020-01-13	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	9296	delivery	5	22
23862	2020-01-13 17:28:37	2020-01-13	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	9310	delivery	5	26
23863	2020-01-13 17:33:17	2020-01-13	9	[{"id_menu":6,"count":1}]	9293	delivery	5	14
23864	2020-01-13 18:41:25	2020-01-13	9	[{"id_menu":7,"count":1}]	4284	delivery	5	14
23865	2020-01-13 18:46:37	2020-01-13	12	[{"id_menu":1,"count":1}]	9260	delivery	5	17
23866	2020-01-13 19:15:09	2020-01-13	17	[{"id_menu":4,"count":1}]	207	pick-up	0	17
23867	2020-01-13 19:41:02	2020-01-13	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5236	delivery	5	22
23868	2020-01-13 19:41:14	2020-01-13	12	[{"id_menu":1,"count":1}]	9171	pick-up	0	12
23869	2020-01-13 19:53:23	2020-01-13	12	[{"id_menu":3,"count":1}]	1075	pick-up	0	12
23870	2020-01-13 19:59:12	2020-01-13	9	[{"id_menu":6,"count":1}]	2080	pick-up	0	9
23871	2020-01-13 20:05:21	2020-01-13	9	[{"id_menu":7,"count":2}]	5485	delivery	5	14
23872	2020-01-13 20:21:00	2020-01-13	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	2823	delivery	5	29
23873	2020-01-13 20:26:52	2020-01-13	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8275	delivery	5	30
23874	2020-01-13 20:30:02	2020-01-13	9	[{"id_menu":6,"count":1}]	9298	delivery	5	14
23875	2020-01-13 20:34:42	2020-01-13	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	9262	delivery	5	31
23876	2020-01-13 20:44:54	2020-01-13	9	[{"id_menu":6,"count":1}]	9001	delivery	5	14
23877	2020-01-13 21:00:48	2020-01-13	17	[{"id_menu":5,"count":3},{"id_menu":6,"count":1}]	440	delivery	5	22
23878	2020-01-13 21:12:10	2020-01-13	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	9283	delivery	5	26
23879	2020-01-13 21:27:20	2020-01-13	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4100	delivery	5	39
23880	2020-01-13 21:29:37	2020-01-13	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	9280	pick-up	0	21
23881	2020-01-13 21:37:40	2020-01-13	17	[{"id_menu":4,"count":1}]	5790	pick-up	0	17
23882	2020-01-13 21:56:15	2020-01-13	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3137	delivery	5	31
23883	2020-01-13 22:23:24	2020-01-13	14	[{"id_menu":2,"count":1}]	9291	pick-up	0	14
23884	2020-01-13 22:24:24	2020-01-13	9	[{"id_menu":7,"count":1}]	9271	delivery	5	14
23885	2020-01-13 22:27:15	2020-01-13	8	[{"id_menu":5,"count":1}]	9303	pick-up	0	8
23886	2020-01-13 22:38:06	2020-01-13	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	9311	delivery	5	26
23887	2020-01-13 22:41:01	2020-01-13	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	8367	delivery	5	39
23888	2020-01-13 22:51:32	2020-01-13	9	[{"id_menu":6,"count":1}]	4823	pick-up	0	9
23889	2020-01-13 23:11:49	2020-01-13	8	[{"id_menu":5,"count":2}]	7523	delivery	5	13
23890	2020-01-13 23:11:55	2020-01-13	8	[{"id_menu":5,"count":1}]	6351	pick-up	0	8
23891	2020-01-13 23:47:56	2020-01-13	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	9273	delivery	5	40
23892	2020-01-13 23:49:50	2020-01-13	9	[{"id_menu":6,"count":1}]	4928	delivery	5	14
23893	2020-01-13 23:59:33	2020-01-13	12	[{"id_menu":1,"count":1}]	2172	delivery	5	17
23894	2020-01-13 23:59:50	2020-01-13	12	[{"id_menu":3,"count":1}]	9300	delivery	5	17
23895	2020-01-14 00:08:31	2020-01-14	8	[{"id_menu":5,"count":1}]	9345	delivery	5	13
23896	2020-01-14 00:26:10	2020-01-14	9	[{"id_menu":6,"count":1}]	2375	pick-up	0	9
23897	2020-01-14 00:29:58	2020-01-14	9	[{"id_menu":6,"count":1}]	9355	pick-up	0	9
23898	2020-01-14 00:53:13	2020-01-14	9	[{"id_menu":7,"count":1}]	9341	delivery	5	14
23899	2020-01-14 00:56:26	2020-01-14	17	[{"id_menu":4,"count":1}]	9333	delivery	5	22
23900	2020-01-14 00:56:29	2020-01-14	12	[{"id_menu":3,"count":1}]	1118	pick-up	0	12
23901	2020-01-14 01:09:37	2020-01-14	12	[{"id_menu":1,"count":1}]	2944	pick-up	0	12
23902	2020-01-14 01:23:02	2020-01-14	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7053	delivery	5	31
23903	2020-01-14 01:44:57	2020-01-14	17	[{"id_menu":4,"count":1}]	9348	pick-up	0	17
23904	2020-01-14 01:46:58	2020-01-14	14	[{"id_menu":2,"count":1}]	9353	delivery	5	19
23905	2020-01-14 01:59:55	2020-01-14	9	[{"id_menu":7,"count":1}]	9399	delivery	5	14
23906	2020-01-14 02:12:05	2020-01-14	8	[{"id_menu":5,"count":1}]	6176	pick-up	0	8
23907	2020-01-14 02:12:30	2020-01-14	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	9329	delivery	5	26
23908	2020-01-14 02:23:35	2020-01-14	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6894	delivery	5	48
23909	2020-01-14 02:28:18	2020-01-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7915	delivery	5	36
23910	2020-01-14 02:45:31	2020-01-14	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3604	pick-up	0	35
23911	2020-01-14 02:50:14	2020-01-14	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	9320	pick-up	0	22
23912	2020-01-14 02:53:47	2020-01-14	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7551	delivery	5	31
23913	2020-01-14 03:00:05	2020-01-14	12	[{"id_menu":1,"count":1}]	3825	pick-up	0	12
23914	2020-01-14 03:17:30	2020-01-14	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9388	delivery	5	48
23915	2020-01-14 03:19:12	2020-01-14	12	[{"id_menu":1,"count":1}]	9321	delivery	5	17
23916	2020-01-14 03:21:15	2020-01-14	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	627	delivery	5	34
23917	2020-01-14 03:29:23	2020-01-14	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	5523	delivery	5	31
23918	2020-01-14 03:45:12	2020-01-14	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	2832	delivery	5	26
23919	2020-01-14 03:51:58	2020-01-14	9	[{"id_menu":7,"count":1}]	6192	delivery	5	14
23920	2020-01-14 03:56:16	2020-01-14	14	[{"id_menu":2,"count":1}]	6477	delivery	5	19
23921	2020-01-14 04:00:26	2020-01-14	8	[{"id_menu":5,"count":1}]	9350	delivery	5	13
23922	2020-01-14 04:34:45	2020-01-14	12	[{"id_menu":1,"count":1}]	3197	delivery	5	17
23923	2020-01-14 04:35:44	2020-01-14	14	[{"id_menu":2,"count":1}]	7038	pick-up	0	14
23924	2020-01-14 04:40:07	2020-01-14	8	[{"id_menu":5,"count":1}]	1262	delivery	5	13
23925	2020-01-14 04:40:46	2020-01-14	9	[{"id_menu":7,"count":1}]	5427	delivery	5	14
23926	2020-01-14 05:01:11	2020-01-14	14	[{"id_menu":2,"count":1}]	9332	pick-up	0	14
23927	2020-01-14 05:04:15	2020-01-14	12	[{"id_menu":3,"count":1}]	3780	pick-up	0	12
23928	2020-01-14 05:08:52	2020-01-14	9	[{"id_menu":6,"count":1}]	9308	delivery	5	14
23929	2020-01-14 05:10:54	2020-01-14	8	[{"id_menu":5,"count":1}]	3098	delivery	5	13
23930	2020-01-14 05:17:12	2020-01-14	9	[{"id_menu":6,"count":1}]	1534	pick-up	0	9
23931	2020-01-14 05:26:17	2020-01-14	17	[{"id_menu":4,"count":1}]	1674	pick-up	0	17
23932	2020-01-14 05:39:23	2020-01-14	14	[{"id_menu":2,"count":1}]	8729	delivery	5	19
23933	2020-01-14 05:46:06	2020-01-14	9	[{"id_menu":6,"count":1}]	1723	pick-up	0	9
23934	2020-01-14 06:09:00	2020-01-14	14	[{"id_menu":2,"count":1}]	7877	delivery	5	19
23935	2020-01-14 06:14:48	2020-01-14	9	[{"id_menu":7,"count":1}]	1461	delivery	5	14
23936	2020-01-14 06:24:42	2020-01-14	12	[{"id_menu":3,"count":1}]	5768	delivery	5	17
23937	2020-01-14 06:31:27	2020-01-14	14	[{"id_menu":2,"count":1}]	6592	delivery	5	19
23938	2020-01-14 06:45:19	2020-01-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":3}]	9391	delivery	5	28
23939	2020-01-14 06:51:42	2020-01-14	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":3}]	9376	delivery	5	26
23940	2020-01-14 06:59:36	2020-01-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8866	delivery	5	31
23941	2020-01-14 07:24:09	2020-01-14	9	[{"id_menu":6,"count":1}]	9370	pick-up	0	9
23942	2020-01-14 07:24:18	2020-01-14	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3045	pick-up	0	35
23943	2020-01-14 07:28:22	2020-01-14	9	[{"id_menu":7,"count":1}]	3135	delivery	5	14
23944	2020-01-14 07:59:16	2020-01-14	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	688	pick-up	0	25
23945	2020-01-14 08:06:04	2020-01-14	17	[{"id_menu":4,"count":1}]	9401	delivery	5	22
23946	2020-01-14 08:40:03	2020-01-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9356	pick-up	0	23
23947	2020-01-14 09:02:15	2020-01-14	9	[{"id_menu":6,"count":1}]	7415	pick-up	0	9
23948	2020-01-14 09:20:00	2020-01-14	14	[{"id_menu":2,"count":1}]	9371	delivery	5	19
23949	2020-01-14 10:00:36	2020-01-14	9	[{"id_menu":7,"count":1}]	9375	delivery	5	14
23950	2020-01-14 10:15:48	2020-01-14	14	[{"id_menu":2,"count":1}]	9319	delivery	5	19
23951	2020-01-14 10:19:33	2020-01-14	9	[{"id_menu":6,"count":1}]	8859	delivery	5	14
23952	2020-01-14 10:23:42	2020-01-14	8	[{"id_menu":5,"count":1}]	2593	delivery	5	13
23953	2020-01-14 10:26:38	2020-01-14	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	9366	delivery	5	43
23954	2020-01-14 10:33:11	2020-01-14	14	[{"id_menu":2,"count":2}]	9373	pick-up	0	14
23955	2020-01-14 10:35:06	2020-01-14	9	[{"id_menu":7,"count":2}]	3514	delivery	5	14
23956	2020-01-14 10:47:59	2020-01-14	17	[{"id_menu":4,"count":1}]	3444	delivery	5	22
23957	2020-01-14 10:52:14	2020-01-14	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9386	delivery	5	39
23958	2020-01-14 10:53:26	2020-01-14	9	[{"id_menu":7,"count":1}]	3230	pick-up	0	9
23959	2020-01-14 10:56:02	2020-01-14	9	[{"id_menu":6,"count":1}]	1865	pick-up	0	9
23960	2020-01-14 10:57:33	2020-01-14	9	[{"id_menu":6,"count":1}]	5468	delivery	5	14
23961	2020-01-14 11:02:51	2020-01-14	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	3472	delivery	5	34
23962	2020-01-14 11:05:05	2020-01-14	14	[{"id_menu":2,"count":1}]	593	pick-up	0	14
23963	2020-01-14 11:27:02	2020-01-14	12	[{"id_menu":1,"count":3}]	9361	delivery	5	17
23964	2020-01-14 11:30:45	2020-01-14	17	[{"id_menu":4,"count":1}]	7688	pick-up	0	17
23965	2020-01-14 11:35:39	2020-01-14	9	[{"id_menu":7,"count":1}]	9349	delivery	5	14
23966	2020-01-14 11:50:42	2020-01-14	12	[{"id_menu":3,"count":1}]	9343	delivery	5	17
23967	2020-01-14 12:11:20	2020-01-14	12	[{"id_menu":3,"count":1}]	9354	delivery	5	17
23968	2020-01-14 12:11:32	2020-01-14	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	9334	delivery	5	28
23969	2020-01-14 12:12:24	2020-01-14	8	[{"id_menu":5,"count":1}]	2206	pick-up	0	8
23970	2020-01-14 12:16:34	2020-01-14	14	[{"id_menu":2,"count":1}]	3869	pick-up	0	14
23971	2020-01-14 13:07:24	2020-01-14	12	[{"id_menu":1,"count":1}]	8347	delivery	5	17
23972	2020-01-14 13:12:59	2020-01-14	9	[{"id_menu":7,"count":1}]	9346	delivery	5	14
23973	2020-01-14 13:14:02	2020-01-14	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4086	delivery	5	34
23974	2020-01-14 13:21:27	2020-01-14	8	[{"id_menu":5,"count":1}]	5655	delivery	5	13
23975	2020-01-14 13:42:05	2020-01-14	9	[{"id_menu":7,"count":1}]	9323	delivery	5	14
23976	2020-01-14 14:04:09	2020-01-14	9	[{"id_menu":7,"count":1}]	9352	delivery	5	14
23977	2020-01-14 14:12:11	2020-01-14	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	5933	pick-up	0	29
23978	2020-01-14 14:17:44	2020-01-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	340	pick-up	0	31
23979	2020-01-14 14:19:57	2020-01-14	9	[{"id_menu":6,"count":1}]	1097	delivery	5	14
23980	2020-01-14 14:22:13	2020-01-14	8	[{"id_menu":5,"count":1}]	9390	delivery	5	13
23981	2020-01-14 14:37:50	2020-01-14	9	[{"id_menu":6,"count":1}]	3012	delivery	5	14
23982	2020-01-14 14:52:01	2020-01-14	9	[{"id_menu":6,"count":1}]	9326	delivery	5	14
23983	2020-01-14 15:11:47	2020-01-14	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	7785	delivery	5	30
23984	2020-01-14 15:19:08	2020-01-14	9	[{"id_menu":6,"count":1}]	6734	delivery	5	14
23985	2020-01-14 15:34:14	2020-01-14	9	[{"id_menu":6,"count":2}]	9327	delivery	5	14
23986	2020-01-14 15:37:05	2020-01-14	9	[{"id_menu":6,"count":3}]	9362	delivery	5	14
23987	2020-01-14 15:44:01	2020-01-14	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	6276	delivery	5	26
23988	2020-01-14 15:59:27	2020-01-14	14	[{"id_menu":2,"count":2}]	2200	pick-up	0	14
23989	2020-01-14 16:05:23	2020-01-14	29	[{"id_menu":3,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9372	delivery	5	34
23990	2020-01-14 16:18:56	2020-01-14	9	[{"id_menu":7,"count":1}]	9374	delivery	5	14
23991	2020-01-14 16:26:50	2020-01-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2238	pick-up	0	31
23992	2020-01-14 16:27:07	2020-01-14	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	7356	delivery	5	27
23993	2020-01-14 16:32:57	2020-01-14	14	[{"id_menu":2,"count":1}]	4633	delivery	5	19
23994	2020-01-14 16:34:53	2020-01-14	8	[{"id_menu":5,"count":1}]	9394	delivery	5	13
23995	2020-01-14 16:39:47	2020-01-14	9	[{"id_menu":6,"count":1}]	9324	delivery	5	14
23996	2020-01-14 16:40:07	2020-01-14	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	9364	delivery	5	28
23997	2020-01-14 16:45:08	2020-01-14	12	[{"id_menu":1,"count":1}]	2768	delivery	5	17
23998	2020-01-14 16:48:13	2020-01-14	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	9398	delivery	5	27
23999	2020-01-14 16:52:50	2020-01-14	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2303	delivery	5	31
24000	2020-01-14 16:59:51	2020-01-14	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	2670	delivery	5	26
24001	2020-01-14 17:04:06	2020-01-14	9	[{"id_menu":7,"count":1}]	802	delivery	5	14
24002	2020-01-14 17:09:34	2020-01-14	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	5303	pick-up	0	29
24003	2020-01-14 17:14:51	2020-01-14	14	[{"id_menu":2,"count":1}]	2922	delivery	5	19
24004	2020-01-14 17:25:43	2020-01-14	55	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	9387	pick-up	0	55
24005	2020-01-14 17:33:02	2020-01-14	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	9397	delivery	5	27
24006	2020-01-14 17:36:11	2020-01-14	12	[{"id_menu":3,"count":1}]	1053	delivery	5	17
24007	2020-01-14 18:00:45	2020-01-14	9	[{"id_menu":6,"count":1}]	6156	pick-up	0	9
24008	2020-01-14 18:03:20	2020-01-14	9	[{"id_menu":7,"count":1}]	7261	delivery	5	14
24009	2020-01-14 18:13:41	2020-01-14	8	[{"id_menu":5,"count":1}]	563	delivery	5	13
24010	2020-01-14 18:16:09	2020-01-14	9	[{"id_menu":6,"count":1}]	9377	delivery	5	14
24011	2020-01-14 18:19:03	2020-01-14	8	[{"id_menu":5,"count":1}]	5571	delivery	5	13
24012	2020-01-14 18:24:16	2020-01-14	9	[{"id_menu":6,"count":1}]	9379	delivery	5	14
24013	2020-01-14 18:59:57	2020-01-14	8	[{"id_menu":5,"count":1}]	1379	pick-up	0	8
24014	2020-01-14 19:42:23	2020-01-14	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9395	delivery	5	22
24015	2020-01-14 19:44:35	2020-01-14	12	[{"id_menu":1,"count":1}]	9357	delivery	5	17
24016	2020-01-14 19:50:44	2020-01-14	9	[{"id_menu":7,"count":1}]	9389	delivery	5	14
24017	2020-01-14 20:03:32	2020-01-14	8	[{"id_menu":5,"count":1}]	9337	pick-up	0	8
24018	2020-01-14 20:08:58	2020-01-14	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	9358	pick-up	0	26
24019	2020-01-14 20:14:15	2020-01-14	38	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9065	delivery	5	43
24020	2020-01-14 20:17:58	2020-01-14	14	[{"id_menu":2,"count":1}]	6104	delivery	5	19
24021	2020-01-14 20:19:54	2020-01-14	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6950	delivery	5	28
24022	2020-01-14 20:53:35	2020-01-14	14	[{"id_menu":2,"count":1}]	4363	delivery	5	19
24023	2020-01-14 21:01:38	2020-01-14	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	820	pick-up	0	29
24024	2020-01-14 21:03:33	2020-01-14	12	[{"id_menu":1,"count":1}]	7249	delivery	5	17
24025	2020-01-14 21:07:23	2020-01-14	17	[{"id_menu":4,"count":1}]	9396	delivery	5	22
24026	2020-01-14 21:26:12	2020-01-14	17	[{"id_menu":4,"count":1}]	5193	delivery	5	22
24027	2020-01-14 21:30:55	2020-01-14	17	[{"id_menu":4,"count":1}]	730	pick-up	0	17
24028	2020-01-14 21:35:08	2020-01-14	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4687	delivery	5	28
24029	2020-01-14 21:41:20	2020-01-14	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9385	delivery	5	52
24030	2020-01-14 22:03:21	2020-01-14	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	7796	delivery	5	34
24031	2020-01-14 22:24:30	2020-01-14	9	[{"id_menu":7,"count":1}]	2447	delivery	5	14
24032	2020-01-14 22:28:12	2020-01-14	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9076	delivery	5	48
24033	2020-01-14 22:29:54	2020-01-14	9	[{"id_menu":6,"count":1}]	9363	pick-up	0	9
24034	2020-01-14 22:42:37	2020-01-14	9	[{"id_menu":6,"count":1}]	7044	delivery	5	14
24035	2020-01-14 23:19:18	2020-01-14	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1862	pick-up	0	20
24036	2020-01-14 23:19:21	2020-01-14	17	[{"id_menu":4,"count":1}]	9107	pick-up	0	17
24037	2020-01-14 23:26:14	2020-01-14	12	[{"id_menu":3,"count":1}]	1893	pick-up	0	12
24038	2020-01-14 23:28:57	2020-01-14	17	[{"id_menu":4,"count":1}]	7046	pick-up	0	17
24039	2020-01-14 23:34:19	2020-01-14	12	[{"id_menu":3,"count":1}]	9344	delivery	5	17
24040	2020-01-15 00:10:33	2020-01-15	8	[{"id_menu":5,"count":1}]	6375	delivery	5	13
24041	2020-01-15 00:19:25	2020-01-15	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9407	delivery	5	35
24042	2020-01-15 00:19:45	2020-01-15	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	9480	delivery	5	27
24043	2020-01-15 00:25:55	2020-01-15	17	[{"id_menu":4,"count":1}]	4890	delivery	5	22
24044	2020-01-15 00:39:13	2020-01-15	14	[{"id_menu":2,"count":1}]	6973	delivery	5	19
24045	2020-01-15 00:42:30	2020-01-15	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	466	delivery	5	31
24046	2020-01-15 00:42:35	2020-01-15	14	[{"id_menu":2,"count":1}]	9444	delivery	5	19
24047	2020-01-15 00:52:12	2020-01-15	17	[{"id_menu":4,"count":1}]	9476	delivery	5	22
24048	2020-01-15 00:57:58	2020-01-15	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	612	pick-up	0	21
24049	2020-01-15 00:59:31	2020-01-15	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9453	delivery	5	22
24050	2020-01-15 01:02:12	2020-01-15	8	[{"id_menu":5,"count":1}]	6176	pick-up	0	8
24051	2020-01-15 01:03:43	2020-01-15	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	5917	pick-up	0	31
24052	2020-01-15 01:26:51	2020-01-15	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	7987	delivery	5	27
24053	2020-01-15 01:26:54	2020-01-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1581	delivery	5	28
24054	2020-01-15 01:27:54	2020-01-15	12	[{"id_menu":1,"count":1}]	3780	pick-up	0	12
24055	2020-01-15 01:31:13	2020-01-15	9	[{"id_menu":6,"count":1}]	9474	delivery	5	14
24056	2020-01-15 01:41:57	2020-01-15	14	[{"id_menu":2,"count":1}]	2550	delivery	5	19
24057	2020-01-15 01:42:06	2020-01-15	8	[{"id_menu":5,"count":3}]	4861	delivery	5	13
24058	2020-01-15 01:46:09	2020-01-15	14	[{"id_menu":2,"count":1}]	6282	pick-up	0	14
24059	2020-01-15 01:56:04	2020-01-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7461	delivery	5	28
24060	2020-01-15 02:03:33	2020-01-15	14	[{"id_menu":2,"count":1}]	9422	delivery	5	19
24061	2020-01-15 02:05:43	2020-01-15	14	[{"id_menu":2,"count":1}]	1259	pick-up	0	14
24062	2020-01-15 02:20:18	2020-01-15	14	[{"id_menu":2,"count":1}]	3869	pick-up	0	14
24063	2020-01-15 02:21:44	2020-01-15	8	[{"id_menu":5,"count":1}]	9478	delivery	5	13
24064	2020-01-15 02:31:24	2020-01-15	9	[{"id_menu":6,"count":1}]	9433	delivery	5	14
24065	2020-01-15 02:33:50	2020-01-15	12	[{"id_menu":3,"count":1}]	1159	pick-up	0	12
24066	2020-01-15 02:56:17	2020-01-15	8	[{"id_menu":5,"count":1}]	1700	pick-up	0	8
24067	2020-01-15 02:56:48	2020-01-15	17	[{"id_menu":4,"count":1}]	3293	delivery	5	22
24068	2020-01-15 03:02:41	2020-01-15	17	[{"id_menu":4,"count":1}]	554	delivery	5	22
24069	2020-01-15 03:09:59	2020-01-15	17	[{"id_menu":4,"count":1}]	1212	delivery	5	22
24070	2020-01-15 03:15:47	2020-01-15	12	[{"id_menu":1,"count":1}]	8185	pick-up	0	12
24071	2020-01-15 03:26:57	2020-01-15	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":2}]	9418	delivery	5	31
24072	2020-01-15 03:33:29	2020-01-15	9	[{"id_menu":6,"count":1}]	7620	delivery	5	14
24073	2020-01-15 03:38:54	2020-01-15	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	5975	delivery	5	39
24074	2020-01-15 03:44:52	2020-01-15	14	[{"id_menu":2,"count":1}]	6658	pick-up	0	14
24075	2020-01-15 03:45:14	2020-01-15	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2467	delivery	5	25
24076	2020-01-15 03:46:51	2020-01-15	9	[{"id_menu":6,"count":1}]	9485	delivery	5	14
24077	2020-01-15 03:49:16	2020-01-15	17	[{"id_menu":4,"count":1}]	6565	pick-up	0	17
24078	2020-01-15 03:53:07	2020-01-15	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2082	delivery	5	26
24079	2020-01-15 03:53:16	2020-01-15	8	[{"id_menu":5,"count":1}]	8543	pick-up	0	8
24080	2020-01-15 04:01:30	2020-01-15	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9484	delivery	5	39
24081	2020-01-15 04:03:19	2020-01-15	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9406	pick-up	0	25
24082	2020-01-15 04:11:02	2020-01-15	17	[{"id_menu":4,"count":1}]	4223	pick-up	0	17
24083	2020-01-15 04:21:05	2020-01-15	12	[{"id_menu":3,"count":1}]	6238	delivery	5	17
24084	2020-01-15 04:25:05	2020-01-15	9	[{"id_menu":7,"count":1}]	5789	delivery	5	14
24085	2020-01-15 04:31:26	2020-01-15	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2790	delivery	5	27
24086	2020-01-15 04:35:01	2020-01-15	9	[{"id_menu":6,"count":2}]	9428	delivery	5	14
24087	2020-01-15 04:42:32	2020-01-15	9	[{"id_menu":6,"count":1}]	9300	delivery	5	14
24088	2020-01-15 04:42:53	2020-01-15	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	9402	pick-up	0	40
24089	2020-01-15 04:48:43	2020-01-15	9	[{"id_menu":6,"count":2}]	9426	delivery	5	14
24090	2020-01-15 04:50:03	2020-01-15	8	[{"id_menu":5,"count":1}]	5312	delivery	5	13
24091	2020-01-15 04:54:00	2020-01-15	12	[{"id_menu":3,"count":1}]	5701	delivery	5	17
24092	2020-01-15 04:56:10	2020-01-15	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7019	pick-up	0	43
24093	2020-01-15 04:57:07	2020-01-15	12	[{"id_menu":3,"count":1}]	8347	pick-up	0	12
24094	2020-01-15 04:57:45	2020-01-15	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	9439	delivery	5	27
24095	2020-01-15 04:59:49	2020-01-15	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	9449	delivery	5	26
24096	2020-01-15 05:01:36	2020-01-15	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	2786	delivery	5	34
24097	2020-01-15 05:24:17	2020-01-15	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	9411	delivery	5	28
24098	2020-01-15 05:26:50	2020-01-15	14	[{"id_menu":2,"count":1}]	2028	pick-up	0	14
24099	2020-01-15 05:27:32	2020-01-15	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9416	delivery	5	40
24100	2020-01-15 05:40:51	2020-01-15	9	[{"id_menu":7,"count":1}]	3164	pick-up	0	9
24101	2020-01-15 05:46:32	2020-01-15	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	271	pick-up	0	20
24102	2020-01-15 06:04:46	2020-01-15	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	9409	delivery	5	22
24103	2020-01-15 06:05:32	2020-01-15	9	[{"id_menu":6,"count":1}]	9421	pick-up	0	9
24104	2020-01-15 06:19:23	2020-01-15	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1753	pick-up	0	25
24105	2020-01-15 06:19:27	2020-01-15	9	[{"id_menu":7,"count":1}]	5757	delivery	5	14
24106	2020-01-15 06:28:17	2020-01-15	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3657	delivery	5	31
24107	2020-01-15 06:33:59	2020-01-15	14	[{"id_menu":2,"count":1}]	8219	delivery	5	19
24108	2020-01-15 06:37:31	2020-01-15	8	[{"id_menu":5,"count":1}]	9404	pick-up	0	8
24109	2020-01-15 06:39:57	2020-01-15	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3127	delivery	5	46
24110	2020-01-15 06:41:11	2020-01-15	14	[{"id_menu":2,"count":1}]	5354	pick-up	0	14
24111	2020-01-15 06:49:45	2020-01-15	17	[{"id_menu":4,"count":1}]	4172	pick-up	0	17
24112	2020-01-15 06:51:17	2020-01-15	9	[{"id_menu":6,"count":1}]	786	pick-up	0	9
24113	2020-01-15 07:11:08	2020-01-15	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	9412	delivery	5	23
24114	2020-01-15 07:37:37	2020-01-15	12	[{"id_menu":3,"count":1}]	9461	delivery	5	17
24115	2020-01-15 07:48:59	2020-01-15	14	[{"id_menu":2,"count":4}]	1844	delivery	5	19
24116	2020-01-15 07:57:01	2020-01-15	9	[{"id_menu":7,"count":1}]	9467	pick-up	0	9
24117	2020-01-15 08:01:23	2020-01-15	9	[{"id_menu":6,"count":1}]	3069	pick-up	0	9
24118	2020-01-15 08:09:05	2020-01-15	14	[{"id_menu":2,"count":1}]	9458	pick-up	0	14
24119	2020-01-15 08:09:33	2020-01-15	17	[{"id_menu":4,"count":1}]	9434	delivery	5	22
24120	2020-01-15 08:17:23	2020-01-15	17	[{"id_menu":4,"count":1}]	1125	delivery	5	22
24121	2020-01-15 08:25:24	2020-01-15	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9024	delivery	5	43
24122	2020-01-15 08:26:03	2020-01-15	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	5875	pick-up	0	26
24123	2020-01-15 08:38:33	2020-01-15	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9482	pick-up	0	34
24124	2020-01-15 08:54:44	2020-01-15	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9424	delivery	5	22
24125	2020-01-15 08:55:52	2020-01-15	14	[{"id_menu":2,"count":1}]	3789	delivery	5	19
24126	2020-01-15 08:59:00	2020-01-15	9	[{"id_menu":7,"count":1}]	6369	delivery	5	14
24127	2020-01-15 09:08:53	2020-01-15	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9443	delivery	5	47
24128	2020-01-15 09:13:12	2020-01-15	9	[{"id_menu":6,"count":1}]	5047	pick-up	0	9
24129	2020-01-15 09:13:34	2020-01-15	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	3968	pick-up	0	24
24130	2020-01-15 09:26:19	2020-01-15	17	[{"id_menu":4,"count":1}]	9427	delivery	5	22
24131	2020-01-15 09:26:37	2020-01-15	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	7594	delivery	5	29
24132	2020-01-15 09:28:11	2020-01-15	9	[{"id_menu":6,"count":1}]	6136	delivery	5	14
24133	2020-01-15 09:35:45	2020-01-15	14	[{"id_menu":2,"count":1}]	998	pick-up	0	14
24134	2020-01-15 09:36:55	2020-01-15	17	[{"id_menu":4,"count":1}]	8454	pick-up	0	17
24135	2020-01-15 09:58:44	2020-01-15	12	[{"id_menu":1,"count":1}]	9429	delivery	5	17
24136	2020-01-15 10:06:30	2020-01-15	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	7806	pick-up	0	18
24137	2020-01-15 10:15:23	2020-01-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2193	pick-up	0	18
24138	2020-01-15 10:24:05	2020-01-15	12	[{"id_menu":3,"count":2}]	9460	delivery	5	17
24139	2020-01-15 10:25:37	2020-01-15	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4526	pick-up	0	26
24140	2020-01-15 10:28:01	2020-01-15	8	[{"id_menu":5,"count":1}]	1444	delivery	5	13
24141	2020-01-15 10:32:35	2020-01-15	9	[{"id_menu":7,"count":1}]	1189	pick-up	0	9
24142	2020-01-15 10:35:46	2020-01-15	12	[{"id_menu":3,"count":1}]	3919	delivery	5	17
24143	2020-01-15 10:53:25	2020-01-15	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9465	delivery	5	54
24144	2020-01-15 10:56:11	2020-01-15	12	[{"id_menu":1,"count":1}]	6942	pick-up	0	12
24145	2020-01-15 11:10:48	2020-01-15	9	[{"id_menu":6,"count":1}]	5567	delivery	5	14
24146	2020-01-15 11:15:10	2020-01-15	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1657	delivery	5	29
24147	2020-01-15 11:23:46	2020-01-15	8	[{"id_menu":5,"count":1}]	1509	delivery	5	13
24148	2020-01-15 11:32:25	2020-01-15	9	[{"id_menu":7,"count":1}]	9452	delivery	5	14
24149	2020-01-15 11:32:42	2020-01-15	17	[{"id_menu":4,"count":1}]	1943	pick-up	0	17
24150	2020-01-15 11:36:15	2020-01-15	17	[{"id_menu":4,"count":1}]	456	pick-up	0	17
24151	2020-01-15 11:45:59	2020-01-15	14	[{"id_menu":2,"count":1}]	9437	delivery	5	19
24152	2020-01-15 12:17:26	2020-01-15	17	[{"id_menu":4,"count":1}]	9464	delivery	5	22
24153	2020-01-15 12:37:30	2020-01-15	12	[{"id_menu":3,"count":1}]	2891	pick-up	0	12
24154	2020-01-15 12:42:39	2020-01-15	12	[{"id_menu":3,"count":1}]	997	pick-up	0	12
24155	2020-01-15 12:48:28	2020-01-15	14	[{"id_menu":2,"count":1}]	3364	delivery	5	19
24156	2020-01-15 13:05:51	2020-01-15	12	[{"id_menu":3,"count":1}]	9442	pick-up	0	12
24157	2020-01-15 13:05:52	2020-01-15	8	[{"id_menu":5,"count":1}]	9445	delivery	5	13
24158	2020-01-15 13:06:54	2020-01-15	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	9457	delivery	5	23
24159	2020-01-15 13:13:20	2020-01-15	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9469	pick-up	0	35
24160	2020-01-15 13:23:13	2020-01-15	12	[{"id_menu":1,"count":2}]	5408	delivery	5	17
24161	2020-01-15 13:31:47	2020-01-15	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9432	delivery	5	34
24162	2020-01-15 13:32:01	2020-01-15	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	9451	delivery	5	45
24163	2020-01-15 13:35:26	2020-01-15	8	[{"id_menu":5,"count":1}]	2764	pick-up	0	8
24164	2020-01-15 13:36:22	2020-01-15	9	[{"id_menu":7,"count":1}]	3835	delivery	5	14
24165	2020-01-15 13:45:33	2020-01-15	9	[{"id_menu":6,"count":1}]	6761	delivery	5	14
24166	2020-01-15 13:58:27	2020-01-15	9	[{"id_menu":6,"count":1}]	9448	delivery	5	14
24167	2020-01-15 14:02:09	2020-01-15	9	[{"id_menu":6,"count":1}]	5509	delivery	5	14
24168	2020-01-15 14:12:01	2020-01-15	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1736	pick-up	0	30
24169	2020-01-15 14:17:47	2020-01-15	9	[{"id_menu":6,"count":2}]	9435	delivery	5	14
24170	2020-01-15 14:20:31	2020-01-15	17	[{"id_menu":4,"count":1}]	8666	delivery	5	22
24171	2020-01-15 14:27:45	2020-01-15	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	668	pick-up	0	40
24172	2020-01-15 14:40:04	2020-01-15	30	[{"id_menu":1,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9419	delivery	5	35
24173	2020-01-15 14:48:56	2020-01-15	12	[{"id_menu":3,"count":1}]	9466	pick-up	0	12
24174	2020-01-15 14:52:29	2020-01-15	8	[{"id_menu":5,"count":1}]	7912	delivery	5	13
24175	2020-01-15 15:01:58	2020-01-15	17	[{"id_menu":4,"count":1}]	5141	pick-up	0	17
24176	2020-01-15 15:08:37	2020-01-15	17	[{"id_menu":4,"count":1}]	3678	pick-up	0	17
24177	2020-01-15 15:09:10	2020-01-15	14	[{"id_menu":2,"count":1}]	1820	pick-up	0	14
24178	2020-01-15 15:20:22	2020-01-15	14	[{"id_menu":2,"count":1}]	4169	delivery	5	19
24179	2020-01-15 15:20:26	2020-01-15	29	[{"id_menu":3,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4841	delivery	5	34
24180	2020-01-15 15:31:39	2020-01-15	8	[{"id_menu":5,"count":1}]	7682	delivery	5	13
24181	2020-01-15 15:36:42	2020-01-15	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3690	delivery	5	36
24182	2020-01-15 15:41:06	2020-01-15	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	9446	delivery	5	22
24183	2020-01-15 15:43:01	2020-01-15	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1993	pick-up	0	22
24184	2020-01-15 15:44:15	2020-01-15	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	7491	delivery	5	26
24185	2020-01-15 15:46:26	2020-01-15	9	[{"id_menu":7,"count":1}]	7321	delivery	5	14
24186	2020-01-15 15:55:51	2020-01-15	8	[{"id_menu":5,"count":1}]	9431	pick-up	0	8
24187	2020-01-15 16:15:16	2020-01-15	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7678	pick-up	0	31
24188	2020-01-15 16:29:54	2020-01-15	12	[{"id_menu":1,"count":1}]	1309	pick-up	0	12
24189	2020-01-15 16:33:05	2020-01-15	14	[{"id_menu":2,"count":1}]	2650	delivery	5	19
24190	2020-01-15 16:55:50	2020-01-15	14	[{"id_menu":2,"count":1}]	669	pick-up	0	14
24191	2020-01-15 17:02:06	2020-01-15	14	[{"id_menu":2,"count":1}]	3785	pick-up	0	14
24192	2020-01-15 17:08:06	2020-01-15	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2233	pick-up	0	20
24193	2020-01-15 17:10:00	2020-01-15	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9410	delivery	5	39
24194	2020-01-15 17:35:43	2020-01-15	14	[{"id_menu":2,"count":1}]	2434	pick-up	0	14
24195	2020-01-15 17:44:48	2020-01-15	14	[{"id_menu":2,"count":1}]	8761	delivery	5	19
24196	2020-01-15 17:45:44	2020-01-15	12	[{"id_menu":3,"count":1}]	9463	delivery	5	17
24197	2020-01-15 17:47:23	2020-01-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	9440	delivery	5	28
24198	2020-01-15 17:56:14	2020-01-15	9	[{"id_menu":7,"count":1}]	2447	pick-up	0	9
24199	2020-01-15 18:06:22	2020-01-15	8	[{"id_menu":5,"count":1}]	9450	delivery	5	13
24200	2020-01-15 18:07:23	2020-01-15	8	[{"id_menu":5,"count":1}]	7241	delivery	5	13
24201	2020-01-15 18:16:39	2020-01-15	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7533	delivery	5	40
24202	2020-01-15 18:25:24	2020-01-15	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2807	pick-up	0	17
24203	2020-01-15 18:26:52	2020-01-15	21	[{"id_menu":3,"count":3},{"id_menu":7,"count":1}]	9436	delivery	5	26
24204	2020-01-15 18:36:44	2020-01-15	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	912	pick-up	0	26
24205	2020-01-15 18:51:57	2020-01-15	9	[{"id_menu":6,"count":1}]	3010	pick-up	0	9
24206	2020-01-15 18:55:02	2020-01-15	8	[{"id_menu":5,"count":1}]	5843	delivery	5	13
24207	2020-01-15 18:55:07	2020-01-15	14	[{"id_menu":2,"count":1}]	6254	pick-up	0	14
24208	2020-01-15 19:05:51	2020-01-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9454	delivery	5	23
24209	2020-01-15 19:25:54	2020-01-15	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	883	pick-up	0	26
24210	2020-01-15 19:26:45	2020-01-15	9	[{"id_menu":7,"count":1}]	9486	delivery	5	14
24211	2020-01-15 19:37:44	2020-01-15	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9414	delivery	5	30
24212	2020-01-15 19:48:14	2020-01-15	14	[{"id_menu":2,"count":1}]	2592	delivery	5	19
24213	2020-01-15 20:16:06	2020-01-15	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1627	pick-up	0	31
24214	2020-01-15 20:17:25	2020-01-15	12	[{"id_menu":3,"count":1}]	9473	delivery	5	17
24215	2020-01-15 20:18:58	2020-01-15	12	[{"id_menu":1,"count":1}]	8590	delivery	5	17
24216	2020-01-15 20:24:54	2020-01-15	14	[{"id_menu":2,"count":1}]	928	pick-up	0	14
24217	2020-01-15 20:42:30	2020-01-15	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9423	pick-up	0	37
24218	2020-01-15 20:51:00	2020-01-15	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	9472	delivery	5	27
24219	2020-01-15 20:51:37	2020-01-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	660	pick-up	0	23
24220	2020-01-15 20:52:28	2020-01-15	8	[{"id_menu":5,"count":1}]	2992	delivery	5	13
24221	2020-01-15 21:02:36	2020-01-15	9	[{"id_menu":6,"count":1}]	9408	delivery	5	14
24222	2020-01-15 21:02:56	2020-01-15	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	9112	delivery	5	36
24223	2020-01-15 21:12:55	2020-01-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8180	delivery	5	31
24224	2020-01-15 21:27:24	2020-01-15	9	[{"id_menu":7,"count":2}]	9333	delivery	5	14
24225	2020-01-15 21:28:35	2020-01-15	14	[{"id_menu":2,"count":1}]	9441	delivery	5	19
24226	2020-01-15 21:37:16	2020-01-15	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	381	pick-up	0	21
24227	2020-01-15 21:38:32	2020-01-15	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	4413	delivery	5	31
24228	2020-01-15 21:40:52	2020-01-15	9	[{"id_menu":7,"count":1}]	9481	delivery	5	14
24229	2020-01-15 22:00:09	2020-01-15	9	[{"id_menu":7,"count":1}]	5152	delivery	5	14
24230	2020-01-15 22:02:08	2020-01-15	14	[{"id_menu":2,"count":2}]	2897	pick-up	0	14
24231	2020-01-15 22:13:33	2020-01-15	17	[{"id_menu":4,"count":1}]	2582	pick-up	0	17
24232	2020-01-15 22:14:46	2020-01-15	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	1053	pick-up	0	22
24233	2020-01-15 22:22:17	2020-01-15	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9456	delivery	5	22
24234	2020-01-15 22:38:56	2020-01-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7050	pick-up	0	23
24235	2020-01-15 22:39:04	2020-01-15	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	9468	delivery	5	31
24236	2020-01-15 22:55:56	2020-01-15	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6987	pick-up	0	40
24237	2020-01-15 22:57:09	2020-01-15	9	[{"id_menu":6,"count":1}]	9295	pick-up	0	9
24238	2020-01-15 22:59:01	2020-01-15	8	[{"id_menu":5,"count":1}]	1025	pick-up	0	8
24239	2020-01-15 23:12:06	2020-01-15	12	[{"id_menu":3,"count":1}]	2333	pick-up	0	12
24240	2020-01-15 23:14:24	2020-01-15	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9425	delivery	5	36
24241	2020-01-15 23:24:53	2020-01-15	14	[{"id_menu":2,"count":1}]	9296	delivery	5	19
24242	2020-01-15 23:35:48	2020-01-15	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9470	delivery	5	42
24243	2020-01-15 23:38:36	2020-01-15	9	[{"id_menu":7,"count":1}]	2520	pick-up	0	9
24244	2020-01-15 23:44:32	2020-01-15	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1693	delivery	5	57
24245	2020-01-15 23:44:52	2020-01-15	12	[{"id_menu":3,"count":1}]	376	pick-up	0	12
24246	2020-01-15 23:54:42	2020-01-15	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	118	pick-up	0	20
24247	2020-01-16 00:00:39	2020-01-16	14	[{"id_menu":2,"count":1}]	9576	delivery	5	19
24248	2020-01-16 00:18:56	2020-01-16	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	800	delivery	5	31
24249	2020-01-16 00:23:29	2020-01-16	9	[{"id_menu":7,"count":1}]	4500	pick-up	0	9
24250	2020-01-16 00:25:08	2020-01-16	17	[{"id_menu":4,"count":1}]	3332	pick-up	0	17
24251	2020-01-16 00:33:36	2020-01-16	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5056	delivery	5	43
24252	2020-01-16 00:36:23	2020-01-16	12	[{"id_menu":1,"count":1}]	5617	pick-up	0	12
24253	2020-01-16 00:47:42	2020-01-16	9	[{"id_menu":6,"count":1}]	9499	delivery	5	14
24254	2020-01-16 00:49:02	2020-01-16	9	[{"id_menu":6,"count":1}]	2806	delivery	5	14
24255	2020-01-16 00:53:30	2020-01-16	17	[{"id_menu":4,"count":1}]	2516	pick-up	0	17
24256	2020-01-16 00:54:50	2020-01-16	9	[{"id_menu":6,"count":1}]	2064	delivery	5	14
24257	2020-01-16 01:00:26	2020-01-16	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	2477	pick-up	0	20
24258	2020-01-16 01:30:11	2020-01-16	8	[{"id_menu":5,"count":1}]	2926	pick-up	0	8
24259	2020-01-16 01:33:18	2020-01-16	12	[{"id_menu":3,"count":1}]	145	pick-up	0	12
24260	2020-01-16 01:33:27	2020-01-16	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8410	delivery	5	34
24261	2020-01-16 01:37:45	2020-01-16	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	6622	delivery	5	31
24262	2020-01-16 01:38:03	2020-01-16	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	9494	delivery	5	38
24263	2020-01-16 01:44:41	2020-01-16	8	[{"id_menu":5,"count":1}]	7941	pick-up	0	8
24264	2020-01-16 01:45:05	2020-01-16	9	[{"id_menu":6,"count":1}]	9512	delivery	5	14
24265	2020-01-16 01:47:05	2020-01-16	9	[{"id_menu":6,"count":1}]	691	pick-up	0	9
24266	2020-01-16 01:51:33	2020-01-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7918	pick-up	0	23
24267	2020-01-16 02:04:56	2020-01-16	12	[{"id_menu":1,"count":1}]	9562	delivery	5	17
24268	2020-01-16 02:08:34	2020-01-16	9	[{"id_menu":6,"count":1}]	8054	pick-up	0	9
24269	2020-01-16 02:11:55	2020-01-16	9	[{"id_menu":7,"count":1}]	1415	delivery	5	14
24270	2020-01-16 02:34:52	2020-01-16	12	[{"id_menu":3,"count":1}]	2492	pick-up	0	12
24271	2020-01-16 02:38:59	2020-01-16	9	[{"id_menu":7,"count":1}]	8286	delivery	5	14
24272	2020-01-16 02:39:05	2020-01-16	12	[{"id_menu":3,"count":1}]	1441	pick-up	0	12
24273	2020-01-16 02:50:25	2020-01-16	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	8450	delivery	5	25
24274	2020-01-16 03:03:14	2020-01-16	9	[{"id_menu":6,"count":1}]	1334	pick-up	0	9
24275	2020-01-16 03:10:17	2020-01-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6873	delivery	5	22
24276	2020-01-16 03:10:42	2020-01-16	9	[{"id_menu":7,"count":1}]	9565	delivery	5	14
24277	2020-01-16 03:21:54	2020-01-16	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	9552	delivery	5	23
24278	2020-01-16 03:27:19	2020-01-16	12	[{"id_menu":3,"count":1}]	7402	pick-up	0	12
24279	2020-01-16 03:28:51	2020-01-16	9	[{"id_menu":7,"count":1}]	9045	delivery	5	14
24280	2020-01-16 03:30:34	2020-01-16	14	[{"id_menu":2,"count":1}]	1858	delivery	5	19
24281	2020-01-16 03:56:30	2020-01-16	9	[{"id_menu":6,"count":1}]	9532	delivery	5	14
24282	2020-01-16 04:02:44	2020-01-16	9	[{"id_menu":6,"count":1}]	9515	delivery	5	14
24283	2020-01-16 04:09:38	2020-01-16	17	[{"id_menu":4,"count":1}]	1640	delivery	5	22
24284	2020-01-16 04:24:40	2020-01-16	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4825	delivery	5	45
24285	2020-01-16 04:27:05	2020-01-16	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	7591	pick-up	0	26
24286	2020-01-16 04:33:36	2020-01-16	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	398	delivery	5	35
24287	2020-01-16 04:35:31	2020-01-16	8	[{"id_menu":5,"count":1}]	4206	pick-up	0	8
24288	2020-01-16 04:37:34	2020-01-16	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9563	delivery	5	39
24289	2020-01-16 04:39:36	2020-01-16	9	[{"id_menu":6,"count":1}]	9574	delivery	5	14
24290	2020-01-16 04:41:48	2020-01-16	17	[{"id_menu":4,"count":3}]	2954	pick-up	0	17
24291	2020-01-16 04:42:00	2020-01-16	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	640	delivery	5	25
24292	2020-01-16 04:42:12	2020-01-16	14	[{"id_menu":2,"count":1}]	9570	delivery	5	19
24293	2020-01-16 04:42:24	2020-01-16	17	[{"id_menu":4,"count":1}]	7383	pick-up	0	17
24294	2020-01-16 04:42:54	2020-01-16	9	[{"id_menu":7,"count":1}]	9540	delivery	5	14
24295	2020-01-16 04:46:46	2020-01-16	9	[{"id_menu":6,"count":1}]	9422	delivery	5	14
24296	2020-01-16 04:50:28	2020-01-16	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9529	delivery	5	39
24297	2020-01-16 04:50:48	2020-01-16	8	[{"id_menu":5,"count":1}]	592	pick-up	0	8
24298	2020-01-16 04:56:44	2020-01-16	9	[{"id_menu":7,"count":1}]	6833	pick-up	0	9
24299	2020-01-16 05:13:59	2020-01-16	9	[{"id_menu":6,"count":1}]	9541	pick-up	0	9
24300	2020-01-16 05:41:08	2020-01-16	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	9495	delivery	5	45
24301	2020-01-16 05:42:42	2020-01-16	12	[{"id_menu":3,"count":1}]	1679	pick-up	0	12
24302	2020-01-16 05:46:42	2020-01-16	14	[{"id_menu":2,"count":1}]	9504	delivery	5	19
24303	2020-01-16 05:56:58	2020-01-16	17	[{"id_menu":4,"count":2}]	9555	delivery	5	22
24304	2020-01-16 06:06:18	2020-01-16	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	9561	delivery	5	45
24305	2020-01-16 06:17:12	2020-01-16	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9527	delivery	5	45
24306	2020-01-16 06:18:53	2020-01-16	8	[{"id_menu":5,"count":1}]	7678	delivery	5	13
24307	2020-01-16 06:19:23	2020-01-16	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1231	pick-up	0	29
24308	2020-01-16 06:29:12	2020-01-16	12	[{"id_menu":1,"count":1}]	541	pick-up	0	12
24309	2020-01-16 06:32:42	2020-01-16	12	[{"id_menu":1,"count":1}]	9520	delivery	5	17
24310	2020-01-16 06:36:28	2020-01-16	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2752	delivery	5	40
24311	2020-01-16 06:40:16	2020-01-16	12	[{"id_menu":1,"count":1}]	9496	delivery	5	17
24312	2020-01-16 07:01:47	2020-01-16	14	[{"id_menu":2,"count":2}]	4486	delivery	5	19
24313	2020-01-16 07:09:54	2020-01-16	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7462	delivery	5	47
24314	2020-01-16 07:21:08	2020-01-16	17	[{"id_menu":4,"count":1}]	3172	pick-up	0	17
24315	2020-01-16 07:27:09	2020-01-16	9	[{"id_menu":6,"count":2}]	9509	pick-up	0	9
24316	2020-01-16 07:27:43	2020-01-16	9	[{"id_menu":6,"count":1}]	9081	delivery	5	14
24317	2020-01-16 07:30:46	2020-01-16	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	9507	delivery	5	26
24318	2020-01-16 07:39:49	2020-01-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	9542	pick-up	0	26
24319	2020-01-16 07:52:35	2020-01-16	8	[{"id_menu":5,"count":1}]	9558	delivery	5	13
24320	2020-01-16 07:53:00	2020-01-16	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	9503	delivery	5	27
24321	2020-01-16 07:53:51	2020-01-16	17	[{"id_menu":5,"count":3},{"id_menu":6,"count":1}]	9530	delivery	5	22
24322	2020-01-16 08:04:09	2020-01-16	17	[{"id_menu":4,"count":1}]	9528	delivery	5	22
24323	2020-01-16 08:04:11	2020-01-16	12	[{"id_menu":1,"count":1}]	4099	pick-up	0	12
24324	2020-01-16 08:20:40	2020-01-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9553	delivery	5	23
24325	2020-01-16 08:22:01	2020-01-16	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	9040	delivery	5	45
24326	2020-01-16 08:22:24	2020-01-16	9	[{"id_menu":6,"count":1}]	9518	delivery	5	14
24327	2020-01-16 08:26:57	2020-01-16	9	[{"id_menu":7,"count":1}]	7167	delivery	5	14
24328	2020-01-16 08:29:56	2020-01-16	12	[{"id_menu":3,"count":1}]	4772	delivery	5	17
24329	2020-01-16 08:45:57	2020-01-16	9	[{"id_menu":7,"count":1}]	9537	delivery	5	14
24330	2020-01-16 08:49:52	2020-01-16	14	[{"id_menu":2,"count":1}]	3977	delivery	5	19
24331	2020-01-16 08:51:43	2020-01-16	9	[{"id_menu":7,"count":1}]	9551	delivery	5	14
24332	2020-01-16 08:57:24	2020-01-16	12	[{"id_menu":3,"count":1}]	9533	pick-up	0	12
24333	2020-01-16 09:08:47	2020-01-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	9488	delivery	5	28
24334	2020-01-16 09:11:25	2020-01-16	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	9534	delivery	5	40
24335	2020-01-16 09:18:03	2020-01-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	519	pick-up	0	23
24336	2020-01-16 09:31:35	2020-01-16	14	[{"id_menu":2,"count":1}]	8522	delivery	5	19
24337	2020-01-16 09:32:46	2020-01-16	9	[{"id_menu":6,"count":2}]	38	pick-up	0	9
24338	2020-01-16 09:38:10	2020-01-16	9	[{"id_menu":6,"count":1}]	9440	delivery	5	14
24339	2020-01-16 09:58:29	2020-01-16	8	[{"id_menu":5,"count":1}]	8090	pick-up	0	8
24340	2020-01-16 09:59:00	2020-01-16	9	[{"id_menu":6,"count":1}]	9564	delivery	5	14
24341	2020-01-16 09:59:41	2020-01-16	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	7188	delivery	5	40
24342	2020-01-16 10:02:09	2020-01-16	14	[{"id_menu":2,"count":1}]	9536	delivery	5	19
24343	2020-01-16 10:03:28	2020-01-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	3547	pick-up	0	21
24344	2020-01-16 10:17:55	2020-01-16	12	[{"id_menu":1,"count":1}]	9571	delivery	5	17
24345	2020-01-16 10:18:40	2020-01-16	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4804	pick-up	0	21
24346	2020-01-16 10:29:26	2020-01-16	8	[{"id_menu":5,"count":1}]	1563	delivery	5	13
24347	2020-01-16 10:34:11	2020-01-16	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8877	delivery	5	57
24348	2020-01-16 10:36:05	2020-01-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	9490	delivery	5	31
24349	2020-01-16 10:36:59	2020-01-16	12	[{"id_menu":1,"count":1}]	4393	pick-up	0	12
24350	2020-01-16 10:43:28	2020-01-16	9	[{"id_menu":6,"count":1}]	196	delivery	5	14
24351	2020-01-16 10:47:14	2020-01-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":3}]	2980	delivery	5	23
24352	2020-01-16 10:51:49	2020-01-16	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	5654	delivery	5	26
24353	2020-01-16 10:53:37	2020-01-16	8	[{"id_menu":5,"count":1}]	3243	delivery	5	13
24354	2020-01-16 10:55:29	2020-01-16	12	[{"id_menu":1,"count":1}]	9516	delivery	5	17
24355	2020-01-16 10:56:50	2020-01-16	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1293	delivery	5	26
24356	2020-01-16 11:03:35	2020-01-16	9	[{"id_menu":7,"count":1}]	964	delivery	5	14
24357	2020-01-16 11:11:10	2020-01-16	29	[{"id_menu":1,"count":3},{"id_menu":4,"count":1}]	4453	pick-up	0	29
24358	2020-01-16 11:15:45	2020-01-16	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	9393	delivery	5	31
24359	2020-01-16 11:20:02	2020-01-16	9	[{"id_menu":6,"count":1}]	122	pick-up	0	9
24360	2020-01-16 11:21:21	2020-01-16	12	[{"id_menu":3,"count":1}]	4863	pick-up	0	12
24361	2020-01-16 11:31:10	2020-01-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5675	delivery	5	22
24362	2020-01-16 11:33:17	2020-01-16	17	[{"id_menu":4,"count":1}]	2025	delivery	5	22
24363	2020-01-16 11:33:41	2020-01-16	8	[{"id_menu":5,"count":1}]	293	pick-up	0	8
24364	2020-01-16 11:42:11	2020-01-16	9	[{"id_menu":7,"count":1}]	1386	pick-up	0	9
24365	2020-01-16 11:59:18	2020-01-16	12	[{"id_menu":3,"count":1}]	9498	delivery	5	17
24366	2020-01-16 11:59:31	2020-01-16	8	[{"id_menu":5,"count":1}]	9296	delivery	5	13
24367	2020-01-16 12:05:45	2020-01-16	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3730	pick-up	0	25
24368	2020-01-16 12:09:49	2020-01-16	9	[{"id_menu":7,"count":1}]	7205	pick-up	0	9
24369	2020-01-16 12:11:47	2020-01-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	9524	pick-up	0	23
24370	2020-01-16 12:17:31	2020-01-16	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5963	delivery	5	22
24371	2020-01-16 12:28:07	2020-01-16	17	[{"id_menu":4,"count":2}]	9526	pick-up	0	17
24372	2020-01-16 12:28:55	2020-01-16	9	[{"id_menu":7,"count":1}]	3353	pick-up	0	9
24373	2020-01-16 12:34:02	2020-01-16	17	[{"id_menu":4,"count":1}]	3113	pick-up	0	17
24374	2020-01-16 12:42:13	2020-01-16	12	[{"id_menu":1,"count":1}]	4596	pick-up	0	12
24375	2020-01-16 12:57:03	2020-01-16	9	[{"id_menu":6,"count":1}]	2633	pick-up	0	9
24376	2020-01-16 12:58:14	2020-01-16	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9501	delivery	5	37
24377	2020-01-16 12:58:51	2020-01-16	8	[{"id_menu":5,"count":1}]	5373	pick-up	0	8
24378	2020-01-16 13:06:44	2020-01-16	9	[{"id_menu":7,"count":1}]	338	delivery	5	14
24379	2020-01-16 13:19:25	2020-01-16	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	7259	delivery	5	26
24380	2020-01-16 13:21:33	2020-01-16	8	[{"id_menu":5,"count":1}]	8683	delivery	5	13
24381	2020-01-16 13:25:31	2020-01-16	9	[{"id_menu":6,"count":1}]	9550	delivery	5	14
24382	2020-01-16 13:34:22	2020-01-16	12	[{"id_menu":1,"count":1}]	4184	pick-up	0	12
24383	2020-01-16 13:39:57	2020-01-16	14	[{"id_menu":2,"count":1}]	4094	pick-up	0	14
24384	2020-01-16 13:59:21	2020-01-16	9	[{"id_menu":6,"count":3}]	9539	delivery	5	14
24385	2020-01-16 14:00:01	2020-01-16	9	[{"id_menu":6,"count":1}]	2791	delivery	5	14
24386	2020-01-16 14:02:53	2020-01-16	14	[{"id_menu":2,"count":1}]	9573	pick-up	0	14
24387	2020-01-16 14:12:06	2020-01-16	9	[{"id_menu":7,"count":1}]	8269	delivery	5	14
24388	2020-01-16 14:24:41	2020-01-16	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9493	delivery	5	34
24389	2020-01-16 14:33:54	2020-01-16	8	[{"id_menu":5,"count":1}]	8272	delivery	5	13
24390	2020-01-16 14:36:06	2020-01-16	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9569	delivery	5	40
24391	2020-01-16 14:44:35	2020-01-16	9	[{"id_menu":6,"count":1}]	2097	pick-up	0	9
24392	2020-01-16 14:46:39	2020-01-16	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	568	delivery	5	34
24393	2020-01-16 14:48:19	2020-01-16	17	[{"id_menu":4,"count":1}]	4248	pick-up	0	17
24394	2020-01-16 14:54:17	2020-01-16	12	[{"id_menu":1,"count":1}]	9525	delivery	5	17
24395	2020-01-16 15:02:56	2020-01-16	9	[{"id_menu":6,"count":1}]	3940	pick-up	0	9
24396	2020-01-16 15:04:24	2020-01-16	9	[{"id_menu":6,"count":1}]	8705	delivery	5	14
24397	2020-01-16 15:10:00	2020-01-16	9	[{"id_menu":7,"count":1}]	9531	pick-up	0	9
24398	2020-01-16 15:16:43	2020-01-16	12	[{"id_menu":3,"count":1}]	9513	delivery	5	17
24399	2020-01-16 15:16:59	2020-01-16	14	[{"id_menu":2,"count":1}]	9519	delivery	5	19
24400	2020-01-16 15:22:12	2020-01-16	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	1854	pick-up	0	26
24401	2020-01-16 15:28:31	2020-01-16	14	[{"id_menu":2,"count":1}]	4350	pick-up	0	14
24402	2020-01-16 15:29:15	2020-01-16	9	[{"id_menu":6,"count":1}]	4451	pick-up	0	9
24403	2020-01-16 15:41:02	2020-01-16	8	[{"id_menu":5,"count":1}]	9489	delivery	5	13
24404	2020-01-16 15:41:25	2020-01-16	9	[{"id_menu":7,"count":1}]	9491	delivery	5	14
24405	2020-01-16 15:54:39	2020-01-16	8	[{"id_menu":5,"count":1}]	1865	delivery	5	13
24406	2020-01-16 15:56:57	2020-01-16	8	[{"id_menu":5,"count":1}]	4081	pick-up	0	8
24407	2020-01-16 16:13:06	2020-01-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7125	delivery	5	31
24408	2020-01-16 16:16:05	2020-01-16	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	9554	delivery	5	38
24409	2020-01-16 16:18:42	2020-01-16	17	[{"id_menu":4,"count":1}]	1337	pick-up	0	17
24410	2020-01-16 16:21:58	2020-01-16	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9510	delivery	5	34
24411	2020-01-16 16:25:54	2020-01-16	9	[{"id_menu":6,"count":1}]	9517	delivery	5	14
24412	2020-01-16 16:34:41	2020-01-16	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9508	pick-up	0	25
24413	2020-01-16 16:39:44	2020-01-16	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9506	delivery	5	36
24414	2020-01-16 16:43:04	2020-01-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	9487	delivery	5	28
24415	2020-01-16 16:48:25	2020-01-16	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	9492	delivery	5	34
24416	2020-01-16 16:57:47	2020-01-16	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	6366	delivery	5	46
24417	2020-01-16 17:01:59	2020-01-16	12	[{"id_menu":3,"count":1}]	4847	delivery	5	17
24418	2020-01-16 17:02:16	2020-01-16	12	[{"id_menu":3,"count":1}]	8883	delivery	5	17
24419	2020-01-16 17:04:42	2020-01-16	9	[{"id_menu":7,"count":2}]	9548	delivery	5	14
24420	2020-01-16 17:05:08	2020-01-16	12	[{"id_menu":3,"count":1}]	9559	delivery	5	17
24421	2020-01-16 17:08:39	2020-01-16	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6341	delivery	5	43
24422	2020-01-16 17:12:35	2020-01-16	17	[{"id_menu":4,"count":1}]	1795	delivery	5	22
24423	2020-01-16 17:13:50	2020-01-16	14	[{"id_menu":2,"count":1}]	2159	pick-up	0	14
24424	2020-01-16 17:28:15	2020-01-16	9	[{"id_menu":6,"count":1}]	5218	delivery	5	14
24425	2020-01-16 17:32:59	2020-01-16	9	[{"id_menu":6,"count":1}]	8077	pick-up	0	9
24426	2020-01-16 17:36:34	2020-01-16	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9205	delivery	5	31
24427	2020-01-16 17:56:04	2020-01-16	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	9511	delivery	5	26
24428	2020-01-16 17:57:31	2020-01-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9500	delivery	5	22
24429	2020-01-16 17:58:05	2020-01-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3909	pick-up	0	26
24430	2020-01-16 17:58:51	2020-01-16	8	[{"id_menu":5,"count":1}]	2260	pick-up	0	8
24431	2020-01-16 17:59:42	2020-01-16	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	7942	delivery	5	44
24432	2020-01-16 18:12:15	2020-01-16	9	[{"id_menu":7,"count":1}]	9104	pick-up	0	9
24433	2020-01-16 18:22:53	2020-01-16	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	213	delivery	5	28
24434	2020-01-16 18:25:44	2020-01-16	12	[{"id_menu":1,"count":1}]	4014	pick-up	0	12
24435	2020-01-16 18:31:22	2020-01-16	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	9560	delivery	5	34
24436	2020-01-16 18:48:54	2020-01-16	9	[{"id_menu":7,"count":1}]	8230	delivery	5	14
24437	2020-01-16 18:51:14	2020-01-16	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	3623	delivery	5	26
24438	2020-01-16 18:52:14	2020-01-16	9	[{"id_menu":6,"count":1}]	9053	pick-up	0	9
24439	2020-01-16 18:57:01	2020-01-16	14	[{"id_menu":2,"count":1}]	1742	pick-up	0	14
24440	2020-01-16 19:02:36	2020-01-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9556	delivery	5	23
24441	2020-01-16 19:10:52	2020-01-16	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2443	pick-up	0	29
24442	2020-01-16 19:14:52	2020-01-16	9	[{"id_menu":6,"count":1}]	5597	delivery	5	14
24443	2020-01-16 19:30:59	2020-01-16	9	[{"id_menu":6,"count":1}]	4712	delivery	5	14
24444	2020-01-16 19:32:51	2020-01-16	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2386	delivery	5	46
24445	2020-01-16 19:47:07	2020-01-16	12	[{"id_menu":1,"count":1}]	232	pick-up	0	12
24446	2020-01-16 19:50:20	2020-01-16	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	9543	delivery	5	22
24447	2020-01-16 19:56:44	2020-01-16	9	[{"id_menu":7,"count":1}]	1296	pick-up	0	9
24448	2020-01-16 20:14:52	2020-01-16	9	[{"id_menu":7,"count":1}]	816	delivery	5	14
24449	2020-01-16 20:16:39	2020-01-16	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	6775	pick-up	0	22
24450	2020-01-16 20:19:50	2020-01-16	14	[{"id_menu":2,"count":1}]	9505	pick-up	0	14
24451	2020-01-16 20:20:33	2020-01-16	14	[{"id_menu":2,"count":1}]	1014	pick-up	0	14
24452	2020-01-16 20:37:52	2020-01-16	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8656	delivery	5	35
24453	2020-01-16 20:38:16	2020-01-16	14	[{"id_menu":2,"count":1}]	9566	pick-up	0	14
24454	2020-01-16 20:42:08	2020-01-16	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3318	pick-up	0	33
24455	2020-01-16 20:44:05	2020-01-16	12	[{"id_menu":1,"count":1}]	9557	delivery	5	17
24456	2020-01-16 20:49:14	2020-01-16	9	[{"id_menu":7,"count":1}]	153	pick-up	0	9
24457	2020-01-16 20:52:13	2020-01-16	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	304	delivery	5	36
24458	2020-01-16 20:55:58	2020-01-16	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	9544	delivery	5	34
24459	2020-01-16 21:00:17	2020-01-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	9538	pick-up	0	23
24460	2020-01-16 21:05:11	2020-01-16	9	[{"id_menu":6,"count":1}]	2480	pick-up	0	9
24461	2020-01-16 21:06:41	2020-01-16	14	[{"id_menu":2,"count":1}]	4622	delivery	5	19
24462	2020-01-16 21:22:24	2020-01-16	8	[{"id_menu":5,"count":1}]	6659	delivery	5	13
24463	2020-01-16 21:32:11	2020-01-16	14	[{"id_menu":2,"count":1}]	5295	delivery	5	19
24464	2020-01-16 21:36:51	2020-01-16	17	[{"id_menu":4,"count":1}]	7550	pick-up	0	17
24465	2020-01-16 21:39:01	2020-01-16	8	[{"id_menu":5,"count":1}]	8757	delivery	5	13
24466	2020-01-16 21:48:05	2020-01-16	14	[{"id_menu":2,"count":2}]	3424	delivery	5	19
24467	2020-01-16 21:54:30	2020-01-16	9	[{"id_menu":6,"count":1}]	9568	delivery	5	14
24468	2020-01-16 21:54:53	2020-01-16	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7509	delivery	5	45
24469	2020-01-16 21:57:10	2020-01-16	9	[{"id_menu":6,"count":1}]	1263	delivery	5	14
24470	2020-01-16 22:00:12	2020-01-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	9497	delivery	5	31
24471	2020-01-16 22:08:13	2020-01-16	12	[{"id_menu":3,"count":1}]	2674	pick-up	0	12
24472	2020-01-16 22:10:16	2020-01-16	17	[{"id_menu":4,"count":1}]	5329	delivery	5	22
24473	2020-01-16 22:13:26	2020-01-16	8	[{"id_menu":5,"count":1}]	5050	pick-up	0	8
24474	2020-01-16 22:13:52	2020-01-16	9	[{"id_menu":7,"count":1}]	9521	delivery	5	14
24475	2020-01-16 22:16:00	2020-01-16	17	[{"id_menu":4,"count":1}]	8311	delivery	5	22
24476	2020-01-16 22:28:02	2020-01-16	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	9572	delivery	5	34
24477	2020-01-16 22:29:03	2020-01-16	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4140	delivery	5	48
24478	2020-01-16 22:31:02	2020-01-16	17	[{"id_menu":5,"count":3},{"id_menu":6,"count":1}]	9547	delivery	5	22
24479	2020-01-16 22:44:45	2020-01-16	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	902	delivery	5	27
24480	2020-01-16 22:59:41	2020-01-16	9	[{"id_menu":6,"count":1}]	4986	pick-up	0	9
24481	2020-01-16 23:02:58	2020-01-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":3}]	4255	delivery	5	31
24482	2020-01-16 23:19:22	2020-01-16	12	[{"id_menu":3,"count":1}]	9546	delivery	5	17
24483	2020-01-16 23:22:48	2020-01-16	8	[{"id_menu":5,"count":1}]	315	pick-up	0	8
24484	2020-01-16 23:26:12	2020-01-16	17	[{"id_menu":4,"count":1}]	7044	delivery	5	22
24485	2020-01-16 23:30:03	2020-01-16	9	[{"id_menu":7,"count":1}]	9575	pick-up	0	9
24486	2020-01-16 23:33:23	2020-01-16	8	[{"id_menu":5,"count":1}]	3736	pick-up	0	8
24487	2020-01-16 23:37:56	2020-01-16	12	[{"id_menu":3,"count":1}]	8666	delivery	5	17
24488	2020-01-16 23:40:04	2020-01-16	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	3887	delivery	5	26
24489	2020-01-16 23:41:33	2020-01-16	14	[{"id_menu":2,"count":1}]	8813	delivery	5	19
24490	2020-01-16 23:54:01	2020-01-16	9	[{"id_menu":7,"count":1}]	3066	pick-up	0	9
24491	2020-01-17 00:00:27	2020-01-17	9	[{"id_menu":7,"count":1}]	9633	delivery	5	14
24492	2020-01-17 00:03:22	2020-01-17	12	[{"id_menu":1,"count":1}]	1403	pick-up	0	12
24493	2020-01-17 00:31:39	2020-01-17	14	[{"id_menu":2,"count":1}]	1287	pick-up	0	14
24494	2020-01-17 00:49:59	2020-01-17	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	9610	pick-up	0	31
24495	2020-01-17 00:54:17	2020-01-17	12	[{"id_menu":1,"count":1}]	1565	delivery	5	17
24496	2020-01-17 00:55:18	2020-01-17	9	[{"id_menu":7,"count":1}]	9531	pick-up	0	9
24497	2020-01-17 00:58:47	2020-01-17	8	[{"id_menu":5,"count":1}]	8994	delivery	5	13
24498	2020-01-17 00:59:04	2020-01-17	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	9654	pick-up	0	22
24499	2020-01-17 00:59:40	2020-01-17	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	9603	delivery	5	26
24500	2020-01-17 01:04:53	2020-01-17	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4546	pick-up	0	31
24501	2020-01-17 01:09:44	2020-01-17	9	[{"id_menu":6,"count":1}]	2492	pick-up	0	9
24502	2020-01-17 01:11:27	2020-01-17	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	310	pick-up	0	25
24503	2020-01-17 01:24:29	2020-01-17	14	[{"id_menu":2,"count":1}]	2608	delivery	5	19
24504	2020-01-17 01:49:22	2020-01-17	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	9614	delivery	5	31
24505	2020-01-17 01:56:12	2020-01-17	9	[{"id_menu":6,"count":1}]	4754	delivery	5	14
24506	2020-01-17 01:58:35	2020-01-17	14	[{"id_menu":2,"count":1}]	2392	delivery	5	19
24507	2020-01-17 02:00:24	2020-01-17	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9619	delivery	5	22
24508	2020-01-17 02:05:02	2020-01-17	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	6729	delivery	5	25
24509	2020-01-17 02:15:07	2020-01-17	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3659	pick-up	0	21
24510	2020-01-17 02:21:38	2020-01-17	9	[{"id_menu":7,"count":2}]	7883	delivery	5	14
24511	2020-01-17 02:25:26	2020-01-17	9	[{"id_menu":7,"count":1}]	9590	delivery	5	14
24512	2020-01-17 02:27:12	2020-01-17	9	[{"id_menu":6,"count":1}]	9648	delivery	5	14
24513	2020-01-17 02:33:54	2020-01-17	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	9612	delivery	5	27
24514	2020-01-17 02:35:46	2020-01-17	17	[{"id_menu":4,"count":1}]	2373	pick-up	0	17
24515	2020-01-17 02:39:33	2020-01-17	17	[{"id_menu":4,"count":1}]	4373	delivery	5	22
24516	2020-01-17 02:39:37	2020-01-17	9	[{"id_menu":7,"count":1}]	8448	pick-up	0	9
24517	2020-01-17 02:46:20	2020-01-17	17	[{"id_menu":4,"count":1}]	1093	delivery	5	22
24518	2020-01-17 02:49:49	2020-01-17	14	[{"id_menu":2,"count":1}]	9609	delivery	5	19
24519	2020-01-17 03:00:55	2020-01-17	12	[{"id_menu":1,"count":1}]	8874	delivery	5	17
24520	2020-01-17 03:07:04	2020-01-17	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	9583	delivery	5	40
24521	2020-01-17 03:17:37	2020-01-17	12	[{"id_menu":1,"count":1}]	1276	delivery	5	17
24522	2020-01-17 03:21:08	2020-01-17	14	[{"id_menu":2,"count":1}]	2536	delivery	5	19
24523	2020-01-17 03:26:13	2020-01-17	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	4547	delivery	5	25
24524	2020-01-17 03:30:09	2020-01-17	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1409	pick-up	0	29
24525	2020-01-17 03:50:21	2020-01-17	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5943	pick-up	0	34
24526	2020-01-17 03:55:19	2020-01-17	9	[{"id_menu":6,"count":1}]	9584	delivery	5	14
24527	2020-01-17 04:03:47	2020-01-17	9	[{"id_menu":6,"count":1}]	5683	pick-up	0	9
24528	2020-01-17 04:11:16	2020-01-17	9	[{"id_menu":7,"count":1}]	9636	pick-up	0	9
24529	2020-01-17 04:37:54	2020-01-17	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	8956	pick-up	0	24
24530	2020-01-17 04:45:29	2020-01-17	12	[{"id_menu":3,"count":1}]	9505	pick-up	0	12
24531	2020-01-17 04:46:00	2020-01-17	9	[{"id_menu":6,"count":1}]	9596	delivery	5	14
24532	2020-01-17 04:56:40	2020-01-17	14	[{"id_menu":2,"count":1}]	7921	delivery	5	19
24533	2020-01-17 04:59:28	2020-01-17	17	[{"id_menu":4,"count":1}]	541	delivery	5	22
24534	2020-01-17 05:10:06	2020-01-17	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4592	delivery	5	26
24535	2020-01-17 05:16:19	2020-01-17	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8397	delivery	5	22
24536	2020-01-17 05:19:27	2020-01-17	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	8358	pick-up	0	31
24537	2020-01-17 05:21:35	2020-01-17	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	9597	delivery	5	48
24538	2020-01-17 05:25:17	2020-01-17	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	9659	delivery	5	31
24539	2020-01-17 05:38:48	2020-01-17	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9650	delivery	5	36
24540	2020-01-17 06:16:27	2020-01-17	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1183	pick-up	0	32
24541	2020-01-17 06:28:15	2020-01-17	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	660	pick-up	0	29
24542	2020-01-17 06:40:03	2020-01-17	12	[{"id_menu":1,"count":1}]	9649	delivery	5	17
24543	2020-01-17 06:43:21	2020-01-17	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	5095	delivery	5	40
24544	2020-01-17 06:43:37	2020-01-17	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	4963	delivery	5	29
24545	2020-01-17 06:50:30	2020-01-17	9	[{"id_menu":6,"count":1}]	9662	delivery	5	14
24546	2020-01-17 07:04:07	2020-01-17	8	[{"id_menu":5,"count":1}]	883	pick-up	0	8
24547	2020-01-17 07:08:22	2020-01-17	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4794	delivery	5	22
24548	2020-01-17 07:08:23	2020-01-17	9	[{"id_menu":6,"count":1}]	821	pick-up	0	9
24549	2020-01-17 07:13:56	2020-01-17	8	[{"id_menu":5,"count":1}]	4982	delivery	5	13
24550	2020-01-17 07:15:33	2020-01-17	14	[{"id_menu":2,"count":1}]	1365	delivery	5	19
24551	2020-01-17 07:20:29	2020-01-17	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9663	delivery	5	30
24552	2020-01-17 07:32:29	2020-01-17	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1545	delivery	5	31
24553	2020-01-17 07:34:07	2020-01-17	8	[{"id_menu":5,"count":1}]	8966	pick-up	0	8
24554	2020-01-17 07:54:28	2020-01-17	12	[{"id_menu":1,"count":1}]	3949	pick-up	0	12
24555	2020-01-17 07:55:00	2020-01-17	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	9664	delivery	5	31
24556	2020-01-17 08:54:31	2020-01-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9588	pick-up	0	23
24557	2020-01-17 08:58:09	2020-01-17	9	[{"id_menu":6,"count":1}]	6328	delivery	5	14
24558	2020-01-17 08:59:51	2020-01-17	12	[{"id_menu":1,"count":1}]	9665	delivery	5	17
24559	2020-01-17 09:02:25	2020-01-17	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2791	delivery	5	35
24560	2020-01-17 09:05:14	2020-01-17	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	9644	pick-up	0	35
24561	2020-01-17 09:05:57	2020-01-17	12	[{"id_menu":3,"count":1}]	9606	delivery	5	17
24562	2020-01-17 09:11:35	2020-01-17	14	[{"id_menu":2,"count":2}]	6419	delivery	5	19
24563	2020-01-17 09:35:43	2020-01-17	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	143	pick-up	0	31
24564	2020-01-17 09:52:18	2020-01-17	17	[{"id_menu":4,"count":1}]	9627	delivery	5	22
24565	2020-01-17 09:54:35	2020-01-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1491	delivery	5	28
24566	2020-01-17 09:58:21	2020-01-17	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	9613	delivery	5	39
24567	2020-01-17 10:06:03	2020-01-17	14	[{"id_menu":2,"count":1}]	8251	pick-up	0	14
24568	2020-01-17 10:11:52	2020-01-17	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	9595	delivery	5	43
24569	2020-01-17 10:33:01	2020-01-17	12	[{"id_menu":1,"count":2}]	9640	pick-up	0	12
24570	2020-01-17 10:33:38	2020-01-17	9	[{"id_menu":7,"count":1}]	9578	delivery	5	14
24571	2020-01-17 10:43:35	2020-01-17	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1293	delivery	5	31
24572	2020-01-17 10:45:40	2020-01-17	17	[{"id_menu":4,"count":1}]	5881	delivery	5	22
24573	2020-01-17 10:59:35	2020-01-17	9	[{"id_menu":7,"count":1}]	2959	pick-up	0	9
24574	2020-01-17 10:59:41	2020-01-17	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5077	delivery	5	43
24575	2020-01-17 11:12:20	2020-01-17	9	[{"id_menu":6,"count":1}]	9632	delivery	5	14
24576	2020-01-17 11:13:10	2020-01-17	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	3364	delivery	5	29
24577	2020-01-17 11:18:17	2020-01-17	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	9657	delivery	5	27
24578	2020-01-17 11:20:44	2020-01-17	8	[{"id_menu":5,"count":1}]	4370	pick-up	0	8
24579	2020-01-17 11:29:44	2020-01-17	9	[{"id_menu":6,"count":1}]	2332	delivery	5	14
24580	2020-01-17 11:31:52	2020-01-17	17	[{"id_menu":4,"count":1}]	9095	delivery	5	22
24581	2020-01-17 11:36:39	2020-01-17	14	[{"id_menu":2,"count":1}]	4506	pick-up	0	14
24582	2020-01-17 11:51:17	2020-01-17	14	[{"id_menu":2,"count":1}]	9604	delivery	5	19
24583	2020-01-17 11:55:08	2020-01-17	9	[{"id_menu":7,"count":1}]	9624	delivery	5	14
24584	2020-01-17 11:56:29	2020-01-17	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	3695	delivery	5	26
24585	2020-01-17 12:04:51	2020-01-17	9	[{"id_menu":7,"count":1}]	6101	pick-up	0	9
24586	2020-01-17 12:18:40	2020-01-17	17	[{"id_menu":4,"count":1}]	7755	delivery	5	22
24587	2020-01-17 12:33:39	2020-01-17	9	[{"id_menu":7,"count":1}]	6444	delivery	5	14
24588	2020-01-17 12:34:13	2020-01-17	17	[{"id_menu":4,"count":1}]	610	pick-up	0	17
24589	2020-01-17 12:36:46	2020-01-17	8	[{"id_menu":5,"count":1}]	9638	delivery	5	13
24590	2020-01-17 12:51:20	2020-01-17	9	[{"id_menu":6,"count":1}]	3308	delivery	5	14
24591	2020-01-17 12:51:40	2020-01-17	17	[{"id_menu":4,"count":1}]	8561	pick-up	0	17
24592	2020-01-17 12:54:25	2020-01-17	14	[{"id_menu":2,"count":1}]	2052	delivery	5	19
24593	2020-01-17 13:04:40	2020-01-17	8	[{"id_menu":5,"count":1}]	9643	delivery	5	13
24594	2020-01-17 13:16:23	2020-01-17	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	9641	delivery	5	28
24595	2020-01-17 13:27:17	2020-01-17	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	8820	delivery	5	39
24596	2020-01-17 13:43:24	2020-01-17	12	[{"id_menu":3,"count":1}]	3372	delivery	5	17
24597	2020-01-17 14:03:34	2020-01-17	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7828	delivery	5	45
24598	2020-01-17 14:05:41	2020-01-17	8	[{"id_menu":5,"count":1}]	9618	delivery	5	13
24599	2020-01-17 14:08:39	2020-01-17	9	[{"id_menu":6,"count":1}]	9592	delivery	5	14
24600	2020-01-17 14:11:44	2020-01-17	17	[{"id_menu":4,"count":1}]	9666	pick-up	0	17
24601	2020-01-17 14:20:25	2020-01-17	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	4061	delivery	5	25
24602	2020-01-17 14:25:18	2020-01-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	7261	delivery	5	31
24603	2020-01-17 14:27:50	2020-01-17	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2139	pick-up	0	34
24604	2020-01-17 14:28:52	2020-01-17	8	[{"id_menu":5,"count":1}]	9623	delivery	5	13
24605	2020-01-17 14:47:21	2020-01-17	12	[{"id_menu":1,"count":1}]	9582	delivery	5	17
24606	2020-01-17 14:48:53	2020-01-17	9	[{"id_menu":6,"count":1}]	678	pick-up	0	9
24607	2020-01-17 14:51:49	2020-01-17	17	[{"id_menu":4,"count":1}]	1657	pick-up	0	17
24608	2020-01-17 15:09:28	2020-01-17	8	[{"id_menu":5,"count":1}]	5050	delivery	5	13
24609	2020-01-17 15:13:34	2020-01-17	9	[{"id_menu":6,"count":1}]	8303	pick-up	0	9
24610	2020-01-17 15:15:11	2020-01-17	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4870	pick-up	0	21
24678	2020-01-18 00:17:35	2020-01-18	14	[{"id_menu":2,"count":1}]	9764	delivery	5	19
24611	2020-01-17 15:27:22	2020-01-17	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7183	delivery	5	48
24612	2020-01-17 15:38:14	2020-01-17	9	[{"id_menu":7,"count":1}]	9611	delivery	5	14
24613	2020-01-17 15:44:45	2020-01-17	12	[{"id_menu":1,"count":1}]	1095	delivery	5	17
24614	2020-01-17 15:57:09	2020-01-17	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9625	delivery	5	22
24615	2020-01-17 16:07:55	2020-01-17	9	[{"id_menu":6,"count":2}]	9642	delivery	5	14
24616	2020-01-17 16:07:57	2020-01-17	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	9637	delivery	5	31
24617	2020-01-17 16:14:19	2020-01-17	9	[{"id_menu":6,"count":1}]	4707	delivery	5	14
24618	2020-01-17 16:15:06	2020-01-17	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7490	delivery	5	22
24619	2020-01-17 16:47:35	2020-01-17	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	281	pick-up	0	21
24620	2020-01-17 16:52:45	2020-01-17	9	[{"id_menu":7,"count":1}]	2633	delivery	5	14
24621	2020-01-17 16:53:24	2020-01-17	9	[{"id_menu":6,"count":1}]	1897	delivery	5	14
24622	2020-01-17 17:22:02	2020-01-17	8	[{"id_menu":5,"count":1}]	4739	delivery	5	13
24623	2020-01-17 17:24:15	2020-01-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2368	delivery	5	28
24624	2020-01-17 17:24:19	2020-01-17	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	9660	delivery	5	28
24625	2020-01-17 17:26:16	2020-01-17	9	[{"id_menu":6,"count":2}]	9587	delivery	5	14
24626	2020-01-17 17:39:00	2020-01-17	14	[{"id_menu":2,"count":2}]	7140	pick-up	0	14
24627	2020-01-17 17:43:54	2020-01-17	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2519	pick-up	0	26
24628	2020-01-17 17:54:53	2020-01-17	12	[{"id_menu":3,"count":1}]	6141	pick-up	0	12
24629	2020-01-17 18:12:01	2020-01-17	12	[{"id_menu":1,"count":1}]	9605	delivery	5	17
24630	2020-01-17 18:17:11	2020-01-17	12	[{"id_menu":3,"count":1}]	7963	delivery	5	17
24631	2020-01-17 18:38:11	2020-01-17	14	[{"id_menu":2,"count":1}]	3491	pick-up	0	14
24632	2020-01-17 18:57:24	2020-01-17	9	[{"id_menu":6,"count":1}]	4350	delivery	5	14
24633	2020-01-17 19:12:40	2020-01-17	12	[{"id_menu":1,"count":1}]	9575	pick-up	0	12
24634	2020-01-17 19:47:04	2020-01-17	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4330	pick-up	0	26
24635	2020-01-17 19:54:15	2020-01-17	17	[{"id_menu":4,"count":1}]	172	delivery	5	22
24636	2020-01-17 20:00:19	2020-01-17	12	[{"id_menu":3,"count":1}]	397	delivery	5	17
24637	2020-01-17 20:02:03	2020-01-17	12	[{"id_menu":3,"count":1}]	4223	delivery	5	17
24638	2020-01-17 20:07:33	2020-01-17	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5186	delivery	5	57
24639	2020-01-17 20:10:53	2020-01-17	9	[{"id_menu":6,"count":1}]	6164	pick-up	0	9
24640	2020-01-17 20:18:34	2020-01-17	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	9661	delivery	5	27
24641	2020-01-17 20:23:09	2020-01-17	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6515	delivery	5	48
24642	2020-01-17 20:30:31	2020-01-17	17	[{"id_menu":4,"count":1}]	1736	pick-up	0	17
24643	2020-01-17 20:32:25	2020-01-17	9	[{"id_menu":6,"count":1}]	9602	pick-up	0	9
24644	2020-01-17 20:51:11	2020-01-17	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	9580	delivery	5	26
24645	2020-01-17 20:55:10	2020-01-17	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2664	delivery	5	35
24646	2020-01-17 20:58:56	2020-01-17	17	[{"id_menu":4,"count":1}]	8389	delivery	5	22
24647	2020-01-17 21:00:16	2020-01-17	17	[{"id_menu":4,"count":2}]	3069	pick-up	0	17
24648	2020-01-17 21:14:41	2020-01-17	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	9371	delivery	5	34
24649	2020-01-17 21:25:49	2020-01-17	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	71	pick-up	0	21
24650	2020-01-17 21:31:20	2020-01-17	9	[{"id_menu":7,"count":1}]	9652	delivery	5	14
24651	2020-01-17 21:31:25	2020-01-17	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	535	delivery	5	38
24652	2020-01-17 21:41:50	2020-01-17	8	[{"id_menu":5,"count":1}]	2551	pick-up	0	8
24653	2020-01-17 21:54:05	2020-01-17	8	[{"id_menu":5,"count":1}]	9589	delivery	5	13
24654	2020-01-17 21:57:44	2020-01-17	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	9628	pick-up	0	26
24655	2020-01-17 22:08:05	2020-01-17	14	[{"id_menu":2,"count":1}]	9630	delivery	5	19
24656	2020-01-17 22:12:37	2020-01-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2123	pick-up	0	26
24657	2020-01-17 22:20:24	2020-01-17	8	[{"id_menu":5,"count":1}]	6201	delivery	5	13
24658	2020-01-17 22:26:29	2020-01-17	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	257	pick-up	0	35
24659	2020-01-17 22:32:40	2020-01-17	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3736	pick-up	0	17
24660	2020-01-17 22:35:25	2020-01-17	12	[{"id_menu":3,"count":1}]	9601	pick-up	0	12
24661	2020-01-17 22:49:24	2020-01-17	12	[{"id_menu":1,"count":1}]	1649	pick-up	0	12
24662	2020-01-17 22:53:30	2020-01-17	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	484	pick-up	0	21
24663	2020-01-17 22:54:14	2020-01-17	14	[{"id_menu":2,"count":1}]	9634	pick-up	0	14
24664	2020-01-17 23:11:30	2020-01-17	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	4139	delivery	5	26
24665	2020-01-17 23:20:23	2020-01-17	14	[{"id_menu":2,"count":1}]	7591	delivery	5	19
24666	2020-01-17 23:22:36	2020-01-17	8	[{"id_menu":5,"count":1}]	9593	pick-up	0	8
24667	2020-01-17 23:38:25	2020-01-17	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	9629	pick-up	0	21
24668	2020-01-17 23:49:06	2020-01-17	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	9622	delivery	5	26
24669	2020-01-17 23:53:38	2020-01-17	8	[{"id_menu":5,"count":1}]	9213	delivery	5	13
24670	2020-01-17 23:54:02	2020-01-17	9	[{"id_menu":7,"count":1}]	9615	delivery	5	14
24671	2020-01-17 23:54:39	2020-01-17	9	[{"id_menu":6,"count":1}]	9594	delivery	5	14
24672	2020-01-17 23:57:15	2020-01-17	14	[{"id_menu":2,"count":1}]	8347	delivery	5	19
24673	2020-01-18 00:06:16	2020-01-18	9	[{"id_menu":6,"count":1}]	1255	pick-up	0	9
24674	2020-01-18 00:06:17	2020-01-18	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	9740	delivery	5	26
24675	2020-01-18 00:13:50	2020-01-18	12	[{"id_menu":1,"count":1}]	6410	pick-up	0	12
24676	2020-01-18 00:15:43	2020-01-18	14	[{"id_menu":2,"count":2}]	9705	delivery	5	19
24677	2020-01-18 00:16:39	2020-01-18	8	[{"id_menu":5,"count":1}]	3751	delivery	5	13
24679	2020-01-18 00:23:07	2020-01-18	8	[{"id_menu":5,"count":1}]	3242	pick-up	0	8
24680	2020-01-18 00:25:29	2020-01-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9695	delivery	5	23
24681	2020-01-18 00:44:24	2020-01-18	12	[{"id_menu":3,"count":1}]	6882	delivery	5	17
24682	2020-01-18 00:46:56	2020-01-18	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	464	pick-up	0	25
24683	2020-01-18 01:06:29	2020-01-18	9	[{"id_menu":6,"count":1}]	9765	delivery	5	14
24684	2020-01-18 01:10:11	2020-01-18	9	[{"id_menu":7,"count":1}]	2962	pick-up	0	9
24685	2020-01-18 01:11:06	2020-01-18	9	[{"id_menu":6,"count":1}]	5637	pick-up	0	9
24686	2020-01-18 01:14:31	2020-01-18	14	[{"id_menu":2,"count":1}]	9739	pick-up	0	14
24687	2020-01-18 01:20:24	2020-01-18	14	[{"id_menu":2,"count":1}]	9667	pick-up	0	14
24688	2020-01-18 01:25:20	2020-01-18	9	[{"id_menu":7,"count":1}]	232	pick-up	0	9
24689	2020-01-18 01:30:37	2020-01-18	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9743	delivery	5	31
24690	2020-01-18 01:33:28	2020-01-18	9	[{"id_menu":7,"count":1}]	3393	delivery	5	14
24691	2020-01-18 01:36:55	2020-01-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9669	delivery	5	28
24692	2020-01-18 01:41:28	2020-01-18	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	408	pick-up	0	26
24693	2020-01-18 01:48:54	2020-01-18	9	[{"id_menu":6,"count":1}]	4757	delivery	5	14
24694	2020-01-18 01:53:31	2020-01-18	9	[{"id_menu":7,"count":1}]	2921	pick-up	0	9
24695	2020-01-18 01:54:50	2020-01-18	17	[{"id_menu":4,"count":1}]	4800	pick-up	0	17
24696	2020-01-18 02:12:59	2020-01-18	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2513	pick-up	0	29
24697	2020-01-18 02:16:16	2020-01-18	9	[{"id_menu":7,"count":1}]	9677	delivery	5	14
24698	2020-01-18 02:19:55	2020-01-18	9	[{"id_menu":7,"count":1}]	2358	pick-up	0	9
24699	2020-01-18 02:25:46	2020-01-18	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9690	delivery	5	22
24700	2020-01-18 02:28:59	2020-01-18	14	[{"id_menu":2,"count":1}]	3172	pick-up	0	14
24701	2020-01-18 02:37:10	2020-01-18	9	[{"id_menu":6,"count":1}]	9722	delivery	5	14
24702	2020-01-18 02:43:30	2020-01-18	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	4407	delivery	5	31
24703	2020-01-18 02:44:05	2020-01-18	14	[{"id_menu":2,"count":1}]	7741	delivery	5	19
24704	2020-01-18 02:44:45	2020-01-18	8	[{"id_menu":5,"count":1}]	9737	delivery	5	13
24705	2020-01-18 02:53:50	2020-01-18	9	[{"id_menu":7,"count":3}]	9729	delivery	5	14
24706	2020-01-18 03:08:47	2020-01-18	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9670	delivery	5	30
24707	2020-01-18 03:19:19	2020-01-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	9725	delivery	5	23
24708	2020-01-18 03:20:29	2020-01-18	8	[{"id_menu":5,"count":1}]	3074	delivery	5	13
24709	2020-01-18 03:23:12	2020-01-18	9	[{"id_menu":6,"count":1}]	7683	pick-up	0	9
24710	2020-01-18 03:28:20	2020-01-18	12	[{"id_menu":1,"count":1}]	6468	delivery	5	17
24711	2020-01-18 03:30:23	2020-01-18	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7217	delivery	5	31
24712	2020-01-18 03:33:25	2020-01-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5790	pick-up	0	23
24713	2020-01-18 03:39:50	2020-01-18	12	[{"id_menu":1,"count":1}]	9699	delivery	5	17
24714	2020-01-18 03:42:22	2020-01-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5843	delivery	5	28
24715	2020-01-18 03:46:25	2020-01-18	8	[{"id_menu":5,"count":1}]	9686	delivery	5	13
24716	2020-01-18 03:48:12	2020-01-18	9	[{"id_menu":7,"count":1}]	6919	delivery	5	14
24717	2020-01-18 03:48:45	2020-01-18	9	[{"id_menu":7,"count":1}]	9751	delivery	5	14
24718	2020-01-18 03:50:34	2020-01-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	81	delivery	5	28
24719	2020-01-18 03:53:34	2020-01-18	14	[{"id_menu":2,"count":1}]	2050	pick-up	0	14
24720	2020-01-18 03:58:50	2020-01-18	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9758	delivery	5	22
24721	2020-01-18 04:03:01	2020-01-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	9668	delivery	5	23
24722	2020-01-18 04:18:31	2020-01-18	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6674	delivery	5	31
24723	2020-01-18 04:35:03	2020-01-18	9	[{"id_menu":7,"count":1}]	9720	delivery	5	14
24724	2020-01-18 04:35:34	2020-01-18	17	[{"id_menu":4,"count":1}]	8265	pick-up	0	17
24725	2020-01-18 04:52:37	2020-01-18	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	9724	delivery	5	22
24726	2020-01-18 04:54:50	2020-01-18	14	[{"id_menu":2,"count":2}]	8139	delivery	5	19
24727	2020-01-18 05:07:54	2020-01-18	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	9746	delivery	5	26
24728	2020-01-18 05:08:21	2020-01-18	17	[{"id_menu":4,"count":2}]	9684	delivery	5	22
24729	2020-01-18 05:17:23	2020-01-18	9	[{"id_menu":6,"count":1}]	9762	delivery	5	14
24730	2020-01-18 05:18:33	2020-01-18	14	[{"id_menu":2,"count":1}]	3742	delivery	5	19
24731	2020-01-18 05:22:26	2020-01-18	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	3170	delivery	5	39
24732	2020-01-18 05:25:32	2020-01-18	12	[{"id_menu":3,"count":1}]	1746	pick-up	0	12
24733	2020-01-18 05:29:19	2020-01-18	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1765	delivery	5	31
24734	2020-01-18 05:38:36	2020-01-18	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9685	delivery	5	36
24735	2020-01-18 05:42:39	2020-01-18	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	9714	pick-up	0	20
24736	2020-01-18 05:44:09	2020-01-18	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	9767	delivery	5	31
24737	2020-01-18 05:50:41	2020-01-18	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9770	delivery	5	51
24738	2020-01-18 05:55:54	2020-01-18	8	[{"id_menu":5,"count":2}]	150	delivery	5	13
24739	2020-01-18 06:00:47	2020-01-18	8	[{"id_menu":5,"count":1}]	5761	pick-up	0	8
24740	2020-01-18 06:02:50	2020-01-18	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	9735	delivery	5	26
24741	2020-01-18 06:12:05	2020-01-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9713	delivery	5	22
24742	2020-01-18 06:14:12	2020-01-18	17	[{"id_menu":4,"count":1}]	2894	delivery	5	22
24743	2020-01-18 06:23:26	2020-01-18	12	[{"id_menu":3,"count":1}]	9701	delivery	5	17
24744	2020-01-18 06:30:22	2020-01-18	9	[{"id_menu":7,"count":1}]	2918	pick-up	0	9
24745	2020-01-18 06:34:28	2020-01-18	12	[{"id_menu":3,"count":1}]	3019	delivery	5	17
24746	2020-01-18 06:40:54	2020-01-18	14	[{"id_menu":2,"count":1}]	6458	pick-up	0	14
24747	2020-01-18 06:46:38	2020-01-18	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	5143	delivery	5	36
24748	2020-01-18 06:50:28	2020-01-18	8	[{"id_menu":5,"count":1}]	9715	delivery	5	13
24749	2020-01-18 07:05:35	2020-01-18	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2619	delivery	5	43
24750	2020-01-18 07:23:20	2020-01-18	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	1597	pick-up	0	24
24751	2020-01-18 07:32:14	2020-01-18	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	806	pick-up	0	31
24752	2020-01-18 07:36:47	2020-01-18	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9674	delivery	5	35
24753	2020-01-18 07:40:58	2020-01-18	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4135	delivery	5	27
24754	2020-01-18 07:46:51	2020-01-18	9	[{"id_menu":6,"count":2}]	7800	delivery	5	14
24755	2020-01-18 07:59:16	2020-01-18	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	7584	delivery	5	35
24756	2020-01-18 08:09:41	2020-01-18	12	[{"id_menu":1,"count":1}]	9688	pick-up	0	12
24757	2020-01-18 08:12:29	2020-01-18	12	[{"id_menu":1,"count":1}]	1350	pick-up	0	12
24758	2020-01-18 08:12:32	2020-01-18	9	[{"id_menu":7,"count":1}]	169	pick-up	0	9
24759	2020-01-18 08:17:35	2020-01-18	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7682	delivery	5	45
24760	2020-01-18 08:27:42	2020-01-18	9	[{"id_menu":7,"count":1}]	8267	delivery	5	14
24761	2020-01-18 08:29:57	2020-01-18	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4205	delivery	5	31
24762	2020-01-18 08:35:25	2020-01-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9741	delivery	5	22
24763	2020-01-18 08:36:33	2020-01-18	9	[{"id_menu":7,"count":1}]	9673	delivery	5	14
24764	2020-01-18 08:37:42	2020-01-18	12	[{"id_menu":3,"count":1}]	5053	delivery	5	17
24765	2020-01-18 08:39:52	2020-01-18	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	6489	pick-up	0	22
24766	2020-01-18 08:50:21	2020-01-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	68	pick-up	0	23
24767	2020-01-18 08:52:01	2020-01-18	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	8628	delivery	5	26
24768	2020-01-18 08:53:10	2020-01-18	9	[{"id_menu":6,"count":1}]	4707	delivery	5	14
24769	2020-01-18 08:55:09	2020-01-18	14	[{"id_menu":2,"count":1}]	5041	pick-up	0	14
24770	2020-01-18 08:57:06	2020-01-18	14	[{"id_menu":2,"count":1}]	9672	delivery	5	19
24771	2020-01-18 08:57:33	2020-01-18	12	[{"id_menu":3,"count":1}]	781	pick-up	0	12
24772	2020-01-18 08:58:22	2020-01-18	12	[{"id_menu":3,"count":1}]	2928	pick-up	0	12
24773	2020-01-18 09:01:42	2020-01-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	5546	delivery	5	28
24774	2020-01-18 09:05:39	2020-01-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	9736	delivery	5	28
24775	2020-01-18 09:06:29	2020-01-18	14	[{"id_menu":2,"count":1}]	9704	pick-up	0	14
24776	2020-01-18 09:09:54	2020-01-18	17	[{"id_menu":4,"count":1}]	4652	pick-up	0	17
24777	2020-01-18 09:10:00	2020-01-18	8	[{"id_menu":5,"count":1}]	7460	delivery	5	13
24778	2020-01-18 09:11:56	2020-01-18	9	[{"id_menu":7,"count":1}]	7530	delivery	5	14
24779	2020-01-18 09:26:31	2020-01-18	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8234	delivery	5	30
24780	2020-01-18 09:27:32	2020-01-18	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	3403	delivery	5	29
24781	2020-01-18 09:32:35	2020-01-18	14	[{"id_menu":2,"count":1}]	9128	pick-up	0	14
24782	2020-01-18 09:42:47	2020-01-18	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":2}]	707	pick-up	0	17
24783	2020-01-18 09:55:51	2020-01-18	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	9748	pick-up	0	22
24784	2020-01-18 10:00:11	2020-01-18	14	[{"id_menu":2,"count":1}]	7444	delivery	5	19
24785	2020-01-18 10:00:18	2020-01-18	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1993	delivery	5	43
24786	2020-01-18 10:05:48	2020-01-18	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8312	pick-up	0	26
24787	2020-01-18 10:38:23	2020-01-18	9	[{"id_menu":6,"count":1}]	9726	delivery	5	14
24788	2020-01-18 10:39:54	2020-01-18	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9712	delivery	5	51
24789	2020-01-18 10:41:29	2020-01-18	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	9706	delivery	5	25
24790	2020-01-18 10:55:25	2020-01-18	9	[{"id_menu":7,"count":2}]	766	delivery	5	14
24791	2020-01-18 10:55:55	2020-01-18	9	[{"id_menu":6,"count":1}]	9738	pick-up	0	9
24792	2020-01-18 11:00:19	2020-01-18	12	[{"id_menu":1,"count":1}]	4994	delivery	5	17
24793	2020-01-18 11:01:01	2020-01-18	9	[{"id_menu":6,"count":1}]	5937	pick-up	0	9
24794	2020-01-18 11:17:03	2020-01-18	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9755	delivery	5	30
24795	2020-01-18 11:18:03	2020-01-18	17	[{"id_menu":4,"count":1}]	8407	pick-up	0	17
24796	2020-01-18 11:20:47	2020-01-18	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4722	pick-up	0	25
24797	2020-01-18 11:25:14	2020-01-18	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9750	pick-up	0	34
24798	2020-01-18 11:33:24	2020-01-18	8	[{"id_menu":5,"count":1}]	9696	delivery	5	13
24799	2020-01-18 11:50:01	2020-01-18	8	[{"id_menu":5,"count":1}]	4750	pick-up	0	8
24800	2020-01-18 12:14:19	2020-01-18	17	[{"id_menu":4,"count":1}]	1461	pick-up	0	17
24801	2020-01-18 12:19:39	2020-01-18	8	[{"id_menu":5,"count":1}]	1531	pick-up	0	8
24802	2020-01-18 12:29:02	2020-01-18	14	[{"id_menu":2,"count":1}]	4890	delivery	5	19
24803	2020-01-18 12:38:41	2020-01-18	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9742	delivery	5	39
24804	2020-01-18 12:38:50	2020-01-18	12	[{"id_menu":3,"count":1}]	9678	delivery	5	17
24805	2020-01-18 12:38:55	2020-01-18	8	[{"id_menu":5,"count":1}]	9671	delivery	5	13
24806	2020-01-18 12:48:28	2020-01-18	9	[{"id_menu":6,"count":1}]	7934	pick-up	0	9
24807	2020-01-18 12:55:35	2020-01-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6147	delivery	5	28
24808	2020-01-18 12:56:04	2020-01-18	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9733	delivery	5	34
24809	2020-01-18 12:58:35	2020-01-18	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	9680	delivery	5	34
24810	2020-01-18 13:00:34	2020-01-18	14	[{"id_menu":2,"count":1}]	2763	delivery	5	19
24811	2020-01-18 13:01:45	2020-01-18	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	9222	delivery	5	34
24812	2020-01-18 13:05:22	2020-01-18	14	[{"id_menu":2,"count":1}]	9687	delivery	5	19
24813	2020-01-18 13:11:53	2020-01-18	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6977	delivery	5	40
24814	2020-01-18 13:12:48	2020-01-18	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5325	delivery	5	44
24815	2020-01-18 13:12:51	2020-01-18	17	[{"id_menu":4,"count":1}]	364	delivery	5	22
24816	2020-01-18 13:21:20	2020-01-18	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	9717	delivery	5	26
24817	2020-01-18 13:23:22	2020-01-18	17	[{"id_menu":4,"count":1}]	9707	pick-up	0	17
24818	2020-01-18 13:36:44	2020-01-18	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3790	pick-up	0	29
24819	2020-01-18 13:39:49	2020-01-18	12	[{"id_menu":1,"count":1}]	9749	pick-up	0	12
24820	2020-01-18 13:43:07	2020-01-18	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9693	pick-up	0	17
24821	2020-01-18 13:48:25	2020-01-18	9	[{"id_menu":6,"count":1}]	9757	delivery	5	14
24822	2020-01-18 13:49:07	2020-01-18	12	[{"id_menu":1,"count":1}]	9700	delivery	5	17
24823	2020-01-18 13:52:42	2020-01-18	9	[{"id_menu":6,"count":1}]	1869	delivery	5	14
24824	2020-01-18 13:59:34	2020-01-18	9	[{"id_menu":7,"count":1}]	9730	delivery	5	14
24825	2020-01-18 14:07:14	2020-01-18	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	5798	pick-up	0	17
24826	2020-01-18 14:10:09	2020-01-18	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1013	delivery	5	34
24827	2020-01-18 14:18:32	2020-01-18	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	5066	delivery	5	30
24828	2020-01-18 14:19:59	2020-01-18	9	[{"id_menu":7,"count":1}]	9761	delivery	5	14
24829	2020-01-18 14:23:21	2020-01-18	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1693	pick-up	0	17
24830	2020-01-18 14:24:20	2020-01-18	9	[{"id_menu":6,"count":1}]	9708	delivery	5	14
24831	2020-01-18 14:33:15	2020-01-18	9	[{"id_menu":7,"count":1}]	9763	delivery	5	14
24832	2020-01-18 14:36:12	2020-01-18	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	389	delivery	5	31
24833	2020-01-18 14:41:04	2020-01-18	14	[{"id_menu":2,"count":1}]	9768	delivery	5	19
24834	2020-01-18 14:41:22	2020-01-18	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9710	delivery	5	47
24835	2020-01-18 15:00:38	2020-01-18	12	[{"id_menu":1,"count":2}]	9314	pick-up	0	12
24836	2020-01-18 15:02:24	2020-01-18	14	[{"id_menu":2,"count":1}]	6589	delivery	5	19
24837	2020-01-18 15:02:49	2020-01-18	8	[{"id_menu":5,"count":1}]	5235	delivery	5	13
24838	2020-01-18 15:03:55	2020-01-18	9	[{"id_menu":6,"count":1}]	6346	delivery	5	14
24839	2020-01-18 15:04:38	2020-01-18	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	9752	delivery	5	26
24840	2020-01-18 15:11:44	2020-01-18	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6366	delivery	5	42
24841	2020-01-18 15:13:25	2020-01-18	8	[{"id_menu":5,"count":1}]	6729	delivery	5	13
24842	2020-01-18 15:13:51	2020-01-18	8	[{"id_menu":5,"count":1}]	1215	pick-up	0	8
24843	2020-01-18 15:16:38	2020-01-18	8	[{"id_menu":5,"count":1}]	3168	delivery	5	13
24844	2020-01-18 15:21:06	2020-01-18	17	[{"id_menu":4,"count":1}]	1312	pick-up	0	17
24845	2020-01-18 15:21:46	2020-01-18	9	[{"id_menu":6,"count":1}]	9683	delivery	5	14
24846	2020-01-18 15:27:22	2020-01-18	14	[{"id_menu":2,"count":1}]	9702	delivery	5	19
24847	2020-01-18 15:32:06	2020-01-18	8	[{"id_menu":5,"count":1}]	2827	pick-up	0	8
24848	2020-01-18 15:37:31	2020-01-18	14	[{"id_menu":2,"count":1}]	6243	pick-up	0	14
24849	2020-01-18 15:48:45	2020-01-18	9	[{"id_menu":7,"count":1}]	3138	pick-up	0	9
24850	2020-01-18 15:50:13	2020-01-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9732	delivery	5	23
24851	2020-01-18 15:50:14	2020-01-18	17	[{"id_menu":4,"count":1}]	6326	delivery	5	22
24852	2020-01-18 15:54:47	2020-01-18	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	9769	delivery	5	27
24853	2020-01-18 15:58:30	2020-01-18	12	[{"id_menu":1,"count":1}]	1267	pick-up	0	12
24854	2020-01-18 15:59:02	2020-01-18	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9754	delivery	5	42
24855	2020-01-18 16:01:15	2020-01-18	17	[{"id_menu":4,"count":1}]	9682	pick-up	0	17
24856	2020-01-18 16:07:09	2020-01-18	9	[{"id_menu":6,"count":1}]	9709	delivery	5	14
24857	2020-01-18 16:09:04	2020-01-18	9	[{"id_menu":6,"count":1}]	9721	delivery	5	14
24858	2020-01-18 16:19:06	2020-01-18	8	[{"id_menu":5,"count":1}]	8697	delivery	5	13
24859	2020-01-18 16:37:04	2020-01-18	12	[{"id_menu":3,"count":1}]	6031	delivery	5	17
24860	2020-01-18 16:40:29	2020-01-18	17	[{"id_menu":4,"count":3}]	9694	delivery	5	22
24861	2020-01-18 16:52:35	2020-01-18	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	4281	delivery	5	31
24862	2020-01-18 17:07:57	2020-01-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3268	pick-up	0	18
24863	2020-01-18 17:08:51	2020-01-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	9692	pick-up	0	23
24864	2020-01-18 17:18:05	2020-01-18	9	[{"id_menu":7,"count":1}]	6069	delivery	5	14
24865	2020-01-18 17:24:48	2020-01-18	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3457	pick-up	0	25
24866	2020-01-18 17:25:29	2020-01-18	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8743	pick-up	0	32
24867	2020-01-18 17:25:54	2020-01-18	12	[{"id_menu":3,"count":1}]	763	delivery	5	17
24868	2020-01-18 17:27:15	2020-01-18	14	[{"id_menu":2,"count":2}]	8038	delivery	5	19
24869	2020-01-18 17:46:13	2020-01-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1232	delivery	5	28
24870	2020-01-18 17:51:34	2020-01-18	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5786	delivery	5	31
24871	2020-01-18 17:53:37	2020-01-18	9	[{"id_menu":7,"count":1}]	5061	delivery	5	14
24872	2020-01-18 17:56:31	2020-01-18	9	[{"id_menu":7,"count":1}]	9734	pick-up	0	9
24873	2020-01-18 18:13:37	2020-01-18	12	[{"id_menu":1,"count":2}]	9337	delivery	5	17
24874	2020-01-18 18:17:24	2020-01-18	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5979	delivery	5	55
24875	2020-01-18 18:20:10	2020-01-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	9744	delivery	5	23
24876	2020-01-18 18:23:28	2020-01-18	9	[{"id_menu":7,"count":1}]	6925	delivery	5	14
24877	2020-01-18 18:42:18	2020-01-18	8	[{"id_menu":5,"count":1}]	3987	delivery	5	13
24878	2020-01-18 18:45:02	2020-01-18	17	[{"id_menu":4,"count":1}]	7425	delivery	5	22
24879	2020-01-18 18:49:42	2020-01-18	8	[{"id_menu":5,"count":1}]	1947	delivery	5	13
24880	2020-01-18 18:55:50	2020-01-18	8	[{"id_menu":5,"count":1}]	9691	pick-up	0	8
24881	2020-01-18 18:58:53	2020-01-18	12	[{"id_menu":1,"count":1}]	4592	delivery	5	17
24882	2020-01-18 19:02:00	2020-01-18	8	[{"id_menu":5,"count":1}]	9731	delivery	5	13
24883	2020-01-18 19:02:53	2020-01-18	14	[{"id_menu":2,"count":1}]	1810	pick-up	0	14
24884	2020-01-18 19:11:07	2020-01-18	20	[{"id_menu":1,"count":3},{"id_menu":5,"count":1}]	5110	delivery	5	25
24885	2020-01-18 19:14:19	2020-01-18	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2684	delivery	5	26
24886	2020-01-18 19:19:41	2020-01-18	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	9723	delivery	5	45
24887	2020-01-18 19:25:24	2020-01-18	9	[{"id_menu":6,"count":1}]	9718	delivery	5	14
24888	2020-01-18 19:33:48	2020-01-18	8	[{"id_menu":5,"count":2}]	9719	delivery	5	13
24889	2020-01-18 19:34:01	2020-01-18	9	[{"id_menu":6,"count":1}]	376	delivery	5	14
24890	2020-01-18 19:37:09	2020-01-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7479	delivery	5	23
24891	2020-01-18 19:39:07	2020-01-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	9681	delivery	5	23
24892	2020-01-18 19:40:18	2020-01-18	12	[{"id_menu":3,"count":1}]	5010	delivery	5	17
24893	2020-01-18 19:42:46	2020-01-18	14	[{"id_menu":2,"count":1}]	4495	delivery	5	19
24894	2020-01-18 19:43:59	2020-01-18	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	9679	delivery	5	25
24895	2020-01-18 19:46:53	2020-01-18	17	[{"id_menu":4,"count":1}]	27	delivery	5	22
24896	2020-01-18 19:46:55	2020-01-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2065	pick-up	0	23
24897	2020-01-18 19:49:38	2020-01-18	12	[{"id_menu":3,"count":1}]	5238	pick-up	0	12
24898	2020-01-18 19:53:44	2020-01-18	14	[{"id_menu":2,"count":1}]	6328	pick-up	0	14
24899	2020-01-18 20:04:00	2020-01-18	9	[{"id_menu":6,"count":1}]	9716	pick-up	0	9
24900	2020-01-18 20:14:36	2020-01-18	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2536	pick-up	0	40
24901	2020-01-18 20:31:36	2020-01-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9753	delivery	5	22
24902	2020-01-18 20:38:22	2020-01-18	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9771	delivery	5	31
24903	2020-01-18 20:41:36	2020-01-18	12	[{"id_menu":1,"count":1}]	9703	delivery	5	17
24904	2020-01-18 20:45:01	2020-01-18	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5613	delivery	5	34
24905	2020-01-18 20:47:34	2020-01-18	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	6167	delivery	5	35
24906	2020-01-18 21:22:36	2020-01-18	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	4899	delivery	5	31
24907	2020-01-18 21:22:59	2020-01-18	12	[{"id_menu":1,"count":1}]	2907	pick-up	0	12
24908	2020-01-18 21:28:39	2020-01-18	14	[{"id_menu":2,"count":1}]	7912	delivery	5	19
24909	2020-01-18 21:29:58	2020-01-18	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	5623	pick-up	0	24
24910	2020-01-18 21:30:03	2020-01-18	12	[{"id_menu":3,"count":1}]	5822	delivery	5	17
24911	2020-01-18 21:35:01	2020-01-18	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	9756	delivery	5	31
24912	2020-01-18 21:38:30	2020-01-18	9	[{"id_menu":6,"count":2}]	9697	delivery	5	14
24913	2020-01-18 21:39:39	2020-01-18	17	[{"id_menu":4,"count":1}]	310	pick-up	0	17
24914	2020-01-18 21:42:02	2020-01-18	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9745	delivery	5	22
24915	2020-01-18 21:42:59	2020-01-18	8	[{"id_menu":5,"count":1}]	9660	delivery	5	13
24916	2020-01-18 21:48:03	2020-01-18	8	[{"id_menu":5,"count":1}]	2567	pick-up	0	8
24917	2020-01-18 21:48:46	2020-01-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9689	delivery	5	28
24918	2020-01-18 21:49:04	2020-01-18	8	[{"id_menu":5,"count":1}]	9698	delivery	5	13
24919	2020-01-18 21:56:50	2020-01-18	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	29	delivery	5	30
24920	2020-01-18 22:07:04	2020-01-18	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3180	pick-up	0	25
24921	2020-01-18 22:14:16	2020-01-18	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3228	pick-up	0	43
24922	2020-01-18 22:18:29	2020-01-18	9	[{"id_menu":6,"count":1}]	2662	delivery	5	14
24923	2020-01-18 22:33:09	2020-01-18	12	[{"id_menu":1,"count":1}]	9747	delivery	5	17
24924	2020-01-18 22:39:32	2020-01-18	9	[{"id_menu":7,"count":2}]	6609	pick-up	0	9
24925	2020-01-18 22:43:40	2020-01-18	14	[{"id_menu":2,"count":1}]	9766	pick-up	0	14
24926	2020-01-18 22:50:57	2020-01-18	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3314	pick-up	0	17
24927	2020-01-18 22:51:23	2020-01-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	337	pick-up	0	23
24928	2020-01-18 22:58:14	2020-01-18	33	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	7740	delivery	5	38
24929	2020-01-18 23:01:17	2020-01-18	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	5281	pick-up	0	21
24930	2020-01-18 23:03:51	2020-01-18	8	[{"id_menu":5,"count":1}]	9759	delivery	5	13
24931	2020-01-18 23:06:38	2020-01-18	8	[{"id_menu":5,"count":1}]	9675	delivery	5	13
24932	2020-01-18 23:16:14	2020-01-18	12	[{"id_menu":3,"count":1}]	9106	pick-up	0	12
24933	2020-01-18 23:20:38	2020-01-18	17	[{"id_menu":4,"count":1}]	2053	pick-up	0	17
24934	2020-01-18 23:23:15	2020-01-18	12	[{"id_menu":3,"count":1}]	9097	delivery	5	17
24935	2020-01-18 23:32:52	2020-01-18	8	[{"id_menu":5,"count":1}]	2964	pick-up	0	8
24936	2020-01-18 23:33:20	2020-01-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	8123	pick-up	0	23
24937	2020-01-18 23:39:18	2020-01-18	9	[{"id_menu":7,"count":1}]	287	pick-up	0	9
24938	2020-01-18 23:45:51	2020-01-18	12	[{"id_menu":3,"count":1}]	6279	delivery	5	17
24939	2020-01-18 23:48:55	2020-01-18	14	[{"id_menu":2,"count":1}]	7017	delivery	5	19
24940	2020-01-18 23:54:03	2020-01-18	9	[{"id_menu":6,"count":1}]	9728	pick-up	0	9
24941	2020-01-18 23:54:49	2020-01-18	9	[{"id_menu":6,"count":1}]	9676	delivery	5	14
24942	2020-01-18 23:58:56	2020-01-18	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5730	delivery	5	42
24943	2020-01-19 00:03:45	2020-01-19	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	9852	pick-up	0	29
24944	2020-01-19 00:15:11	2020-01-19	12	[{"id_menu":3,"count":1}]	7590	pick-up	0	12
24945	2020-01-19 00:15:19	2020-01-19	14	[{"id_menu":2,"count":1}]	9391	delivery	5	19
24946	2020-01-19 00:21:02	2020-01-19	9	[{"id_menu":6,"count":1}]	4562	pick-up	0	9
24947	2020-01-19 00:21:56	2020-01-19	17	[{"id_menu":4,"count":1}]	9850	delivery	5	22
24948	2020-01-19 00:31:54	2020-01-19	9	[{"id_menu":6,"count":1}]	9843	delivery	5	14
24949	2020-01-19 00:39:22	2020-01-19	12	[{"id_menu":1,"count":1}]	1119	delivery	5	17
24950	2020-01-19 00:42:34	2020-01-19	8	[{"id_menu":5,"count":1}]	6174	delivery	5	13
24951	2020-01-19 00:42:39	2020-01-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":3}]	9786	delivery	5	31
24952	2020-01-19 00:45:32	2020-01-19	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	5094	pick-up	0	21
24953	2020-01-19 00:46:20	2020-01-19	14	[{"id_menu":2,"count":1}]	6341	delivery	5	19
24954	2020-01-19 00:47:31	2020-01-19	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	3142	delivery	5	36
24955	2020-01-19 00:50:32	2020-01-19	8	[{"id_menu":5,"count":1}]	9851	delivery	5	13
24956	2020-01-19 00:53:39	2020-01-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3968	pick-up	0	23
24957	2020-01-19 00:54:33	2020-01-19	8	[{"id_menu":5,"count":1}]	6207	delivery	5	13
24958	2020-01-19 00:54:51	2020-01-19	17	[{"id_menu":4,"count":1}]	1957	pick-up	0	17
24959	2020-01-19 00:57:02	2020-01-19	9	[{"id_menu":7,"count":1}]	4062	pick-up	0	9
24960	2020-01-19 01:11:39	2020-01-19	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1992	delivery	5	34
24961	2020-01-19 01:16:48	2020-01-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9819	delivery	5	22
24962	2020-01-19 01:18:04	2020-01-19	9	[{"id_menu":7,"count":1}]	1479	delivery	5	14
24963	2020-01-19 01:25:02	2020-01-19	14	[{"id_menu":2,"count":1}]	245	pick-up	0	14
24964	2020-01-19 01:26:39	2020-01-19	12	[{"id_menu":1,"count":1}]	7092	delivery	5	17
24965	2020-01-19 01:38:31	2020-01-19	17	[{"id_menu":4,"count":1}]	9841	delivery	5	22
24966	2020-01-19 01:42:35	2020-01-19	8	[{"id_menu":5,"count":1}]	7267	delivery	5	13
24967	2020-01-19 01:43:30	2020-01-19	9	[{"id_menu":7,"count":1}]	9820	delivery	5	14
24968	2020-01-19 02:06:19	2020-01-19	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9805	delivery	5	36
24969	2020-01-19 02:06:54	2020-01-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2291	pick-up	0	17
24970	2020-01-19 02:36:04	2020-01-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	9797	delivery	5	22
24971	2020-01-19 02:39:52	2020-01-19	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	4655	delivery	5	27
24972	2020-01-19 03:05:38	2020-01-19	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	3898	pick-up	0	26
24973	2020-01-19 03:10:53	2020-01-19	12	[{"id_menu":3,"count":1}]	4937	pick-up	0	12
24974	2020-01-19 03:13:55	2020-01-19	9	[{"id_menu":7,"count":1}]	9799	delivery	5	14
24975	2020-01-19 03:21:59	2020-01-19	12	[{"id_menu":1,"count":1}]	1991	pick-up	0	12
24976	2020-01-19 03:23:34	2020-01-19	14	[{"id_menu":2,"count":1}]	5857	delivery	5	19
24977	2020-01-19 03:26:25	2020-01-19	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2633	pick-up	0	21
24978	2020-01-19 03:30:59	2020-01-19	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1970	pick-up	0	20
24979	2020-01-19 03:31:18	2020-01-19	12	[{"id_menu":3,"count":1}]	4695	pick-up	0	12
24980	2020-01-19 03:50:38	2020-01-19	8	[{"id_menu":5,"count":1}]	9790	delivery	5	13
24981	2020-01-19 03:52:29	2020-01-19	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	4281	delivery	5	26
24982	2020-01-19 03:57:28	2020-01-19	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1529	pick-up	0	26
24983	2020-01-19 03:59:49	2020-01-19	9	[{"id_menu":6,"count":1}]	9831	delivery	5	14
24984	2020-01-19 04:01:44	2020-01-19	12	[{"id_menu":1,"count":1}]	9845	delivery	5	17
24985	2020-01-19 04:09:30	2020-01-19	17	[{"id_menu":4,"count":1}]	9802	pick-up	0	17
24986	2020-01-19 04:11:59	2020-01-19	26	[{"id_menu":4,"count":3},{"id_menu":7,"count":1}]	9830	pick-up	0	26
24987	2020-01-19 04:14:11	2020-01-19	14	[{"id_menu":2,"count":1}]	9847	pick-up	0	14
24988	2020-01-19 04:17:49	2020-01-19	12	[{"id_menu":1,"count":1}]	7511	delivery	5	17
24989	2020-01-19 04:33:49	2020-01-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	9814	delivery	5	31
24990	2020-01-19 04:34:19	2020-01-19	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	9798	delivery	5	23
24991	2020-01-19 04:34:54	2020-01-19	17	[{"id_menu":4,"count":1}]	9782	delivery	5	22
24992	2020-01-19 04:39:39	2020-01-19	8	[{"id_menu":5,"count":1}]	8470	delivery	5	13
24993	2020-01-19 04:42:54	2020-01-19	8	[{"id_menu":5,"count":1}]	4100	delivery	5	13
24994	2020-01-19 05:02:37	2020-01-19	8	[{"id_menu":5,"count":1}]	9789	delivery	5	13
24995	2020-01-19 05:05:37	2020-01-19	9	[{"id_menu":7,"count":1}]	5583	delivery	5	14
24996	2020-01-19 05:15:58	2020-01-19	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1101	delivery	5	26
24997	2020-01-19 05:20:00	2020-01-19	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	6062	delivery	5	26
24998	2020-01-19 05:22:53	2020-01-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	9815	delivery	5	22
24999	2020-01-19 05:45:41	2020-01-19	9	[{"id_menu":6,"count":2}]	7053	delivery	5	14
25000	2020-01-19 05:51:07	2020-01-19	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	9826	pick-up	0	26
25001	2020-01-19 06:05:58	2020-01-19	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	7242	delivery	5	31
25002	2020-01-19 06:13:33	2020-01-19	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8319	delivery	5	36
25003	2020-01-19 06:16:54	2020-01-19	9	[{"id_menu":6,"count":1}]	9783	delivery	5	14
25004	2020-01-19 06:17:16	2020-01-19	14	[{"id_menu":2,"count":1}]	6156	pick-up	0	14
25005	2020-01-19 06:21:23	2020-01-19	14	[{"id_menu":2,"count":1}]	7170	pick-up	0	14
25006	2020-01-19 06:27:47	2020-01-19	8	[{"id_menu":5,"count":1}]	9791	delivery	5	13
25007	2020-01-19 06:35:26	2020-01-19	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	9834	delivery	5	44
25008	2020-01-19 06:40:58	2020-01-19	14	[{"id_menu":2,"count":1}]	2474	pick-up	0	14
25009	2020-01-19 06:43:17	2020-01-19	9	[{"id_menu":6,"count":2}]	9781	delivery	5	14
25010	2020-01-19 06:55:08	2020-01-19	14	[{"id_menu":2,"count":1}]	5853	delivery	5	19
25011	2020-01-19 07:13:25	2020-01-19	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	124	pick-up	0	43
25012	2020-01-19 07:22:44	2020-01-19	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	2494	pick-up	0	24
25013	2020-01-19 07:33:28	2020-01-19	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2367	pick-up	0	25
25014	2020-01-19 07:35:21	2020-01-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	8394	delivery	5	36
25015	2020-01-19 07:49:02	2020-01-19	12	[{"id_menu":1,"count":1}]	546	delivery	5	17
25016	2020-01-19 07:54:50	2020-01-19	14	[{"id_menu":2,"count":1}]	4372	pick-up	0	14
25017	2020-01-19 07:57:22	2020-01-19	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7970	delivery	5	31
25018	2020-01-19 07:57:27	2020-01-19	9	[{"id_menu":6,"count":1}]	6584	delivery	5	14
25019	2020-01-19 08:00:01	2020-01-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6133	delivery	5	22
25020	2020-01-19 08:00:25	2020-01-19	9	[{"id_menu":6,"count":3}]	6116	delivery	5	14
25021	2020-01-19 08:10:09	2020-01-19	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9836	delivery	5	55
25022	2020-01-19 08:10:29	2020-01-19	17	[{"id_menu":4,"count":1}]	8400	delivery	5	22
25023	2020-01-19 08:11:55	2020-01-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9559	delivery	5	22
25024	2020-01-19 08:15:03	2020-01-19	14	[{"id_menu":2,"count":1}]	9807	delivery	5	19
25025	2020-01-19 08:18:34	2020-01-19	14	[{"id_menu":2,"count":1}]	358	delivery	5	19
25026	2020-01-19 08:18:38	2020-01-19	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2928	pick-up	0	25
25027	2020-01-19 08:23:24	2020-01-19	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8178	delivery	5	30
25028	2020-01-19 08:26:37	2020-01-19	12	[{"id_menu":3,"count":1}]	3820	delivery	5	17
25029	2020-01-19 08:35:41	2020-01-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5182	delivery	5	28
25030	2020-01-19 08:36:30	2020-01-19	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	9795	delivery	5	45
25031	2020-01-19 08:36:49	2020-01-19	9	[{"id_menu":7,"count":1}]	2951	delivery	5	14
25032	2020-01-19 08:39:29	2020-01-19	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8784	delivery	5	56
25033	2020-01-19 08:46:34	2020-01-19	9	[{"id_menu":6,"count":1}]	5095	delivery	5	14
25034	2020-01-19 08:50:18	2020-01-19	12	[{"id_menu":1,"count":1}]	1314	pick-up	0	12
25035	2020-01-19 08:53:11	2020-01-19	14	[{"id_menu":2,"count":2}]	9842	delivery	5	19
25036	2020-01-19 08:57:28	2020-01-19	8	[{"id_menu":5,"count":1}]	9746	delivery	5	13
25037	2020-01-19 08:58:19	2020-01-19	12	[{"id_menu":3,"count":1}]	9796	pick-up	0	12
25038	2020-01-19 09:06:42	2020-01-19	14	[{"id_menu":2,"count":2}]	9811	pick-up	0	14
25039	2020-01-19 09:15:04	2020-01-19	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	1834	pick-up	0	25
25040	2020-01-19 09:23:21	2020-01-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9839	delivery	5	28
25041	2020-01-19 09:34:21	2020-01-19	9	[{"id_menu":7,"count":1}]	4659	pick-up	0	9
25042	2020-01-19 09:37:51	2020-01-19	8	[{"id_menu":5,"count":1}]	1337	pick-up	0	8
25043	2020-01-19 09:43:46	2020-01-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6160	delivery	5	28
25044	2020-01-19 09:47:03	2020-01-19	12	[{"id_menu":1,"count":1}]	9829	pick-up	0	12
25045	2020-01-19 09:56:13	2020-01-19	12	[{"id_menu":3,"count":1}]	9202	delivery	5	17
25046	2020-01-19 09:58:11	2020-01-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	8708	delivery	5	22
25047	2020-01-19 10:13:28	2020-01-19	9	[{"id_menu":7,"count":1}]	2540	pick-up	0	9
25048	2020-01-19 10:18:48	2020-01-19	9	[{"id_menu":6,"count":1}]	9833	delivery	5	14
25049	2020-01-19 10:23:58	2020-01-19	14	[{"id_menu":2,"count":1}]	9772	delivery	5	19
25050	2020-01-19 10:35:34	2020-01-19	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3556	delivery	5	48
25051	2020-01-19 10:40:04	2020-01-19	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	4636	pick-up	0	24
25052	2020-01-19 10:43:34	2020-01-19	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	285	pick-up	0	29
25053	2020-01-19 10:45:52	2020-01-19	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1574	pick-up	0	29
25054	2020-01-19 10:47:49	2020-01-19	12	[{"id_menu":1,"count":1}]	682	pick-up	0	12
25055	2020-01-19 10:50:21	2020-01-19	17	[{"id_menu":4,"count":1}]	6180	delivery	5	22
25056	2020-01-19 10:59:27	2020-01-19	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9403	delivery	5	43
25057	2020-01-19 11:00:35	2020-01-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1963	delivery	5	28
25058	2020-01-19 11:01:17	2020-01-19	17	[{"id_menu":4,"count":1}]	1490	pick-up	0	17
25059	2020-01-19 11:06:58	2020-01-19	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5148	delivery	5	31
25060	2020-01-19 11:07:58	2020-01-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	9779	delivery	5	22
25061	2020-01-19 11:15:30	2020-01-19	9	[{"id_menu":6,"count":2}]	9739	pick-up	0	9
25062	2020-01-19 11:22:57	2020-01-19	14	[{"id_menu":2,"count":1}]	799	pick-up	0	14
25063	2020-01-19 11:24:34	2020-01-19	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	8448	delivery	5	39
25064	2020-01-19 11:28:13	2020-01-19	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9838	delivery	5	39
25065	2020-01-19 11:28:38	2020-01-19	9	[{"id_menu":7,"count":1}]	3754	pick-up	0	9
25066	2020-01-19 11:30:35	2020-01-19	9	[{"id_menu":6,"count":1}]	9775	delivery	5	14
25067	2020-01-19 11:31:45	2020-01-19	12	[{"id_menu":3,"count":1}]	9816	delivery	5	17
25068	2020-01-19 11:38:48	2020-01-19	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	4137	pick-up	0	23
25069	2020-01-19 11:41:14	2020-01-19	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1385	pick-up	0	21
25070	2020-01-19 11:41:53	2020-01-19	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1914	pick-up	0	35
25071	2020-01-19 11:42:40	2020-01-19	14	[{"id_menu":2,"count":1}]	1656	delivery	5	19
25072	2020-01-19 11:48:51	2020-01-19	9	[{"id_menu":6,"count":1}]	9809	pick-up	0	9
25073	2020-01-19 11:49:38	2020-01-19	12	[{"id_menu":1,"count":1}]	4813	pick-up	0	12
25074	2020-01-19 12:00:39	2020-01-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	28	pick-up	0	26
25075	2020-01-19 12:03:37	2020-01-19	9	[{"id_menu":6,"count":1}]	5232	pick-up	0	9
25076	2020-01-19 12:05:40	2020-01-19	9	[{"id_menu":6,"count":1}]	9065	pick-up	0	9
25077	2020-01-19 12:22:57	2020-01-19	12	[{"id_menu":1,"count":1}]	441	delivery	5	17
25078	2020-01-19 12:23:24	2020-01-19	12	[{"id_menu":1,"count":1}]	9792	delivery	5	17
25079	2020-01-19 12:23:25	2020-01-19	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	9774	delivery	5	26
25080	2020-01-19 12:27:44	2020-01-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8945	delivery	5	23
25081	2020-01-19 12:29:44	2020-01-19	17	[{"id_menu":4,"count":1}]	6301	delivery	5	22
25082	2020-01-19 12:37:27	2020-01-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2868	delivery	5	22
25083	2020-01-19 12:37:53	2020-01-19	12	[{"id_menu":3,"count":1}]	4068	pick-up	0	12
25084	2020-01-19 12:52:14	2020-01-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	9846	pick-up	0	31
25085	2020-01-19 12:52:54	2020-01-19	17	[{"id_menu":4,"count":1}]	4245	pick-up	0	17
25086	2020-01-19 12:55:07	2020-01-19	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	9835	delivery	5	25
25087	2020-01-19 12:55:51	2020-01-19	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	9844	delivery	5	43
25088	2020-01-19 13:08:57	2020-01-19	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	6085	delivery	5	26
25089	2020-01-19 13:12:26	2020-01-19	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	154	pick-up	0	30
25090	2020-01-19 13:15:21	2020-01-19	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4216	delivery	5	57
25091	2020-01-19 13:38:14	2020-01-19	12	[{"id_menu":1,"count":1}]	2613	pick-up	0	12
25092	2020-01-19 13:44:11	2020-01-19	8	[{"id_menu":5,"count":1}]	8900	delivery	5	13
25093	2020-01-19 13:44:13	2020-01-19	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	7177	delivery	5	26
25094	2020-01-19 13:52:00	2020-01-19	9	[{"id_menu":6,"count":1}]	9853	delivery	5	14
25095	2020-01-19 13:56:19	2020-01-19	9	[{"id_menu":6,"count":2}]	9832	delivery	5	14
25096	2020-01-19 13:57:41	2020-01-19	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6027	delivery	5	52
25097	2020-01-19 13:58:56	2020-01-19	17	[{"id_menu":4,"count":1}]	9787	delivery	5	22
25098	2020-01-19 14:01:25	2020-01-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9460	delivery	5	28
25099	2020-01-19 14:11:53	2020-01-19	9	[{"id_menu":6,"count":1}]	4781	delivery	5	14
25100	2020-01-19 14:12:31	2020-01-19	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9773	delivery	5	37
25101	2020-01-19 14:15:51	2020-01-19	9	[{"id_menu":6,"count":2}]	3827	pick-up	0	9
25102	2020-01-19 14:16:26	2020-01-19	14	[{"id_menu":2,"count":1}]	1072	pick-up	0	14
25103	2020-01-19 14:17:02	2020-01-19	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7200	delivery	5	30
25104	2020-01-19 14:27:55	2020-01-19	8	[{"id_menu":5,"count":1}]	9825	delivery	5	13
25105	2020-01-19 14:35:59	2020-01-19	17	[{"id_menu":4,"count":1}]	2261	pick-up	0	17
25106	2020-01-19 14:36:12	2020-01-19	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	9794	delivery	5	39
25107	2020-01-19 14:40:16	2020-01-19	9	[{"id_menu":6,"count":1}]	2672	pick-up	0	9
25108	2020-01-19 14:57:35	2020-01-19	9	[{"id_menu":7,"count":1}]	4132	pick-up	0	9
25109	2020-01-19 14:58:52	2020-01-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	9803	pick-up	0	23
25110	2020-01-19 15:19:42	2020-01-19	12	[{"id_menu":1,"count":1}]	9778	delivery	5	17
25111	2020-01-19 15:22:37	2020-01-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2441	delivery	5	23
25112	2020-01-19 15:35:12	2020-01-19	8	[{"id_menu":5,"count":1}]	729	delivery	5	13
25113	2020-01-19 15:35:22	2020-01-19	9	[{"id_menu":7,"count":1}]	3195	delivery	5	14
25114	2020-01-19 15:40:31	2020-01-19	9	[{"id_menu":6,"count":1}]	9788	pick-up	0	9
25115	2020-01-19 15:43:21	2020-01-19	8	[{"id_menu":5,"count":1}]	2475	pick-up	0	8
25116	2020-01-19 15:43:25	2020-01-19	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	754	pick-up	0	26
25117	2020-01-19 15:43:56	2020-01-19	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2126	pick-up	0	26
25118	2020-01-19 15:47:04	2020-01-19	17	[{"id_menu":4,"count":1}]	732	delivery	5	22
25119	2020-01-19 15:52:36	2020-01-19	9	[{"id_menu":6,"count":1}]	3264	pick-up	0	9
25120	2020-01-19 15:55:01	2020-01-19	9	[{"id_menu":6,"count":1}]	9840	delivery	5	14
25121	2020-01-19 16:00:07	2020-01-19	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	4124	delivery	5	31
25122	2020-01-19 16:06:50	2020-01-19	9	[{"id_menu":6,"count":1}]	5919	delivery	5	14
25123	2020-01-19 16:12:59	2020-01-19	12	[{"id_menu":1,"count":1}]	189	delivery	5	17
25124	2020-01-19 16:13:25	2020-01-19	8	[{"id_menu":5,"count":1}]	9848	delivery	5	13
25125	2020-01-19 16:16:15	2020-01-19	17	[{"id_menu":4,"count":1}]	2189	pick-up	0	17
25126	2020-01-19 16:17:12	2020-01-19	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	382	pick-up	0	29
25127	2020-01-19 16:17:14	2020-01-19	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	396	pick-up	0	29
25128	2020-01-19 16:19:15	2020-01-19	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3314	pick-up	0	21
25129	2020-01-19 16:29:36	2020-01-19	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2937	delivery	5	55
25130	2020-01-19 16:30:31	2020-01-19	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	9837	pick-up	0	40
25131	2020-01-19 16:36:00	2020-01-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9017	delivery	5	28
25132	2020-01-19 16:45:17	2020-01-19	14	[{"id_menu":2,"count":1}]	5091	delivery	5	19
25133	2020-01-19 16:46:07	2020-01-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	6568	delivery	5	31
25134	2020-01-19 16:51:00	2020-01-19	17	[{"id_menu":4,"count":1}]	5189	pick-up	0	17
25135	2020-01-19 16:55:58	2020-01-19	17	[{"id_menu":4,"count":1}]	6410	pick-up	0	17
25136	2020-01-19 16:57:42	2020-01-19	12	[{"id_menu":3,"count":1}]	8071	delivery	5	17
25137	2020-01-19 17:13:27	2020-01-19	9	[{"id_menu":6,"count":1}]	9804	pick-up	0	9
25138	2020-01-19 18:00:39	2020-01-19	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	2072	delivery	5	43
25139	2020-01-19 18:04:08	2020-01-19	9	[{"id_menu":6,"count":1}]	3512	pick-up	0	9
25140	2020-01-19 18:09:21	2020-01-19	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	9785	delivery	5	26
25141	2020-01-19 18:10:39	2020-01-19	14	[{"id_menu":2,"count":1}]	581	delivery	5	19
25142	2020-01-19 18:11:55	2020-01-19	9	[{"id_menu":6,"count":1}]	6564	delivery	5	14
25143	2020-01-19 18:14:35	2020-01-19	12	[{"id_menu":1,"count":1}]	4404	delivery	5	17
25144	2020-01-19 18:19:10	2020-01-19	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6274	delivery	5	30
25145	2020-01-19 18:19:12	2020-01-19	8	[{"id_menu":5,"count":1}]	6080	delivery	5	13
25146	2020-01-19 18:23:05	2020-01-19	14	[{"id_menu":2,"count":1}]	6714	delivery	5	19
25147	2020-01-19 18:28:01	2020-01-19	12	[{"id_menu":1,"count":1}]	834	pick-up	0	12
25148	2020-01-19 18:29:14	2020-01-19	14	[{"id_menu":2,"count":1}]	6813	delivery	5	19
25149	2020-01-19 18:35:59	2020-01-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	2842	delivery	5	28
25150	2020-01-19 18:36:50	2020-01-19	8	[{"id_menu":5,"count":1}]	6049	pick-up	0	8
25151	2020-01-19 18:38:53	2020-01-19	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9821	delivery	5	39
25152	2020-01-19 18:39:16	2020-01-19	9	[{"id_menu":7,"count":1}]	153	delivery	5	14
25153	2020-01-19 18:45:32	2020-01-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9818	delivery	5	23
25154	2020-01-19 18:53:39	2020-01-19	12	[{"id_menu":1,"count":1}]	9541	delivery	5	17
25155	2020-01-19 18:54:14	2020-01-19	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	9849	delivery	5	40
25156	2020-01-19 18:57:56	2020-01-19	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	9817	pick-up	0	21
25157	2020-01-19 19:02:34	2020-01-19	14	[{"id_menu":2,"count":1}]	9575	pick-up	0	14
25158	2020-01-19 19:15:05	2020-01-19	9	[{"id_menu":6,"count":1}]	1088	delivery	5	14
25159	2020-01-19 19:16:52	2020-01-19	17	[{"id_menu":4,"count":1}]	5508	pick-up	0	17
25160	2020-01-19 19:20:06	2020-01-19	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	9525	delivery	5	27
25161	2020-01-19 19:20:39	2020-01-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2694	delivery	5	22
25162	2020-01-19 19:21:13	2020-01-19	12	[{"id_menu":3,"count":1}]	5397	delivery	5	17
25163	2020-01-19 19:36:36	2020-01-19	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	4712	delivery	5	26
25164	2020-01-19 19:46:25	2020-01-19	14	[{"id_menu":2,"count":1}]	5015	delivery	5	19
25165	2020-01-19 19:46:47	2020-01-19	9	[{"id_menu":6,"count":1}]	9503	delivery	5	14
25166	2020-01-19 20:02:59	2020-01-19	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	5580	delivery	5	26
25167	2020-01-19 20:03:22	2020-01-19	9	[{"id_menu":6,"count":1}]	9800	delivery	5	14
25168	2020-01-19 20:10:08	2020-01-19	12	[{"id_menu":3,"count":1}]	944	delivery	5	17
25169	2020-01-19 20:13:27	2020-01-19	17	[{"id_menu":4,"count":1}]	8044	delivery	5	22
25170	2020-01-19 20:18:20	2020-01-19	8	[{"id_menu":5,"count":1}]	9822	delivery	5	13
25171	2020-01-19 20:21:29	2020-01-19	17	[{"id_menu":4,"count":1}]	6987	pick-up	0	17
25172	2020-01-19 20:21:46	2020-01-19	9	[{"id_menu":6,"count":1}]	9827	delivery	5	14
25173	2020-01-19 20:25:48	2020-01-19	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	9812	delivery	5	40
25174	2020-01-19 20:28:17	2020-01-19	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	9053	pick-up	0	21
25175	2020-01-19 20:35:56	2020-01-19	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	4172	pick-up	0	34
25176	2020-01-19 20:36:13	2020-01-19	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9828	delivery	5	34
25177	2020-01-19 20:37:28	2020-01-19	9	[{"id_menu":6,"count":1}]	925	pick-up	0	9
25178	2020-01-19 20:38:04	2020-01-19	12	[{"id_menu":3,"count":1}]	1993	pick-up	0	12
25179	2020-01-19 20:50:14	2020-01-19	14	[{"id_menu":2,"count":1}]	4556	delivery	5	19
25180	2020-01-19 20:53:59	2020-01-19	14	[{"id_menu":2,"count":1}]	3752	pick-up	0	14
25181	2020-01-19 20:55:21	2020-01-19	14	[{"id_menu":2,"count":1}]	9776	delivery	5	19
25182	2020-01-19 20:56:49	2020-01-19	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9502	delivery	5	42
25183	2020-01-19 20:59:45	2020-01-19	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	9780	delivery	5	25
25184	2020-01-19 21:01:28	2020-01-19	17	[{"id_menu":4,"count":1}]	3931	delivery	5	22
25185	2020-01-19 21:01:58	2020-01-19	8	[{"id_menu":5,"count":1}]	2280	pick-up	0	8
25186	2020-01-19 21:03:02	2020-01-19	9	[{"id_menu":7,"count":1}]	2174	delivery	5	14
25187	2020-01-19 21:03:13	2020-01-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9824	delivery	5	23
25188	2020-01-19 21:10:12	2020-01-19	9	[{"id_menu":6,"count":1}]	4949	delivery	5	14
25189	2020-01-19 21:10:44	2020-01-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2021	pick-up	0	23
25190	2020-01-19 21:15:59	2020-01-19	12	[{"id_menu":3,"count":1}]	5823	delivery	5	17
25191	2020-01-19 21:16:07	2020-01-19	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	9793	pick-up	0	38
25192	2020-01-19 21:16:18	2020-01-19	14	[{"id_menu":2,"count":1}]	9784	delivery	5	19
25193	2020-01-19 21:18:12	2020-01-19	17	[{"id_menu":4,"count":1}]	9777	delivery	5	22
25194	2020-01-19 21:23:14	2020-01-19	12	[{"id_menu":3,"count":1}]	489	delivery	5	17
25195	2020-01-19 21:30:22	2020-01-19	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3204	delivery	5	39
25196	2020-01-19 21:33:19	2020-01-19	8	[{"id_menu":5,"count":1}]	4518	delivery	5	13
25197	2020-01-19 21:34:26	2020-01-19	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	6202	pick-up	0	20
25198	2020-01-19 21:35:04	2020-01-19	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	9810	delivery	5	26
25199	2020-01-19 21:37:49	2020-01-19	12	[{"id_menu":3,"count":1}]	21	delivery	5	17
25200	2020-01-19 21:43:42	2020-01-19	12	[{"id_menu":3,"count":1}]	1795	pick-up	0	12
25201	2020-01-19 21:50:45	2020-01-19	14	[{"id_menu":2,"count":1}]	9256	pick-up	0	14
25202	2020-01-19 21:54:24	2020-01-19	12	[{"id_menu":1,"count":1}]	8736	delivery	5	17
25203	2020-01-19 22:01:04	2020-01-19	8	[{"id_menu":5,"count":1}]	9823	pick-up	0	8
25204	2020-01-19 22:01:29	2020-01-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2602	pick-up	0	26
25205	2020-01-19 22:12:28	2020-01-19	12	[{"id_menu":3,"count":1}]	6249	delivery	5	17
25206	2020-01-19 22:17:38	2020-01-19	14	[{"id_menu":2,"count":1}]	8877	delivery	5	19
25207	2020-01-19 22:27:15	2020-01-19	9	[{"id_menu":6,"count":1}]	2899	delivery	5	14
25208	2020-01-19 22:27:58	2020-01-19	14	[{"id_menu":2,"count":1}]	3679	delivery	5	19
25209	2020-01-19 22:36:10	2020-01-19	14	[{"id_menu":2,"count":1}]	158	pick-up	0	14
25210	2020-01-19 22:37:38	2020-01-19	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8503	delivery	5	47
25211	2020-01-19 22:42:48	2020-01-19	9	[{"id_menu":6,"count":2}]	4262	delivery	5	14
25212	2020-01-19 22:44:16	2020-01-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	8623	pick-up	0	23
25213	2020-01-19 22:45:32	2020-01-19	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	886	delivery	5	26
25214	2020-01-19 22:50:31	2020-01-19	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	9801	delivery	5	25
25215	2020-01-19 22:51:11	2020-01-19	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4021	delivery	5	31
25216	2020-01-19 22:59:16	2020-01-19	9	[{"id_menu":7,"count":1}]	660	pick-up	0	9
25217	2020-01-19 23:12:40	2020-01-19	9	[{"id_menu":7,"count":1}]	1902	pick-up	0	9
25218	2020-01-19 23:17:15	2020-01-19	9	[{"id_menu":6,"count":1}]	5350	pick-up	0	9
25219	2020-01-19 23:17:31	2020-01-19	8	[{"id_menu":5,"count":1}]	8628	delivery	5	13
25220	2020-01-19 23:17:58	2020-01-19	17	[{"id_menu":4,"count":1}]	1468	pick-up	0	17
25221	2020-01-19 23:19:51	2020-01-19	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	5870	delivery	5	25
25222	2020-01-19 23:33:08	2020-01-19	9	[{"id_menu":7,"count":1}]	9208	pick-up	0	9
25223	2020-01-19 23:37:06	2020-01-19	9	[{"id_menu":6,"count":1}]	7274	delivery	5	14
25224	2020-01-19 23:42:13	2020-01-19	9	[{"id_menu":6,"count":1}]	5910	delivery	5	14
25225	2020-01-19 23:43:56	2020-01-19	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	9813	pick-up	0	21
25226	2020-01-19 23:51:40	2020-01-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	1495	delivery	5	22
25227	2020-01-20 00:12:42	2020-01-20	17	[{"id_menu":4,"count":2}]	3547	pick-up	0	17
25228	2020-01-20 00:27:44	2020-01-20	14	[{"id_menu":2,"count":1}]	5253	pick-up	0	14
25229	2020-01-20 00:33:14	2020-01-20	9	[{"id_menu":6,"count":1}]	3148	pick-up	0	9
25230	2020-01-20 00:50:02	2020-01-20	9	[{"id_menu":6,"count":1}]	2378	pick-up	0	9
25231	2020-01-20 00:54:23	2020-01-20	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8798	delivery	5	42
25232	2020-01-20 01:00:18	2020-01-20	9	[{"id_menu":6,"count":1}]	9870	delivery	5	14
25233	2020-01-20 01:00:24	2020-01-20	12	[{"id_menu":3,"count":1}]	3160	pick-up	0	12
25234	2020-01-20 01:03:06	2020-01-20	12	[{"id_menu":3,"count":1}]	9855	delivery	5	17
25235	2020-01-20 01:05:42	2020-01-20	12	[{"id_menu":1,"count":1}]	9888	delivery	5	17
25236	2020-01-20 01:11:13	2020-01-20	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9866	delivery	5	42
25237	2020-01-20 01:19:34	2020-01-20	17	[{"id_menu":4,"count":1}]	3425	pick-up	0	17
25238	2020-01-20 01:30:32	2020-01-20	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	8265	pick-up	0	20
25239	2020-01-20 01:31:56	2020-01-20	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":3}]	8655	delivery	5	26
25240	2020-01-20 01:39:17	2020-01-20	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3320	pick-up	0	26
25241	2020-01-20 01:42:08	2020-01-20	12	[{"id_menu":3,"count":1}]	2579	pick-up	0	12
25242	2020-01-20 01:56:53	2020-01-20	9	[{"id_menu":7,"count":1}]	9898	delivery	5	14
25243	2020-01-20 01:57:20	2020-01-20	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	3294	delivery	5	25
25244	2020-01-20 02:02:02	2020-01-20	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	9878	delivery	5	26
25245	2020-01-20 02:12:03	2020-01-20	9	[{"id_menu":6,"count":3}]	3511	delivery	5	14
25246	2020-01-20 02:24:53	2020-01-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	9904	delivery	5	28
25247	2020-01-20 02:26:08	2020-01-20	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3647	pick-up	0	29
25248	2020-01-20 02:29:30	2020-01-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6369	pick-up	0	18
25249	2020-01-20 02:32:36	2020-01-20	12	[{"id_menu":3,"count":1}]	1186	delivery	5	17
25250	2020-01-20 02:38:34	2020-01-20	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7597	delivery	5	40
25251	2020-01-20 03:03:10	2020-01-20	9	[{"id_menu":6,"count":1}]	9864	delivery	5	14
25252	2020-01-20 03:12:27	2020-01-20	14	[{"id_menu":2,"count":1}]	9875	delivery	5	19
25253	2020-01-20 03:18:54	2020-01-20	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	8474	delivery	5	34
25254	2020-01-20 03:25:59	2020-01-20	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	2577	pick-up	0	24
25255	2020-01-20 03:26:28	2020-01-20	12	[{"id_menu":1,"count":1}]	3069	delivery	5	17
25256	2020-01-20 03:39:24	2020-01-20	8	[{"id_menu":5,"count":1}]	9907	pick-up	0	8
25257	2020-01-20 04:07:07	2020-01-20	9	[{"id_menu":6,"count":1}]	1997	delivery	5	14
25258	2020-01-20 04:16:18	2020-01-20	9	[{"id_menu":6,"count":1}]	9908	delivery	5	14
25259	2020-01-20 04:43:16	2020-01-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2181	pick-up	0	23
25260	2020-01-20 05:07:28	2020-01-20	12	[{"id_menu":3,"count":1}]	9865	delivery	5	17
25261	2020-01-20 05:13:36	2020-01-20	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3821	delivery	5	34
25262	2020-01-20 05:16:31	2020-01-20	12	[{"id_menu":3,"count":1}]	5192	delivery	5	17
25263	2020-01-20 05:30:06	2020-01-20	9	[{"id_menu":7,"count":2}]	9856	pick-up	0	9
25264	2020-01-20 05:33:29	2020-01-20	12	[{"id_menu":1,"count":1}]	1313	pick-up	0	12
25265	2020-01-20 06:03:41	2020-01-20	9	[{"id_menu":6,"count":2}]	9931	pick-up	0	9
25266	2020-01-20 06:08:07	2020-01-20	12	[{"id_menu":1,"count":1}]	5191	delivery	5	17
25267	2020-01-20 06:18:10	2020-01-20	9	[{"id_menu":6,"count":1}]	2025	pick-up	0	9
25268	2020-01-20 06:18:26	2020-01-20	14	[{"id_menu":2,"count":1}]	2519	pick-up	0	14
25269	2020-01-20 06:20:31	2020-01-20	8	[{"id_menu":5,"count":1}]	4284	delivery	5	13
25270	2020-01-20 06:25:01	2020-01-20	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2647	delivery	5	34
25271	2020-01-20 07:14:03	2020-01-20	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4190	delivery	5	36
25272	2020-01-20 07:22:04	2020-01-20	9	[{"id_menu":6,"count":1}]	1989	delivery	5	14
25273	2020-01-20 07:25:54	2020-01-20	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	9894	delivery	5	40
25274	2020-01-20 08:13:09	2020-01-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4870	delivery	5	23
25275	2020-01-20 08:18:56	2020-01-20	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	164	delivery	5	31
25276	2020-01-20 08:49:06	2020-01-20	14	[{"id_menu":2,"count":1}]	8071	pick-up	0	14
25277	2020-01-20 08:54:52	2020-01-20	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1630	delivery	5	31
25278	2020-01-20 09:07:31	2020-01-20	12	[{"id_menu":3,"count":1}]	3959	pick-up	0	12
25279	2020-01-20 09:36:44	2020-01-20	8	[{"id_menu":5,"count":1}]	5400	pick-up	0	8
25280	2020-01-20 10:02:45	2020-01-20	9	[{"id_menu":7,"count":1}]	2442	pick-up	0	9
25281	2020-01-20 10:17:58	2020-01-20	9	[{"id_menu":7,"count":1}]	6712	pick-up	0	9
25282	2020-01-20 10:18:57	2020-01-20	9	[{"id_menu":7,"count":1}]	8635	delivery	5	14
25283	2020-01-20 10:29:21	2020-01-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5249	delivery	5	22
25284	2020-01-20 10:39:31	2020-01-20	9	[{"id_menu":7,"count":1}]	9901	delivery	5	14
25285	2020-01-20 10:49:41	2020-01-20	12	[{"id_menu":3,"count":1}]	7563	delivery	5	17
25286	2020-01-20 11:07:15	2020-01-20	17	[{"id_menu":4,"count":1}]	3067	delivery	5	22
25287	2020-01-20 11:12:37	2020-01-20	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5765	pick-up	0	35
25288	2020-01-20 11:13:45	2020-01-20	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	9906	delivery	5	36
25289	2020-01-20 11:15:49	2020-01-20	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	4624	pick-up	0	26
25290	2020-01-20 11:23:47	2020-01-20	9	[{"id_menu":6,"count":1}]	4411	delivery	5	14
25291	2020-01-20 11:49:38	2020-01-20	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	9043	pick-up	0	21
25292	2020-01-20 11:59:52	2020-01-20	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7007	delivery	5	36
25293	2020-01-20 12:06:51	2020-01-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9871	delivery	5	28
25294	2020-01-20 12:26:53	2020-01-20	9	[{"id_menu":6,"count":1}]	1494	delivery	5	14
25295	2020-01-20 12:38:58	2020-01-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6154	delivery	5	28
25296	2020-01-20 12:55:28	2020-01-20	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	6265	pick-up	0	26
25297	2020-01-20 12:58:31	2020-01-20	12	[{"id_menu":3,"count":1}]	9922	delivery	5	17
25298	2020-01-20 13:10:03	2020-01-20	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":2}]	3116	pick-up	0	26
25299	2020-01-20 13:14:31	2020-01-20	12	[{"id_menu":3,"count":1}]	9889	delivery	5	17
25300	2020-01-20 13:18:56	2020-01-20	17	[{"id_menu":4,"count":1}]	9916	delivery	5	22
25301	2020-01-20 13:24:40	2020-01-20	17	[{"id_menu":4,"count":1}]	2812	delivery	5	22
25302	2020-01-20 13:26:14	2020-01-20	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	9924	delivery	5	26
25303	2020-01-20 13:30:01	2020-01-20	12	[{"id_menu":3,"count":1}]	9895	delivery	5	17
25304	2020-01-20 13:31:42	2020-01-20	14	[{"id_menu":2,"count":1}]	9900	delivery	5	19
25305	2020-01-20 13:44:56	2020-01-20	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3123	pick-up	0	33
25306	2020-01-20 14:05:00	2020-01-20	8	[{"id_menu":5,"count":1}]	9862	pick-up	0	8
25307	2020-01-20 14:09:29	2020-01-20	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2798	pick-up	0	47
25308	2020-01-20 14:22:50	2020-01-20	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	9890	delivery	5	57
25309	2020-01-20 14:23:37	2020-01-20	9	[{"id_menu":6,"count":1}]	4276	delivery	5	14
25310	2020-01-20 14:42:49	2020-01-20	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	5629	delivery	5	26
25311	2020-01-20 14:54:03	2020-01-20	9	[{"id_menu":7,"count":1}]	9876	delivery	5	14
25312	2020-01-20 15:08:18	2020-01-20	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5679	pick-up	0	34
25313	2020-01-20 15:23:48	2020-01-20	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	3202	delivery	5	26
25314	2020-01-20 15:26:49	2020-01-20	14	[{"id_menu":2,"count":1}]	5643	pick-up	0	14
25315	2020-01-20 15:33:33	2020-01-20	12	[{"id_menu":3,"count":1}]	9897	delivery	5	17
25316	2020-01-20 15:34:38	2020-01-20	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	9860	delivery	5	26
25317	2020-01-20 15:40:32	2020-01-20	14	[{"id_menu":2,"count":1}]	3303	delivery	5	19
25318	2020-01-20 15:47:08	2020-01-20	14	[{"id_menu":2,"count":1}]	4934	delivery	5	19
25319	2020-01-20 15:55:28	2020-01-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	6393	delivery	5	28
25320	2020-01-20 15:55:37	2020-01-20	12	[{"id_menu":3,"count":1}]	8700	delivery	5	17
25321	2020-01-20 16:02:21	2020-01-20	14	[{"id_menu":2,"count":1}]	8683	delivery	5	19
25322	2020-01-20 16:09:15	2020-01-20	12	[{"id_menu":3,"count":1}]	9652	delivery	5	17
25323	2020-01-20 16:20:37	2020-01-20	9	[{"id_menu":6,"count":1}]	2564	pick-up	0	9
25324	2020-01-20 16:23:12	2020-01-20	9	[{"id_menu":6,"count":1}]	9874	delivery	5	14
25325	2020-01-20 16:27:41	2020-01-20	17	[{"id_menu":4,"count":1}]	9896	delivery	5	22
25326	2020-01-20 16:38:18	2020-01-20	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5886	delivery	5	39
25327	2020-01-20 16:39:58	2020-01-20	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	9858	delivery	5	37
25328	2020-01-20 16:51:58	2020-01-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3640	delivery	5	28
25329	2020-01-20 16:54:25	2020-01-20	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	9915	delivery	5	37
25330	2020-01-20 17:02:16	2020-01-20	8	[{"id_menu":5,"count":1}]	4274	delivery	5	13
25331	2020-01-20 17:08:06	2020-01-20	8	[{"id_menu":5,"count":1}]	2536	pick-up	0	8
25332	2020-01-20 17:21:10	2020-01-20	12	[{"id_menu":1,"count":1}]	9869	delivery	5	17
25333	2020-01-20 17:26:09	2020-01-20	12	[{"id_menu":1,"count":1}]	8748	pick-up	0	12
25334	2020-01-20 17:27:51	2020-01-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	371	pick-up	0	17
25335	2020-01-20 17:29:39	2020-01-20	14	[{"id_menu":2,"count":1}]	2469	pick-up	0	14
25336	2020-01-20 17:41:31	2020-01-20	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1179	delivery	5	39
25337	2020-01-20 17:56:42	2020-01-20	8	[{"id_menu":5,"count":1}]	9879	delivery	5	13
25338	2020-01-20 17:58:04	2020-01-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9909	delivery	5	28
25339	2020-01-20 17:59:38	2020-01-20	9	[{"id_menu":7,"count":1}]	6854	delivery	5	14
25340	2020-01-20 18:13:46	2020-01-20	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	9854	delivery	5	28
25341	2020-01-20 18:14:49	2020-01-20	12	[{"id_menu":3,"count":1}]	9934	pick-up	0	12
25342	2020-01-20 18:25:32	2020-01-20	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9872	delivery	5	40
25343	2020-01-20 18:42:15	2020-01-20	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9917	delivery	5	48
25344	2020-01-20 18:58:55	2020-01-20	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	475	delivery	5	25
25345	2020-01-20 18:59:40	2020-01-20	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	3507	pick-up	0	21
25346	2020-01-20 19:00:19	2020-01-20	9	[{"id_menu":7,"count":1}]	3444	pick-up	0	9
25347	2020-01-20 19:14:41	2020-01-20	8	[{"id_menu":5,"count":1}]	6497	delivery	5	13
25348	2020-01-20 19:36:18	2020-01-20	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	5790	delivery	5	36
25349	2020-01-20 19:52:33	2020-01-20	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":2}]	9892	delivery	5	34
25350	2020-01-20 20:06:43	2020-01-20	9	[{"id_menu":7,"count":1}]	8747	delivery	5	14
25351	2020-01-20 20:07:56	2020-01-20	12	[{"id_menu":1,"count":1}]	9936	delivery	5	17
25352	2020-01-20 20:09:15	2020-01-20	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6600	delivery	5	31
25353	2020-01-20 20:09:52	2020-01-20	12	[{"id_menu":3,"count":1}]	8068	pick-up	0	12
25354	2020-01-20 20:12:50	2020-01-20	17	[{"id_menu":4,"count":1}]	4982	delivery	5	22
25355	2020-01-20 20:13:57	2020-01-20	12	[{"id_menu":1,"count":1}]	69	pick-up	0	12
25356	2020-01-20 20:15:21	2020-01-20	9	[{"id_menu":7,"count":1}]	170	pick-up	0	9
25357	2020-01-20 20:29:23	2020-01-20	9	[{"id_menu":7,"count":1}]	9798	delivery	5	14
25358	2020-01-20 20:30:34	2020-01-20	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2440	delivery	5	35
25359	2020-01-20 20:32:01	2020-01-20	12	[{"id_menu":1,"count":1}]	9920	delivery	5	17
25360	2020-01-20 20:32:15	2020-01-20	9	[{"id_menu":6,"count":2}]	9938	delivery	5	14
25361	2020-01-20 20:32:59	2020-01-20	9	[{"id_menu":6,"count":1}]	2783	pick-up	0	9
25362	2020-01-20 20:39:38	2020-01-20	12	[{"id_menu":3,"count":1}]	9193	pick-up	0	12
25363	2020-01-20 20:48:10	2020-01-20	8	[{"id_menu":5,"count":1}]	2114	pick-up	0	8
25364	2020-01-20 20:50:05	2020-01-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	9929	delivery	5	28
25365	2020-01-20 21:05:16	2020-01-20	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2004	pick-up	0	26
25366	2020-01-20 21:06:57	2020-01-20	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9885	delivery	5	36
25367	2020-01-20 21:34:05	2020-01-20	9	[{"id_menu":7,"count":1}]	6789	pick-up	0	9
25368	2020-01-20 21:34:38	2020-01-20	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	996	pick-up	0	29
25369	2020-01-20 21:53:49	2020-01-20	17	[{"id_menu":4,"count":1}]	9021	delivery	5	22
25370	2020-01-20 22:11:01	2020-01-20	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9868	delivery	5	45
25371	2020-01-20 22:12:01	2020-01-20	14	[{"id_menu":2,"count":2}]	8561	delivery	5	19
25372	2020-01-20 22:12:42	2020-01-20	12	[{"id_menu":1,"count":1}]	7306	delivery	5	17
25373	2020-01-20 22:17:04	2020-01-20	12	[{"id_menu":1,"count":1}]	9857	delivery	5	17
25374	2020-01-20 22:20:04	2020-01-20	12	[{"id_menu":1,"count":1}]	9928	delivery	5	17
25375	2020-01-20 22:23:54	2020-01-20	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1026	pick-up	0	29
25376	2020-01-20 22:25:11	2020-01-20	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	8583	delivery	5	26
25377	2020-01-20 22:46:03	2020-01-20	9	[{"id_menu":6,"count":1}]	9939	delivery	5	14
25378	2020-01-20 22:51:31	2020-01-20	17	[{"id_menu":4,"count":1}]	9903	delivery	5	22
25379	2020-01-20 23:02:50	2020-01-20	12	[{"id_menu":3,"count":1}]	9902	delivery	5	17
25380	2020-01-20 23:03:18	2020-01-20	14	[{"id_menu":2,"count":1}]	5	pick-up	0	14
25381	2020-01-20 23:25:32	2020-01-20	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	4685	pick-up	0	38
25382	2020-01-20 23:27:49	2020-01-20	9	[{"id_menu":7,"count":1}]	9882	delivery	5	14
25383	2020-01-20 23:41:37	2020-01-20	9	[{"id_menu":6,"count":1}]	7766	pick-up	0	9
25384	2020-01-20 23:46:39	2020-01-20	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	9880	delivery	5	26
25385	2020-01-20 23:56:22	2020-01-20	12	[{"id_menu":1,"count":1}]	7772	pick-up	0	12
25386	2020-01-21 00:11:42	2020-01-21	14	[{"id_menu":2,"count":1}]	9968	delivery	5	19
25387	2020-01-21 00:20:22	2020-01-21	9	[{"id_menu":7,"count":1}]	5642	pick-up	0	9
25388	2020-01-21 00:25:44	2020-01-21	12	[{"id_menu":3,"count":1}]	5332	delivery	5	17
25389	2020-01-21 00:29:14	2020-01-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2956	pick-up	0	26
25390	2020-01-21 00:46:44	2020-01-21	9	[{"id_menu":6,"count":1}]	9941	delivery	5	14
25391	2020-01-21 00:49:10	2020-01-21	8	[{"id_menu":5,"count":1}]	9966	delivery	5	13
25392	2020-01-21 01:21:06	2020-01-21	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10017	delivery	5	39
25393	2020-01-21 01:21:32	2020-01-21	9	[{"id_menu":6,"count":1}]	1657	pick-up	0	9
25394	2020-01-21 01:27:30	2020-01-21	9	[{"id_menu":7,"count":2}]	9987	pick-up	0	9
25395	2020-01-21 01:28:14	2020-01-21	12	[{"id_menu":1,"count":1}]	551	pick-up	0	12
25396	2020-01-21 01:31:21	2020-01-21	12	[{"id_menu":1,"count":1}]	3877	delivery	5	17
25397	2020-01-21 01:34:41	2020-01-21	9	[{"id_menu":6,"count":1}]	2074	delivery	5	14
25398	2020-01-21 01:43:04	2020-01-21	9	[{"id_menu":7,"count":2}]	9958	delivery	5	14
25399	2020-01-21 01:45:52	2020-01-21	12	[{"id_menu":3,"count":1}]	10013	delivery	5	17
25400	2020-01-21 01:50:56	2020-01-21	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2706	pick-up	0	38
25401	2020-01-21 01:56:11	2020-01-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8971	delivery	5	23
25402	2020-01-21 02:04:44	2020-01-21	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	8716	pick-up	0	31
25403	2020-01-21 02:37:57	2020-01-21	9	[{"id_menu":6,"count":1}]	10001	delivery	5	14
25404	2020-01-21 02:48:19	2020-01-21	12	[{"id_menu":1,"count":1}]	2798	pick-up	0	12
25405	2020-01-21 02:49:39	2020-01-21	8	[{"id_menu":5,"count":1}]	9896	delivery	5	13
25406	2020-01-21 02:50:06	2020-01-21	8	[{"id_menu":5,"count":1}]	7435	delivery	5	13
25407	2020-01-21 03:11:32	2020-01-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6825	pick-up	0	17
25408	2020-01-21 03:26:40	2020-01-21	17	[{"id_menu":4,"count":1}]	7161	delivery	5	22
25409	2020-01-21 03:31:01	2020-01-21	12	[{"id_menu":1,"count":2}]	9995	pick-up	0	12
25410	2020-01-21 03:36:00	2020-01-21	9	[{"id_menu":6,"count":1}]	3116	delivery	5	14
25411	2020-01-21 03:38:27	2020-01-21	14	[{"id_menu":2,"count":1}]	5215	pick-up	0	14
25412	2020-01-21 03:42:47	2020-01-21	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":3}]	9956	delivery	5	25
25413	2020-01-21 03:46:16	2020-01-21	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	372	pick-up	0	31
25414	2020-01-21 04:17:09	2020-01-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6894	delivery	5	28
25415	2020-01-21 04:17:25	2020-01-21	12	[{"id_menu":1,"count":1}]	9988	delivery	5	17
25416	2020-01-21 04:20:36	2020-01-21	17	[{"id_menu":4,"count":1}]	10008	pick-up	0	17
25417	2020-01-21 04:23:09	2020-01-21	9	[{"id_menu":6,"count":1}]	1727	delivery	5	14
25418	2020-01-21 04:27:12	2020-01-21	8	[{"id_menu":5,"count":2}]	32	pick-up	0	8
25419	2020-01-21 04:33:10	2020-01-21	9	[{"id_menu":7,"count":1}]	9998	delivery	5	14
25420	2020-01-21 04:34:01	2020-01-21	17	[{"id_menu":4,"count":1}]	6869	pick-up	0	17
25421	2020-01-21 04:53:29	2020-01-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9977	pick-up	0	26
25422	2020-01-21 04:53:40	2020-01-21	12	[{"id_menu":3,"count":1}]	10012	delivery	5	17
25423	2020-01-21 04:55:06	2020-01-21	9	[{"id_menu":7,"count":1}]	9969	delivery	5	14
25424	2020-01-21 04:57:29	2020-01-21	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2770	pick-up	0	32
25425	2020-01-21 05:20:54	2020-01-21	17	[{"id_menu":4,"count":1}]	868	pick-up	0	17
25426	2020-01-21 05:35:34	2020-01-21	17	[{"id_menu":4,"count":1}]	3113	pick-up	0	17
25427	2020-01-21 06:23:12	2020-01-21	9	[{"id_menu":7,"count":1}]	5794	delivery	5	14
25428	2020-01-21 06:45:14	2020-01-21	8	[{"id_menu":5,"count":1}]	6993	delivery	5	13
25429	2020-01-21 06:50:24	2020-01-21	9	[{"id_menu":6,"count":1}]	8087	delivery	5	14
25430	2020-01-21 07:06:29	2020-01-21	8	[{"id_menu":5,"count":1}]	9994	delivery	5	13
25431	2020-01-21 07:15:03	2020-01-21	9	[{"id_menu":6,"count":1}]	9944	delivery	5	14
25432	2020-01-21 07:18:57	2020-01-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9963	delivery	5	23
25433	2020-01-21 07:25:11	2020-01-21	9	[{"id_menu":7,"count":1}]	5094	pick-up	0	9
25434	2020-01-21 07:41:15	2020-01-21	14	[{"id_menu":2,"count":1}]	9428	delivery	5	19
25435	2020-01-21 07:47:15	2020-01-21	9	[{"id_menu":6,"count":2}]	1722	delivery	5	14
25436	2020-01-21 07:50:36	2020-01-21	12	[{"id_menu":3,"count":1}]	3788	pick-up	0	12
25437	2020-01-21 08:18:01	2020-01-21	12	[{"id_menu":1,"count":1}]	8312	pick-up	0	12
25438	2020-01-21 08:34:46	2020-01-21	9	[{"id_menu":7,"count":1}]	1068	pick-up	0	9
25439	2020-01-21 08:43:49	2020-01-21	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2420	pick-up	0	29
25440	2020-01-21 08:48:29	2020-01-21	14	[{"id_menu":2,"count":1}]	6769	pick-up	0	14
25441	2020-01-21 08:48:50	2020-01-21	12	[{"id_menu":3,"count":1}]	478	pick-up	0	12
25442	2020-01-21 09:05:44	2020-01-21	14	[{"id_menu":2,"count":1}]	10014	delivery	5	19
25443	2020-01-21 09:06:21	2020-01-21	12	[{"id_menu":1,"count":1}]	1529	delivery	5	17
25444	2020-01-21 09:10:04	2020-01-21	14	[{"id_menu":2,"count":1}]	6480	delivery	5	19
25445	2020-01-21 09:21:22	2020-01-21	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	9984	delivery	5	26
25446	2020-01-21 09:32:15	2020-01-21	9	[{"id_menu":6,"count":1}]	2580	pick-up	0	9
25447	2020-01-21 09:36:45	2020-01-21	9	[{"id_menu":7,"count":1}]	506	delivery	5	14
25448	2020-01-21 09:40:14	2020-01-21	8	[{"id_menu":5,"count":1}]	9989	pick-up	0	8
25449	2020-01-21 09:57:08	2020-01-21	9	[{"id_menu":7,"count":1}]	9620	delivery	5	14
25450	2020-01-21 10:03:01	2020-01-21	14	[{"id_menu":2,"count":1}]	3365	delivery	5	19
25451	2020-01-21 10:03:12	2020-01-21	14	[{"id_menu":2,"count":2}]	2478	delivery	5	19
25452	2020-01-21 10:10:20	2020-01-21	12	[{"id_menu":3,"count":1}]	5180	pick-up	0	12
25453	2020-01-21 10:13:13	2020-01-21	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	265	delivery	5	31
25454	2020-01-21 10:20:49	2020-01-21	9	[{"id_menu":6,"count":1}]	7876	delivery	5	14
25455	2020-01-21 10:26:58	2020-01-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3755	delivery	5	22
25456	2020-01-21 10:27:36	2020-01-21	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	2116	pick-up	0	22
25457	2020-01-21 10:38:30	2020-01-21	17	[{"id_menu":4,"count":1}]	932	pick-up	0	17
25458	2020-01-21 10:40:23	2020-01-21	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	9737	delivery	5	42
25459	2020-01-21 11:00:21	2020-01-21	9	[{"id_menu":6,"count":1}]	8092	delivery	5	14
25460	2020-01-21 11:04:36	2020-01-21	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5473	delivery	5	42
25461	2020-01-21 11:07:05	2020-01-21	14	[{"id_menu":2,"count":1}]	9938	delivery	5	19
25462	2020-01-21 11:30:58	2020-01-21	8	[{"id_menu":5,"count":1}]	71	delivery	5	13
25463	2020-01-21 11:39:09	2020-01-21	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	291	pick-up	0	40
25464	2020-01-21 11:43:24	2020-01-21	14	[{"id_menu":2,"count":1}]	2305	delivery	5	19
25465	2020-01-21 11:43:39	2020-01-21	17	[{"id_menu":4,"count":1}]	4089	pick-up	0	17
25466	2020-01-21 11:45:39	2020-01-21	14	[{"id_menu":2,"count":1}]	5811	delivery	5	19
25467	2020-01-21 11:48:50	2020-01-21	17	[{"id_menu":4,"count":1}]	8054	pick-up	0	17
25468	2020-01-21 11:52:29	2020-01-21	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2604	delivery	5	30
25469	2020-01-21 11:55:47	2020-01-21	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10011	delivery	5	42
25470	2020-01-21 12:00:21	2020-01-21	9	[{"id_menu":6,"count":1}]	2139	pick-up	0	9
25471	2020-01-21 12:06:44	2020-01-21	8	[{"id_menu":5,"count":1}]	9943	pick-up	0	8
25472	2020-01-21 12:13:45	2020-01-21	9	[{"id_menu":6,"count":1}]	4076	delivery	5	14
25473	2020-01-21 12:30:50	2020-01-21	26	[{"id_menu":1,"count":3},{"id_menu":2,"count":1}]	4634	pick-up	0	26
25474	2020-01-21 12:36:32	2020-01-21	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3871	pick-up	0	39
25475	2020-01-21 13:07:19	2020-01-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	7000	delivery	5	28
25476	2020-01-21 13:10:33	2020-01-21	9	[{"id_menu":6,"count":1}]	9990	pick-up	0	9
25477	2020-01-21 13:14:49	2020-01-21	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9942	delivery	5	31
25478	2020-01-21 13:31:22	2020-01-21	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9021	delivery	5	44
25479	2020-01-21 13:47:45	2020-01-21	8	[{"id_menu":5,"count":1}]	9951	delivery	5	13
25480	2020-01-21 14:08:10	2020-01-21	8	[{"id_menu":5,"count":1}]	3150	delivery	5	13
25481	2020-01-21 14:28:40	2020-01-21	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	10006	delivery	5	23
25482	2020-01-21 14:40:01	2020-01-21	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9982	delivery	5	42
25483	2020-01-21 14:46:05	2020-01-21	12	[{"id_menu":1,"count":1}]	7170	delivery	5	17
25484	2020-01-21 14:55:10	2020-01-21	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9587	delivery	5	34
25485	2020-01-21 14:58:45	2020-01-21	9	[{"id_menu":6,"count":1}]	10016	pick-up	0	9
25486	2020-01-21 15:23:53	2020-01-21	14	[{"id_menu":2,"count":1}]	9991	delivery	5	19
25487	2020-01-21 15:29:47	2020-01-21	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	5764	delivery	5	29
25488	2020-01-21 15:46:06	2020-01-21	9	[{"id_menu":7,"count":1}]	10020	delivery	5	14
25489	2020-01-21 15:49:57	2020-01-21	9	[{"id_menu":6,"count":1}]	9954	delivery	5	14
25490	2020-01-21 15:50:02	2020-01-21	17	[{"id_menu":4,"count":1}]	21	pick-up	0	17
25491	2020-01-21 15:53:56	2020-01-21	17	[{"id_menu":4,"count":1}]	10018	delivery	5	22
25492	2020-01-21 15:56:48	2020-01-21	12	[{"id_menu":1,"count":1}]	10010	pick-up	0	12
25493	2020-01-21 15:57:39	2020-01-21	17	[{"id_menu":4,"count":1}]	6101	pick-up	0	17
25494	2020-01-21 16:33:09	2020-01-21	14	[{"id_menu":2,"count":1}]	5963	pick-up	0	14
25495	2020-01-21 16:40:58	2020-01-21	8	[{"id_menu":5,"count":1}]	3142	delivery	5	13
25496	2020-01-21 16:45:57	2020-01-21	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	7143	delivery	5	26
25497	2020-01-21 16:58:13	2020-01-21	9	[{"id_menu":7,"count":1}]	3779	delivery	5	14
25498	2020-01-21 17:00:37	2020-01-21	9	[{"id_menu":6,"count":1}]	7854	pick-up	0	9
25499	2020-01-21 17:01:33	2020-01-21	23	[{"id_menu":2,"count":3},{"id_menu":7,"count":1}]	1072	pick-up	0	23
25500	2020-01-21 17:12:13	2020-01-21	17	[{"id_menu":4,"count":1}]	801	delivery	5	22
25501	2020-01-21 17:34:13	2020-01-21	17	[{"id_menu":4,"count":1}]	351	delivery	5	22
25502	2020-01-21 17:53:41	2020-01-21	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9992	delivery	5	30
25503	2020-01-21 17:56:37	2020-01-21	12	[{"id_menu":3,"count":1}]	7387	delivery	5	17
25504	2020-01-21 17:58:43	2020-01-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5423	delivery	5	28
25505	2020-01-21 18:00:04	2020-01-21	9	[{"id_menu":6,"count":1}]	3380	pick-up	0	9
25506	2020-01-21 18:01:34	2020-01-21	9	[{"id_menu":6,"count":1}]	9986	delivery	5	14
25507	2020-01-21 18:01:45	2020-01-21	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1055	pick-up	0	38
25508	2020-01-21 18:06:40	2020-01-21	14	[{"id_menu":2,"count":1}]	10007	pick-up	0	14
25509	2020-01-21 18:33:05	2020-01-21	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9891	delivery	5	39
25510	2020-01-21 18:53:46	2020-01-21	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5475	delivery	5	52
25511	2020-01-21 19:06:33	2020-01-21	12	[{"id_menu":3,"count":2}]	228	pick-up	0	12
25512	2020-01-21 19:15:26	2020-01-21	17	[{"id_menu":4,"count":1}]	9999	delivery	5	22
25513	2020-01-21 19:42:40	2020-01-21	12	[{"id_menu":1,"count":1}]	7299	delivery	5	17
25514	2020-01-21 20:03:38	2020-01-21	9	[{"id_menu":6,"count":1}]	9970	delivery	5	14
25515	2020-01-21 20:13:12	2020-01-21	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	9996	delivery	5	39
25516	2020-01-21 20:14:32	2020-01-21	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	9285	delivery	5	27
25517	2020-01-21 20:17:19	2020-01-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	9964	delivery	5	22
25518	2020-01-21 20:22:40	2020-01-21	12	[{"id_menu":3,"count":1}]	2418	pick-up	0	12
25519	2020-01-21 20:35:09	2020-01-21	14	[{"id_menu":2,"count":1}]	9978	delivery	5	19
25520	2020-01-21 20:44:47	2020-01-21	17	[{"id_menu":4,"count":1}]	1106	delivery	5	22
25521	2020-01-21 20:45:26	2020-01-21	8	[{"id_menu":5,"count":1}]	749	pick-up	0	8
25522	2020-01-21 20:45:51	2020-01-21	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6062	pick-up	0	38
25523	2020-01-21 20:52:17	2020-01-21	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9967	delivery	5	36
25524	2020-01-21 20:59:58	2020-01-21	9	[{"id_menu":7,"count":1}]	2131	pick-up	0	9
25525	2020-01-21 21:02:59	2020-01-21	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3509	pick-up	0	22
25526	2020-01-21 21:03:43	2020-01-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	5635	delivery	5	22
25527	2020-01-21 21:05:21	2020-01-21	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3366	pick-up	0	25
25528	2020-01-21 21:09:27	2020-01-21	9	[{"id_menu":6,"count":2}]	10015	delivery	5	14
25529	2020-01-21 21:11:56	2020-01-21	12	[{"id_menu":1,"count":1}]	10019	pick-up	0	12
25530	2020-01-21 21:12:36	2020-01-21	9	[{"id_menu":7,"count":1}]	5308	pick-up	0	9
25531	2020-01-21 21:18:23	2020-01-21	17	[{"id_menu":4,"count":1}]	2931	delivery	5	22
25532	2020-01-21 21:27:46	2020-01-21	14	[{"id_menu":2,"count":1}]	4629	pick-up	0	14
25533	2020-01-21 21:34:49	2020-01-21	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	10002	delivery	5	26
25534	2020-01-21 21:35:02	2020-01-21	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	10000	delivery	5	26
25535	2020-01-21 21:44:33	2020-01-21	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	9948	delivery	5	25
25536	2020-01-21 22:18:48	2020-01-21	9	[{"id_menu":6,"count":1}]	1604	pick-up	0	9
25537	2020-01-21 22:46:15	2020-01-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9950	delivery	5	22
25538	2020-01-21 23:25:44	2020-01-21	17	[{"id_menu":4,"count":1}]	2584	pick-up	0	17
25539	2020-01-21 23:30:37	2020-01-21	9	[{"id_menu":7,"count":1}]	7643	delivery	5	14
25540	2020-01-21 23:33:39	2020-01-21	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	9957	delivery	5	36
25541	2020-01-21 23:34:36	2020-01-21	14	[{"id_menu":2,"count":1}]	9947	pick-up	0	14
25542	2020-01-21 23:38:35	2020-01-21	9	[{"id_menu":7,"count":1}]	2986	pick-up	0	9
25543	2020-01-21 23:44:13	2020-01-21	17	[{"id_menu":4,"count":1}]	397	delivery	5	22
25544	2020-01-21 23:44:16	2020-01-21	9	[{"id_menu":6,"count":1}]	5354	delivery	5	14
25545	2020-01-21 23:48:28	2020-01-21	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	5570	delivery	5	37
25546	2020-01-21 23:56:31	2020-01-21	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	7476	delivery	5	26
25547	2020-01-22 00:02:35	2020-01-22	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2007	delivery	5	31
25548	2020-01-22 00:14:14	2020-01-22	12	[{"id_menu":1,"count":1}]	8658	pick-up	0	12
25549	2020-01-22 00:24:29	2020-01-22	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	10101	delivery	5	29
25550	2020-01-22 00:27:19	2020-01-22	9	[{"id_menu":6,"count":1}]	5473	pick-up	0	9
25551	2020-01-22 00:29:42	2020-01-22	14	[{"id_menu":2,"count":1}]	418	pick-up	0	14
25552	2020-01-22 00:33:22	2020-01-22	9	[{"id_menu":6,"count":1}]	1118	pick-up	0	9
25553	2020-01-22 00:35:42	2020-01-22	14	[{"id_menu":2,"count":1}]	9166	delivery	5	19
25554	2020-01-22 00:38:11	2020-01-22	17	[{"id_menu":4,"count":1}]	6969	delivery	5	22
25555	2020-01-22 00:44:03	2020-01-22	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	10078	delivery	5	26
25556	2020-01-22 00:44:36	2020-01-22	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	10050	pick-up	0	26
25557	2020-01-22 00:58:24	2020-01-22	14	[{"id_menu":2,"count":1}]	9627	pick-up	0	14
25558	2020-01-22 01:23:36	2020-01-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7821	delivery	5	22
25559	2020-01-22 01:48:54	2020-01-22	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1638	delivery	5	26
25560	2020-01-22 01:53:48	2020-01-22	8	[{"id_menu":5,"count":1}]	4193	delivery	5	13
25561	2020-01-22 01:53:48	2020-01-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10091	delivery	5	22
25562	2020-01-22 01:54:13	2020-01-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10081	delivery	5	23
25563	2020-01-22 02:00:54	2020-01-22	14	[{"id_menu":2,"count":1}]	4685	delivery	5	19
25564	2020-01-22 02:01:49	2020-01-22	12	[{"id_menu":1,"count":1}]	4132	pick-up	0	12
25565	2020-01-22 02:07:43	2020-01-22	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	7259	delivery	5	26
25566	2020-01-22 02:10:55	2020-01-22	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3449	pick-up	0	26
25567	2020-01-22 02:15:01	2020-01-22	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	10098	pick-up	0	33
25568	2020-01-22 02:15:31	2020-01-22	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	9076	delivery	5	25
25569	2020-01-22 02:29:44	2020-01-22	14	[{"id_menu":2,"count":2}]	10065	delivery	5	19
25570	2020-01-22 02:33:09	2020-01-22	12	[{"id_menu":3,"count":1}]	4004	pick-up	0	12
25571	2020-01-22 02:41:21	2020-01-22	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	3831	delivery	5	22
25572	2020-01-22 02:48:52	2020-01-22	9	[{"id_menu":7,"count":1}]	8265	delivery	5	14
25573	2020-01-22 02:54:52	2020-01-22	9	[{"id_menu":6,"count":1}]	2858	delivery	5	14
25574	2020-01-22 02:56:27	2020-01-22	17	[{"id_menu":4,"count":1}]	1890	delivery	5	22
25575	2020-01-22 02:56:47	2020-01-22	17	[{"id_menu":4,"count":1}]	1409	pick-up	0	17
25576	2020-01-22 02:57:00	2020-01-22	8	[{"id_menu":5,"count":1}]	10104	delivery	5	13
25577	2020-01-22 03:05:31	2020-01-22	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10027	delivery	5	45
25578	2020-01-22 03:12:25	2020-01-22	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9612	delivery	5	42
25579	2020-01-22 03:25:06	2020-01-22	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10056	delivery	5	37
25580	2020-01-22 03:30:19	2020-01-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10052	delivery	5	22
25581	2020-01-22 03:30:23	2020-01-22	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	6885	pick-up	0	22
25582	2020-01-22 03:36:55	2020-01-22	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	6221	delivery	5	39
25583	2020-01-22 03:44:03	2020-01-22	17	[{"id_menu":4,"count":1}]	1106	pick-up	0	17
25584	2020-01-22 03:49:05	2020-01-22	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	10029	delivery	5	26
25585	2020-01-22 03:55:47	2020-01-22	17	[{"id_menu":4,"count":1}]	10040	pick-up	0	17
25586	2020-01-22 03:56:04	2020-01-22	9	[{"id_menu":7,"count":1}]	2815	delivery	5	14
25587	2020-01-22 03:57:28	2020-01-22	8	[{"id_menu":5,"count":1}]	10072	delivery	5	13
25588	2020-01-22 03:58:53	2020-01-22	14	[{"id_menu":2,"count":2}]	2585	delivery	5	19
25589	2020-01-22 04:01:42	2020-01-22	9	[{"id_menu":7,"count":1}]	10044	pick-up	0	9
25590	2020-01-22 04:01:51	2020-01-22	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	591	delivery	5	26
25591	2020-01-22 04:24:38	2020-01-22	17	[{"id_menu":4,"count":1}]	8354	pick-up	0	17
25592	2020-01-22 04:28:10	2020-01-22	12	[{"id_menu":1,"count":1}]	4204	delivery	5	17
25593	2020-01-22 04:43:20	2020-01-22	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10038	pick-up	0	25
25594	2020-01-22 04:48:38	2020-01-22	8	[{"id_menu":5,"count":1}]	2851	delivery	5	13
25595	2020-01-22 04:48:59	2020-01-22	12	[{"id_menu":3,"count":1}]	4300	delivery	5	17
25596	2020-01-22 04:59:21	2020-01-22	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	8355	pick-up	0	21
25597	2020-01-22 04:59:51	2020-01-22	8	[{"id_menu":5,"count":2}]	4364	delivery	5	13
25598	2020-01-22 05:17:29	2020-01-22	9	[{"id_menu":7,"count":1}]	9675	delivery	5	14
25599	2020-01-22 05:18:46	2020-01-22	12	[{"id_menu":1,"count":1}]	1468	pick-up	0	12
25600	2020-01-22 05:31:28	2020-01-22	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	10048	delivery	5	31
25601	2020-01-22 05:36:06	2020-01-22	14	[{"id_menu":2,"count":1}]	10042	pick-up	0	14
25602	2020-01-22 05:39:18	2020-01-22	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9039	delivery	5	31
25603	2020-01-22 05:46:54	2020-01-22	17	[{"id_menu":4,"count":1}]	3864	pick-up	0	17
25604	2020-01-22 05:49:41	2020-01-22	14	[{"id_menu":2,"count":1}]	1588	delivery	5	19
25605	2020-01-22 06:06:09	2020-01-22	17	[{"id_menu":4,"count":1}]	963	pick-up	0	17
25606	2020-01-22 06:10:55	2020-01-22	9	[{"id_menu":6,"count":1}]	970	delivery	5	14
25607	2020-01-22 06:17:51	2020-01-22	8	[{"id_menu":5,"count":1}]	5082	delivery	5	13
25608	2020-01-22 06:25:14	2020-01-22	14	[{"id_menu":2,"count":1}]	511	pick-up	0	14
25609	2020-01-22 06:32:01	2020-01-22	9	[{"id_menu":6,"count":2}]	4084	delivery	5	14
25610	2020-01-22 06:32:30	2020-01-22	9	[{"id_menu":7,"count":1}]	1947	pick-up	0	9
25611	2020-01-22 06:32:52	2020-01-22	9	[{"id_menu":6,"count":1}]	7580	delivery	5	14
25612	2020-01-22 06:34:36	2020-01-22	14	[{"id_menu":2,"count":1}]	5180	delivery	5	19
25613	2020-01-22 06:45:08	2020-01-22	17	[{"id_menu":4,"count":1}]	1765	pick-up	0	17
25614	2020-01-22 06:49:12	2020-01-22	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2729	delivery	5	43
25615	2020-01-22 06:52:40	2020-01-22	9	[{"id_menu":7,"count":1}]	1563	pick-up	0	9
25616	2020-01-22 06:59:59	2020-01-22	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	10073	pick-up	0	21
25617	2020-01-22 07:01:49	2020-01-22	12	[{"id_menu":1,"count":1}]	6951	delivery	5	17
25618	2020-01-22 07:01:54	2020-01-22	14	[{"id_menu":2,"count":1}]	787	delivery	5	19
25619	2020-01-22 07:13:28	2020-01-22	9	[{"id_menu":6,"count":1}]	8873	pick-up	0	9
25620	2020-01-22 07:31:03	2020-01-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1000	pick-up	0	23
25621	2020-01-22 07:41:04	2020-01-22	14	[{"id_menu":2,"count":1}]	5172	delivery	5	19
25622	2020-01-22 07:42:38	2020-01-22	14	[{"id_menu":2,"count":1}]	4655	delivery	5	19
25623	2020-01-22 07:43:19	2020-01-22	8	[{"id_menu":5,"count":1}]	7947	delivery	5	13
25624	2020-01-22 07:44:25	2020-01-22	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	505	pick-up	0	26
25625	2020-01-22 07:48:17	2020-01-22	17	[{"id_menu":4,"count":1}]	5179	delivery	5	22
25626	2020-01-22 07:50:20	2020-01-22	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	10051	delivery	5	26
25627	2020-01-22 08:03:47	2020-01-22	14	[{"id_menu":2,"count":1}]	3780	pick-up	0	14
25628	2020-01-22 08:09:09	2020-01-22	12	[{"id_menu":3,"count":1}]	10067	pick-up	0	12
25629	2020-01-22 08:09:26	2020-01-22	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	379	pick-up	0	20
25630	2020-01-22 08:19:48	2020-01-22	12	[{"id_menu":3,"count":2}]	6604	delivery	5	17
25631	2020-01-22 08:33:15	2020-01-22	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	6879	delivery	5	37
25632	2020-01-22 08:38:45	2020-01-22	17	[{"id_menu":4,"count":1}]	10062	delivery	5	22
25633	2020-01-22 08:51:29	2020-01-22	8	[{"id_menu":5,"count":1}]	10036	delivery	5	13
25634	2020-01-22 08:52:04	2020-01-22	9	[{"id_menu":7,"count":1}]	6015	delivery	5	14
25635	2020-01-22 08:56:53	2020-01-22	9	[{"id_menu":6,"count":1}]	1484	pick-up	0	9
25636	2020-01-22 08:59:14	2020-01-22	14	[{"id_menu":2,"count":1}]	527	pick-up	0	14
25637	2020-01-22 08:59:31	2020-01-22	12	[{"id_menu":1,"count":1}]	1215	pick-up	0	12
25638	2020-01-22 09:02:53	2020-01-22	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10069	delivery	5	22
25639	2020-01-22 09:10:15	2020-01-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8068	pick-up	0	23
25640	2020-01-22 09:10:25	2020-01-22	17	[{"id_menu":4,"count":1}]	8314	delivery	5	22
25641	2020-01-22 09:35:07	2020-01-22	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	1960	pick-up	0	40
25642	2020-01-22 09:40:47	2020-01-22	12	[{"id_menu":1,"count":1}]	1834	pick-up	0	12
25643	2020-01-22 09:47:47	2020-01-22	17	[{"id_menu":4,"count":1}]	1889	pick-up	0	17
25644	2020-01-22 10:00:14	2020-01-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2504	delivery	5	22
25645	2020-01-22 10:16:06	2020-01-22	9	[{"id_menu":6,"count":1}]	3633	delivery	5	14
25646	2020-01-22 10:27:25	2020-01-22	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10025	delivery	5	36
25647	2020-01-22 10:30:43	2020-01-22	12	[{"id_menu":1,"count":1}]	10089	delivery	5	17
25648	2020-01-22 10:36:49	2020-01-22	9	[{"id_menu":6,"count":1}]	10097	delivery	5	14
25649	2020-01-22 10:44:12	2020-01-22	9	[{"id_menu":6,"count":1}]	10033	delivery	5	14
25650	2020-01-22 10:48:17	2020-01-22	17	[{"id_menu":4,"count":1}]	10037	delivery	5	22
25651	2020-01-22 10:52:21	2020-01-22	9	[{"id_menu":7,"count":1}]	6147	delivery	5	14
25652	2020-01-22 10:58:02	2020-01-22	17	[{"id_menu":4,"count":1}]	6941	pick-up	0	17
25653	2020-01-22 11:00:15	2020-01-22	9	[{"id_menu":7,"count":1}]	10096	delivery	5	14
25654	2020-01-22 11:02:31	2020-01-22	8	[{"id_menu":5,"count":1}]	10059	delivery	5	13
25655	2020-01-22 11:13:46	2020-01-22	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7178	delivery	5	36
25656	2020-01-22 11:28:10	2020-01-22	8	[{"id_menu":5,"count":1}]	6869	pick-up	0	8
25657	2020-01-22 11:28:14	2020-01-22	9	[{"id_menu":6,"count":1}]	10026	delivery	5	14
25658	2020-01-22 11:36:36	2020-01-22	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10031	delivery	5	45
25659	2020-01-22 11:57:27	2020-01-22	12	[{"id_menu":3,"count":1}]	5786	delivery	5	17
25660	2020-01-22 12:01:18	2020-01-22	17	[{"id_menu":4,"count":1}]	10076	delivery	5	22
25661	2020-01-22 12:10:09	2020-01-22	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	10083	delivery	5	40
25662	2020-01-22 12:13:39	2020-01-22	12	[{"id_menu":1,"count":1}]	5279	pick-up	0	12
25663	2020-01-22 12:29:32	2020-01-22	17	[{"id_menu":4,"count":1}]	2706	pick-up	0	17
25664	2020-01-22 12:41:23	2020-01-22	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1742	delivery	5	25
25665	2020-01-22 12:50:13	2020-01-22	14	[{"id_menu":2,"count":1}]	10023	delivery	5	19
25666	2020-01-22 13:01:30	2020-01-22	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10071	delivery	5	40
25667	2020-01-22 13:06:32	2020-01-22	9	[{"id_menu":6,"count":1}]	3459	pick-up	0	9
25668	2020-01-22 13:14:30	2020-01-22	17	[{"id_menu":4,"count":2}]	3527	pick-up	0	17
25669	2020-01-22 13:15:30	2020-01-22	9	[{"id_menu":7,"count":1}]	3069	delivery	5	14
25670	2020-01-22 13:19:46	2020-01-22	12	[{"id_menu":1,"count":1}]	10030	delivery	5	17
25671	2020-01-22 13:26:26	2020-01-22	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1243	pick-up	0	17
25672	2020-01-22 14:00:06	2020-01-22	9	[{"id_menu":7,"count":1}]	10057	delivery	5	14
25673	2020-01-22 14:01:14	2020-01-22	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	6121	pick-up	0	33
25674	2020-01-22 14:06:00	2020-01-22	17	[{"id_menu":4,"count":1}]	9833	delivery	5	22
25675	2020-01-22 14:11:37	2020-01-22	8	[{"id_menu":5,"count":2}]	3681	delivery	5	13
25676	2020-01-22 14:16:24	2020-01-22	12	[{"id_menu":3,"count":1}]	10063	delivery	5	17
25677	2020-01-22 14:42:05	2020-01-22	9	[{"id_menu":7,"count":2}]	10074	delivery	5	14
25678	2020-01-22 14:42:33	2020-01-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10103	delivery	5	22
25679	2020-01-22 14:42:37	2020-01-22	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4748	delivery	5	35
25680	2020-01-22 14:42:59	2020-01-22	14	[{"id_menu":2,"count":1}]	10045	delivery	5	19
25681	2020-01-22 14:49:06	2020-01-22	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	10060	delivery	5	27
25682	2020-01-22 14:54:08	2020-01-22	9	[{"id_menu":7,"count":1}]	4960	pick-up	0	9
25683	2020-01-22 14:58:42	2020-01-22	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	10093	delivery	5	26
25684	2020-01-22 15:02:34	2020-01-22	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10090	delivery	5	30
25685	2020-01-22 15:07:53	2020-01-22	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	6987	pick-up	0	26
25686	2020-01-22 15:11:57	2020-01-22	8	[{"id_menu":5,"count":1}]	3370	pick-up	0	8
25687	2020-01-22 15:12:25	2020-01-22	17	[{"id_menu":4,"count":1}]	456	delivery	5	22
25688	2020-01-22 15:14:17	2020-01-22	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	10095	delivery	5	42
25689	2020-01-22 15:22:07	2020-01-22	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	10075	delivery	5	31
25690	2020-01-22 15:27:41	2020-01-22	14	[{"id_menu":2,"count":1}]	62	delivery	5	19
25691	2020-01-22 15:28:05	2020-01-22	17	[{"id_menu":4,"count":1}]	6402	delivery	5	22
25692	2020-01-22 15:34:50	2020-01-22	12	[{"id_menu":3,"count":1}]	10043	delivery	5	17
25693	2020-01-22 15:54:04	2020-01-22	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	7261	delivery	5	28
25694	2020-01-22 15:55:51	2020-01-22	17	[{"id_menu":4,"count":1}]	1781	pick-up	0	17
25695	2020-01-22 15:56:00	2020-01-22	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10034	delivery	5	34
25696	2020-01-22 16:05:42	2020-01-22	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3491	delivery	5	31
25697	2020-01-22 16:06:25	2020-01-22	17	[{"id_menu":4,"count":2}]	2776	pick-up	0	17
25698	2020-01-22 16:06:34	2020-01-22	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	6871	delivery	5	26
25699	2020-01-22 16:08:07	2020-01-22	8	[{"id_menu":5,"count":1}]	10082	delivery	5	13
25700	2020-01-22 16:17:54	2020-01-22	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	9587	delivery	5	43
25701	2020-01-22 16:23:52	2020-01-22	14	[{"id_menu":2,"count":1}]	3257	delivery	5	19
25702	2020-01-22 16:45:10	2020-01-22	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	10046	delivery	5	25
25703	2020-01-22 17:00:05	2020-01-22	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1720	delivery	5	27
25704	2020-01-22 17:02:30	2020-01-22	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10077	delivery	5	30
25705	2020-01-22 17:13:35	2020-01-22	14	[{"id_menu":2,"count":1}]	730	pick-up	0	14
25706	2020-01-22 17:13:41	2020-01-22	14	[{"id_menu":2,"count":1}]	9941	delivery	5	19
25707	2020-01-22 17:23:58	2020-01-22	9	[{"id_menu":6,"count":1}]	8698	delivery	5	14
25708	2020-01-22 17:31:12	2020-01-22	14	[{"id_menu":2,"count":1}]	4996	delivery	5	19
25709	2020-01-22 17:40:08	2020-01-22	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1795	pick-up	0	29
25710	2020-01-22 17:45:53	2020-01-22	9	[{"id_menu":6,"count":1}]	7931	pick-up	0	9
25711	2020-01-22 17:53:21	2020-01-22	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	10070	delivery	5	27
25712	2020-01-22 17:55:06	2020-01-22	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10099	delivery	5	42
25713	2020-01-22 18:00:13	2020-01-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6398	delivery	5	28
25714	2020-01-22 18:22:33	2020-01-22	17	[{"id_menu":4,"count":1}]	10039	pick-up	0	17
25715	2020-01-22 18:30:48	2020-01-22	17	[{"id_menu":4,"count":1}]	332	delivery	5	22
25716	2020-01-22 18:32:31	2020-01-22	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	4028	pick-up	0	38
25717	2020-01-22 18:45:13	2020-01-22	9	[{"id_menu":6,"count":1}]	10028	pick-up	0	9
25718	2020-01-22 18:52:36	2020-01-22	14	[{"id_menu":2,"count":1}]	1559	pick-up	0	14
25719	2020-01-22 18:54:43	2020-01-22	9	[{"id_menu":6,"count":1}]	10080	delivery	5	14
25720	2020-01-22 18:58:34	2020-01-22	12	[{"id_menu":3,"count":1}]	8448	pick-up	0	12
25721	2020-01-22 19:20:06	2020-01-22	17	[{"id_menu":4,"count":1}]	1174	pick-up	0	17
25722	2020-01-22 19:21:09	2020-01-22	14	[{"id_menu":2,"count":1}]	10055	pick-up	0	14
25723	2020-01-22 19:23:56	2020-01-22	9	[{"id_menu":7,"count":1}]	10068	delivery	5	14
25724	2020-01-22 19:28:32	2020-01-22	17	[{"id_menu":4,"count":1}]	10054	delivery	5	22
25725	2020-01-22 19:34:12	2020-01-22	12	[{"id_menu":3,"count":1}]	4060	delivery	5	17
25726	2020-01-22 19:34:41	2020-01-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10094	delivery	5	22
25727	2020-01-22 19:43:53	2020-01-22	17	[{"id_menu":4,"count":1}]	8656	pick-up	0	17
25728	2020-01-22 19:49:00	2020-01-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1445	pick-up	0	18
25729	2020-01-22 19:49:59	2020-01-22	9	[{"id_menu":7,"count":1}]	8755	pick-up	0	9
25730	2020-01-22 19:57:08	2020-01-22	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	9272	delivery	5	25
25731	2020-01-22 20:01:36	2020-01-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	5812	pick-up	0	23
25732	2020-01-22 20:01:56	2020-01-22	12	[{"id_menu":3,"count":1}]	9958	delivery	5	17
25733	2020-01-22 20:04:16	2020-01-22	9	[{"id_menu":7,"count":1}]	6023	delivery	5	14
25734	2020-01-22 20:25:55	2020-01-22	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	5691	delivery	5	39
25735	2020-01-22 20:27:11	2020-01-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9733	delivery	5	28
25736	2020-01-22 20:40:28	2020-01-22	12	[{"id_menu":1,"count":2}]	9379	delivery	5	17
25737	2020-01-22 20:49:44	2020-01-22	17	[{"id_menu":4,"count":1}]	623	pick-up	0	17
25738	2020-01-22 21:03:10	2020-01-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10066	delivery	5	23
25739	2020-01-22 21:05:51	2020-01-22	9	[{"id_menu":6,"count":1}]	10084	delivery	5	14
25740	2020-01-22 21:10:37	2020-01-22	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	33	pick-up	0	32
25741	2020-01-22 22:05:49	2020-01-22	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4321	delivery	5	37
25742	2020-01-22 22:07:13	2020-01-22	17	[{"id_menu":4,"count":1}]	3388	delivery	5	22
25743	2020-01-22 22:09:17	2020-01-22	17	[{"id_menu":4,"count":1}]	1075	pick-up	0	17
25744	2020-01-22 22:10:24	2020-01-22	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	10061	delivery	5	48
25745	2020-01-22 22:34:13	2020-01-22	9	[{"id_menu":6,"count":1}]	6807	delivery	5	14
25746	2020-01-22 22:41:04	2020-01-22	8	[{"id_menu":5,"count":1}]	7086	delivery	5	13
25747	2020-01-22 22:44:18	2020-01-22	9	[{"id_menu":6,"count":1}]	10102	delivery	5	14
25748	2020-01-22 22:56:45	2020-01-22	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	10092	delivery	5	23
25749	2020-01-22 23:04:31	2020-01-22	14	[{"id_menu":2,"count":1}]	4520	delivery	5	19
25750	2020-01-22 23:11:28	2020-01-22	9	[{"id_menu":6,"count":1}]	6200	delivery	5	14
25751	2020-01-22 23:40:21	2020-01-22	9	[{"id_menu":6,"count":1}]	10035	pick-up	0	9
25752	2020-01-22 23:40:42	2020-01-22	9	[{"id_menu":6,"count":1}]	1760	pick-up	0	9
25753	2020-01-22 23:46:23	2020-01-22	8	[{"id_menu":5,"count":1}]	5310	pick-up	0	8
25754	2020-01-22 23:47:35	2020-01-22	17	[{"id_menu":4,"count":1}]	10100	delivery	5	22
25755	2020-01-22 23:50:16	2020-01-22	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	10053	delivery	5	25
25756	2020-01-22 23:56:14	2020-01-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7297	pick-up	0	23
25757	2020-01-23 00:13:35	2020-01-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	626	delivery	5	26
25758	2020-01-23 00:31:38	2020-01-23	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	10167	delivery	5	35
25759	2020-01-23 00:36:46	2020-01-23	14	[{"id_menu":2,"count":1}]	62	delivery	5	19
25760	2020-01-23 00:38:14	2020-01-23	9	[{"id_menu":6,"count":1}]	5886	delivery	5	14
25761	2020-01-23 00:49:06	2020-01-23	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	10179	delivery	5	31
25762	2020-01-23 01:04:42	2020-01-23	9	[{"id_menu":7,"count":1}]	8887	pick-up	0	9
25763	2020-01-23 01:19:39	2020-01-23	14	[{"id_menu":2,"count":1}]	7159	pick-up	0	14
25764	2020-01-23 01:26:03	2020-01-23	17	[{"id_menu":4,"count":1}]	6428	pick-up	0	17
25765	2020-01-23 01:28:01	2020-01-23	12	[{"id_menu":1,"count":1}]	41	pick-up	0	12
25766	2020-01-23 01:28:18	2020-01-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	10133	delivery	5	26
25767	2020-01-23 01:31:25	2020-01-23	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4595	pick-up	0	17
25768	2020-01-23 01:37:51	2020-01-23	14	[{"id_menu":2,"count":1}]	2615	pick-up	0	14
25769	2020-01-23 02:02:23	2020-01-23	14	[{"id_menu":2,"count":1}]	10158	delivery	5	19
25770	2020-01-23 02:22:43	2020-01-23	9	[{"id_menu":6,"count":1}]	6666	pick-up	0	9
25771	2020-01-23 02:31:36	2020-01-23	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	10171	pick-up	0	31
25772	2020-01-23 02:40:43	2020-01-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3831	delivery	5	22
25773	2020-01-23 03:00:10	2020-01-23	8	[{"id_menu":5,"count":1}]	7171	delivery	5	13
25774	2020-01-23 03:02:28	2020-01-23	12	[{"id_menu":3,"count":1}]	1973	pick-up	0	12
25775	2020-01-23 03:03:11	2020-01-23	9	[{"id_menu":6,"count":1}]	10141	delivery	5	14
25776	2020-01-23 03:10:46	2020-01-23	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":2}]	1923	delivery	5	26
25777	2020-01-23 03:10:52	2020-01-23	8	[{"id_menu":5,"count":1}]	10124	delivery	5	13
25778	2020-01-23 03:22:04	2020-01-23	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	10147	pick-up	0	21
25779	2020-01-23 03:29:49	2020-01-23	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4344	delivery	5	40
25780	2020-01-23 03:43:41	2020-01-23	14	[{"id_menu":2,"count":1}]	10162	delivery	5	19
25781	2020-01-23 03:53:08	2020-01-23	9	[{"id_menu":6,"count":1}]	4274	delivery	5	14
25782	2020-01-23 04:12:44	2020-01-23	8	[{"id_menu":5,"count":1}]	8813	delivery	5	13
25783	2020-01-23 04:15:23	2020-01-23	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	431	pick-up	0	29
25784	2020-01-23 04:16:18	2020-01-23	17	[{"id_menu":4,"count":1}]	6410	pick-up	0	17
25785	2020-01-23 04:20:29	2020-01-23	9	[{"id_menu":7,"count":1}]	10154	delivery	5	14
25786	2020-01-23 04:44:41	2020-01-23	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	6881	delivery	5	39
25787	2020-01-23 04:49:06	2020-01-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2712	delivery	5	31
25788	2020-01-23 04:55:45	2020-01-23	17	[{"id_menu":4,"count":1}]	1929	delivery	5	22
25789	2020-01-23 04:59:31	2020-01-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7061	pick-up	0	17
25790	2020-01-23 05:04:06	2020-01-23	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2729	delivery	5	34
25791	2020-01-23 05:04:18	2020-01-23	34	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4519	delivery	5	39
25792	2020-01-23 05:10:01	2020-01-23	14	[{"id_menu":2,"count":1}]	9300	pick-up	0	14
25793	2020-01-23 05:15:51	2020-01-23	9	[{"id_menu":6,"count":1}]	879	pick-up	0	9
25794	2020-01-23 05:21:09	2020-01-23	9	[{"id_menu":6,"count":1}]	7161	delivery	5	14
25795	2020-01-23 05:25:59	2020-01-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4592	delivery	5	31
25796	2020-01-23 05:56:16	2020-01-23	14	[{"id_menu":2,"count":1}]	3647	pick-up	0	14
25797	2020-01-23 06:05:57	2020-01-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	9358	pick-up	0	21
25798	2020-01-23 06:16:08	2020-01-23	12	[{"id_menu":1,"count":1}]	10033	delivery	5	17
25799	2020-01-23 06:21:30	2020-01-23	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	8261	delivery	5	27
25800	2020-01-23 06:24:34	2020-01-23	12	[{"id_menu":3,"count":1}]	8185	pick-up	0	12
25801	2020-01-23 06:35:00	2020-01-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10135	delivery	5	23
25802	2020-01-23 06:45:31	2020-01-23	12	[{"id_menu":1,"count":1}]	5050	pick-up	0	12
25803	2020-01-23 07:02:55	2020-01-23	14	[{"id_menu":2,"count":1}]	10151	pick-up	0	14
25804	2020-01-23 07:04:34	2020-01-23	17	[{"id_menu":4,"count":1}]	10120	delivery	5	22
25805	2020-01-23 07:05:06	2020-01-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	10178	delivery	5	26
25806	2020-01-23 07:11:17	2020-01-23	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10148	delivery	5	37
25807	2020-01-23 07:19:51	2020-01-23	9	[{"id_menu":6,"count":1}]	7591	pick-up	0	9
25808	2020-01-23 07:20:21	2020-01-23	17	[{"id_menu":4,"count":1}]	8610	delivery	5	22
25809	2020-01-23 07:21:36	2020-01-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	2634	pick-up	0	21
25810	2020-01-23 07:21:49	2020-01-23	12	[{"id_menu":1,"count":1}]	340	pick-up	0	12
25811	2020-01-23 07:24:01	2020-01-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	10159	delivery	5	36
25812	2020-01-23 07:28:29	2020-01-23	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	10122	delivery	5	26
25813	2020-01-23 07:46:34	2020-01-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	10142	pick-up	0	21
25814	2020-01-23 07:49:29	2020-01-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	5470	delivery	5	28
25815	2020-01-23 08:05:33	2020-01-23	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	481	pick-up	0	26
25816	2020-01-23 08:09:05	2020-01-23	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	883	pick-up	0	17
25817	2020-01-23 08:18:21	2020-01-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	7806	pick-up	0	21
25818	2020-01-23 08:28:21	2020-01-23	12	[{"id_menu":3,"count":1}]	8372	delivery	5	17
25819	2020-01-23 08:31:40	2020-01-23	12	[{"id_menu":3,"count":1}]	10125	delivery	5	17
25820	2020-01-23 08:32:32	2020-01-23	12	[{"id_menu":3,"count":1}]	365	delivery	5	17
25821	2020-01-23 08:33:06	2020-01-23	12	[{"id_menu":1,"count":1}]	4294	delivery	5	17
25822	2020-01-23 08:34:59	2020-01-23	17	[{"id_menu":4,"count":1}]	7041	delivery	5	22
25823	2020-01-23 08:43:26	2020-01-23	12	[{"id_menu":1,"count":2}]	2068	pick-up	0	12
25824	2020-01-23 08:59:04	2020-01-23	8	[{"id_menu":5,"count":1}]	6825	delivery	5	13
25825	2020-01-23 09:01:32	2020-01-23	17	[{"id_menu":4,"count":1}]	10173	delivery	5	22
25826	2020-01-23 09:02:29	2020-01-23	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10131	delivery	5	22
25827	2020-01-23 09:06:56	2020-01-23	9	[{"id_menu":7,"count":1}]	3169	delivery	5	14
25828	2020-01-23 09:36:04	2020-01-23	8	[{"id_menu":5,"count":1}]	10153	pick-up	0	8
25829	2020-01-23 09:45:16	2020-01-23	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9894	delivery	5	53
25830	2020-01-23 09:47:04	2020-01-23	8	[{"id_menu":5,"count":1}]	7058	pick-up	0	8
25831	2020-01-23 09:47:40	2020-01-23	17	[{"id_menu":4,"count":1}]	3148	delivery	5	22
25832	2020-01-23 09:57:11	2020-01-23	9	[{"id_menu":7,"count":1}]	4935	delivery	5	14
25833	2020-01-23 10:08:09	2020-01-23	8	[{"id_menu":5,"count":1}]	2447	pick-up	0	8
25834	2020-01-23 10:10:06	2020-01-23	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4336	pick-up	0	34
25835	2020-01-23 10:16:20	2020-01-23	8	[{"id_menu":5,"count":1}]	9102	delivery	5	13
25836	2020-01-23 10:20:21	2020-01-23	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1257	pick-up	0	29
25837	2020-01-23 10:21:26	2020-01-23	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1522	delivery	5	25
25838	2020-01-23 10:24:22	2020-01-23	12	[{"id_menu":3,"count":1}]	1928	pick-up	0	12
25839	2020-01-23 10:25:08	2020-01-23	9	[{"id_menu":6,"count":1}]	7870	delivery	5	14
25840	2020-01-23 10:27:20	2020-01-23	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10152	pick-up	0	26
25841	2020-01-23 10:33:39	2020-01-23	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	10126	delivery	5	25
25842	2020-01-23 10:34:58	2020-01-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5082	delivery	5	28
25843	2020-01-23 10:40:45	2020-01-23	17	[{"id_menu":4,"count":1}]	2915	delivery	5	22
25844	2020-01-23 10:51:45	2020-01-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	1076	delivery	5	26
25845	2020-01-23 10:53:22	2020-01-23	12	[{"id_menu":1,"count":1}]	2604	delivery	5	17
25846	2020-01-23 10:54:05	2020-01-23	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4230	delivery	5	48
25847	2020-01-23 10:55:41	2020-01-23	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	8666	pick-up	0	23
25848	2020-01-23 10:57:57	2020-01-23	12	[{"id_menu":1,"count":1}]	2277	pick-up	0	12
25849	2020-01-23 11:03:11	2020-01-23	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10084	delivery	5	57
25850	2020-01-23 11:08:28	2020-01-23	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	10170	delivery	5	23
25851	2020-01-23 11:10:13	2020-01-23	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	148	pick-up	0	24
25852	2020-01-23 11:13:16	2020-01-23	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10114	delivery	5	31
25853	2020-01-23 11:13:29	2020-01-23	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	6641	pick-up	0	29
25854	2020-01-23 11:14:20	2020-01-23	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9825	delivery	5	43
25855	2020-01-23 11:16:42	2020-01-23	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	6200	delivery	5	31
25856	2020-01-23 11:26:15	2020-01-23	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	10165	delivery	5	40
25857	2020-01-23 11:27:43	2020-01-23	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	10134	delivery	5	40
25858	2020-01-23 11:34:28	2020-01-23	9	[{"id_menu":6,"count":1}]	6787	delivery	5	14
25859	2020-01-23 11:38:56	2020-01-23	17	[{"id_menu":4,"count":1}]	3000	pick-up	0	17
25860	2020-01-23 11:41:22	2020-01-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9695	delivery	5	23
25861	2020-01-23 11:52:18	2020-01-23	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	6732	delivery	5	27
25862	2020-01-23 12:00:07	2020-01-23	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1177	pick-up	0	29
25863	2020-01-23 12:01:18	2020-01-23	9	[{"id_menu":7,"count":1}]	9781	delivery	5	14
25864	2020-01-23 12:03:07	2020-01-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	5468	delivery	5	26
25865	2020-01-23 12:03:59	2020-01-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7589	delivery	5	23
25866	2020-01-23 12:23:48	2020-01-23	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5865	delivery	5	47
25867	2020-01-23 12:24:26	2020-01-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3800	delivery	5	28
25868	2020-01-23 12:42:19	2020-01-23	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	8596	delivery	5	31
25869	2020-01-23 12:43:18	2020-01-23	12	[{"id_menu":3,"count":1}]	10113	delivery	5	17
25870	2020-01-23 12:46:09	2020-01-23	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10111	delivery	5	36
25871	2020-01-23 12:52:31	2020-01-23	8	[{"id_menu":5,"count":1}]	10181	delivery	5	13
25872	2020-01-23 12:56:49	2020-01-23	9	[{"id_menu":6,"count":1}]	10149	delivery	5	14
25873	2020-01-23 13:18:30	2020-01-23	9	[{"id_menu":7,"count":1}]	6773	delivery	5	14
25874	2020-01-23 13:25:20	2020-01-23	9	[{"id_menu":7,"count":1}]	10105	delivery	5	14
25875	2020-01-23 13:28:32	2020-01-23	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	2888	delivery	5	39
25876	2020-01-23 13:43:13	2020-01-23	8	[{"id_menu":5,"count":1}]	10155	pick-up	0	8
25877	2020-01-23 13:47:50	2020-01-23	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	9106	pick-up	0	20
25878	2020-01-23 13:49:55	2020-01-23	14	[{"id_menu":2,"count":1}]	9629	pick-up	0	14
25879	2020-01-23 13:50:09	2020-01-23	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	10116	delivery	5	36
25880	2020-01-23 13:58:33	2020-01-23	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	593	pick-up	0	26
25881	2020-01-23 14:09:15	2020-01-23	14	[{"id_menu":2,"count":1}]	9044	delivery	5	19
25882	2020-01-23 14:09:57	2020-01-23	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	10140	pick-up	0	20
25883	2020-01-23 14:10:47	2020-01-23	9	[{"id_menu":7,"count":1}]	1460	pick-up	0	9
25884	2020-01-23 14:14:28	2020-01-23	14	[{"id_menu":2,"count":1}]	6613	delivery	5	19
25885	2020-01-23 14:17:18	2020-01-23	14	[{"id_menu":2,"count":2}]	2599	pick-up	0	14
25886	2020-01-23 14:21:24	2020-01-23	8	[{"id_menu":5,"count":1}]	920	pick-up	0	8
25887	2020-01-23 14:22:18	2020-01-23	14	[{"id_menu":2,"count":1}]	2024	pick-up	0	14
25888	2020-01-23 14:25:45	2020-01-23	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3679	delivery	5	31
25889	2020-01-23 14:34:03	2020-01-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6962	pick-up	0	26
25890	2020-01-23 14:38:26	2020-01-23	12	[{"id_menu":1,"count":1}]	2313	pick-up	0	12
25891	2020-01-23 14:56:47	2020-01-23	14	[{"id_menu":2,"count":1}]	1736	pick-up	0	14
25892	2020-01-23 14:58:24	2020-01-23	17	[{"id_menu":4,"count":1}]	2245	pick-up	0	17
25893	2020-01-23 15:06:57	2020-01-23	9	[{"id_menu":6,"count":1}]	6622	pick-up	0	9
25894	2020-01-23 15:07:10	2020-01-23	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1796	pick-up	0	29
25895	2020-01-23 15:12:34	2020-01-23	9	[{"id_menu":6,"count":1}]	10128	delivery	5	14
25896	2020-01-23 15:17:29	2020-01-23	17	[{"id_menu":4,"count":1}]	2173	delivery	5	22
25897	2020-01-23 15:21:37	2020-01-23	9	[{"id_menu":7,"count":1}]	6131	delivery	5	14
25898	2020-01-23 15:26:00	2020-01-23	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4459	delivery	5	43
25899	2020-01-23 15:27:15	2020-01-23	17	[{"id_menu":4,"count":1}]	8694	delivery	5	22
25900	2020-01-23 15:31:48	2020-01-23	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	10160	delivery	5	26
25901	2020-01-23 15:33:52	2020-01-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	414	pick-up	0	18
25902	2020-01-23 15:34:52	2020-01-23	14	[{"id_menu":2,"count":1}]	8323	pick-up	0	14
25903	2020-01-23 15:42:28	2020-01-23	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	5768	delivery	5	30
25904	2020-01-23 15:42:53	2020-01-23	12	[{"id_menu":1,"count":1}]	10168	pick-up	0	12
25905	2020-01-23 15:46:59	2020-01-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3480	pick-up	0	23
25906	2020-01-23 15:52:42	2020-01-23	14	[{"id_menu":2,"count":1}]	10161	delivery	5	19
25907	2020-01-23 15:53:03	2020-01-23	8	[{"id_menu":5,"count":1}]	109	pick-up	0	8
25908	2020-01-23 16:01:03	2020-01-23	17	[{"id_menu":4,"count":1}]	1555	pick-up	0	17
25909	2020-01-23 16:02:20	2020-01-23	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4101	delivery	5	26
25910	2020-01-23 16:02:40	2020-01-23	14	[{"id_menu":2,"count":1}]	8939	pick-up	0	14
25911	2020-01-23 16:13:14	2020-01-23	9	[{"id_menu":7,"count":1}]	5215	delivery	5	14
25912	2020-01-23 16:18:16	2020-01-23	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1834	pick-up	0	21
25913	2020-01-23 16:47:34	2020-01-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3172	delivery	5	22
25914	2020-01-23 16:54:09	2020-01-23	9	[{"id_menu":7,"count":1}]	10144	delivery	5	14
25915	2020-01-23 17:07:39	2020-01-23	12	[{"id_menu":3,"count":1}]	2291	pick-up	0	12
25916	2020-01-23 17:08:31	2020-01-23	8	[{"id_menu":5,"count":1}]	10127	delivery	5	13
25917	2020-01-23 17:12:34	2020-01-23	8	[{"id_menu":5,"count":1}]	8414	delivery	5	13
25918	2020-01-23 17:28:45	2020-01-23	8	[{"id_menu":5,"count":2}]	3889	delivery	5	13
25919	2020-01-23 17:29:33	2020-01-23	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	7690	pick-up	0	20
25920	2020-01-23 17:39:56	2020-01-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	10177	pick-up	0	21
25921	2020-01-23 17:42:40	2020-01-23	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6556	delivery	5	44
25922	2020-01-23 17:45:59	2020-01-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	10157	delivery	5	28
25923	2020-01-23 17:49:19	2020-01-23	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	638	delivery	5	30
25924	2020-01-23 17:50:27	2020-01-23	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	9265	delivery	5	40
25925	2020-01-23 17:51:29	2020-01-23	8	[{"id_menu":5,"count":1}]	6609	delivery	5	13
25926	2020-01-23 17:51:35	2020-01-23	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6090	delivery	5	34
25927	2020-01-23 17:55:47	2020-01-23	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	3078	delivery	5	43
25928	2020-01-23 17:58:03	2020-01-23	12	[{"id_menu":3,"count":1}]	10106	pick-up	0	12
25929	2020-01-23 18:03:10	2020-01-23	14	[{"id_menu":2,"count":1}]	10174	pick-up	0	14
25930	2020-01-23 18:13:19	2020-01-23	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7620	delivery	5	37
25931	2020-01-23 18:24:43	2020-01-23	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	10117	delivery	5	31
25932	2020-01-23 18:25:39	2020-01-23	17	[{"id_menu":4,"count":1}]	5503	delivery	5	22
25933	2020-01-23 18:29:57	2020-01-23	12	[{"id_menu":1,"count":1}]	2252	pick-up	0	12
25934	2020-01-23 18:30:25	2020-01-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	10119	pick-up	0	21
25935	2020-01-23 18:42:21	2020-01-23	9	[{"id_menu":6,"count":1}]	4193	pick-up	0	9
25936	2020-01-23 18:51:14	2020-01-23	17	[{"id_menu":4,"count":1}]	1263	pick-up	0	17
25937	2020-01-23 19:05:41	2020-01-23	12	[{"id_menu":1,"count":1}]	1968	pick-up	0	12
25938	2020-01-23 19:16:05	2020-01-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10137	delivery	5	23
25939	2020-01-23 19:16:48	2020-01-23	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1777	pick-up	0	17
25940	2020-01-23 19:23:53	2020-01-23	9	[{"id_menu":6,"count":1}]	10169	delivery	5	14
25941	2020-01-23 19:36:32	2020-01-23	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	10139	delivery	5	25
25942	2020-01-23 19:37:58	2020-01-23	14	[{"id_menu":2,"count":1}]	10110	pick-up	0	14
25943	2020-01-23 19:55:01	2020-01-23	9	[{"id_menu":6,"count":1}]	10164	delivery	5	14
25944	2020-01-23 20:04:10	2020-01-23	9	[{"id_menu":6,"count":1}]	2635	delivery	5	14
25945	2020-01-23 20:18:32	2020-01-23	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	3600	pick-up	0	20
25946	2020-01-23 20:24:33	2020-01-23	12	[{"id_menu":3,"count":1}]	10143	delivery	5	17
25947	2020-01-23 20:27:52	2020-01-23	17	[{"id_menu":4,"count":1}]	9688	pick-up	0	17
25948	2020-01-23 20:34:13	2020-01-23	9	[{"id_menu":6,"count":1}]	552	delivery	5	14
25949	2020-01-23 20:34:46	2020-01-23	9	[{"id_menu":6,"count":1}]	3198	pick-up	0	9
25950	2020-01-23 20:39:40	2020-01-23	8	[{"id_menu":5,"count":1}]	7049	delivery	5	13
25951	2020-01-23 20:48:13	2020-01-23	9	[{"id_menu":7,"count":1}]	10180	delivery	5	14
25952	2020-01-23 20:51:00	2020-01-23	12	[{"id_menu":1,"count":1}]	93	pick-up	0	12
25953	2020-01-23 20:52:14	2020-01-23	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	10132	pick-up	0	24
25954	2020-01-23 21:04:41	2020-01-23	12	[{"id_menu":1,"count":1}]	10008	pick-up	0	12
25955	2020-01-23 21:05:25	2020-01-23	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10118	delivery	5	51
25956	2020-01-23 21:21:06	2020-01-23	8	[{"id_menu":5,"count":1}]	10166	delivery	5	13
25957	2020-01-23 21:22:24	2020-01-23	14	[{"id_menu":2,"count":1}]	5197	delivery	5	19
25958	2020-01-23 21:24:15	2020-01-23	17	[{"id_menu":4,"count":1}]	10129	delivery	5	22
25959	2020-01-23 22:14:39	2020-01-23	17	[{"id_menu":4,"count":1}]	8448	pick-up	0	17
25960	2020-01-23 22:41:41	2020-01-23	9	[{"id_menu":7,"count":1}]	4007	delivery	5	14
25961	2020-01-23 22:51:20	2020-01-23	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10115	pick-up	0	25
25962	2020-01-23 23:13:35	2020-01-23	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	10150	delivery	5	34
25963	2020-01-23 23:24:31	2020-01-23	14	[{"id_menu":2,"count":1}]	1821	pick-up	0	14
25964	2020-01-23 23:26:06	2020-01-23	12	[{"id_menu":1,"count":1}]	1395	delivery	5	17
25965	2020-01-23 23:30:15	2020-01-23	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	10130	delivery	5	31
25966	2020-01-23 23:35:28	2020-01-23	12	[{"id_menu":1,"count":1}]	193	pick-up	0	12
25967	2020-01-23 23:46:20	2020-01-23	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3321	delivery	5	27
25968	2020-01-23 23:47:17	2020-01-23	9	[{"id_menu":6,"count":1}]	10138	delivery	5	14
25969	2020-01-23 23:52:07	2020-01-23	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	32	pick-up	0	29
25970	2020-01-23 23:57:06	2020-01-23	8	[{"id_menu":5,"count":1}]	10172	delivery	5	13
25971	2020-01-24 00:04:07	2020-01-24	12	[{"id_menu":3,"count":1}]	2477	pick-up	0	12
25972	2020-01-24 00:06:32	2020-01-24	9	[{"id_menu":6,"count":1}]	10228	delivery	5	14
25973	2020-01-24 00:08:03	2020-01-24	9	[{"id_menu":7,"count":1}]	10222	delivery	5	14
25974	2020-01-24 00:19:01	2020-01-24	9	[{"id_menu":6,"count":1}]	996	pick-up	0	9
25975	2020-01-24 00:41:20	2020-01-24	9	[{"id_menu":6,"count":2}]	2604	pick-up	0	9
25976	2020-01-24 00:55:53	2020-01-24	17	[{"id_menu":4,"count":1}]	2911	pick-up	0	17
25977	2020-01-24 01:06:24	2020-01-24	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	10229	delivery	5	37
25978	2020-01-24 01:06:36	2020-01-24	17	[{"id_menu":4,"count":1}]	10207	delivery	5	22
25979	2020-01-24 01:36:24	2020-01-24	17	[{"id_menu":4,"count":1}]	2693	pick-up	0	17
25980	2020-01-24 01:36:39	2020-01-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	5884	delivery	5	28
25981	2020-01-24 01:50:36	2020-01-24	9	[{"id_menu":6,"count":1}]	7494	delivery	5	14
25982	2020-01-24 01:54:02	2020-01-24	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8185	delivery	5	31
25983	2020-01-24 02:00:07	2020-01-24	12	[{"id_menu":1,"count":1}]	9191	pick-up	0	12
25984	2020-01-24 02:17:52	2020-01-24	9	[{"id_menu":6,"count":1}]	5332	pick-up	0	9
25985	2020-01-24 02:27:39	2020-01-24	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	852	delivery	5	22
25986	2020-01-24 02:35:34	2020-01-24	8	[{"id_menu":5,"count":1}]	2217	delivery	5	13
25987	2020-01-24 02:41:07	2020-01-24	14	[{"id_menu":2,"count":1}]	7205	pick-up	0	14
25988	2020-01-24 03:08:03	2020-01-24	12	[{"id_menu":1,"count":1}]	10265	delivery	5	17
25989	2020-01-24 03:35:57	2020-01-24	9	[{"id_menu":7,"count":1}]	10187	pick-up	0	9
25990	2020-01-24 03:40:50	2020-01-24	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	5460	pick-up	0	20
25991	2020-01-24 03:42:35	2020-01-24	12	[{"id_menu":3,"count":1}]	2358	pick-up	0	12
25992	2020-01-24 03:55:12	2020-01-24	14	[{"id_menu":2,"count":1}]	7179	pick-up	0	14
25993	2020-01-24 04:04:39	2020-01-24	12	[{"id_menu":3,"count":1}]	10211	delivery	5	17
25994	2020-01-24 04:05:48	2020-01-24	8	[{"id_menu":5,"count":1}]	10277	delivery	5	13
25995	2020-01-24 04:09:07	2020-01-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9167	delivery	5	23
25996	2020-01-24 04:12:17	2020-01-24	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	5961	pick-up	0	21
25997	2020-01-24 04:20:34	2020-01-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6074	pick-up	0	23
25998	2020-01-24 04:27:39	2020-01-24	14	[{"id_menu":2,"count":1}]	10262	delivery	5	19
25999	2020-01-24 04:38:22	2020-01-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	10210	delivery	5	28
26000	2020-01-24 04:38:51	2020-01-24	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	6816	delivery	5	31
26001	2020-01-24 04:40:18	2020-01-24	8	[{"id_menu":5,"count":1}]	7313	delivery	5	13
26002	2020-01-24 04:43:25	2020-01-24	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	10280	delivery	5	40
26003	2020-01-24 04:48:32	2020-01-24	12	[{"id_menu":1,"count":2}]	7543	delivery	5	17
26004	2020-01-24 04:49:45	2020-01-24	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	7784	delivery	5	34
26005	2020-01-24 04:51:27	2020-01-24	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	10242	delivery	5	39
26006	2020-01-24 04:53:31	2020-01-24	9	[{"id_menu":7,"count":1}]	10250	delivery	5	14
26007	2020-01-24 04:57:48	2020-01-24	9	[{"id_menu":6,"count":1}]	2928	pick-up	0	9
26008	2020-01-24 05:00:42	2020-01-24	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5164	pick-up	0	30
26009	2020-01-24 05:01:52	2020-01-24	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	2055	pick-up	0	17
26010	2020-01-24 05:04:48	2020-01-24	9	[{"id_menu":6,"count":1}]	10239	delivery	5	14
26011	2020-01-24 05:07:41	2020-01-24	8	[{"id_menu":5,"count":1}]	4976	pick-up	0	8
26012	2020-01-24 05:11:09	2020-01-24	9	[{"id_menu":7,"count":1}]	7835	delivery	5	14
26013	2020-01-24 05:18:19	2020-01-24	17	[{"id_menu":4,"count":1}]	3604	pick-up	0	17
26014	2020-01-24 05:39:25	2020-01-24	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	456	delivery	5	31
26015	2020-01-24 05:43:58	2020-01-24	8	[{"id_menu":5,"count":1}]	6385	pick-up	0	8
26016	2020-01-24 05:50:19	2020-01-24	17	[{"id_menu":4,"count":1}]	10238	delivery	5	22
26017	2020-01-24 05:52:41	2020-01-24	9	[{"id_menu":7,"count":1}]	9024	delivery	5	14
26018	2020-01-24 06:08:02	2020-01-24	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	9404	pick-up	0	31
26019	2020-01-24 06:12:56	2020-01-24	9	[{"id_menu":6,"count":1}]	7510	delivery	5	14
26020	2020-01-24 06:13:22	2020-01-24	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	8311	delivery	5	25
26021	2020-01-24 06:14:37	2020-01-24	9	[{"id_menu":6,"count":1}]	10218	delivery	5	14
26022	2020-01-24 06:20:04	2020-01-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10226	delivery	5	23
26023	2020-01-24 06:25:31	2020-01-24	9	[{"id_menu":6,"count":1}]	8372	pick-up	0	9
26024	2020-01-24 07:04:35	2020-01-24	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	10169	delivery	5	40
26025	2020-01-24 07:44:25	2020-01-24	8	[{"id_menu":5,"count":1}]	10269	delivery	5	13
26026	2020-01-24 07:50:21	2020-01-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10268	delivery	5	23
26027	2020-01-24 07:50:58	2020-01-24	8	[{"id_menu":5,"count":1}]	2033	pick-up	0	8
26028	2020-01-24 08:00:24	2020-01-24	14	[{"id_menu":2,"count":1}]	371	delivery	5	19
26029	2020-01-24 08:01:29	2020-01-24	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	471	delivery	5	43
26030	2020-01-24 08:01:41	2020-01-24	14	[{"id_menu":2,"count":1}]	6007	delivery	5	19
26031	2020-01-24 08:09:27	2020-01-24	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	10272	delivery	5	36
26032	2020-01-24 08:18:08	2020-01-24	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	10267	delivery	5	36
26033	2020-01-24 08:20:33	2020-01-24	12	[{"id_menu":1,"count":1}]	1714	pick-up	0	12
26034	2020-01-24 08:21:06	2020-01-24	9	[{"id_menu":6,"count":1}]	48	pick-up	0	9
26035	2020-01-24 08:21:56	2020-01-24	14	[{"id_menu":2,"count":1}]	3931	delivery	5	19
26036	2020-01-24 08:28:23	2020-01-24	17	[{"id_menu":4,"count":1}]	9358	pick-up	0	17
26037	2020-01-24 08:28:37	2020-01-24	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	10197	delivery	5	34
26038	2020-01-24 08:29:10	2020-01-24	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	10249	delivery	5	38
26039	2020-01-24 08:33:09	2020-01-24	14	[{"id_menu":2,"count":1}]	2425	delivery	5	19
26040	2020-01-24 08:37:34	2020-01-24	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	2332	delivery	5	34
26041	2020-01-24 08:38:02	2020-01-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	187	pick-up	0	23
26042	2020-01-24 08:40:17	2020-01-24	14	[{"id_menu":2,"count":1}]	6733	delivery	5	19
26043	2020-01-24 08:40:38	2020-01-24	9	[{"id_menu":6,"count":1}]	6873	delivery	5	14
26044	2020-01-24 08:47:56	2020-01-24	9	[{"id_menu":6,"count":1}]	8408	delivery	5	14
26045	2020-01-24 08:49:33	2020-01-24	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1419	delivery	5	36
26046	2020-01-24 08:49:49	2020-01-24	9	[{"id_menu":6,"count":1}]	8770	delivery	5	14
26047	2020-01-24 08:55:48	2020-01-24	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	970	pick-up	0	21
26048	2020-01-24 09:01:42	2020-01-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	10257	delivery	5	28
26049	2020-01-24 09:07:12	2020-01-24	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1166	delivery	5	31
26050	2020-01-24 09:11:14	2020-01-24	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6347	delivery	5	40
26051	2020-01-24 09:28:27	2020-01-24	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	3002	pick-up	0	26
26052	2020-01-24 09:34:17	2020-01-24	9	[{"id_menu":7,"count":1}]	10255	delivery	5	14
26053	2020-01-24 09:38:13	2020-01-24	8	[{"id_menu":5,"count":1}]	3534	delivery	5	13
26054	2020-01-24 09:48:00	2020-01-24	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5793	delivery	5	39
26055	2020-01-24 09:52:25	2020-01-24	12	[{"id_menu":1,"count":1}]	10205	delivery	5	17
26056	2020-01-24 10:08:57	2020-01-24	14	[{"id_menu":2,"count":1}]	5970	delivery	5	19
26057	2020-01-24 10:15:02	2020-01-24	17	[{"id_menu":4,"count":1}]	10234	delivery	5	22
26058	2020-01-24 10:15:07	2020-01-24	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	9334	delivery	5	25
26059	2020-01-24 10:23:50	2020-01-24	9	[{"id_menu":7,"count":1}]	8669	delivery	5	14
26060	2020-01-24 10:31:06	2020-01-24	9	[{"id_menu":7,"count":1}]	10186	delivery	5	14
26061	2020-01-24 10:31:08	2020-01-24	17	[{"id_menu":4,"count":1}]	5527	delivery	5	22
26062	2020-01-24 10:39:56	2020-01-24	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	10244	delivery	5	34
26063	2020-01-24 11:02:03	2020-01-24	8	[{"id_menu":5,"count":1}]	7098	delivery	5	13
26064	2020-01-24 11:08:03	2020-01-24	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10278	delivery	5	22
26065	2020-01-24 11:25:15	2020-01-24	9	[{"id_menu":6,"count":1}]	2538	delivery	5	14
26066	2020-01-24 11:26:04	2020-01-24	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10266	delivery	5	55
26067	2020-01-24 11:27:40	2020-01-24	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	9043	delivery	5	26
26068	2020-01-24 11:30:46	2020-01-24	14	[{"id_menu":2,"count":1}]	10230	delivery	5	19
26069	2020-01-24 11:51:43	2020-01-24	9	[{"id_menu":6,"count":1}]	4433	delivery	5	14
26070	2020-01-24 11:52:56	2020-01-24	9	[{"id_menu":6,"count":1}]	7930	delivery	5	14
26071	2020-01-24 12:02:25	2020-01-24	9	[{"id_menu":7,"count":1}]	2507	delivery	5	14
26072	2020-01-24 12:19:40	2020-01-24	12	[{"id_menu":1,"count":1}]	10214	delivery	5	17
26073	2020-01-24 12:20:14	2020-01-24	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10263	delivery	5	45
26074	2020-01-24 12:21:52	2020-01-24	9	[{"id_menu":7,"count":1}]	10183	pick-up	0	9
26075	2020-01-24 12:32:44	2020-01-24	17	[{"id_menu":4,"count":1}]	1583	pick-up	0	17
26076	2020-01-24 12:33:27	2020-01-24	9	[{"id_menu":6,"count":2}]	140	pick-up	0	9
26077	2020-01-24 12:39:19	2020-01-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10264	pick-up	0	17
26078	2020-01-24 12:42:03	2020-01-24	9	[{"id_menu":6,"count":1}]	1481	pick-up	0	9
26079	2020-01-24 12:43:57	2020-01-24	12	[{"id_menu":3,"count":1}]	8380	delivery	5	17
26080	2020-01-24 12:48:39	2020-01-24	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	10198	delivery	5	27
26081	2020-01-24 12:52:00	2020-01-24	9	[{"id_menu":7,"count":1}]	63	pick-up	0	9
26082	2020-01-24 12:52:59	2020-01-24	14	[{"id_menu":2,"count":3}]	2803	delivery	5	19
26083	2020-01-24 13:01:12	2020-01-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2540	pick-up	0	23
26084	2020-01-24 13:07:38	2020-01-24	17	[{"id_menu":4,"count":1}]	10235	delivery	5	22
26085	2020-01-24 13:09:51	2020-01-24	17	[{"id_menu":4,"count":1}]	7869	delivery	5	22
26086	2020-01-24 13:34:30	2020-01-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	10251	delivery	5	28
26087	2020-01-24 13:51:14	2020-01-24	17	[{"id_menu":4,"count":1}]	10199	delivery	5	22
26088	2020-01-24 13:52:25	2020-01-24	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	8327	delivery	5	30
26089	2020-01-24 13:53:14	2020-01-24	17	[{"id_menu":4,"count":1}]	10273	pick-up	0	17
26090	2020-01-24 14:12:56	2020-01-24	17	[{"id_menu":4,"count":1}]	3300	delivery	5	22
26091	2020-01-24 14:20:34	2020-01-24	12	[{"id_menu":3,"count":1}]	7806	pick-up	0	12
26092	2020-01-24 14:22:15	2020-01-24	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	10209	pick-up	0	47
26093	2020-01-24 14:25:58	2020-01-24	9	[{"id_menu":7,"count":1}]	229	delivery	5	14
26094	2020-01-24 14:26:41	2020-01-24	9	[{"id_menu":6,"count":1}]	6796	pick-up	0	9
26095	2020-01-24 14:28:26	2020-01-24	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":2}]	10215	delivery	5	26
26096	2020-01-24 14:55:33	2020-01-24	17	[{"id_menu":4,"count":1}]	525	delivery	5	22
26097	2020-01-24 14:57:41	2020-01-24	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	10261	delivery	5	26
26098	2020-01-24 15:01:22	2020-01-24	14	[{"id_menu":2,"count":1}]	10203	pick-up	0	14
26099	2020-01-24 15:01:49	2020-01-24	14	[{"id_menu":2,"count":1}]	9603	pick-up	0	14
26100	2020-01-24 15:06:05	2020-01-24	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	10225	delivery	5	31
26101	2020-01-24 15:46:38	2020-01-24	12	[{"id_menu":1,"count":1}]	1233	delivery	5	17
26102	2020-01-24 15:47:34	2020-01-24	17	[{"id_menu":4,"count":1}]	2447	pick-up	0	17
26103	2020-01-24 16:00:25	2020-01-24	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	9989	pick-up	0	31
26104	2020-01-24 16:05:19	2020-01-24	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	10259	delivery	5	39
26105	2020-01-24 16:12:36	2020-01-24	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10233	delivery	5	30
26106	2020-01-24 16:28:38	2020-01-24	14	[{"id_menu":2,"count":1}]	10196	delivery	5	19
26107	2020-01-24 16:31:32	2020-01-24	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	10217	delivery	5	25
26108	2020-01-24 16:35:52	2020-01-24	12	[{"id_menu":1,"count":1}]	10245	delivery	5	17
26109	2020-01-24 16:49:25	2020-01-24	9	[{"id_menu":6,"count":2}]	4254	delivery	5	14
26110	2020-01-24 16:49:52	2020-01-24	9	[{"id_menu":6,"count":1}]	3293	delivery	5	14
26111	2020-01-24 16:56:18	2020-01-24	17	[{"id_menu":4,"count":1}]	10208	delivery	5	22
26112	2020-01-24 17:16:03	2020-01-24	9	[{"id_menu":7,"count":1}]	3380	delivery	5	14
26113	2020-01-24 17:27:47	2020-01-24	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	4912	delivery	5	26
26114	2020-01-24 17:29:28	2020-01-24	12	[{"id_menu":1,"count":1}]	2442	pick-up	0	12
26115	2020-01-24 17:33:02	2020-01-24	14	[{"id_menu":2,"count":1}]	10270	pick-up	0	14
26116	2020-01-24 17:48:42	2020-01-24	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3482	delivery	5	26
26117	2020-01-24 17:49:14	2020-01-24	14	[{"id_menu":2,"count":1}]	2496	pick-up	0	14
26118	2020-01-24 17:50:50	2020-01-24	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3901	delivery	5	39
26119	2020-01-24 17:52:46	2020-01-24	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	8993	delivery	5	25
26120	2020-01-24 18:01:04	2020-01-24	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4967	pick-up	0	43
26121	2020-01-24 18:03:33	2020-01-24	14	[{"id_menu":2,"count":1}]	2519	delivery	5	19
26122	2020-01-24 18:12:46	2020-01-24	9	[{"id_menu":7,"count":2}]	946	delivery	5	14
26123	2020-01-24 18:14:52	2020-01-24	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	4374	delivery	5	34
26124	2020-01-24 18:47:27	2020-01-24	17	[{"id_menu":4,"count":1}]	10204	delivery	5	22
26125	2020-01-24 18:52:02	2020-01-24	9	[{"id_menu":7,"count":1}]	4471	delivery	5	14
26126	2020-01-24 19:04:04	2020-01-24	17	[{"id_menu":4,"count":1}]	9725	delivery	5	22
26127	2020-01-24 19:19:03	2020-01-24	14	[{"id_menu":2,"count":1}]	10252	delivery	5	19
26128	2020-01-24 19:20:03	2020-01-24	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5315	delivery	5	31
26129	2020-01-24 19:22:24	2020-01-24	9	[{"id_menu":6,"count":1}]	10193	delivery	5	14
26130	2020-01-24 19:23:53	2020-01-24	17	[{"id_menu":4,"count":1}]	10200	pick-up	0	17
26131	2020-01-24 19:29:33	2020-01-24	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10271	delivery	5	22
26132	2020-01-24 19:34:34	2020-01-24	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	3588	delivery	5	23
26133	2020-01-24 19:50:08	2020-01-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8270	delivery	5	23
26134	2020-01-24 19:52:01	2020-01-24	9	[{"id_menu":6,"count":1}]	9394	pick-up	0	9
26135	2020-01-24 20:10:21	2020-01-24	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8016	delivery	5	30
26136	2020-01-24 20:18:00	2020-01-24	17	[{"id_menu":4,"count":1}]	6446	delivery	5	22
26137	2020-01-24 20:18:55	2020-01-24	12	[{"id_menu":3,"count":1}]	10206	delivery	5	17
26138	2020-01-24 20:38:12	2020-01-24	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	5933	pick-up	0	26
26139	2020-01-24 21:10:14	2020-01-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2959	pick-up	0	23
26140	2020-01-24 21:19:31	2020-01-24	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	10247	delivery	5	23
26141	2020-01-24 21:22:38	2020-01-24	17	[{"id_menu":4,"count":1}]	10279	pick-up	0	17
26142	2020-01-24 21:30:26	2020-01-24	9	[{"id_menu":6,"count":1}]	10220	delivery	5	14
26143	2020-01-24 21:54:58	2020-01-24	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1942	delivery	5	43
26144	2020-01-24 21:54:58	2020-01-24	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	8237	pick-up	0	21
26145	2020-01-24 21:58:43	2020-01-24	17	[{"id_menu":4,"count":2}]	10236	delivery	5	22
26146	2020-01-24 22:05:05	2020-01-24	9	[{"id_menu":7,"count":1}]	10194	delivery	5	14
26147	2020-01-24 22:05:29	2020-01-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10240	delivery	5	23
26148	2020-01-24 22:05:57	2020-01-24	8	[{"id_menu":5,"count":1}]	7656	delivery	5	13
26149	2020-01-24 22:07:52	2020-01-24	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	334	delivery	5	45
26150	2020-01-24 22:08:36	2020-01-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2089	pick-up	0	23
26151	2020-01-24 22:11:00	2020-01-24	14	[{"id_menu":2,"count":1}]	10241	delivery	5	19
26152	2020-01-24 22:13:06	2020-01-24	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2085	pick-up	0	31
26153	2020-01-24 22:18:03	2020-01-24	12	[{"id_menu":1,"count":1}]	10201	pick-up	0	12
26154	2020-01-24 22:19:11	2020-01-24	9	[{"id_menu":7,"count":1}]	1316	pick-up	0	9
26155	2020-01-24 22:44:10	2020-01-24	12	[{"id_menu":1,"count":1}]	751	pick-up	0	12
26156	2020-01-24 22:45:45	2020-01-24	17	[{"id_menu":4,"count":1}]	2470	pick-up	0	17
26157	2020-01-24 22:48:00	2020-01-24	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1795	pick-up	0	25
26158	2020-01-24 23:05:32	2020-01-24	14	[{"id_menu":2,"count":1}]	10253	pick-up	0	14
26159	2020-01-24 23:09:22	2020-01-24	14	[{"id_menu":2,"count":1}]	10095	delivery	5	19
26160	2020-01-24 23:15:29	2020-01-24	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5760	pick-up	0	17
26161	2020-01-24 23:23:59	2020-01-24	14	[{"id_menu":2,"count":1}]	7306	pick-up	0	14
26162	2020-01-24 23:25:08	2020-01-24	9	[{"id_menu":7,"count":1}]	10184	delivery	5	14
26163	2020-01-24 23:25:45	2020-01-24	9	[{"id_menu":7,"count":1}]	3755	delivery	5	14
26164	2020-01-24 23:28:04	2020-01-24	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	5972	pick-up	0	29
26165	2020-01-24 23:36:37	2020-01-24	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":3}]	8825	delivery	5	26
26166	2020-01-24 23:38:27	2020-01-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	10232	pick-up	0	23
26167	2020-01-24 23:39:43	2020-01-24	12	[{"id_menu":3,"count":1}]	6092	pick-up	0	12
26168	2020-01-24 23:42:02	2020-01-24	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	10190	delivery	5	34
26169	2020-01-24 23:44:31	2020-01-24	9	[{"id_menu":7,"count":1}]	552	pick-up	0	9
26170	2020-01-24 23:49:37	2020-01-24	9	[{"id_menu":6,"count":1}]	972	delivery	5	14
26171	2020-01-24 23:59:22	2020-01-24	9	[{"id_menu":7,"count":1}]	7832	delivery	5	14
26172	2020-01-25 00:09:55	2020-01-25	9	[{"id_menu":7,"count":1}]	6480	delivery	5	14
26173	2020-01-25 00:10:00	2020-01-25	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	10349	delivery	5	25
26174	2020-01-25 00:11:31	2020-01-25	14	[{"id_menu":2,"count":1}]	1515	pick-up	0	14
26175	2020-01-25 00:26:31	2020-01-25	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	10375	delivery	5	35
26176	2020-01-25 00:27:32	2020-01-25	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	10324	delivery	5	34
26177	2020-01-25 00:36:25	2020-01-25	14	[{"id_menu":2,"count":1}]	10295	delivery	5	19
26178	2020-01-25 00:38:03	2020-01-25	9	[{"id_menu":6,"count":1}]	9290	delivery	5	14
26179	2020-01-25 00:47:38	2020-01-25	12	[{"id_menu":1,"count":1}]	10304	delivery	5	17
26180	2020-01-25 00:53:28	2020-01-25	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	10288	delivery	5	26
26181	2020-01-25 00:58:42	2020-01-25	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10327	delivery	5	37
26182	2020-01-25 00:59:58	2020-01-25	12	[{"id_menu":3,"count":1}]	6870	delivery	5	17
26183	2020-01-25 01:04:27	2020-01-25	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	8900	delivery	5	36
26184	2020-01-25 01:15:37	2020-01-25	8	[{"id_menu":5,"count":1}]	10328	delivery	5	13
26185	2020-01-25 01:18:46	2020-01-25	9	[{"id_menu":7,"count":1}]	9563	delivery	5	14
26186	2020-01-25 01:23:01	2020-01-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2697	delivery	5	28
26187	2020-01-25 01:24:26	2020-01-25	8	[{"id_menu":5,"count":1}]	9444	delivery	5	13
26188	2020-01-25 01:26:32	2020-01-25	14	[{"id_menu":2,"count":1}]	9965	delivery	5	19
26189	2020-01-25 01:31:03	2020-01-25	14	[{"id_menu":2,"count":1}]	10330	pick-up	0	14
26190	2020-01-25 01:32:45	2020-01-25	9	[{"id_menu":7,"count":1}]	9345	delivery	5	14
26191	2020-01-25 01:59:44	2020-01-25	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	5141	delivery	5	27
26192	2020-01-25 01:59:49	2020-01-25	17	[{"id_menu":4,"count":1}]	10323	delivery	5	22
26193	2020-01-25 02:06:44	2020-01-25	12	[{"id_menu":3,"count":1}]	10312	delivery	5	17
26194	2020-01-25 02:13:17	2020-01-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6609	delivery	5	23
26195	2020-01-25 02:15:15	2020-01-25	17	[{"id_menu":4,"count":1}]	981	delivery	5	22
26196	2020-01-25 02:16:46	2020-01-25	14	[{"id_menu":2,"count":2}]	124	pick-up	0	14
26197	2020-01-25 02:23:35	2020-01-25	14	[{"id_menu":2,"count":1}]	6700	delivery	5	19
26198	2020-01-25 02:25:00	2020-01-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10333	delivery	5	22
26199	2020-01-25 02:28:34	2020-01-25	9	[{"id_menu":6,"count":1}]	2821	pick-up	0	9
26200	2020-01-25 02:31:39	2020-01-25	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	491	delivery	5	29
26201	2020-01-25 02:31:56	2020-01-25	14	[{"id_menu":2,"count":1}]	10294	delivery	5	19
26202	2020-01-25 02:43:30	2020-01-25	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	6874	delivery	5	34
26203	2020-01-25 03:15:26	2020-01-25	9	[{"id_menu":7,"count":1}]	10305	delivery	5	14
26204	2020-01-25 03:15:52	2020-01-25	14	[{"id_menu":2,"count":1}]	4807	delivery	5	19
26205	2020-01-25 03:15:52	2020-01-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6037	pick-up	0	26
26206	2020-01-25 03:16:52	2020-01-25	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3598	delivery	5	26
26207	2020-01-25 03:28:15	2020-01-25	12	[{"id_menu":1,"count":1}]	10318	delivery	5	17
26208	2020-01-25 03:30:29	2020-01-25	12	[{"id_menu":3,"count":1}]	204	pick-up	0	12
26209	2020-01-25 03:35:29	2020-01-25	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	9941	delivery	5	29
26210	2020-01-25 03:36:12	2020-01-25	12	[{"id_menu":3,"count":1}]	10373	delivery	5	17
26211	2020-01-25 03:39:51	2020-01-25	9	[{"id_menu":6,"count":1}]	213	pick-up	0	9
26212	2020-01-25 03:59:47	2020-01-25	9	[{"id_menu":7,"count":1}]	1914	pick-up	0	9
26213	2020-01-25 04:02:11	2020-01-25	9	[{"id_menu":6,"count":1}]	4020	delivery	5	14
26214	2020-01-25 04:04:35	2020-01-25	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	378	pick-up	0	31
26215	2020-01-25 04:07:05	2020-01-25	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10282	delivery	5	43
26216	2020-01-25 04:12:06	2020-01-25	9	[{"id_menu":6,"count":2}]	9859	delivery	5	14
26217	2020-01-25 04:13:16	2020-01-25	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10310	delivery	5	31
26218	2020-01-25 04:13:39	2020-01-25	14	[{"id_menu":2,"count":1}]	6405	pick-up	0	14
26219	2020-01-25 04:15:18	2020-01-25	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10301	pick-up	0	43
26220	2020-01-25 04:19:31	2020-01-25	9	[{"id_menu":6,"count":1}]	6848	pick-up	0	9
26221	2020-01-25 04:27:15	2020-01-25	17	[{"id_menu":4,"count":1}]	10355	pick-up	0	17
26222	2020-01-25 04:35:39	2020-01-25	9	[{"id_menu":7,"count":1}]	7332	delivery	5	14
26223	2020-01-25 04:36:05	2020-01-25	12	[{"id_menu":3,"count":1}]	10345	pick-up	0	12
26224	2020-01-25 04:45:35	2020-01-25	14	[{"id_menu":2,"count":1}]	8164	delivery	5	19
26225	2020-01-25 04:48:59	2020-01-25	8	[{"id_menu":5,"count":1}]	9084	delivery	5	13
26226	2020-01-25 04:57:11	2020-01-25	17	[{"id_menu":4,"count":1}]	10369	pick-up	0	17
26227	2020-01-25 05:00:40	2020-01-25	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10348	delivery	5	40
26228	2020-01-25 05:12:25	2020-01-25	9	[{"id_menu":7,"count":1}]	10014	delivery	5	14
26229	2020-01-25 05:15:04	2020-01-25	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8702	delivery	5	52
26230	2020-01-25 05:25:47	2020-01-25	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	10307	delivery	5	40
26231	2020-01-25 05:35:49	2020-01-25	9	[{"id_menu":6,"count":1}]	4054	pick-up	0	9
26232	2020-01-25 05:38:57	2020-01-25	14	[{"id_menu":2,"count":1}]	2728	pick-up	0	14
26233	2020-01-25 05:45:58	2020-01-25	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	5992	delivery	5	26
26234	2020-01-25 05:56:33	2020-01-25	9	[{"id_menu":6,"count":1}]	6926	pick-up	0	9
26235	2020-01-25 06:05:07	2020-01-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	236	pick-up	0	23
26236	2020-01-25 06:05:53	2020-01-25	9	[{"id_menu":6,"count":1}]	1166	pick-up	0	9
26237	2020-01-25 06:08:32	2020-01-25	9	[{"id_menu":6,"count":1}]	3734	delivery	5	14
26238	2020-01-25 06:11:39	2020-01-25	14	[{"id_menu":2,"count":1}]	27	pick-up	0	14
26239	2020-01-25 06:16:03	2020-01-25	17	[{"id_menu":4,"count":1}]	5240	pick-up	0	17
26240	2020-01-25 06:16:33	2020-01-25	9	[{"id_menu":7,"count":1}]	7000	delivery	5	14
26241	2020-01-25 06:22:41	2020-01-25	14	[{"id_menu":2,"count":1}]	806	delivery	5	19
26242	2020-01-25 06:27:17	2020-01-25	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	7539	pick-up	0	21
26243	2020-01-25 06:29:03	2020-01-25	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	6439	pick-up	0	21
26244	2020-01-25 06:31:05	2020-01-25	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10340	delivery	5	36
26245	2020-01-25 06:34:03	2020-01-25	17	[{"id_menu":4,"count":1}]	10315	delivery	5	22
26246	2020-01-25 06:34:24	2020-01-25	9	[{"id_menu":7,"count":1}]	4062	pick-up	0	9
26247	2020-01-25 06:39:25	2020-01-25	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	2276	pick-up	0	23
26248	2020-01-25 06:48:57	2020-01-25	12	[{"id_menu":3,"count":1}]	3511	pick-up	0	12
26249	2020-01-25 06:49:24	2020-01-25	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	2392	delivery	5	40
26250	2020-01-25 06:50:01	2020-01-25	17	[{"id_menu":4,"count":1}]	2286	pick-up	0	17
26251	2020-01-25 06:51:36	2020-01-25	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	3174	delivery	5	31
26252	2020-01-25 06:59:07	2020-01-25	14	[{"id_menu":2,"count":1}]	8748	pick-up	0	14
26253	2020-01-25 07:05:06	2020-01-25	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	851	delivery	5	37
26254	2020-01-25 07:06:41	2020-01-25	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10374	pick-up	0	39
26255	2020-01-25 07:09:03	2020-01-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5427	pick-up	0	23
26256	2020-01-25 07:14:44	2020-01-25	12	[{"id_menu":1,"count":1}]	6865	pick-up	0	12
26257	2020-01-25 07:15:29	2020-01-25	12	[{"id_menu":1,"count":1}]	10281	pick-up	0	12
26258	2020-01-25 07:16:20	2020-01-25	9	[{"id_menu":6,"count":1}]	7222	delivery	5	14
26259	2020-01-25 07:17:49	2020-01-25	17	[{"id_menu":4,"count":1}]	10376	delivery	5	22
26260	2020-01-25 07:18:34	2020-01-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10292	delivery	5	22
26261	2020-01-25 07:22:15	2020-01-25	9	[{"id_menu":6,"count":2}]	10290	pick-up	0	9
26262	2020-01-25 07:22:48	2020-01-25	12	[{"id_menu":3,"count":1}]	10361	delivery	5	17
26263	2020-01-25 07:32:05	2020-01-25	9	[{"id_menu":7,"count":1}]	92	pick-up	0	9
26264	2020-01-25 07:34:03	2020-01-25	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	5929	delivery	5	28
26265	2020-01-25 07:36:14	2020-01-25	14	[{"id_menu":2,"count":1}]	10285	delivery	5	19
26266	2020-01-25 07:53:17	2020-01-25	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2472	pick-up	0	23
26267	2020-01-25 07:54:24	2020-01-25	9	[{"id_menu":6,"count":1}]	3964	delivery	5	14
26268	2020-01-25 07:55:10	2020-01-25	9	[{"id_menu":7,"count":1}]	10377	delivery	5	14
26269	2020-01-25 07:57:47	2020-01-25	8	[{"id_menu":5,"count":1}]	2731	delivery	5	13
26270	2020-01-25 08:03:35	2020-01-25	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	1387	pick-up	0	23
26271	2020-01-25 08:26:39	2020-01-25	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10352	delivery	5	22
26272	2020-01-25 08:31:45	2020-01-25	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10336	delivery	5	31
26273	2020-01-25 08:35:59	2020-01-25	8	[{"id_menu":5,"count":1}]	2681	delivery	5	13
26274	2020-01-25 08:37:47	2020-01-25	9	[{"id_menu":6,"count":1}]	9099	delivery	5	14
26275	2020-01-25 08:41:04	2020-01-25	12	[{"id_menu":1,"count":1}]	1648	delivery	5	17
26276	2020-01-25 08:49:54	2020-01-25	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	123	pick-up	0	20
26277	2020-01-25 08:50:36	2020-01-25	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3647	pick-up	0	22
26278	2020-01-25 09:00:03	2020-01-25	17	[{"id_menu":4,"count":1}]	10356	delivery	5	22
26279	2020-01-25 09:05:32	2020-01-25	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	3399	pick-up	0	24
26280	2020-01-25 09:06:45	2020-01-25	9	[{"id_menu":6,"count":1}]	7726	pick-up	0	9
26281	2020-01-25 09:15:10	2020-01-25	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7791	delivery	5	28
26282	2020-01-25 09:20:25	2020-01-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	10322	delivery	5	28
26283	2020-01-25 09:23:46	2020-01-25	17	[{"id_menu":4,"count":1}]	2677	delivery	5	22
26284	2020-01-25 09:24:50	2020-01-25	9	[{"id_menu":7,"count":1}]	6097	pick-up	0	9
26285	2020-01-25 09:25:37	2020-01-25	14	[{"id_menu":2,"count":1}]	10293	delivery	5	19
26286	2020-01-25 09:38:52	2020-01-25	17	[{"id_menu":4,"count":1}]	10284	delivery	5	22
26287	2020-01-25 09:50:10	2020-01-25	12	[{"id_menu":3,"count":1}]	9533	pick-up	0	12
26288	2020-01-25 09:59:31	2020-01-25	14	[{"id_menu":2,"count":1}]	10313	delivery	5	19
26289	2020-01-25 10:10:32	2020-01-25	9	[{"id_menu":7,"count":1}]	3614	delivery	5	14
26290	2020-01-25 10:16:14	2020-01-25	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10335	delivery	5	22
26291	2020-01-25 10:22:28	2020-01-25	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10317	delivery	5	43
26292	2020-01-25 10:27:23	2020-01-25	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2959	pick-up	0	33
26293	2020-01-25 10:28:19	2020-01-25	14	[{"id_menu":2,"count":1}]	5786	delivery	5	19
26294	2020-01-25 10:32:02	2020-01-25	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10240	delivery	5	40
26295	2020-01-25 10:41:30	2020-01-25	17	[{"id_menu":4,"count":1}]	511	pick-up	0	17
26296	2020-01-25 10:42:29	2020-01-25	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	10353	delivery	5	31
26297	2020-01-25 10:43:42	2020-01-25	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10286	delivery	5	45
26298	2020-01-25 10:49:35	2020-01-25	12	[{"id_menu":1,"count":1}]	708	pick-up	0	12
26299	2020-01-25 10:50:52	2020-01-25	17	[{"id_menu":4,"count":1}]	10120	delivery	5	22
26300	2020-01-25 10:52:44	2020-01-25	17	[{"id_menu":4,"count":1}]	4901	delivery	5	22
26301	2020-01-25 10:56:39	2020-01-25	14	[{"id_menu":2,"count":1}]	1035	pick-up	0	14
26302	2020-01-25 10:57:38	2020-01-25	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	7178	delivery	5	26
26303	2020-01-25 11:14:43	2020-01-25	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	8505	pick-up	0	31
26304	2020-01-25 11:16:22	2020-01-25	12	[{"id_menu":3,"count":1}]	2682	pick-up	0	12
26305	2020-01-25 11:18:17	2020-01-25	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	10329	pick-up	0	31
26306	2020-01-25 11:29:09	2020-01-25	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	5462	delivery	5	25
26307	2020-01-25 11:34:04	2020-01-25	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10337	delivery	5	48
26308	2020-01-25 11:35:49	2020-01-25	9	[{"id_menu":7,"count":1}]	6570	delivery	5	14
26309	2020-01-25 11:40:03	2020-01-25	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5099	delivery	5	43
26310	2020-01-25 11:44:20	2020-01-25	9	[{"id_menu":7,"count":1}]	3459	pick-up	0	9
26311	2020-01-25 11:44:52	2020-01-25	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	10283	pick-up	0	35
26312	2020-01-25 11:46:04	2020-01-25	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	3996	delivery	5	25
26313	2020-01-25 11:46:44	2020-01-25	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	286	delivery	5	25
26314	2020-01-25 11:48:49	2020-01-25	8	[{"id_menu":5,"count":1}]	728	pick-up	0	8
26315	2020-01-25 11:50:41	2020-01-25	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	8526	delivery	5	43
26316	2020-01-25 11:54:08	2020-01-25	9	[{"id_menu":6,"count":1}]	1390	delivery	5	14
26317	2020-01-25 12:01:44	2020-01-25	8	[{"id_menu":5,"count":1}]	3524	pick-up	0	8
26318	2020-01-25 12:07:06	2020-01-25	9	[{"id_menu":6,"count":1}]	10331	delivery	5	14
26319	2020-01-25 12:09:30	2020-01-25	14	[{"id_menu":2,"count":1}]	7931	pick-up	0	14
26320	2020-01-25 12:14:36	2020-01-25	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7550	pick-up	0	44
26321	2020-01-25 12:15:43	2020-01-25	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	39	delivery	5	36
26322	2020-01-25 12:23:07	2020-01-25	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	8090	pick-up	0	34
26323	2020-01-25 12:28:26	2020-01-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1394	pick-up	0	23
26324	2020-01-25 12:35:08	2020-01-25	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	7017	pick-up	0	33
26325	2020-01-25 12:43:10	2020-01-25	14	[{"id_menu":2,"count":1}]	10343	pick-up	0	14
26326	2020-01-25 12:44:05	2020-01-25	12	[{"id_menu":3,"count":1}]	10332	delivery	5	17
26327	2020-01-25 12:45:33	2020-01-25	9	[{"id_menu":6,"count":1}]	7766	pick-up	0	9
26328	2020-01-25 12:48:28	2020-01-25	17	[{"id_menu":4,"count":1}]	10351	delivery	5	22
26329	2020-01-25 12:53:33	2020-01-25	9	[{"id_menu":7,"count":1}]	10298	delivery	5	14
26330	2020-01-25 12:55:50	2020-01-25	14	[{"id_menu":2,"count":1}]	10359	delivery	5	19
26331	2020-01-25 13:02:25	2020-01-25	17	[{"id_menu":4,"count":1}]	10244	pick-up	0	17
26332	2020-01-25 13:05:00	2020-01-25	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	4374	delivery	5	26
26333	2020-01-25 13:05:50	2020-01-25	17	[{"id_menu":4,"count":1}]	1196	pick-up	0	17
26334	2020-01-25 13:08:25	2020-01-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10379	delivery	5	23
26335	2020-01-25 13:12:50	2020-01-25	9	[{"id_menu":6,"count":1}]	5503	delivery	5	14
26336	2020-01-25 13:33:45	2020-01-25	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	6675	delivery	5	35
26337	2020-01-25 13:48:18	2020-01-25	17	[{"id_menu":4,"count":1}]	10326	pick-up	0	17
26338	2020-01-25 13:52:39	2020-01-25	8	[{"id_menu":5,"count":1}]	10346	delivery	5	13
26339	2020-01-25 13:54:21	2020-01-25	9	[{"id_menu":7,"count":1}]	10371	pick-up	0	9
26340	2020-01-25 13:54:50	2020-01-25	8	[{"id_menu":5,"count":1}]	3754	delivery	5	13
26341	2020-01-25 13:58:34	2020-01-25	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	6938	delivery	5	40
26342	2020-01-25 13:59:09	2020-01-25	17	[{"id_menu":4,"count":1}]	7919	pick-up	0	17
26343	2020-01-25 14:07:00	2020-01-25	9	[{"id_menu":7,"count":1}]	10378	delivery	5	14
26344	2020-01-25 14:10:18	2020-01-25	14	[{"id_menu":2,"count":1}]	1993	pick-up	0	14
26345	2020-01-25 14:17:44	2020-01-25	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	2806	delivery	5	22
26346	2020-01-25 14:26:32	2020-01-25	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	10339	delivery	5	23
26347	2020-01-25 14:28:50	2020-01-25	12	[{"id_menu":1,"count":1}]	3385	delivery	5	17
26348	2020-01-25 14:28:50	2020-01-25	12	[{"id_menu":1,"count":1}]	2857	delivery	5	17
26349	2020-01-25 14:30:10	2020-01-25	12	[{"id_menu":1,"count":1}]	914	pick-up	0	12
26350	2020-01-25 14:32:18	2020-01-25	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10297	delivery	5	36
26351	2020-01-25 14:37:24	2020-01-25	14	[{"id_menu":2,"count":1}]	10287	delivery	5	19
26352	2020-01-25 14:51:29	2020-01-25	14	[{"id_menu":2,"count":1}]	106	pick-up	0	14
26353	2020-01-25 15:01:38	2020-01-25	9	[{"id_menu":6,"count":1}]	10367	delivery	5	14
26354	2020-01-25 15:08:45	2020-01-25	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	10296	delivery	5	25
26355	2020-01-25 15:14:55	2020-01-25	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	8010	delivery	5	26
26356	2020-01-25 15:17:04	2020-01-25	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2244	delivery	5	22
26357	2020-01-25 15:31:47	2020-01-25	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	1907	pick-up	0	35
26358	2020-01-25 15:37:52	2020-01-25	9	[{"id_menu":6,"count":1}]	3705	delivery	5	14
26359	2020-01-25 15:41:38	2020-01-25	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	4090	delivery	5	26
26360	2020-01-25 15:55:22	2020-01-25	17	[{"id_menu":4,"count":1}]	3780	pick-up	0	17
26361	2020-01-25 15:58:52	2020-01-25	9	[{"id_menu":7,"count":1}]	4982	delivery	5	14
26362	2020-01-25 16:02:22	2020-01-25	14	[{"id_menu":2,"count":1}]	8298	pick-up	0	14
26363	2020-01-25 16:04:45	2020-01-25	9	[{"id_menu":7,"count":1}]	5383	delivery	5	14
26364	2020-01-25 16:07:34	2020-01-25	9	[{"id_menu":6,"count":1}]	206	delivery	5	14
26365	2020-01-25 16:10:59	2020-01-25	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4125	delivery	5	34
26366	2020-01-25 16:22:08	2020-01-25	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	10309	delivery	5	31
26367	2020-01-25 16:35:29	2020-01-25	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	754	delivery	5	36
26368	2020-01-25 16:42:15	2020-01-25	9	[{"id_menu":6,"count":1}]	676	delivery	5	14
26369	2020-01-25 16:46:55	2020-01-25	12	[{"id_menu":1,"count":1}]	2672	pick-up	0	12
26370	2020-01-25 16:55:07	2020-01-25	9	[{"id_menu":6,"count":2}]	9340	delivery	5	14
26371	2020-01-25 17:00:31	2020-01-25	9	[{"id_menu":7,"count":1}]	1233	pick-up	0	9
26372	2020-01-25 17:17:47	2020-01-25	14	[{"id_menu":2,"count":1}]	396	delivery	5	19
26373	2020-01-25 17:22:26	2020-01-25	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	8622	delivery	5	34
26374	2020-01-25 17:25:58	2020-01-25	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	10311	delivery	5	26
26375	2020-01-25 17:29:08	2020-01-25	17	[{"id_menu":4,"count":1}]	10360	delivery	5	22
26376	2020-01-25 17:37:18	2020-01-25	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6894	delivery	5	49
26377	2020-01-25 17:38:16	2020-01-25	14	[{"id_menu":2,"count":1}]	3338	pick-up	0	14
26378	2020-01-25 17:40:22	2020-01-25	17	[{"id_menu":4,"count":1}]	10358	pick-up	0	17
26379	2020-01-25 17:40:46	2020-01-25	17	[{"id_menu":4,"count":1}]	9097	delivery	5	22
26380	2020-01-25 17:44:48	2020-01-25	12	[{"id_menu":3,"count":1}]	7190	pick-up	0	12
26381	2020-01-25 17:49:51	2020-01-25	34	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	10368	delivery	5	39
26382	2020-01-25 17:52:36	2020-01-25	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3676	delivery	5	31
26383	2020-01-25 17:55:24	2020-01-25	14	[{"id_menu":2,"count":1}]	8322	pick-up	0	14
26384	2020-01-25 17:59:19	2020-01-25	9	[{"id_menu":7,"count":1}]	3065	pick-up	0	9
26385	2020-01-25 17:59:30	2020-01-25	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	10334	delivery	5	36
26386	2020-01-25 18:03:39	2020-01-25	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10364	delivery	5	34
26387	2020-01-25 18:03:56	2020-01-25	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	4836	delivery	5	26
26388	2020-01-25 18:07:07	2020-01-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10325	delivery	5	31
26389	2020-01-25 18:12:03	2020-01-25	12	[{"id_menu":3,"count":1}]	868	delivery	5	17
26390	2020-01-25 18:15:22	2020-01-25	8	[{"id_menu":5,"count":1}]	10003	delivery	5	13
26391	2020-01-25 18:21:00	2020-01-25	12	[{"id_menu":1,"count":1}]	9061	pick-up	0	12
26392	2020-01-25 18:23:17	2020-01-25	9	[{"id_menu":7,"count":1}]	10314	delivery	5	14
26393	2020-01-25 18:25:14	2020-01-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8239	delivery	5	22
26394	2020-01-25 18:25:14	2020-01-25	9	[{"id_menu":7,"count":1}]	6232	pick-up	0	9
26395	2020-01-25 18:25:45	2020-01-25	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10306	delivery	5	51
26396	2020-01-25 18:27:55	2020-01-25	12	[{"id_menu":1,"count":1}]	3289	pick-up	0	12
26397	2020-01-25 18:31:47	2020-01-25	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10321	delivery	5	34
26398	2020-01-25 18:33:14	2020-01-25	12	[{"id_menu":1,"count":1}]	1800	pick-up	0	12
26399	2020-01-25 18:46:06	2020-01-25	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10308	delivery	5	43
26400	2020-01-25 19:07:12	2020-01-25	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2237	delivery	5	31
26401	2020-01-25 19:07:21	2020-01-25	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10363	pick-up	0	26
26402	2020-01-25 19:15:43	2020-01-25	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10380	delivery	5	51
26403	2020-01-25 19:18:10	2020-01-25	12	[{"id_menu":3,"count":1}]	44	delivery	5	17
26404	2020-01-25 19:27:00	2020-01-25	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	229	pick-up	0	26
26405	2020-01-25 19:32:23	2020-01-25	14	[{"id_menu":2,"count":1}]	8102	delivery	5	19
26406	2020-01-25 19:36:15	2020-01-25	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	10365	delivery	5	25
26407	2020-01-25 19:36:20	2020-01-25	9	[{"id_menu":6,"count":1}]	9192	delivery	5	14
26408	2020-01-25 19:40:38	2020-01-25	14	[{"id_menu":2,"count":1}]	577	delivery	5	19
26409	2020-01-25 19:48:34	2020-01-25	9	[{"id_menu":7,"count":1}]	3010	pick-up	0	9
26410	2020-01-25 19:49:26	2020-01-25	8	[{"id_menu":5,"count":1}]	10366	delivery	5	13
26411	2020-01-25 19:54:52	2020-01-25	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10341	delivery	5	22
26412	2020-01-25 19:57:12	2020-01-25	14	[{"id_menu":2,"count":1}]	73	pick-up	0	14
26413	2020-01-25 20:07:05	2020-01-25	17	[{"id_menu":4,"count":1}]	8598	pick-up	0	17
26414	2020-01-25 20:07:47	2020-01-25	12	[{"id_menu":3,"count":1}]	10300	delivery	5	17
26415	2020-01-25 20:07:59	2020-01-25	9	[{"id_menu":7,"count":1}]	2613	delivery	5	14
26416	2020-01-25 20:26:16	2020-01-25	17	[{"id_menu":4,"count":1}]	7902	delivery	5	22
26417	2020-01-25 20:26:49	2020-01-25	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4682	pick-up	0	25
26418	2020-01-25 20:26:52	2020-01-25	17	[{"id_menu":4,"count":1}]	5292	delivery	5	22
26419	2020-01-25 20:28:28	2020-01-25	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1021	pick-up	0	29
26420	2020-01-25 20:36:00	2020-01-25	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	612	delivery	5	29
26421	2020-01-25 20:37:48	2020-01-25	9	[{"id_menu":6,"count":1}]	10344	delivery	5	14
26422	2020-01-25 20:43:47	2020-01-25	9	[{"id_menu":7,"count":2}]	10370	delivery	5	14
26423	2020-01-25 20:48:28	2020-01-25	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	5457	pick-up	0	21
26424	2020-01-25 20:50:27	2020-01-25	9	[{"id_menu":6,"count":1}]	10342	delivery	5	14
26425	2020-01-25 20:52:40	2020-01-25	12	[{"id_menu":1,"count":1}]	867	delivery	5	17
26426	2020-01-25 20:58:44	2020-01-25	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9405	delivery	5	36
26427	2020-01-25 21:05:26	2020-01-25	12	[{"id_menu":1,"count":1}]	10320	delivery	5	17
26428	2020-01-25 21:19:14	2020-01-25	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2902	pick-up	0	26
26429	2020-01-25 21:19:48	2020-01-25	12	[{"id_menu":1,"count":1}]	6644	delivery	5	17
26430	2020-01-25 21:21:31	2020-01-25	12	[{"id_menu":1,"count":1}]	112	delivery	5	17
26431	2020-01-25 21:26:31	2020-01-25	9	[{"id_menu":6,"count":1}]	10362	delivery	5	14
26432	2020-01-25 21:27:15	2020-01-25	9	[{"id_menu":6,"count":1}]	10289	delivery	5	14
26433	2020-01-25 21:28:55	2020-01-25	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3268	delivery	5	43
26434	2020-01-25 21:42:26	2020-01-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9924	delivery	5	31
26435	2020-01-25 21:47:17	2020-01-25	9	[{"id_menu":7,"count":1}]	5189	delivery	5	14
26436	2020-01-25 21:48:53	2020-01-25	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	6331	pick-up	0	29
26437	2020-01-25 21:51:36	2020-01-25	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8717	delivery	5	40
26438	2020-01-25 21:52:13	2020-01-25	8	[{"id_menu":5,"count":1}]	2056	pick-up	0	8
26439	2020-01-25 21:57:48	2020-01-25	12	[{"id_menu":1,"count":1}]	10303	delivery	5	17
26440	2020-01-25 21:59:18	2020-01-25	12	[{"id_menu":1,"count":1}]	1689	pick-up	0	12
26441	2020-01-25 22:03:56	2020-01-25	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	10274	delivery	5	39
26442	2020-01-25 22:06:57	2020-01-25	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10316	delivery	5	45
26443	2020-01-25 22:15:12	2020-01-25	8	[{"id_menu":5,"count":1}]	7061	pick-up	0	8
26444	2020-01-25 22:18:05	2020-01-25	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6728	delivery	5	30
26445	2020-01-25 22:19:33	2020-01-25	9	[{"id_menu":6,"count":1}]	8925	delivery	5	14
26446	2020-01-25 22:20:43	2020-01-25	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	8410	delivery	5	39
26447	2020-01-25 22:23:37	2020-01-25	9	[{"id_menu":7,"count":1}]	5499	delivery	5	14
26448	2020-01-25 22:26:34	2020-01-25	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4592	delivery	5	28
26449	2020-01-25 22:29:04	2020-01-25	12	[{"id_menu":3,"count":1}]	10338	delivery	5	17
26450	2020-01-25 22:31:26	2020-01-25	17	[{"id_menu":4,"count":1}]	8048	pick-up	0	17
26451	2020-01-25 22:31:37	2020-01-25	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2651	delivery	5	35
26452	2020-01-25 22:32:00	2020-01-25	30	[{"id_menu":1,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10354	delivery	5	35
26453	2020-01-25 22:34:39	2020-01-25	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6573	pick-up	0	25
26454	2020-01-25 22:36:21	2020-01-25	17	[{"id_menu":4,"count":1}]	4630	delivery	5	22
26455	2020-01-25 22:40:01	2020-01-25	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	9979	delivery	5	26
26456	2020-01-25 22:40:07	2020-01-25	9	[{"id_menu":6,"count":1}]	9762	delivery	5	14
26457	2020-01-25 22:43:39	2020-01-25	14	[{"id_menu":2,"count":1}]	10302	delivery	5	19
26458	2020-01-25 22:44:08	2020-01-25	12	[{"id_menu":1,"count":2}]	10223	pick-up	0	12
26459	2020-01-25 22:46:13	2020-01-25	14	[{"id_menu":2,"count":1}]	10372	delivery	5	19
26460	2020-01-25 22:56:23	2020-01-25	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1266	pick-up	0	29
26461	2020-01-25 22:59:55	2020-01-25	8	[{"id_menu":5,"count":1}]	8963	delivery	5	13
26462	2020-01-25 23:02:31	2020-01-25	12	[{"id_menu":3,"count":2}]	5587	pick-up	0	12
26463	2020-01-25 23:18:48	2020-01-25	8	[{"id_menu":5,"count":1}]	9562	delivery	5	13
26464	2020-01-25 23:19:37	2020-01-25	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	10299	delivery	5	34
26465	2020-01-25 23:21:29	2020-01-25	12	[{"id_menu":1,"count":1}]	7069	pick-up	0	12
26466	2020-01-25 23:24:12	2020-01-25	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4163	delivery	5	39
26467	2020-01-25 23:26:39	2020-01-25	9	[{"id_menu":6,"count":2}]	1334	pick-up	0	9
26468	2020-01-25 23:32:51	2020-01-25	12	[{"id_menu":1,"count":1}]	2266	pick-up	0	12
26469	2020-01-25 23:34:59	2020-01-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	10291	delivery	5	23
26470	2020-01-25 23:39:59	2020-01-25	9	[{"id_menu":6,"count":1}]	5936	delivery	5	14
26471	2020-01-25 23:44:25	2020-01-25	12	[{"id_menu":3,"count":1}]	10357	delivery	5	17
26472	2020-01-25 23:56:09	2020-01-25	12	[{"id_menu":1,"count":1}]	8060	delivery	5	17
26473	2020-01-25 23:58:27	2020-01-25	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	10319	pick-up	0	26
26474	2020-01-26 00:07:25	2020-01-26	12	[{"id_menu":1,"count":1}]	4287	delivery	5	17
26475	2020-01-26 00:08:06	2020-01-26	12	[{"id_menu":3,"count":1}]	5318	pick-up	0	12
26476	2020-01-26 00:17:35	2020-01-26	8	[{"id_menu":5,"count":1}]	3179	pick-up	0	8
26477	2020-01-26 00:19:15	2020-01-26	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7215	delivery	5	43
26478	2020-01-26 00:19:19	2020-01-26	9	[{"id_menu":6,"count":1}]	6956	delivery	5	14
26479	2020-01-26 00:21:31	2020-01-26	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	880	delivery	5	36
26480	2020-01-26 00:24:58	2020-01-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8347	pick-up	0	26
26481	2020-01-26 00:26:08	2020-01-26	12	[{"id_menu":1,"count":1}]	10453	delivery	5	17
26482	2020-01-26 00:32:14	2020-01-26	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2878	delivery	5	40
26483	2020-01-26 00:39:57	2020-01-26	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	7411	delivery	5	40
26484	2020-01-26 00:42:47	2020-01-26	12	[{"id_menu":1,"count":1}]	1303	pick-up	0	12
26485	2020-01-26 00:46:01	2020-01-26	9	[{"id_menu":6,"count":1}]	8104	delivery	5	14
26486	2020-01-26 00:46:43	2020-01-26	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	6647	pick-up	0	26
26487	2020-01-26 00:52:06	2020-01-26	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2175	delivery	5	26
26488	2020-01-26 00:52:10	2020-01-26	9	[{"id_menu":6,"count":1}]	7963	delivery	5	14
26489	2020-01-26 01:01:00	2020-01-26	9	[{"id_menu":6,"count":1}]	10428	delivery	5	14
26490	2020-01-26 01:02:04	2020-01-26	14	[{"id_menu":2,"count":1}]	10445	delivery	5	19
26491	2020-01-26 01:04:24	2020-01-26	12	[{"id_menu":1,"count":1}]	10441	pick-up	0	12
26492	2020-01-26 01:06:42	2020-01-26	12	[{"id_menu":3,"count":1}]	1485	pick-up	0	12
26493	2020-01-26 01:10:31	2020-01-26	8	[{"id_menu":5,"count":1}]	9575	delivery	5	13
26494	2020-01-26 01:16:22	2020-01-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10271	delivery	5	31
26495	2020-01-26 01:16:44	2020-01-26	12	[{"id_menu":1,"count":1}]	2439	pick-up	0	12
26496	2020-01-26 01:18:12	2020-01-26	14	[{"id_menu":2,"count":1}]	6046	pick-up	0	14
26497	2020-01-26 01:21:23	2020-01-26	14	[{"id_menu":2,"count":1}]	10398	delivery	5	19
26498	2020-01-26 01:24:14	2020-01-26	12	[{"id_menu":1,"count":1}]	4078	delivery	5	17
26499	2020-01-26 01:28:45	2020-01-26	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	7122	delivery	5	28
26500	2020-01-26 01:32:39	2020-01-26	9	[{"id_menu":7,"count":1}]	10395	delivery	5	14
26501	2020-01-26 01:35:46	2020-01-26	8	[{"id_menu":5,"count":1}]	4248	delivery	5	13
26502	2020-01-26 01:40:11	2020-01-26	17	[{"id_menu":4,"count":1}]	8596	delivery	5	22
26503	2020-01-26 01:44:40	2020-01-26	9	[{"id_menu":7,"count":1}]	5628	delivery	5	14
26504	2020-01-26 01:46:46	2020-01-26	12	[{"id_menu":3,"count":1}]	9907	pick-up	0	12
26505	2020-01-26 01:57:27	2020-01-26	17	[{"id_menu":4,"count":1}]	5880	delivery	5	22
26506	2020-01-26 01:57:44	2020-01-26	9	[{"id_menu":7,"count":1}]	10424	delivery	5	14
26507	2020-01-26 02:08:13	2020-01-26	12	[{"id_menu":3,"count":2}]	6307	delivery	5	17
26508	2020-01-26 02:18:15	2020-01-26	9	[{"id_menu":7,"count":1}]	5050	pick-up	0	9
26509	2020-01-26 02:23:34	2020-01-26	9	[{"id_menu":7,"count":1}]	4588	delivery	5	14
26510	2020-01-26 02:30:01	2020-01-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10409	delivery	5	23
26511	2020-01-26 02:31:42	2020-01-26	12	[{"id_menu":3,"count":1}]	2185	pick-up	0	12
26512	2020-01-26 02:32:36	2020-01-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1791	delivery	5	23
26513	2020-01-26 02:46:25	2020-01-26	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	10417	delivery	5	38
26514	2020-01-26 02:53:25	2020-01-26	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	10399	delivery	5	25
26515	2020-01-26 02:58:05	2020-01-26	14	[{"id_menu":2,"count":1}]	10235	delivery	5	19
26516	2020-01-26 03:02:44	2020-01-26	8	[{"id_menu":5,"count":1}]	9014	delivery	5	13
26517	2020-01-26 03:04:28	2020-01-26	17	[{"id_menu":4,"count":1}]	2072	pick-up	0	17
26518	2020-01-26 03:05:00	2020-01-26	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	475	delivery	5	34
26519	2020-01-26 03:13:32	2020-01-26	9	[{"id_menu":6,"count":1}]	2916	pick-up	0	9
26520	2020-01-26 03:24:28	2020-01-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3411	delivery	5	28
26521	2020-01-26 03:28:01	2020-01-26	9	[{"id_menu":6,"count":1}]	6067	pick-up	0	9
26522	2020-01-26 03:34:21	2020-01-26	9	[{"id_menu":7,"count":1}]	4456	delivery	5	14
26523	2020-01-26 03:41:22	2020-01-26	9	[{"id_menu":6,"count":1}]	10381	pick-up	0	9
26524	2020-01-26 03:43:37	2020-01-26	9	[{"id_menu":6,"count":2}]	2585	delivery	5	14
26525	2020-01-26 03:49:27	2020-01-26	12	[{"id_menu":1,"count":1}]	4993	pick-up	0	12
26526	2020-01-26 03:59:34	2020-01-26	12	[{"id_menu":3,"count":1}]	10436	pick-up	0	12
26527	2020-01-26 04:03:57	2020-01-26	8	[{"id_menu":5,"count":1}]	1782	delivery	5	13
26528	2020-01-26 04:06:20	2020-01-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	4356	delivery	5	26
26529	2020-01-26 04:13:19	2020-01-26	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	1781	pick-up	0	26
26530	2020-01-26 04:13:35	2020-01-26	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	6557	delivery	5	26
26531	2020-01-26 04:16:54	2020-01-26	9	[{"id_menu":7,"count":1}]	3934	delivery	5	14
26532	2020-01-26 04:25:03	2020-01-26	9	[{"id_menu":6,"count":1}]	2517	pick-up	0	9
26533	2020-01-26 04:28:17	2020-01-26	9	[{"id_menu":7,"count":1}]	5354	delivery	5	14
26534	2020-01-26 04:30:32	2020-01-26	9	[{"id_menu":7,"count":1}]	10405	delivery	5	14
26535	2020-01-26 04:32:58	2020-01-26	9	[{"id_menu":7,"count":1}]	158	pick-up	0	9
26536	2020-01-26 04:35:40	2020-01-26	9	[{"id_menu":7,"count":1}]	8866	delivery	5	14
26537	2020-01-26 04:38:16	2020-01-26	12	[{"id_menu":1,"count":1}]	9819	delivery	5	17
26538	2020-01-26 04:48:56	2020-01-26	12	[{"id_menu":1,"count":1}]	10420	delivery	5	17
26539	2020-01-26 05:26:59	2020-01-26	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10450	delivery	5	34
26540	2020-01-26 05:27:15	2020-01-26	9	[{"id_menu":6,"count":1}]	10474	delivery	5	14
26541	2020-01-26 05:28:33	2020-01-26	9	[{"id_menu":6,"count":1}]	10390	delivery	5	14
26542	2020-01-26 05:35:26	2020-01-26	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	2556	pick-up	0	40
26543	2020-01-26 05:35:53	2020-01-26	17	[{"id_menu":4,"count":1}]	6644	delivery	5	22
26544	2020-01-26 05:48:06	2020-01-26	9	[{"id_menu":7,"count":1}]	5917	delivery	5	14
26545	2020-01-26 05:55:54	2020-01-26	14	[{"id_menu":2,"count":1}]	931	pick-up	0	14
26546	2020-01-26 06:00:42	2020-01-26	9	[{"id_menu":6,"count":1}]	10410	pick-up	0	9
26547	2020-01-26 06:01:17	2020-01-26	9	[{"id_menu":6,"count":1}]	8131	delivery	5	14
26548	2020-01-26 06:02:23	2020-01-26	12	[{"id_menu":1,"count":1}]	10408	delivery	5	17
26549	2020-01-26 06:12:07	2020-01-26	14	[{"id_menu":2,"count":1}]	5194	pick-up	0	14
26550	2020-01-26 06:25:41	2020-01-26	9	[{"id_menu":6,"count":1}]	5783	pick-up	0	9
26551	2020-01-26 06:26:44	2020-01-26	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	7048	delivery	5	34
26552	2020-01-26 06:28:31	2020-01-26	9	[{"id_menu":6,"count":1}]	2811	delivery	5	14
26553	2020-01-26 06:29:20	2020-01-26	9	[{"id_menu":7,"count":1}]	2997	delivery	5	14
26554	2020-01-26 06:30:40	2020-01-26	9	[{"id_menu":6,"count":1}]	2735	pick-up	0	9
26555	2020-01-26 06:32:32	2020-01-26	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2564	pick-up	0	43
26556	2020-01-26 06:35:19	2020-01-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":3}]	10476	delivery	5	23
26557	2020-01-26 06:35:21	2020-01-26	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	10435	delivery	5	34
26558	2020-01-26 06:36:01	2020-01-26	12	[{"id_menu":3,"count":1}]	1343	pick-up	0	12
26559	2020-01-26 06:47:00	2020-01-26	17	[{"id_menu":4,"count":1}]	10418	delivery	5	22
26560	2020-01-26 06:47:43	2020-01-26	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10423	delivery	5	45
26561	2020-01-26 06:52:20	2020-01-26	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	1736	delivery	5	45
26562	2020-01-26 06:54:30	2020-01-26	9	[{"id_menu":7,"count":1}]	5945	pick-up	0	9
26563	2020-01-26 07:09:25	2020-01-26	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4486	pick-up	0	32
26564	2020-01-26 07:37:07	2020-01-26	8	[{"id_menu":5,"count":1}]	8202	delivery	5	13
26565	2020-01-26 07:41:13	2020-01-26	14	[{"id_menu":2,"count":1}]	10425	pick-up	0	14
26566	2020-01-26 07:47:28	2020-01-26	9	[{"id_menu":6,"count":1}]	304	delivery	5	14
26567	2020-01-26 07:52:40	2020-01-26	9	[{"id_menu":7,"count":1}]	10447	delivery	5	14
26568	2020-01-26 08:00:20	2020-01-26	14	[{"id_menu":2,"count":1}]	432	pick-up	0	14
26569	2020-01-26 08:10:09	2020-01-26	12	[{"id_menu":3,"count":1}]	2575	delivery	5	17
26570	2020-01-26 08:14:48	2020-01-26	17	[{"id_menu":4,"count":1}]	3317	delivery	5	22
26571	2020-01-26 08:22:18	2020-01-26	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10455	delivery	5	35
26572	2020-01-26 08:25:55	2020-01-26	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	10454	delivery	5	27
26573	2020-01-26 08:25:57	2020-01-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10432	delivery	5	22
26574	2020-01-26 08:28:42	2020-01-26	9	[{"id_menu":6,"count":1}]	2142	delivery	5	14
26575	2020-01-26 08:30:42	2020-01-26	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2631	pick-up	0	29
26576	2020-01-26 08:31:56	2020-01-26	9	[{"id_menu":6,"count":1}]	10396	pick-up	0	9
26577	2020-01-26 08:32:04	2020-01-26	9	[{"id_menu":6,"count":1}]	7041	delivery	5	14
26578	2020-01-26 08:41:35	2020-01-26	14	[{"id_menu":2,"count":1}]	1467	delivery	5	19
26579	2020-01-26 08:44:36	2020-01-26	12	[{"id_menu":1,"count":1}]	3540	delivery	5	17
26580	2020-01-26 08:51:37	2020-01-26	14	[{"id_menu":2,"count":2}]	2524	pick-up	0	14
26581	2020-01-26 08:52:39	2020-01-26	17	[{"id_menu":4,"count":1}]	10411	delivery	5	22
26582	2020-01-26 08:59:47	2020-01-26	9	[{"id_menu":6,"count":1}]	5220	delivery	5	14
26583	2020-01-26 09:05:46	2020-01-26	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	6174	delivery	5	34
26584	2020-01-26 09:12:49	2020-01-26	14	[{"id_menu":2,"count":1}]	10438	delivery	5	19
26585	2020-01-26 09:15:05	2020-01-26	9	[{"id_menu":6,"count":2}]	10384	delivery	5	14
26586	2020-01-26 09:15:22	2020-01-26	9	[{"id_menu":6,"count":1}]	10456	delivery	5	14
26587	2020-01-26 09:28:52	2020-01-26	17	[{"id_menu":4,"count":1}]	10386	delivery	5	22
26588	2020-01-26 09:51:31	2020-01-26	12	[{"id_menu":3,"count":1}]	6369	pick-up	0	12
26589	2020-01-26 10:00:33	2020-01-26	8	[{"id_menu":5,"count":1}]	10459	delivery	5	13
26590	2020-01-26 10:04:09	2020-01-26	9	[{"id_menu":6,"count":1}]	5787	delivery	5	14
26591	2020-01-26 10:08:20	2020-01-26	9	[{"id_menu":6,"count":1}]	10406	pick-up	0	9
26592	2020-01-26 10:10:46	2020-01-26	14	[{"id_menu":2,"count":1}]	6743	delivery	5	19
26593	2020-01-26 10:14:29	2020-01-26	9	[{"id_menu":7,"count":1}]	10467	delivery	5	14
26594	2020-01-26 10:16:32	2020-01-26	17	[{"id_menu":4,"count":1}]	3949	delivery	5	22
26595	2020-01-26 10:27:41	2020-01-26	12	[{"id_menu":3,"count":1}]	10422	delivery	5	17
26596	2020-01-26 10:29:44	2020-01-26	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	143	pick-up	0	33
26597	2020-01-26 10:31:15	2020-01-26	17	[{"id_menu":4,"count":1}]	2071	pick-up	0	17
26598	2020-01-26 10:36:44	2020-01-26	9	[{"id_menu":6,"count":1}]	10427	delivery	5	14
26599	2020-01-26 10:37:48	2020-01-26	12	[{"id_menu":3,"count":1}]	10446	delivery	5	17
26600	2020-01-26 10:41:38	2020-01-26	17	[{"id_menu":4,"count":1}]	10451	pick-up	0	17
26601	2020-01-26 10:47:51	2020-01-26	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10475	delivery	5	39
26602	2020-01-26 10:52:38	2020-01-26	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10388	delivery	5	43
26603	2020-01-26 10:53:44	2020-01-26	12	[{"id_menu":3,"count":1}]	1681	delivery	5	17
26604	2020-01-26 11:01:03	2020-01-26	9	[{"id_menu":7,"count":1}]	10443	delivery	5	14
26605	2020-01-26 11:01:45	2020-01-26	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	2519	delivery	5	29
26606	2020-01-26 11:04:37	2020-01-26	9	[{"id_menu":7,"count":1}]	6783	delivery	5	14
26607	2020-01-26 11:16:22	2020-01-26	17	[{"id_menu":4,"count":1}]	3622	pick-up	0	17
26608	2020-01-26 11:16:59	2020-01-26	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	10407	delivery	5	34
26609	2020-01-26 11:19:24	2020-01-26	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	10419	delivery	5	40
26610	2020-01-26 11:21:15	2020-01-26	12	[{"id_menu":3,"count":1}]	472	delivery	5	17
26611	2020-01-26 11:21:22	2020-01-26	9	[{"id_menu":7,"count":1}]	2947	pick-up	0	9
26612	2020-01-26 11:24:46	2020-01-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2000	delivery	5	22
26613	2020-01-26 11:38:09	2020-01-26	8	[{"id_menu":5,"count":1}]	7217	delivery	5	13
26614	2020-01-26 11:39:11	2020-01-26	9	[{"id_menu":6,"count":1}]	4206	pick-up	0	9
26615	2020-01-26 11:56:42	2020-01-26	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	9355	pick-up	0	29
26616	2020-01-26 12:03:35	2020-01-26	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	10430	delivery	5	39
26617	2020-01-26 12:04:38	2020-01-26	9	[{"id_menu":7,"count":1}]	437	delivery	5	14
26618	2020-01-26 12:09:05	2020-01-26	12	[{"id_menu":3,"count":1}]	4081	pick-up	0	12
26619	2020-01-26 12:09:11	2020-01-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	10397	pick-up	0	23
26620	2020-01-26 12:16:26	2020-01-26	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10431	delivery	5	34
26621	2020-01-26 12:23:06	2020-01-26	17	[{"id_menu":4,"count":1}]	2320	pick-up	0	17
26622	2020-01-26 12:25:41	2020-01-26	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	245	pick-up	0	31
26623	2020-01-26 12:27:51	2020-01-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	511	pick-up	0	18
26624	2020-01-26 12:30:39	2020-01-26	12	[{"id_menu":3,"count":1}]	8081	pick-up	0	12
26625	2020-01-26 12:35:37	2020-01-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	10469	delivery	5	26
26626	2020-01-26 12:36:16	2020-01-26	12	[{"id_menu":1,"count":1}]	4870	pick-up	0	12
26627	2020-01-26 12:41:48	2020-01-26	9	[{"id_menu":7,"count":1}]	6844	delivery	5	14
26628	2020-01-26 12:51:12	2020-01-26	8	[{"id_menu":5,"count":1}]	4625	delivery	5	13
26629	2020-01-26 13:03:29	2020-01-26	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7916	delivery	5	34
26630	2020-01-26 13:12:29	2020-01-26	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1676	delivery	5	34
26631	2020-01-26 13:17:34	2020-01-26	14	[{"id_menu":2,"count":1}]	2168	pick-up	0	14
26632	2020-01-26 13:19:36	2020-01-26	17	[{"id_menu":4,"count":1}]	10470	delivery	5	22
26633	2020-01-26 13:20:22	2020-01-26	9	[{"id_menu":7,"count":1}]	1453	pick-up	0	9
26634	2020-01-26 13:26:31	2020-01-26	17	[{"id_menu":4,"count":1}]	3627	delivery	5	22
26635	2020-01-26 13:31:13	2020-01-26	12	[{"id_menu":1,"count":1}]	9300	pick-up	0	12
26636	2020-01-26 13:39:52	2020-01-26	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10429	delivery	5	45
26637	2020-01-26 13:49:40	2020-01-26	8	[{"id_menu":5,"count":1}]	8382	delivery	5	13
26638	2020-01-26 13:50:49	2020-01-26	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	226	pick-up	0	20
26639	2020-01-26 13:56:23	2020-01-26	12	[{"id_menu":1,"count":1}]	3433	pick-up	0	12
26640	2020-01-26 13:59:25	2020-01-26	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4760	pick-up	0	21
26641	2020-01-26 14:10:14	2020-01-26	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5485	delivery	5	39
26642	2020-01-26 14:12:24	2020-01-26	12	[{"id_menu":3,"count":1}]	10387	pick-up	0	12
26643	2020-01-26 14:14:02	2020-01-26	12	[{"id_menu":3,"count":1}]	7128	pick-up	0	12
26644	2020-01-26 14:18:21	2020-01-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	10389	pick-up	0	21
26645	2020-01-26 14:21:57	2020-01-26	9	[{"id_menu":7,"count":1}]	7435	pick-up	0	9
26646	2020-01-26 14:23:09	2020-01-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	45	pick-up	0	26
26647	2020-01-26 14:31:50	2020-01-26	12	[{"id_menu":3,"count":1}]	8583	delivery	5	17
26648	2020-01-26 14:35:23	2020-01-26	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9996	delivery	5	42
26649	2020-01-26 14:40:42	2020-01-26	12	[{"id_menu":1,"count":1}]	1227	delivery	5	17
26650	2020-01-26 14:41:16	2020-01-26	9	[{"id_menu":6,"count":1}]	999	pick-up	0	9
26651	2020-01-26 14:46:36	2020-01-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":3}]	8628	delivery	5	26
26652	2020-01-26 14:47:42	2020-01-26	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6509	delivery	5	45
26653	2020-01-26 14:52:15	2020-01-26	9	[{"id_menu":6,"count":1}]	133	pick-up	0	9
26654	2020-01-26 15:00:00	2020-01-26	9	[{"id_menu":7,"count":1}]	1685	pick-up	0	9
26655	2020-01-26 15:02:50	2020-01-26	8	[{"id_menu":5,"count":1}]	9804	delivery	5	13
26656	2020-01-26 15:05:42	2020-01-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	7679	delivery	5	28
26657	2020-01-26 15:08:26	2020-01-26	14	[{"id_menu":2,"count":1}]	2964	delivery	5	19
26658	2020-01-26 15:17:02	2020-01-26	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	5430	pick-up	0	21
26659	2020-01-26 15:17:52	2020-01-26	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	710	delivery	5	31
26660	2020-01-26 15:19:01	2020-01-26	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	10402	delivery	5	23
26661	2020-01-26 15:20:22	2020-01-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	10468	delivery	5	26
26662	2020-01-26 15:22:02	2020-01-26	17	[{"id_menu":4,"count":1}]	5758	pick-up	0	17
26663	2020-01-26 15:22:09	2020-01-26	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	4590	delivery	5	31
26664	2020-01-26 15:24:58	2020-01-26	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	7248	pick-up	0	22
26665	2020-01-26 15:26:13	2020-01-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	7143	delivery	5	26
26666	2020-01-26 15:29:38	2020-01-26	12	[{"id_menu":3,"count":1}]	751	pick-up	0	12
26667	2020-01-26 15:30:06	2020-01-26	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7865	delivery	5	40
26668	2020-01-26 15:33:32	2020-01-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7168	delivery	5	22
26669	2020-01-26 15:39:47	2020-01-26	8	[{"id_menu":5,"count":3}]	10444	delivery	5	13
26670	2020-01-26 15:39:59	2020-01-26	17	[{"id_menu":4,"count":1}]	547	pick-up	0	17
26671	2020-01-26 15:42:01	2020-01-26	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	10354	delivery	5	37
26672	2020-01-26 15:47:03	2020-01-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	7873	delivery	5	22
26673	2020-01-26 15:47:35	2020-01-26	8	[{"id_menu":5,"count":1}]	10452	pick-up	0	8
26674	2020-01-26 15:48:22	2020-01-26	9	[{"id_menu":7,"count":1}]	1880	delivery	5	14
26675	2020-01-26 15:48:28	2020-01-26	9	[{"id_menu":6,"count":1}]	6456	delivery	5	14
26676	2020-01-26 15:50:50	2020-01-26	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10471	delivery	5	52
26677	2020-01-26 16:10:31	2020-01-26	14	[{"id_menu":2,"count":1}]	5538	pick-up	0	14
26678	2020-01-26 16:20:04	2020-01-26	8	[{"id_menu":5,"count":1}]	3385	pick-up	0	8
26679	2020-01-26 16:23:42	2020-01-26	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2416	pick-up	0	22
26680	2020-01-26 16:28:55	2020-01-26	12	[{"id_menu":1,"count":1}]	2984	delivery	5	17
26681	2020-01-26 16:30:17	2020-01-26	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	6247	pick-up	0	21
26682	2020-01-26 16:32:46	2020-01-26	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	10426	delivery	5	27
26683	2020-01-26 16:36:34	2020-01-26	12	[{"id_menu":1,"count":1}]	10457	delivery	5	17
26684	2020-01-26 16:38:13	2020-01-26	12	[{"id_menu":3,"count":1}]	4577	pick-up	0	12
26685	2020-01-26 16:44:53	2020-01-26	14	[{"id_menu":2,"count":3}]	10391	delivery	5	19
26686	2020-01-26 16:51:22	2020-01-26	12	[{"id_menu":1,"count":1}]	9125	pick-up	0	12
26687	2020-01-26 16:59:36	2020-01-26	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	10401	delivery	5	25
26688	2020-01-26 16:59:59	2020-01-26	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3628	pick-up	0	26
26689	2020-01-26 17:04:16	2020-01-26	14	[{"id_menu":2,"count":1}]	7094	pick-up	0	14
26690	2020-01-26 17:09:05	2020-01-26	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9120	delivery	5	31
26691	2020-01-26 17:14:45	2020-01-26	12	[{"id_menu":1,"count":1}]	4546	pick-up	0	12
26692	2020-01-26 17:22:27	2020-01-26	17	[{"id_menu":4,"count":1}]	10414	delivery	5	22
26693	2020-01-26 17:25:46	2020-01-26	8	[{"id_menu":5,"count":1}]	9319	delivery	5	13
26694	2020-01-26 17:26:05	2020-01-26	12	[{"id_menu":1,"count":1}]	9474	delivery	5	17
26695	2020-01-26 17:26:49	2020-01-26	14	[{"id_menu":2,"count":1}]	1306	pick-up	0	14
26696	2020-01-26 17:31:22	2020-01-26	17	[{"id_menu":4,"count":1}]	9518	delivery	5	22
26697	2020-01-26 17:35:24	2020-01-26	9	[{"id_menu":7,"count":1}]	5997	delivery	5	14
26698	2020-01-26 17:36:55	2020-01-26	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10472	delivery	5	30
26699	2020-01-26 17:41:50	2020-01-26	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4809	delivery	5	40
26700	2020-01-26 17:48:21	2020-01-26	30	[{"id_menu":1,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8273	delivery	5	35
26701	2020-01-26 17:55:43	2020-01-26	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	10404	delivery	5	25
26702	2020-01-26 17:59:09	2020-01-26	9	[{"id_menu":7,"count":1}]	4836	delivery	5	14
26703	2020-01-26 18:06:14	2020-01-26	14	[{"id_menu":2,"count":1}]	1065	delivery	5	19
26704	2020-01-26 18:18:15	2020-01-26	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	10433	delivery	5	43
26705	2020-01-26 18:25:04	2020-01-26	17	[{"id_menu":4,"count":2}]	3868	pick-up	0	17
26706	2020-01-26 18:26:34	2020-01-26	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	10462	delivery	5	40
26707	2020-01-26 18:27:25	2020-01-26	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4324	delivery	5	36
26708	2020-01-26 18:42:04	2020-01-26	12	[{"id_menu":1,"count":1}]	10385	pick-up	0	12
26709	2020-01-26 18:42:30	2020-01-26	17	[{"id_menu":4,"count":1}]	63	delivery	5	22
26710	2020-01-26 18:46:16	2020-01-26	17	[{"id_menu":4,"count":1}]	10400	pick-up	0	17
26711	2020-01-26 18:49:52	2020-01-26	12	[{"id_menu":1,"count":1}]	10442	delivery	5	17
26712	2020-01-26 18:56:04	2020-01-26	8	[{"id_menu":5,"count":1}]	4688	delivery	5	13
26713	2020-01-26 18:57:01	2020-01-26	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10383	pick-up	0	25
26714	2020-01-26 19:04:52	2020-01-26	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6101	pick-up	0	40
26715	2020-01-26 19:06:22	2020-01-26	9	[{"id_menu":7,"count":1}]	2277	pick-up	0	9
26716	2020-01-26 19:16:38	2020-01-26	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	10458	delivery	5	25
26717	2020-01-26 19:17:45	2020-01-26	14	[{"id_menu":2,"count":1}]	3871	pick-up	0	14
26718	2020-01-26 19:21:01	2020-01-26	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	10473	delivery	5	40
26719	2020-01-26 19:29:50	2020-01-26	12	[{"id_menu":3,"count":1}]	10466	delivery	5	17
26720	2020-01-26 19:32:28	2020-01-26	9	[{"id_menu":7,"count":1}]	8627	delivery	5	14
26721	2020-01-26 19:38:49	2020-01-26	9	[{"id_menu":6,"count":1}]	6979	delivery	5	14
26722	2020-01-26 19:57:26	2020-01-26	9	[{"id_menu":7,"count":1}]	10465	delivery	5	14
26723	2020-01-26 19:58:45	2020-01-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	10415	delivery	5	26
26724	2020-01-26 20:03:06	2020-01-26	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3692	delivery	5	43
26725	2020-01-26 20:06:37	2020-01-26	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	8244	delivery	5	37
26726	2020-01-26 20:07:18	2020-01-26	12	[{"id_menu":1,"count":1}]	646	delivery	5	17
26727	2020-01-26 20:08:41	2020-01-26	9	[{"id_menu":7,"count":1}]	2154	pick-up	0	9
26728	2020-01-26 20:15:28	2020-01-26	9	[{"id_menu":6,"count":1}]	9148	delivery	5	14
26729	2020-01-26 20:17:03	2020-01-26	12	[{"id_menu":3,"count":1}]	4086	delivery	5	17
26730	2020-01-26 20:20:00	2020-01-26	8	[{"id_menu":5,"count":1}]	5125	pick-up	0	8
26731	2020-01-26 20:31:06	2020-01-26	12	[{"id_menu":1,"count":1}]	2221	pick-up	0	12
26732	2020-01-26 20:35:18	2020-01-26	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	10463	delivery	5	34
26733	2020-01-26 20:41:25	2020-01-26	9	[{"id_menu":7,"count":1}]	2599	delivery	5	14
26734	2020-01-26 20:44:47	2020-01-26	9	[{"id_menu":7,"count":1}]	10393	pick-up	0	9
26735	2020-01-26 20:50:09	2020-01-26	8	[{"id_menu":5,"count":1}]	10440	delivery	5	13
26736	2020-01-26 21:00:07	2020-01-26	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	10449	delivery	5	26
26737	2020-01-26 21:00:40	2020-01-26	17	[{"id_menu":4,"count":1}]	10434	delivery	5	22
26738	2020-01-26 21:01:14	2020-01-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	7164	delivery	5	31
26739	2020-01-26 21:01:24	2020-01-26	12	[{"id_menu":1,"count":1}]	8900	delivery	5	17
26740	2020-01-26 21:04:03	2020-01-26	12	[{"id_menu":3,"count":1}]	10394	pick-up	0	12
26741	2020-01-26 21:04:35	2020-01-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	10461	delivery	5	28
26742	2020-01-26 21:23:55	2020-01-26	8	[{"id_menu":5,"count":1}]	10464	delivery	5	13
26743	2020-01-26 21:33:33	2020-01-26	14	[{"id_menu":2,"count":1}]	10439	delivery	5	19
26744	2020-01-26 21:39:00	2020-01-26	12	[{"id_menu":1,"count":1}]	10437	delivery	5	17
26745	2020-01-26 21:42:34	2020-01-26	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	9574	delivery	5	31
26746	2020-01-26 21:49:37	2020-01-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	10392	delivery	5	28
26747	2020-01-26 21:55:46	2020-01-26	17	[{"id_menu":4,"count":1}]	1904	pick-up	0	17
26748	2020-01-26 21:56:10	2020-01-26	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6865	delivery	5	40
26749	2020-01-26 22:05:50	2020-01-26	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	7227	delivery	5	40
26750	2020-01-26 22:10:45	2020-01-26	12	[{"id_menu":1,"count":1}]	10448	delivery	5	17
26751	2020-01-26 22:19:14	2020-01-26	17	[{"id_menu":4,"count":1}]	491	delivery	5	22
26752	2020-01-26 22:20:05	2020-01-26	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	6151	pick-up	0	41
26753	2020-01-26 22:21:37	2020-01-26	17	[{"id_menu":4,"count":1}]	9356	pick-up	0	17
26754	2020-01-26 22:22:02	2020-01-26	12	[{"id_menu":1,"count":1}]	27	delivery	5	17
26755	2020-01-26 22:25:47	2020-01-26	9	[{"id_menu":6,"count":1}]	669	delivery	5	14
26756	2020-01-26 22:28:39	2020-01-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10382	delivery	5	31
26757	2020-01-26 22:36:33	2020-01-26	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	1055	pick-up	0	18
26758	2020-01-26 22:36:36	2020-01-26	8	[{"id_menu":5,"count":1}]	6965	delivery	5	13
26759	2020-01-26 22:49:35	2020-01-26	12	[{"id_menu":3,"count":1}]	2299	pick-up	0	12
26760	2020-01-26 22:49:59	2020-01-26	8	[{"id_menu":5,"count":1}]	10460	delivery	5	13
26761	2020-01-26 22:52:51	2020-01-26	9	[{"id_menu":7,"count":1}]	5961	pick-up	0	9
26762	2020-01-26 22:55:53	2020-01-26	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10413	delivery	5	37
26763	2020-01-26 22:58:25	2020-01-26	8	[{"id_menu":5,"count":1}]	7901	delivery	5	13
26764	2020-01-26 23:08:53	2020-01-26	9	[{"id_menu":6,"count":1}]	10416	pick-up	0	9
26765	2020-01-26 23:10:11	2020-01-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10421	delivery	5	23
26766	2020-01-26 23:14:26	2020-01-26	9	[{"id_menu":7,"count":1}]	4431	delivery	5	14
26767	2020-01-26 23:16:38	2020-01-26	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	10412	pick-up	0	20
26768	2020-01-26 23:22:09	2020-01-26	12	[{"id_menu":1,"count":1}]	2276	pick-up	0	12
26769	2020-01-26 23:34:56	2020-01-26	12	[{"id_menu":3,"count":1}]	149	delivery	5	17
26770	2020-01-26 23:39:27	2020-01-26	9	[{"id_menu":7,"count":1}]	5292	delivery	5	14
26771	2020-01-26 23:41:18	2020-01-26	14	[{"id_menu":2,"count":1}]	3582	pick-up	0	14
26772	2020-01-26 23:44:15	2020-01-26	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5935	delivery	5	30
26773	2020-01-26 23:44:46	2020-01-26	17	[{"id_menu":4,"count":1}]	7069	pick-up	0	17
26774	2020-01-26 23:47:45	2020-01-26	17	[{"id_menu":4,"count":1}]	9466	delivery	5	22
26775	2020-01-26 23:49:49	2020-01-26	9	[{"id_menu":7,"count":1}]	10403	pick-up	0	9
26776	2020-01-26 23:53:11	2020-01-26	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1092	pick-up	0	31
26777	2020-01-27 00:14:07	2020-01-27	9	[{"id_menu":7,"count":1}]	9766	pick-up	0	9
26778	2020-01-27 00:14:38	2020-01-27	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":3}]	3796	delivery	5	22
26779	2020-01-27 00:18:20	2020-01-27	9	[{"id_menu":6,"count":1}]	338	pick-up	0	9
26780	2020-01-27 00:35:31	2020-01-27	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5054	delivery	5	40
26781	2020-01-27 00:50:53	2020-01-27	14	[{"id_menu":2,"count":1}]	5141	pick-up	0	14
26782	2020-01-27 00:52:36	2020-01-27	9	[{"id_menu":7,"count":1}]	10501	delivery	5	14
26783	2020-01-27 00:57:39	2020-01-27	9	[{"id_menu":6,"count":1}]	10505	delivery	5	14
26784	2020-01-27 00:59:23	2020-01-27	9	[{"id_menu":7,"count":1}]	10180	delivery	5	14
26785	2020-01-27 01:06:32	2020-01-27	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	6987	pick-up	0	24
26786	2020-01-27 01:13:59	2020-01-27	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	8352	delivery	5	26
26787	2020-01-27 01:16:20	2020-01-27	14	[{"id_menu":2,"count":1}]	1489	pick-up	0	14
26788	2020-01-27 01:23:26	2020-01-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2531	pick-up	0	17
26789	2020-01-27 01:28:28	2020-01-27	12	[{"id_menu":1,"count":1}]	10554	delivery	5	17
26790	2020-01-27 01:31:52	2020-01-27	14	[{"id_menu":2,"count":1}]	399	pick-up	0	14
26791	2020-01-27 01:39:39	2020-01-27	9	[{"id_menu":7,"count":1}]	3894	pick-up	0	9
26792	2020-01-27 01:53:41	2020-01-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2075	delivery	5	36
26793	2020-01-27 02:05:18	2020-01-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6108	delivery	5	23
26794	2020-01-27 02:08:49	2020-01-27	9	[{"id_menu":6,"count":1}]	10539	pick-up	0	9
26795	2020-01-27 02:13:40	2020-01-27	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	10527	delivery	5	22
26796	2020-01-27 02:14:03	2020-01-27	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4139	delivery	5	40
26797	2020-01-27 02:26:27	2020-01-27	12	[{"id_menu":1,"count":1}]	9014	delivery	5	17
26798	2020-01-27 02:38:46	2020-01-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10523	pick-up	0	17
26799	2020-01-27 02:47:10	2020-01-27	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2897	pick-up	0	20
26800	2020-01-27 02:50:55	2020-01-27	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1055	delivery	5	26
26801	2020-01-27 02:52:14	2020-01-27	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7050	pick-up	0	25
26802	2020-01-27 02:54:03	2020-01-27	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	8010	delivery	5	31
26803	2020-01-27 03:01:32	2020-01-27	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10536	delivery	5	34
26804	2020-01-27 03:05:21	2020-01-27	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10525	pick-up	0	26
26805	2020-01-27 03:08:26	2020-01-27	8	[{"id_menu":5,"count":1}]	6163	pick-up	0	8
26806	2020-01-27 03:09:07	2020-01-27	17	[{"id_menu":4,"count":1}]	2200	pick-up	0	17
26807	2020-01-27 03:12:45	2020-01-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10495	delivery	5	23
26808	2020-01-27 03:26:09	2020-01-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3366	pick-up	0	17
26809	2020-01-27 04:00:09	2020-01-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	92	pick-up	0	31
26810	2020-01-27 04:14:06	2020-01-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	6429	delivery	5	22
26811	2020-01-27 04:18:49	2020-01-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4144	pick-up	0	17
26812	2020-01-27 04:20:52	2020-01-27	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	10323	delivery	5	22
26813	2020-01-27 04:24:11	2020-01-27	17	[{"id_menu":4,"count":1}]	7619	delivery	5	22
26814	2020-01-27 04:54:41	2020-01-27	14	[{"id_menu":2,"count":1}]	10116	delivery	5	19
26815	2020-01-27 04:59:13	2020-01-27	9	[{"id_menu":7,"count":1}]	10534	delivery	5	14
26816	2020-01-27 05:11:16	2020-01-27	17	[{"id_menu":4,"count":1}]	3700	delivery	5	22
26817	2020-01-27 05:12:09	2020-01-27	9	[{"id_menu":6,"count":1}]	10556	delivery	5	14
26818	2020-01-27 05:15:31	2020-01-27	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	701	pick-up	0	38
26819	2020-01-27 05:33:35	2020-01-27	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3524	pick-up	0	40
26820	2020-01-27 05:34:21	2020-01-27	17	[{"id_menu":4,"count":2}]	1115	pick-up	0	17
26821	2020-01-27 05:36:29	2020-01-27	12	[{"id_menu":3,"count":1}]	1897	delivery	5	17
26822	2020-01-27 05:48:32	2020-01-27	17	[{"id_menu":4,"count":1}]	8323	delivery	5	22
26823	2020-01-27 06:05:12	2020-01-27	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	8057	delivery	5	25
26824	2020-01-27 06:12:56	2020-01-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	10517	delivery	5	36
26825	2020-01-27 06:15:09	2020-01-27	9	[{"id_menu":7,"count":1}]	1834	pick-up	0	9
26826	2020-01-27 06:18:57	2020-01-27	12	[{"id_menu":1,"count":1}]	5768	delivery	5	17
26827	2020-01-27 06:24:01	2020-01-27	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	10486	delivery	5	23
26828	2020-01-27 06:33:16	2020-01-27	14	[{"id_menu":2,"count":1}]	9513	delivery	5	19
26829	2020-01-27 06:42:22	2020-01-27	12	[{"id_menu":3,"count":1}]	6195	pick-up	0	12
26830	2020-01-27 06:47:33	2020-01-27	9	[{"id_menu":7,"count":1}]	6164	pick-up	0	9
26831	2020-01-27 06:59:15	2020-01-27	8	[{"id_menu":5,"count":1}]	4824	delivery	5	13
26832	2020-01-27 07:00:15	2020-01-27	9	[{"id_menu":7,"count":1}]	10496	pick-up	0	9
26833	2020-01-27 07:10:56	2020-01-27	9	[{"id_menu":6,"count":1}]	2669	delivery	5	14
26834	2020-01-27 07:18:39	2020-01-27	12	[{"id_menu":1,"count":1}]	10532	delivery	5	17
26835	2020-01-27 07:27:48	2020-01-27	8	[{"id_menu":5,"count":1}]	10519	delivery	5	13
26836	2020-01-27 07:30:59	2020-01-27	8	[{"id_menu":5,"count":1}]	10487	delivery	5	13
26837	2020-01-27 07:33:57	2020-01-27	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	10542	delivery	5	34
26838	2020-01-27 07:41:42	2020-01-27	14	[{"id_menu":2,"count":1}]	907	delivery	5	19
26839	2020-01-27 07:47:20	2020-01-27	12	[{"id_menu":3,"count":1}]	992	delivery	5	17
26840	2020-01-27 08:00:36	2020-01-27	9	[{"id_menu":7,"count":1}]	10562	delivery	5	14
26841	2020-01-27 08:02:46	2020-01-27	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1166	pick-up	0	26
26842	2020-01-27 08:12:18	2020-01-27	9	[{"id_menu":6,"count":1}]	7934	pick-up	0	9
26843	2020-01-27 08:13:42	2020-01-27	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	721	pick-up	0	23
26844	2020-01-27 08:15:26	2020-01-27	12	[{"id_menu":3,"count":2}]	1226	pick-up	0	12
26845	2020-01-27 08:23:54	2020-01-27	8	[{"id_menu":5,"count":1}]	2525	delivery	5	13
26846	2020-01-27 08:25:28	2020-01-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4867	delivery	5	22
26847	2020-01-27 08:32:16	2020-01-27	14	[{"id_menu":2,"count":1}]	4502	delivery	5	19
26848	2020-01-27 08:33:04	2020-01-27	9	[{"id_menu":6,"count":1}]	10522	delivery	5	14
26849	2020-01-27 08:39:06	2020-01-27	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	10490	delivery	5	48
26850	2020-01-27 08:54:02	2020-01-27	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	138	pick-up	0	46
26851	2020-01-27 09:00:27	2020-01-27	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	10507	delivery	5	22
26852	2020-01-27 09:03:03	2020-01-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3565	delivery	5	22
26853	2020-01-27 09:10:47	2020-01-27	17	[{"id_menu":4,"count":2}]	413	pick-up	0	17
26854	2020-01-27 09:15:15	2020-01-27	9	[{"id_menu":7,"count":1}]	10484	delivery	5	14
26855	2020-01-27 09:15:49	2020-01-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1144	delivery	5	22
26856	2020-01-27 09:21:16	2020-01-27	8	[{"id_menu":5,"count":1}]	10561	delivery	5	13
26857	2020-01-27 09:22:30	2020-01-27	17	[{"id_menu":4,"count":1}]	932	pick-up	0	17
26858	2020-01-27 09:34:32	2020-01-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	10479	pick-up	0	23
26859	2020-01-27 10:05:35	2020-01-27	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9012	delivery	5	34
26860	2020-01-27 10:12:14	2020-01-27	9	[{"id_menu":6,"count":1}]	10494	delivery	5	14
26861	2020-01-27 10:35:52	2020-01-27	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10502	delivery	5	34
26862	2020-01-27 10:40:56	2020-01-27	8	[{"id_menu":5,"count":1}]	634	pick-up	0	8
26863	2020-01-27 10:41:54	2020-01-27	9	[{"id_menu":7,"count":1}]	1640	delivery	5	14
26864	2020-01-27 10:50:59	2020-01-27	9	[{"id_menu":6,"count":1}]	8864	delivery	5	14
26865	2020-01-27 10:54:03	2020-01-27	14	[{"id_menu":2,"count":1}]	757	delivery	5	19
26866	2020-01-27 10:54:54	2020-01-27	9	[{"id_menu":6,"count":1}]	4605	delivery	5	14
26867	2020-01-27 11:05:35	2020-01-27	9	[{"id_menu":7,"count":1}]	5293	pick-up	0	9
26868	2020-01-27 11:21:20	2020-01-27	12	[{"id_menu":3,"count":1}]	5723	delivery	5	17
26869	2020-01-27 11:23:30	2020-01-27	9	[{"id_menu":6,"count":1}]	2398	delivery	5	14
26870	2020-01-27 11:31:21	2020-01-27	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	6154	delivery	5	26
26871	2020-01-27 11:43:08	2020-01-27	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	10488	delivery	5	26
26872	2020-01-27 11:48:18	2020-01-27	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	5818	delivery	5	26
26873	2020-01-27 11:59:02	2020-01-27	17	[{"id_menu":4,"count":1}]	3395	pick-up	0	17
26874	2020-01-27 12:01:48	2020-01-27	9	[{"id_menu":7,"count":1}]	281	pick-up	0	9
26875	2020-01-27 12:03:09	2020-01-27	12	[{"id_menu":3,"count":1}]	1664	pick-up	0	12
26876	2020-01-27 12:09:53	2020-01-27	12	[{"id_menu":1,"count":1}]	1044	pick-up	0	12
26877	2020-01-27 12:18:08	2020-01-27	9	[{"id_menu":7,"count":1}]	8727	delivery	5	14
26878	2020-01-27 12:25:19	2020-01-27	12	[{"id_menu":1,"count":1}]	235	delivery	5	17
26879	2020-01-27 12:42:36	2020-01-27	12	[{"id_menu":1,"count":2}]	9308	pick-up	0	12
26880	2020-01-27 12:53:36	2020-01-27	9	[{"id_menu":7,"count":1}]	7646	delivery	5	14
26881	2020-01-27 12:57:33	2020-01-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6297	pick-up	0	17
26882	2020-01-27 12:58:05	2020-01-27	9	[{"id_menu":7,"count":1}]	10557	delivery	5	14
26883	2020-01-27 13:09:34	2020-01-27	9	[{"id_menu":7,"count":1}]	3445	delivery	5	14
26884	2020-01-27 13:12:45	2020-01-27	12	[{"id_menu":1,"count":1}]	10480	pick-up	0	12
26885	2020-01-27 13:23:28	2020-01-27	14	[{"id_menu":2,"count":1}]	6790	delivery	5	19
26886	2020-01-27 13:35:16	2020-01-27	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	6647	pick-up	0	22
26887	2020-01-27 13:41:47	2020-01-27	14	[{"id_menu":2,"count":1}]	1455	pick-up	0	14
26888	2020-01-27 13:45:45	2020-01-27	9	[{"id_menu":7,"count":1}]	10497	delivery	5	14
26889	2020-01-27 14:12:32	2020-01-27	17	[{"id_menu":4,"count":1}]	4075	delivery	5	22
26890	2020-01-27 14:13:13	2020-01-27	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8410	delivery	5	37
26891	2020-01-27 14:15:26	2020-01-27	9	[{"id_menu":7,"count":1}]	10524	delivery	5	14
26892	2020-01-27 14:38:12	2020-01-27	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1914	pick-up	0	39
26893	2020-01-27 14:58:22	2020-01-27	14	[{"id_menu":2,"count":1}]	4998	delivery	5	19
26894	2020-01-27 15:06:08	2020-01-27	9	[{"id_menu":6,"count":1}]	10498	delivery	5	14
26895	2020-01-27 15:07:38	2020-01-27	17	[{"id_menu":4,"count":1}]	10550	delivery	5	22
26896	2020-01-27 15:26:08	2020-01-27	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	9836	delivery	5	27
26897	2020-01-27 15:30:37	2020-01-27	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	9736	delivery	5	38
26898	2020-01-27 15:45:06	2020-01-27	9	[{"id_menu":6,"count":1}]	2099	pick-up	0	9
26899	2020-01-27 16:14:52	2020-01-27	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	5846	delivery	5	26
26900	2020-01-27 16:22:32	2020-01-27	9	[{"id_menu":7,"count":1}]	10520	delivery	5	14
26901	2020-01-27 16:33:00	2020-01-27	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	10526	pick-up	0	23
26902	2020-01-27 16:48:38	2020-01-27	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	10492	delivery	5	23
26903	2020-01-27 17:00:25	2020-01-27	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5523	delivery	5	43
26904	2020-01-27 17:07:46	2020-01-27	9	[{"id_menu":7,"count":1}]	10533	delivery	5	14
26905	2020-01-27 17:15:49	2020-01-27	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	10103	delivery	5	39
26906	2020-01-27 17:19:28	2020-01-27	9	[{"id_menu":6,"count":1}]	2119	pick-up	0	9
26907	2020-01-27 17:27:08	2020-01-27	14	[{"id_menu":2,"count":1}]	20	pick-up	0	14
26908	2020-01-27 17:34:45	2020-01-27	12	[{"id_menu":3,"count":1}]	6167	delivery	5	17
26909	2020-01-27 17:36:52	2020-01-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3711	pick-up	0	23
26910	2020-01-27 18:32:24	2020-01-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	828	delivery	5	28
26911	2020-01-27 19:46:45	2020-01-27	8	[{"id_menu":5,"count":1}]	10491	delivery	5	13
26912	2020-01-27 19:47:50	2020-01-27	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	5380	delivery	5	28
26913	2020-01-27 20:00:04	2020-01-27	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	10543	delivery	5	31
26914	2020-01-27 20:01:58	2020-01-27	12	[{"id_menu":3,"count":1}]	10563	delivery	5	17
26915	2020-01-27 20:02:14	2020-01-27	9	[{"id_menu":6,"count":1}]	4982	delivery	5	14
26916	2020-01-27 20:05:24	2020-01-27	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1087	pick-up	0	38
26917	2020-01-27 20:20:08	2020-01-27	17	[{"id_menu":4,"count":1}]	9288	pick-up	0	17
26918	2020-01-27 20:22:36	2020-01-27	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	10478	delivery	5	26
26919	2020-01-27 20:28:25	2020-01-27	14	[{"id_menu":2,"count":1}]	10511	delivery	5	19
26920	2020-01-27 20:40:18	2020-01-27	9	[{"id_menu":7,"count":3}]	10544	delivery	5	14
26921	2020-01-27 20:45:02	2020-01-27	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	3000	delivery	5	29
26922	2020-01-27 20:51:10	2020-01-27	9	[{"id_menu":6,"count":1}]	7746	delivery	5	14
26923	2020-01-27 21:06:36	2020-01-27	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	7675	delivery	5	25
26924	2020-01-27 21:25:17	2020-01-27	17	[{"id_menu":4,"count":1}]	10548	pick-up	0	17
26925	2020-01-27 21:37:21	2020-01-27	12	[{"id_menu":1,"count":1}]	2672	pick-up	0	12
26926	2020-01-27 21:39:43	2020-01-27	9	[{"id_menu":6,"count":1}]	8873	delivery	5	14
26927	2020-01-27 21:43:01	2020-01-27	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	10529	delivery	5	40
26928	2020-01-27 21:43:11	2020-01-27	12	[{"id_menu":1,"count":1}]	10506	delivery	5	17
26929	2020-01-27 21:50:41	2020-01-27	12	[{"id_menu":3,"count":1}]	10555	pick-up	0	12
26930	2020-01-27 21:55:35	2020-01-27	9	[{"id_menu":7,"count":1}]	10489	delivery	5	14
26931	2020-01-27 22:02:32	2020-01-27	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2828	pick-up	0	29
26932	2020-01-27 22:03:30	2020-01-27	12	[{"id_menu":1,"count":1}]	9565	delivery	5	17
26933	2020-01-27 22:17:32	2020-01-27	12	[{"id_menu":3,"count":1}]	3509	pick-up	0	12
26934	2020-01-27 22:20:49	2020-01-27	9	[{"id_menu":7,"count":1}]	10516	delivery	5	14
26935	2020-01-27 22:20:55	2020-01-27	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	158	pick-up	0	21
26936	2020-01-27 22:22:50	2020-01-27	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1188	pick-up	0	23
26937	2020-01-27 22:44:31	2020-01-27	9	[{"id_menu":7,"count":1}]	5874	delivery	5	14
26938	2020-01-27 22:46:21	2020-01-27	17	[{"id_menu":4,"count":1}]	1528	delivery	5	22
26939	2020-01-27 22:56:28	2020-01-27	9	[{"id_menu":6,"count":1}]	2310	pick-up	0	9
26940	2020-01-27 22:58:24	2020-01-27	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10515	delivery	5	45
26941	2020-01-27 23:02:09	2020-01-27	17	[{"id_menu":4,"count":1}]	9523	pick-up	0	17
26942	2020-01-27 23:02:12	2020-01-27	9	[{"id_menu":7,"count":1}]	10541	delivery	5	14
26943	2020-01-27 23:10:27	2020-01-27	14	[{"id_menu":2,"count":1}]	4463	pick-up	0	14
26944	2020-01-27 23:22:00	2020-01-27	9	[{"id_menu":6,"count":1}]	1036	pick-up	0	9
26945	2020-01-27 23:36:22	2020-01-27	17	[{"id_menu":4,"count":1}]	8358	pick-up	0	17
26946	2020-01-27 23:41:01	2020-01-27	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10518	delivery	5	36
26947	2020-01-27 23:42:09	2020-01-27	9	[{"id_menu":6,"count":1}]	1519	delivery	5	14
26948	2020-01-27 23:44:42	2020-01-27	12	[{"id_menu":1,"count":1}]	6548	pick-up	0	12
26949	2020-01-27 23:53:57	2020-01-27	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10512	delivery	5	30
26950	2020-01-28 00:01:21	2020-01-28	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6032	delivery	5	36
26951	2020-01-28 00:07:02	2020-01-28	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	10642	delivery	5	29
26952	2020-01-28 00:27:54	2020-01-28	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7526	delivery	5	43
26953	2020-01-28 00:50:55	2020-01-28	12	[{"id_menu":1,"count":1}]	10575	delivery	5	17
26954	2020-01-28 00:55:38	2020-01-28	14	[{"id_menu":2,"count":1}]	5790	delivery	5	19
26955	2020-01-28 00:56:53	2020-01-28	12	[{"id_menu":3,"count":1}]	44	pick-up	0	12
26956	2020-01-28 01:03:17	2020-01-28	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	10643	delivery	5	26
26957	2020-01-28 01:04:37	2020-01-28	17	[{"id_menu":4,"count":1}]	8809	delivery	5	22
26958	2020-01-28 01:07:48	2020-01-28	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	950	delivery	5	30
26959	2020-01-28 01:16:23	2020-01-28	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10194	pick-up	0	34
26960	2020-01-28 01:17:29	2020-01-28	9	[{"id_menu":7,"count":1}]	7059	delivery	5	14
26961	2020-01-28 01:37:53	2020-01-28	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	4607	pick-up	0	20
26962	2020-01-28 01:56:36	2020-01-28	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	10597	delivery	5	28
26963	2020-01-28 02:03:09	2020-01-28	9	[{"id_menu":7,"count":1}]	4187	delivery	5	14
26964	2020-01-28 02:03:48	2020-01-28	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	10605	delivery	5	23
26965	2020-01-28 02:04:27	2020-01-28	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	10609	delivery	5	31
26966	2020-01-28 02:16:25	2020-01-28	14	[{"id_menu":2,"count":1}]	6911	delivery	5	19
26967	2020-01-28 02:30:40	2020-01-28	12	[{"id_menu":1,"count":1}]	5310	delivery	5	17
26968	2020-01-28 02:31:39	2020-01-28	17	[{"id_menu":4,"count":1}]	10596	pick-up	0	17
26969	2020-01-28 02:31:50	2020-01-28	9	[{"id_menu":7,"count":1}]	7380	pick-up	0	9
26970	2020-01-28 02:41:14	2020-01-28	12	[{"id_menu":1,"count":1}]	6472	delivery	5	17
26971	2020-01-28 02:49:13	2020-01-28	9	[{"id_menu":6,"count":1}]	9492	delivery	5	14
26972	2020-01-28 02:49:17	2020-01-28	9	[{"id_menu":6,"count":1}]	7550	pick-up	0	9
26973	2020-01-28 02:58:12	2020-01-28	12	[{"id_menu":3,"count":1}]	9847	pick-up	0	12
26974	2020-01-28 03:05:20	2020-01-28	12	[{"id_menu":3,"count":1}]	2434	pick-up	0	12
26975	2020-01-28 03:15:36	2020-01-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	3813	delivery	5	31
26976	2020-01-28 03:16:22	2020-01-28	14	[{"id_menu":2,"count":1}]	5361	delivery	5	19
26977	2020-01-28 03:24:17	2020-01-28	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3546	delivery	5	34
26978	2020-01-28 03:49:08	2020-01-28	17	[{"id_menu":4,"count":1}]	64	delivery	5	22
26979	2020-01-28 03:55:46	2020-01-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8471	delivery	5	31
26980	2020-01-28 04:02:32	2020-01-28	12	[{"id_menu":1,"count":1}]	2778	delivery	5	17
26981	2020-01-28 04:24:38	2020-01-28	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1069	delivery	5	34
26982	2020-01-28 04:28:57	2020-01-28	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	7581	delivery	5	26
26983	2020-01-28 04:29:51	2020-01-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10586	pick-up	0	17
26984	2020-01-28 04:36:05	2020-01-28	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1304	pick-up	0	38
26985	2020-01-28 05:00:23	2020-01-28	17	[{"id_menu":4,"count":1}]	9995	pick-up	0	17
26986	2020-01-28 05:22:16	2020-01-28	9	[{"id_menu":6,"count":1}]	1479	delivery	5	14
26987	2020-01-28 05:29:07	2020-01-28	9	[{"id_menu":7,"count":3}]	10625	delivery	5	14
26988	2020-01-28 05:40:19	2020-01-28	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3684	delivery	5	46
26989	2020-01-28 05:40:53	2020-01-28	9	[{"id_menu":6,"count":1}]	8380	delivery	5	14
26990	2020-01-28 05:41:22	2020-01-28	12	[{"id_menu":3,"count":1}]	259	pick-up	0	12
26991	2020-01-28 05:45:51	2020-01-28	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2613	pick-up	0	21
26992	2020-01-28 05:51:04	2020-01-28	12	[{"id_menu":3,"count":1}]	654	pick-up	0	12
26993	2020-01-28 05:51:07	2020-01-28	17	[{"id_menu":4,"count":1}]	4465	pick-up	0	17
26994	2020-01-28 05:51:39	2020-01-28	12	[{"id_menu":1,"count":1}]	729	pick-up	0	12
26995	2020-01-28 06:04:50	2020-01-28	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	493	pick-up	0	35
26996	2020-01-28 06:05:28	2020-01-28	14	[{"id_menu":2,"count":1}]	10617	pick-up	0	14
26997	2020-01-28 06:10:27	2020-01-28	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	10595	delivery	5	40
26998	2020-01-28 06:15:29	2020-01-28	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10571	delivery	5	30
26999	2020-01-28 06:26:21	2020-01-28	17	[{"id_menu":4,"count":1}]	2941	delivery	5	22
27000	2020-01-28 06:27:31	2020-01-28	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	10591	delivery	5	26
27001	2020-01-28 06:29:16	2020-01-28	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6362	delivery	5	42
27002	2020-01-28 06:41:55	2020-01-28	12	[{"id_menu":1,"count":1}]	10644	delivery	5	17
27003	2020-01-28 06:42:53	2020-01-28	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	330	pick-up	0	29
27004	2020-01-28 07:08:10	2020-01-28	9	[{"id_menu":7,"count":2}]	2023	pick-up	0	9
27005	2020-01-28 07:14:01	2020-01-28	9	[{"id_menu":7,"count":1}]	1677	delivery	5	14
27006	2020-01-28 07:17:51	2020-01-28	17	[{"id_menu":4,"count":1}]	10316	delivery	5	22
27007	2020-01-28 07:17:53	2020-01-28	12	[{"id_menu":1,"count":1}]	10593	pick-up	0	12
27008	2020-01-28 07:31:54	2020-01-28	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	10623	delivery	5	36
27009	2020-01-28 07:40:19	2020-01-28	14	[{"id_menu":2,"count":1}]	1832	pick-up	0	14
27010	2020-01-28 07:41:18	2020-01-28	8	[{"id_menu":5,"count":1}]	8946	delivery	5	13
27011	2020-01-28 07:45:24	2020-01-28	8	[{"id_menu":5,"count":1}]	10628	delivery	5	13
27012	2020-01-28 07:47:01	2020-01-28	9	[{"id_menu":6,"count":1}]	9171	pick-up	0	9
27013	2020-01-28 07:52:00	2020-01-28	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	10203	pick-up	0	20
27014	2020-01-28 08:18:56	2020-01-28	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10576	delivery	5	30
27015	2020-01-28 08:30:18	2020-01-28	12	[{"id_menu":1,"count":1}]	10583	delivery	5	17
27016	2020-01-28 08:50:06	2020-01-28	12	[{"id_menu":3,"count":1}]	10649	pick-up	0	12
27017	2020-01-28 08:50:51	2020-01-28	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	78	pick-up	0	21
27018	2020-01-28 08:53:48	2020-01-28	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	10632	pick-up	0	22
27019	2020-01-28 08:56:33	2020-01-28	9	[{"id_menu":6,"count":1}]	1166	pick-up	0	9
27020	2020-01-28 08:56:44	2020-01-28	8	[{"id_menu":5,"count":1}]	10577	delivery	5	13
27021	2020-01-28 08:57:07	2020-01-28	9	[{"id_menu":7,"count":1}]	10648	pick-up	0	9
27022	2020-01-28 09:00:51	2020-01-28	9	[{"id_menu":6,"count":1}]	10611	delivery	5	14
27023	2020-01-28 09:04:18	2020-01-28	9	[{"id_menu":7,"count":1}]	6491	delivery	5	14
27024	2020-01-28 09:15:54	2020-01-28	9	[{"id_menu":7,"count":1}]	4688	pick-up	0	9
27025	2020-01-28 09:17:12	2020-01-28	17	[{"id_menu":4,"count":1}]	10590	delivery	5	22
27026	2020-01-28 09:24:55	2020-01-28	12	[{"id_menu":1,"count":1}]	8305	delivery	5	17
27027	2020-01-28 09:36:21	2020-01-28	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1592	pick-up	0	39
27028	2020-01-28 09:40:27	2020-01-28	17	[{"id_menu":4,"count":1}]	10580	pick-up	0	17
27029	2020-01-28 09:43:58	2020-01-28	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1922	delivery	5	38
27030	2020-01-28 09:54:35	2020-01-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	9261	delivery	5	22
27031	2020-01-28 09:59:25	2020-01-28	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	10566	delivery	5	36
27032	2020-01-28 10:11:13	2020-01-28	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	7431	delivery	5	36
27033	2020-01-28 10:21:32	2020-01-28	14	[{"id_menu":2,"count":1}]	912	pick-up	0	14
27034	2020-01-28 10:39:06	2020-01-28	8	[{"id_menu":5,"count":1}]	931	delivery	5	13
27035	2020-01-28 10:42:18	2020-01-28	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	10564	delivery	5	43
27036	2020-01-28 10:50:55	2020-01-28	12	[{"id_menu":1,"count":1}]	3480	pick-up	0	12
27037	2020-01-28 10:51:33	2020-01-28	14	[{"id_menu":2,"count":1}]	10569	delivery	5	19
27038	2020-01-28 11:05:04	2020-01-28	14	[{"id_menu":2,"count":1}]	2080	delivery	5	19
27039	2020-01-28 11:09:10	2020-01-28	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	10572	delivery	5	30
27040	2020-01-28 11:10:25	2020-01-28	9	[{"id_menu":6,"count":1}]	10618	delivery	5	14
27041	2020-01-28 11:16:22	2020-01-28	9	[{"id_menu":7,"count":1}]	1644	pick-up	0	9
27042	2020-01-28 11:28:45	2020-01-28	8	[{"id_menu":5,"count":1}]	796	delivery	5	13
27043	2020-01-28 11:38:54	2020-01-28	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2107	delivery	5	25
27044	2020-01-28 11:39:07	2020-01-28	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	10599	delivery	5	40
27045	2020-01-28 11:46:49	2020-01-28	17	[{"id_menu":4,"count":1}]	6703	pick-up	0	17
27046	2020-01-28 11:57:46	2020-01-28	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	9011	delivery	5	31
27047	2020-01-28 12:04:13	2020-01-28	17	[{"id_menu":4,"count":1}]	7834	pick-up	0	17
27048	2020-01-28 12:13:04	2020-01-28	14	[{"id_menu":2,"count":1}]	486	pick-up	0	14
27049	2020-01-28 12:32:58	2020-01-28	12	[{"id_menu":1,"count":1}]	6067	pick-up	0	12
27050	2020-01-28 12:40:00	2020-01-28	8	[{"id_menu":5,"count":1}]	5736	pick-up	0	8
27051	2020-01-28 12:42:57	2020-01-28	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7782	delivery	5	45
27052	2020-01-28 13:07:32	2020-01-28	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	398	delivery	5	40
27053	2020-01-28 13:09:50	2020-01-28	12	[{"id_menu":3,"count":1}]	10633	delivery	5	17
27054	2020-01-28 13:10:38	2020-01-28	9	[{"id_menu":7,"count":1}]	10610	delivery	5	14
27055	2020-01-28 13:18:12	2020-01-28	14	[{"id_menu":2,"count":1}]	5293	pick-up	0	14
27056	2020-01-28 13:18:28	2020-01-28	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	10635	delivery	5	27
27057	2020-01-28 13:20:55	2020-01-28	12	[{"id_menu":1,"count":1}]	3241	pick-up	0	12
27058	2020-01-28 13:28:57	2020-01-28	8	[{"id_menu":5,"count":1}]	10574	delivery	5	13
27059	2020-01-28 13:38:23	2020-01-28	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3111	pick-up	0	35
27060	2020-01-28 13:47:46	2020-01-28	12	[{"id_menu":1,"count":1}]	1242	pick-up	0	12
27061	2020-01-28 13:48:15	2020-01-28	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	10581	delivery	5	48
27062	2020-01-28 13:50:08	2020-01-28	9	[{"id_menu":6,"count":1}]	2694	delivery	5	14
27063	2020-01-28 14:20:08	2020-01-28	8	[{"id_menu":5,"count":2}]	3855	delivery	5	13
27064	2020-01-28 14:49:53	2020-01-28	17	[{"id_menu":4,"count":1}]	10483	pick-up	0	17
27065	2020-01-28 15:02:19	2020-01-28	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	10615	delivery	5	36
27066	2020-01-28 15:19:44	2020-01-28	9	[{"id_menu":7,"count":1}]	2850	pick-up	0	9
27067	2020-01-28 15:19:51	2020-01-28	12	[{"id_menu":3,"count":1}]	10629	delivery	5	17
27068	2020-01-28 15:21:46	2020-01-28	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	3570	delivery	5	36
27069	2020-01-28 15:23:47	2020-01-28	8	[{"id_menu":5,"count":1}]	10614	delivery	5	13
27070	2020-01-28 15:33:23	2020-01-28	17	[{"id_menu":4,"count":1}]	8146	pick-up	0	17
27071	2020-01-28 15:36:50	2020-01-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10620	delivery	5	31
27072	2020-01-28 15:39:32	2020-01-28	9	[{"id_menu":6,"count":1}]	10573	delivery	5	14
27073	2020-01-28 15:46:30	2020-01-28	8	[{"id_menu":5,"count":1}]	2101	pick-up	0	8
27074	2020-01-28 15:47:30	2020-01-28	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4390	delivery	5	40
27075	2020-01-28 15:47:34	2020-01-28	17	[{"id_menu":4,"count":1}]	5308	pick-up	0	17
27076	2020-01-28 15:51:52	2020-01-28	12	[{"id_menu":1,"count":1}]	10588	delivery	5	17
27077	2020-01-28 15:59:57	2020-01-28	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2889	pick-up	0	22
27078	2020-01-28 16:09:34	2020-01-28	17	[{"id_menu":4,"count":1}]	35	pick-up	0	17
27079	2020-01-28 16:11:36	2020-01-28	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1645	pick-up	0	29
27080	2020-01-28 16:11:40	2020-01-28	9	[{"id_menu":7,"count":1}]	4436	pick-up	0	9
27081	2020-01-28 16:13:21	2020-01-28	8	[{"id_menu":5,"count":1}]	4692	delivery	5	13
27082	2020-01-28 16:26:18	2020-01-28	17	[{"id_menu":4,"count":1}]	9346	delivery	5	22
27083	2020-01-28 16:31:47	2020-01-28	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2384	pick-up	0	29
27084	2020-01-28 16:34:47	2020-01-28	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	1442	pick-up	0	43
27085	2020-01-28 16:35:27	2020-01-28	17	[{"id_menu":4,"count":1}]	7140	delivery	5	22
27086	2020-01-28 16:37:12	2020-01-28	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	4356	delivery	5	26
27087	2020-01-28 16:46:34	2020-01-28	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10626	pick-up	0	51
27088	2020-01-28 16:49:52	2020-01-28	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1297	delivery	5	56
27089	2020-01-28 16:51:27	2020-01-28	8	[{"id_menu":5,"count":1}]	10592	pick-up	0	8
27090	2020-01-28 17:23:43	2020-01-28	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	10613	delivery	5	45
27091	2020-01-28 17:52:24	2020-01-28	14	[{"id_menu":2,"count":1}]	10616	delivery	5	19
27092	2020-01-28 17:56:55	2020-01-28	9	[{"id_menu":7,"count":1}]	2939	delivery	5	14
27093	2020-01-28 18:00:14	2020-01-28	9	[{"id_menu":6,"count":1}]	10612	delivery	5	14
27094	2020-01-28 18:16:24	2020-01-28	17	[{"id_menu":4,"count":2}]	10637	delivery	5	22
27095	2020-01-28 18:20:11	2020-01-28	12	[{"id_menu":3,"count":1}]	10326	delivery	5	17
27096	2020-01-28 18:28:01	2020-01-28	9	[{"id_menu":6,"count":1}]	7924	delivery	5	14
27097	2020-01-28 18:51:44	2020-01-28	9	[{"id_menu":6,"count":1}]	6975	pick-up	0	9
27098	2020-01-28 19:00:46	2020-01-28	8	[{"id_menu":5,"count":1}]	10621	delivery	5	13
27099	2020-01-28 19:01:16	2020-01-28	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	9874	delivery	5	26
27100	2020-01-28 19:07:58	2020-01-28	12	[{"id_menu":3,"count":1}]	10622	pick-up	0	12
27101	2020-01-28 19:09:56	2020-01-28	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	8177	delivery	5	29
27102	2020-01-28 19:19:07	2020-01-28	12	[{"id_menu":1,"count":1}]	8068	pick-up	0	12
27103	2020-01-28 19:27:21	2020-01-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10567	delivery	5	31
27104	2020-01-28 19:34:07	2020-01-28	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	472	delivery	5	31
27105	2020-01-28 19:43:31	2020-01-28	8	[{"id_menu":5,"count":2}]	10631	pick-up	0	8
27106	2020-01-28 19:46:31	2020-01-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	10627	delivery	5	23
27107	2020-01-28 20:03:31	2020-01-28	9	[{"id_menu":6,"count":1}]	1467	delivery	5	14
27108	2020-01-28 20:05:16	2020-01-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7821	delivery	5	23
27109	2020-01-28 20:21:23	2020-01-28	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10602	delivery	5	36
27110	2020-01-28 20:28:59	2020-01-28	17	[{"id_menu":4,"count":1}]	10579	pick-up	0	17
27111	2020-01-28 20:37:49	2020-01-28	8	[{"id_menu":5,"count":1}]	10624	delivery	5	13
27112	2020-01-28 20:42:18	2020-01-28	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2668	pick-up	0	26
27113	2020-01-28 20:45:22	2020-01-28	9	[{"id_menu":7,"count":1}]	10634	delivery	5	14
27114	2020-01-28 20:46:48	2020-01-28	9	[{"id_menu":6,"count":1}]	7686	delivery	5	14
27115	2020-01-28 20:52:42	2020-01-28	12	[{"id_menu":1,"count":1}]	10606	pick-up	0	12
27116	2020-01-28 21:08:19	2020-01-28	14	[{"id_menu":2,"count":1}]	8584	delivery	5	19
27117	2020-01-28 21:09:15	2020-01-28	14	[{"id_menu":2,"count":1}]	10582	delivery	5	19
27118	2020-01-28 21:21:59	2020-01-28	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	946	pick-up	0	41
27119	2020-01-28 21:27:02	2020-01-28	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	10007	delivery	5	25
27120	2020-01-28 21:37:40	2020-01-28	17	[{"id_menu":4,"count":1}]	7678	pick-up	0	17
27121	2020-01-28 21:45:44	2020-01-28	14	[{"id_menu":2,"count":1}]	10607	delivery	5	19
27122	2020-01-28 21:46:38	2020-01-28	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8815	pick-up	0	25
27123	2020-01-28 21:53:14	2020-01-28	8	[{"id_menu":5,"count":1}]	2282	delivery	5	13
27124	2020-01-28 22:19:09	2020-01-28	9	[{"id_menu":7,"count":1}]	643	pick-up	0	9
27125	2020-01-28 22:22:09	2020-01-28	12	[{"id_menu":1,"count":1}]	4929	delivery	5	17
27126	2020-01-28 22:33:05	2020-01-28	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	847	delivery	5	51
27127	2020-01-28 22:53:28	2020-01-28	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	10639	delivery	5	25
27128	2020-01-28 23:01:12	2020-01-28	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	8700	pick-up	0	20
27129	2020-01-28 23:07:09	2020-01-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	8546	pick-up	0	23
27130	2020-01-28 23:09:09	2020-01-28	17	[{"id_menu":4,"count":1}]	1507	pick-up	0	17
27131	2020-01-28 23:11:31	2020-01-28	9	[{"id_menu":6,"count":1}]	5554	delivery	5	14
27132	2020-01-28 23:29:13	2020-01-28	14	[{"id_menu":2,"count":1}]	6394	pick-up	0	14
27133	2020-01-28 23:34:26	2020-01-28	9	[{"id_menu":6,"count":1}]	7410	delivery	5	14
27134	2020-01-28 23:46:15	2020-01-28	9	[{"id_menu":6,"count":1}]	5677	delivery	5	14
27135	2020-01-28 23:47:34	2020-01-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10647	delivery	5	23
27136	2020-01-29 00:01:00	2020-01-29	9	[{"id_menu":6,"count":1}]	10013	delivery	5	14
27137	2020-01-29 00:02:06	2020-01-29	9	[{"id_menu":6,"count":1}]	6920	delivery	5	14
27138	2020-01-29 00:06:03	2020-01-29	8	[{"id_menu":5,"count":1}]	3812	delivery	5	13
27139	2020-01-29 00:08:38	2020-01-29	14	[{"id_menu":2,"count":1}]	10691	delivery	5	19
27140	2020-01-29 00:11:14	2020-01-29	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	7530	delivery	5	26
27141	2020-01-29 00:17:44	2020-01-29	9	[{"id_menu":6,"count":1}]	10711	delivery	5	14
27142	2020-01-29 00:19:41	2020-01-29	12	[{"id_menu":1,"count":1}]	806	delivery	5	17
27143	2020-01-29 00:21:51	2020-01-29	9	[{"id_menu":6,"count":3}]	6771	delivery	5	14
27144	2020-01-29 00:35:56	2020-01-29	9	[{"id_menu":7,"count":1}]	10687	delivery	5	14
27145	2020-01-29 00:40:47	2020-01-29	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":2}]	10656	delivery	5	26
27146	2020-01-29 00:58:30	2020-01-29	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	10653	delivery	5	40
27147	2020-01-29 00:58:36	2020-01-29	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	10714	delivery	5	31
27148	2020-01-29 01:00:22	2020-01-29	9	[{"id_menu":7,"count":1}]	9554	delivery	5	14
27149	2020-01-29 01:05:31	2020-01-29	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7508	delivery	5	54
27150	2020-01-29 01:11:40	2020-01-29	14	[{"id_menu":2,"count":1}]	6757	delivery	5	19
27151	2020-01-29 01:23:43	2020-01-29	12	[{"id_menu":1,"count":1}]	9296	delivery	5	17
27152	2020-01-29 01:24:27	2020-01-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1529	pick-up	0	21
27153	2020-01-29 01:25:48	2020-01-29	12	[{"id_menu":1,"count":1}]	10651	delivery	5	17
27154	2020-01-29 01:27:45	2020-01-29	9	[{"id_menu":7,"count":1}]	10405	delivery	5	14
27155	2020-01-29 01:28:21	2020-01-29	12	[{"id_menu":3,"count":1}]	2950	pick-up	0	12
27156	2020-01-29 01:39:29	2020-01-29	12	[{"id_menu":3,"count":1}]	3493	delivery	5	17
27157	2020-01-29 01:40:20	2020-01-29	12	[{"id_menu":3,"count":1}]	6716	delivery	5	17
27158	2020-01-29 01:41:52	2020-01-29	12	[{"id_menu":1,"count":1}]	10719	delivery	5	17
27159	2020-01-29 01:47:00	2020-01-29	8	[{"id_menu":5,"count":1}]	3736	delivery	5	13
27160	2020-01-29 01:52:55	2020-01-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	10747	delivery	5	31
27161	2020-01-29 02:02:39	2020-01-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10673	delivery	5	23
27162	2020-01-29 02:14:30	2020-01-29	9	[{"id_menu":6,"count":1}]	694	delivery	5	14
27163	2020-01-29 02:18:22	2020-01-29	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	9264	delivery	5	26
27164	2020-01-29 02:18:44	2020-01-29	8	[{"id_menu":5,"count":1}]	2690	delivery	5	13
27165	2020-01-29 02:30:34	2020-01-29	14	[{"id_menu":2,"count":1}]	6341	delivery	5	19
27166	2020-01-29 02:35:04	2020-01-29	14	[{"id_menu":2,"count":1}]	10183	pick-up	0	14
27167	2020-01-29 02:35:59	2020-01-29	9	[{"id_menu":6,"count":1}]	5368	delivery	5	14
27168	2020-01-29 02:40:44	2020-01-29	8	[{"id_menu":5,"count":1}]	6593	delivery	5	13
27169	2020-01-29 02:42:16	2020-01-29	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	8110	delivery	5	40
27170	2020-01-29 02:43:17	2020-01-29	17	[{"id_menu":4,"count":1}]	10706	pick-up	0	17
27171	2020-01-29 02:48:53	2020-01-29	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2557	pick-up	0	31
27172	2020-01-29 02:52:06	2020-01-29	12	[{"id_menu":1,"count":1}]	6183	pick-up	0	12
27173	2020-01-29 02:58:59	2020-01-29	9	[{"id_menu":6,"count":1}]	10692	pick-up	0	9
27174	2020-01-29 03:01:29	2020-01-29	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10730	delivery	5	37
27175	2020-01-29 03:06:31	2020-01-29	12	[{"id_menu":1,"count":1}]	10735	pick-up	0	12
27176	2020-01-29 03:06:48	2020-01-29	17	[{"id_menu":4,"count":1}]	1296	delivery	5	22
27177	2020-01-29 03:07:06	2020-01-29	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1627	pick-up	0	26
27178	2020-01-29 03:16:34	2020-01-29	14	[{"id_menu":2,"count":1}]	1597	pick-up	0	14
27179	2020-01-29 03:19:44	2020-01-29	12	[{"id_menu":3,"count":1}]	2276	pick-up	0	12
27180	2020-01-29 03:27:40	2020-01-29	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	9071	delivery	5	26
27181	2020-01-29 03:35:21	2020-01-29	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10693	delivery	5	35
27182	2020-01-29 03:57:04	2020-01-29	9	[{"id_menu":7,"count":1}]	10677	delivery	5	14
27183	2020-01-29 03:57:24	2020-01-29	9	[{"id_menu":6,"count":1}]	10654	delivery	5	14
27184	2020-01-29 03:59:52	2020-01-29	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	2944	pick-up	0	35
27185	2020-01-29 04:01:22	2020-01-29	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2109	delivery	5	35
27186	2020-01-29 04:03:53	2020-01-29	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10723	delivery	5	46
27187	2020-01-29 04:04:18	2020-01-29	12	[{"id_menu":1,"count":1}]	10708	pick-up	0	12
27188	2020-01-29 04:05:08	2020-01-29	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	10722	delivery	5	23
27189	2020-01-29 04:07:18	2020-01-29	12	[{"id_menu":1,"count":1}]	10663	pick-up	0	12
27190	2020-01-29 04:14:01	2020-01-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10685	delivery	5	22
27191	2020-01-29 04:21:34	2020-01-29	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7987	delivery	5	39
27192	2020-01-29 04:21:57	2020-01-29	14	[{"id_menu":2,"count":1}]	5823	delivery	5	19
27193	2020-01-29 04:30:50	2020-01-29	9	[{"id_menu":6,"count":1}]	10737	delivery	5	14
27194	2020-01-29 04:31:55	2020-01-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	2362	delivery	5	28
27195	2020-01-29 04:33:26	2020-01-29	17	[{"id_menu":4,"count":1}]	10721	delivery	5	22
27196	2020-01-29 04:43:54	2020-01-29	12	[{"id_menu":3,"count":1}]	10696	delivery	5	17
27197	2020-01-29 04:48:52	2020-01-29	9	[{"id_menu":6,"count":1}]	7921	pick-up	0	9
27198	2020-01-29 04:51:10	2020-01-29	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10686	delivery	5	45
27199	2020-01-29 05:21:41	2020-01-29	8	[{"id_menu":5,"count":1}]	4594	delivery	5	13
27200	2020-01-29 05:23:08	2020-01-29	9	[{"id_menu":7,"count":1}]	2743	delivery	5	14
27201	2020-01-29 05:27:59	2020-01-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	10140	pick-up	0	21
27202	2020-01-29 05:39:28	2020-01-29	8	[{"id_menu":5,"count":1}]	10674	pick-up	0	8
27203	2020-01-29 05:50:48	2020-01-29	8	[{"id_menu":5,"count":1}]	10565	delivery	5	13
27204	2020-01-29 05:51:27	2020-01-29	9	[{"id_menu":7,"count":1}]	10699	delivery	5	14
27205	2020-01-29 05:51:33	2020-01-29	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	7924	delivery	5	38
27206	2020-01-29 05:54:05	2020-01-29	9	[{"id_menu":7,"count":1}]	559	delivery	5	14
27207	2020-01-29 05:55:05	2020-01-29	9	[{"id_menu":6,"count":1}]	1232	delivery	5	14
27208	2020-01-29 05:55:13	2020-01-29	17	[{"id_menu":4,"count":1}]	8755	pick-up	0	17
27209	2020-01-29 05:57:14	2020-01-29	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10208	delivery	5	40
27210	2020-01-29 05:58:32	2020-01-29	17	[{"id_menu":4,"count":1}]	10746	delivery	5	22
27211	2020-01-29 06:02:37	2020-01-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2418	delivery	5	31
27212	2020-01-29 06:03:47	2020-01-29	17	[{"id_menu":4,"count":1}]	5138	pick-up	0	17
27213	2020-01-29 06:03:56	2020-01-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	10678	delivery	5	27
27214	2020-01-29 06:06:24	2020-01-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	10637	delivery	5	22
27215	2020-01-29 06:09:59	2020-01-29	9	[{"id_menu":6,"count":1}]	10732	delivery	5	14
27216	2020-01-29 06:12:07	2020-01-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	730	delivery	5	26
27217	2020-01-29 06:15:36	2020-01-29	14	[{"id_menu":2,"count":1}]	1095	delivery	5	19
27218	2020-01-29 06:21:45	2020-01-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	10712	delivery	5	26
27219	2020-01-29 06:30:35	2020-01-29	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2605	delivery	5	30
27220	2020-01-29 06:48:06	2020-01-29	9	[{"id_menu":7,"count":1}]	1523	pick-up	0	9
27221	2020-01-29 06:49:38	2020-01-29	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10704	delivery	5	43
27222	2020-01-29 06:51:40	2020-01-29	9	[{"id_menu":6,"count":1}]	10703	delivery	5	14
27223	2020-01-29 06:59:59	2020-01-29	17	[{"id_menu":4,"count":1}]	1396	pick-up	0	17
27224	2020-01-29 07:01:31	2020-01-29	12	[{"id_menu":1,"count":1}]	1040	pick-up	0	12
27225	2020-01-29 07:06:29	2020-01-29	9	[{"id_menu":6,"count":1}]	7279	delivery	5	14
27226	2020-01-29 07:18:42	2020-01-29	17	[{"id_menu":4,"count":1}]	4576	delivery	5	22
27227	2020-01-29 07:30:34	2020-01-29	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	10652	delivery	5	31
27228	2020-01-29 07:37:01	2020-01-29	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10667	delivery	5	45
27229	2020-01-29 07:39:54	2020-01-29	9	[{"id_menu":6,"count":1}]	9373	delivery	5	14
27230	2020-01-29 07:47:04	2020-01-29	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10664	delivery	5	37
27231	2020-01-29 07:52:14	2020-01-29	12	[{"id_menu":1,"count":1}]	6975	pick-up	0	12
27232	2020-01-29 08:05:28	2020-01-29	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1252	pick-up	0	26
27233	2020-01-29 08:09:10	2020-01-29	14	[{"id_menu":2,"count":1}]	10727	pick-up	0	14
27234	2020-01-29 08:19:43	2020-01-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8651	delivery	5	23
27235	2020-01-29 08:28:32	2020-01-29	9	[{"id_menu":6,"count":1}]	9846	pick-up	0	9
27236	2020-01-29 08:35:24	2020-01-29	9	[{"id_menu":6,"count":1}]	10713	delivery	5	14
27237	2020-01-29 08:37:37	2020-01-29	12	[{"id_menu":3,"count":1}]	10728	delivery	5	17
27238	2020-01-29 08:38:38	2020-01-29	8	[{"id_menu":5,"count":1}]	10655	delivery	5	13
27239	2020-01-29 08:39:07	2020-01-29	14	[{"id_menu":2,"count":2}]	10658	delivery	5	19
27240	2020-01-29 08:40:58	2020-01-29	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	480	delivery	5	31
27241	2020-01-29 08:41:24	2020-01-29	12	[{"id_menu":1,"count":1}]	659	pick-up	0	12
27242	2020-01-29 09:17:30	2020-01-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	822	pick-up	0	21
27243	2020-01-29 09:20:14	2020-01-29	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	8240	delivery	5	36
27244	2020-01-29 09:23:30	2020-01-29	9	[{"id_menu":7,"count":1}]	5286	pick-up	0	9
27245	2020-01-29 09:24:12	2020-01-29	8	[{"id_menu":5,"count":1}]	123	pick-up	0	8
27246	2020-01-29 09:33:52	2020-01-29	12	[{"id_menu":1,"count":1}]	10659	pick-up	0	12
27247	2020-01-29 09:39:44	2020-01-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	10715	delivery	5	31
27248	2020-01-29 09:47:58	2020-01-29	17	[{"id_menu":4,"count":1}]	3701	pick-up	0	17
27249	2020-01-29 09:54:14	2020-01-29	17	[{"id_menu":4,"count":1}]	8145	pick-up	0	17
27250	2020-01-29 09:57:28	2020-01-29	12	[{"id_menu":3,"count":1}]	1335	pick-up	0	12
27251	2020-01-29 09:58:26	2020-01-29	8	[{"id_menu":5,"count":1}]	3964	delivery	5	13
27252	2020-01-29 10:02:34	2020-01-29	14	[{"id_menu":2,"count":1}]	10679	delivery	5	19
27253	2020-01-29 10:04:50	2020-01-29	12	[{"id_menu":3,"count":1}]	455	delivery	5	17
27254	2020-01-29 10:23:30	2020-01-29	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10671	delivery	5	34
27255	2020-01-29 10:28:37	2020-01-29	8	[{"id_menu":5,"count":1}]	9021	delivery	5	13
27256	2020-01-29 10:39:55	2020-01-29	17	[{"id_menu":4,"count":1}]	2332	delivery	5	22
27257	2020-01-29 11:18:15	2020-01-29	9	[{"id_menu":6,"count":1}]	143	pick-up	0	9
27258	2020-01-29 11:34:19	2020-01-29	9	[{"id_menu":7,"count":1}]	10743	delivery	5	14
27259	2020-01-29 11:38:25	2020-01-29	12	[{"id_menu":3,"count":1}]	7517	pick-up	0	12
27260	2020-01-29 11:45:07	2020-01-29	8	[{"id_menu":5,"count":1}]	1115	pick-up	0	8
27261	2020-01-29 11:58:51	2020-01-29	12	[{"id_menu":1,"count":1}]	9061	pick-up	0	12
27262	2020-01-29 11:59:22	2020-01-29	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	5845	delivery	5	31
27263	2020-01-29 11:59:25	2020-01-29	14	[{"id_menu":2,"count":1}]	1905	pick-up	0	14
27264	2020-01-29 12:02:52	2020-01-29	14	[{"id_menu":2,"count":1}]	10736	delivery	5	19
27265	2020-01-29 12:14:29	2020-01-29	8	[{"id_menu":5,"count":1}]	10755	pick-up	0	8
27266	2020-01-29 12:32:07	2020-01-29	9	[{"id_menu":7,"count":1}]	10753	delivery	5	14
27267	2020-01-29 12:35:52	2020-01-29	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10695	delivery	5	31
27268	2020-01-29 12:43:06	2020-01-29	9	[{"id_menu":6,"count":1}]	10738	pick-up	0	9
27269	2020-01-29 12:50:22	2020-01-29	12	[{"id_menu":1,"count":1}]	3984	delivery	5	17
27270	2020-01-29 12:52:54	2020-01-29	8	[{"id_menu":5,"count":1}]	10724	delivery	5	13
27271	2020-01-29 12:58:52	2020-01-29	9	[{"id_menu":6,"count":1}]	1947	pick-up	0	9
27272	2020-01-29 13:01:39	2020-01-29	14	[{"id_menu":2,"count":1}]	10718	delivery	5	19
27273	2020-01-29 13:12:44	2020-01-29	12	[{"id_menu":3,"count":1}]	2855	pick-up	0	12
27274	2020-01-29 13:16:07	2020-01-29	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	5227	delivery	5	31
27275	2020-01-29 13:17:52	2020-01-29	17	[{"id_menu":4,"count":1}]	10689	delivery	5	22
27276	2020-01-29 13:18:47	2020-01-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10742	delivery	5	31
27277	2020-01-29 13:28:24	2020-01-29	9	[{"id_menu":7,"count":2}]	10702	delivery	5	14
27278	2020-01-29 13:32:29	2020-01-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	9920	delivery	5	26
27279	2020-01-29 13:41:46	2020-01-29	8	[{"id_menu":5,"count":1}]	10710	delivery	5	13
27280	2020-01-29 13:55:29	2020-01-29	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9193	pick-up	0	41
27281	2020-01-29 14:03:58	2020-01-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3976	delivery	5	26
27282	2020-01-29 14:08:06	2020-01-29	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	1343	delivery	5	34
27283	2020-01-29 14:10:43	2020-01-29	12	[{"id_menu":3,"count":1}]	10745	delivery	5	17
27284	2020-01-29 14:23:11	2020-01-29	9	[{"id_menu":7,"count":1}]	189	delivery	5	14
27285	2020-01-29 14:37:25	2020-01-29	17	[{"id_menu":4,"count":1}]	3491	pick-up	0	17
27286	2020-01-29 15:08:45	2020-01-29	8	[{"id_menu":5,"count":1}]	246	delivery	5	13
27287	2020-01-29 15:19:13	2020-01-29	14	[{"id_menu":2,"count":1}]	6816	delivery	5	19
27288	2020-01-29 15:25:05	2020-01-29	9	[{"id_menu":7,"count":1}]	10669	delivery	5	14
27289	2020-01-29 15:28:47	2020-01-29	12	[{"id_menu":1,"count":1}]	10016	delivery	5	17
27290	2020-01-29 15:33:22	2020-01-29	12	[{"id_menu":3,"count":1}]	2083	pick-up	0	12
27291	2020-01-29 15:58:39	2020-01-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	346	pick-up	0	18
27292	2020-01-29 15:59:31	2020-01-29	9	[{"id_menu":7,"count":1}]	1352	delivery	5	14
27293	2020-01-29 16:06:01	2020-01-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6058	delivery	5	22
27294	2020-01-29 16:13:11	2020-01-29	8	[{"id_menu":5,"count":1}]	9572	pick-up	0	8
27295	2020-01-29 16:13:54	2020-01-29	9	[{"id_menu":6,"count":1}]	5903	delivery	5	14
27296	2020-01-29 16:14:36	2020-01-29	12	[{"id_menu":3,"count":1}]	271	delivery	5	17
27297	2020-01-29 16:20:32	2020-01-29	8	[{"id_menu":5,"count":1}]	5933	pick-up	0	8
27298	2020-01-29 16:22:40	2020-01-29	9	[{"id_menu":7,"count":1}]	10709	delivery	5	14
27299	2020-01-29 16:25:01	2020-01-29	9	[{"id_menu":7,"count":1}]	5736	delivery	5	14
27300	2020-01-29 16:31:09	2020-01-29	12	[{"id_menu":3,"count":1}]	10668	delivery	5	17
27301	2020-01-29 16:31:24	2020-01-29	12	[{"id_menu":3,"count":1}]	4804	pick-up	0	12
27302	2020-01-29 16:37:58	2020-01-29	9	[{"id_menu":7,"count":1}]	10684	delivery	5	14
27303	2020-01-29 16:42:23	2020-01-29	12	[{"id_menu":3,"count":1}]	799	delivery	5	17
27304	2020-01-29 16:42:54	2020-01-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	5526	pick-up	0	22
27305	2020-01-29 16:47:02	2020-01-29	8	[{"id_menu":5,"count":1}]	10731	delivery	5	13
27306	2020-01-29 17:10:12	2020-01-29	9	[{"id_menu":7,"count":1}]	6340	delivery	5	14
27307	2020-01-29 17:10:36	2020-01-29	9	[{"id_menu":7,"count":1}]	3877	pick-up	0	9
27308	2020-01-29 17:18:20	2020-01-29	8	[{"id_menu":5,"count":1}]	1448	pick-up	0	8
27309	2020-01-29 17:19:50	2020-01-29	17	[{"id_menu":4,"count":1}]	7150	pick-up	0	17
27310	2020-01-29 17:22:11	2020-01-29	12	[{"id_menu":1,"count":1}]	111	pick-up	0	12
27311	2020-01-29 17:23:54	2020-01-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3404	delivery	5	22
27312	2020-01-29 18:06:07	2020-01-29	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	10733	delivery	5	28
27313	2020-01-29 18:08:54	2020-01-29	8	[{"id_menu":5,"count":2}]	10756	pick-up	0	8
27314	2020-01-29 18:09:14	2020-01-29	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	9902	delivery	5	43
27315	2020-01-29 18:15:20	2020-01-29	8	[{"id_menu":5,"count":1}]	9723	delivery	5	13
27316	2020-01-29 18:21:43	2020-01-29	8	[{"id_menu":5,"count":1}]	10661	delivery	5	13
27317	2020-01-29 18:26:42	2020-01-29	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2119	pick-up	0	26
27318	2020-01-29 18:26:59	2020-01-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10681	delivery	5	36
27319	2020-01-29 18:33:40	2020-01-29	9	[{"id_menu":7,"count":1}]	482	delivery	5	14
27320	2020-01-29 18:36:41	2020-01-29	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	5649	delivery	5	43
27321	2020-01-29 18:41:03	2020-01-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	10660	delivery	5	26
27322	2020-01-29 18:41:45	2020-01-29	14	[{"id_menu":2,"count":1}]	1121	pick-up	0	14
27323	2020-01-29 18:42:32	2020-01-29	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	10740	delivery	5	27
27324	2020-01-29 18:45:38	2020-01-29	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	10666	delivery	5	48
27325	2020-01-29 18:51:09	2020-01-29	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8884	delivery	5	39
27326	2020-01-29 18:57:21	2020-01-29	9	[{"id_menu":6,"count":1}]	379	pick-up	0	9
27327	2020-01-29 19:00:10	2020-01-29	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	10662	delivery	5	25
27328	2020-01-29 19:08:17	2020-01-29	14	[{"id_menu":2,"count":1}]	10744	delivery	5	19
27329	2020-01-29 19:12:39	2020-01-29	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	10650	delivery	5	25
27330	2020-01-29 19:12:49	2020-01-29	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	8666	pick-up	0	26
27331	2020-01-29 19:15:04	2020-01-29	9	[{"id_menu":7,"count":1}]	10375	delivery	5	14
27332	2020-01-29 19:24:43	2020-01-29	12	[{"id_menu":1,"count":1}]	10694	pick-up	0	12
27333	2020-01-29 19:29:15	2020-01-29	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	10725	delivery	5	48
27334	2020-01-29 19:31:21	2020-01-29	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	2107	pick-up	0	21
27335	2020-01-29 19:33:44	2020-01-29	12	[{"id_menu":3,"count":1}]	10717	delivery	5	17
27336	2020-01-29 19:33:48	2020-01-29	9	[{"id_menu":6,"count":1}]	10680	delivery	5	14
27337	2020-01-29 19:34:26	2020-01-29	12	[{"id_menu":1,"count":1}]	10688	delivery	5	17
27338	2020-01-29 19:41:17	2020-01-29	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3452	delivery	5	43
27339	2020-01-29 19:42:33	2020-01-29	8	[{"id_menu":5,"count":1}]	1806	pick-up	0	8
27340	2020-01-29 19:48:02	2020-01-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5099	pick-up	0	23
27341	2020-01-29 19:49:42	2020-01-29	9	[{"id_menu":7,"count":1}]	10676	delivery	5	14
27342	2020-01-29 19:51:50	2020-01-29	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9830	pick-up	0	43
27343	2020-01-29 19:56:58	2020-01-29	8	[{"id_menu":5,"count":1}]	2087	pick-up	0	8
27344	2020-01-29 20:05:36	2020-01-29	9	[{"id_menu":6,"count":2}]	10697	pick-up	0	9
27345	2020-01-29 20:05:37	2020-01-29	14	[{"id_menu":2,"count":1}]	4052	delivery	5	19
27346	2020-01-29 20:09:10	2020-01-29	14	[{"id_menu":2,"count":1}]	1266	delivery	5	19
27347	2020-01-29 20:11:34	2020-01-29	17	[{"id_menu":4,"count":1}]	6589	pick-up	0	17
27348	2020-01-29 20:14:45	2020-01-29	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10690	delivery	5	48
27349	2020-01-29 20:25:08	2020-01-29	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	6883	delivery	5	40
27350	2020-01-29 20:39:09	2020-01-29	17	[{"id_menu":4,"count":1}]	10729	delivery	5	22
27351	2020-01-29 20:39:54	2020-01-29	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6496	delivery	5	45
27352	2020-01-29 20:47:26	2020-01-29	9	[{"id_menu":6,"count":1}]	1441	delivery	5	14
27353	2020-01-29 20:56:48	2020-01-29	9	[{"id_menu":6,"count":1}]	6778	delivery	5	14
27354	2020-01-29 21:01:28	2020-01-29	14	[{"id_menu":2,"count":1}]	10741	pick-up	0	14
27355	2020-01-29 21:02:00	2020-01-29	8	[{"id_menu":5,"count":1}]	558	pick-up	0	8
27356	2020-01-29 21:04:21	2020-01-29	9	[{"id_menu":6,"count":1}]	10707	delivery	5	14
27357	2020-01-29 21:08:04	2020-01-29	9	[{"id_menu":6,"count":1}]	7966	delivery	5	14
27358	2020-01-29 21:11:36	2020-01-29	14	[{"id_menu":2,"count":1}]	3300	delivery	5	19
27359	2020-01-29 21:12:10	2020-01-29	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10716	delivery	5	52
27360	2020-01-29 21:20:47	2020-01-29	12	[{"id_menu":3,"count":1}]	9740	delivery	5	17
27361	2020-01-29 21:47:39	2020-01-29	14	[{"id_menu":2,"count":1}]	4536	pick-up	0	14
27362	2020-01-29 21:51:24	2020-01-29	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	10370	delivery	5	26
27363	2020-01-29 22:00:49	2020-01-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4411	pick-up	0	26
27364	2020-01-29 22:06:54	2020-01-29	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10739	delivery	5	45
27365	2020-01-29 22:08:57	2020-01-29	17	[{"id_menu":4,"count":1}]	7104	delivery	5	22
27366	2020-01-29 22:13:51	2020-01-29	17	[{"id_menu":4,"count":1}]	10665	pick-up	0	17
27367	2020-01-29 22:31:10	2020-01-29	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	7247	pick-up	0	24
27368	2020-01-29 22:38:53	2020-01-29	14	[{"id_menu":2,"count":1}]	10273	delivery	5	19
27369	2020-01-29 22:45:09	2020-01-29	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7156	pick-up	0	38
27370	2020-01-29 22:51:56	2020-01-29	8	[{"id_menu":5,"count":1}]	10751	delivery	5	13
27371	2020-01-29 22:53:37	2020-01-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	10750	delivery	5	22
27372	2020-01-29 22:57:31	2020-01-29	9	[{"id_menu":7,"count":1}]	1862	pick-up	0	9
27373	2020-01-29 23:08:40	2020-01-29	12	[{"id_menu":3,"count":1}]	7046	pick-up	0	12
27374	2020-01-29 23:21:56	2020-01-29	8	[{"id_menu":5,"count":1}]	5538	delivery	5	13
27375	2020-01-29 23:27:07	2020-01-29	12	[{"id_menu":3,"count":1}]	1118	delivery	5	17
27376	2020-01-29 23:28:49	2020-01-29	17	[{"id_menu":4,"count":1}]	9492	delivery	5	22
27377	2020-01-29 23:32:01	2020-01-29	14	[{"id_menu":2,"count":1}]	5783	pick-up	0	14
27378	2020-01-29 23:43:32	2020-01-29	17	[{"id_menu":4,"count":1}]	9404	pick-up	0	17
27379	2020-01-29 23:46:42	2020-01-29	9	[{"id_menu":6,"count":1}]	5279	pick-up	0	9
27380	2020-01-29 23:47:24	2020-01-29	12	[{"id_menu":1,"count":1}]	3105	pick-up	0	12
27381	2020-01-29 23:55:07	2020-01-29	9	[{"id_menu":7,"count":2}]	10757	delivery	5	14
27382	2020-01-30 00:27:41	2020-01-30	17	[{"id_menu":4,"count":1}]	10807	pick-up	0	17
27383	2020-01-30 00:35:02	2020-01-30	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5044	delivery	5	39
27384	2020-01-30 00:42:36	2020-01-30	17	[{"id_menu":4,"count":1}]	10798	pick-up	0	17
27385	2020-01-30 00:52:22	2020-01-30	9	[{"id_menu":6,"count":2}]	2641	pick-up	0	9
27386	2020-01-30 00:59:18	2020-01-30	12	[{"id_menu":1,"count":1}]	7934	delivery	5	17
27387	2020-01-30 01:06:34	2020-01-30	14	[{"id_menu":2,"count":1}]	4767	pick-up	0	14
27388	2020-01-30 01:11:10	2020-01-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10815	delivery	5	31
27389	2020-01-30 01:18:00	2020-01-30	9	[{"id_menu":6,"count":1}]	4984	pick-up	0	9
27390	2020-01-30 01:19:25	2020-01-30	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	10797	delivery	5	26
27391	2020-01-30 01:31:02	2020-01-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4782	pick-up	0	23
27392	2020-01-30 01:32:50	2020-01-30	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	4190	delivery	5	26
27393	2020-01-30 01:38:16	2020-01-30	14	[{"id_menu":2,"count":1}]	10654	pick-up	0	14
27394	2020-01-30 01:39:25	2020-01-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	916	pick-up	0	17
27395	2020-01-30 01:44:12	2020-01-30	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	10767	pick-up	0	29
27396	2020-01-30 01:49:44	2020-01-30	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	10808	delivery	5	23
27397	2020-01-30 02:02:59	2020-01-30	12	[{"id_menu":1,"count":1}]	5144	delivery	5	17
27398	2020-01-30 02:08:05	2020-01-30	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	4828	delivery	5	31
27399	2020-01-30 02:08:41	2020-01-30	9	[{"id_menu":7,"count":1}]	8609	pick-up	0	9
27400	2020-01-30 02:10:44	2020-01-30	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	9943	pick-up	0	41
27401	2020-01-30 02:11:37	2020-01-30	12	[{"id_menu":1,"count":1}]	10779	delivery	5	17
27402	2020-01-30 02:34:09	2020-01-30	14	[{"id_menu":2,"count":1}]	8229	pick-up	0	14
27403	2020-01-30 02:37:19	2020-01-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1848	pick-up	0	21
27404	2020-01-30 02:44:40	2020-01-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	10170	delivery	5	23
27405	2020-01-30 02:56:59	2020-01-30	9	[{"id_menu":7,"count":1}]	56	delivery	5	14
27406	2020-01-30 03:02:20	2020-01-30	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2520	pick-up	0	21
27407	2020-01-30 03:23:17	2020-01-30	14	[{"id_menu":2,"count":1}]	8755	pick-up	0	14
27408	2020-01-30 03:30:20	2020-01-30	8	[{"id_menu":5,"count":1}]	10768	delivery	5	13
27409	2020-01-30 03:36:57	2020-01-30	9	[{"id_menu":6,"count":1}]	10819	pick-up	0	9
27410	2020-01-30 03:42:16	2020-01-30	8	[{"id_menu":5,"count":1}]	8693	pick-up	0	8
27411	2020-01-30 03:42:33	2020-01-30	14	[{"id_menu":2,"count":1}]	123	pick-up	0	14
27412	2020-01-30 03:50:17	2020-01-30	9	[{"id_menu":7,"count":1}]	10785	delivery	5	14
27413	2020-01-30 03:56:11	2020-01-30	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	5832	pick-up	0	21
27414	2020-01-30 03:56:58	2020-01-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	338	delivery	5	31
27415	2020-01-30 04:00:27	2020-01-30	9	[{"id_menu":6,"count":1}]	456	pick-up	0	9
27416	2020-01-30 04:12:45	2020-01-30	17	[{"id_menu":4,"count":1}]	1104	pick-up	0	17
27417	2020-01-30 04:17:04	2020-01-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8054	delivery	5	31
27418	2020-01-30 04:26:13	2020-01-30	9	[{"id_menu":6,"count":1}]	10637	delivery	5	14
27419	2020-01-30 04:36:02	2020-01-30	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10776	delivery	5	35
27420	2020-01-30 04:47:00	2020-01-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9348	pick-up	0	23
27421	2020-01-30 04:48:17	2020-01-30	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	77	pick-up	0	40
27422	2020-01-30 04:52:52	2020-01-30	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	10809	delivery	5	34
27423	2020-01-30 04:55:24	2020-01-30	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10823	delivery	5	34
27424	2020-01-30 04:56:10	2020-01-30	14	[{"id_menu":2,"count":1}]	2959	delivery	5	19
27425	2020-01-30 04:59:09	2020-01-30	12	[{"id_menu":3,"count":1}]	6529	delivery	5	17
27426	2020-01-30 05:00:18	2020-01-30	17	[{"id_menu":4,"count":1}]	1902	delivery	5	22
27427	2020-01-30 05:08:33	2020-01-30	12	[{"id_menu":1,"count":1}]	5332	delivery	5	17
27428	2020-01-30 05:11:21	2020-01-30	12	[{"id_menu":1,"count":1}]	4096	pick-up	0	12
27429	2020-01-30 05:11:38	2020-01-30	9	[{"id_menu":6,"count":1}]	5040	delivery	5	14
27430	2020-01-30 05:14:52	2020-01-30	14	[{"id_menu":2,"count":1}]	10814	delivery	5	19
27431	2020-01-30 05:21:11	2020-01-30	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	10765	delivery	5	26
27432	2020-01-30 05:22:35	2020-01-30	17	[{"id_menu":4,"count":1}]	10824	delivery	5	22
27433	2020-01-30 05:29:38	2020-01-30	8	[{"id_menu":5,"count":1}]	10832	delivery	5	13
27434	2020-01-30 05:40:01	2020-01-30	9	[{"id_menu":6,"count":1}]	2309	pick-up	0	9
27435	2020-01-30 05:42:43	2020-01-30	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	10813	delivery	5	26
27436	2020-01-30 05:47:23	2020-01-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5416	delivery	5	28
27437	2020-01-30 05:52:28	2020-01-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7123	delivery	5	31
27438	2020-01-30 05:53:59	2020-01-30	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2780	delivery	5	36
27439	2020-01-30 05:54:08	2020-01-30	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10802	delivery	5	30
27440	2020-01-30 06:06:41	2020-01-30	9	[{"id_menu":7,"count":2}]	6489	pick-up	0	9
27441	2020-01-30 06:13:14	2020-01-30	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2573	delivery	5	38
27442	2020-01-30 06:17:41	2020-01-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	4074	delivery	5	26
27443	2020-01-30 06:20:15	2020-01-30	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	10805	delivery	5	25
27444	2020-01-30 06:25:12	2020-01-30	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10794	delivery	5	34
27445	2020-01-30 06:30:13	2020-01-30	9	[{"id_menu":6,"count":1}]	9550	delivery	5	14
27446	2020-01-30 06:38:11	2020-01-30	12	[{"id_menu":3,"count":1}]	10792	delivery	5	17
27447	2020-01-30 06:41:44	2020-01-30	14	[{"id_menu":2,"count":1}]	5329	delivery	5	19
27448	2020-01-30 06:45:18	2020-01-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1697	pick-up	0	26
27449	2020-01-30 06:49:44	2020-01-30	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	2523	pick-up	0	20
27450	2020-01-30 06:58:50	2020-01-30	9	[{"id_menu":6,"count":1}]	1481	delivery	5	14
27451	2020-01-30 07:09:49	2020-01-30	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	10388	delivery	5	38
27452	2020-01-30 07:13:26	2020-01-30	17	[{"id_menu":4,"count":1}]	10793	pick-up	0	17
27453	2020-01-30 07:17:52	2020-01-30	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4172	delivery	5	34
27454	2020-01-30 07:21:57	2020-01-30	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	8646	delivery	5	26
27455	2020-01-30 07:22:15	2020-01-30	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1069	pick-up	0	26
27456	2020-01-30 07:34:53	2020-01-30	12	[{"id_menu":1,"count":1}]	10812	delivery	5	17
27457	2020-01-30 07:38:08	2020-01-30	12	[{"id_menu":3,"count":1}]	8286	delivery	5	17
27458	2020-01-30 07:39:24	2020-01-30	17	[{"id_menu":4,"count":1}]	8615	delivery	5	22
27459	2020-01-30 07:44:08	2020-01-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2569	delivery	5	28
27460	2020-01-30 07:44:13	2020-01-30	12	[{"id_menu":3,"count":1}]	228	pick-up	0	12
27461	2020-01-30 07:53:17	2020-01-30	9	[{"id_menu":6,"count":1}]	10772	pick-up	0	9
27462	2020-01-30 07:54:28	2020-01-30	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	4794	delivery	5	34
27463	2020-01-30 07:54:44	2020-01-30	12	[{"id_menu":3,"count":1}]	7976	delivery	5	17
27464	2020-01-30 08:05:44	2020-01-30	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	10759	delivery	5	26
27465	2020-01-30 08:19:11	2020-01-30	8	[{"id_menu":5,"count":1}]	10520	delivery	5	13
27466	2020-01-30 08:29:44	2020-01-30	17	[{"id_menu":4,"count":1}]	451	pick-up	0	17
27467	2020-01-30 08:46:59	2020-01-30	8	[{"id_menu":5,"count":1}]	6164	pick-up	0	8
27468	2020-01-30 08:53:46	2020-01-30	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	10818	delivery	5	38
27469	2020-01-30 08:57:23	2020-01-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	10231	delivery	5	28
27470	2020-01-30 09:08:29	2020-01-30	9	[{"id_menu":6,"count":2}]	10764	delivery	5	14
27471	2020-01-30 09:10:38	2020-01-30	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	9075	delivery	5	26
27472	2020-01-30 09:17:49	2020-01-30	12	[{"id_menu":3,"count":1}]	9502	delivery	5	17
27473	2020-01-30 09:25:51	2020-01-30	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6057	delivery	5	44
27474	2020-01-30 09:28:17	2020-01-30	9	[{"id_menu":6,"count":2}]	10773	delivery	5	14
27475	2020-01-30 09:35:13	2020-01-30	9	[{"id_menu":6,"count":1}]	4082	pick-up	0	9
27476	2020-01-30 09:38:24	2020-01-30	8	[{"id_menu":5,"count":2}]	10766	delivery	5	13
27477	2020-01-30 09:53:17	2020-01-30	9	[{"id_menu":6,"count":1}]	9017	pick-up	0	9
27478	2020-01-30 10:03:06	2020-01-30	12	[{"id_menu":3,"count":1}]	4870	pick-up	0	12
27479	2020-01-30 10:06:07	2020-01-30	9	[{"id_menu":6,"count":1}]	7491	delivery	5	14
27480	2020-01-30 10:11:32	2020-01-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4453	delivery	5	28
27481	2020-01-30 10:29:45	2020-01-30	17	[{"id_menu":4,"count":1}]	10789	delivery	5	22
27482	2020-01-30 10:34:49	2020-01-30	14	[{"id_menu":2,"count":1}]	10761	pick-up	0	14
27483	2020-01-30 10:41:45	2020-01-30	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10831	delivery	5	43
27484	2020-01-30 10:46:48	2020-01-30	9	[{"id_menu":7,"count":2}]	9504	delivery	5	14
27485	2020-01-30 10:57:10	2020-01-30	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1855	delivery	5	48
27486	2020-01-30 11:03:51	2020-01-30	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	1079	delivery	5	39
27487	2020-01-30 11:13:32	2020-01-30	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	10806	delivery	5	34
27488	2020-01-30 11:14:53	2020-01-30	12	[{"id_menu":1,"count":1}]	1742	delivery	5	17
27489	2020-01-30 11:19:01	2020-01-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10782	delivery	5	23
27490	2020-01-30 11:24:19	2020-01-30	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	4088	delivery	5	25
27491	2020-01-30 11:31:19	2020-01-30	14	[{"id_menu":2,"count":1}]	729	delivery	5	19
27492	2020-01-30 11:34:34	2020-01-30	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3797	delivery	5	38
27493	2020-01-30 11:40:13	2020-01-30	12	[{"id_menu":1,"count":1}]	10778	pick-up	0	12
27494	2020-01-30 11:41:10	2020-01-30	12	[{"id_menu":1,"count":1}]	969	delivery	5	17
27495	2020-01-30 11:45:14	2020-01-30	8	[{"id_menu":5,"count":1}]	10781	delivery	5	13
27496	2020-01-30 11:53:39	2020-01-30	17	[{"id_menu":4,"count":1}]	10799	delivery	5	22
27497	2020-01-30 12:15:26	2020-01-30	14	[{"id_menu":2,"count":1}]	10760	delivery	5	19
27498	2020-01-30 12:19:56	2020-01-30	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	223	pick-up	0	31
27499	2020-01-30 12:27:22	2020-01-30	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	10829	pick-up	0	34
27500	2020-01-30 12:44:40	2020-01-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10184	delivery	5	23
27501	2020-01-30 13:09:21	2020-01-30	12	[{"id_menu":1,"count":1}]	10791	delivery	5	17
27502	2020-01-30 13:15:51	2020-01-30	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	4818	delivery	5	26
27503	2020-01-30 13:27:57	2020-01-30	9	[{"id_menu":7,"count":1}]	10801	pick-up	0	9
27504	2020-01-30 13:45:33	2020-01-30	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	10804	delivery	5	37
27505	2020-01-30 13:50:06	2020-01-30	12	[{"id_menu":1,"count":1}]	10393	pick-up	0	12
27506	2020-01-30 13:53:14	2020-01-30	14	[{"id_menu":2,"count":1}]	2623	delivery	5	19
27507	2020-01-30 13:58:05	2020-01-30	12	[{"id_menu":3,"count":1}]	4170	delivery	5	17
27508	2020-01-30 14:08:38	2020-01-30	8	[{"id_menu":5,"count":1}]	764	delivery	5	13
27509	2020-01-30 14:09:50	2020-01-30	9	[{"id_menu":6,"count":1}]	10445	delivery	5	14
27510	2020-01-30 14:12:06	2020-01-30	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1661	pick-up	0	20
27511	2020-01-30 14:17:14	2020-01-30	9	[{"id_menu":6,"count":1}]	7899	delivery	5	14
27512	2020-01-30 14:26:16	2020-01-30	14	[{"id_menu":2,"count":1}]	5019	pick-up	0	14
27513	2020-01-30 14:39:19	2020-01-30	17	[{"id_menu":4,"count":1}]	2055	pick-up	0	17
27514	2020-01-30 14:59:10	2020-01-30	9	[{"id_menu":7,"count":1}]	1064	delivery	5	14
27515	2020-01-30 15:04:53	2020-01-30	17	[{"id_menu":4,"count":1}]	2572	delivery	5	22
27516	2020-01-30 15:07:48	2020-01-30	12	[{"id_menu":1,"count":1}]	10826	delivery	5	17
27517	2020-01-30 15:16:01	2020-01-30	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5805	delivery	5	34
27518	2020-01-30 15:17:59	2020-01-30	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5691	delivery	5	30
27519	2020-01-30 15:18:16	2020-01-30	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	10795	delivery	5	26
27520	2020-01-30 15:31:22	2020-01-30	8	[{"id_menu":5,"count":1}]	6036	delivery	5	13
27521	2020-01-30 15:38:12	2020-01-30	8	[{"id_menu":5,"count":1}]	2251	delivery	5	13
27522	2020-01-30 16:13:08	2020-01-30	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	2743	delivery	5	45
27523	2020-01-30 16:27:51	2020-01-30	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1629	pick-up	0	44
27524	2020-01-30 16:42:57	2020-01-30	17	[{"id_menu":4,"count":1}]	7552	pick-up	0	17
27525	2020-01-30 16:54:37	2020-01-30	14	[{"id_menu":2,"count":3}]	10803	delivery	5	19
27526	2020-01-30 16:57:29	2020-01-30	12	[{"id_menu":3,"count":1}]	10796	delivery	5	17
27527	2020-01-30 17:00:04	2020-01-30	14	[{"id_menu":2,"count":1}]	9421	pick-up	0	14
27528	2020-01-30 17:12:21	2020-01-30	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1075	pick-up	0	20
27529	2020-01-30 17:16:18	2020-01-30	9	[{"id_menu":6,"count":1}]	6137	delivery	5	14
27530	2020-01-30 17:25:55	2020-01-30	12	[{"id_menu":3,"count":1}]	8471	pick-up	0	12
27531	2020-01-30 17:25:57	2020-01-30	12	[{"id_menu":1,"count":1}]	10774	delivery	5	17
27532	2020-01-30 17:37:59	2020-01-30	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	9039	delivery	5	40
27533	2020-01-30 17:42:52	2020-01-30	8	[{"id_menu":5,"count":1}]	6242	pick-up	0	8
27534	2020-01-30 17:43:34	2020-01-30	9	[{"id_menu":6,"count":1}]	6426	delivery	5	14
27535	2020-01-30 17:45:55	2020-01-30	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10763	delivery	5	35
27536	2020-01-30 18:08:46	2020-01-30	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	10816	delivery	5	48
27537	2020-01-30 18:12:55	2020-01-30	12	[{"id_menu":3,"count":1}]	6152	pick-up	0	12
27538	2020-01-30 18:13:59	2020-01-30	8	[{"id_menu":5,"count":1}]	10822	delivery	5	13
27539	2020-01-30 18:14:57	2020-01-30	17	[{"id_menu":4,"count":1}]	6177	pick-up	0	17
27540	2020-01-30 18:20:04	2020-01-30	14	[{"id_menu":2,"count":1}]	8698	delivery	5	19
27541	2020-01-30 18:23:43	2020-01-30	14	[{"id_menu":2,"count":1}]	4332	delivery	5	19
27542	2020-01-30 18:28:12	2020-01-30	17	[{"id_menu":4,"count":1}]	10770	delivery	5	22
27543	2020-01-30 18:35:05	2020-01-30	14	[{"id_menu":2,"count":2}]	10817	delivery	5	19
27544	2020-01-30 18:37:27	2020-01-30	12	[{"id_menu":3,"count":1}]	6039	pick-up	0	12
27545	2020-01-30 18:39:00	2020-01-30	12	[{"id_menu":3,"count":1}]	10142	pick-up	0	12
27546	2020-01-30 18:41:48	2020-01-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8887	delivery	5	31
27547	2020-01-30 18:43:58	2020-01-30	12	[{"id_menu":3,"count":1}]	1968	delivery	5	17
27548	2020-01-30 18:46:37	2020-01-30	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10811	delivery	5	36
27549	2020-01-30 18:47:13	2020-01-30	12	[{"id_menu":1,"count":1}]	579	pick-up	0	12
27550	2020-01-30 18:52:24	2020-01-30	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	10830	delivery	5	38
27551	2020-01-30 18:52:52	2020-01-30	9	[{"id_menu":7,"count":1}]	6323	delivery	5	14
27552	2020-01-30 18:56:40	2020-01-30	9	[{"id_menu":6,"count":1}]	660	pick-up	0	9
27553	2020-01-30 18:57:32	2020-01-30	14	[{"id_menu":2,"count":1}]	10810	delivery	5	19
27554	2020-01-30 19:16:30	2020-01-30	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1958	delivery	5	25
27555	2020-01-30 19:35:16	2020-01-30	14	[{"id_menu":2,"count":1}]	10101	delivery	5	19
27556	2020-01-30 19:43:11	2020-01-30	8	[{"id_menu":5,"count":1}]	2216	pick-up	0	8
27557	2020-01-30 19:44:04	2020-01-30	9	[{"id_menu":7,"count":1}]	8747	delivery	5	14
27558	2020-01-30 20:00:43	2020-01-30	14	[{"id_menu":2,"count":1}]	4973	delivery	5	19
27559	2020-01-30 20:07:23	2020-01-30	14	[{"id_menu":2,"count":1}]	2401	delivery	5	19
27560	2020-01-30 20:13:01	2020-01-30	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	910	pick-up	0	26
27561	2020-01-30 20:43:12	2020-01-30	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10786	delivery	5	39
27562	2020-01-30 20:47:32	2020-01-30	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	10821	delivery	5	26
27563	2020-01-30 20:49:52	2020-01-30	9	[{"id_menu":6,"count":1}]	10340	delivery	5	14
27564	2020-01-30 20:50:31	2020-01-30	17	[{"id_menu":4,"count":1}]	1792	pick-up	0	17
27565	2020-01-30 20:50:40	2020-01-30	14	[{"id_menu":2,"count":1}]	6062	pick-up	0	14
27566	2020-01-30 20:57:09	2020-01-30	12	[{"id_menu":1,"count":1}]	10787	delivery	5	17
27567	2020-01-30 21:06:01	2020-01-30	14	[{"id_menu":2,"count":1}]	751	delivery	5	19
27568	2020-01-30 21:09:50	2020-01-30	8	[{"id_menu":5,"count":1}]	4060	delivery	5	13
27569	2020-01-30 21:13:04	2020-01-30	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	5729	pick-up	0	32
27570	2020-01-30 21:22:15	2020-01-30	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	158	pick-up	0	29
27571	2020-01-30 21:22:48	2020-01-30	12	[{"id_menu":1,"count":1}]	10784	delivery	5	17
27572	2020-01-30 21:34:38	2020-01-30	12	[{"id_menu":1,"count":1}]	10828	pick-up	0	12
27573	2020-01-30 21:37:11	2020-01-30	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1460	pick-up	0	31
27574	2020-01-30 21:50:34	2020-01-30	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10181	delivery	5	44
27575	2020-01-30 22:04:58	2020-01-30	9	[{"id_menu":6,"count":1}]	2231	pick-up	0	9
27576	2020-01-30 22:17:34	2020-01-30	12	[{"id_menu":1,"count":1}]	424	pick-up	0	12
27577	2020-01-30 22:21:27	2020-01-30	12	[{"id_menu":1,"count":1}]	1509	pick-up	0	12
27578	2020-01-30 22:25:59	2020-01-30	9	[{"id_menu":6,"count":1}]	6786	delivery	5	14
27579	2020-01-30 22:26:37	2020-01-30	17	[{"id_menu":4,"count":1}]	92	pick-up	0	17
27580	2020-01-30 22:36:59	2020-01-30	12	[{"id_menu":1,"count":1}]	5846	delivery	5	17
27581	2020-01-30 22:39:45	2020-01-30	9	[{"id_menu":6,"count":1}]	10771	delivery	5	14
27582	2020-01-30 22:41:28	2020-01-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	10509	delivery	5	27
27583	2020-01-30 22:47:43	2020-01-30	9	[{"id_menu":7,"count":1}]	10820	delivery	5	14
27584	2020-01-30 23:04:15	2020-01-30	12	[{"id_menu":1,"count":2}]	10258	pick-up	0	12
27585	2020-01-30 23:22:09	2020-01-30	17	[{"id_menu":4,"count":2}]	10777	delivery	5	22
27586	2020-01-30 23:25:09	2020-01-30	8	[{"id_menu":5,"count":1}]	1681	pick-up	0	8
27587	2020-01-30 23:25:26	2020-01-30	12	[{"id_menu":3,"count":1}]	4347	delivery	5	17
27588	2020-01-30 23:42:39	2020-01-30	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6232	delivery	5	36
27589	2020-01-30 23:45:40	2020-01-30	17	[{"id_menu":4,"count":1}]	10783	delivery	5	22
27590	2020-01-30 23:47:53	2020-01-30	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1531	pick-up	0	26
27591	2020-01-30 23:52:09	2020-01-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10354	delivery	5	22
27592	2020-01-30 23:57:25	2020-01-30	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	3112	pick-up	0	43
27593	2020-01-31 00:01:44	2020-01-31	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3748	delivery	5	48
27594	2020-01-31 00:04:06	2020-01-31	8	[{"id_menu":5,"count":1}]	10742	delivery	5	13
27595	2020-01-31 00:21:12	2020-01-31	12	[{"id_menu":3,"count":1}]	4091	pick-up	0	12
27596	2020-01-31 00:23:22	2020-01-31	9	[{"id_menu":7,"count":1}]	2642	pick-up	0	9
27597	2020-01-31 00:26:43	2020-01-31	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	285	pick-up	0	21
27598	2020-01-31 00:30:37	2020-01-31	14	[{"id_menu":2,"count":1}]	7644	delivery	5	19
27599	2020-01-31 00:32:09	2020-01-31	14	[{"id_menu":2,"count":1}]	10886	delivery	5	19
27600	2020-01-31 00:45:32	2020-01-31	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8180	delivery	5	45
27601	2020-01-31 00:49:59	2020-01-31	12	[{"id_menu":3,"count":1}]	2297	delivery	5	17
27602	2020-01-31 00:52:22	2020-01-31	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10901	delivery	5	36
27603	2020-01-31 00:53:33	2020-01-31	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	883	pick-up	0	26
27604	2020-01-31 00:54:01	2020-01-31	14	[{"id_menu":2,"count":1}]	7299	delivery	5	19
27605	2020-01-31 00:56:31	2020-01-31	12	[{"id_menu":3,"count":1}]	10887	delivery	5	17
27606	2020-01-31 00:56:48	2020-01-31	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10676	delivery	5	23
27607	2020-01-31 01:01:36	2020-01-31	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10888	delivery	5	43
27608	2020-01-31 01:04:42	2020-01-31	9	[{"id_menu":6,"count":1}]	2492	delivery	5	14
27609	2020-01-31 01:11:12	2020-01-31	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7047	delivery	5	30
27610	2020-01-31 01:13:32	2020-01-31	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6735	delivery	5	31
27611	2020-01-31 01:27:18	2020-01-31	14	[{"id_menu":2,"count":1}]	10879	delivery	5	19
27612	2020-01-31 01:37:02	2020-01-31	12	[{"id_menu":3,"count":1}]	10858	delivery	5	17
27613	2020-01-31 01:50:45	2020-01-31	9	[{"id_menu":7,"count":1}]	5416	pick-up	0	9
27614	2020-01-31 02:07:38	2020-01-31	9	[{"id_menu":6,"count":1}]	10846	delivery	5	14
27615	2020-01-31 02:11:52	2020-01-31	12	[{"id_menu":3,"count":1}]	7829	delivery	5	17
27616	2020-01-31 02:14:17	2020-01-31	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	9082	pick-up	0	31
27617	2020-01-31 02:21:44	2020-01-31	9	[{"id_menu":7,"count":1}]	7204	delivery	5	14
27618	2020-01-31 02:29:07	2020-01-31	9	[{"id_menu":6,"count":1}]	3227	pick-up	0	9
27619	2020-01-31 02:39:19	2020-01-31	9	[{"id_menu":7,"count":1}]	9295	pick-up	0	9
27620	2020-01-31 02:41:41	2020-01-31	17	[{"id_menu":4,"count":1}]	5517	pick-up	0	17
27621	2020-01-31 02:47:57	2020-01-31	9	[{"id_menu":7,"count":1}]	10897	delivery	5	14
27622	2020-01-31 02:52:05	2020-01-31	12	[{"id_menu":1,"count":1}]	10927	delivery	5	17
27623	2020-01-31 02:56:22	2020-01-31	8	[{"id_menu":5,"count":1}]	10921	delivery	5	13
27624	2020-01-31 02:56:25	2020-01-31	9	[{"id_menu":6,"count":1}]	983	delivery	5	14
27625	2020-01-31 03:15:40	2020-01-31	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10884	delivery	5	36
27626	2020-01-31 03:18:56	2020-01-31	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10860	delivery	5	43
27627	2020-01-31 03:22:05	2020-01-31	12	[{"id_menu":3,"count":1}]	8102	delivery	5	17
27628	2020-01-31 03:29:32	2020-01-31	14	[{"id_menu":2,"count":1}]	8065	pick-up	0	14
27629	2020-01-31 03:38:50	2020-01-31	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	10926	delivery	5	28
27630	2020-01-31 03:44:30	2020-01-31	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10851	delivery	5	23
27631	2020-01-31 03:46:28	2020-01-31	9	[{"id_menu":6,"count":1}]	10912	delivery	5	14
27632	2020-01-31 03:49:42	2020-01-31	17	[{"id_menu":4,"count":1}]	4253	delivery	5	22
27633	2020-01-31 03:50:28	2020-01-31	14	[{"id_menu":2,"count":1}]	3372	pick-up	0	14
27634	2020-01-31 04:13:43	2020-01-31	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	10853	pick-up	0	23
27635	2020-01-31 04:19:51	2020-01-31	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	4008	delivery	5	31
27636	2020-01-31 04:35:36	2020-01-31	12	[{"id_menu":1,"count":1}]	10876	delivery	5	17
27637	2020-01-31 04:44:42	2020-01-31	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":2}]	5875	pick-up	0	17
27638	2020-01-31 05:06:15	2020-01-31	9	[{"id_menu":7,"count":1}]	10865	delivery	5	14
27639	2020-01-31 05:06:38	2020-01-31	9	[{"id_menu":7,"count":1}]	1460	pick-up	0	9
27640	2020-01-31 05:07:43	2020-01-31	9	[{"id_menu":6,"count":1}]	9846	delivery	5	14
27641	2020-01-31 05:09:34	2020-01-31	9	[{"id_menu":7,"count":1}]	10882	delivery	5	14
27642	2020-01-31 05:15:39	2020-01-31	14	[{"id_menu":2,"count":1}]	10885	delivery	5	19
27643	2020-01-31 05:19:57	2020-01-31	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6147	delivery	5	22
27644	2020-01-31 05:41:37	2020-01-31	9	[{"id_menu":7,"count":1}]	21	delivery	5	14
27645	2020-01-31 06:10:51	2020-01-31	17	[{"id_menu":4,"count":1}]	10164	delivery	5	22
27646	2020-01-31 06:26:00	2020-01-31	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	8407	pick-up	0	26
27647	2020-01-31 06:47:31	2020-01-31	9	[{"id_menu":6,"count":1}]	893	pick-up	0	9
27648	2020-01-31 06:48:56	2020-01-31	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	8866	delivery	5	28
27649	2020-01-31 06:49:28	2020-01-31	9	[{"id_menu":6,"count":1}]	9128	pick-up	0	9
27650	2020-01-31 06:50:59	2020-01-31	17	[{"id_menu":4,"count":1}]	10854	delivery	5	22
27651	2020-01-31 06:55:25	2020-01-31	12	[{"id_menu":1,"count":1}]	8240	pick-up	0	12
27652	2020-01-31 06:56:56	2020-01-31	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	10856	delivery	5	22
27653	2020-01-31 06:59:20	2020-01-31	9	[{"id_menu":6,"count":1}]	1005	delivery	5	14
27654	2020-01-31 07:01:13	2020-01-31	9	[{"id_menu":7,"count":1}]	10892	delivery	5	14
27655	2020-01-31 07:06:30	2020-01-31	9	[{"id_menu":6,"count":1}]	10863	delivery	5	14
27656	2020-01-31 07:13:23	2020-01-31	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3827	pick-up	0	26
27657	2020-01-31 07:13:31	2020-01-31	14	[{"id_menu":2,"count":1}]	9995	delivery	5	19
27658	2020-01-31 07:24:26	2020-01-31	8	[{"id_menu":5,"count":1}]	10871	delivery	5	13
27659	2020-01-31 07:30:24	2020-01-31	17	[{"id_menu":4,"count":1}]	10835	delivery	5	22
27660	2020-01-31 07:37:07	2020-01-31	12	[{"id_menu":1,"count":1}]	2526	pick-up	0	12
27661	2020-01-31 07:38:48	2020-01-31	12	[{"id_menu":1,"count":1}]	3799	delivery	5	17
27662	2020-01-31 07:45:57	2020-01-31	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1670	pick-up	0	26
27663	2020-01-31 07:48:18	2020-01-31	14	[{"id_menu":2,"count":1}]	6666	delivery	5	19
27664	2020-01-31 07:54:47	2020-01-31	12	[{"id_menu":1,"count":1}]	1756	pick-up	0	12
27665	2020-01-31 07:56:50	2020-01-31	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4737	delivery	5	31
27666	2020-01-31 07:59:56	2020-01-31	12	[{"id_menu":3,"count":1}]	10916	pick-up	0	12
27667	2020-01-31 08:15:10	2020-01-31	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	3102	pick-up	0	26
27668	2020-01-31 08:15:56	2020-01-31	14	[{"id_menu":2,"count":1}]	7527	pick-up	0	14
27669	2020-01-31 08:23:17	2020-01-31	9	[{"id_menu":7,"count":1}]	10873	delivery	5	14
27670	2020-01-31 08:47:20	2020-01-31	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5186	delivery	5	54
27671	2020-01-31 08:51:36	2020-01-31	9	[{"id_menu":6,"count":1}]	3627	pick-up	0	9
27672	2020-01-31 08:59:27	2020-01-31	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	7341	delivery	5	27
27673	2020-01-31 09:09:13	2020-01-31	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	10899	delivery	5	25
27674	2020-01-31 09:11:01	2020-01-31	8	[{"id_menu":5,"count":1}]	10598	pick-up	0	8
27675	2020-01-31 09:31:28	2020-01-31	9	[{"id_menu":6,"count":1}]	1559	delivery	5	14
27676	2020-01-31 09:35:11	2020-01-31	14	[{"id_menu":2,"count":1}]	10111	delivery	5	19
27677	2020-01-31 09:37:41	2020-01-31	9	[{"id_menu":6,"count":1}]	3830	pick-up	0	9
27678	2020-01-31 09:49:27	2020-01-31	17	[{"id_menu":4,"count":1}]	8176	delivery	5	22
27679	2020-01-31 10:01:56	2020-01-31	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	10864	delivery	5	25
27680	2020-01-31 10:09:32	2020-01-31	12	[{"id_menu":3,"count":1}]	10845	pick-up	0	12
27681	2020-01-31 10:26:58	2020-01-31	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10785	delivery	5	23
27682	2020-01-31 10:28:38	2020-01-31	14	[{"id_menu":2,"count":2}]	4594	delivery	5	19
27683	2020-01-31 10:51:38	2020-01-31	8	[{"id_menu":5,"count":1}]	5318	pick-up	0	8
27684	2020-01-31 10:51:59	2020-01-31	8	[{"id_menu":5,"count":1}]	8813	delivery	5	13
27685	2020-01-31 10:54:17	2020-01-31	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10425	pick-up	0	31
27686	2020-01-31 11:04:40	2020-01-31	17	[{"id_menu":4,"count":1}]	1140	pick-up	0	17
27687	2020-01-31 11:12:39	2020-01-31	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10843	delivery	5	31
27688	2020-01-31 11:17:49	2020-01-31	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1481	pick-up	0	26
27689	2020-01-31 11:18:23	2020-01-31	14	[{"id_menu":2,"count":1}]	7888	delivery	5	19
27690	2020-01-31 11:27:19	2020-01-31	9	[{"id_menu":7,"count":1}]	10834	delivery	5	14
27691	2020-01-31 11:32:47	2020-01-31	9	[{"id_menu":7,"count":1}]	10799	delivery	5	14
27692	2020-01-31 11:37:51	2020-01-31	8	[{"id_menu":5,"count":1}]	7312	delivery	5	13
27693	2020-01-31 12:01:44	2020-01-31	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	10919	delivery	5	26
27694	2020-01-31 12:02:20	2020-01-31	9	[{"id_menu":7,"count":1}]	4542	delivery	5	14
27695	2020-01-31 12:34:41	2020-01-31	14	[{"id_menu":2,"count":1}]	10557	delivery	5	19
27696	2020-01-31 12:35:28	2020-01-31	9	[{"id_menu":6,"count":1}]	6191	pick-up	0	9
27697	2020-01-31 12:36:44	2020-01-31	12	[{"id_menu":1,"count":1}]	10895	pick-up	0	12
27698	2020-01-31 12:45:36	2020-01-31	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	5963	pick-up	0	20
27699	2020-01-31 12:48:54	2020-01-31	9	[{"id_menu":7,"count":2}]	10909	delivery	5	14
27700	2020-01-31 12:58:16	2020-01-31	12	[{"id_menu":3,"count":1}]	1148	pick-up	0	12
27701	2020-01-31 13:04:16	2020-01-31	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2296	delivery	5	36
27702	2020-01-31 13:07:30	2020-01-31	14	[{"id_menu":2,"count":1}]	9982	delivery	5	19
27703	2020-01-31 13:10:53	2020-01-31	17	[{"id_menu":4,"count":1}]	4604	delivery	5	22
27704	2020-01-31 13:14:45	2020-01-31	12	[{"id_menu":1,"count":2}]	9836	delivery	5	17
27705	2020-01-31 13:16:57	2020-01-31	17	[{"id_menu":4,"count":1}]	10850	pick-up	0	17
27706	2020-01-31 13:31:44	2020-01-31	9	[{"id_menu":7,"count":1}]	6591	pick-up	0	9
27707	2020-01-31 13:32:57	2020-01-31	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	8298	pick-up	0	26
27708	2020-01-31 13:35:02	2020-01-31	14	[{"id_menu":2,"count":1}]	9358	pick-up	0	14
27709	2020-01-31 13:38:24	2020-01-31	14	[{"id_menu":2,"count":3}]	9562	pick-up	0	14
27710	2020-01-31 13:42:03	2020-01-31	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	6305	delivery	5	36
27711	2020-01-31 13:49:09	2020-01-31	9	[{"id_menu":6,"count":1}]	10905	delivery	5	14
27712	2020-01-31 13:59:14	2020-01-31	9	[{"id_menu":7,"count":1}]	2875	pick-up	0	9
27713	2020-01-31 14:11:47	2020-01-31	8	[{"id_menu":5,"count":1}]	2253	delivery	5	13
27714	2020-01-31 14:17:01	2020-01-31	12	[{"id_menu":3,"count":1}]	10918	pick-up	0	12
27715	2020-01-31 14:20:50	2020-01-31	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	10924	delivery	5	45
27716	2020-01-31 14:25:48	2020-01-31	8	[{"id_menu":5,"count":1}]	4546	delivery	5	13
27717	2020-01-31 14:32:50	2020-01-31	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10914	delivery	5	42
27718	2020-01-31 14:35:11	2020-01-31	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1780	delivery	5	30
27719	2020-01-31 14:36:15	2020-01-31	8	[{"id_menu":5,"count":1}]	10007	pick-up	0	8
27720	2020-01-31 14:45:24	2020-01-31	12	[{"id_menu":1,"count":1}]	10857	pick-up	0	12
27721	2020-01-31 14:50:41	2020-01-31	12	[{"id_menu":3,"count":1}]	10881	delivery	5	17
27722	2020-01-31 14:51:26	2020-01-31	17	[{"id_menu":4,"count":1}]	7201	pick-up	0	17
27723	2020-01-31 15:03:28	2020-01-31	12	[{"id_menu":1,"count":1}]	10890	pick-up	0	12
27724	2020-01-31 15:10:15	2020-01-31	9	[{"id_menu":6,"count":1}]	10839	pick-up	0	9
27725	2020-01-31 15:12:31	2020-01-31	12	[{"id_menu":3,"count":1}]	427	delivery	5	17
27726	2020-01-31 15:30:30	2020-01-31	8	[{"id_menu":5,"count":1}]	10877	delivery	5	13
27727	2020-01-31 15:30:32	2020-01-31	14	[{"id_menu":2,"count":1}]	10875	pick-up	0	14
27728	2020-01-31 15:36:28	2020-01-31	9	[{"id_menu":6,"count":1}]	8201	delivery	5	14
27729	2020-01-31 15:58:07	2020-01-31	12	[{"id_menu":1,"count":1}]	6943	delivery	5	17
27730	2020-01-31 16:06:44	2020-01-31	12	[{"id_menu":1,"count":1}]	9920	pick-up	0	12
27731	2020-01-31 16:17:53	2020-01-31	12	[{"id_menu":1,"count":1}]	10848	delivery	5	17
27732	2020-01-31 16:18:42	2020-01-31	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	10868	delivery	5	26
27733	2020-01-31 16:19:38	2020-01-31	14	[{"id_menu":2,"count":1}]	10847	pick-up	0	14
27734	2020-01-31 16:24:44	2020-01-31	14	[{"id_menu":2,"count":1}]	1353	pick-up	0	14
27735	2020-01-31 16:29:42	2020-01-31	9	[{"id_menu":7,"count":1}]	2386	delivery	5	14
27736	2020-01-31 16:30:18	2020-01-31	14	[{"id_menu":2,"count":1}]	7918	delivery	5	19
27737	2020-01-31 16:49:57	2020-01-31	17	[{"id_menu":4,"count":1}]	2366	pick-up	0	17
27738	2020-01-31 16:51:59	2020-01-31	14	[{"id_menu":2,"count":1}]	5494	delivery	5	19
27739	2020-01-31 16:52:34	2020-01-31	9	[{"id_menu":6,"count":1}]	7338	delivery	5	14
27740	2020-01-31 16:55:50	2020-01-31	17	[{"id_menu":4,"count":1}]	8946	delivery	5	22
27741	2020-01-31 17:04:40	2020-01-31	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	10880	pick-up	0	26
27742	2020-01-31 17:19:35	2020-01-31	9	[{"id_menu":7,"count":1}]	10870	pick-up	0	9
27743	2020-01-31 17:28:40	2020-01-31	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	10836	delivery	5	34
27744	2020-01-31 17:35:21	2020-01-31	12	[{"id_menu":1,"count":1}]	10855	delivery	5	17
27745	2020-01-31 17:38:23	2020-01-31	12	[{"id_menu":3,"count":1}]	4018	delivery	5	17
27746	2020-01-31 17:38:54	2020-01-31	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10894	delivery	5	35
27747	2020-01-31 17:49:35	2020-01-31	14	[{"id_menu":2,"count":1}]	996	pick-up	0	14
27748	2020-01-31 17:54:57	2020-01-31	8	[{"id_menu":5,"count":1}]	8331	delivery	5	13
27749	2020-01-31 18:09:52	2020-01-31	8	[{"id_menu":5,"count":1}]	10902	delivery	5	13
27750	2020-01-31 18:19:57	2020-01-31	12	[{"id_menu":1,"count":1}]	8104	delivery	5	17
27751	2020-01-31 18:29:17	2020-01-31	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	5097	delivery	5	26
27752	2020-01-31 18:34:22	2020-01-31	12	[{"id_menu":3,"count":1}]	10896	delivery	5	17
27753	2020-01-31 18:47:03	2020-01-31	9	[{"id_menu":6,"count":1}]	8508	delivery	5	14
27754	2020-01-31 18:52:42	2020-01-31	9	[{"id_menu":6,"count":1}]	4996	delivery	5	14
27755	2020-01-31 18:53:35	2020-01-31	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	6373	delivery	5	22
27756	2020-01-31 19:06:19	2020-01-31	8	[{"id_menu":5,"count":1}]	1597	pick-up	0	8
27757	2020-01-31 19:14:11	2020-01-31	8	[{"id_menu":5,"count":1}]	8193	delivery	5	13
27758	2020-01-31 19:17:13	2020-01-31	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	10898	delivery	5	29
27759	2020-01-31 19:24:27	2020-01-31	12	[{"id_menu":1,"count":1}]	2520	pick-up	0	12
27760	2020-01-31 19:37:33	2020-01-31	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	10867	pick-up	0	21
27761	2020-01-31 19:43:59	2020-01-31	14	[{"id_menu":2,"count":1}]	8877	delivery	5	19
27762	2020-01-31 19:51:30	2020-01-31	9	[{"id_menu":6,"count":1}]	10920	delivery	5	14
27763	2020-01-31 19:52:01	2020-01-31	14	[{"id_menu":2,"count":1}]	10142	pick-up	0	14
27764	2020-01-31 19:57:52	2020-01-31	12	[{"id_menu":3,"count":1}]	1077	pick-up	0	12
27765	2020-01-31 20:07:02	2020-01-31	12	[{"id_menu":1,"count":1}]	1719	pick-up	0	12
27766	2020-01-31 20:10:29	2020-01-31	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	10650	delivery	5	26
27767	2020-01-31 20:14:04	2020-01-31	9	[{"id_menu":6,"count":1}]	10903	delivery	5	14
27768	2020-01-31 20:19:55	2020-01-31	8	[{"id_menu":5,"count":2}]	8230	delivery	5	13
27769	2020-01-31 20:21:46	2020-01-31	8	[{"id_menu":5,"count":1}]	3640	pick-up	0	8
27770	2020-01-31 20:23:49	2020-01-31	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	10150	pick-up	0	29
27771	2020-01-31 20:29:59	2020-01-31	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6769	pick-up	0	26
27772	2020-01-31 20:35:08	2020-01-31	14	[{"id_menu":2,"count":1}]	10917	delivery	5	19
27773	2020-01-31 20:35:44	2020-01-31	12	[{"id_menu":3,"count":1}]	10852	pick-up	0	12
27774	2020-01-31 20:40:56	2020-01-31	12	[{"id_menu":1,"count":1}]	10874	delivery	5	17
27775	2020-01-31 20:44:24	2020-01-31	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3527	pick-up	0	23
27776	2020-01-31 20:44:41	2020-01-31	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4177	pick-up	0	35
27777	2020-01-31 20:49:42	2020-01-31	8	[{"id_menu":5,"count":1}]	6102	delivery	5	13
27778	2020-01-31 20:50:56	2020-01-31	17	[{"id_menu":4,"count":1}]	10859	delivery	5	22
27779	2020-01-31 21:07:05	2020-01-31	9	[{"id_menu":7,"count":1}]	2190	pick-up	0	9
27780	2020-01-31 21:10:25	2020-01-31	12	[{"id_menu":3,"count":2}]	10849	delivery	5	17
27781	2020-01-31 21:22:37	2020-01-31	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	5966	delivery	5	28
27782	2020-01-31 21:42:52	2020-01-31	14	[{"id_menu":2,"count":2}]	1867	pick-up	0	14
27783	2020-01-31 21:44:55	2020-01-31	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	10837	pick-up	0	31
27784	2020-01-31 21:57:13	2020-01-31	8	[{"id_menu":5,"count":1}]	10907	delivery	5	13
27785	2020-01-31 22:03:49	2020-01-31	8	[{"id_menu":5,"count":1}]	2153	pick-up	0	8
27786	2020-01-31 22:08:22	2020-01-31	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	10844	pick-up	0	21
27787	2020-01-31 22:34:01	2020-01-31	9	[{"id_menu":6,"count":1}]	150	pick-up	0	9
27788	2020-01-31 22:38:32	2020-01-31	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	10889	delivery	5	26
27789	2020-01-31 22:39:20	2020-01-31	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10911	delivery	5	31
27790	2020-01-31 23:38:07	2020-01-31	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10292	delivery	5	31
27791	2020-01-31 23:40:23	2020-01-31	9	[{"id_menu":6,"count":2}]	7912	delivery	5	14
27792	2020-01-31 23:47:44	2020-01-31	9	[{"id_menu":6,"count":1}]	10906	delivery	5	14
27793	2020-01-31 23:47:46	2020-01-31	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5649	delivery	5	36
27794	2020-01-31 23:48:00	2020-01-31	14	[{"id_menu":2,"count":1}]	3567	pick-up	0	14
27795	2020-02-01 00:06:08	2020-02-01	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4868	delivery	5	36
27796	2020-02-01 00:10:37	2020-02-01	12	[{"id_menu":1,"count":1}]	10935	pick-up	0	12
27797	2020-02-01 00:16:56	2020-02-01	9	[{"id_menu":6,"count":1}]	5203	pick-up	0	9
27798	2020-02-01 00:17:23	2020-02-01	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10964	delivery	5	42
27799	2020-02-01 00:22:36	2020-02-01	8	[{"id_menu":5,"count":1}]	10951	pick-up	0	8
27800	2020-02-01 00:32:58	2020-02-01	14	[{"id_menu":2,"count":1}]	7835	delivery	5	19
27801	2020-02-01 00:35:25	2020-02-01	14	[{"id_menu":2,"count":1}]	10998	delivery	5	19
27802	2020-02-01 00:39:20	2020-02-01	12	[{"id_menu":3,"count":1}]	10971	pick-up	0	12
27803	2020-02-01 00:40:54	2020-02-01	12	[{"id_menu":1,"count":1}]	1432	pick-up	0	12
27804	2020-02-01 00:50:47	2020-02-01	8	[{"id_menu":5,"count":1}]	6998	delivery	5	13
27805	2020-02-01 00:51:21	2020-02-01	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	10984	delivery	5	31
27806	2020-02-01 00:56:48	2020-02-01	12	[{"id_menu":3,"count":1}]	10943	delivery	5	17
27807	2020-02-01 01:10:50	2020-02-01	9	[{"id_menu":6,"count":1}]	10997	delivery	5	14
27808	2020-02-01 01:13:56	2020-02-01	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	11012	delivery	5	27
27809	2020-02-01 01:24:36	2020-02-01	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	10985	pick-up	0	29
27810	2020-02-01 01:28:13	2020-02-01	9	[{"id_menu":7,"count":1}]	4075	pick-up	0	9
27811	2020-02-01 01:40:55	2020-02-01	9	[{"id_menu":7,"count":1}]	10989	delivery	5	14
27812	2020-02-01 01:44:08	2020-02-01	9	[{"id_menu":6,"count":1}]	3198	pick-up	0	9
27813	2020-02-01 01:56:56	2020-02-01	8	[{"id_menu":5,"count":1}]	2694	delivery	5	13
27814	2020-02-01 01:57:21	2020-02-01	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	11001	delivery	5	34
27815	2020-02-01 02:04:56	2020-02-01	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	5089	delivery	5	31
27816	2020-02-01 02:10:54	2020-02-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4562	pick-up	0	23
27817	2020-02-01 02:13:41	2020-02-01	17	[{"id_menu":4,"count":1}]	3668	delivery	5	22
27818	2020-02-01 02:33:43	2020-02-01	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	2799	pick-up	0	26
27819	2020-02-01 02:34:32	2020-02-01	14	[{"id_menu":2,"count":1}]	8747	delivery	5	19
27820	2020-02-01 02:35:07	2020-02-01	9	[{"id_menu":6,"count":1}]	5594	delivery	5	14
27821	2020-02-01 02:47:20	2020-02-01	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	10993	delivery	5	26
27822	2020-02-01 02:52:43	2020-02-01	9	[{"id_menu":7,"count":1}]	10986	delivery	5	14
27823	2020-02-01 02:54:48	2020-02-01	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	11002	delivery	5	26
27824	2020-02-01 02:56:03	2020-02-01	12	[{"id_menu":1,"count":1}]	9266	delivery	5	17
27825	2020-02-01 03:04:08	2020-02-01	14	[{"id_menu":2,"count":1}]	456	pick-up	0	14
27826	2020-02-01 03:05:41	2020-02-01	14	[{"id_menu":2,"count":1}]	10977	pick-up	0	14
27827	2020-02-01 03:06:10	2020-02-01	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	8963	delivery	5	31
27828	2020-02-01 03:07:48	2020-02-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3829	delivery	5	28
27829	2020-02-01 03:08:59	2020-02-01	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	7527	pick-up	0	21
27830	2020-02-01 03:20:39	2020-02-01	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	7044	delivery	5	25
27831	2020-02-01 03:21:43	2020-02-01	9	[{"id_menu":6,"count":1}]	10933	delivery	5	14
27832	2020-02-01 03:25:21	2020-02-01	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7171	delivery	5	43
27833	2020-02-01 03:25:59	2020-02-01	14	[{"id_menu":2,"count":1}]	10996	delivery	5	19
27834	2020-02-01 03:35:29	2020-02-01	9	[{"id_menu":7,"count":1}]	3264	pick-up	0	9
27835	2020-02-01 03:44:43	2020-02-01	12	[{"id_menu":3,"count":1}]	5757	delivery	5	17
27836	2020-02-01 03:45:20	2020-02-01	9	[{"id_menu":6,"count":1}]	5945	pick-up	0	9
27837	2020-02-01 03:47:49	2020-02-01	12	[{"id_menu":3,"count":1}]	5729	delivery	5	17
27838	2020-02-01 03:50:22	2020-02-01	17	[{"id_menu":4,"count":1}]	6589	pick-up	0	17
27839	2020-02-01 03:55:07	2020-02-01	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10969	delivery	5	40
27840	2020-02-01 03:55:34	2020-02-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1806	delivery	5	22
27841	2020-02-01 03:59:36	2020-02-01	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7074	delivery	5	30
27842	2020-02-01 04:01:58	2020-02-01	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	376	delivery	5	31
27843	2020-02-01 04:02:15	2020-02-01	8	[{"id_menu":5,"count":1}]	10974	delivery	5	13
27844	2020-02-01 04:04:17	2020-02-01	8	[{"id_menu":5,"count":1}]	8840	delivery	5	13
27845	2020-02-01 04:10:06	2020-02-01	12	[{"id_menu":1,"count":1}]	10576	delivery	5	17
27846	2020-02-01 04:15:34	2020-02-01	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	8410	delivery	5	26
27847	2020-02-01 04:20:34	2020-02-01	9	[{"id_menu":7,"count":1}]	5180	pick-up	0	9
27848	2020-02-01 04:21:13	2020-02-01	12	[{"id_menu":3,"count":1}]	5461	pick-up	0	12
27849	2020-02-01 04:23:30	2020-02-01	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	1173	delivery	5	29
27850	2020-02-01 04:37:37	2020-02-01	17	[{"id_menu":4,"count":2}]	6033	pick-up	0	17
27851	2020-02-01 04:52:46	2020-02-01	12	[{"id_menu":3,"count":1}]	10983	pick-up	0	12
27852	2020-02-01 04:56:19	2020-02-01	14	[{"id_menu":2,"count":1}]	10972	delivery	5	19
27853	2020-02-01 05:00:51	2020-02-01	12	[{"id_menu":3,"count":1}]	9798	delivery	5	17
27854	2020-02-01 05:02:14	2020-02-01	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	3404	delivery	5	31
27855	2020-02-01 05:09:15	2020-02-01	9	[{"id_menu":7,"count":1}]	4125	delivery	5	14
27856	2020-02-01 05:12:11	2020-02-01	8	[{"id_menu":5,"count":1}]	6201	delivery	5	13
27857	2020-02-01 05:20:35	2020-02-01	8	[{"id_menu":5,"count":1}]	1000	delivery	5	13
27858	2020-02-01 05:23:23	2020-02-01	9	[{"id_menu":6,"count":1}]	6894	delivery	5	14
27859	2020-02-01 05:23:32	2020-02-01	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2601	pick-up	0	21
27860	2020-02-01 05:33:18	2020-02-01	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	10024	delivery	5	31
27861	2020-02-01 05:34:03	2020-02-01	9	[{"id_menu":7,"count":1}]	270	delivery	5	14
27862	2020-02-01 05:37:41	2020-02-01	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	10966	delivery	5	40
27863	2020-02-01 05:43:29	2020-02-01	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":3}]	1355	delivery	5	27
27864	2020-02-01 05:44:12	2020-02-01	9	[{"id_menu":6,"count":1}]	6499	delivery	5	14
27865	2020-02-01 05:49:33	2020-02-01	9	[{"id_menu":6,"count":1}]	3380	pick-up	0	9
27866	2020-02-01 06:03:19	2020-02-01	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	8550	pick-up	0	20
27867	2020-02-01 06:20:35	2020-02-01	12	[{"id_menu":1,"count":2}]	2072	pick-up	0	12
27868	2020-02-01 06:22:53	2020-02-01	12	[{"id_menu":3,"count":1}]	10882	pick-up	0	12
27869	2020-02-01 06:23:55	2020-02-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10979	delivery	5	23
27870	2020-02-01 06:26:03	2020-02-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	10956	delivery	5	26
27871	2020-02-01 06:38:51	2020-02-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10384	pick-up	0	26
27872	2020-02-01 06:46:56	2020-02-01	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5503	pick-up	0	35
27873	2020-02-01 06:54:15	2020-02-01	14	[{"id_menu":2,"count":1}]	1914	pick-up	0	14
27874	2020-02-01 06:54:30	2020-02-01	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	11011	delivery	5	30
27875	2020-02-01 06:55:27	2020-02-01	12	[{"id_menu":3,"count":1}]	9702	delivery	5	17
27876	2020-02-01 07:01:01	2020-02-01	9	[{"id_menu":6,"count":1}]	6242	pick-up	0	9
27877	2020-02-01 07:07:31	2020-02-01	17	[{"id_menu":4,"count":1}]	1829	pick-up	0	17
27878	2020-02-01 07:07:37	2020-02-01	9	[{"id_menu":6,"count":1}]	6694	delivery	5	14
27879	2020-02-01 07:08:31	2020-02-01	14	[{"id_menu":2,"count":1}]	2477	pick-up	0	14
27880	2020-02-01 07:09:16	2020-02-01	14	[{"id_menu":2,"count":1}]	9404	pick-up	0	14
27881	2020-02-01 07:10:41	2020-02-01	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5292	delivery	5	55
27882	2020-02-01 07:10:42	2020-02-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	10975	delivery	5	31
27883	2020-02-01 07:15:28	2020-02-01	9	[{"id_menu":6,"count":2}]	4804	pick-up	0	9
27884	2020-02-01 07:15:55	2020-02-01	12	[{"id_menu":3,"count":1}]	5052	pick-up	0	12
27885	2020-02-01 07:16:57	2020-02-01	9	[{"id_menu":7,"count":2}]	10076	delivery	5	14
27886	2020-02-01 07:19:56	2020-02-01	9	[{"id_menu":6,"count":1}]	11003	delivery	5	14
27887	2020-02-01 07:21:31	2020-02-01	9	[{"id_menu":6,"count":1}]	10948	pick-up	0	9
27888	2020-02-01 07:26:43	2020-02-01	12	[{"id_menu":3,"count":1}]	4846	pick-up	0	12
27889	2020-02-01 07:27:11	2020-02-01	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9563	delivery	5	44
27890	2020-02-01 07:27:54	2020-02-01	12	[{"id_menu":3,"count":1}]	3123	pick-up	0	12
27891	2020-02-01 07:32:58	2020-02-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10999	delivery	5	22
27892	2020-02-01 07:38:07	2020-02-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4120	delivery	5	23
27893	2020-02-01 07:44:18	2020-02-01	9	[{"id_menu":7,"count":1}]	2052	pick-up	0	9
27894	2020-02-01 07:45:03	2020-02-01	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	158	delivery	5	26
27895	2020-02-01 07:50:38	2020-02-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7424	pick-up	0	17
27896	2020-02-01 07:50:48	2020-02-01	9	[{"id_menu":6,"count":1}]	10229	delivery	5	14
27897	2020-02-01 08:00:37	2020-02-01	8	[{"id_menu":5,"count":1}]	3077	pick-up	0	8
27898	2020-02-01 08:19:58	2020-02-01	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	6628	delivery	5	38
27899	2020-02-01 08:25:10	2020-02-01	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10785	pick-up	0	38
27900	2020-02-01 08:38:39	2020-02-01	17	[{"id_menu":4,"count":2}]	4008	delivery	5	22
27901	2020-02-01 08:41:07	2020-02-01	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	5215	delivery	5	31
27902	2020-02-01 08:50:38	2020-02-01	9	[{"id_menu":6,"count":1}]	10717	delivery	5	14
27903	2020-02-01 09:00:18	2020-02-01	9	[{"id_menu":6,"count":1}]	5859	pick-up	0	9
27904	2020-02-01 09:03:02	2020-02-01	9	[{"id_menu":7,"count":1}]	10970	delivery	5	14
27905	2020-02-01 09:10:38	2020-02-01	17	[{"id_menu":4,"count":1}]	766	delivery	5	22
27906	2020-02-01 09:11:33	2020-02-01	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	10458	delivery	5	26
27907	2020-02-01 09:28:17	2020-02-01	12	[{"id_menu":3,"count":1}]	7699	delivery	5	17
27908	2020-02-01 09:28:58	2020-02-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	123	pick-up	0	17
27909	2020-02-01 09:30:31	2020-02-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10480	delivery	5	22
27910	2020-02-01 09:32:58	2020-02-01	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10995	delivery	5	36
27911	2020-02-01 09:33:28	2020-02-01	12	[{"id_menu":1,"count":1}]	1968	pick-up	0	12
27912	2020-02-01 09:34:31	2020-02-01	12	[{"id_menu":1,"count":1}]	1243	delivery	5	17
27913	2020-02-01 09:38:55	2020-02-01	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8584	delivery	5	34
27914	2020-02-01 09:48:46	2020-02-01	9	[{"id_menu":7,"count":1}]	11000	delivery	5	14
27915	2020-02-01 09:50:27	2020-02-01	17	[{"id_menu":4,"count":1}]	477	delivery	5	22
27916	2020-02-01 09:52:04	2020-02-01	12	[{"id_menu":3,"count":1}]	10959	delivery	5	17
27917	2020-02-01 09:57:51	2020-02-01	12	[{"id_menu":1,"count":1}]	832	delivery	5	17
27918	2020-02-01 10:05:09	2020-02-01	14	[{"id_menu":2,"count":1}]	11010	delivery	5	19
27919	2020-02-01 10:06:01	2020-02-01	8	[{"id_menu":5,"count":2}]	3446	delivery	5	13
27920	2020-02-01 10:11:48	2020-02-01	8	[{"id_menu":5,"count":1}]	10988	pick-up	0	8
27921	2020-02-01 10:12:12	2020-02-01	12	[{"id_menu":1,"count":1}]	6347	delivery	5	17
27922	2020-02-01 10:14:31	2020-02-01	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2047	delivery	5	34
27923	2020-02-01 10:22:28	2020-02-01	9	[{"id_menu":6,"count":1}]	5220	delivery	5	14
27924	2020-02-01 10:27:07	2020-02-01	8	[{"id_menu":5,"count":1}]	10987	delivery	5	13
27925	2020-02-01 10:27:22	2020-02-01	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	10961	delivery	5	25
27926	2020-02-01 10:27:35	2020-02-01	25	[{"id_menu":4,"count":3},{"id_menu":5,"count":1}]	8770	delivery	5	30
27927	2020-02-01 10:45:54	2020-02-01	12	[{"id_menu":1,"count":1}]	2320	pick-up	0	12
27928	2020-02-01 10:48:23	2020-02-01	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	382	pick-up	0	38
27929	2020-02-01 10:53:04	2020-02-01	12	[{"id_menu":3,"count":1}]	6173	pick-up	0	12
27930	2020-02-01 10:56:13	2020-02-01	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5050	pick-up	0	38
27931	2020-02-01 10:57:20	2020-02-01	17	[{"id_menu":4,"count":1}]	654	pick-up	0	17
27932	2020-02-01 11:01:44	2020-02-01	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	3493	delivery	5	31
27933	2020-02-01 11:04:03	2020-02-01	9	[{"id_menu":6,"count":1}]	1817	delivery	5	14
27934	2020-02-01 11:05:49	2020-02-01	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	10962	pick-up	0	26
27935	2020-02-01 11:10:06	2020-02-01	9	[{"id_menu":6,"count":1}]	11004	delivery	5	14
27936	2020-02-01 11:21:38	2020-02-01	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	543	delivery	5	26
27937	2020-02-01 11:23:50	2020-02-01	9	[{"id_menu":7,"count":1}]	5303	delivery	5	14
27938	2020-02-01 11:33:21	2020-02-01	12	[{"id_menu":1,"count":1}]	537	pick-up	0	12
27939	2020-02-01 11:33:49	2020-02-01	9	[{"id_menu":6,"count":1}]	3362	delivery	5	14
27940	2020-02-01 11:45:55	2020-02-01	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	10944	delivery	5	40
27941	2020-02-01 11:49:11	2020-02-01	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3651	pick-up	0	29
27942	2020-02-01 11:56:38	2020-02-01	12	[{"id_menu":3,"count":1}]	8145	pick-up	0	12
27943	2020-02-01 12:03:16	2020-02-01	14	[{"id_menu":2,"count":1}]	5790	delivery	5	19
27944	2020-02-01 12:03:59	2020-02-01	9	[{"id_menu":6,"count":1}]	10953	delivery	5	14
27945	2020-02-01 12:12:52	2020-02-01	9	[{"id_menu":7,"count":1}]	4926	delivery	5	14
27946	2020-02-01 12:20:35	2020-02-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7280	delivery	5	22
27947	2020-02-01 12:22:21	2020-02-01	12	[{"id_menu":3,"count":1}]	2967	delivery	5	17
27948	2020-02-01 12:23:29	2020-02-01	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	11007	delivery	5	40
27949	2020-02-01 12:25:49	2020-02-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	11009	delivery	5	23
27950	2020-02-01 12:40:28	2020-02-01	14	[{"id_menu":2,"count":1}]	3915	pick-up	0	14
27951	2020-02-01 12:40:49	2020-02-01	9	[{"id_menu":6,"count":1}]	7764	delivery	5	14
27952	2020-02-01 12:56:26	2020-02-01	12	[{"id_menu":1,"count":1}]	10976	pick-up	0	12
27953	2020-02-01 12:57:16	2020-02-01	12	[{"id_menu":1,"count":1}]	1934	pick-up	0	12
27954	2020-02-01 13:03:05	2020-02-01	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10929	delivery	5	37
27955	2020-02-01 13:09:06	2020-02-01	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	664	delivery	5	27
27956	2020-02-01 13:09:54	2020-02-01	12	[{"id_menu":1,"count":1}]	5521	delivery	5	17
27957	2020-02-01 13:15:31	2020-02-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3995	pick-up	0	31
27958	2020-02-01 13:23:05	2020-02-01	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	10936	delivery	5	40
27959	2020-02-01 13:49:00	2020-02-01	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1062	delivery	5	48
27960	2020-02-01 14:00:18	2020-02-01	14	[{"id_menu":2,"count":1}]	10931	delivery	5	19
27961	2020-02-01 14:04:34	2020-02-01	17	[{"id_menu":4,"count":2}]	531	pick-up	0	17
27962	2020-02-01 14:12:58	2020-02-01	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5970	pick-up	0	35
27963	2020-02-01 14:31:32	2020-02-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4872	pick-up	0	31
27964	2020-02-01 14:36:37	2020-02-01	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	5400	delivery	5	27
27965	2020-02-01 14:36:54	2020-02-01	9	[{"id_menu":7,"count":1}]	11006	delivery	5	14
27966	2020-02-01 14:39:29	2020-02-01	17	[{"id_menu":4,"count":1}]	2207	delivery	5	22
27967	2020-02-01 14:41:24	2020-02-01	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11014	delivery	5	34
27968	2020-02-01 14:42:04	2020-02-01	8	[{"id_menu":5,"count":1}]	8597	delivery	5	13
27969	2020-02-01 14:43:30	2020-02-01	14	[{"id_menu":2,"count":1}]	8638	delivery	5	19
27970	2020-02-01 14:48:03	2020-02-01	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	9489	delivery	5	43
27971	2020-02-01 14:52:38	2020-02-01	8	[{"id_menu":5,"count":1}]	2540	pick-up	0	8
27972	2020-02-01 14:56:22	2020-02-01	14	[{"id_menu":2,"count":1}]	2415	delivery	5	19
27973	2020-02-01 15:14:23	2020-02-01	12	[{"id_menu":1,"count":1}]	4867	pick-up	0	12
27974	2020-02-01 15:15:22	2020-02-01	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	7662	pick-up	0	22
27975	2020-02-01 15:22:09	2020-02-01	14	[{"id_menu":2,"count":1}]	8985	pick-up	0	14
27976	2020-02-01 15:28:39	2020-02-01	17	[{"id_menu":4,"count":1}]	10952	delivery	5	22
27977	2020-02-01 15:39:22	2020-02-01	14	[{"id_menu":2,"count":1}]	5498	pick-up	0	14
27978	2020-02-01 15:43:03	2020-02-01	12	[{"id_menu":1,"count":1}]	81	delivery	5	17
27979	2020-02-01 15:43:49	2020-02-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10947	delivery	5	31
27980	2020-02-01 15:45:34	2020-02-01	12	[{"id_menu":1,"count":1}]	5141	pick-up	0	12
27981	2020-02-01 15:48:44	2020-02-01	14	[{"id_menu":2,"count":1}]	5097	delivery	5	19
27982	2020-02-01 15:56:23	2020-02-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	9198	pick-up	0	31
27983	2020-02-01 16:13:42	2020-02-01	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	7206	pick-up	0	20
27984	2020-02-01 16:22:34	2020-02-01	14	[{"id_menu":2,"count":1}]	5694	delivery	5	19
27985	2020-02-01 16:24:41	2020-02-01	14	[{"id_menu":2,"count":1}]	7262	delivery	5	19
27986	2020-02-01 16:29:12	2020-02-01	17	[{"id_menu":4,"count":1}]	676	delivery	5	22
27987	2020-02-01 16:36:17	2020-02-01	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	207	pick-up	0	25
27988	2020-02-01 16:36:26	2020-02-01	12	[{"id_menu":1,"count":1}]	3125	delivery	5	17
27989	2020-02-01 16:42:55	2020-02-01	17	[{"id_menu":4,"count":1}]	5958	pick-up	0	17
27990	2020-02-01 16:43:16	2020-02-01	12	[{"id_menu":1,"count":1}]	8516	delivery	5	17
27991	2020-02-01 16:45:01	2020-02-01	9	[{"id_menu":7,"count":1}]	9599	delivery	5	14
27992	2020-02-01 16:46:11	2020-02-01	8	[{"id_menu":5,"count":1}]	10930	delivery	5	13
27993	2020-02-01 16:53:50	2020-02-01	17	[{"id_menu":4,"count":1}]	6366	delivery	5	22
27994	2020-02-01 16:54:59	2020-02-01	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3002	pick-up	0	44
27995	2020-02-01 17:15:17	2020-02-01	12	[{"id_menu":1,"count":1}]	1645	pick-up	0	12
27996	2020-02-01 17:18:04	2020-02-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	4459	delivery	5	22
27997	2020-02-01 17:29:58	2020-02-01	8	[{"id_menu":5,"count":1}]	9097	pick-up	0	8
27998	2020-02-01 17:30:55	2020-02-01	9	[{"id_menu":6,"count":1}]	7006	delivery	5	14
27999	2020-02-01 17:33:30	2020-02-01	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	550	delivery	5	36
28000	2020-02-01 17:51:33	2020-02-01	12	[{"id_menu":1,"count":1}]	330	pick-up	0	12
28001	2020-02-01 17:55:40	2020-02-01	9	[{"id_menu":7,"count":1}]	4026	delivery	5	14
28002	2020-02-01 18:02:22	2020-02-01	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7953	delivery	5	40
28003	2020-02-01 18:05:21	2020-02-01	8	[{"id_menu":5,"count":1}]	4281	delivery	5	13
28004	2020-02-01 18:09:58	2020-02-01	9	[{"id_menu":6,"count":1}]	10955	delivery	5	14
28005	2020-02-01 18:11:33	2020-02-01	17	[{"id_menu":4,"count":1}]	10958	pick-up	0	17
28006	2020-02-01 18:22:08	2020-02-01	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	9651	delivery	5	35
28007	2020-02-01 18:24:51	2020-02-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10939	pick-up	0	17
28008	2020-02-01 18:25:10	2020-02-01	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5427	delivery	5	40
28009	2020-02-01 18:33:30	2020-02-01	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	3654	delivery	5	31
28010	2020-02-01 18:33:39	2020-02-01	17	[{"id_menu":4,"count":1}]	10932	delivery	5	22
28011	2020-02-01 18:41:49	2020-02-01	9	[{"id_menu":6,"count":2}]	1605	pick-up	0	9
28012	2020-02-01 18:44:57	2020-02-01	8	[{"id_menu":5,"count":1}]	3068	pick-up	0	8
28013	2020-02-01 19:02:13	2020-02-01	8	[{"id_menu":5,"count":1}]	10694	pick-up	0	8
28014	2020-02-01 19:05:47	2020-02-01	8	[{"id_menu":5,"count":1}]	393	pick-up	0	8
28015	2020-02-01 19:06:03	2020-02-01	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	10125	delivery	5	34
28016	2020-02-01 19:11:56	2020-02-01	9	[{"id_menu":7,"count":2}]	10991	delivery	5	14
28017	2020-02-01 19:17:04	2020-02-01	17	[{"id_menu":4,"count":1}]	2358	delivery	5	22
28018	2020-02-01 19:19:29	2020-02-01	9	[{"id_menu":7,"count":1}]	10938	pick-up	0	9
28019	2020-02-01 19:33:35	2020-02-01	9	[{"id_menu":6,"count":1}]	2560	pick-up	0	9
28020	2020-02-01 19:34:44	2020-02-01	8	[{"id_menu":5,"count":1}]	4463	pick-up	0	8
28021	2020-02-01 19:37:30	2020-02-01	8	[{"id_menu":5,"count":1}]	10994	delivery	5	13
28022	2020-02-01 19:37:33	2020-02-01	17	[{"id_menu":4,"count":1}]	2291	pick-up	0	17
28023	2020-02-01 19:58:45	2020-02-01	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	10981	delivery	5	48
28024	2020-02-01 20:02:18	2020-02-01	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	9160	pick-up	0	23
28025	2020-02-01 20:06:52	2020-02-01	8	[{"id_menu":5,"count":1}]	10946	delivery	5	13
28026	2020-02-01 20:15:16	2020-02-01	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	10941	delivery	5	25
28027	2020-02-01 20:24:45	2020-02-01	17	[{"id_menu":4,"count":1}]	10990	pick-up	0	17
28028	2020-02-01 20:29:51	2020-02-01	17	[{"id_menu":4,"count":1}]	11008	delivery	5	22
28029	2020-02-01 20:41:10	2020-02-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	10957	delivery	5	26
28030	2020-02-01 20:42:23	2020-02-01	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	10960	delivery	5	26
28031	2020-02-01 20:48:45	2020-02-01	14	[{"id_menu":2,"count":1}]	7293	delivery	5	19
28032	2020-02-01 20:49:10	2020-02-01	12	[{"id_menu":3,"count":1}]	5867	delivery	5	17
28033	2020-02-01 20:52:03	2020-02-01	8	[{"id_menu":5,"count":1}]	526	delivery	5	13
28034	2020-02-01 20:56:08	2020-02-01	9	[{"id_menu":6,"count":1}]	10190	delivery	5	14
28035	2020-02-01 20:58:49	2020-02-01	9	[{"id_menu":6,"count":1}]	10949	delivery	5	14
28036	2020-02-01 20:59:12	2020-02-01	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10934	delivery	5	34
28037	2020-02-01 21:02:57	2020-02-01	14	[{"id_menu":2,"count":1}]	2932	pick-up	0	14
28038	2020-02-01 21:04:55	2020-02-01	17	[{"id_menu":4,"count":1}]	10942	delivery	5	22
28039	2020-02-01 21:11:32	2020-02-01	8	[{"id_menu":5,"count":1}]	10937	delivery	5	13
28040	2020-02-01 21:21:18	2020-02-01	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	10992	delivery	5	25
28041	2020-02-01 21:26:54	2020-02-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9317	delivery	5	22
28042	2020-02-01 21:35:34	2020-02-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	837	pick-up	0	23
28043	2020-02-01 21:35:37	2020-02-01	29	[{"id_menu":3,"count":3},{"id_menu":4,"count":1}]	7963	pick-up	0	29
28044	2020-02-01 21:50:01	2020-02-01	12	[{"id_menu":1,"count":1}]	10828	pick-up	0	12
28045	2020-02-01 21:57:45	2020-02-01	17	[{"id_menu":4,"count":1}]	10968	pick-up	0	17
28046	2020-02-01 21:59:12	2020-02-01	9	[{"id_menu":7,"count":1}]	1880	delivery	5	14
28047	2020-02-01 22:10:18	2020-02-01	12	[{"id_menu":1,"count":1}]	10965	delivery	5	17
28048	2020-02-01 22:14:35	2020-02-01	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	34	pick-up	0	21
28049	2020-02-01 22:21:00	2020-02-01	14	[{"id_menu":2,"count":1}]	6489	pick-up	0	14
28050	2020-02-01 22:21:21	2020-02-01	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6137	pick-up	0	30
28051	2020-02-01 22:27:05	2020-02-01	9	[{"id_menu":7,"count":1}]	5133	pick-up	0	9
28052	2020-02-01 22:36:12	2020-02-01	9	[{"id_menu":7,"count":1}]	10940	pick-up	0	9
28053	2020-02-01 22:38:39	2020-02-01	12	[{"id_menu":1,"count":1}]	9483	pick-up	0	12
28054	2020-02-01 22:40:07	2020-02-01	9	[{"id_menu":6,"count":1}]	6037	pick-up	0	9
28055	2020-02-01 22:40:37	2020-02-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9330	delivery	5	28
28056	2020-02-01 22:47:05	2020-02-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":3}]	7418	delivery	5	26
28057	2020-02-01 22:51:29	2020-02-01	8	[{"id_menu":5,"count":1}]	2681	delivery	5	13
28058	2020-02-01 22:55:15	2020-02-01	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	812	delivery	5	31
28059	2020-02-01 22:56:20	2020-02-01	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10982	delivery	5	44
28060	2020-02-01 22:56:41	2020-02-01	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	808	delivery	5	43
28061	2020-02-01 23:02:41	2020-02-01	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10963	delivery	5	53
28062	2020-02-01 23:05:55	2020-02-01	9	[{"id_menu":6,"count":1}]	7015	delivery	5	14
28063	2020-02-01 23:10:02	2020-02-01	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	10221	delivery	5	25
28064	2020-02-01 23:13:20	2020-02-01	9	[{"id_menu":7,"count":1}]	10973	delivery	5	14
28065	2020-02-01 23:19:21	2020-02-01	12	[{"id_menu":1,"count":1}]	2434	pick-up	0	12
28066	2020-02-01 23:27:53	2020-02-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10954	delivery	5	22
28067	2020-02-01 23:27:57	2020-02-01	8	[{"id_menu":5,"count":1}]	10967	delivery	5	13
28068	2020-02-01 23:42:32	2020-02-01	14	[{"id_menu":2,"count":1}]	1899	pick-up	0	14
28069	2020-02-01 23:47:23	2020-02-01	8	[{"id_menu":5,"count":1}]	11005	pick-up	0	8
28070	2020-02-01 23:50:24	2020-02-01	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10945	delivery	5	31
28071	2020-02-01 23:54:06	2020-02-01	8	[{"id_menu":5,"count":1}]	9394	pick-up	0	8
28072	2020-02-01 23:54:58	2020-02-01	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	4059	delivery	5	31
28073	2020-02-02 00:00:23	2020-02-02	9	[{"id_menu":7,"count":1}]	3679	delivery	5	14
28074	2020-02-02 00:04:41	2020-02-02	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	11058	delivery	5	26
28075	2020-02-02 00:06:21	2020-02-02	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	671	delivery	5	26
28076	2020-02-02 00:11:12	2020-02-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7081	delivery	5	31
28077	2020-02-02 00:11:19	2020-02-02	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	5898	delivery	5	35
28078	2020-02-02 00:16:15	2020-02-02	9	[{"id_menu":6,"count":1}]	11029	delivery	5	14
28079	2020-02-02 00:16:16	2020-02-02	12	[{"id_menu":1,"count":1}]	11054	delivery	5	17
28080	2020-02-02 00:21:17	2020-02-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	10440	delivery	5	28
28081	2020-02-02 00:27:12	2020-02-02	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	10802	delivery	5	36
28082	2020-02-02 00:37:46	2020-02-02	14	[{"id_menu":2,"count":1}]	4809	delivery	5	19
28083	2020-02-02 00:46:16	2020-02-02	9	[{"id_menu":7,"count":1}]	9321	delivery	5	14
28084	2020-02-02 00:51:41	2020-02-02	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	11020	delivery	5	30
28085	2020-02-02 00:52:16	2020-02-02	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	8490	delivery	5	25
28086	2020-02-02 00:52:32	2020-02-02	17	[{"id_menu":4,"count":1}]	11097	delivery	5	22
28087	2020-02-02 00:54:02	2020-02-02	17	[{"id_menu":4,"count":1}]	11059	delivery	5	22
28088	2020-02-02 01:02:53	2020-02-02	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	11091	pick-up	0	21
28089	2020-02-02 01:08:42	2020-02-02	9	[{"id_menu":7,"count":1}]	6221	pick-up	0	9
28090	2020-02-02 01:08:44	2020-02-02	17	[{"id_menu":4,"count":1}]	7429	pick-up	0	17
28091	2020-02-02 01:15:39	2020-02-02	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6711	pick-up	0	50
28092	2020-02-02 01:16:16	2020-02-02	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1464	pick-up	0	26
28093	2020-02-02 01:18:30	2020-02-02	12	[{"id_menu":3,"count":1}]	2350	delivery	5	17
28094	2020-02-02 01:20:57	2020-02-02	17	[{"id_menu":4,"count":1}]	5047	pick-up	0	17
28095	2020-02-02 01:23:02	2020-02-02	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	7237	delivery	5	28
28096	2020-02-02 01:30:23	2020-02-02	12	[{"id_menu":1,"count":1}]	11071	pick-up	0	12
28097	2020-02-02 01:35:39	2020-02-02	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2442	pick-up	0	21
28098	2020-02-02 01:43:54	2020-02-02	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	3566	delivery	5	26
28099	2020-02-02 01:54:17	2020-02-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7018	delivery	5	22
28100	2020-02-02 01:58:39	2020-02-02	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	9642	delivery	5	26
28101	2020-02-02 02:08:49	2020-02-02	8	[{"id_menu":5,"count":1}]	3133	delivery	5	13
28102	2020-02-02 02:09:12	2020-02-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6645	pick-up	0	23
28103	2020-02-02 02:11:19	2020-02-02	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	9320	pick-up	0	24
28104	2020-02-02 02:19:54	2020-02-02	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	3934	delivery	5	31
28105	2020-02-02 02:20:53	2020-02-02	9	[{"id_menu":7,"count":1}]	10755	pick-up	0	9
28106	2020-02-02 02:23:18	2020-02-02	8	[{"id_menu":5,"count":1}]	3997	delivery	5	13
28107	2020-02-02 02:23:58	2020-02-02	9	[{"id_menu":7,"count":1}]	5650	pick-up	0	9
28108	2020-02-02 02:35:04	2020-02-02	9	[{"id_menu":7,"count":1}]	11018	delivery	5	14
28109	2020-02-02 02:37:23	2020-02-02	9	[{"id_menu":7,"count":1}]	10600	delivery	5	14
28110	2020-02-02 02:37:25	2020-02-02	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	11069	delivery	5	39
28111	2020-02-02 02:38:37	2020-02-02	12	[{"id_menu":3,"count":1}]	7479	delivery	5	17
28112	2020-02-02 02:42:12	2020-02-02	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3069	pick-up	0	43
28113	2020-02-02 02:50:31	2020-02-02	8	[{"id_menu":5,"count":1}]	11110	delivery	5	13
28114	2020-02-02 02:53:13	2020-02-02	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11021	delivery	5	34
28115	2020-02-02 02:54:06	2020-02-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	9860	delivery	5	22
28116	2020-02-02 02:59:18	2020-02-02	8	[{"id_menu":5,"count":1}]	8166	delivery	5	13
28117	2020-02-02 03:03:59	2020-02-02	14	[{"id_menu":2,"count":1}]	1148	pick-up	0	14
28118	2020-02-02 03:04:12	2020-02-02	12	[{"id_menu":1,"count":1}]	7604	delivery	5	17
28119	2020-02-02 03:06:28	2020-02-02	17	[{"id_menu":4,"count":1}]	6798	pick-up	0	17
28120	2020-02-02 03:20:58	2020-02-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2935	pick-up	0	23
28121	2020-02-02 03:38:54	2020-02-02	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	11049	delivery	5	28
28122	2020-02-02 03:40:11	2020-02-02	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	10895	delivery	5	31
28123	2020-02-02 03:51:03	2020-02-02	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	3150	delivery	5	26
28124	2020-02-02 03:52:39	2020-02-02	9	[{"id_menu":6,"count":1}]	6104	delivery	5	14
28125	2020-02-02 03:57:04	2020-02-02	17	[{"id_menu":4,"count":1}]	5082	pick-up	0	17
28126	2020-02-02 04:07:27	2020-02-02	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	8587	delivery	5	37
28127	2020-02-02 04:21:14	2020-02-02	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	8303	pick-up	0	29
28128	2020-02-02 04:25:49	2020-02-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	11038	delivery	5	31
28129	2020-02-02 04:42:02	2020-02-02	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9352	delivery	5	37
28130	2020-02-02 04:44:32	2020-02-02	12	[{"id_menu":3,"count":1}]	4459	delivery	5	17
28131	2020-02-02 04:44:51	2020-02-02	9	[{"id_menu":6,"count":1}]	10682	delivery	5	14
28132	2020-02-02 04:49:21	2020-02-02	9	[{"id_menu":7,"count":1}]	11022	pick-up	0	9
28133	2020-02-02 04:51:24	2020-02-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7552	delivery	5	23
28134	2020-02-02 04:54:00	2020-02-02	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1368	pick-up	0	30
28135	2020-02-02 04:57:22	2020-02-02	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	7924	delivery	5	31
28136	2020-02-02 05:04:09	2020-02-02	14	[{"id_menu":2,"count":1}]	11089	pick-up	0	14
28137	2020-02-02 05:06:11	2020-02-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11090	delivery	5	31
28138	2020-02-02 05:07:31	2020-02-02	9	[{"id_menu":7,"count":1}]	10392	delivery	5	14
28139	2020-02-02 05:11:19	2020-02-02	14	[{"id_menu":2,"count":1}]	1969	pick-up	0	14
28140	2020-02-02 05:18:49	2020-02-02	14	[{"id_menu":2,"count":1}]	11045	delivery	5	19
28141	2020-02-02 05:28:24	2020-02-02	12	[{"id_menu":1,"count":1}]	4161	delivery	5	17
28142	2020-02-02 05:35:56	2020-02-02	8	[{"id_menu":5,"count":1}]	8899	delivery	5	13
28143	2020-02-02 05:40:00	2020-02-02	12	[{"id_menu":3,"count":1}]	11063	delivery	5	17
28144	2020-02-02 05:52:42	2020-02-02	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1092	pick-up	0	26
28145	2020-02-02 05:55:43	2020-02-02	9	[{"id_menu":7,"count":1}]	265	delivery	5	14
28146	2020-02-02 05:57:41	2020-02-02	14	[{"id_menu":2,"count":1}]	684	delivery	5	19
28147	2020-02-02 05:57:55	2020-02-02	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	11103	delivery	5	31
28148	2020-02-02 05:58:51	2020-02-02	9	[{"id_menu":6,"count":1}]	2252	delivery	5	14
28149	2020-02-02 06:05:28	2020-02-02	17	[{"id_menu":4,"count":1}]	3996	delivery	5	22
28150	2020-02-02 06:05:53	2020-02-02	9	[{"id_menu":7,"count":1}]	1176	pick-up	0	9
28151	2020-02-02 06:07:12	2020-02-02	9	[{"id_menu":7,"count":1}]	7706	delivery	5	14
28152	2020-02-02 06:11:08	2020-02-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2933	pick-up	0	26
28153	2020-02-02 06:20:58	2020-02-02	8	[{"id_menu":5,"count":1}]	11084	delivery	5	13
28154	2020-02-02 06:23:57	2020-02-02	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	10433	delivery	5	39
28155	2020-02-02 06:24:55	2020-02-02	9	[{"id_menu":6,"count":1}]	2470	pick-up	0	9
28156	2020-02-02 06:25:09	2020-02-02	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11093	delivery	5	45
28157	2020-02-02 06:27:56	2020-02-02	17	[{"id_menu":4,"count":1}]	6369	pick-up	0	17
28158	2020-02-02 06:34:18	2020-02-02	8	[{"id_menu":5,"count":1}]	11088	pick-up	0	8
28159	2020-02-02 06:38:03	2020-02-02	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11068	delivery	5	22
28160	2020-02-02 06:38:19	2020-02-02	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	9996	delivery	5	26
28161	2020-02-02 06:41:30	2020-02-02	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2474	delivery	5	26
28162	2020-02-02 06:45:20	2020-02-02	9	[{"id_menu":6,"count":1}]	10617	delivery	5	14
28163	2020-02-02 06:56:37	2020-02-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11095	delivery	5	23
28164	2020-02-02 07:11:57	2020-02-02	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3106	delivery	5	49
28165	2020-02-02 07:16:02	2020-02-02	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	5784	pick-up	0	20
28166	2020-02-02 07:19:00	2020-02-02	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	11039	delivery	5	29
28167	2020-02-02 07:31:45	2020-02-02	9	[{"id_menu":6,"count":1}]	81	pick-up	0	9
28168	2020-02-02 07:34:43	2020-02-02	12	[{"id_menu":1,"count":1}]	1715	pick-up	0	12
28169	2020-02-02 07:38:36	2020-02-02	8	[{"id_menu":5,"count":1}]	1373	pick-up	0	8
28170	2020-02-02 07:38:47	2020-02-02	9	[{"id_menu":6,"count":1}]	2776	pick-up	0	9
28171	2020-02-02 07:47:15	2020-02-02	9	[{"id_menu":7,"count":1}]	3172	pick-up	0	9
28172	2020-02-02 08:00:33	2020-02-02	17	[{"id_menu":4,"count":1}]	3822	pick-up	0	17
28173	2020-02-02 08:05:41	2020-02-02	9	[{"id_menu":6,"count":1}]	11104	delivery	5	14
28174	2020-02-02 08:14:44	2020-02-02	14	[{"id_menu":2,"count":1}]	9303	delivery	5	19
28175	2020-02-02 08:16:07	2020-02-02	9	[{"id_menu":6,"count":1}]	11108	delivery	5	14
28176	2020-02-02 08:22:46	2020-02-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8142	delivery	5	22
28177	2020-02-02 08:33:00	2020-02-02	17	[{"id_menu":4,"count":1}]	10580	delivery	5	22
28178	2020-02-02 08:34:38	2020-02-02	9	[{"id_menu":7,"count":1}]	2119	pick-up	0	9
28179	2020-02-02 08:41:14	2020-02-02	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2698	pick-up	0	21
28180	2020-02-02 08:46:14	2020-02-02	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	11096	delivery	5	26
28181	2020-02-02 08:46:50	2020-02-02	9	[{"id_menu":6,"count":1}]	2830	pick-up	0	9
28182	2020-02-02 08:48:49	2020-02-02	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	8380	delivery	5	40
28183	2020-02-02 08:50:06	2020-02-02	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	11083	delivery	5	31
28184	2020-02-02 08:55:37	2020-02-02	14	[{"id_menu":2,"count":1}]	7550	pick-up	0	14
28185	2020-02-02 08:58:55	2020-02-02	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	5901	pick-up	0	26
28186	2020-02-02 09:09:14	2020-02-02	39	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7603	delivery	5	44
28187	2020-02-02 09:18:58	2020-02-02	9	[{"id_menu":7,"count":1}]	11027	delivery	5	14
28188	2020-02-02 09:19:18	2020-02-02	12	[{"id_menu":3,"count":1}]	11019	delivery	5	17
28189	2020-02-02 09:27:35	2020-02-02	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	11067	delivery	5	26
28190	2020-02-02 09:31:03	2020-02-02	14	[{"id_menu":2,"count":1}]	2658	delivery	5	19
28191	2020-02-02 09:35:12	2020-02-02	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3869	pick-up	0	21
28192	2020-02-02 09:44:09	2020-02-02	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11047	delivery	5	36
28193	2020-02-02 09:45:36	2020-02-02	12	[{"id_menu":1,"count":1}]	11053	delivery	5	17
28194	2020-02-02 09:47:23	2020-02-02	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	8809	delivery	5	36
28195	2020-02-02 09:49:17	2020-02-02	9	[{"id_menu":6,"count":1}]	1380	delivery	5	14
28196	2020-02-02 09:58:01	2020-02-02	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11064	delivery	5	34
28197	2020-02-02 09:58:42	2020-02-02	12	[{"id_menu":1,"count":1}]	11078	delivery	5	17
28198	2020-02-02 10:17:40	2020-02-02	14	[{"id_menu":2,"count":1}]	338	pick-up	0	14
28199	2020-02-02 10:19:35	2020-02-02	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	6255	delivery	5	34
28200	2020-02-02 10:19:55	2020-02-02	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	11081	delivery	5	25
28201	2020-02-02 10:20:19	2020-02-02	8	[{"id_menu":5,"count":1}]	10920	delivery	5	13
28202	2020-02-02 10:24:34	2020-02-02	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	11107	delivery	5	39
28203	2020-02-02 10:26:59	2020-02-02	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	11050	pick-up	0	29
28204	2020-02-02 10:32:05	2020-02-02	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7896	delivery	5	39
28205	2020-02-02 10:36:09	2020-02-02	17	[{"id_menu":4,"count":1}]	833	delivery	5	22
28206	2020-02-02 10:38:32	2020-02-02	17	[{"id_menu":4,"count":1}]	5503	delivery	5	22
28207	2020-02-02 10:40:37	2020-02-02	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	11085	pick-up	0	20
28208	2020-02-02 10:42:03	2020-02-02	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11052	delivery	5	34
28209	2020-02-02 10:52:26	2020-02-02	9	[{"id_menu":7,"count":3}]	11016	delivery	5	14
28210	2020-02-02 10:57:24	2020-02-02	12	[{"id_menu":3,"count":1}]	4615	pick-up	0	12
28211	2020-02-02 10:58:46	2020-02-02	9	[{"id_menu":6,"count":1}]	8418	pick-up	0	9
28212	2020-02-02 11:01:59	2020-02-02	12	[{"id_menu":1,"count":1}]	3604	delivery	5	17
28213	2020-02-02 11:03:36	2020-02-02	12	[{"id_menu":3,"count":1}]	6848	pick-up	0	12
28214	2020-02-02 11:22:32	2020-02-02	8	[{"id_menu":5,"count":3}]	11086	delivery	5	13
28215	2020-02-02 11:24:25	2020-02-02	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	11112	delivery	5	31
28216	2020-02-02 11:25:18	2020-02-02	9	[{"id_menu":6,"count":1}]	11070	delivery	5	14
28217	2020-02-02 11:30:09	2020-02-02	17	[{"id_menu":4,"count":1}]	11032	delivery	5	22
28218	2020-02-02 11:30:31	2020-02-02	14	[{"id_menu":2,"count":1}]	48	pick-up	0	14
28219	2020-02-02 11:32:10	2020-02-02	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	11036	delivery	5	39
28220	2020-02-02 11:33:04	2020-02-02	9	[{"id_menu":7,"count":1}]	9893	delivery	5	14
28221	2020-02-02 11:37:42	2020-02-02	17	[{"id_menu":4,"count":1}]	1654	pick-up	0	17
28222	2020-02-02 11:44:07	2020-02-02	12	[{"id_menu":3,"count":1}]	11035	delivery	5	17
28223	2020-02-02 11:45:25	2020-02-02	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	9107	delivery	5	28
28224	2020-02-02 11:48:32	2020-02-02	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	11098	delivery	5	29
28225	2020-02-02 11:51:28	2020-02-02	14	[{"id_menu":2,"count":1}]	8065	pick-up	0	14
28226	2020-02-02 11:53:04	2020-02-02	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2740	delivery	5	36
28227	2020-02-02 11:54:54	2020-02-02	12	[{"id_menu":1,"count":1}]	10240	delivery	5	17
28228	2020-02-02 12:02:13	2020-02-02	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11066	pick-up	0	31
28229	2020-02-02 12:06:31	2020-02-02	14	[{"id_menu":2,"count":1}]	2498	pick-up	0	14
28230	2020-02-02 12:07:07	2020-02-02	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2134	pick-up	0	26
28231	2020-02-02 12:07:18	2020-02-02	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9296	delivery	5	22
28232	2020-02-02 12:10:53	2020-02-02	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1531	pick-up	0	21
28233	2020-02-02 12:15:24	2020-02-02	9	[{"id_menu":7,"count":1}]	3041	delivery	5	14
28234	2020-02-02 12:18:21	2020-02-02	8	[{"id_menu":5,"count":1}]	4060	delivery	5	13
28235	2020-02-02 12:23:25	2020-02-02	12	[{"id_menu":1,"count":1}]	5915	delivery	5	17
28236	2020-02-02 12:25:08	2020-02-02	17	[{"id_menu":4,"count":1}]	11087	delivery	5	22
28237	2020-02-02 12:28:32	2020-02-02	12	[{"id_menu":3,"count":1}]	9843	delivery	5	17
28238	2020-02-02 12:31:49	2020-02-02	9	[{"id_menu":7,"count":2}]	11017	delivery	5	14
28239	2020-02-02 12:34:54	2020-02-02	17	[{"id_menu":4,"count":1}]	11043	pick-up	0	17
28240	2020-02-02 12:35:29	2020-02-02	12	[{"id_menu":1,"count":1}]	2447	pick-up	0	12
28241	2020-02-02 12:41:42	2020-02-02	9	[{"id_menu":6,"count":1}]	11102	delivery	5	14
28242	2020-02-02 12:43:40	2020-02-02	12	[{"id_menu":1,"count":1}]	9759	delivery	5	17
28243	2020-02-02 12:45:10	2020-02-02	12	[{"id_menu":3,"count":1}]	11080	pick-up	0	12
28244	2020-02-02 12:46:31	2020-02-02	9	[{"id_menu":6,"count":1}]	617	pick-up	0	9
28245	2020-02-02 12:47:02	2020-02-02	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11092	delivery	5	36
28246	2020-02-02 12:50:31	2020-02-02	9	[{"id_menu":7,"count":1}]	4120	pick-up	0	9
28247	2020-02-02 12:53:11	2020-02-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7347	delivery	5	22
28248	2020-02-02 12:58:21	2020-02-02	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":3}]	11042	delivery	5	26
28249	2020-02-02 13:00:22	2020-02-02	9	[{"id_menu":7,"count":1}]	7504	delivery	5	14
28250	2020-02-02 13:06:33	2020-02-02	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	11073	pick-up	0	29
28251	2020-02-02 13:10:34	2020-02-02	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7502	pick-up	0	23
28252	2020-02-02 13:12:38	2020-02-02	17	[{"id_menu":4,"count":1}]	10825	delivery	5	22
28253	2020-02-02 13:26:24	2020-02-02	9	[{"id_menu":7,"count":1}]	172	delivery	5	14
28254	2020-02-02 13:30:12	2020-02-02	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	697	pick-up	0	37
28255	2020-02-02 13:31:41	2020-02-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3471	delivery	5	23
28256	2020-02-02 13:33:58	2020-02-02	14	[{"id_menu":2,"count":1}]	11028	delivery	5	19
28257	2020-02-02 13:39:39	2020-02-02	8	[{"id_menu":5,"count":1}]	5565	delivery	5	13
28258	2020-02-02 13:39:49	2020-02-02	12	[{"id_menu":1,"count":1}]	3160	pick-up	0	12
28259	2020-02-02 13:41:56	2020-02-02	9	[{"id_menu":6,"count":1}]	50	delivery	5	14
28260	2020-02-02 13:43:29	2020-02-02	12	[{"id_menu":3,"count":1}]	10532	delivery	5	17
28261	2020-02-02 13:50:51	2020-02-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	489	pick-up	0	26
28262	2020-02-02 13:56:21	2020-02-02	8	[{"id_menu":5,"count":1}]	423	pick-up	0	8
28263	2020-02-02 14:09:44	2020-02-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	11031	delivery	5	28
28264	2020-02-02 14:24:18	2020-02-02	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4733	delivery	5	31
28265	2020-02-02 14:41:35	2020-02-02	14	[{"id_menu":2,"count":1}]	3873	delivery	5	19
28266	2020-02-02 14:41:46	2020-02-02	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	292	delivery	5	52
28267	2020-02-02 14:42:57	2020-02-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	11100	delivery	5	28
28268	2020-02-02 14:48:16	2020-02-02	9	[{"id_menu":6,"count":1}]	9040	pick-up	0	9
28269	2020-02-02 14:52:32	2020-02-02	9	[{"id_menu":7,"count":1}]	11113	delivery	5	14
28270	2020-02-02 14:55:10	2020-02-02	14	[{"id_menu":2,"count":2}]	5338	pick-up	0	14
28271	2020-02-02 14:56:41	2020-02-02	9	[{"id_menu":7,"count":1}]	638	pick-up	0	9
28272	2020-02-02 15:03:01	2020-02-02	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	300	delivery	5	31
28273	2020-02-02 15:06:46	2020-02-02	12	[{"id_menu":3,"count":1}]	11061	delivery	5	17
28274	2020-02-02 15:09:45	2020-02-02	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	6605	delivery	5	28
28275	2020-02-02 15:20:31	2020-02-02	17	[{"id_menu":4,"count":1}]	4775	delivery	5	22
28276	2020-02-02 15:21:41	2020-02-02	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6951	delivery	5	36
28277	2020-02-02 15:21:56	2020-02-02	14	[{"id_menu":2,"count":1}]	3635	pick-up	0	14
28278	2020-02-02 15:24:46	2020-02-02	8	[{"id_menu":5,"count":1}]	2967	pick-up	0	8
28279	2020-02-02 15:27:10	2020-02-02	14	[{"id_menu":2,"count":2}]	4739	delivery	5	19
28280	2020-02-02 15:36:23	2020-02-02	8	[{"id_menu":5,"count":1}]	9324	delivery	5	13
28281	2020-02-02 15:40:22	2020-02-02	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	3372	pick-up	0	20
28282	2020-02-02 15:41:08	2020-02-02	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	11109	delivery	5	31
28283	2020-02-02 15:47:17	2020-02-02	9	[{"id_menu":6,"count":1}]	4172	delivery	5	14
28284	2020-02-02 15:49:49	2020-02-02	12	[{"id_menu":3,"count":1}]	11034	delivery	5	17
28285	2020-02-02 15:50:27	2020-02-02	12	[{"id_menu":1,"count":1}]	688	delivery	5	17
28286	2020-02-02 15:51:15	2020-02-02	12	[{"id_menu":1,"count":1}]	10853	delivery	5	17
28287	2020-02-02 15:54:48	2020-02-02	8	[{"id_menu":5,"count":1}]	11033	delivery	5	13
28288	2020-02-02 15:55:58	2020-02-02	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	11051	pick-up	0	31
28289	2020-02-02 16:00:26	2020-02-02	12	[{"id_menu":3,"count":1}]	1842	pick-up	0	12
28290	2020-02-02 16:00:29	2020-02-02	9	[{"id_menu":7,"count":1}]	11076	delivery	5	14
28291	2020-02-02 16:00:55	2020-02-02	17	[{"id_menu":4,"count":2}]	11040	pick-up	0	17
28292	2020-02-02 16:02:11	2020-02-02	12	[{"id_menu":1,"count":1}]	10434	delivery	5	17
28293	2020-02-02 16:02:36	2020-02-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	3540	delivery	5	31
28294	2020-02-02 16:03:34	2020-02-02	29	[{"id_menu":3,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11055	delivery	5	34
28295	2020-02-02 16:08:44	2020-02-02	14	[{"id_menu":2,"count":1}]	5311	pick-up	0	14
28296	2020-02-02 16:13:31	2020-02-02	14	[{"id_menu":2,"count":1}]	9483	pick-up	0	14
28297	2020-02-02 16:24:21	2020-02-02	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	3314	pick-up	0	21
28298	2020-02-02 16:25:55	2020-02-02	8	[{"id_menu":5,"count":1}]	3094	delivery	5	13
28299	2020-02-02 16:27:40	2020-02-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2631	pick-up	0	23
28300	2020-02-02 16:30:06	2020-02-02	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10151	pick-up	0	35
28301	2020-02-02 16:30:44	2020-02-02	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	4763	delivery	5	25
28302	2020-02-02 16:37:11	2020-02-02	17	[{"id_menu":4,"count":1}]	5329	delivery	5	22
28303	2020-02-02 16:41:25	2020-02-02	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7870	delivery	5	52
28304	2020-02-02 16:42:27	2020-02-02	12	[{"id_menu":3,"count":1}]	1581	pick-up	0	12
28305	2020-02-02 16:42:45	2020-02-02	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7684	delivery	5	35
28306	2020-02-02 16:49:30	2020-02-02	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2244	delivery	5	40
28307	2020-02-02 16:51:41	2020-02-02	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	8448	pick-up	0	20
28308	2020-02-02 16:58:36	2020-02-02	14	[{"id_menu":2,"count":1}]	11114	pick-up	0	14
28309	2020-02-02 17:11:43	2020-02-02	9	[{"id_menu":7,"count":1}]	11062	delivery	5	14
28310	2020-02-02 17:23:41	2020-02-02	12	[{"id_menu":3,"count":1}]	11079	delivery	5	17
28311	2020-02-02 17:31:22	2020-02-02	9	[{"id_menu":6,"count":1}]	6241	delivery	5	14
28312	2020-02-02 17:42:54	2020-02-02	17	[{"id_menu":4,"count":1}]	5987	pick-up	0	17
28313	2020-02-02 17:48:26	2020-02-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1781	pick-up	0	17
28314	2020-02-02 17:49:24	2020-02-02	9	[{"id_menu":6,"count":2}]	1025	pick-up	0	9
28315	2020-02-02 17:49:58	2020-02-02	12	[{"id_menu":1,"count":1}]	9704	delivery	5	17
28316	2020-02-02 17:54:56	2020-02-02	17	[{"id_menu":4,"count":1}]	6828	delivery	5	22
28317	2020-02-02 17:55:55	2020-02-02	12	[{"id_menu":3,"count":1}]	824	pick-up	0	12
28318	2020-02-02 17:57:56	2020-02-02	12	[{"id_menu":3,"count":1}]	11056	pick-up	0	12
28319	2020-02-02 18:00:43	2020-02-02	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	7046	pick-up	0	20
28320	2020-02-02 18:06:39	2020-02-02	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9997	delivery	5	39
28321	2020-02-02 18:14:09	2020-02-02	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	3887	delivery	5	37
28322	2020-02-02 18:17:50	2020-02-02	17	[{"id_menu":4,"count":1}]	11106	delivery	5	22
28323	2020-02-02 18:39:37	2020-02-02	12	[{"id_menu":1,"count":1}]	970	pick-up	0	12
28324	2020-02-02 18:51:30	2020-02-02	12	[{"id_menu":1,"count":1}]	3383	pick-up	0	12
28325	2020-02-02 18:53:26	2020-02-02	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	5550	delivery	5	34
28326	2020-02-02 18:58:55	2020-02-02	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	11077	delivery	5	36
28327	2020-02-02 19:00:38	2020-02-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10247	delivery	5	22
28328	2020-02-02 19:01:00	2020-02-02	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1427	pick-up	0	26
28329	2020-02-02 19:03:20	2020-02-02	14	[{"id_menu":2,"count":1}]	9804	pick-up	0	14
28330	2020-02-02 19:05:00	2020-02-02	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	10264	pick-up	0	26
28331	2020-02-02 19:19:46	2020-02-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10330	pick-up	0	26
28332	2020-02-02 19:20:25	2020-02-02	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	11048	delivery	5	27
28333	2020-02-02 19:37:45	2020-02-02	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	7318	delivery	5	26
28334	2020-02-02 19:40:58	2020-02-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	11060	delivery	5	28
28335	2020-02-02 19:44:31	2020-02-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	11015	delivery	5	28
28336	2020-02-02 19:47:56	2020-02-02	14	[{"id_menu":2,"count":1}]	11074	delivery	5	19
28337	2020-02-02 19:49:32	2020-02-02	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10436	pick-up	0	26
28338	2020-02-02 19:52:25	2020-02-02	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	11037	delivery	5	28
28339	2020-02-02 20:01:17	2020-02-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	856	delivery	5	31
28340	2020-02-02 20:06:29	2020-02-02	17	[{"id_menu":4,"count":1}]	11026	pick-up	0	17
28341	2020-02-02 20:10:17	2020-02-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10014	delivery	5	31
28342	2020-02-02 20:15:38	2020-02-02	34	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	11030	delivery	5	39
28343	2020-02-02 20:16:50	2020-02-02	9	[{"id_menu":6,"count":1}]	11057	delivery	5	14
28344	2020-02-02 20:18:27	2020-02-02	14	[{"id_menu":2,"count":1}]	11041	delivery	5	19
28345	2020-02-02 20:29:14	2020-02-02	17	[{"id_menu":4,"count":1}]	5826	delivery	5	22
28346	2020-02-02 20:45:23	2020-02-02	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	5571	delivery	5	40
28347	2020-02-02 20:47:42	2020-02-02	9	[{"id_menu":7,"count":1}]	1670	delivery	5	14
28348	2020-02-02 20:47:53	2020-02-02	17	[{"id_menu":4,"count":1}]	10209	delivery	5	22
28349	2020-02-02 20:48:09	2020-02-02	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	4983	delivery	5	23
28350	2020-02-02 20:48:32	2020-02-02	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	11111	pick-up	0	26
28351	2020-02-02 21:08:07	2020-02-02	17	[{"id_menu":4,"count":1}]	11094	delivery	5	22
28352	2020-02-02 21:19:48	2020-02-02	17	[{"id_menu":4,"count":1}]	6965	pick-up	0	17
28353	2020-02-02 21:22:43	2020-02-02	14	[{"id_menu":2,"count":1}]	993	pick-up	0	14
28354	2020-02-02 21:29:36	2020-02-02	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	7187	pick-up	0	21
28355	2020-02-02 21:42:16	2020-02-02	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	11072	delivery	5	40
28356	2020-02-02 21:44:33	2020-02-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	11075	delivery	5	31
28357	2020-02-02 21:44:37	2020-02-02	9	[{"id_menu":7,"count":1}]	9464	delivery	5	14
28358	2020-02-02 21:45:25	2020-02-02	9	[{"id_menu":7,"count":1}]	5508	pick-up	0	9
28359	2020-02-02 21:58:41	2020-02-02	9	[{"id_menu":6,"count":1}]	8655	pick-up	0	9
28360	2020-02-02 22:14:01	2020-02-02	9	[{"id_menu":7,"count":1}]	4703	delivery	5	14
28361	2020-02-02 22:25:33	2020-02-02	12	[{"id_menu":1,"count":1}]	11065	delivery	5	17
28362	2020-02-02 22:26:03	2020-02-02	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1753	delivery	5	26
28363	2020-02-02 22:36:39	2020-02-02	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	11044	delivery	5	42
28364	2020-02-02 22:39:34	2020-02-02	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5668	pick-up	0	50
28365	2020-02-02 22:40:57	2020-02-02	9	[{"id_menu":6,"count":1}]	8726	delivery	5	14
28366	2020-02-02 22:46:51	2020-02-02	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	11046	delivery	5	26
28367	2020-02-02 22:50:17	2020-02-02	12	[{"id_menu":1,"count":1}]	11023	delivery	5	17
28368	2020-02-02 22:53:10	2020-02-02	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1729	pick-up	0	21
28369	2020-02-02 22:55:26	2020-02-02	9	[{"id_menu":7,"count":1}]	3932	delivery	5	14
28370	2020-02-02 22:56:38	2020-02-02	9	[{"id_menu":6,"count":1}]	11082	delivery	5	14
28371	2020-02-02 23:02:44	2020-02-02	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11105	delivery	5	36
28372	2020-02-02 23:03:31	2020-02-02	12	[{"id_menu":1,"count":2}]	7997	delivery	5	17
28373	2020-02-02 23:05:57	2020-02-02	12	[{"id_menu":3,"count":1}]	5308	pick-up	0	12
28374	2020-02-02 23:10:45	2020-02-02	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4314	delivery	5	34
28375	2020-02-02 23:15:24	2020-02-02	14	[{"id_menu":2,"count":2}]	11024	delivery	5	19
28376	2020-02-02 23:21:54	2020-02-02	12	[{"id_menu":1,"count":1}]	1609	pick-up	0	12
28377	2020-02-02 23:23:39	2020-02-02	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11099	delivery	5	45
28378	2020-02-02 23:25:01	2020-02-02	12	[{"id_menu":3,"count":1}]	2943	pick-up	0	12
28379	2020-02-02 23:29:06	2020-02-02	12	[{"id_menu":3,"count":1}]	2855	pick-up	0	12
28380	2020-02-02 23:30:50	2020-02-02	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	4578	pick-up	0	21
28381	2020-02-02 23:33:22	2020-02-02	14	[{"id_menu":2,"count":1}]	11101	delivery	5	19
28382	2020-02-02 23:45:11	2020-02-02	8	[{"id_menu":5,"count":1}]	6166	delivery	5	13
28383	2020-02-02 23:45:28	2020-02-02	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	8651	delivery	5	31
28384	2020-02-02 23:46:03	2020-02-02	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4428	pick-up	0	26
28385	2020-02-02 23:46:15	2020-02-02	9	[{"id_menu":6,"count":1}]	4606	delivery	5	14
28386	2020-02-02 23:50:18	2020-02-02	12	[{"id_menu":1,"count":1}]	6937	delivery	5	17
28387	2020-02-02 23:55:37	2020-02-02	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	11025	delivery	5	25
28388	2020-02-02 23:58:38	2020-02-02	9	[{"id_menu":6,"count":1}]	9038	delivery	5	14
28389	2020-02-03 00:00:02	2020-02-03	30	[{"id_menu":1,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9537	delivery	5	35
28390	2020-02-03 00:15:52	2020-02-03	9	[{"id_menu":7,"count":1}]	9352	delivery	5	14
28391	2020-02-03 00:18:41	2020-02-03	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4343	delivery	5	36
28392	2020-02-03 00:25:02	2020-02-03	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9275	delivery	5	48
28393	2020-02-03 00:28:34	2020-02-03	14	[{"id_menu":2,"count":1}]	9706	pick-up	0	14
28394	2020-02-03 00:37:16	2020-02-03	8	[{"id_menu":5,"count":1}]	11133	delivery	5	13
28395	2020-02-03 00:44:50	2020-02-03	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	11170	delivery	5	48
28396	2020-02-03 00:52:11	2020-02-03	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1313	delivery	5	31
28397	2020-02-03 00:57:02	2020-02-03	14	[{"id_menu":2,"count":1}]	11189	delivery	5	19
28398	2020-02-03 01:42:52	2020-02-03	9	[{"id_menu":7,"count":1}]	4655	delivery	5	14
28399	2020-02-03 01:54:13	2020-02-03	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1282	pick-up	0	18
28400	2020-02-03 02:00:01	2020-02-03	8	[{"id_menu":5,"count":1}]	11145	delivery	5	13
28401	2020-02-03 02:02:35	2020-02-03	17	[{"id_menu":4,"count":1}]	11152	delivery	5	22
28402	2020-02-03 02:17:41	2020-02-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4695	pick-up	0	23
28403	2020-02-03 02:20:39	2020-02-03	9	[{"id_menu":6,"count":1}]	3540	delivery	5	14
28404	2020-02-03 02:23:01	2020-02-03	12	[{"id_menu":3,"count":1}]	6489	delivery	5	17
28405	2020-02-03 02:36:42	2020-02-03	17	[{"id_menu":4,"count":1}]	3229	delivery	5	22
28406	2020-02-03 02:41:13	2020-02-03	14	[{"id_menu":2,"count":1}]	11156	pick-up	0	14
28407	2020-02-03 03:01:50	2020-02-03	9	[{"id_menu":6,"count":1}]	11124	pick-up	0	9
28408	2020-02-03 03:15:00	2020-02-03	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	880	delivery	5	23
28409	2020-02-03 03:25:09	2020-02-03	8	[{"id_menu":5,"count":1}]	10434	delivery	5	13
28410	2020-02-03 03:26:41	2020-02-03	14	[{"id_menu":2,"count":1}]	9160	pick-up	0	14
28411	2020-02-03 03:29:34	2020-02-03	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	128	pick-up	0	29
28412	2020-02-03 03:35:52	2020-02-03	12	[{"id_menu":1,"count":1}]	706	delivery	5	17
28413	2020-02-03 03:41:14	2020-02-03	9	[{"id_menu":6,"count":1}]	2876	delivery	5	14
28414	2020-02-03 03:41:28	2020-02-03	12	[{"id_menu":3,"count":1}]	11116	pick-up	0	12
28415	2020-02-03 03:48:16	2020-02-03	30	[{"id_menu":1,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11144	delivery	5	35
28416	2020-02-03 04:01:06	2020-02-03	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4947	delivery	5	43
28417	2020-02-03 04:08:06	2020-02-03	17	[{"id_menu":4,"count":1}]	8598	pick-up	0	17
28418	2020-02-03 04:24:38	2020-02-03	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	11129	delivery	5	27
28419	2020-02-03 04:25:47	2020-02-03	9	[{"id_menu":7,"count":1}]	3965	delivery	5	14
28420	2020-02-03 04:33:40	2020-02-03	14	[{"id_menu":2,"count":1}]	1258	pick-up	0	14
28421	2020-02-03 04:43:53	2020-02-03	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	518	delivery	5	31
28422	2020-02-03 04:46:16	2020-02-03	9	[{"id_menu":7,"count":1}]	11212	delivery	5	14
28423	2020-02-03 05:26:01	2020-02-03	12	[{"id_menu":1,"count":1}]	11161	delivery	5	17
28424	2020-02-03 05:26:41	2020-02-03	17	[{"id_menu":4,"count":2}]	7145	delivery	5	22
28425	2020-02-03 05:30:42	2020-02-03	14	[{"id_menu":2,"count":1}]	677	delivery	5	19
28426	2020-02-03 05:44:30	2020-02-03	12	[{"id_menu":1,"count":1}]	2965	delivery	5	17
28427	2020-02-03 06:18:23	2020-02-03	17	[{"id_menu":4,"count":1}]	3621	pick-up	0	17
28428	2020-02-03 06:39:18	2020-02-03	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5396	delivery	5	45
28429	2020-02-03 06:40:57	2020-02-03	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4190	delivery	5	36
28430	2020-02-03 06:47:29	2020-02-03	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	5174	delivery	5	26
28431	2020-02-03 06:56:16	2020-02-03	9	[{"id_menu":7,"count":1}]	3604	pick-up	0	9
28432	2020-02-03 06:56:34	2020-02-03	14	[{"id_menu":2,"count":1}]	7931	pick-up	0	14
28433	2020-02-03 07:06:21	2020-02-03	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	6842	pick-up	0	21
28434	2020-02-03 07:07:31	2020-02-03	14	[{"id_menu":2,"count":1}]	3634	pick-up	0	14
28435	2020-02-03 07:08:04	2020-02-03	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	11157	delivery	5	26
28436	2020-02-03 07:25:05	2020-02-03	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	11179	delivery	5	30
28437	2020-02-03 07:26:01	2020-02-03	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6212	delivery	5	43
28438	2020-02-03 07:41:19	2020-02-03	17	[{"id_menu":4,"count":1}]	7182	delivery	5	22
28439	2020-02-03 07:41:26	2020-02-03	8	[{"id_menu":5,"count":1}]	11122	delivery	5	13
28440	2020-02-03 07:50:38	2020-02-03	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	310	pick-up	0	21
28441	2020-02-03 07:53:13	2020-02-03	12	[{"id_menu":3,"count":1}]	338	pick-up	0	12
28442	2020-02-03 08:07:24	2020-02-03	12	[{"id_menu":3,"count":1}]	6666	delivery	5	17
28443	2020-02-03 08:13:24	2020-02-03	9	[{"id_menu":6,"count":1}]	11121	delivery	5	14
28444	2020-02-03 08:18:02	2020-02-03	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3615	pick-up	0	26
28445	2020-02-03 08:18:38	2020-02-03	9	[{"id_menu":6,"count":1}]	11172	delivery	5	14
28446	2020-02-03 08:29:12	2020-02-03	9	[{"id_menu":6,"count":1}]	11143	delivery	5	14
28447	2020-02-03 08:30:52	2020-02-03	9	[{"id_menu":7,"count":1}]	11162	delivery	5	14
28448	2020-02-03 08:34:07	2020-02-03	17	[{"id_menu":4,"count":1}]	11199	pick-up	0	17
28449	2020-02-03 08:40:09	2020-02-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	11215	delivery	5	31
28450	2020-02-03 08:41:01	2020-02-03	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9228	delivery	5	35
28451	2020-02-03 08:47:03	2020-02-03	12	[{"id_menu":1,"count":1}]	11127	pick-up	0	12
28452	2020-02-03 08:59:57	2020-02-03	12	[{"id_menu":1,"count":1}]	1492	delivery	5	17
28453	2020-02-03 09:03:12	2020-02-03	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11186	delivery	5	52
28454	2020-02-03 09:15:27	2020-02-03	12	[{"id_menu":1,"count":1}]	11224	delivery	5	17
28455	2020-02-03 09:22:02	2020-02-03	17	[{"id_menu":4,"count":1}]	2062	pick-up	0	17
28456	2020-02-03 09:23:34	2020-02-03	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	11220	delivery	5	28
28457	2020-02-03 09:56:26	2020-02-03	9	[{"id_menu":7,"count":2}]	1795	pick-up	0	9
28458	2020-02-03 10:08:23	2020-02-03	9	[{"id_menu":6,"count":1}]	5338	pick-up	0	9
28459	2020-02-03 10:11:10	2020-02-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	541	pick-up	0	23
28460	2020-02-03 10:31:07	2020-02-03	14	[{"id_menu":2,"count":1}]	2599	delivery	5	19
28461	2020-02-03 10:58:46	2020-02-03	14	[{"id_menu":2,"count":1}]	4895	delivery	5	19
28462	2020-02-03 11:09:01	2020-02-03	12	[{"id_menu":1,"count":1}]	11200	delivery	5	17
28463	2020-02-03 11:17:00	2020-02-03	17	[{"id_menu":4,"count":1}]	11191	delivery	5	22
28464	2020-02-03 11:28:54	2020-02-03	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	11175	delivery	5	30
28465	2020-02-03 11:38:54	2020-02-03	8	[{"id_menu":5,"count":1}]	11131	pick-up	0	8
28466	2020-02-03 11:48:03	2020-02-03	12	[{"id_menu":1,"count":1}]	5503	pick-up	0	12
28467	2020-02-03 11:50:51	2020-02-03	8	[{"id_menu":5,"count":1}]	9547	delivery	5	13
28468	2020-02-03 12:09:50	2020-02-03	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	11222	delivery	5	43
28469	2020-02-03 12:16:07	2020-02-03	12	[{"id_menu":1,"count":2}]	11218	delivery	5	17
28470	2020-02-03 12:24:05	2020-02-03	9	[{"id_menu":6,"count":1}]	2954	pick-up	0	9
28471	2020-02-03 12:27:14	2020-02-03	17	[{"id_menu":4,"count":1}]	8640	delivery	5	22
28472	2020-02-03 12:27:21	2020-02-03	8	[{"id_menu":5,"count":1}]	11173	pick-up	0	8
28473	2020-02-03 12:28:34	2020-02-03	17	[{"id_menu":4,"count":1}]	11119	delivery	5	22
28474	2020-02-03 12:33:04	2020-02-03	14	[{"id_menu":2,"count":1}]	11203	delivery	5	19
28475	2020-02-03 12:34:28	2020-02-03	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	11139	delivery	5	36
28476	2020-02-03 12:38:31	2020-02-03	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10629	delivery	5	22
28477	2020-02-03 12:57:15	2020-02-03	14	[{"id_menu":2,"count":1}]	8689	delivery	5	19
28478	2020-02-03 13:02:08	2020-02-03	41	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	11141	delivery	5	46
28479	2020-02-03 13:28:53	2020-02-03	9	[{"id_menu":7,"count":3}]	11187	delivery	5	14
28480	2020-02-03 13:39:01	2020-02-03	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11150	delivery	5	39
28481	2020-02-03 13:45:58	2020-02-03	12	[{"id_menu":3,"count":1}]	10244	pick-up	0	12
28482	2020-02-03 13:55:39	2020-02-03	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	7493	pick-up	0	21
28483	2020-02-03 13:56:17	2020-02-03	12	[{"id_menu":3,"count":1}]	11167	delivery	5	17
28484	2020-02-03 14:06:19	2020-02-03	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11160	delivery	5	22
28485	2020-02-03 14:06:23	2020-02-03	8	[{"id_menu":5,"count":1}]	11197	delivery	5	13
28486	2020-02-03 14:13:55	2020-02-03	9	[{"id_menu":7,"count":1}]	694	delivery	5	14
28487	2020-02-03 14:16:05	2020-02-03	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	359	pick-up	0	47
28488	2020-02-03 14:16:29	2020-02-03	12	[{"id_menu":1,"count":1}]	4347	delivery	5	17
28489	2020-02-03 14:21:31	2020-02-03	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2085	pick-up	0	26
28490	2020-02-03 14:22:32	2020-02-03	14	[{"id_menu":2,"count":1}]	11153	delivery	5	19
28491	2020-02-03 15:01:30	2020-02-03	9	[{"id_menu":7,"count":1}]	1289	pick-up	0	9
28492	2020-02-03 15:29:58	2020-02-03	9	[{"id_menu":7,"count":1}]	8798	delivery	5	14
28493	2020-02-03 15:39:52	2020-02-03	12	[{"id_menu":3,"count":1}]	2364	pick-up	0	12
28494	2020-02-03 15:44:08	2020-02-03	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	780	delivery	5	56
28495	2020-02-03 15:58:53	2020-02-03	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2422	delivery	5	26
28496	2020-02-03 16:00:27	2020-02-03	9	[{"id_menu":7,"count":1}]	7438	delivery	5	14
28497	2020-02-03 16:04:48	2020-02-03	12	[{"id_menu":3,"count":1}]	10452	pick-up	0	12
28498	2020-02-03 16:10:02	2020-02-03	9	[{"id_menu":6,"count":1}]	2608	delivery	5	14
28499	2020-02-03 16:15:38	2020-02-03	12	[{"id_menu":3,"count":1}]	3385	pick-up	0	12
28500	2020-02-03 16:16:37	2020-02-03	14	[{"id_menu":2,"count":1}]	343	pick-up	0	14
28501	2020-02-03 16:17:39	2020-02-03	14	[{"id_menu":2,"count":1}]	3847	pick-up	0	14
28502	2020-02-03 16:26:54	2020-02-03	17	[{"id_menu":4,"count":1}]	5501	delivery	5	22
28503	2020-02-03 16:32:14	2020-02-03	9	[{"id_menu":7,"count":1}]	3122	delivery	5	14
28504	2020-02-03 16:32:45	2020-02-03	8	[{"id_menu":5,"count":2}]	2567	pick-up	0	8
28505	2020-02-03 16:37:41	2020-02-03	9	[{"id_menu":6,"count":1}]	6309	delivery	5	14
28506	2020-02-03 16:48:32	2020-02-03	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1666	pick-up	0	31
28507	2020-02-03 16:49:56	2020-02-03	14	[{"id_menu":2,"count":1}]	6838	delivery	5	19
28508	2020-02-03 16:56:21	2020-02-03	8	[{"id_menu":5,"count":1}]	6593	delivery	5	13
28509	2020-02-03 17:04:48	2020-02-03	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1223	delivery	5	26
28510	2020-02-03 17:26:23	2020-02-03	9	[{"id_menu":6,"count":1}]	4685	pick-up	0	9
28511	2020-02-03 17:28:48	2020-02-03	17	[{"id_menu":4,"count":1}]	996	pick-up	0	17
28512	2020-02-03 17:30:35	2020-02-03	17	[{"id_menu":4,"count":1}]	228	pick-up	0	17
28513	2020-02-03 17:40:27	2020-02-03	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1326	delivery	5	23
28514	2020-02-03 17:42:10	2020-02-03	9	[{"id_menu":7,"count":1}]	8206	delivery	5	14
28515	2020-02-03 17:52:09	2020-02-03	12	[{"id_menu":1,"count":1}]	8013	delivery	5	17
28516	2020-02-03 18:10:32	2020-02-03	12	[{"id_menu":3,"count":1}]	5088	delivery	5	17
28517	2020-02-03 18:13:21	2020-02-03	14	[{"id_menu":2,"count":1}]	11190	pick-up	0	14
28518	2020-02-03 18:15:49	2020-02-03	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	9364	delivery	5	37
28519	2020-02-03 18:18:54	2020-02-03	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9705	delivery	5	43
28520	2020-02-03 18:35:54	2020-02-03	12	[{"id_menu":3,"count":1}]	3343	delivery	5	17
28521	2020-02-03 18:54:26	2020-02-03	9	[{"id_menu":6,"count":1}]	2004	pick-up	0	9
28522	2020-02-03 19:02:53	2020-02-03	9	[{"id_menu":6,"count":1}]	11221	delivery	5	14
28523	2020-02-03 19:23:30	2020-02-03	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11178	pick-up	0	50
28524	2020-02-03 19:27:05	2020-02-03	9	[{"id_menu":7,"count":1}]	11198	pick-up	0	9
28525	2020-02-03 19:28:24	2020-02-03	14	[{"id_menu":2,"count":1}]	10548	pick-up	0	14
28526	2020-02-03 19:34:57	2020-02-03	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	4877	delivery	5	34
28527	2020-02-03 19:55:10	2020-02-03	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8884	delivery	5	34
28528	2020-02-03 19:55:30	2020-02-03	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	11128	pick-up	0	21
28529	2020-02-03 20:13:54	2020-02-03	17	[{"id_menu":4,"count":1}]	2471	pick-up	0	17
28530	2020-02-03 20:28:59	2020-02-03	9	[{"id_menu":7,"count":1}]	741	delivery	5	14
28531	2020-02-03 20:51:14	2020-02-03	17	[{"id_menu":4,"count":1}]	5642	delivery	5	22
28532	2020-02-03 20:55:01	2020-02-03	46	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	11130	delivery	5	51
28533	2020-02-03 21:27:30	2020-02-03	17	[{"id_menu":4,"count":1}]	11183	pick-up	0	17
28534	2020-02-03 21:31:51	2020-02-03	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7910	delivery	5	57
28535	2020-02-03 21:48:32	2020-02-03	12	[{"id_menu":3,"count":1}]	5016	delivery	5	17
28536	2020-02-03 21:53:31	2020-02-03	9	[{"id_menu":7,"count":1}]	11126	delivery	5	14
28537	2020-02-03 21:59:38	2020-02-03	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2798	pick-up	0	26
28538	2020-02-03 22:04:05	2020-02-03	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11151	delivery	5	22
28539	2020-02-03 22:06:30	2020-02-03	12	[{"id_menu":3,"count":1}]	3812	delivery	5	17
28540	2020-02-03 22:11:01	2020-02-03	8	[{"id_menu":5,"count":1}]	7021	delivery	5	13
28541	2020-02-03 22:19:39	2020-02-03	12	[{"id_menu":3,"count":1}]	11136	delivery	5	17
28542	2020-02-03 22:29:46	2020-02-03	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	11159	delivery	5	40
28543	2020-02-03 22:29:57	2020-02-03	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	11214	delivery	5	27
28544	2020-02-03 22:33:12	2020-02-03	9	[{"id_menu":7,"count":1}]	8749	delivery	5	14
28545	2020-02-03 22:35:43	2020-02-03	12	[{"id_menu":1,"count":1}]	2995	delivery	5	17
28546	2020-02-03 23:07:14	2020-02-03	9	[{"id_menu":6,"count":1}]	4795	delivery	5	14
28547	2020-02-03 23:27:27	2020-02-03	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9769	delivery	5	57
28548	2020-02-03 23:40:03	2020-02-03	8	[{"id_menu":5,"count":1}]	11118	delivery	5	13
28549	2020-02-03 23:45:22	2020-02-03	9	[{"id_menu":7,"count":1}]	11138	delivery	5	14
28550	2020-02-03 23:45:29	2020-02-03	9	[{"id_menu":7,"count":1}]	169	pick-up	0	9
28551	2020-02-03 23:47:12	2020-02-03	9	[{"id_menu":6,"count":1}]	3485	delivery	5	14
28552	2020-02-03 23:50:07	2020-02-03	9	[{"id_menu":7,"count":1}]	11155	delivery	5	14
28553	2020-02-03 23:50:21	2020-02-03	9	[{"id_menu":7,"count":1}]	2443	pick-up	0	9
28554	2020-02-04 00:00:32	2020-02-04	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	11270	delivery	5	27
28555	2020-02-04 00:04:34	2020-02-04	9	[{"id_menu":7,"count":1}]	3570	pick-up	0	9
28556	2020-02-04 00:10:42	2020-02-04	14	[{"id_menu":2,"count":2}]	11272	pick-up	0	14
28557	2020-02-04 00:16:52	2020-02-04	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3173	delivery	5	51
28558	2020-02-04 00:20:28	2020-02-04	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	11273	delivery	5	36
28559	2020-02-04 00:29:46	2020-02-04	17	[{"id_menu":4,"count":1}]	9415	delivery	5	22
28560	2020-02-04 00:40:22	2020-02-04	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	10879	delivery	5	26
28561	2020-02-04 00:43:16	2020-02-04	17	[{"id_menu":4,"count":1}]	11244	pick-up	0	17
28562	2020-02-04 00:45:52	2020-02-04	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	7677	delivery	5	25
28563	2020-02-04 00:48:59	2020-02-04	12	[{"id_menu":3,"count":1}]	4011	pick-up	0	12
28564	2020-02-04 00:55:04	2020-02-04	12	[{"id_menu":3,"count":1}]	2041	pick-up	0	12
28565	2020-02-04 00:55:31	2020-02-04	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	6277	delivery	5	43
28566	2020-02-04 00:56:10	2020-02-04	14	[{"id_menu":2,"count":1}]	1406	pick-up	0	14
28567	2020-02-04 01:08:24	2020-02-04	8	[{"id_menu":5,"count":1}]	11269	delivery	5	13
28568	2020-02-04 01:22:01	2020-02-04	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3007	pick-up	0	21
28569	2020-02-04 01:39:24	2020-02-04	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5183	delivery	5	36
28570	2020-02-04 01:41:58	2020-02-04	12	[{"id_menu":3,"count":1}]	6470	pick-up	0	12
28571	2020-02-04 01:45:56	2020-02-04	14	[{"id_menu":2,"count":1}]	2677	pick-up	0	14
28572	2020-02-04 01:47:29	2020-02-04	17	[{"id_menu":4,"count":1}]	3825	delivery	5	22
28573	2020-02-04 01:49:12	2020-02-04	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11264	delivery	5	37
28574	2020-02-04 01:51:17	2020-02-04	14	[{"id_menu":2,"count":1}]	4320	delivery	5	19
28575	2020-02-04 01:52:37	2020-02-04	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11227	pick-up	0	17
28576	2020-02-04 02:19:21	2020-02-04	9	[{"id_menu":7,"count":1}]	1687	pick-up	0	9
28577	2020-02-04 02:20:25	2020-02-04	8	[{"id_menu":5,"count":1}]	6641	pick-up	0	8
28578	2020-02-04 02:26:00	2020-02-04	9	[{"id_menu":6,"count":1}]	11276	delivery	5	14
28579	2020-02-04 02:45:11	2020-02-04	12	[{"id_menu":1,"count":1}]	68	delivery	5	17
28580	2020-02-04 02:51:42	2020-02-04	14	[{"id_menu":2,"count":1}]	11250	delivery	5	19
28581	2020-02-04 02:52:22	2020-02-04	12	[{"id_menu":1,"count":1}]	5738	pick-up	0	12
28582	2020-02-04 02:52:38	2020-02-04	9	[{"id_menu":7,"count":1}]	8866	delivery	5	14
28583	2020-02-04 02:57:55	2020-02-04	12	[{"id_menu":3,"count":1}]	11302	delivery	5	17
28584	2020-02-04 03:05:04	2020-02-04	12	[{"id_menu":1,"count":1}]	3863	pick-up	0	12
28585	2020-02-04 03:15:16	2020-02-04	9	[{"id_menu":7,"count":1}]	719	delivery	5	14
28586	2020-02-04 03:24:24	2020-02-04	9	[{"id_menu":7,"count":1}]	8210	delivery	5	14
28587	2020-02-04 03:27:56	2020-02-04	12	[{"id_menu":1,"count":1}]	10904	delivery	5	17
28588	2020-02-04 03:30:47	2020-02-04	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	11251	delivery	5	25
28589	2020-02-04 04:00:48	2020-02-04	8	[{"id_menu":5,"count":1}]	11249	delivery	5	13
28590	2020-02-04 04:00:55	2020-02-04	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7293	delivery	5	22
28591	2020-02-04 04:04:36	2020-02-04	12	[{"id_menu":1,"count":1}]	10101	delivery	5	17
28592	2020-02-04 04:22:56	2020-02-04	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4561	delivery	5	22
28593	2020-02-04 04:32:26	2020-02-04	9	[{"id_menu":6,"count":1}]	5048	pick-up	0	9
28594	2020-02-04 04:35:30	2020-02-04	8	[{"id_menu":5,"count":1}]	813	pick-up	0	8
28595	2020-02-04 04:56:42	2020-02-04	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	9192	delivery	5	23
28596	2020-02-04 05:06:21	2020-02-04	12	[{"id_menu":3,"count":1}]	6739	delivery	5	17
28597	2020-02-04 05:13:30	2020-02-04	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11284	delivery	5	43
28598	2020-02-04 05:17:48	2020-02-04	14	[{"id_menu":2,"count":1}]	11280	delivery	5	19
28599	2020-02-04 05:25:00	2020-02-04	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7053	pick-up	0	26
28600	2020-02-04 05:42:24	2020-02-04	8	[{"id_menu":5,"count":1}]	11290	delivery	5	13
28601	2020-02-04 06:01:52	2020-02-04	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10197	delivery	5	22
28602	2020-02-04 06:06:43	2020-02-04	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2366	pick-up	0	17
28603	2020-02-04 06:17:35	2020-02-04	12	[{"id_menu":3,"count":1}]	659	pick-up	0	12
28604	2020-02-04 06:18:36	2020-02-04	12	[{"id_menu":1,"count":1}]	1682	pick-up	0	12
28605	2020-02-04 06:21:19	2020-02-04	9	[{"id_menu":6,"count":1}]	11248	delivery	5	14
28606	2020-02-04 06:22:36	2020-02-04	9	[{"id_menu":6,"count":1}]	7710	delivery	5	14
28607	2020-02-04 06:29:11	2020-02-04	9	[{"id_menu":6,"count":1}]	11253	pick-up	0	9
28608	2020-02-04 06:49:29	2020-02-04	12	[{"id_menu":1,"count":1}]	7453	delivery	5	17
28609	2020-02-04 07:20:41	2020-02-04	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11233	delivery	5	51
28610	2020-02-04 07:47:06	2020-02-04	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3361	pick-up	0	26
28611	2020-02-04 07:53:01	2020-02-04	8	[{"id_menu":5,"count":1}]	3579	delivery	5	13
28612	2020-02-04 08:21:59	2020-02-04	9	[{"id_menu":7,"count":1}]	1147	delivery	5	14
28613	2020-02-04 08:24:22	2020-02-04	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	11299	pick-up	0	20
28614	2020-02-04 08:35:17	2020-02-04	12	[{"id_menu":1,"count":1}]	324	pick-up	0	12
28615	2020-02-04 08:38:36	2020-02-04	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	11226	delivery	5	26
28616	2020-02-04 08:39:37	2020-02-04	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11246	delivery	5	39
28617	2020-02-04 08:47:45	2020-02-04	9	[{"id_menu":6,"count":1}]	11297	delivery	5	14
28618	2020-02-04 08:56:34	2020-02-04	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11313	delivery	5	34
28619	2020-02-04 08:58:07	2020-02-04	17	[{"id_menu":4,"count":1}]	5721	pick-up	0	17
28620	2020-02-04 09:03:59	2020-02-04	8	[{"id_menu":5,"count":1}]	4555	delivery	5	13
28621	2020-02-04 09:08:16	2020-02-04	12	[{"id_menu":1,"count":1}]	4368	delivery	5	17
28622	2020-02-04 09:21:12	2020-02-04	12	[{"id_menu":3,"count":1}]	11288	delivery	5	17
28623	2020-02-04 09:21:37	2020-02-04	14	[{"id_menu":2,"count":1}]	2894	delivery	5	19
28624	2020-02-04 09:29:14	2020-02-04	12	[{"id_menu":1,"count":1}]	5780	delivery	5	17
28625	2020-02-04 09:31:02	2020-02-04	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11230	delivery	5	31
28626	2020-02-04 09:32:47	2020-02-04	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7928	delivery	5	22
28627	2020-02-04 09:38:21	2020-02-04	12	[{"id_menu":1,"count":1}]	9183	delivery	5	17
28628	2020-02-04 09:45:37	2020-02-04	9	[{"id_menu":7,"count":1}]	11283	delivery	5	14
28629	2020-02-04 09:49:06	2020-02-04	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	10130	delivery	5	31
28630	2020-02-04 09:52:49	2020-02-04	14	[{"id_menu":2,"count":1}]	11257	delivery	5	19
28631	2020-02-04 10:01:58	2020-02-04	9	[{"id_menu":6,"count":1}]	3508	pick-up	0	9
28632	2020-02-04 10:03:05	2020-02-04	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3666	delivery	5	52
28633	2020-02-04 10:03:23	2020-02-04	14	[{"id_menu":2,"count":1}]	3716	pick-up	0	14
28634	2020-02-04 10:12:29	2020-02-04	12	[{"id_menu":3,"count":1}]	1351	delivery	5	17
28635	2020-02-04 10:19:11	2020-02-04	9	[{"id_menu":7,"count":1}]	11296	delivery	5	14
28636	2020-02-04 10:26:23	2020-02-04	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	11254	delivery	5	30
28637	2020-02-04 10:35:59	2020-02-04	9	[{"id_menu":6,"count":1}]	11298	delivery	5	14
28638	2020-02-04 10:47:41	2020-02-04	12	[{"id_menu":3,"count":1}]	1800	delivery	5	17
28639	2020-02-04 10:59:57	2020-02-04	12	[{"id_menu":1,"count":1}]	1854	pick-up	0	12
28640	2020-02-04 11:19:04	2020-02-04	12	[{"id_menu":3,"count":1}]	6328	pick-up	0	12
28641	2020-02-04 11:20:23	2020-02-04	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11231	delivery	5	31
28642	2020-02-04 11:23:40	2020-02-04	12	[{"id_menu":1,"count":1}]	4721	pick-up	0	12
28643	2020-02-04 11:25:37	2020-02-04	14	[{"id_menu":2,"count":1}]	11292	delivery	5	19
28644	2020-02-04 11:27:57	2020-02-04	12	[{"id_menu":3,"count":1}]	3696	pick-up	0	12
28645	2020-02-04 11:35:00	2020-02-04	9	[{"id_menu":6,"count":1}]	7622	delivery	5	14
28646	2020-02-04 11:48:58	2020-02-04	9	[{"id_menu":7,"count":1}]	9295	pick-up	0	9
28647	2020-02-04 11:51:41	2020-02-04	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	8461	delivery	5	26
28648	2020-02-04 11:52:59	2020-02-04	17	[{"id_menu":4,"count":1}]	847	pick-up	0	17
28649	2020-02-04 11:53:43	2020-02-04	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11265	delivery	5	39
28650	2020-02-04 12:17:17	2020-02-04	12	[{"id_menu":1,"count":1}]	4498	delivery	5	17
28651	2020-02-04 12:25:48	2020-02-04	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8994	delivery	5	31
28652	2020-02-04 12:44:33	2020-02-04	12	[{"id_menu":3,"count":1}]	6015	delivery	5	17
28653	2020-02-04 12:45:13	2020-02-04	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	4867	delivery	5	26
28654	2020-02-04 12:46:06	2020-02-04	14	[{"id_menu":2,"count":1}]	10800	pick-up	0	14
28655	2020-02-04 13:28:47	2020-02-04	8	[{"id_menu":5,"count":1}]	2089	pick-up	0	8
28656	2020-02-04 13:29:36	2020-02-04	9	[{"id_menu":6,"count":2}]	897	delivery	5	14
28657	2020-02-04 13:40:08	2020-02-04	8	[{"id_menu":5,"count":1}]	11268	delivery	5	13
28658	2020-02-04 13:42:52	2020-02-04	9	[{"id_menu":6,"count":1}]	9833	delivery	5	14
28659	2020-02-04 13:54:31	2020-02-04	12	[{"id_menu":1,"count":1}]	10951	pick-up	0	12
28660	2020-02-04 14:08:39	2020-02-04	17	[{"id_menu":4,"count":1}]	5439	pick-up	0	17
28661	2020-02-04 14:08:44	2020-02-04	12	[{"id_menu":1,"count":1}]	4827	pick-up	0	12
28662	2020-02-04 14:10:07	2020-02-04	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11234	delivery	5	22
28663	2020-02-04 14:20:49	2020-02-04	9	[{"id_menu":6,"count":1}]	1457	delivery	5	14
28664	2020-02-04 14:25:51	2020-02-04	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	11240	delivery	5	26
28665	2020-02-04 14:25:56	2020-02-04	14	[{"id_menu":2,"count":1}]	11305	pick-up	0	14
28666	2020-02-04 14:29:14	2020-02-04	12	[{"id_menu":3,"count":1}]	213	delivery	5	17
28667	2020-02-04 14:31:45	2020-02-04	9	[{"id_menu":6,"count":1}]	11259	delivery	5	14
28668	2020-02-04 14:48:11	2020-02-04	9	[{"id_menu":7,"count":1}]	4745	delivery	5	14
28669	2020-02-04 14:49:11	2020-02-04	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1233	pick-up	0	22
28670	2020-02-04 15:46:32	2020-02-04	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	8223	delivery	5	40
28671	2020-02-04 15:54:36	2020-02-04	9	[{"id_menu":7,"count":1}]	11285	delivery	5	14
28672	2020-02-04 16:00:58	2020-02-04	9	[{"id_menu":6,"count":2}]	3113	pick-up	0	9
28673	2020-02-04 16:08:33	2020-02-04	12	[{"id_menu":3,"count":1}]	11289	delivery	5	17
28674	2020-02-04 16:15:29	2020-02-04	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	11267	delivery	5	22
28675	2020-02-04 16:16:36	2020-02-04	17	[{"id_menu":4,"count":1}]	1316	pick-up	0	17
28676	2020-02-04 16:25:15	2020-02-04	9	[{"id_menu":7,"count":1}]	10173	delivery	5	14
28677	2020-02-04 16:31:44	2020-02-04	8	[{"id_menu":5,"count":1}]	5996	delivery	5	13
28678	2020-02-04 16:48:03	2020-02-04	8	[{"id_menu":5,"count":1}]	7630	pick-up	0	8
28679	2020-02-04 16:55:08	2020-02-04	17	[{"id_menu":4,"count":1}]	3916	pick-up	0	17
28680	2020-02-04 16:56:40	2020-02-04	8	[{"id_menu":5,"count":1}]	7681	delivery	5	13
28681	2020-02-04 16:59:08	2020-02-04	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5875	pick-up	0	38
28682	2020-02-04 16:59:22	2020-02-04	9	[{"id_menu":6,"count":1}]	9033	delivery	5	14
28683	2020-02-04 17:03:13	2020-02-04	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	11303	delivery	5	44
28684	2020-02-04 17:04:44	2020-02-04	17	[{"id_menu":4,"count":1}]	5033	pick-up	0	17
28685	2020-02-04 17:07:08	2020-02-04	9	[{"id_menu":7,"count":1}]	11275	delivery	5	14
28686	2020-02-04 17:11:46	2020-02-04	14	[{"id_menu":2,"count":1}]	372	delivery	5	19
28687	2020-02-04 17:53:18	2020-02-04	9	[{"id_menu":6,"count":1}]	8911	pick-up	0	9
28688	2020-02-04 17:57:44	2020-02-04	12	[{"id_menu":1,"count":1}]	3871	pick-up	0	12
28689	2020-02-04 18:01:13	2020-02-04	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	9576	delivery	5	26
28690	2020-02-04 18:11:41	2020-02-04	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9798	delivery	5	45
28691	2020-02-04 18:21:37	2020-02-04	12	[{"id_menu":1,"count":1}]	11300	delivery	5	17
28692	2020-02-04 18:27:52	2020-02-04	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11309	delivery	5	36
28693	2020-02-04 18:36:50	2020-02-04	14	[{"id_menu":2,"count":1}]	4920	pick-up	0	14
28694	2020-02-04 18:37:25	2020-02-04	9	[{"id_menu":6,"count":1}]	11291	delivery	5	14
28695	2020-02-04 18:42:52	2020-02-04	9	[{"id_menu":7,"count":1}]	11146	delivery	5	14
28696	2020-02-04 19:05:23	2020-02-04	12	[{"id_menu":3,"count":1}]	7617	delivery	5	17
28697	2020-02-04 19:07:40	2020-02-04	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	8189	pick-up	0	21
28698	2020-02-04 20:01:40	2020-02-04	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	6511	pick-up	0	21
28699	2020-02-04 20:06:43	2020-02-04	9	[{"id_menu":6,"count":1}]	4025	pick-up	0	9
28700	2020-02-04 20:12:07	2020-02-04	14	[{"id_menu":2,"count":1}]	11235	delivery	5	19
28701	2020-02-04 20:12:48	2020-02-04	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10406	pick-up	0	18
28702	2020-02-04 20:13:17	2020-02-04	14	[{"id_menu":2,"count":1}]	11245	delivery	5	19
28703	2020-02-04 20:28:19	2020-02-04	9	[{"id_menu":7,"count":1}]	6444	delivery	5	14
28704	2020-02-04 20:44:40	2020-02-04	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4139	pick-up	0	17
28705	2020-02-04 20:52:55	2020-02-04	9	[{"id_menu":7,"count":1}]	8755	pick-up	0	9
28706	2020-02-04 20:55:13	2020-02-04	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3149	delivery	5	35
28707	2020-02-04 21:02:41	2020-02-04	9	[{"id_menu":6,"count":1}]	11242	delivery	5	14
28708	2020-02-04 21:05:02	2020-02-04	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2725	pick-up	0	17
28709	2020-02-04 21:22:37	2020-02-04	9	[{"id_menu":7,"count":1}]	3645	delivery	5	14
28710	2020-02-04 21:22:59	2020-02-04	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11293	delivery	5	31
28711	2020-02-04 21:23:08	2020-02-04	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	1322	delivery	5	31
28712	2020-02-04 21:27:10	2020-02-04	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3048	delivery	5	31
28713	2020-02-04 21:30:25	2020-02-04	9	[{"id_menu":6,"count":1}]	1415	pick-up	0	9
28714	2020-02-04 21:35:58	2020-02-04	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	684	delivery	5	49
28715	2020-02-04 21:37:32	2020-02-04	12	[{"id_menu":1,"count":1}]	513	delivery	5	17
28716	2020-02-04 21:38:42	2020-02-04	8	[{"id_menu":5,"count":1}]	546	delivery	5	13
28717	2020-02-04 21:39:22	2020-02-04	12	[{"id_menu":1,"count":1}]	584	pick-up	0	12
28718	2020-02-04 21:45:44	2020-02-04	9	[{"id_menu":7,"count":2}]	11262	delivery	5	14
28719	2020-02-04 21:46:55	2020-02-04	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	11256	delivery	5	31
28720	2020-02-04 21:49:39	2020-02-04	14	[{"id_menu":2,"count":1}]	11252	delivery	5	19
28721	2020-02-04 21:51:49	2020-02-04	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2767	delivery	5	28
28722	2020-02-04 22:01:02	2020-02-04	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2731	pick-up	0	31
28723	2020-02-04 22:02:37	2020-02-04	12	[{"id_menu":1,"count":1}]	9854	pick-up	0	12
28724	2020-02-04 22:15:26	2020-02-04	9	[{"id_menu":7,"count":1}]	6471	delivery	5	14
28725	2020-02-04 22:17:03	2020-02-04	12	[{"id_menu":3,"count":1}]	9089	delivery	5	17
28726	2020-02-04 22:25:03	2020-02-04	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	11294	delivery	5	30
28727	2020-02-04 22:26:51	2020-02-04	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11260	delivery	5	31
28728	2020-02-04 22:29:17	2020-02-04	12	[{"id_menu":3,"count":1}]	7247	pick-up	0	12
28729	2020-02-04 22:37:39	2020-02-04	12	[{"id_menu":3,"count":1}]	3241	pick-up	0	12
28730	2020-02-04 22:56:49	2020-02-04	8	[{"id_menu":5,"count":1}]	10331	delivery	5	13
28731	2020-02-04 23:05:38	2020-02-04	12	[{"id_menu":1,"count":1}]	3619	pick-up	0	12
28732	2020-02-04 23:08:29	2020-02-04	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	4869	pick-up	0	30
28733	2020-02-04 23:14:46	2020-02-04	17	[{"id_menu":4,"count":1}]	10394	pick-up	0	17
28734	2020-02-04 23:22:27	2020-02-04	12	[{"id_menu":3,"count":1}]	10532	delivery	5	17
28735	2020-02-04 23:25:05	2020-02-04	14	[{"id_menu":2,"count":1}]	10993	delivery	5	19
28736	2020-02-04 23:30:27	2020-02-04	12	[{"id_menu":3,"count":1}]	11301	delivery	5	17
28737	2020-02-04 23:37:19	2020-02-04	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	1563	delivery	5	36
28738	2020-02-04 23:46:56	2020-02-04	17	[{"id_menu":4,"count":1}]	10798	pick-up	0	17
28739	2020-02-04 23:47:21	2020-02-04	14	[{"id_menu":2,"count":1}]	11255	delivery	5	19
28740	2020-02-05 00:00:33	2020-02-05	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	11378	delivery	5	31
28741	2020-02-05 00:16:42	2020-02-05	9	[{"id_menu":6,"count":1}]	11336	delivery	5	14
28742	2020-02-05 00:19:56	2020-02-05	12	[{"id_menu":1,"count":1}]	946	pick-up	0	12
28743	2020-02-05 00:25:22	2020-02-05	17	[{"id_menu":4,"count":2}]	5387	pick-up	0	17
28744	2020-02-05 00:26:54	2020-02-05	12	[{"id_menu":3,"count":1}]	11326	pick-up	0	12
28745	2020-02-05 00:30:30	2020-02-05	14	[{"id_menu":2,"count":1}]	3660	pick-up	0	14
28746	2020-02-05 00:32:10	2020-02-05	8	[{"id_menu":5,"count":1}]	10444	delivery	5	13
28747	2020-02-05 00:32:17	2020-02-05	12	[{"id_menu":1,"count":1}]	4570	delivery	5	17
28748	2020-02-05 00:45:33	2020-02-05	12	[{"id_menu":3,"count":1}]	7746	pick-up	0	12
28749	2020-02-05 00:46:32	2020-02-05	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	3194	delivery	5	36
28750	2020-02-05 00:48:03	2020-02-05	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8558	delivery	5	40
28751	2020-02-05 00:59:18	2020-02-05	14	[{"id_menu":2,"count":1}]	2168	pick-up	0	14
28752	2020-02-05 01:07:51	2020-02-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10598	delivery	5	31
28753	2020-02-05 01:23:28	2020-02-05	12	[{"id_menu":1,"count":1}]	1373	delivery	5	17
28754	2020-02-05 01:34:23	2020-02-05	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7516	pick-up	0	26
28755	2020-02-05 01:44:05	2020-02-05	17	[{"id_menu":4,"count":1}]	11335	delivery	5	22
28756	2020-02-05 01:49:21	2020-02-05	12	[{"id_menu":3,"count":1}]	6869	delivery	5	17
28757	2020-02-05 01:49:27	2020-02-05	8	[{"id_menu":5,"count":1}]	10369	delivery	5	13
28758	2020-02-05 01:50:29	2020-02-05	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11355	delivery	5	31
28759	2020-02-05 01:57:06	2020-02-05	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11285	delivery	5	31
28760	2020-02-05 01:58:53	2020-02-05	9	[{"id_menu":6,"count":1}]	5886	delivery	5	14
28761	2020-02-05 01:59:55	2020-02-05	12	[{"id_menu":1,"count":1}]	9434	delivery	5	17
28762	2020-02-05 02:13:42	2020-02-05	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11348	delivery	5	39
28763	2020-02-05 02:21:51	2020-02-05	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	5729	pick-up	0	31
28764	2020-02-05 02:23:51	2020-02-05	9	[{"id_menu":6,"count":2}]	1282	pick-up	0	9
28765	2020-02-05 02:36:12	2020-02-05	12	[{"id_menu":3,"count":1}]	7918	pick-up	0	12
28766	2020-02-05 02:45:09	2020-02-05	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	541	pick-up	0	29
28767	2020-02-05 02:49:55	2020-02-05	12	[{"id_menu":1,"count":1}]	1838	pick-up	0	12
28768	2020-02-05 03:01:18	2020-02-05	12	[{"id_menu":1,"count":1}]	1404	delivery	5	17
28769	2020-02-05 03:08:17	2020-02-05	14	[{"id_menu":2,"count":1}]	9139	delivery	5	19
28770	2020-02-05 03:10:30	2020-02-05	9	[{"id_menu":7,"count":1}]	1286	delivery	5	14
28771	2020-02-05 03:19:33	2020-02-05	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1233	delivery	5	38
28772	2020-02-05 03:21:22	2020-02-05	17	[{"id_menu":4,"count":1}]	10212	pick-up	0	17
28773	2020-02-05 03:24:03	2020-02-05	8	[{"id_menu":5,"count":1}]	2943	pick-up	0	8
28774	2020-02-05 03:29:43	2020-02-05	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	11331	delivery	5	27
28775	2020-02-05 03:31:56	2020-02-05	14	[{"id_menu":2,"count":1}]	11330	delivery	5	19
28776	2020-02-05 03:32:55	2020-02-05	14	[{"id_menu":2,"count":2}]	1679	pick-up	0	14
28777	2020-02-05 04:21:18	2020-02-05	12	[{"id_menu":3,"count":1}]	8640	pick-up	0	12
28778	2020-02-05 04:24:07	2020-02-05	9	[{"id_menu":6,"count":1}]	1369	delivery	5	14
28779	2020-02-05 04:24:31	2020-02-05	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	10662	delivery	5	31
28780	2020-02-05 04:29:55	2020-02-05	46	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	11389	delivery	5	51
28781	2020-02-05 04:30:12	2020-02-05	12	[{"id_menu":1,"count":1}]	4477	pick-up	0	12
28782	2020-02-05 04:37:39	2020-02-05	8	[{"id_menu":5,"count":1}]	3350	delivery	5	13
28783	2020-02-05 04:48:44	2020-02-05	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	7533	delivery	5	22
28784	2020-02-05 05:19:12	2020-02-05	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4862	pick-up	0	22
28785	2020-02-05 05:19:26	2020-02-05	12	[{"id_menu":1,"count":1}]	6091	pick-up	0	12
28786	2020-02-05 05:20:45	2020-02-05	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11375	delivery	5	57
28787	2020-02-05 05:21:23	2020-02-05	9	[{"id_menu":7,"count":1}]	11343	pick-up	0	9
28788	2020-02-05 05:23:08	2020-02-05	12	[{"id_menu":3,"count":1}]	5445	delivery	5	17
28789	2020-02-05 05:24:59	2020-02-05	9	[{"id_menu":6,"count":1}]	11251	delivery	5	14
28790	2020-02-05 05:25:00	2020-02-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2706	pick-up	0	17
28791	2020-02-05 05:25:05	2020-02-05	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	9296	delivery	5	29
28792	2020-02-05 05:32:11	2020-02-05	14	[{"id_menu":2,"count":1}]	1314	delivery	5	19
28793	2020-02-05 05:32:41	2020-02-05	14	[{"id_menu":2,"count":1}]	2176	pick-up	0	14
28794	2020-02-05 05:35:43	2020-02-05	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	11347	delivery	5	26
28795	2020-02-05 05:52:46	2020-02-05	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	11328	delivery	5	31
28796	2020-02-05 05:53:43	2020-02-05	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	11349	delivery	5	26
28797	2020-02-05 06:02:25	2020-02-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5096	delivery	5	22
28798	2020-02-05 06:18:31	2020-02-05	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	48	pick-up	0	20
28799	2020-02-05 06:29:13	2020-02-05	8	[{"id_menu":5,"count":1}]	8240	pick-up	0	8
28800	2020-02-05 06:32:21	2020-02-05	17	[{"id_menu":4,"count":1}]	3441	delivery	5	22
28801	2020-02-05 06:37:15	2020-02-05	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7205	delivery	5	37
28802	2020-02-05 06:38:37	2020-02-05	8	[{"id_menu":5,"count":1}]	7844	delivery	5	13
28803	2020-02-05 06:40:59	2020-02-05	9	[{"id_menu":7,"count":1}]	2572	delivery	5	14
28804	2020-02-05 06:45:30	2020-02-05	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1293	delivery	5	40
28805	2020-02-05 06:46:45	2020-02-05	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	7670	delivery	5	34
28806	2020-02-05 06:53:28	2020-02-05	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	11390	delivery	5	31
28807	2020-02-05 06:54:19	2020-02-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	11379	pick-up	0	23
28808	2020-02-05 07:04:57	2020-02-05	9	[{"id_menu":7,"count":1}]	11352	delivery	5	14
28809	2020-02-05 07:11:06	2020-02-05	9	[{"id_menu":6,"count":1}]	3980	pick-up	0	9
28810	2020-02-05 07:12:34	2020-02-05	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11341	delivery	5	34
28811	2020-02-05 07:17:30	2020-02-05	17	[{"id_menu":4,"count":1}]	2276	pick-up	0	17
28812	2020-02-05 07:18:33	2020-02-05	14	[{"id_menu":2,"count":1}]	1431	delivery	5	19
28813	2020-02-05 07:19:36	2020-02-05	14	[{"id_menu":2,"count":1}]	777	delivery	5	19
28814	2020-02-05 07:28:28	2020-02-05	14	[{"id_menu":2,"count":1}]	11388	delivery	5	19
28815	2020-02-05 07:46:06	2020-02-05	14	[{"id_menu":2,"count":1}]	11367	delivery	5	19
28816	2020-02-05 07:54:45	2020-02-05	12	[{"id_menu":1,"count":1}]	3507	delivery	5	17
28817	2020-02-05 07:59:02	2020-02-05	12	[{"id_menu":3,"count":2}]	6282	pick-up	0	12
28818	2020-02-05 08:02:34	2020-02-05	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4284	delivery	5	49
28819	2020-02-05 08:04:15	2020-02-05	8	[{"id_menu":5,"count":1}]	2285	delivery	5	13
28820	2020-02-05 08:21:25	2020-02-05	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	1370	pick-up	0	21
28821	2020-02-05 08:22:22	2020-02-05	9	[{"id_menu":7,"count":1}]	1780	pick-up	0	9
28822	2020-02-05 08:28:00	2020-02-05	9	[{"id_menu":7,"count":1}]	6811	delivery	5	14
28823	2020-02-05 08:32:08	2020-02-05	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11358	delivery	5	40
28824	2020-02-05 08:53:57	2020-02-05	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	145	pick-up	0	29
28825	2020-02-05 08:56:49	2020-02-05	12	[{"id_menu":3,"count":1}]	3578	pick-up	0	12
28826	2020-02-05 09:11:15	2020-02-05	9	[{"id_menu":7,"count":1}]	4946	delivery	5	14
28827	2020-02-05 09:18:06	2020-02-05	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	385	delivery	5	22
28828	2020-02-05 09:21:43	2020-02-05	9	[{"id_menu":6,"count":1}]	2123	pick-up	0	9
28829	2020-02-05 09:36:33	2020-02-05	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	11320	delivery	5	40
28830	2020-02-05 09:41:35	2020-02-05	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	477	pick-up	0	31
28831	2020-02-05 09:44:50	2020-02-05	14	[{"id_menu":2,"count":1}]	1704	pick-up	0	14
28832	2020-02-05 09:46:16	2020-02-05	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5303	delivery	5	31
28833	2020-02-05 09:56:33	2020-02-05	8	[{"id_menu":5,"count":3}]	11371	delivery	5	13
28834	2020-02-05 10:07:01	2020-02-05	8	[{"id_menu":5,"count":1}]	1832	delivery	5	13
28835	2020-02-05 10:13:43	2020-02-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3393	delivery	5	23
28836	2020-02-05 10:16:30	2020-02-05	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	1585	delivery	5	26
28837	2020-02-05 10:17:32	2020-02-05	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1923	delivery	5	37
28838	2020-02-05 10:22:45	2020-02-05	14	[{"id_menu":2,"count":1}]	9300	pick-up	0	14
28839	2020-02-05 10:30:56	2020-02-05	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	6762	delivery	5	39
28840	2020-02-05 10:31:49	2020-02-05	8	[{"id_menu":5,"count":1}]	6690	delivery	5	13
28841	2020-02-05 10:31:58	2020-02-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9647	delivery	5	31
28842	2020-02-05 10:32:09	2020-02-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4639	delivery	5	28
28843	2020-02-05 10:40:28	2020-02-05	9	[{"id_menu":7,"count":1}]	10689	delivery	5	14
28844	2020-02-05 11:01:35	2020-02-05	14	[{"id_menu":2,"count":1}]	2889	pick-up	0	14
28845	2020-02-05 11:01:56	2020-02-05	9	[{"id_menu":7,"count":1}]	11361	delivery	5	14
28846	2020-02-05 11:02:05	2020-02-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	32	pick-up	0	23
28847	2020-02-05 11:02:15	2020-02-05	9	[{"id_menu":6,"count":1}]	4566	pick-up	0	9
28848	2020-02-05 11:03:38	2020-02-05	17	[{"id_menu":4,"count":1}]	11385	delivery	5	22
28849	2020-02-05 11:10:01	2020-02-05	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	5078	delivery	5	25
28850	2020-02-05 11:17:04	2020-02-05	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	11344	delivery	5	34
28851	2020-02-05 11:26:02	2020-02-05	12	[{"id_menu":3,"count":1}]	937	pick-up	0	12
28852	2020-02-05 11:29:02	2020-02-05	8	[{"id_menu":5,"count":1}]	11353	delivery	5	13
28853	2020-02-05 11:34:01	2020-02-05	9	[{"id_menu":6,"count":1}]	7206	pick-up	0	9
28854	2020-02-05 11:48:00	2020-02-05	14	[{"id_menu":2,"count":1}]	5381	delivery	5	19
28855	2020-02-05 11:49:02	2020-02-05	8	[{"id_menu":5,"count":1}]	4307	delivery	5	13
28856	2020-02-05 11:50:02	2020-02-05	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	11172	delivery	5	36
28857	2020-02-05 12:07:22	2020-02-05	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	11342	delivery	5	40
28858	2020-02-05 12:07:50	2020-02-05	17	[{"id_menu":4,"count":1}]	2410	pick-up	0	17
28859	2020-02-05 12:28:23	2020-02-05	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11332	pick-up	0	17
28860	2020-02-05 12:33:45	2020-02-05	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	292	delivery	5	34
28861	2020-02-05 12:44:14	2020-02-05	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6885	delivery	5	30
28862	2020-02-05 12:52:03	2020-02-05	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	11356	pick-up	0	21
28863	2020-02-05 13:02:36	2020-02-05	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	10987	delivery	5	29
28864	2020-02-05 13:05:01	2020-02-05	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11318	pick-up	0	26
28865	2020-02-05 13:05:38	2020-02-05	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11373	delivery	5	31
28866	2020-02-05 13:09:56	2020-02-05	12	[{"id_menu":1,"count":1}]	2951	delivery	5	17
28867	2020-02-05 13:14:19	2020-02-05	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	7220	delivery	5	29
28868	2020-02-05 13:21:32	2020-02-05	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1194	delivery	5	45
28869	2020-02-05 13:27:12	2020-02-05	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	878	pick-up	0	20
28870	2020-02-05 13:47:15	2020-02-05	12	[{"id_menu":1,"count":1}]	11364	delivery	5	17
28871	2020-02-05 13:52:03	2020-02-05	9	[{"id_menu":6,"count":2}]	11350	delivery	5	14
28872	2020-02-05 14:03:02	2020-02-05	12	[{"id_menu":1,"count":1}]	9483	pick-up	0	12
28873	2020-02-05 14:04:35	2020-02-05	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3378	delivery	5	31
28874	2020-02-05 14:06:34	2020-02-05	9	[{"id_menu":7,"count":1}]	5822	delivery	5	14
28875	2020-02-05 14:32:36	2020-02-05	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	11384	delivery	5	36
28876	2020-02-05 14:42:22	2020-02-05	12	[{"id_menu":1,"count":1}]	423	pick-up	0	12
28877	2020-02-05 14:43:37	2020-02-05	17	[{"id_menu":4,"count":1}]	11360	delivery	5	22
28878	2020-02-05 14:55:52	2020-02-05	8	[{"id_menu":5,"count":1}]	8651	delivery	5	13
28879	2020-02-05 14:57:02	2020-02-05	12	[{"id_menu":3,"count":1}]	257	pick-up	0	12
28880	2020-02-05 14:59:37	2020-02-05	17	[{"id_menu":4,"count":1}]	1696	pick-up	0	17
28881	2020-02-05 15:29:51	2020-02-05	9	[{"id_menu":7,"count":1}]	10580	delivery	5	14
28882	2020-02-05 15:33:55	2020-02-05	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1541	pick-up	0	21
28883	2020-02-05 15:51:12	2020-02-05	9	[{"id_menu":7,"count":1}]	4354	delivery	5	14
28884	2020-02-05 15:59:17	2020-02-05	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	5926	delivery	5	40
28885	2020-02-05 15:59:22	2020-02-05	9	[{"id_menu":6,"count":1}]	4913	delivery	5	14
28886	2020-02-05 16:00:58	2020-02-05	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	10159	delivery	5	31
28887	2020-02-05 16:09:27	2020-02-05	14	[{"id_menu":2,"count":1}]	11327	delivery	5	19
28888	2020-02-05 16:14:20	2020-02-05	14	[{"id_menu":2,"count":1}]	11383	pick-up	0	14
28889	2020-02-05 16:19:24	2020-02-05	14	[{"id_menu":2,"count":1}]	11325	delivery	5	19
28890	2020-02-05 16:37:19	2020-02-05	9	[{"id_menu":6,"count":1}]	10032	delivery	5	14
28891	2020-02-05 16:45:10	2020-02-05	17	[{"id_menu":4,"count":1}]	10356	delivery	5	22
28892	2020-02-05 16:49:24	2020-02-05	17	[{"id_menu":4,"count":1}]	11380	delivery	5	22
28893	2020-02-05 16:51:00	2020-02-05	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	7560	delivery	5	26
28894	2020-02-05 16:51:06	2020-02-05	8	[{"id_menu":5,"count":1}]	2193	pick-up	0	8
28895	2020-02-05 16:54:04	2020-02-05	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4982	delivery	5	40
28896	2020-02-05 16:54:11	2020-02-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2287	delivery	5	23
28897	2020-02-05 17:02:18	2020-02-05	9	[{"id_menu":6,"count":1}]	11368	pick-up	0	9
28898	2020-02-05 17:23:37	2020-02-05	12	[{"id_menu":1,"count":1}]	11370	pick-up	0	12
28899	2020-02-05 17:42:07	2020-02-05	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5183	delivery	5	35
28900	2020-02-05 17:49:20	2020-02-05	14	[{"id_menu":2,"count":1}]	10488	delivery	5	19
28901	2020-02-05 17:57:45	2020-02-05	9	[{"id_menu":6,"count":1}]	11338	pick-up	0	9
28902	2020-02-05 18:03:10	2020-02-05	8	[{"id_menu":5,"count":1}]	11322	delivery	5	13
28903	2020-02-05 18:09:10	2020-02-05	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	5144	delivery	5	52
28904	2020-02-05 18:09:50	2020-02-05	17	[{"id_menu":4,"count":1}]	3539	pick-up	0	17
28905	2020-02-05 18:17:09	2020-02-05	12	[{"id_menu":3,"count":2}]	623	pick-up	0	12
28906	2020-02-05 18:22:57	2020-02-05	9	[{"id_menu":7,"count":1}]	7077	delivery	5	14
28907	2020-02-05 18:26:02	2020-02-05	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	9592	delivery	5	26
28908	2020-02-05 18:35:17	2020-02-05	9	[{"id_menu":6,"count":1}]	11365	delivery	5	14
28909	2020-02-05 18:47:53	2020-02-05	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	8631	delivery	5	34
28910	2020-02-05 18:55:09	2020-02-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5478	delivery	5	22
28911	2020-02-05 18:56:20	2020-02-05	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	5453	delivery	5	40
28912	2020-02-05 19:05:38	2020-02-05	14	[{"id_menu":2,"count":1}]	3228	pick-up	0	14
28913	2020-02-05 19:09:59	2020-02-05	9	[{"id_menu":7,"count":1}]	2806	delivery	5	14
28914	2020-02-05 19:10:19	2020-02-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11319	delivery	5	23
28915	2020-02-05 19:19:24	2020-02-05	9	[{"id_menu":7,"count":1}]	11351	delivery	5	14
28916	2020-02-05 19:29:01	2020-02-05	12	[{"id_menu":3,"count":1}]	256	pick-up	0	12
28917	2020-02-05 19:45:36	2020-02-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	11337	delivery	5	23
28918	2020-02-05 19:46:51	2020-02-05	12	[{"id_menu":1,"count":2}]	6543	delivery	5	17
28919	2020-02-05 19:51:27	2020-02-05	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11382	delivery	5	43
28920	2020-02-05 19:58:01	2020-02-05	12	[{"id_menu":1,"count":1}]	71	delivery	5	17
28921	2020-02-05 20:08:26	2020-02-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6568	delivery	5	28
28922	2020-02-05 20:09:50	2020-02-05	8	[{"id_menu":5,"count":1}]	11363	delivery	5	13
28923	2020-02-05 20:10:10	2020-02-05	14	[{"id_menu":2,"count":1}]	11391	delivery	5	19
28924	2020-02-05 20:14:58	2020-02-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7688	delivery	5	28
28925	2020-02-05 20:18:45	2020-02-05	9	[{"id_menu":6,"count":1}]	7156	pick-up	0	9
28926	2020-02-05 20:29:57	2020-02-05	12	[{"id_menu":3,"count":1}]	4782	delivery	5	17
28927	2020-02-05 20:43:45	2020-02-05	9	[{"id_menu":6,"count":1}]	11369	delivery	5	14
28928	2020-02-05 21:00:39	2020-02-05	9	[{"id_menu":7,"count":1}]	11333	delivery	5	14
28929	2020-02-05 21:01:53	2020-02-05	14	[{"id_menu":2,"count":1}]	8783	delivery	5	19
28930	2020-02-05 21:12:33	2020-02-05	9	[{"id_menu":6,"count":1}]	5346	delivery	5	14
28931	2020-02-05 21:12:34	2020-02-05	9	[{"id_menu":6,"count":1}]	11354	delivery	5	14
28932	2020-02-05 21:15:46	2020-02-05	8	[{"id_menu":5,"count":1}]	11377	delivery	5	13
28933	2020-02-05 21:21:00	2020-02-05	14	[{"id_menu":2,"count":1}]	10867	pick-up	0	14
28934	2020-02-05 21:40:38	2020-02-05	14	[{"id_menu":2,"count":1}]	3230	delivery	5	19
28935	2020-02-05 21:50:28	2020-02-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11376	delivery	5	22
28936	2020-02-05 21:53:20	2020-02-05	17	[{"id_menu":4,"count":1}]	7767	delivery	5	22
28937	2020-02-05 22:02:12	2020-02-05	9	[{"id_menu":6,"count":1}]	11316	delivery	5	14
28938	2020-02-05 22:04:29	2020-02-05	8	[{"id_menu":5,"count":1}]	10330	pick-up	0	8
28939	2020-02-05 22:05:51	2020-02-05	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8963	delivery	5	34
28940	2020-02-05 22:07:08	2020-02-05	17	[{"id_menu":4,"count":1}]	6470	pick-up	0	17
28941	2020-02-05 22:25:40	2020-02-05	12	[{"id_menu":3,"count":1}]	5786	delivery	5	17
28942	2020-02-05 22:28:49	2020-02-05	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8380	delivery	5	40
28943	2020-02-05 22:35:56	2020-02-05	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	11314	pick-up	0	29
28944	2020-02-05 22:38:27	2020-02-05	9	[{"id_menu":6,"count":1}]	4342	pick-up	0	9
28945	2020-02-05 22:45:05	2020-02-05	8	[{"id_menu":5,"count":1}]	8726	delivery	5	13
28946	2020-02-05 22:49:12	2020-02-05	12	[{"id_menu":1,"count":1}]	1208	pick-up	0	12
28947	2020-02-05 22:51:53	2020-02-05	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3940	delivery	5	27
28948	2020-02-05 22:56:35	2020-02-05	12	[{"id_menu":3,"count":1}]	11386	delivery	5	17
28949	2020-02-05 23:05:42	2020-02-05	12	[{"id_menu":3,"count":1}]	10068	delivery	5	17
28950	2020-02-05 23:08:50	2020-02-05	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7130	delivery	5	40
28951	2020-02-05 23:16:52	2020-02-05	17	[{"id_menu":4,"count":1}]	6664	delivery	5	22
28952	2020-02-05 23:20:17	2020-02-05	9	[{"id_menu":6,"count":1}]	2730	delivery	5	14
28953	2020-02-05 23:20:52	2020-02-05	9	[{"id_menu":6,"count":1}]	9980	delivery	5	14
28954	2020-02-05 23:35:45	2020-02-05	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11381	delivery	5	43
28955	2020-02-05 23:36:21	2020-02-05	12	[{"id_menu":3,"count":1}]	1097	pick-up	0	12
28956	2020-02-05 23:48:08	2020-02-05	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	11334	delivery	5	31
28957	2020-02-05 23:48:49	2020-02-05	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11372	delivery	5	22
28958	2020-02-05 23:51:44	2020-02-05	9	[{"id_menu":6,"count":1}]	11366	delivery	5	14
28959	2020-02-06 00:01:05	2020-02-06	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	11429	delivery	5	26
28960	2020-02-06 00:03:38	2020-02-06	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	938	delivery	5	26
28961	2020-02-06 00:15:17	2020-02-06	12	[{"id_menu":3,"count":1}]	10088	delivery	5	17
28962	2020-02-06 00:18:07	2020-02-06	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	11427	delivery	5	39
28963	2020-02-06 00:19:22	2020-02-06	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11400	delivery	5	22
28964	2020-02-06 00:27:25	2020-02-06	9	[{"id_menu":6,"count":1}]	11464	delivery	5	14
28965	2020-02-06 00:36:03	2020-02-06	17	[{"id_menu":4,"count":1}]	8155	delivery	5	22
28966	2020-02-06 00:42:12	2020-02-06	12	[{"id_menu":1,"count":1}]	3002	pick-up	0	12
28967	2020-02-06 01:05:32	2020-02-06	8	[{"id_menu":5,"count":1}]	6857	delivery	5	13
28968	2020-02-06 01:05:58	2020-02-06	12	[{"id_menu":1,"count":1}]	3898	pick-up	0	12
28969	2020-02-06 01:06:24	2020-02-06	9	[{"id_menu":7,"count":1}]	11454	pick-up	0	9
28970	2020-02-06 01:08:11	2020-02-06	12	[{"id_menu":1,"count":1}]	2599	delivery	5	17
28971	2020-02-06 01:10:10	2020-02-06	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3241	pick-up	0	25
28972	2020-02-06 01:22:43	2020-02-06	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1896	pick-up	0	18
28973	2020-02-06 01:34:36	2020-02-06	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11466	delivery	5	23
28974	2020-02-06 01:35:25	2020-02-06	9	[{"id_menu":6,"count":1}]	11460	pick-up	0	9
28975	2020-02-06 01:43:30	2020-02-06	14	[{"id_menu":2,"count":1}]	11392	delivery	5	19
28976	2020-02-06 01:54:56	2020-02-06	14	[{"id_menu":2,"count":1}]	9737	delivery	5	19
28977	2020-02-06 02:01:42	2020-02-06	8	[{"id_menu":5,"count":1}]	6173	delivery	5	13
28978	2020-02-06 02:02:11	2020-02-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1747	pick-up	0	23
28979	2020-02-06 02:15:46	2020-02-06	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11437	delivery	5	22
28980	2020-02-06 02:24:35	2020-02-06	12	[{"id_menu":1,"count":1}]	9833	delivery	5	17
28981	2020-02-06 02:24:55	2020-02-06	9	[{"id_menu":6,"count":1}]	11477	delivery	5	14
28982	2020-02-06 02:25:45	2020-02-06	14	[{"id_menu":2,"count":2}]	3820	pick-up	0	14
28983	2020-02-06 02:26:36	2020-02-06	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	11414	delivery	5	36
28984	2020-02-06 02:33:46	2020-02-06	9	[{"id_menu":7,"count":1}]	2623	pick-up	0	9
28985	2020-02-06 02:39:28	2020-02-06	9	[{"id_menu":7,"count":2}]	11451	delivery	5	14
28986	2020-02-06 02:43:49	2020-02-06	8	[{"id_menu":5,"count":1}]	11449	pick-up	0	8
28987	2020-02-06 02:56:16	2020-02-06	9	[{"id_menu":6,"count":1}]	7549	delivery	5	14
28988	2020-02-06 02:57:09	2020-02-06	17	[{"id_menu":4,"count":1}]	2185	pick-up	0	17
28989	2020-02-06 03:01:31	2020-02-06	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11394	delivery	5	31
28990	2020-02-06 03:28:15	2020-02-06	9	[{"id_menu":7,"count":1}]	6187	delivery	5	14
28991	2020-02-06 03:39:16	2020-02-06	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	5250	delivery	5	25
28992	2020-02-06 03:40:10	2020-02-06	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8998	pick-up	0	39
28993	2020-02-06 03:41:45	2020-02-06	14	[{"id_menu":2,"count":1}]	5648	pick-up	0	14
28994	2020-02-06 03:49:18	2020-02-06	17	[{"id_menu":4,"count":1}]	6050	pick-up	0	17
28995	2020-02-06 03:49:21	2020-02-06	17	[{"id_menu":4,"count":1}]	11421	delivery	5	22
28996	2020-02-06 03:58:30	2020-02-06	17	[{"id_menu":4,"count":1}]	2364	delivery	5	22
28997	2020-02-06 03:58:34	2020-02-06	8	[{"id_menu":5,"count":2}]	9976	delivery	5	13
28998	2020-02-06 04:02:41	2020-02-06	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	10848	delivery	5	28
28999	2020-02-06 04:16:09	2020-02-06	9	[{"id_menu":7,"count":1}]	3040	delivery	5	14
29000	2020-02-06 04:21:43	2020-02-06	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	11415	delivery	5	27
29001	2020-02-06 04:28:46	2020-02-06	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9446	delivery	5	30
29002	2020-02-06 04:36:29	2020-02-06	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	11468	delivery	5	26
29003	2020-02-06 04:41:12	2020-02-06	8	[{"id_menu":5,"count":1}]	3147	pick-up	0	8
29004	2020-02-06 04:52:31	2020-02-06	12	[{"id_menu":3,"count":1}]	3227	pick-up	0	12
29005	2020-02-06 04:57:07	2020-02-06	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2320	delivery	5	35
29006	2020-02-06 04:59:36	2020-02-06	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3886	delivery	5	34
29007	2020-02-06 05:00:29	2020-02-06	17	[{"id_menu":4,"count":1}]	9498	delivery	5	22
29008	2020-02-06 05:09:56	2020-02-06	12	[{"id_menu":1,"count":1}]	3332	pick-up	0	12
29009	2020-02-06 05:13:02	2020-02-06	8	[{"id_menu":5,"count":1}]	10964	delivery	5	13
29010	2020-02-06 05:17:00	2020-02-06	17	[{"id_menu":4,"count":1}]	8873	delivery	5	22
29011	2020-02-06 05:19:01	2020-02-06	17	[{"id_menu":4,"count":1}]	5992	delivery	5	22
29012	2020-02-06 05:20:36	2020-02-06	9	[{"id_menu":7,"count":1}]	3172	delivery	5	14
29013	2020-02-06 05:20:56	2020-02-06	9	[{"id_menu":6,"count":2}]	701	pick-up	0	9
29014	2020-02-06 05:21:47	2020-02-06	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	9554	delivery	5	34
29015	2020-02-06 05:32:41	2020-02-06	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	9533	pick-up	0	22
29016	2020-02-06 05:36:04	2020-02-06	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9052	delivery	5	30
29017	2020-02-06 05:47:16	2020-02-06	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	6946	delivery	5	26
29018	2020-02-06 05:48:46	2020-02-06	9	[{"id_menu":7,"count":1}]	150	delivery	5	14
29019	2020-02-06 05:57:22	2020-02-06	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3158	pick-up	0	26
29020	2020-02-06 06:02:57	2020-02-06	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	11343	delivery	5	31
29021	2020-02-06 06:19:05	2020-02-06	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	9079	pick-up	0	31
29022	2020-02-06 06:26:22	2020-02-06	14	[{"id_menu":2,"count":1}]	2333	pick-up	0	14
29023	2020-02-06 06:26:33	2020-02-06	9	[{"id_menu":7,"count":1}]	11408	delivery	5	14
29024	2020-02-06 06:29:50	2020-02-06	14	[{"id_menu":2,"count":1}]	11469	delivery	5	19
29025	2020-02-06 06:31:33	2020-02-06	9	[{"id_menu":6,"count":1}]	10260	delivery	5	14
29026	2020-02-06 06:33:29	2020-02-06	17	[{"id_menu":4,"count":1}]	6482	delivery	5	22
29027	2020-02-06 06:33:57	2020-02-06	17	[{"id_menu":4,"count":1}]	11416	delivery	5	22
29028	2020-02-06 06:34:57	2020-02-06	17	[{"id_menu":4,"count":1}]	4342	pick-up	0	17
29029	2020-02-06 06:35:37	2020-02-06	8	[{"id_menu":5,"count":2}]	10179	delivery	5	13
29030	2020-02-06 06:45:46	2020-02-06	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1061	delivery	5	31
29031	2020-02-06 06:51:31	2020-02-06	17	[{"id_menu":4,"count":1}]	11299	pick-up	0	17
29032	2020-02-06 06:53:11	2020-02-06	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11426	delivery	5	48
29033	2020-02-06 07:14:03	2020-02-06	9	[{"id_menu":7,"count":1}]	11395	pick-up	0	9
29034	2020-02-06 07:23:57	2020-02-06	9	[{"id_menu":7,"count":3}]	11403	delivery	5	14
29035	2020-02-06 07:24:56	2020-02-06	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	9394	delivery	5	34
29036	2020-02-06 07:37:03	2020-02-06	14	[{"id_menu":2,"count":1}]	11456	pick-up	0	14
29037	2020-02-06 07:40:52	2020-02-06	12	[{"id_menu":3,"count":1}]	9134	delivery	5	17
29038	2020-02-06 07:41:16	2020-02-06	14	[{"id_menu":2,"count":1}]	1273	pick-up	0	14
29039	2020-02-06 07:47:39	2020-02-06	9	[{"id_menu":6,"count":1}]	11317	delivery	5	14
29040	2020-02-06 07:47:56	2020-02-06	14	[{"id_menu":2,"count":1}]	11442	delivery	5	19
29041	2020-02-06 07:57:17	2020-02-06	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11441	delivery	5	23
29042	2020-02-06 08:04:45	2020-02-06	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	7690	delivery	5	35
29043	2020-02-06 08:07:55	2020-02-06	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3396	delivery	5	39
29044	2020-02-06 08:14:58	2020-02-06	9	[{"id_menu":7,"count":1}]	9418	delivery	5	14
29045	2020-02-06 08:16:25	2020-02-06	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	8962	delivery	5	25
29046	2020-02-06 08:23:26	2020-02-06	14	[{"id_menu":2,"count":1}]	11445	delivery	5	19
29047	2020-02-06 08:32:13	2020-02-06	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	7541	delivery	5	23
29048	2020-02-06 08:50:11	2020-02-06	9	[{"id_menu":6,"count":1}]	11436	delivery	5	14
29049	2020-02-06 08:58:02	2020-02-06	17	[{"id_menu":4,"count":1}]	11430	delivery	5	22
29050	2020-02-06 08:59:52	2020-02-06	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	7790	delivery	5	28
29051	2020-02-06 09:00:21	2020-02-06	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	8947	delivery	5	28
29052	2020-02-06 09:01:17	2020-02-06	9	[{"id_menu":6,"count":1}]	11476	pick-up	0	9
29053	2020-02-06 09:01:35	2020-02-06	9	[{"id_menu":7,"count":1}]	10953	delivery	5	14
29054	2020-02-06 09:06:48	2020-02-06	17	[{"id_menu":4,"count":1}]	5236	delivery	5	22
29055	2020-02-06 09:08:26	2020-02-06	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11410	delivery	5	49
29056	2020-02-06 09:09:31	2020-02-06	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	4215	delivery	5	37
29057	2020-02-06 09:13:48	2020-02-06	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4309	pick-up	0	29
29058	2020-02-06 09:22:37	2020-02-06	9	[{"id_menu":7,"count":1}]	9352	delivery	5	14
29059	2020-02-06 09:25:22	2020-02-06	9	[{"id_menu":6,"count":1}]	11425	delivery	5	14
29060	2020-02-06 09:42:53	2020-02-06	12	[{"id_menu":1,"count":1}]	1720	delivery	5	17
29061	2020-02-06 09:58:46	2020-02-06	9	[{"id_menu":7,"count":1}]	10354	delivery	5	14
29062	2020-02-06 10:14:07	2020-02-06	12	[{"id_menu":3,"count":2}]	204	pick-up	0	12
29063	2020-02-06 10:17:28	2020-02-06	12	[{"id_menu":3,"count":1}]	9370	pick-up	0	12
29064	2020-02-06 10:20:43	2020-02-06	17	[{"id_menu":4,"count":1}]	71	pick-up	0	17
29065	2020-02-06 10:25:45	2020-02-06	8	[{"id_menu":5,"count":1}]	9696	delivery	5	13
29066	2020-02-06 10:31:32	2020-02-06	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	69	pick-up	0	23
29067	2020-02-06 10:39:59	2020-02-06	17	[{"id_menu":4,"count":1}]	1837	delivery	5	22
29068	2020-02-06 10:43:13	2020-02-06	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	11393	delivery	5	22
29069	2020-02-06 10:48:42	2020-02-06	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	734	pick-up	0	25
29070	2020-02-06 10:52:55	2020-02-06	14	[{"id_menu":2,"count":1}]	3871	pick-up	0	14
29071	2020-02-06 11:06:57	2020-02-06	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	11409	delivery	5	23
29072	2020-02-06 11:08:14	2020-02-06	9	[{"id_menu":6,"count":1}]	7752	delivery	5	14
29073	2020-02-06 11:18:04	2020-02-06	12	[{"id_menu":3,"count":1}]	3449	delivery	5	17
29074	2020-02-06 11:18:37	2020-02-06	9	[{"id_menu":6,"count":1}]	1854	pick-up	0	9
29075	2020-02-06 11:23:26	2020-02-06	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	10532	delivery	5	27
29076	2020-02-06 11:25:48	2020-02-06	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	11419	delivery	5	40
29077	2020-02-06 11:26:15	2020-02-06	12	[{"id_menu":3,"count":1}]	4172	pick-up	0	12
29078	2020-02-06 11:41:34	2020-02-06	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4678	pick-up	0	29
29079	2020-02-06 11:47:22	2020-02-06	12	[{"id_menu":3,"count":1}]	11463	delivery	5	17
29080	2020-02-06 11:48:49	2020-02-06	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	11471	delivery	5	26
29081	2020-02-06 11:51:10	2020-02-06	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	3883	delivery	5	25
29082	2020-02-06 11:52:27	2020-02-06	9	[{"id_menu":7,"count":1}]	11446	delivery	5	14
29083	2020-02-06 12:01:42	2020-02-06	12	[{"id_menu":3,"count":1}]	3444	pick-up	0	12
29084	2020-02-06 12:02:00	2020-02-06	12	[{"id_menu":1,"count":1}]	2191	pick-up	0	12
29085	2020-02-06 12:10:05	2020-02-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5354	pick-up	0	23
29086	2020-02-06 12:13:01	2020-02-06	9	[{"id_menu":7,"count":1}]	10080	delivery	5	14
29087	2020-02-06 12:24:54	2020-02-06	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	11461	delivery	5	36
29088	2020-02-06 12:28:02	2020-02-06	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	8173	delivery	5	31
29089	2020-02-06 12:29:16	2020-02-06	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4929	delivery	5	27
29090	2020-02-06 12:52:49	2020-02-06	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	11398	delivery	5	43
29091	2020-02-06 12:55:01	2020-02-06	9	[{"id_menu":7,"count":1}]	466	delivery	5	14
29092	2020-02-06 12:55:09	2020-02-06	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	8085	delivery	5	36
29093	2020-02-06 13:05:31	2020-02-06	12	[{"id_menu":1,"count":1}]	4810	delivery	5	17
29094	2020-02-06 13:23:40	2020-02-06	12	[{"id_menu":3,"count":1}]	11474	delivery	5	17
29095	2020-02-06 13:31:45	2020-02-06	14	[{"id_menu":2,"count":1}]	11452	pick-up	0	14
29096	2020-02-06 13:36:04	2020-02-06	9	[{"id_menu":7,"count":1}]	9348	pick-up	0	9
29097	2020-02-06 13:44:49	2020-02-06	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	10033	delivery	5	28
29098	2020-02-06 13:45:14	2020-02-06	8	[{"id_menu":5,"count":1}]	11457	delivery	5	13
29099	2020-02-06 13:53:17	2020-02-06	8	[{"id_menu":5,"count":1}]	3117	delivery	5	13
29100	2020-02-06 13:59:44	2020-02-06	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	11428	delivery	5	36
29101	2020-02-06 14:04:42	2020-02-06	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	8640	pick-up	0	47
29102	2020-02-06 14:10:26	2020-02-06	8	[{"id_menu":5,"count":1}]	11440	delivery	5	13
29103	2020-02-06 14:25:31	2020-02-06	8	[{"id_menu":5,"count":1}]	10873	delivery	5	13
29104	2020-02-06 14:43:43	2020-02-06	12	[{"id_menu":3,"count":1}]	2551	pick-up	0	12
29105	2020-02-06 14:48:46	2020-02-06	43	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2761	delivery	5	48
29106	2020-02-06 14:55:28	2020-02-06	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11406	delivery	5	22
29107	2020-02-06 14:58:24	2020-02-06	14	[{"id_menu":2,"count":1}]	6836	delivery	5	19
29108	2020-02-06 15:26:09	2020-02-06	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":2}]	308	delivery	5	31
29109	2020-02-06 15:26:13	2020-02-06	9	[{"id_menu":6,"count":1}]	11478	delivery	5	14
29110	2020-02-06 15:42:02	2020-02-06	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	3768	delivery	5	26
29111	2020-02-06 15:45:13	2020-02-06	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7154	delivery	5	23
29112	2020-02-06 15:49:16	2020-02-06	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	11435	pick-up	0	29
29113	2020-02-06 15:51:09	2020-02-06	12	[{"id_menu":1,"count":1}]	1093	delivery	5	17
29114	2020-02-06 15:58:38	2020-02-06	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1670	pick-up	0	30
29115	2020-02-06 16:02:52	2020-02-06	14	[{"id_menu":2,"count":2}]	9124	delivery	5	19
29116	2020-02-06 16:05:40	2020-02-06	12	[{"id_menu":3,"count":1}]	10632	pick-up	0	12
29117	2020-02-06 16:11:27	2020-02-06	12	[{"id_menu":1,"count":1}]	7891	pick-up	0	12
29118	2020-02-06 16:15:01	2020-02-06	8	[{"id_menu":5,"count":1}]	541	delivery	5	13
29119	2020-02-06 16:15:49	2020-02-06	17	[{"id_menu":4,"count":1}]	8318	delivery	5	22
29120	2020-02-06 16:20:50	2020-02-06	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	11432	pick-up	0	43
29121	2020-02-06 16:23:32	2020-02-06	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6182	pick-up	0	17
29122	2020-02-06 16:34:56	2020-02-06	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	3140	delivery	5	43
29123	2020-02-06 16:46:25	2020-02-06	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	337	delivery	5	28
29124	2020-02-06 16:52:20	2020-02-06	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	11450	delivery	5	36
29125	2020-02-06 17:02:30	2020-02-06	8	[{"id_menu":5,"count":1}]	10737	delivery	5	13
29126	2020-02-06 17:05:42	2020-02-06	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11418	delivery	5	22
29127	2020-02-06 17:16:10	2020-02-06	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	7819	delivery	5	25
29128	2020-02-06 17:18:05	2020-02-06	9	[{"id_menu":6,"count":1}]	10880	delivery	5	14
29129	2020-02-06 17:27:06	2020-02-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	1366	pick-up	0	23
29130	2020-02-06 17:44:17	2020-02-06	12	[{"id_menu":1,"count":1}]	11413	delivery	5	17
29131	2020-02-06 17:48:04	2020-02-06	9	[{"id_menu":6,"count":1}]	372	pick-up	0	9
29132	2020-02-06 17:51:39	2020-02-06	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	11444	pick-up	0	39
29133	2020-02-06 17:51:47	2020-02-06	9	[{"id_menu":7,"count":1}]	11470	pick-up	0	9
29134	2020-02-06 17:55:21	2020-02-06	9	[{"id_menu":7,"count":1}]	11405	delivery	5	14
29135	2020-02-06 18:02:14	2020-02-06	14	[{"id_menu":2,"count":1}]	546	delivery	5	19
29136	2020-02-06 18:04:53	2020-02-06	12	[{"id_menu":3,"count":1}]	2123	pick-up	0	12
29137	2020-02-06 18:09:48	2020-02-06	17	[{"id_menu":4,"count":1}]	601	delivery	5	22
29138	2020-02-06 18:11:51	2020-02-06	9	[{"id_menu":7,"count":1}]	1752	delivery	5	14
29139	2020-02-06 18:25:51	2020-02-06	9	[{"id_menu":6,"count":1}]	4370	delivery	5	14
29140	2020-02-06 18:50:46	2020-02-06	14	[{"id_menu":2,"count":1}]	5374	delivery	5	19
29141	2020-02-06 18:52:14	2020-02-06	9	[{"id_menu":6,"count":1}]	11417	delivery	5	14
29142	2020-02-06 19:02:20	2020-02-06	17	[{"id_menu":4,"count":1}]	11480	delivery	5	22
29143	2020-02-06 19:04:50	2020-02-06	12	[{"id_menu":3,"count":1}]	4558	delivery	5	17
29144	2020-02-06 19:08:01	2020-02-06	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11399	delivery	5	39
29145	2020-02-06 19:14:46	2020-02-06	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	10480	pick-up	0	21
29146	2020-02-06 19:26:15	2020-02-06	12	[{"id_menu":3,"count":1}]	11424	pick-up	0	12
29147	2020-02-06 19:36:14	2020-02-06	12	[{"id_menu":3,"count":1}]	266	pick-up	0	12
29148	2020-02-06 19:39:27	2020-02-06	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	11412	delivery	5	35
29149	2020-02-06 19:46:03	2020-02-06	9	[{"id_menu":7,"count":1}]	239	delivery	5	14
29150	2020-02-06 19:58:37	2020-02-06	14	[{"id_menu":2,"count":1}]	11401	pick-up	0	14
29151	2020-02-06 20:00:49	2020-02-06	12	[{"id_menu":3,"count":1}]	1258	pick-up	0	12
29152	2020-02-06 20:01:40	2020-02-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	880	delivery	5	28
29153	2020-02-06 20:02:13	2020-02-06	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11481	delivery	5	31
29154	2020-02-06 20:12:46	2020-02-06	12	[{"id_menu":1,"count":1}]	11433	delivery	5	17
29155	2020-02-06 20:14:49	2020-02-06	14	[{"id_menu":2,"count":1}]	10706	delivery	5	19
29156	2020-02-06 20:15:19	2020-02-06	14	[{"id_menu":2,"count":1}]	9238	delivery	5	19
29157	2020-02-06 20:16:09	2020-02-06	17	[{"id_menu":4,"count":1}]	287	pick-up	0	17
29158	2020-02-06 20:18:46	2020-02-06	9	[{"id_menu":6,"count":1}]	11420	delivery	5	14
29159	2020-02-06 20:28:20	2020-02-06	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	11479	delivery	5	27
29160	2020-02-06 20:34:25	2020-02-06	9	[{"id_menu":6,"count":1}]	10645	delivery	5	14
29161	2020-02-06 20:41:55	2020-02-06	17	[{"id_menu":4,"count":1}]	3480	pick-up	0	17
29162	2020-02-06 20:56:58	2020-02-06	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11397	delivery	5	31
29163	2020-02-06 20:58:19	2020-02-06	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	11447	delivery	5	36
29164	2020-02-06 21:05:43	2020-02-06	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	10128	delivery	5	31
29165	2020-02-06 21:11:41	2020-02-06	12	[{"id_menu":1,"count":1}]	11443	delivery	5	17
29166	2020-02-06 21:15:08	2020-02-06	17	[{"id_menu":4,"count":1}]	11422	delivery	5	22
29167	2020-02-06 21:19:57	2020-02-06	9	[{"id_menu":7,"count":1}]	11475	delivery	5	14
29168	2020-02-06 21:21:30	2020-02-06	9	[{"id_menu":6,"count":1}]	4986	pick-up	0	9
29169	2020-02-06 21:30:36	2020-02-06	9	[{"id_menu":7,"count":1}]	2745	delivery	5	14
29170	2020-02-06 21:41:17	2020-02-06	14	[{"id_menu":2,"count":1}]	8341	pick-up	0	14
29171	2020-02-06 21:43:28	2020-02-06	14	[{"id_menu":2,"count":1}]	11040	pick-up	0	14
29172	2020-02-06 21:57:15	2020-02-06	12	[{"id_menu":1,"count":1}]	11434	delivery	5	17
29173	2020-02-06 21:58:46	2020-02-06	12	[{"id_menu":1,"count":1}]	10555	pick-up	0	12
29174	2020-02-06 22:00:39	2020-02-06	9	[{"id_menu":6,"count":1}]	92	delivery	5	14
29175	2020-02-06 22:02:36	2020-02-06	8	[{"id_menu":5,"count":1}]	3908	pick-up	0	8
29176	2020-02-06 22:09:02	2020-02-06	12	[{"id_menu":1,"count":1}]	10479	pick-up	0	12
29177	2020-02-06 22:09:07	2020-02-06	9	[{"id_menu":7,"count":1}]	2579	pick-up	0	9
29178	2020-02-06 22:14:23	2020-02-06	12	[{"id_menu":3,"count":1}]	11402	delivery	5	17
29179	2020-02-06 22:19:03	2020-02-06	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	8298	delivery	5	26
29180	2020-02-06 22:24:52	2020-02-06	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	11473	delivery	5	26
29181	2020-02-06 22:35:22	2020-02-06	9	[{"id_menu":7,"count":2}]	11467	delivery	5	14
29182	2020-02-06 22:41:29	2020-02-06	9	[{"id_menu":6,"count":1}]	8112	delivery	5	14
29183	2020-02-06 22:42:30	2020-02-06	8	[{"id_menu":5,"count":1}]	11439	pick-up	0	8
29184	2020-02-06 22:53:12	2020-02-06	9	[{"id_menu":7,"count":1}]	11407	pick-up	0	9
29185	2020-02-06 22:58:00	2020-02-06	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	11462	pick-up	0	21
29186	2020-02-06 23:01:08	2020-02-06	9	[{"id_menu":7,"count":1}]	11438	delivery	5	14
29187	2020-02-06 23:12:46	2020-02-06	17	[{"id_menu":4,"count":1}]	11455	delivery	5	22
29188	2020-02-06 23:26:31	2020-02-06	17	[{"id_menu":4,"count":1}]	4477	pick-up	0	17
29189	2020-02-06 23:36:51	2020-02-06	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	2321	pick-up	0	31
29190	2020-02-06 23:38:28	2020-02-06	9	[{"id_menu":7,"count":1}]	11465	pick-up	0	9
29191	2020-02-06 23:45:16	2020-02-06	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	11253	pick-up	0	33
29192	2020-02-06 23:54:53	2020-02-06	12	[{"id_menu":1,"count":1}]	3230	pick-up	0	12
29193	2020-02-07 00:00:28	2020-02-07	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3140	delivery	5	45
29194	2020-02-07 00:20:12	2020-02-07	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11555	delivery	5	36
29195	2020-02-07 00:26:24	2020-02-07	12	[{"id_menu":1,"count":1}]	11562	delivery	5	17
29196	2020-02-07 00:31:41	2020-02-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	11537	delivery	5	28
29197	2020-02-07 00:42:36	2020-02-07	14	[{"id_menu":2,"count":1}]	3275	pick-up	0	14
29198	2020-02-07 00:49:41	2020-02-07	9	[{"id_menu":7,"count":1}]	11547	delivery	5	14
29199	2020-02-07 00:56:15	2020-02-07	8	[{"id_menu":5,"count":1}]	6342	pick-up	0	8
29200	2020-02-07 01:04:13	2020-02-07	8	[{"id_menu":5,"count":1}]	11497	delivery	5	13
29201	2020-02-07 01:04:24	2020-02-07	12	[{"id_menu":1,"count":1}]	9941	delivery	5	17
29202	2020-02-07 01:11:41	2020-02-07	9	[{"id_menu":7,"count":1}]	11576	delivery	5	14
29203	2020-02-07 01:12:32	2020-02-07	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	11486	delivery	5	34
29204	2020-02-07 01:21:48	2020-02-07	17	[{"id_menu":4,"count":1}]	11157	delivery	5	22
29205	2020-02-07 01:40:17	2020-02-07	12	[{"id_menu":1,"count":1}]	330	delivery	5	17
29206	2020-02-07 01:44:30	2020-02-07	8	[{"id_menu":5,"count":1}]	11519	pick-up	0	8
29207	2020-02-07 01:52:52	2020-02-07	9	[{"id_menu":7,"count":1}]	7953	delivery	5	14
29208	2020-02-07 01:55:09	2020-02-07	12	[{"id_menu":1,"count":1}]	11491	pick-up	0	12
29209	2020-02-07 02:00:30	2020-02-07	8	[{"id_menu":5,"count":1}]	11495	pick-up	0	8
29210	2020-02-07 02:02:41	2020-02-07	9	[{"id_menu":6,"count":1}]	3720	delivery	5	14
29211	2020-02-07 02:13:03	2020-02-07	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	11513	delivery	5	30
29212	2020-02-07 02:16:58	2020-02-07	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	11483	delivery	5	26
29213	2020-02-07 02:26:31	2020-02-07	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	11489	delivery	5	22
29214	2020-02-07 02:35:53	2020-02-07	14	[{"id_menu":2,"count":1}]	11530	delivery	5	19
29215	2020-02-07 02:38:36	2020-02-07	14	[{"id_menu":2,"count":2}]	4867	pick-up	0	14
29216	2020-02-07 02:42:07	2020-02-07	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	3654	delivery	5	39
29217	2020-02-07 03:10:22	2020-02-07	9	[{"id_menu":7,"count":1}]	6798	pick-up	0	9
29218	2020-02-07 03:22:35	2020-02-07	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	7789	delivery	5	26
29219	2020-02-07 03:26:18	2020-02-07	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	11512	delivery	5	36
29220	2020-02-07 03:32:02	2020-02-07	12	[{"id_menu":3,"count":1}]	11561	delivery	5	17
29221	2020-02-07 03:36:36	2020-02-07	17	[{"id_menu":4,"count":1}]	4513	pick-up	0	17
29222	2020-02-07 03:38:47	2020-02-07	14	[{"id_menu":2,"count":1}]	11189	pick-up	0	14
29223	2020-02-07 03:40:03	2020-02-07	12	[{"id_menu":3,"count":1}]	6348	delivery	5	17
29224	2020-02-07 03:49:18	2020-02-07	9	[{"id_menu":6,"count":1}]	7561	delivery	5	14
29225	2020-02-07 03:51:06	2020-02-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	5317	delivery	5	28
29226	2020-02-07 04:05:43	2020-02-07	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11563	delivery	5	48
29227	2020-02-07 04:06:55	2020-02-07	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11505	delivery	5	45
29228	2020-02-07 04:08:37	2020-02-07	14	[{"id_menu":2,"count":1}]	2827	pick-up	0	14
29229	2020-02-07 04:08:58	2020-02-07	12	[{"id_menu":1,"count":1}]	11511	pick-up	0	12
29230	2020-02-07 04:17:26	2020-02-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4905	delivery	5	22
29231	2020-02-07 04:30:30	2020-02-07	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1820	delivery	5	29
29232	2020-02-07 04:30:41	2020-02-07	9	[{"id_menu":7,"count":1}]	8716	pick-up	0	9
29233	2020-02-07 04:37:18	2020-02-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9994	delivery	5	28
29234	2020-02-07 04:41:40	2020-02-07	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10122	delivery	5	40
29235	2020-02-07 04:43:18	2020-02-07	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	7435	pick-up	0	21
29236	2020-02-07 04:44:08	2020-02-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	11542	delivery	5	26
29237	2020-02-07 04:44:58	2020-02-07	17	[{"id_menu":4,"count":1}]	10159	delivery	5	22
29238	2020-02-07 04:51:57	2020-02-07	14	[{"id_menu":2,"count":1}]	7726	delivery	5	19
29239	2020-02-07 05:04:44	2020-02-07	12	[{"id_menu":3,"count":1}]	7627	pick-up	0	12
29240	2020-02-07 05:08:07	2020-02-07	12	[{"id_menu":1,"count":1}]	11553	pick-up	0	12
29241	2020-02-07 05:09:08	2020-02-07	17	[{"id_menu":4,"count":1}]	6566	delivery	5	22
29242	2020-02-07 05:16:13	2020-02-07	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6052	delivery	5	42
29243	2020-02-07 05:22:03	2020-02-07	9	[{"id_menu":6,"count":3}]	10453	delivery	5	14
29244	2020-02-07 05:31:12	2020-02-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	11572	delivery	5	26
29245	2020-02-07 05:32:33	2020-02-07	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11552	delivery	5	45
29246	2020-02-07 05:37:16	2020-02-07	14	[{"id_menu":2,"count":1}]	11532	pick-up	0	14
29247	2020-02-07 05:51:49	2020-02-07	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	6831	delivery	5	43
29248	2020-02-07 06:13:22	2020-02-07	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	377	pick-up	0	29
29249	2020-02-07 06:14:38	2020-02-07	9	[{"id_menu":7,"count":1}]	11485	delivery	5	14
29250	2020-02-07 06:20:30	2020-02-07	17	[{"id_menu":4,"count":1}]	5941	pick-up	0	17
29251	2020-02-07 06:22:40	2020-02-07	8	[{"id_menu":5,"count":1}]	5918	delivery	5	13
29252	2020-02-07 06:29:34	2020-02-07	8	[{"id_menu":5,"count":1}]	7519	delivery	5	13
29253	2020-02-07 06:37:01	2020-02-07	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	11502	delivery	5	27
29254	2020-02-07 06:56:07	2020-02-07	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5926	delivery	5	49
29255	2020-02-07 06:56:34	2020-02-07	9	[{"id_menu":7,"count":2}]	11188	delivery	5	14
29256	2020-02-07 07:06:32	2020-02-07	14	[{"id_menu":2,"count":2}]	4667	pick-up	0	14
29257	2020-02-07 07:10:38	2020-02-07	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	10388	delivery	5	25
29258	2020-02-07 07:11:38	2020-02-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11557	delivery	5	22
29259	2020-02-07 07:16:52	2020-02-07	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	11239	pick-up	0	29
29260	2020-02-07 07:20:11	2020-02-07	14	[{"id_menu":2,"count":1}]	11574	pick-up	0	14
29261	2020-02-07 07:22:18	2020-02-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	138	delivery	5	28
29262	2020-02-07 07:22:18	2020-02-07	9	[{"id_menu":6,"count":1}]	9677	delivery	5	14
29263	2020-02-07 07:28:43	2020-02-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9656	delivery	5	23
29264	2020-02-07 07:28:48	2020-02-07	12	[{"id_menu":3,"count":1}]	11581	delivery	5	17
29265	2020-02-07 07:29:49	2020-02-07	8	[{"id_menu":5,"count":1}]	11095	delivery	5	13
29266	2020-02-07 07:31:31	2020-02-07	14	[{"id_menu":2,"count":1}]	2658	delivery	5	19
29267	2020-02-07 07:34:11	2020-02-07	17	[{"id_menu":4,"count":1}]	3075	delivery	5	22
29268	2020-02-07 07:42:47	2020-02-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2081	delivery	5	28
29269	2020-02-07 07:48:36	2020-02-07	9	[{"id_menu":7,"count":1}]	11548	delivery	5	14
29270	2020-02-07 07:48:50	2020-02-07	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4695	pick-up	0	31
29271	2020-02-07 07:59:01	2020-02-07	12	[{"id_menu":1,"count":1}]	294	delivery	5	17
29272	2020-02-07 08:02:42	2020-02-07	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	11524	delivery	5	30
29273	2020-02-07 08:04:25	2020-02-07	8	[{"id_menu":5,"count":1}]	6012	delivery	5	13
29274	2020-02-07 08:12:08	2020-02-07	9	[{"id_menu":6,"count":1}]	11314	delivery	5	14
29275	2020-02-07 08:15:39	2020-02-07	17	[{"id_menu":4,"count":1}]	4943	pick-up	0	17
29276	2020-02-07 08:20:50	2020-02-07	9	[{"id_menu":6,"count":1}]	10287	pick-up	0	9
29277	2020-02-07 08:30:42	2020-02-07	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":3}]	8350	pick-up	0	31
29278	2020-02-07 08:35:12	2020-02-07	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	11496	delivery	5	45
29279	2020-02-07 09:00:54	2020-02-07	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	628	delivery	5	34
29280	2020-02-07 09:02:35	2020-02-07	9	[{"id_menu":6,"count":1}]	11571	delivery	5	14
29281	2020-02-07 09:02:46	2020-02-07	9	[{"id_menu":6,"count":1}]	3961	pick-up	0	9
29282	2020-02-07 09:25:57	2020-02-07	12	[{"id_menu":1,"count":1}]	10244	pick-up	0	12
29283	2020-02-07 09:28:00	2020-02-07	12	[{"id_menu":3,"count":1}]	2881	pick-up	0	12
29284	2020-02-07 09:38:05	2020-02-07	9	[{"id_menu":7,"count":1}]	11544	pick-up	0	9
29285	2020-02-07 09:38:33	2020-02-07	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1484	delivery	5	43
29286	2020-02-07 09:49:45	2020-02-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	11560	delivery	5	28
29287	2020-02-07 10:04:21	2020-02-07	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3467	delivery	5	38
29288	2020-02-07 10:11:09	2020-02-07	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11503	delivery	5	39
29289	2020-02-07 10:13:18	2020-02-07	9	[{"id_menu":6,"count":1}]	648	pick-up	0	9
29290	2020-02-07 10:26:13	2020-02-07	9	[{"id_menu":7,"count":1}]	3647	pick-up	0	9
29291	2020-02-07 10:50:44	2020-02-07	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6341	delivery	5	36
29292	2020-02-07 10:57:02	2020-02-07	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	11556	delivery	5	30
29293	2020-02-07 11:01:35	2020-02-07	17	[{"id_menu":4,"count":1}]	11500	pick-up	0	17
29294	2020-02-07 11:09:37	2020-02-07	12	[{"id_menu":1,"count":1}]	11540	delivery	5	17
29295	2020-02-07 11:16:03	2020-02-07	9	[{"id_menu":6,"count":1}]	2338	delivery	5	14
29296	2020-02-07 11:18:02	2020-02-07	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	11499	pick-up	0	29
29297	2020-02-07 11:19:39	2020-02-07	17	[{"id_menu":4,"count":1}]	11516	delivery	5	22
29298	2020-02-07 11:26:18	2020-02-07	9	[{"id_menu":6,"count":2}]	8044	delivery	5	14
29299	2020-02-07 11:53:24	2020-02-07	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	543	delivery	5	26
29300	2020-02-07 11:57:29	2020-02-07	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":2}]	10715	delivery	5	30
29301	2020-02-07 12:04:30	2020-02-07	9	[{"id_menu":7,"count":1}]	6005	delivery	5	14
29302	2020-02-07 12:15:32	2020-02-07	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	11193	delivery	5	31
29303	2020-02-07 12:27:11	2020-02-07	17	[{"id_menu":4,"count":1}]	1862	pick-up	0	17
29304	2020-02-07 12:28:31	2020-02-07	8	[{"id_menu":5,"count":1}]	2995	delivery	5	13
29305	2020-02-07 12:28:50	2020-02-07	14	[{"id_menu":2,"count":1}]	3667	delivery	5	19
29306	2020-02-07 12:31:40	2020-02-07	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5303	delivery	5	48
29307	2020-02-07 12:32:11	2020-02-07	14	[{"id_menu":2,"count":1}]	4916	delivery	5	19
29308	2020-02-07 12:42:13	2020-02-07	14	[{"id_menu":2,"count":1}]	5914	delivery	5	19
29309	2020-02-07 12:45:21	2020-02-07	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1965	delivery	5	26
29310	2020-02-07 12:51:11	2020-02-07	14	[{"id_menu":2,"count":1}]	1720	pick-up	0	14
29311	2020-02-07 13:01:30	2020-02-07	9	[{"id_menu":6,"count":1}]	11484	delivery	5	14
29312	2020-02-07 13:12:20	2020-02-07	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9791	delivery	5	31
29313	2020-02-07 13:14:31	2020-02-07	8	[{"id_menu":5,"count":1}]	11421	delivery	5	13
29314	2020-02-07 13:16:08	2020-02-07	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1659	delivery	5	26
29315	2020-02-07 13:17:44	2020-02-07	8	[{"id_menu":5,"count":1}]	5430	pick-up	0	8
29316	2020-02-07 13:25:03	2020-02-07	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	424	pick-up	0	29
29317	2020-02-07 13:26:48	2020-02-07	14	[{"id_menu":2,"count":1}]	9081	delivery	5	19
29318	2020-02-07 13:53:53	2020-02-07	17	[{"id_menu":4,"count":1}]	2802	pick-up	0	17
29319	2020-02-07 13:54:43	2020-02-07	12	[{"id_menu":1,"count":1}]	11446	delivery	5	17
29320	2020-02-07 14:06:42	2020-02-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11543	delivery	5	22
29321	2020-02-07 14:12:45	2020-02-07	9	[{"id_menu":7,"count":1}]	8866	delivery	5	14
29322	2020-02-07 14:17:35	2020-02-07	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7361	pick-up	0	34
29323	2020-02-07 14:24:46	2020-02-07	14	[{"id_menu":2,"count":1}]	11531	pick-up	0	14
29324	2020-02-07 14:27:24	2020-02-07	8	[{"id_menu":5,"count":1}]	11488	delivery	5	13
29325	2020-02-07 14:28:23	2020-02-07	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	11534	delivery	5	31
29326	2020-02-07 14:30:08	2020-02-07	9	[{"id_menu":6,"count":1}]	11529	delivery	5	14
29327	2020-02-07 14:31:51	2020-02-07	17	[{"id_menu":4,"count":1}]	3529	delivery	5	22
29328	2020-02-07 14:34:52	2020-02-07	14	[{"id_menu":2,"count":1}]	11494	delivery	5	19
29329	2020-02-07 14:39:51	2020-02-07	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	6882	delivery	5	23
29330	2020-02-07 14:46:36	2020-02-07	9	[{"id_menu":6,"count":1}]	11501	delivery	5	14
29331	2020-02-07 14:54:01	2020-02-07	55	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	10670	delivery	5	60
29332	2020-02-07 15:18:19	2020-02-07	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11527	delivery	5	39
29333	2020-02-07 15:28:01	2020-02-07	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	11579	delivery	5	40
29334	2020-02-07 15:28:42	2020-02-07	17	[{"id_menu":4,"count":1}]	11566	delivery	5	22
29335	2020-02-07 15:33:15	2020-02-07	14	[{"id_menu":2,"count":1}]	11522	delivery	5	19
29336	2020-02-07 15:43:01	2020-02-07	12	[{"id_menu":3,"count":1}]	4952	delivery	5	17
29337	2020-02-07 15:56:58	2020-02-07	17	[{"id_menu":4,"count":1}]	3006	delivery	5	22
29338	2020-02-07 15:59:25	2020-02-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	7373	delivery	5	26
29339	2020-02-07 16:11:14	2020-02-07	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1280	delivery	5	25
29340	2020-02-07 16:16:43	2020-02-07	14	[{"id_menu":2,"count":1}]	2618	pick-up	0	14
29341	2020-02-07 16:26:18	2020-02-07	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1251	delivery	5	43
29342	2020-02-07 16:27:40	2020-02-07	9	[{"id_menu":6,"count":1}]	5232	pick-up	0	9
29343	2020-02-07 16:28:04	2020-02-07	9	[{"id_menu":6,"count":1}]	11492	pick-up	0	9
29344	2020-02-07 16:31:41	2020-02-07	8	[{"id_menu":5,"count":1}]	1689	pick-up	0	8
29345	2020-02-07 16:43:52	2020-02-07	9	[{"id_menu":6,"count":1}]	11578	delivery	5	14
29346	2020-02-07 16:50:07	2020-02-07	9	[{"id_menu":6,"count":1}]	880	delivery	5	14
29347	2020-02-07 16:53:29	2020-02-07	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11493	pick-up	0	34
29348	2020-02-07 17:08:31	2020-02-07	14	[{"id_menu":2,"count":1}]	9394	delivery	5	19
29349	2020-02-07 17:09:35	2020-02-07	14	[{"id_menu":2,"count":1}]	9128	delivery	5	19
29350	2020-02-07 17:23:56	2020-02-07	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11518	pick-up	0	49
29351	2020-02-07 17:28:38	2020-02-07	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	3128	pick-up	0	29
29352	2020-02-07 17:29:27	2020-02-07	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1941	pick-up	0	29
29353	2020-02-07 17:31:20	2020-02-07	14	[{"id_menu":2,"count":1}]	4139	pick-up	0	14
29354	2020-02-07 17:32:03	2020-02-07	14	[{"id_menu":2,"count":1}]	9115	pick-up	0	14
29355	2020-02-07 17:43:56	2020-02-07	12	[{"id_menu":1,"count":1}]	477	delivery	5	17
29356	2020-02-07 17:48:28	2020-02-07	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	4686	pick-up	0	26
29357	2020-02-07 17:49:07	2020-02-07	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1128	pick-up	0	29
29358	2020-02-07 17:50:50	2020-02-07	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	7879	delivery	5	31
29359	2020-02-07 17:55:22	2020-02-07	9	[{"id_menu":6,"count":1}]	547	pick-up	0	9
29360	2020-02-07 18:13:41	2020-02-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	11564	delivery	5	26
29361	2020-02-07 18:13:56	2020-02-07	9	[{"id_menu":7,"count":1}]	11546	delivery	5	14
29362	2020-02-07 18:14:37	2020-02-07	33	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	11533	delivery	5	38
29363	2020-02-07 18:15:31	2020-02-07	12	[{"id_menu":3,"count":1}]	1107	pick-up	0	12
29364	2020-02-07 18:33:32	2020-02-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5780	delivery	5	28
29365	2020-02-07 18:39:17	2020-02-07	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4398	delivery	5	34
29366	2020-02-07 18:41:44	2020-02-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	11565	delivery	5	28
29367	2020-02-07 18:47:51	2020-02-07	14	[{"id_menu":2,"count":1}]	2607	pick-up	0	14
29368	2020-02-07 18:53:41	2020-02-07	9	[{"id_menu":7,"count":1}]	2017	delivery	5	14
29369	2020-02-07 18:58:14	2020-02-07	12	[{"id_menu":3,"count":1}]	5346	delivery	5	17
29370	2020-02-07 19:00:44	2020-02-07	14	[{"id_menu":2,"count":2}]	11538	delivery	5	19
29371	2020-02-07 19:07:18	2020-02-07	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	8730	delivery	5	25
29372	2020-02-07 19:23:45	2020-02-07	9	[{"id_menu":6,"count":1}]	11498	delivery	5	14
29373	2020-02-07 19:37:25	2020-02-07	9	[{"id_menu":7,"count":1}]	11509	pick-up	0	9
29374	2020-02-07 19:43:12	2020-02-07	17	[{"id_menu":4,"count":1}]	6164	pick-up	0	17
29375	2020-02-07 19:44:07	2020-02-07	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	11504	pick-up	0	37
29376	2020-02-07 19:47:39	2020-02-07	9	[{"id_menu":7,"count":1}]	1687	delivery	5	14
29377	2020-02-07 19:51:13	2020-02-07	8	[{"id_menu":5,"count":1}]	11583	delivery	5	13
29378	2020-02-07 19:52:52	2020-02-07	14	[{"id_menu":2,"count":1}]	11487	delivery	5	19
29379	2020-02-07 19:53:47	2020-02-07	12	[{"id_menu":3,"count":1}]	4528	delivery	5	17
29380	2020-02-07 19:55:44	2020-02-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2271	delivery	5	28
29381	2020-02-07 20:02:16	2020-02-07	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1889	delivery	5	25
29382	2020-02-07 20:30:10	2020-02-07	12	[{"id_menu":1,"count":1}]	11549	delivery	5	17
29383	2020-02-07 20:53:41	2020-02-07	9	[{"id_menu":6,"count":1}]	11490	delivery	5	14
29384	2020-02-07 20:55:55	2020-02-07	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10582	delivery	5	39
29385	2020-02-07 20:59:54	2020-02-07	14	[{"id_menu":2,"count":1}]	11523	delivery	5	19
29386	2020-02-07 21:00:22	2020-02-07	9	[{"id_menu":7,"count":1}]	4840	delivery	5	14
29387	2020-02-07 21:15:57	2020-02-07	8	[{"id_menu":5,"count":1}]	837	pick-up	0	8
29388	2020-02-07 21:21:17	2020-02-07	14	[{"id_menu":2,"count":1}]	1722	delivery	5	19
29389	2020-02-07 21:24:15	2020-02-07	12	[{"id_menu":1,"count":1}]	10951	pick-up	0	12
29390	2020-02-07 21:25:58	2020-02-07	9	[{"id_menu":7,"count":1}]	1670	delivery	5	14
29391	2020-02-07 21:32:42	2020-02-07	12	[{"id_menu":1,"count":1}]	10116	delivery	5	17
29392	2020-02-07 21:39:59	2020-02-07	9	[{"id_menu":7,"count":1}]	8900	pick-up	0	9
29393	2020-02-07 21:47:40	2020-02-07	14	[{"id_menu":2,"count":1}]	7974	pick-up	0	14
29394	2020-02-07 21:51:17	2020-02-07	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	11539	pick-up	0	29
29395	2020-02-07 22:00:28	2020-02-07	12	[{"id_menu":1,"count":1}]	8748	pick-up	0	12
29396	2020-02-07 22:07:01	2020-02-07	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	6772	pick-up	0	29
29397	2020-02-07 22:10:53	2020-02-07	17	[{"id_menu":4,"count":1}]	11573	pick-up	0	17
29398	2020-02-07 22:14:16	2020-02-07	9	[{"id_menu":6,"count":1}]	5050	pick-up	0	9
29399	2020-02-07 22:25:53	2020-02-07	12	[{"id_menu":3,"count":1}]	11558	delivery	5	17
29400	2020-02-07 22:38:37	2020-02-07	9	[{"id_menu":6,"count":2}]	2134	delivery	5	14
29401	2020-02-07 22:39:33	2020-02-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6364	pick-up	0	23
29402	2020-02-07 22:46:38	2020-02-07	8	[{"id_menu":5,"count":1}]	10970	delivery	5	13
29403	2020-02-07 22:52:20	2020-02-07	9	[{"id_menu":7,"count":1}]	11517	delivery	5	14
29404	2020-02-07 22:58:47	2020-02-07	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11550	delivery	5	43
29405	2020-02-07 23:00:19	2020-02-07	12	[{"id_menu":1,"count":1}]	7854	pick-up	0	12
29406	2020-02-07 23:07:47	2020-02-07	9	[{"id_menu":6,"count":1}]	11541	delivery	5	14
29407	2020-02-07 23:09:15	2020-02-07	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	11575	delivery	5	28
29408	2020-02-07 23:10:41	2020-02-07	9	[{"id_menu":7,"count":1}]	11510	delivery	5	14
29409	2020-02-07 23:13:08	2020-02-07	12	[{"id_menu":3,"count":1}]	11567	delivery	5	17
29410	2020-02-07 23:13:28	2020-02-07	17	[{"id_menu":4,"count":1}]	6641	delivery	5	22
29411	2020-02-07 23:15:40	2020-02-07	14	[{"id_menu":2,"count":1}]	5935	delivery	5	19
29412	2020-02-07 23:18:20	2020-02-07	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	11535	delivery	5	34
29413	2020-02-07 23:34:46	2020-02-07	8	[{"id_menu":5,"count":1}]	11514	delivery	5	13
29414	2020-02-07 23:36:38	2020-02-07	14	[{"id_menu":2,"count":1}]	345	pick-up	0	14
29415	2020-02-07 23:53:27	2020-02-07	8	[{"id_menu":5,"count":1}]	11545	delivery	5	13
29416	2020-02-08 00:00:04	2020-02-08	9	[{"id_menu":7,"count":1}]	511	delivery	5	14
29417	2020-02-08 00:04:40	2020-02-08	9	[{"id_menu":6,"count":1}]	11600	delivery	5	14
29418	2020-02-08 00:07:33	2020-02-08	9	[{"id_menu":7,"count":1}]	1526	pick-up	0	9
29419	2020-02-08 00:28:18	2020-02-08	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8256	delivery	5	31
29420	2020-02-08 00:29:24	2020-02-08	12	[{"id_menu":3,"count":1}]	2843	delivery	5	17
29421	2020-02-08 00:30:53	2020-02-08	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	2838	delivery	5	29
29422	2020-02-08 00:43:14	2020-02-08	8	[{"id_menu":5,"count":1}]	587	pick-up	0	8
29423	2020-02-08 00:43:39	2020-02-08	14	[{"id_menu":2,"count":1}]	3449	pick-up	0	14
29424	2020-02-08 00:53:52	2020-02-08	9	[{"id_menu":7,"count":1}]	4152	delivery	5	14
29425	2020-02-08 00:57:55	2020-02-08	17	[{"id_menu":4,"count":1}]	11616	delivery	5	22
29426	2020-02-08 01:01:18	2020-02-08	9	[{"id_menu":6,"count":1}]	10630	delivery	5	14
29427	2020-02-08 01:03:44	2020-02-08	8	[{"id_menu":5,"count":1}]	7358	delivery	5	13
29428	2020-02-08 01:40:02	2020-02-08	9	[{"id_menu":6,"count":1}]	11683	delivery	5	14
29429	2020-02-08 01:41:40	2020-02-08	12	[{"id_menu":1,"count":1}]	7205	pick-up	0	12
29430	2020-02-08 01:44:38	2020-02-08	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	5790	pick-up	0	29
29431	2020-02-08 01:50:09	2020-02-08	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10402	delivery	5	34
29432	2020-02-08 02:02:33	2020-02-08	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11621	delivery	5	31
29433	2020-02-08 02:05:41	2020-02-08	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6644	pick-up	0	25
29434	2020-02-08 02:10:01	2020-02-08	14	[{"id_menu":2,"count":1}]	4292	delivery	5	19
29435	2020-02-08 02:11:29	2020-02-08	17	[{"id_menu":4,"count":1}]	11637	delivery	5	22
29436	2020-02-08 02:12:49	2020-02-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8140	delivery	5	23
29437	2020-02-08 02:14:35	2020-02-08	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	11647	delivery	5	34
29438	2020-02-08 02:15:14	2020-02-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7676	delivery	5	28
29439	2020-02-08 02:20:48	2020-02-08	14	[{"id_menu":2,"count":1}]	11276	pick-up	0	14
29440	2020-02-08 02:33:24	2020-02-08	8	[{"id_menu":5,"count":1}]	10908	delivery	5	13
29441	2020-02-08 02:35:57	2020-02-08	9	[{"id_menu":7,"count":1}]	3066	pick-up	0	9
29442	2020-02-08 02:38:39	2020-02-08	9	[{"id_menu":6,"count":1}]	11670	delivery	5	14
29443	2020-02-08 02:41:24	2020-02-08	8	[{"id_menu":5,"count":1}]	11659	delivery	5	13
29444	2020-02-08 02:43:55	2020-02-08	12	[{"id_menu":1,"count":1}]	1819	delivery	5	17
29445	2020-02-08 02:55:37	2020-02-08	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	343	pick-up	0	17
29446	2020-02-08 03:04:04	2020-02-08	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	720	delivery	5	34
29447	2020-02-08 03:07:39	2020-02-08	12	[{"id_menu":3,"count":1}]	10983	pick-up	0	12
29448	2020-02-08 03:15:06	2020-02-08	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4060	delivery	5	40
29449	2020-02-08 03:26:06	2020-02-08	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11610	delivery	5	39
29450	2020-02-08 03:26:51	2020-02-08	9	[{"id_menu":7,"count":1}]	11680	delivery	5	14
29451	2020-02-08 03:42:57	2020-02-08	8	[{"id_menu":5,"count":1}]	10365	delivery	5	13
29452	2020-02-08 03:44:40	2020-02-08	9	[{"id_menu":7,"count":1}]	4546	pick-up	0	9
29453	2020-02-08 03:47:02	2020-02-08	17	[{"id_menu":4,"count":1}]	5701	delivery	5	22
29454	2020-02-08 03:50:02	2020-02-08	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	9259	delivery	5	26
29455	2020-02-08 03:51:31	2020-02-08	17	[{"id_menu":4,"count":1}]	1259	pick-up	0	17
29456	2020-02-08 04:03:41	2020-02-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	10954	pick-up	0	23
29457	2020-02-08 04:06:44	2020-02-08	17	[{"id_menu":4,"count":2}]	4161	pick-up	0	17
29458	2020-02-08 04:06:57	2020-02-08	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7306	delivery	5	31
29459	2020-02-08 04:08:02	2020-02-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	11597	delivery	5	28
29460	2020-02-08 04:13:05	2020-02-08	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1693	delivery	5	31
29461	2020-02-08 04:15:17	2020-02-08	9	[{"id_menu":6,"count":1}]	140	pick-up	0	9
29462	2020-02-08 04:16:45	2020-02-08	9	[{"id_menu":7,"count":1}]	543	pick-up	0	9
29463	2020-02-08 04:23:44	2020-02-08	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6116	delivery	5	43
29464	2020-02-08 04:25:50	2020-02-08	12	[{"id_menu":1,"count":1}]	11655	delivery	5	17
29465	2020-02-08 04:25:58	2020-02-08	17	[{"id_menu":4,"count":2}]	11636	delivery	5	22
29466	2020-02-08 04:40:33	2020-02-08	9	[{"id_menu":6,"count":1}]	3496	pick-up	0	9
29467	2020-02-08 04:48:42	2020-02-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	11658	delivery	5	28
29468	2020-02-08 04:49:59	2020-02-08	9	[{"id_menu":7,"count":2}]	11622	delivery	5	14
29469	2020-02-08 04:54:48	2020-02-08	9	[{"id_menu":6,"count":1}]	8190	delivery	5	14
29470	2020-02-08 05:00:10	2020-02-08	9	[{"id_menu":7,"count":1}]	6364	pick-up	0	9
29471	2020-02-08 05:16:50	2020-02-08	9	[{"id_menu":6,"count":1}]	3827	pick-up	0	9
29472	2020-02-08 05:20:26	2020-02-08	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11627	delivery	5	45
29473	2020-02-08 05:21:37	2020-02-08	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	11602	delivery	5	25
29474	2020-02-08 05:23:16	2020-02-08	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4762	delivery	5	31
29475	2020-02-08 05:25:07	2020-02-08	9	[{"id_menu":7,"count":2}]	3640	pick-up	0	9
29476	2020-02-08 05:25:28	2020-02-08	17	[{"id_menu":4,"count":1}]	5892	delivery	5	22
29477	2020-02-08 05:32:30	2020-02-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	4622	delivery	5	23
29478	2020-02-08 05:36:08	2020-02-08	14	[{"id_menu":2,"count":1}]	3870	pick-up	0	14
29479	2020-02-08 05:38:52	2020-02-08	17	[{"id_menu":4,"count":1}]	5994	delivery	5	22
29480	2020-02-08 05:43:31	2020-02-08	9	[{"id_menu":6,"count":1}]	401	delivery	5	14
29481	2020-02-08 05:45:34	2020-02-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	6398	delivery	5	22
29482	2020-02-08 05:50:29	2020-02-08	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9798	delivery	5	31
29483	2020-02-08 05:52:01	2020-02-08	12	[{"id_menu":1,"count":1}]	11650	delivery	5	17
29484	2020-02-08 05:57:04	2020-02-08	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4929	pick-up	0	26
29485	2020-02-08 05:57:34	2020-02-08	8	[{"id_menu":5,"count":1}]	10870	delivery	5	13
29486	2020-02-08 05:59:45	2020-02-08	12	[{"id_menu":1,"count":1}]	6074	delivery	5	17
29487	2020-02-08 06:04:20	2020-02-08	9	[{"id_menu":7,"count":1}]	8754	delivery	5	14
29488	2020-02-08 06:14:07	2020-02-08	14	[{"id_menu":2,"count":1}]	1207	delivery	5	19
29489	2020-02-08 06:23:49	2020-02-08	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3507	pick-up	0	43
29490	2020-02-08 06:25:47	2020-02-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	11608	delivery	5	28
29491	2020-02-08 06:36:42	2020-02-08	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4411	pick-up	0	31
29492	2020-02-08 06:42:24	2020-02-08	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4184	pick-up	0	32
29493	2020-02-08 06:42:46	2020-02-08	9	[{"id_menu":6,"count":1}]	4454	delivery	5	14
29494	2020-02-08 06:48:56	2020-02-08	9	[{"id_menu":6,"count":1}]	7002	delivery	5	14
29495	2020-02-08 06:57:07	2020-02-08	17	[{"id_menu":4,"count":1}]	3124	delivery	5	22
29496	2020-02-08 06:58:47	2020-02-08	12	[{"id_menu":3,"count":1}]	234	pick-up	0	12
29497	2020-02-08 06:58:53	2020-02-08	12	[{"id_menu":1,"count":1}]	6038	pick-up	0	12
29498	2020-02-08 07:03:18	2020-02-08	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1681	pick-up	0	24
29499	2020-02-08 07:03:29	2020-02-08	8	[{"id_menu":5,"count":1}]	11661	delivery	5	13
29500	2020-02-08 07:07:28	2020-02-08	9	[{"id_menu":6,"count":1}]	3368	delivery	5	14
29501	2020-02-08 07:13:19	2020-02-08	9	[{"id_menu":7,"count":1}]	3270	pick-up	0	9
29502	2020-02-08 07:18:15	2020-02-08	12	[{"id_menu":1,"count":1}]	2476	delivery	5	17
29503	2020-02-08 07:20:44	2020-02-08	9	[{"id_menu":7,"count":1}]	6146	delivery	5	14
29504	2020-02-08 07:29:12	2020-02-08	8	[{"id_menu":5,"count":1}]	1112	delivery	5	13
29505	2020-02-08 07:29:28	2020-02-08	9	[{"id_menu":6,"count":1}]	7186	delivery	5	14
29506	2020-02-08 07:40:15	2020-02-08	9	[{"id_menu":6,"count":1}]	11678	delivery	5	14
29507	2020-02-08 07:44:34	2020-02-08	9	[{"id_menu":6,"count":1}]	11651	delivery	5	14
29508	2020-02-08 07:46:51	2020-02-08	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	4433	delivery	5	31
29509	2020-02-08 07:46:54	2020-02-08	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":2}]	8305	delivery	5	22
29510	2020-02-08 07:51:41	2020-02-08	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	11671	delivery	5	31
29511	2020-02-08 08:01:06	2020-02-08	9	[{"id_menu":7,"count":2}]	11606	delivery	5	14
29512	2020-02-08 08:03:25	2020-02-08	12	[{"id_menu":3,"count":1}]	7572	delivery	5	17
29513	2020-02-08 08:08:01	2020-02-08	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11585	delivery	5	39
29514	2020-02-08 08:13:13	2020-02-08	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11591	delivery	5	45
29515	2020-02-08 08:14:03	2020-02-08	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	7300	delivery	5	23
29516	2020-02-08 08:16:40	2020-02-08	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2542	pick-up	0	26
29517	2020-02-08 08:23:03	2020-02-08	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	11667	delivery	5	40
29518	2020-02-08 08:29:00	2020-02-08	17	[{"id_menu":4,"count":1}]	1566	pick-up	0	17
29519	2020-02-08 08:30:24	2020-02-08	12	[{"id_menu":3,"count":1}]	11669	delivery	5	17
29520	2020-02-08 08:32:08	2020-02-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	996	pick-up	0	18
29521	2020-02-08 08:32:20	2020-02-08	9	[{"id_menu":6,"count":1}]	11620	delivery	5	14
29522	2020-02-08 08:38:09	2020-02-08	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	3684	delivery	5	37
29523	2020-02-08 08:39:27	2020-02-08	17	[{"id_menu":4,"count":1}]	11625	delivery	5	22
29524	2020-02-08 08:39:49	2020-02-08	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11681	pick-up	0	30
29525	2020-02-08 08:46:17	2020-02-08	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2623	pick-up	0	26
29526	2020-02-08 08:53:16	2020-02-08	12	[{"id_menu":1,"count":1}]	3570	delivery	5	17
29527	2020-02-08 08:55:12	2020-02-08	9	[{"id_menu":6,"count":1}]	10410	pick-up	0	9
29528	2020-02-08 08:58:39	2020-02-08	8	[{"id_menu":5,"count":1}]	6825	pick-up	0	8
29529	2020-02-08 09:00:56	2020-02-08	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3389	pick-up	0	29
29530	2020-02-08 09:02:44	2020-02-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6800	delivery	5	22
29531	2020-02-08 09:03:18	2020-02-08	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	429	delivery	5	26
29532	2020-02-08 09:03:40	2020-02-08	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	2867	pick-up	0	20
29533	2020-02-08 09:04:53	2020-02-08	14	[{"id_menu":2,"count":1}]	6834	delivery	5	19
29534	2020-02-08 09:09:40	2020-02-08	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11596	delivery	5	39
29535	2020-02-08 09:15:05	2020-02-08	12	[{"id_menu":3,"count":1}]	7250	pick-up	0	12
29536	2020-02-08 09:24:41	2020-02-08	12	[{"id_menu":3,"count":1}]	1685	pick-up	0	12
29537	2020-02-08 09:34:46	2020-02-08	14	[{"id_menu":2,"count":1}]	4368	delivery	5	19
29538	2020-02-08 09:40:41	2020-02-08	17	[{"id_menu":4,"count":1}]	11684	delivery	5	22
29539	2020-02-08 09:53:31	2020-02-08	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	11686	pick-up	0	24
29540	2020-02-08 09:53:54	2020-02-08	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	5430	pick-up	0	29
29541	2020-02-08 10:03:46	2020-02-08	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	11133	delivery	5	26
29542	2020-02-08 10:04:32	2020-02-08	14	[{"id_menu":2,"count":1}]	547	pick-up	0	14
29543	2020-02-08 10:07:10	2020-02-08	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11607	delivery	5	45
29544	2020-02-08 10:09:10	2020-02-08	12	[{"id_menu":3,"count":1}]	1159	pick-up	0	12
29545	2020-02-08 10:09:19	2020-02-08	9	[{"id_menu":6,"count":1}]	6668	delivery	5	14
29546	2020-02-08 10:17:01	2020-02-08	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	10952	delivery	5	36
29547	2020-02-08 10:20:17	2020-02-08	9	[{"id_menu":6,"count":2}]	531	pick-up	0	9
29548	2020-02-08 10:26:09	2020-02-08	12	[{"id_menu":1,"count":1}]	9871	delivery	5	17
29549	2020-02-08 10:35:07	2020-02-08	9	[{"id_menu":6,"count":1}]	11674	delivery	5	14
29550	2020-02-08 10:39:26	2020-02-08	9	[{"id_menu":7,"count":1}]	2557	pick-up	0	9
29551	2020-02-08 10:50:14	2020-02-08	9	[{"id_menu":6,"count":1}]	11629	delivery	5	14
29552	2020-02-08 10:55:22	2020-02-08	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	11653	delivery	5	48
29553	2020-02-08 10:58:23	2020-02-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11599	delivery	5	22
29554	2020-02-08 10:58:49	2020-02-08	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11656	delivery	5	31
29555	2020-02-08 11:03:43	2020-02-08	14	[{"id_menu":2,"count":1}]	11643	pick-up	0	14
29556	2020-02-08 11:26:42	2020-02-08	9	[{"id_menu":7,"count":1}]	359	pick-up	0	9
29557	2020-02-08 11:28:20	2020-02-08	8	[{"id_menu":5,"count":1}]	73	pick-up	0	8
29558	2020-02-08 11:29:37	2020-02-08	12	[{"id_menu":3,"count":1}]	5509	delivery	5	17
29559	2020-02-08 11:32:54	2020-02-08	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	11679	delivery	5	31
29560	2020-02-08 11:34:45	2020-02-08	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	10141	delivery	5	25
29561	2020-02-08 11:34:46	2020-02-08	12	[{"id_menu":3,"count":1}]	7638	delivery	5	17
29562	2020-02-08 11:39:48	2020-02-08	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11604	pick-up	0	43
29563	2020-02-08 11:40:56	2020-02-08	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5483	pick-up	0	26
29564	2020-02-08 11:46:16	2020-02-08	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	11601	pick-up	0	43
29565	2020-02-08 11:48:09	2020-02-08	17	[{"id_menu":4,"count":1}]	11657	pick-up	0	17
29566	2020-02-08 11:48:35	2020-02-08	12	[{"id_menu":3,"count":1}]	7874	delivery	5	17
29567	2020-02-08 11:54:28	2020-02-08	12	[{"id_menu":1,"count":1}]	2907	pick-up	0	12
29568	2020-02-08 12:00:20	2020-02-08	17	[{"id_menu":4,"count":1}]	11345	delivery	5	22
29569	2020-02-08 12:06:27	2020-02-08	17	[{"id_menu":4,"count":1}]	4468	delivery	5	22
29570	2020-02-08 12:12:43	2020-02-08	9	[{"id_menu":7,"count":1}]	10968	pick-up	0	9
29571	2020-02-08 12:18:45	2020-02-08	9	[{"id_menu":7,"count":1}]	7451	delivery	5	14
29572	2020-02-08 12:19:46	2020-02-08	12	[{"id_menu":1,"count":2}]	9466	pick-up	0	12
29573	2020-02-08 12:30:09	2020-02-08	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9610	pick-up	0	25
29574	2020-02-08 12:30:30	2020-02-08	9	[{"id_menu":7,"count":1}]	11668	delivery	5	14
29575	2020-02-08 12:31:49	2020-02-08	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	11675	delivery	5	26
29576	2020-02-08 12:35:08	2020-02-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11630	delivery	5	23
29577	2020-02-08 12:38:43	2020-02-08	14	[{"id_menu":2,"count":1}]	947	pick-up	0	14
29578	2020-02-08 12:39:40	2020-02-08	9	[{"id_menu":6,"count":1}]	11593	pick-up	0	9
29579	2020-02-08 12:47:21	2020-02-08	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	11632	delivery	5	38
29580	2020-02-08 12:47:32	2020-02-08	9	[{"id_menu":7,"count":1}]	2264	pick-up	0	9
29581	2020-02-08 12:57:50	2020-02-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2888	delivery	5	22
29582	2020-02-08 13:00:07	2020-02-08	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11665	delivery	5	36
29583	2020-02-08 13:23:27	2020-02-08	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	533	delivery	5	48
29584	2020-02-08 13:30:23	2020-02-08	8	[{"id_menu":5,"count":1}]	11039	delivery	5	13
29585	2020-02-08 13:57:12	2020-02-08	17	[{"id_menu":4,"count":1}]	7919	pick-up	0	17
29586	2020-02-08 13:59:47	2020-02-08	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	11605	delivery	5	25
29587	2020-02-08 14:07:26	2020-02-08	9	[{"id_menu":7,"count":2}]	5252	pick-up	0	9
29588	2020-02-08 14:13:19	2020-02-08	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	2575	pick-up	0	40
29589	2020-02-08 14:16:30	2020-02-08	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8149	delivery	5	34
29590	2020-02-08 14:17:35	2020-02-08	12	[{"id_menu":1,"count":1}]	11646	delivery	5	17
29591	2020-02-08 14:22:51	2020-02-08	12	[{"id_menu":1,"count":1}]	10323	delivery	5	17
29592	2020-02-08 14:23:35	2020-02-08	12	[{"id_menu":3,"count":1}]	6851	pick-up	0	12
29593	2020-02-08 14:25:33	2020-02-08	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	11682	delivery	5	29
29594	2020-02-08 14:29:01	2020-02-08	9	[{"id_menu":6,"count":1}]	11598	delivery	5	14
29595	2020-02-08 14:50:58	2020-02-08	9	[{"id_menu":7,"count":1}]	11070	pick-up	0	9
29596	2020-02-08 15:01:12	2020-02-08	12	[{"id_menu":3,"count":1}]	7203	pick-up	0	12
29597	2020-02-08 15:01:47	2020-02-08	9	[{"id_menu":7,"count":2}]	11587	delivery	5	14
29598	2020-02-08 15:11:53	2020-02-08	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	3715	delivery	5	39
29599	2020-02-08 15:12:18	2020-02-08	14	[{"id_menu":2,"count":1}]	4937	pick-up	0	14
29600	2020-02-08 15:14:30	2020-02-08	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	11623	delivery	5	40
29601	2020-02-08 15:17:27	2020-02-08	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	3519	delivery	5	26
29602	2020-02-08 15:25:13	2020-02-08	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11588	delivery	5	22
29603	2020-02-08 15:26:06	2020-02-08	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	11624	delivery	5	36
29604	2020-02-08 15:26:08	2020-02-08	9	[{"id_menu":6,"count":1}]	9326	delivery	5	14
29605	2020-02-08 15:26:35	2020-02-08	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	315	pick-up	0	21
29606	2020-02-08 15:28:58	2020-02-08	17	[{"id_menu":4,"count":1}]	6905	delivery	5	22
29607	2020-02-08 15:33:36	2020-02-08	9	[{"id_menu":6,"count":2}]	5472	delivery	5	14
29608	2020-02-08 15:35:52	2020-02-08	9	[{"id_menu":7,"count":1}]	11590	delivery	5	14
29609	2020-02-08 15:39:43	2020-02-08	9	[{"id_menu":7,"count":1}]	964	delivery	5	14
29610	2020-02-08 15:45:53	2020-02-08	12	[{"id_menu":3,"count":1}]	11613	delivery	5	17
29611	2020-02-08 15:46:34	2020-02-08	12	[{"id_menu":3,"count":1}]	11589	delivery	5	17
29612	2020-02-08 15:55:05	2020-02-08	14	[{"id_menu":2,"count":1}]	11664	delivery	5	19
29613	2020-02-08 15:56:14	2020-02-08	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	7828	delivery	5	26
29614	2020-02-08 15:59:51	2020-02-08	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7613	delivery	5	31
29615	2020-02-08 16:00:03	2020-02-08	9	[{"id_menu":6,"count":1}]	8580	delivery	5	14
29616	2020-02-08 16:02:47	2020-02-08	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2019	pick-up	0	43
29617	2020-02-08 16:02:52	2020-02-08	12	[{"id_menu":1,"count":3}]	11673	delivery	5	17
29618	2020-02-08 16:07:44	2020-02-08	12	[{"id_menu":1,"count":1}]	3077	pick-up	0	12
29619	2020-02-08 16:08:18	2020-02-08	9	[{"id_menu":6,"count":1}]	466	delivery	5	14
29620	2020-02-08 16:10:41	2020-02-08	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	11104	delivery	5	36
29621	2020-02-08 16:16:26	2020-02-08	14	[{"id_menu":2,"count":1}]	11660	delivery	5	19
29622	2020-02-08 16:17:16	2020-02-08	17	[{"id_menu":4,"count":1}]	433	pick-up	0	17
29623	2020-02-08 16:17:33	2020-02-08	14	[{"id_menu":2,"count":1}]	7779	delivery	5	19
29624	2020-02-08 16:23:18	2020-02-08	14	[{"id_menu":2,"count":1}]	2119	pick-up	0	14
29625	2020-02-08 16:39:23	2020-02-08	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	10100	pick-up	0	33
29626	2020-02-08 16:46:10	2020-02-08	17	[{"id_menu":4,"count":1}]	8205	pick-up	0	17
29627	2020-02-08 16:58:34	2020-02-08	12	[{"id_menu":1,"count":1}]	1415	pick-up	0	12
29628	2020-02-08 17:05:46	2020-02-08	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11649	pick-up	0	31
29629	2020-02-08 17:11:12	2020-02-08	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	11594	delivery	5	36
29630	2020-02-08 17:13:08	2020-02-08	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11584	delivery	5	39
29631	2020-02-08 17:14:24	2020-02-08	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	5875	pick-up	0	29
29632	2020-02-08 17:17:57	2020-02-08	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2092	delivery	5	40
29633	2020-02-08 17:25:58	2020-02-08	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	3506	delivery	5	36
29634	2020-02-08 17:34:15	2020-02-08	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11612	delivery	5	34
29635	2020-02-08 17:34:58	2020-02-08	8	[{"id_menu":5,"count":1}]	9869	delivery	5	13
29636	2020-02-08 17:36:51	2020-02-08	8	[{"id_menu":5,"count":1}]	11634	pick-up	0	8
29637	2020-02-08 17:40:38	2020-02-08	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11614	pick-up	0	44
29638	2020-02-08 17:44:32	2020-02-08	17	[{"id_menu":4,"count":1}]	11652	pick-up	0	17
29639	2020-02-08 17:47:15	2020-02-08	8	[{"id_menu":5,"count":1}]	2570	pick-up	0	8
29640	2020-02-08 18:03:56	2020-02-08	14	[{"id_menu":2,"count":1}]	6962	delivery	5	19
29641	2020-02-08 18:07:25	2020-02-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	966	pick-up	0	18
29642	2020-02-08 18:09:44	2020-02-08	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	424	delivery	5	36
29643	2020-02-08 18:17:15	2020-02-08	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	11645	delivery	5	46
29644	2020-02-08 18:22:41	2020-02-08	9	[{"id_menu":6,"count":1}]	11628	delivery	5	14
29645	2020-02-08 18:23:36	2020-02-08	9	[{"id_menu":6,"count":2}]	6666	pick-up	0	9
29646	2020-02-08 18:26:08	2020-02-08	9	[{"id_menu":6,"count":1}]	11676	delivery	5	14
29647	2020-02-08 18:26:49	2020-02-08	17	[{"id_menu":4,"count":1}]	6470	pick-up	0	17
29648	2020-02-08 18:27:48	2020-02-08	9	[{"id_menu":7,"count":1}]	11595	delivery	5	14
29649	2020-02-08 18:36:09	2020-02-08	17	[{"id_menu":4,"count":1}]	11644	pick-up	0	17
29650	2020-02-08 18:40:51	2020-02-08	17	[{"id_menu":4,"count":1}]	244	delivery	5	22
29651	2020-02-08 18:42:05	2020-02-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	11609	delivery	5	22
29652	2020-02-08 18:45:33	2020-02-08	17	[{"id_menu":4,"count":1}]	10876	delivery	5	22
29653	2020-02-08 18:59:50	2020-02-08	9	[{"id_menu":7,"count":1}]	9344	delivery	5	14
29654	2020-02-08 19:00:36	2020-02-08	17	[{"id_menu":4,"count":1}]	9633	delivery	5	22
29655	2020-02-08 19:01:04	2020-02-08	14	[{"id_menu":2,"count":1}]	3650	pick-up	0	14
29656	2020-02-08 19:02:42	2020-02-08	12	[{"id_menu":3,"count":1}]	7204	delivery	5	17
29657	2020-02-08 19:10:55	2020-02-08	9	[{"id_menu":6,"count":1}]	1025	pick-up	0	9
29658	2020-02-08 19:21:18	2020-02-08	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	5310	pick-up	0	29
29659	2020-02-08 19:29:25	2020-02-08	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1101	pick-up	0	29
29660	2020-02-08 19:29:29	2020-02-08	12	[{"id_menu":1,"count":1}]	11592	pick-up	0	12
29661	2020-02-08 19:31:11	2020-02-08	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	11663	delivery	5	27
29662	2020-02-08 19:37:17	2020-02-08	9	[{"id_menu":6,"count":1}]	2197	delivery	5	14
29663	2020-02-08 19:53:41	2020-02-08	12	[{"id_menu":3,"count":1}]	11642	delivery	5	17
29664	2020-02-08 20:02:49	2020-02-08	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	11631	delivery	5	31
29665	2020-02-08 20:05:07	2020-02-08	8	[{"id_menu":5,"count":1}]	2416	pick-up	0	8
29666	2020-02-08 20:08:58	2020-02-08	26	[{"id_menu":4,"count":3},{"id_menu":7,"count":1}]	7706	pick-up	0	26
29667	2020-02-08 20:15:20	2020-02-08	17	[{"id_menu":4,"count":1}]	5530	delivery	5	22
29668	2020-02-08 20:33:36	2020-02-08	12	[{"id_menu":3,"count":1}]	1657	delivery	5	17
29669	2020-02-08 20:33:45	2020-02-08	9	[{"id_menu":6,"count":1}]	4125	delivery	5	14
29670	2020-02-08 20:45:51	2020-02-08	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8919	delivery	5	30
29671	2020-02-08 20:49:04	2020-02-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11666	delivery	5	22
29672	2020-02-08 20:52:41	2020-02-08	12	[{"id_menu":3,"count":1}]	3106	delivery	5	17
29673	2020-02-08 20:59:23	2020-02-08	9	[{"id_menu":7,"count":1}]	4698	delivery	5	14
29674	2020-02-08 21:02:36	2020-02-08	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8423	delivery	5	52
29675	2020-02-08 21:04:21	2020-02-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	11654	delivery	5	28
29676	2020-02-08 21:07:44	2020-02-08	8	[{"id_menu":5,"count":1}]	3910	delivery	5	13
29677	2020-02-08 21:10:55	2020-02-08	17	[{"id_menu":4,"count":1}]	11639	delivery	5	22
29678	2020-02-08 21:12:28	2020-02-08	14	[{"id_menu":2,"count":1}]	11618	delivery	5	19
29679	2020-02-08 21:12:52	2020-02-08	8	[{"id_menu":5,"count":1}]	6405	pick-up	0	8
29680	2020-02-08 21:17:33	2020-02-08	14	[{"id_menu":2,"count":1}]	11130	delivery	5	19
29681	2020-02-08 21:21:10	2020-02-08	9	[{"id_menu":7,"count":1}]	3116	delivery	5	14
29682	2020-02-08 21:30:27	2020-02-08	12	[{"id_menu":1,"count":1}]	3600	pick-up	0	12
29683	2020-02-08 21:32:10	2020-02-08	14	[{"id_menu":2,"count":1}]	11619	delivery	5	19
29684	2020-02-08 21:36:23	2020-02-08	9	[{"id_menu":7,"count":1}]	8581	delivery	5	14
29685	2020-02-08 21:37:33	2020-02-08	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	1944	delivery	5	35
29686	2020-02-08 21:39:50	2020-02-08	12	[{"id_menu":3,"count":1}]	932	delivery	5	17
29687	2020-02-08 21:43:07	2020-02-08	9	[{"id_menu":6,"count":1}]	11287	pick-up	0	9
29688	2020-02-08 21:46:01	2020-02-08	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	11617	pick-up	0	29
29689	2020-02-08 21:48:56	2020-02-08	17	[{"id_menu":4,"count":1}]	2711	delivery	5	22
29690	2020-02-08 21:49:38	2020-02-08	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11635	delivery	5	53
29691	2020-02-08 21:55:41	2020-02-08	12	[{"id_menu":3,"count":2}]	1089	pick-up	0	12
29692	2020-02-08 21:56:20	2020-02-08	9	[{"id_menu":6,"count":1}]	5724	delivery	5	14
29693	2020-02-08 21:56:35	2020-02-08	9	[{"id_menu":7,"count":1}]	11108	delivery	5	14
29694	2020-02-08 22:05:58	2020-02-08	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4045	delivery	5	31
29695	2020-02-08 22:06:12	2020-02-08	14	[{"id_menu":2,"count":1}]	2021	pick-up	0	14
29696	2020-02-08 22:06:41	2020-02-08	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7668	delivery	5	40
29697	2020-02-08 22:13:01	2020-02-08	8	[{"id_menu":5,"count":1}]	2567	pick-up	0	8
29698	2020-02-08 22:13:10	2020-02-08	14	[{"id_menu":2,"count":1}]	396	pick-up	0	14
29699	2020-02-08 22:24:59	2020-02-08	9	[{"id_menu":6,"count":1}]	4513	delivery	5	14
29700	2020-02-08 22:38:47	2020-02-08	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	11473	delivery	5	40
29701	2020-02-08 22:46:14	2020-02-08	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	11685	delivery	5	26
29702	2020-02-08 22:52:31	2020-02-08	12	[{"id_menu":1,"count":1}]	11314	pick-up	0	12
29703	2020-02-08 23:02:42	2020-02-08	12	[{"id_menu":1,"count":1}]	11615	pick-up	0	12
29704	2020-02-08 23:06:54	2020-02-08	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	578	delivery	5	25
29705	2020-02-08 23:12:59	2020-02-08	12	[{"id_menu":3,"count":1}]	8683	delivery	5	17
29706	2020-02-08 23:15:13	2020-02-08	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7013	delivery	5	22
29707	2020-02-08 23:15:53	2020-02-08	12	[{"id_menu":3,"count":1}]	1072	pick-up	0	12
29708	2020-02-08 23:16:21	2020-02-08	17	[{"id_menu":4,"count":1}]	6092	pick-up	0	17
29709	2020-02-08 23:21:12	2020-02-08	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	11672	delivery	5	30
29710	2020-02-08 23:23:53	2020-02-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	11603	delivery	5	28
29711	2020-02-08 23:41:04	2020-02-08	12	[{"id_menu":3,"count":1}]	7496	delivery	5	17
29712	2020-02-08 23:44:52	2020-02-08	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1767	delivery	5	25
29713	2020-02-08 23:45:15	2020-02-08	17	[{"id_menu":4,"count":1}]	11648	delivery	5	22
29714	2020-02-08 23:45:44	2020-02-08	12	[{"id_menu":1,"count":1}]	6773	delivery	5	17
29715	2020-02-08 23:46:17	2020-02-08	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11586	delivery	5	31
29716	2020-02-08 23:47:59	2020-02-08	12	[{"id_menu":1,"count":1}]	2283	pick-up	0	12
29717	2020-02-08 23:48:27	2020-02-08	12	[{"id_menu":1,"count":1}]	11662	delivery	5	17
29718	2020-02-08 23:53:17	2020-02-08	17	[{"id_menu":4,"count":1}]	4629	pick-up	0	17
29719	2020-02-09 00:05:37	2020-02-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	11733	delivery	5	22
29720	2020-02-09 00:08:53	2020-02-09	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	11782	delivery	5	30
29721	2020-02-09 00:16:51	2020-02-09	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	11756	delivery	5	26
29722	2020-02-09 00:26:44	2020-02-09	9	[{"id_menu":7,"count":1}]	11691	delivery	5	14
29723	2020-02-09 00:32:41	2020-02-09	14	[{"id_menu":2,"count":1}]	11697	delivery	5	19
29724	2020-02-09 00:37:17	2020-02-09	14	[{"id_menu":2,"count":1}]	11710	delivery	5	19
29725	2020-02-09 00:42:13	2020-02-09	12	[{"id_menu":1,"count":1}]	11726	delivery	5	17
29726	2020-02-09 00:50:37	2020-02-09	14	[{"id_menu":2,"count":1}]	11714	pick-up	0	14
29727	2020-02-09 00:51:24	2020-02-09	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11706	delivery	5	34
29728	2020-02-09 00:52:53	2020-02-09	14	[{"id_menu":2,"count":1}]	6453	delivery	5	19
29729	2020-02-09 00:53:07	2020-02-09	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	11732	delivery	5	26
29730	2020-02-09 00:58:22	2020-02-09	9	[{"id_menu":7,"count":1}]	7574	pick-up	0	9
29731	2020-02-09 01:01:33	2020-02-09	17	[{"id_menu":4,"count":1}]	203	pick-up	0	17
29732	2020-02-09 01:02:25	2020-02-09	9	[{"id_menu":7,"count":2}]	994	delivery	5	14
29733	2020-02-09 01:06:28	2020-02-09	12	[{"id_menu":3,"count":2}]	1781	delivery	5	17
29734	2020-02-09 01:06:58	2020-02-09	9	[{"id_menu":7,"count":1}]	11693	delivery	5	14
29735	2020-02-09 01:12:52	2020-02-09	8	[{"id_menu":5,"count":1}]	5047	delivery	5	13
29736	2020-02-09 01:18:16	2020-02-09	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	11107	delivery	5	40
29737	2020-02-09 01:27:42	2020-02-09	8	[{"id_menu":5,"count":1}]	7138	delivery	5	13
29738	2020-02-09 01:29:06	2020-02-09	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	11699	delivery	5	36
29739	2020-02-09 01:33:38	2020-02-09	12	[{"id_menu":1,"count":1}]	2210	delivery	5	17
29740	2020-02-09 01:37:43	2020-02-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5215	pick-up	0	23
29741	2020-02-09 01:40:20	2020-02-09	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	11759	delivery	5	43
29742	2020-02-09 01:46:55	2020-02-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	10963	delivery	5	28
29743	2020-02-09 01:47:23	2020-02-09	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	106	pick-up	0	26
29744	2020-02-09 01:57:56	2020-02-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10452	pick-up	0	18
29745	2020-02-09 02:00:45	2020-02-09	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11708	delivery	5	31
29746	2020-02-09 02:03:50	2020-02-09	9	[{"id_menu":6,"count":1}]	11799	delivery	5	14
29747	2020-02-09 02:09:48	2020-02-09	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	11720	delivery	5	40
29748	2020-02-09 02:10:07	2020-02-09	9	[{"id_menu":6,"count":1}]	11763	delivery	5	14
29749	2020-02-09 02:14:48	2020-02-09	17	[{"id_menu":4,"count":1}]	463	pick-up	0	17
29750	2020-02-09 02:19:31	2020-02-09	17	[{"id_menu":4,"count":1}]	11777	delivery	5	22
29751	2020-02-09 02:28:18	2020-02-09	9	[{"id_menu":6,"count":1}]	11786	delivery	5	14
29752	2020-02-09 02:29:27	2020-02-09	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	11616	delivery	5	30
29753	2020-02-09 02:33:30	2020-02-09	12	[{"id_menu":3,"count":1}]	9266	pick-up	0	12
29754	2020-02-09 02:42:55	2020-02-09	14	[{"id_menu":2,"count":1}]	841	pick-up	0	14
29755	2020-02-09 02:43:54	2020-02-09	14	[{"id_menu":2,"count":1}]	3167	pick-up	0	14
29756	2020-02-09 02:51:37	2020-02-09	14	[{"id_menu":2,"count":1}]	10907	delivery	5	19
29757	2020-02-09 02:55:51	2020-02-09	8	[{"id_menu":5,"count":1}]	11784	delivery	5	13
29758	2020-02-09 02:58:23	2020-02-09	14	[{"id_menu":2,"count":1}]	1432	delivery	5	19
29759	2020-02-09 02:59:34	2020-02-09	12	[{"id_menu":3,"count":1}]	4825	pick-up	0	12
29760	2020-02-09 03:06:55	2020-02-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	11793	pick-up	0	23
29761	2020-02-09 03:09:16	2020-02-09	9	[{"id_menu":7,"count":1}]	11796	delivery	5	14
29762	2020-02-09 03:18:54	2020-02-09	14	[{"id_menu":2,"count":1}]	11751	pick-up	0	14
29763	2020-02-09 03:23:22	2020-02-09	9	[{"id_menu":7,"count":1}]	11734	delivery	5	14
29764	2020-02-09 03:26:32	2020-02-09	17	[{"id_menu":4,"count":1}]	11741	delivery	5	22
29765	2020-02-09 03:27:59	2020-02-09	9	[{"id_menu":6,"count":1}]	11721	delivery	5	14
29766	2020-02-09 03:28:14	2020-02-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	655	pick-up	0	23
29767	2020-02-09 03:29:25	2020-02-09	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	5906	delivery	5	31
29768	2020-02-09 03:34:37	2020-02-09	9	[{"id_menu":7,"count":1}]	10488	delivery	5	14
29769	2020-02-09 03:35:24	2020-02-09	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3110	delivery	5	36
29770	2020-02-09 03:47:44	2020-02-09	9	[{"id_menu":6,"count":2}]	3559	pick-up	0	9
29771	2020-02-09 03:54:59	2020-02-09	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	11791	delivery	5	38
29772	2020-02-09 04:02:08	2020-02-09	8	[{"id_menu":5,"count":1}]	1387	pick-up	0	8
29773	2020-02-09 04:02:42	2020-02-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	592	pick-up	0	23
29774	2020-02-09 04:03:19	2020-02-09	9	[{"id_menu":7,"count":1}]	4781	delivery	5	14
29775	2020-02-09 04:06:57	2020-02-09	9	[{"id_menu":7,"count":1}]	6396	pick-up	0	9
29776	2020-02-09 04:08:48	2020-02-09	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2550	pick-up	0	29
29777	2020-02-09 04:09:06	2020-02-09	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	11757	delivery	5	25
29778	2020-02-09 04:11:20	2020-02-09	9	[{"id_menu":6,"count":2}]	626	delivery	5	14
29779	2020-02-09 04:23:03	2020-02-09	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10373	delivery	5	39
29780	2020-02-09 04:23:29	2020-02-09	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11764	delivery	5	34
29781	2020-02-09 04:27:55	2020-02-09	12	[{"id_menu":1,"count":2}]	1533	pick-up	0	12
29782	2020-02-09 04:28:25	2020-02-09	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8483	delivery	5	40
29783	2020-02-09 04:37:53	2020-02-09	17	[{"id_menu":4,"count":1}]	5586	pick-up	0	17
29784	2020-02-09 04:42:34	2020-02-09	12	[{"id_menu":3,"count":1}]	8362	delivery	5	17
29785	2020-02-09 04:47:26	2020-02-09	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8555	delivery	5	40
29786	2020-02-09 04:49:20	2020-02-09	9	[{"id_menu":7,"count":1}]	11748	delivery	5	14
29787	2020-02-09 04:49:47	2020-02-09	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	9775	delivery	5	25
29788	2020-02-09 04:54:56	2020-02-09	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	11761	delivery	5	39
29789	2020-02-09 04:56:03	2020-02-09	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	227	delivery	5	34
29790	2020-02-09 04:56:26	2020-02-09	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	11778	delivery	5	26
29791	2020-02-09 05:01:03	2020-02-09	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11736	delivery	5	45
29792	2020-02-09 05:06:48	2020-02-09	9	[{"id_menu":7,"count":1}]	2633	pick-up	0	9
29793	2020-02-09 05:11:33	2020-02-09	12	[{"id_menu":1,"count":1}]	11740	delivery	5	17
29794	2020-02-09 05:11:53	2020-02-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10930	pick-up	0	17
29795	2020-02-09 05:12:45	2020-02-09	9	[{"id_menu":7,"count":1}]	676	delivery	5	14
29796	2020-02-09 05:13:19	2020-02-09	12	[{"id_menu":3,"count":1}]	6987	pick-up	0	12
29797	2020-02-09 05:16:12	2020-02-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	11739	delivery	5	28
29798	2020-02-09 05:28:34	2020-02-09	14	[{"id_menu":2,"count":1}]	11788	pick-up	0	14
29799	2020-02-09 05:36:02	2020-02-09	12	[{"id_menu":3,"count":1}]	10755	pick-up	0	12
29800	2020-02-09 05:54:43	2020-02-09	17	[{"id_menu":4,"count":1}]	8244	delivery	5	22
29801	2020-02-09 05:57:49	2020-02-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2115	pick-up	0	17
29802	2020-02-09 06:05:58	2020-02-09	9	[{"id_menu":7,"count":1}]	11772	delivery	5	14
29803	2020-02-09 06:06:34	2020-02-09	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1731	pick-up	0	21
29804	2020-02-09 06:12:08	2020-02-09	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	8470	delivery	5	40
29805	2020-02-09 06:27:08	2020-02-09	9	[{"id_menu":6,"count":3}]	4892	delivery	5	14
29806	2020-02-09 06:28:37	2020-02-09	8	[{"id_menu":5,"count":1}]	6538	delivery	5	13
29807	2020-02-09 06:31:35	2020-02-09	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	11752	delivery	5	31
29808	2020-02-09 06:48:46	2020-02-09	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	10200	pick-up	0	21
29809	2020-02-09 06:51:22	2020-02-09	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1465	pick-up	0	31
29810	2020-02-09 07:03:35	2020-02-09	9	[{"id_menu":7,"count":1}]	3444	delivery	5	14
29811	2020-02-09 07:18:09	2020-02-09	8	[{"id_menu":5,"count":1}]	7603	pick-up	0	8
29812	2020-02-09 07:26:00	2020-02-09	12	[{"id_menu":1,"count":1}]	11789	delivery	5	17
29813	2020-02-09 07:29:18	2020-02-09	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2085	delivery	5	36
29814	2020-02-09 07:29:23	2020-02-09	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2712	delivery	5	22
29815	2020-02-09 07:32:02	2020-02-09	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	7796	delivery	5	26
29816	2020-02-09 07:35:18	2020-02-09	17	[{"id_menu":4,"count":1}]	3891	delivery	5	22
29817	2020-02-09 07:42:08	2020-02-09	9	[{"id_menu":6,"count":1}]	4370	pick-up	0	9
29818	2020-02-09 07:42:55	2020-02-09	9	[{"id_menu":6,"count":1}]	2974	delivery	5	14
29819	2020-02-09 07:47:13	2020-02-09	9	[{"id_menu":7,"count":1}]	11725	delivery	5	14
29820	2020-02-09 07:49:19	2020-02-09	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3036	delivery	5	49
29821	2020-02-09 07:49:20	2020-02-09	9	[{"id_menu":7,"count":1}]	11785	delivery	5	14
29822	2020-02-09 07:51:17	2020-02-09	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	11758	delivery	5	25
29823	2020-02-09 07:52:31	2020-02-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	640	delivery	5	28
29824	2020-02-09 07:54:17	2020-02-09	8	[{"id_menu":5,"count":1}]	11709	delivery	5	13
29825	2020-02-09 07:57:40	2020-02-09	12	[{"id_menu":3,"count":1}]	654	delivery	5	17
29826	2020-02-09 07:58:57	2020-02-09	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	11776	delivery	5	31
29827	2020-02-09 08:03:00	2020-02-09	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6924	pick-up	0	26
29828	2020-02-09 08:07:14	2020-02-09	12	[{"id_menu":1,"count":1}]	5007	delivery	5	17
29829	2020-02-09 08:17:02	2020-02-09	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4562	pick-up	0	22
29830	2020-02-09 08:18:37	2020-02-09	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	11780	delivery	5	27
29831	2020-02-09 08:35:31	2020-02-09	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	11722	pick-up	0	29
29832	2020-02-09 08:38:19	2020-02-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5401	delivery	5	23
29833	2020-02-09 08:40:11	2020-02-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5924	delivery	5	22
29834	2020-02-09 08:41:50	2020-02-09	12	[{"id_menu":1,"count":1}]	1924	pick-up	0	12
29835	2020-02-09 08:43:40	2020-02-09	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	5481	delivery	5	26
29836	2020-02-09 08:44:09	2020-02-09	12	[{"id_menu":3,"count":1}]	6941	pick-up	0	12
29837	2020-02-09 08:47:35	2020-02-09	14	[{"id_menu":2,"count":1}]	2300	pick-up	0	14
29838	2020-02-09 08:47:47	2020-02-09	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	5318	pick-up	0	35
29839	2020-02-09 08:54:58	2020-02-09	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	11745	delivery	5	45
29840	2020-02-09 08:59:14	2020-02-09	9	[{"id_menu":6,"count":1}]	11798	delivery	5	14
29841	2020-02-09 09:02:01	2020-02-09	9	[{"id_menu":7,"count":1}]	2000	pick-up	0	9
29842	2020-02-09 09:03:11	2020-02-09	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":3}]	11730	delivery	5	26
29843	2020-02-09 09:10:01	2020-02-09	14	[{"id_menu":2,"count":1}]	486	pick-up	0	14
29844	2020-02-09 09:12:20	2020-02-09	17	[{"id_menu":4,"count":1}]	5141	pick-up	0	17
29845	2020-02-09 09:12:46	2020-02-09	12	[{"id_menu":1,"count":1}]	1644	pick-up	0	12
29846	2020-02-09 09:12:47	2020-02-09	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8705	delivery	5	34
29847	2020-02-09 09:17:05	2020-02-09	9	[{"id_menu":7,"count":1}]	11717	delivery	5	14
29848	2020-02-09 09:28:07	2020-02-09	17	[{"id_menu":4,"count":1}]	3230	pick-up	0	17
29849	2020-02-09 09:43:10	2020-02-09	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1996	pick-up	0	26
29850	2020-02-09 09:47:53	2020-02-09	14	[{"id_menu":2,"count":1}]	8358	pick-up	0	14
29851	2020-02-09 09:48:07	2020-02-09	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11509	pick-up	0	38
29852	2020-02-09 09:53:04	2020-02-09	8	[{"id_menu":5,"count":1}]	11723	delivery	5	13
29853	2020-02-09 09:53:22	2020-02-09	9	[{"id_menu":6,"count":1}]	1679	pick-up	0	9
29854	2020-02-09 09:57:03	2020-02-09	9	[{"id_menu":7,"count":2}]	2439	pick-up	0	9
29855	2020-02-09 10:00:51	2020-02-09	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	8574	pick-up	0	21
29856	2020-02-09 10:13:59	2020-02-09	9	[{"id_menu":6,"count":1}]	11696	pick-up	0	9
29857	2020-02-09 10:17:58	2020-02-09	12	[{"id_menu":3,"count":1}]	11766	delivery	5	17
29858	2020-02-09 10:26:39	2020-02-09	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11719	delivery	5	31
29859	2020-02-09 10:27:15	2020-02-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	8265	delivery	5	28
29860	2020-02-09 10:28:22	2020-02-09	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	11715	pick-up	0	39
29861	2020-02-09 10:37:24	2020-02-09	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	9009	delivery	5	34
29862	2020-02-09 10:40:21	2020-02-09	17	[{"id_menu":4,"count":1}]	9575	pick-up	0	17
29863	2020-02-09 10:41:31	2020-02-09	9	[{"id_menu":7,"count":1}]	11773	delivery	5	14
29864	2020-02-09 10:42:46	2020-02-09	9	[{"id_menu":6,"count":1}]	8865	delivery	5	14
29865	2020-02-09 10:43:53	2020-02-09	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	8038	delivery	5	36
29866	2020-02-09 10:49:33	2020-02-09	12	[{"id_menu":3,"count":1}]	11688	delivery	5	17
29867	2020-02-09 10:52:00	2020-02-09	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9270	delivery	5	22
29868	2020-02-09 10:52:46	2020-02-09	9	[{"id_menu":6,"count":1}]	2124	pick-up	0	9
29869	2020-02-09 10:54:28	2020-02-09	8	[{"id_menu":5,"count":1}]	2594	pick-up	0	8
29870	2020-02-09 10:56:42	2020-02-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11779	pick-up	0	17
29871	2020-02-09 11:05:00	2020-02-09	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11790	pick-up	0	17
29872	2020-02-09 11:06:23	2020-02-09	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4461	delivery	5	31
29873	2020-02-09 11:06:51	2020-02-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7050	delivery	5	28
29874	2020-02-09 11:09:48	2020-02-09	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5004	delivery	5	30
29875	2020-02-09 11:13:39	2020-02-09	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3235	delivery	5	36
29876	2020-02-09 11:13:42	2020-02-09	9	[{"id_menu":7,"count":1}]	1408	pick-up	0	9
29877	2020-02-09 11:13:47	2020-02-09	9	[{"id_menu":6,"count":1}]	1233	pick-up	0	9
29878	2020-02-09 11:16:47	2020-02-09	8	[{"id_menu":5,"count":1}]	5538	pick-up	0	8
29879	2020-02-09 11:18:19	2020-02-09	14	[{"id_menu":2,"count":1}]	9103	delivery	5	19
29880	2020-02-09 11:28:39	2020-02-09	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	11728	delivery	5	22
29881	2020-02-09 11:29:07	2020-02-09	9	[{"id_menu":7,"count":1}]	7850	delivery	5	14
29882	2020-02-09 11:33:45	2020-02-09	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	7338	delivery	5	22
29883	2020-02-09 11:41:15	2020-02-09	12	[{"id_menu":1,"count":1}]	9492	delivery	5	17
29884	2020-02-09 11:43:10	2020-02-09	14	[{"id_menu":2,"count":1}]	11753	delivery	5	19
29885	2020-02-09 11:44:01	2020-02-09	12	[{"id_menu":1,"count":1}]	1030	pick-up	0	12
29886	2020-02-09 11:45:09	2020-02-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	10544	delivery	5	28
29887	2020-02-09 11:46:25	2020-02-09	9	[{"id_menu":7,"count":1}]	11749	delivery	5	14
29888	2020-02-09 11:50:23	2020-02-09	12	[{"id_menu":3,"count":2}]	5886	delivery	5	17
29889	2020-02-09 11:53:26	2020-02-09	12	[{"id_menu":1,"count":1}]	8181	delivery	5	17
29890	2020-02-09 12:02:38	2020-02-09	12	[{"id_menu":3,"count":1}]	360	pick-up	0	12
29891	2020-02-09 12:07:12	2020-02-09	8	[{"id_menu":5,"count":1}]	2401	pick-up	0	8
29892	2020-02-09 12:11:54	2020-02-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	10715	delivery	5	23
29893	2020-02-09 12:19:26	2020-02-09	12	[{"id_menu":1,"count":1}]	1839	delivery	5	17
29894	2020-02-09 12:22:35	2020-02-09	12	[{"id_menu":3,"count":1}]	5161	delivery	5	17
29895	2020-02-09 12:23:40	2020-02-09	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2282	pick-up	0	21
29896	2020-02-09 12:24:25	2020-02-09	14	[{"id_menu":2,"count":1}]	11334	pick-up	0	14
29897	2020-02-09 12:25:51	2020-02-09	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	11774	pick-up	0	25
29898	2020-02-09 12:27:03	2020-02-09	8	[{"id_menu":5,"count":1}]	11762	delivery	5	13
29899	2020-02-09 12:32:11	2020-02-09	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	11690	delivery	5	30
29900	2020-02-09 12:32:58	2020-02-09	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	7388	delivery	5	43
29901	2020-02-09 12:35:46	2020-02-09	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	11727	delivery	5	35
29902	2020-02-09 12:36:10	2020-02-09	12	[{"id_menu":1,"count":1}]	11705	delivery	5	17
29903	2020-02-09 12:44:24	2020-02-09	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	5558	delivery	5	25
29904	2020-02-09 12:59:41	2020-02-09	9	[{"id_menu":6,"count":2}]	11781	delivery	5	14
29905	2020-02-09 13:08:34	2020-02-09	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	11743	delivery	5	31
29906	2020-02-09 13:12:32	2020-02-09	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	304	delivery	5	43
29907	2020-02-09 13:19:55	2020-02-09	9	[{"id_menu":7,"count":1}]	8550	pick-up	0	9
29908	2020-02-09 13:29:28	2020-02-09	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5979	delivery	5	45
29909	2020-02-09 13:30:08	2020-02-09	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11704	pick-up	0	34
29910	2020-02-09 13:30:58	2020-02-09	9	[{"id_menu":6,"count":1}]	11738	delivery	5	14
29911	2020-02-09 13:31:28	2020-02-09	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	4981	pick-up	0	26
29912	2020-02-09 13:36:16	2020-02-09	17	[{"id_menu":4,"count":1}]	11744	delivery	5	22
29913	2020-02-09 13:53:20	2020-02-09	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11276	pick-up	0	38
29914	2020-02-09 13:55:08	2020-02-09	8	[{"id_menu":5,"count":1}]	8878	pick-up	0	8
29915	2020-02-09 13:55:43	2020-02-09	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11771	delivery	5	31
29916	2020-02-09 13:58:50	2020-02-09	9	[{"id_menu":6,"count":1}]	11702	delivery	5	14
29917	2020-02-09 14:13:24	2020-02-09	17	[{"id_menu":4,"count":1}]	1727	delivery	5	22
29918	2020-02-09 14:25:15	2020-02-09	17	[{"id_menu":4,"count":1}]	7190	delivery	5	22
29919	2020-02-09 14:28:55	2020-02-09	14	[{"id_menu":2,"count":1}]	5970	delivery	5	19
29920	2020-02-09 14:30:05	2020-02-09	17	[{"id_menu":4,"count":1}]	281	pick-up	0	17
29921	2020-02-09 14:36:31	2020-02-09	9	[{"id_menu":7,"count":1}]	11701	delivery	5	14
29922	2020-02-09 14:36:56	2020-02-09	14	[{"id_menu":2,"count":1}]	5104	delivery	5	19
29923	2020-02-09 14:49:31	2020-02-09	9	[{"id_menu":7,"count":1}]	2951	delivery	5	14
29924	2020-02-09 15:00:44	2020-02-09	17	[{"id_menu":4,"count":1}]	11768	pick-up	0	17
29925	2020-02-09 15:03:03	2020-02-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	10287	pick-up	0	23
29926	2020-02-09 15:06:40	2020-02-09	9	[{"id_menu":6,"count":1}]	7957	pick-up	0	9
29927	2020-02-09 15:09:36	2020-02-09	9	[{"id_menu":7,"count":1}]	3393	delivery	5	14
29928	2020-02-09 15:12:16	2020-02-09	9	[{"id_menu":6,"count":1}]	11775	delivery	5	14
29929	2020-02-09 15:12:37	2020-02-09	9	[{"id_menu":6,"count":1}]	11767	delivery	5	14
29930	2020-02-09 15:20:42	2020-02-09	14	[{"id_menu":2,"count":1}]	2245	pick-up	0	14
29931	2020-02-09 15:20:54	2020-02-09	9	[{"id_menu":6,"count":1}]	11787	delivery	5	14
29932	2020-02-09 15:35:28	2020-02-09	14	[{"id_menu":2,"count":1}]	389	delivery	5	19
29933	2020-02-09 15:35:59	2020-02-09	17	[{"id_menu":4,"count":1}]	1374	pick-up	0	17
29934	2020-02-09 15:36:37	2020-02-09	8	[{"id_menu":5,"count":1}]	11797	pick-up	0	8
29935	2020-02-09 15:37:02	2020-02-09	12	[{"id_menu":1,"count":1}]	4132	pick-up	0	12
29936	2020-02-09 15:40:22	2020-02-09	14	[{"id_menu":2,"count":1}]	9716	pick-up	0	14
29937	2020-02-09 15:41:10	2020-02-09	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	8240	pick-up	0	33
29938	2020-02-09 15:45:12	2020-02-09	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	11713	delivery	5	31
29939	2020-02-09 15:51:11	2020-02-09	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9926	delivery	5	31
29940	2020-02-09 16:01:18	2020-02-09	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	371	pick-up	0	26
29941	2020-02-09 16:11:32	2020-02-09	17	[{"id_menu":4,"count":1}]	11755	delivery	5	22
29942	2020-02-09 16:14:33	2020-02-09	17	[{"id_menu":4,"count":1}]	4996	pick-up	0	17
29943	2020-02-09 16:16:52	2020-02-09	8	[{"id_menu":5,"count":1}]	296	delivery	5	13
29944	2020-02-09 16:22:09	2020-02-09	12	[{"id_menu":1,"count":2}]	643	delivery	5	17
29945	2020-02-09 16:27:07	2020-02-09	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	11735	delivery	5	23
29946	2020-02-09 16:27:47	2020-02-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11737	pick-up	0	18
29947	2020-02-09 16:28:29	2020-02-09	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	5354	pick-up	0	29
29948	2020-02-09 16:34:19	2020-02-09	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	136	pick-up	0	23
29949	2020-02-09 16:47:35	2020-02-09	9	[{"id_menu":6,"count":2}]	7261	delivery	5	14
29950	2020-02-09 16:54:05	2020-02-09	12	[{"id_menu":1,"count":1}]	3916	pick-up	0	12
29951	2020-02-09 16:58:39	2020-02-09	12	[{"id_menu":1,"count":1}]	2645	delivery	5	17
29952	2020-02-09 16:58:53	2020-02-09	9	[{"id_menu":6,"count":1}]	9608	delivery	5	14
29953	2020-02-09 17:06:01	2020-02-09	9	[{"id_menu":7,"count":1}]	11703	delivery	5	14
29954	2020-02-09 17:08:26	2020-02-09	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	11794	delivery	5	31
29955	2020-02-09 17:08:30	2020-02-09	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11765	delivery	5	45
29956	2020-02-09 17:24:49	2020-02-09	9	[{"id_menu":6,"count":1}]	11746	delivery	5	14
29957	2020-02-09 17:28:19	2020-02-09	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4075	delivery	5	36
29958	2020-02-09 17:30:13	2020-02-09	9	[{"id_menu":6,"count":1}]	9318	delivery	5	14
29959	2020-02-09 17:31:44	2020-02-09	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3361	pick-up	0	31
29960	2020-02-09 17:32:33	2020-02-09	12	[{"id_menu":1,"count":1}]	11750	delivery	5	17
29961	2020-02-09 17:33:09	2020-02-09	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	5818	delivery	5	23
29962	2020-02-09 17:40:33	2020-02-09	12	[{"id_menu":3,"count":1}]	6518	delivery	5	17
29963	2020-02-09 17:49:42	2020-02-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	7274	delivery	5	23
29964	2020-02-09 17:49:53	2020-02-09	12	[{"id_menu":1,"count":1}]	7390	delivery	5	17
29965	2020-02-09 17:51:31	2020-02-09	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	9082	pick-up	0	31
29966	2020-02-09 17:52:30	2020-02-09	9	[{"id_menu":7,"count":1}]	6921	delivery	5	14
29967	2020-02-09 17:52:56	2020-02-09	12	[{"id_menu":3,"count":1}]	10434	delivery	5	17
29968	2020-02-09 17:54:16	2020-02-09	17	[{"id_menu":4,"count":1}]	5023	delivery	5	22
29969	2020-02-09 18:04:23	2020-02-09	8	[{"id_menu":5,"count":1}]	8417	delivery	5	13
29970	2020-02-09 18:12:24	2020-02-09	12	[{"id_menu":3,"count":1}]	1486	pick-up	0	12
29971	2020-02-09 18:25:24	2020-02-09	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2332	delivery	5	22
29972	2020-02-09 18:25:49	2020-02-09	9	[{"id_menu":7,"count":1}]	11021	delivery	5	14
29973	2020-02-09 18:29:05	2020-02-09	9	[{"id_menu":7,"count":1}]	11718	delivery	5	14
29974	2020-02-09 18:42:06	2020-02-09	12	[{"id_menu":3,"count":1}]	10793	pick-up	0	12
29975	2020-02-09 18:50:05	2020-02-09	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	6255	delivery	5	31
29976	2020-02-09 18:56:59	2020-02-09	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5078	delivery	5	52
29977	2020-02-09 18:58:04	2020-02-09	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5082	pick-up	0	26
29978	2020-02-09 19:08:29	2020-02-09	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	6366	delivery	5	25
29979	2020-02-09 19:09:37	2020-02-09	14	[{"id_menu":2,"count":1}]	7908	delivery	5	19
29980	2020-02-09 19:16:10	2020-02-09	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	456	pick-up	0	31
29981	2020-02-09 19:18:32	2020-02-09	14	[{"id_menu":2,"count":1}]	9273	delivery	5	19
29982	2020-02-09 19:22:53	2020-02-09	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	11687	delivery	5	28
29983	2020-02-09 19:29:38	2020-02-09	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11694	delivery	5	22
29984	2020-02-09 19:37:32	2020-02-09	9	[{"id_menu":6,"count":1}]	1376	delivery	5	14
29985	2020-02-09 19:37:46	2020-02-09	9	[{"id_menu":6,"count":2}]	11783	delivery	5	14
29986	2020-02-09 19:42:27	2020-02-09	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4714	pick-up	0	30
29987	2020-02-09 19:43:37	2020-02-09	9	[{"id_menu":7,"count":1}]	743	delivery	5	14
29988	2020-02-09 19:48:35	2020-02-09	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10288	delivery	5	57
29989	2020-02-09 19:55:56	2020-02-09	12	[{"id_menu":1,"count":1}]	1223	pick-up	0	12
29990	2020-02-09 20:10:59	2020-02-09	14	[{"id_menu":2,"count":1}]	11692	delivery	5	19
29991	2020-02-09 20:11:37	2020-02-09	9	[{"id_menu":6,"count":1}]	6399	delivery	5	14
29992	2020-02-09 20:17:28	2020-02-09	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	7582	delivery	5	26
29993	2020-02-09 20:20:22	2020-02-09	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11729	delivery	5	31
29994	2020-02-09 20:30:47	2020-02-09	9	[{"id_menu":6,"count":1}]	856	delivery	5	14
29995	2020-02-09 20:33:47	2020-02-09	12	[{"id_menu":1,"count":1}]	11724	delivery	5	17
29996	2020-02-09 20:36:34	2020-02-09	17	[{"id_menu":4,"count":1}]	8666	pick-up	0	17
29997	2020-02-09 20:37:32	2020-02-09	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	609	pick-up	0	50
29998	2020-02-09 20:37:39	2020-02-09	9	[{"id_menu":7,"count":1}]	11635	delivery	5	14
29999	2020-02-09 20:37:42	2020-02-09	12	[{"id_menu":1,"count":1}]	11801	delivery	5	17
30000	2020-02-09 20:39:11	2020-02-09	12	[{"id_menu":3,"count":1}]	2227	pick-up	0	12
30001	2020-02-09 20:43:26	2020-02-09	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11769	delivery	5	34
30002	2020-02-09 20:43:58	2020-02-09	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	35	pick-up	0	21
30003	2020-02-09 20:45:22	2020-02-09	9	[{"id_menu":6,"count":1}]	11707	delivery	5	14
30004	2020-02-09 20:45:31	2020-02-09	17	[{"id_menu":4,"count":1}]	1914	pick-up	0	17
30005	2020-02-09 20:45:44	2020-02-09	9	[{"id_menu":6,"count":1}]	11800	pick-up	0	9
30006	2020-02-09 20:51:27	2020-02-09	14	[{"id_menu":2,"count":1}]	6848	pick-up	0	14
30007	2020-02-09 20:54:12	2020-02-09	12	[{"id_menu":3,"count":1}]	5166	pick-up	0	12
30008	2020-02-09 21:09:02	2020-02-09	9	[{"id_menu":6,"count":1}]	66	pick-up	0	9
30009	2020-02-09 21:10:41	2020-02-09	14	[{"id_menu":2,"count":1}]	10319	pick-up	0	14
30010	2020-02-09 21:12:43	2020-02-09	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2391	delivery	5	40
30011	2020-02-09 21:18:17	2020-02-09	17	[{"id_menu":4,"count":1}]	5033	delivery	5	22
30012	2020-02-09 21:19:28	2020-02-09	8	[{"id_menu":5,"count":1}]	642	delivery	5	13
30013	2020-02-09 21:23:55	2020-02-09	8	[{"id_menu":5,"count":1}]	3135	delivery	5	13
30014	2020-02-09 21:29:58	2020-02-09	17	[{"id_menu":4,"count":1}]	4076	delivery	5	22
30015	2020-02-09 21:40:00	2020-02-09	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	11747	delivery	5	56
30016	2020-02-09 21:41:45	2020-02-09	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	10469	delivery	5	31
30017	2020-02-09 21:46:20	2020-02-09	9	[{"id_menu":7,"count":1}]	9312	delivery	5	14
30018	2020-02-09 21:54:08	2020-02-09	14	[{"id_menu":2,"count":1}]	11754	delivery	5	19
30019	2020-02-09 21:58:04	2020-02-09	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	9296	delivery	5	39
30020	2020-02-09 22:06:38	2020-02-09	12	[{"id_menu":1,"count":1}]	8706	pick-up	0	12
30021	2020-02-09 22:12:05	2020-02-09	17	[{"id_menu":4,"count":1}]	6046	pick-up	0	17
30022	2020-02-09 22:14:32	2020-02-09	9	[{"id_menu":6,"count":1}]	1199	pick-up	0	9
30023	2020-02-09 22:15:59	2020-02-09	9	[{"id_menu":7,"count":1}]	529	delivery	5	14
30024	2020-02-09 22:17:51	2020-02-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":3}]	6914	delivery	5	28
30025	2020-02-09 22:21:36	2020-02-09	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4612	delivery	5	36
30026	2020-02-09 22:26:33	2020-02-09	9	[{"id_menu":6,"count":1}]	5751	delivery	5	14
30027	2020-02-09 22:29:20	2020-02-09	17	[{"id_menu":4,"count":1}]	11689	delivery	5	22
30028	2020-02-09 22:31:04	2020-02-09	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2187	pick-up	0	26
30029	2020-02-09 22:35:50	2020-02-09	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1850	pick-up	0	26
30030	2020-02-09 22:43:34	2020-02-09	12	[{"id_menu":1,"count":1}]	2943	pick-up	0	12
30031	2020-02-09 22:55:21	2020-02-09	8	[{"id_menu":5,"count":1}]	11731	delivery	5	13
30032	2020-02-09 22:56:24	2020-02-09	9	[{"id_menu":7,"count":1}]	173	pick-up	0	9
30033	2020-02-09 22:57:24	2020-02-09	8	[{"id_menu":5,"count":1}]	11795	delivery	5	13
30034	2020-02-09 23:00:32	2020-02-09	12	[{"id_menu":3,"count":1}]	5311	pick-up	0	12
30035	2020-02-09 23:01:41	2020-02-09	9	[{"id_menu":7,"count":1}]	11716	delivery	5	14
30036	2020-02-09 23:03:42	2020-02-09	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11760	delivery	5	43
30037	2020-02-09 23:04:31	2020-02-09	12	[{"id_menu":3,"count":1}]	172	pick-up	0	12
30038	2020-02-09 23:06:08	2020-02-09	12	[{"id_menu":3,"count":1}]	10623	delivery	5	17
30039	2020-02-09 23:07:49	2020-02-09	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	10157	delivery	5	26
30040	2020-02-09 23:14:03	2020-02-09	17	[{"id_menu":4,"count":1}]	37	delivery	5	22
30041	2020-02-09 23:14:07	2020-02-09	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	8933	pick-up	0	21
30042	2020-02-09 23:20:31	2020-02-09	9	[{"id_menu":7,"count":1}]	8568	delivery	5	14
30043	2020-02-09 23:21:45	2020-02-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	11712	delivery	5	22
30044	2020-02-09 23:25:42	2020-02-09	17	[{"id_menu":4,"count":1}]	2857	pick-up	0	17
30045	2020-02-09 23:26:04	2020-02-09	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	11742	delivery	5	25
30046	2020-02-09 23:31:47	2020-02-09	14	[{"id_menu":2,"count":1}]	11792	delivery	5	19
30047	2020-02-09 23:37:51	2020-02-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8206	delivery	5	22
30048	2020-02-09 23:37:53	2020-02-09	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	176	pick-up	0	40
30049	2020-02-09 23:41:54	2020-02-09	12	[{"id_menu":1,"count":1}]	11700	delivery	5	17
30050	2020-02-09 23:50:05	2020-02-09	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	11695	delivery	5	26
30051	2020-02-09 23:52:56	2020-02-09	14	[{"id_menu":2,"count":1}]	1673	pick-up	0	14
30052	2020-02-09 23:55:00	2020-02-09	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11698	delivery	5	51
30053	2020-02-09 23:56:09	2020-02-09	17	[{"id_menu":4,"count":1}]	634	pick-up	0	17
30054	2020-02-09 23:58:36	2020-02-09	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	6088	delivery	5	39
30055	2020-02-09 23:59:47	2020-02-09	9	[{"id_menu":7,"count":2}]	6632	delivery	5	14
30056	2020-02-10 00:10:53	2020-02-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	788	pick-up	0	23
30057	2020-02-10 00:11:08	2020-02-10	12	[{"id_menu":3,"count":1}]	286	pick-up	0	12
30058	2020-02-10 00:20:03	2020-02-10	17	[{"id_menu":4,"count":1}]	11889	delivery	5	22
30059	2020-02-10 00:22:34	2020-02-10	12	[{"id_menu":3,"count":1}]	3635	pick-up	0	12
30060	2020-02-10 00:37:18	2020-02-10	9	[{"id_menu":7,"count":1}]	11833	pick-up	0	9
30061	2020-02-10 00:46:54	2020-02-10	8	[{"id_menu":5,"count":1}]	80	pick-up	0	8
30062	2020-02-10 00:47:38	2020-02-10	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	316	delivery	5	22
30063	2020-02-10 00:54:37	2020-02-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10366	delivery	5	23
30064	2020-02-10 00:56:34	2020-02-10	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	6848	pick-up	0	26
30065	2020-02-10 00:56:37	2020-02-10	17	[{"id_menu":4,"count":1}]	11827	delivery	5	22
30066	2020-02-10 01:10:02	2020-02-10	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8640	pick-up	0	26
30067	2020-02-10 01:12:22	2020-02-10	12	[{"id_menu":1,"count":1}]	8349	delivery	5	17
30068	2020-02-10 01:14:30	2020-02-10	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10421	delivery	5	42
30069	2020-02-10 01:15:45	2020-02-10	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	11828	pick-up	0	21
30070	2020-02-10 01:24:45	2020-02-10	9	[{"id_menu":6,"count":1}]	11840	delivery	5	14
30071	2020-02-10 01:35:14	2020-02-10	12	[{"id_menu":3,"count":1}]	2575	pick-up	0	12
30072	2020-02-10 02:00:30	2020-02-10	9	[{"id_menu":7,"count":1}]	11865	delivery	5	14
30073	2020-02-10 02:00:35	2020-02-10	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11858	delivery	5	35
30074	2020-02-10 02:02:02	2020-02-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8093	delivery	5	23
30075	2020-02-10 02:03:41	2020-02-10	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	766	pick-up	0	20
30076	2020-02-10 02:09:07	2020-02-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	502	delivery	5	28
30077	2020-02-10 02:12:19	2020-02-10	8	[{"id_menu":5,"count":1}]	11832	delivery	5	13
30078	2020-02-10 02:14:09	2020-02-10	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":3}]	11802	delivery	5	26
30079	2020-02-10 02:25:38	2020-02-10	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11841	delivery	5	48
30080	2020-02-10 02:33:03	2020-02-10	8	[{"id_menu":5,"count":1}]	6660	delivery	5	13
30081	2020-02-10 03:04:33	2020-02-10	17	[{"id_menu":4,"count":1}]	7190	pick-up	0	17
30082	2020-02-10 03:09:08	2020-02-10	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	5461	pick-up	0	22
30083	2020-02-10 03:11:59	2020-02-10	9	[{"id_menu":6,"count":1}]	10447	delivery	5	14
30084	2020-02-10 03:15:14	2020-02-10	14	[{"id_menu":2,"count":1}]	6053	delivery	5	19
30085	2020-02-10 03:23:52	2020-02-10	9	[{"id_menu":7,"count":1}]	11819	delivery	5	14
30086	2020-02-10 03:27:36	2020-02-10	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	9034	delivery	5	36
30087	2020-02-10 03:31:25	2020-02-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11877	delivery	5	22
30088	2020-02-10 03:35:49	2020-02-10	8	[{"id_menu":5,"count":1}]	11826	delivery	5	13
30089	2020-02-10 03:55:23	2020-02-10	12	[{"id_menu":1,"count":1}]	11459	pick-up	0	12
30090	2020-02-10 03:56:37	2020-02-10	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	11882	delivery	5	36
30091	2020-02-10 04:01:41	2020-02-10	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	8634	delivery	5	31
30092	2020-02-10 04:09:13	2020-02-10	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11830	delivery	5	34
30093	2020-02-10 04:16:02	2020-02-10	9	[{"id_menu":7,"count":1}]	2783	pick-up	0	9
30094	2020-02-10 04:17:07	2020-02-10	17	[{"id_menu":4,"count":1}]	10194	pick-up	0	17
30095	2020-02-10 04:17:24	2020-02-10	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11805	delivery	5	35
30096	2020-02-10 04:37:00	2020-02-10	9	[{"id_menu":7,"count":1}]	11887	pick-up	0	9
30097	2020-02-10 04:44:55	2020-02-10	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11876	delivery	5	52
30098	2020-02-10 04:45:30	2020-02-10	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	11836	delivery	5	31
30099	2020-02-10 04:51:15	2020-02-10	12	[{"id_menu":1,"count":1}]	11846	delivery	5	17
30100	2020-02-10 05:03:41	2020-02-10	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	11853	delivery	5	25
30101	2020-02-10 05:07:50	2020-02-10	9	[{"id_menu":7,"count":1}]	739	delivery	5	14
30102	2020-02-10 05:51:04	2020-02-10	17	[{"id_menu":4,"count":1}]	8578	delivery	5	22
30103	2020-02-10 05:59:04	2020-02-10	14	[{"id_menu":2,"count":1}]	5970	delivery	5	19
30104	2020-02-10 06:02:18	2020-02-10	9	[{"id_menu":6,"count":1}]	5994	delivery	5	14
30105	2020-02-10 06:05:37	2020-02-10	8	[{"id_menu":5,"count":1}]	2666	pick-up	0	8
30106	2020-02-10 06:13:13	2020-02-10	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	2814	delivery	5	31
30107	2020-02-10 06:49:34	2020-02-10	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	11817	delivery	5	40
30108	2020-02-10 07:20:48	2020-02-10	12	[{"id_menu":1,"count":1}]	9103	delivery	5	17
30109	2020-02-10 07:36:00	2020-02-10	9	[{"id_menu":6,"count":1}]	3503	pick-up	0	9
30110	2020-02-10 07:51:33	2020-02-10	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	964	delivery	5	39
30111	2020-02-10 07:55:40	2020-02-10	9	[{"id_menu":7,"count":1}]	2819	delivery	5	14
30112	2020-02-10 08:14:52	2020-02-10	17	[{"id_menu":4,"count":1}]	1322	delivery	5	22
30113	2020-02-10 08:19:12	2020-02-10	14	[{"id_menu":2,"count":2}]	11837	pick-up	0	14
30114	2020-02-10 08:26:40	2020-02-10	9	[{"id_menu":6,"count":1}]	11893	delivery	5	14
30115	2020-02-10 08:29:54	2020-02-10	17	[{"id_menu":4,"count":1}]	536	pick-up	0	17
30116	2020-02-10 08:33:36	2020-02-10	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":3}]	1680	delivery	5	31
30117	2020-02-10 08:44:19	2020-02-10	9	[{"id_menu":6,"count":1}]	11872	delivery	5	14
30118	2020-02-10 08:55:21	2020-02-10	14	[{"id_menu":2,"count":1}]	656	delivery	5	19
30119	2020-02-10 08:58:55	2020-02-10	14	[{"id_menu":2,"count":1}]	11814	delivery	5	19
30120	2020-02-10 09:03:29	2020-02-10	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8994	delivery	5	43
30121	2020-02-10 09:08:02	2020-02-10	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	2605	delivery	5	26
30122	2020-02-10 09:08:57	2020-02-10	9	[{"id_menu":7,"count":1}]	2719	delivery	5	14
30123	2020-02-10 09:29:18	2020-02-10	9	[{"id_menu":6,"count":1}]	11810	delivery	5	14
30124	2020-02-10 09:35:28	2020-02-10	14	[{"id_menu":2,"count":1}]	7941	pick-up	0	14
30125	2020-02-10 09:41:01	2020-02-10	12	[{"id_menu":1,"count":1}]	11874	delivery	5	17
30126	2020-02-10 09:46:12	2020-02-10	9	[{"id_menu":6,"count":1}]	1427	delivery	5	14
30127	2020-02-10 09:50:13	2020-02-10	8	[{"id_menu":5,"count":1}]	11851	delivery	5	13
30128	2020-02-10 09:53:13	2020-02-10	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11861	delivery	5	49
30129	2020-02-10 09:57:10	2020-02-10	14	[{"id_menu":2,"count":1}]	3288	delivery	5	19
30130	2020-02-10 10:01:04	2020-02-10	9	[{"id_menu":7,"count":1}]	11863	delivery	5	14
30131	2020-02-10 10:07:23	2020-02-10	17	[{"id_menu":4,"count":1}]	11581	delivery	5	22
30132	2020-02-10 10:16:17	2020-02-10	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2280	delivery	5	40
30133	2020-02-10 10:19:00	2020-02-10	8	[{"id_menu":5,"count":1}]	1992	delivery	5	13
30134	2020-02-10 10:20:30	2020-02-10	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	4094	pick-up	0	18
30135	2020-02-10 10:46:04	2020-02-10	8	[{"id_menu":5,"count":1}]	11444	pick-up	0	8
30136	2020-02-10 11:21:46	2020-02-10	14	[{"id_menu":2,"count":1}]	124	pick-up	0	14
30137	2020-02-10 11:26:13	2020-02-10	9	[{"id_menu":6,"count":1}]	11894	pick-up	0	9
30138	2020-02-10 11:46:40	2020-02-10	14	[{"id_menu":2,"count":1}]	1275	delivery	5	19
30139	2020-02-10 11:46:57	2020-02-10	14	[{"id_menu":2,"count":1}]	8743	delivery	5	19
30140	2020-02-10 11:53:03	2020-02-10	17	[{"id_menu":4,"count":1}]	6385	pick-up	0	17
30141	2020-02-10 12:04:15	2020-02-10	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	11867	delivery	5	56
30142	2020-02-10 12:08:13	2020-02-10	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	4881	delivery	5	36
30143	2020-02-10 12:20:53	2020-02-10	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3434	pick-up	0	26
30144	2020-02-10 12:39:19	2020-02-10	12	[{"id_menu":3,"count":1}]	11888	delivery	5	17
30145	2020-02-10 12:39:55	2020-02-10	17	[{"id_menu":4,"count":1}]	11842	delivery	5	22
30146	2020-02-10 12:41:27	2020-02-10	14	[{"id_menu":2,"count":1}]	11875	delivery	5	19
30147	2020-02-10 12:44:39	2020-02-10	17	[{"id_menu":4,"count":1}]	11844	delivery	5	22
30148	2020-02-10 12:45:09	2020-02-10	12	[{"id_menu":1,"count":1}]	9723	delivery	5	17
30149	2020-02-10 12:50:21	2020-02-10	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	7726	delivery	5	25
30150	2020-02-10 13:00:31	2020-02-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10269	delivery	5	23
30151	2020-02-10 13:21:56	2020-02-10	9	[{"id_menu":7,"count":1}]	4874	delivery	5	14
30152	2020-02-10 13:22:31	2020-02-10	8	[{"id_menu":5,"count":1}]	11878	pick-up	0	8
30153	2020-02-10 13:30:55	2020-02-10	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1387	pick-up	0	29
30154	2020-02-10 13:39:26	2020-02-10	12	[{"id_menu":1,"count":1}]	6295	delivery	5	17
30155	2020-02-10 13:46:58	2020-02-10	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11849	delivery	5	39
30156	2020-02-10 13:51:54	2020-02-10	17	[{"id_menu":4,"count":1}]	1208	delivery	5	22
30157	2020-02-10 14:03:06	2020-02-10	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8598	pick-up	0	38
30158	2020-02-10 14:04:11	2020-02-10	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4770	pick-up	0	29
30159	2020-02-10 14:16:21	2020-02-10	12	[{"id_menu":3,"count":1}]	9249	delivery	5	17
30160	2020-02-10 14:33:13	2020-02-10	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5173	delivery	5	22
30161	2020-02-10 14:38:49	2020-02-10	12	[{"id_menu":1,"count":1}]	11809	pick-up	0	12
30162	2020-02-10 14:47:11	2020-02-10	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	919	pick-up	0	26
30163	2020-02-10 15:04:32	2020-02-10	14	[{"id_menu":2,"count":1}]	3116	pick-up	0	14
30164	2020-02-10 15:10:03	2020-02-10	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	11804	delivery	5	30
30165	2020-02-10 15:13:49	2020-02-10	9	[{"id_menu":6,"count":1}]	2000	pick-up	0	9
30166	2020-02-10 15:24:24	2020-02-10	9	[{"id_menu":6,"count":1}]	3968	pick-up	0	9
30167	2020-02-10 15:30:08	2020-02-10	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	946	pick-up	0	21
30168	2020-02-10 15:42:17	2020-02-10	14	[{"id_menu":2,"count":1}]	2313	pick-up	0	14
30169	2020-02-10 15:51:53	2020-02-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	371	pick-up	0	23
30170	2020-02-10 16:07:25	2020-02-10	9	[{"id_menu":6,"count":1}]	11835	delivery	5	14
30171	2020-02-10 16:07:47	2020-02-10	12	[{"id_menu":1,"count":2}]	5110	delivery	5	17
30172	2020-02-10 16:10:14	2020-02-10	12	[{"id_menu":1,"count":1}]	11868	delivery	5	17
30173	2020-02-10 16:22:45	2020-02-10	12	[{"id_menu":1,"count":1}]	11390	delivery	5	17
30174	2020-02-10 16:25:50	2020-02-10	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	5134	delivery	5	31
30175	2020-02-10 16:26:18	2020-02-10	9	[{"id_menu":7,"count":2}]	1902	pick-up	0	9
30176	2020-02-10 16:28:28	2020-02-10	9	[{"id_menu":6,"count":1}]	4634	pick-up	0	9
30177	2020-02-10 16:31:43	2020-02-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	11686	pick-up	0	18
30178	2020-02-10 16:37:41	2020-02-10	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11869	delivery	5	36
30179	2020-02-10 16:40:34	2020-02-10	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	11870	pick-up	0	31
30180	2020-02-10 16:43:02	2020-02-10	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	7544	delivery	5	28
30181	2020-02-10 16:44:05	2020-02-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3660	delivery	5	22
30182	2020-02-10 17:04:15	2020-02-10	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	4287	delivery	5	31
30183	2020-02-10 17:14:04	2020-02-10	14	[{"id_menu":2,"count":1}]	9566	pick-up	0	14
30184	2020-02-10 17:26:58	2020-02-10	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	9609	delivery	5	31
30185	2020-02-10 17:27:00	2020-02-10	14	[{"id_menu":2,"count":1}]	5360	delivery	5	19
30186	2020-02-10 17:29:05	2020-02-10	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11879	delivery	5	45
30187	2020-02-10 17:44:28	2020-02-10	17	[{"id_menu":4,"count":1}]	11871	delivery	5	22
30188	2020-02-10 18:12:43	2020-02-10	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9021	delivery	5	34
30189	2020-02-10 18:14:59	2020-02-10	12	[{"id_menu":1,"count":1}]	6916	delivery	5	17
30190	2020-02-10 18:34:25	2020-02-10	14	[{"id_menu":2,"count":1}]	260	pick-up	0	14
30191	2020-02-10 18:40:34	2020-02-10	14	[{"id_menu":2,"count":1}]	11813	delivery	5	19
30192	2020-02-10 19:07:38	2020-02-10	17	[{"id_menu":4,"count":1}]	4062	pick-up	0	17
30193	2020-02-10 19:13:28	2020-02-10	8	[{"id_menu":5,"count":1}]	8081	delivery	5	13
30194	2020-02-10 19:16:21	2020-02-10	14	[{"id_menu":2,"count":1}]	1268	delivery	5	19
30195	2020-02-10 19:19:25	2020-02-10	9	[{"id_menu":7,"count":1}]	11850	pick-up	0	9
30196	2020-02-10 19:26:35	2020-02-10	14	[{"id_menu":2,"count":1}]	11812	delivery	5	19
30197	2020-02-10 19:27:20	2020-02-10	12	[{"id_menu":1,"count":1}]	431	pick-up	0	12
30198	2020-02-10 19:40:14	2020-02-10	9	[{"id_menu":6,"count":1}]	11807	delivery	5	14
30199	2020-02-10 19:42:42	2020-02-10	9	[{"id_menu":7,"count":1}]	11873	delivery	5	14
30200	2020-02-10 19:44:33	2020-02-10	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	4411	delivery	5	34
30201	2020-02-10 20:11:26	2020-02-10	9	[{"id_menu":6,"count":2}]	3681	delivery	5	14
30202	2020-02-10 20:20:46	2020-02-10	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1110	pick-up	0	21
30203	2020-02-10 20:26:02	2020-02-10	9	[{"id_menu":7,"count":1}]	2683	delivery	5	14
30204	2020-02-10 20:40:46	2020-02-10	14	[{"id_menu":2,"count":1}]	9352	delivery	5	19
30205	2020-02-10 20:46:00	2020-02-10	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9380	delivery	5	37
30206	2020-02-10 20:46:39	2020-02-10	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	11816	delivery	5	27
30207	2020-02-10 20:49:19	2020-02-10	8	[{"id_menu":5,"count":1}]	5517	delivery	5	13
30208	2020-02-10 20:57:17	2020-02-10	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	3403	pick-up	0	26
30209	2020-02-10 21:05:57	2020-02-10	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	6424	delivery	5	39
30210	2020-02-10 21:09:33	2020-02-10	17	[{"id_menu":4,"count":1}]	8251	pick-up	0	17
30211	2020-02-10 21:13:21	2020-02-10	12	[{"id_menu":1,"count":1}]	1509	pick-up	0	12
30212	2020-02-10 21:25:27	2020-02-10	14	[{"id_menu":2,"count":1}]	11797	pick-up	0	14
30213	2020-02-10 21:38:30	2020-02-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2519	pick-up	0	23
30214	2020-02-10 21:38:50	2020-02-10	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	11886	delivery	5	40
30215	2020-02-10 21:46:23	2020-02-10	12	[{"id_menu":1,"count":1}]	1896	pick-up	0	12
30216	2020-02-10 22:10:55	2020-02-10	8	[{"id_menu":5,"count":1}]	575	pick-up	0	8
30217	2020-02-10 22:17:40	2020-02-10	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	4800	pick-up	0	17
30218	2020-02-10 22:33:03	2020-02-10	9	[{"id_menu":7,"count":1}]	1494	delivery	5	14
30219	2020-02-10 22:55:22	2020-02-10	8	[{"id_menu":5,"count":1}]	4485	delivery	5	13
30220	2020-02-10 23:01:45	2020-02-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	11823	delivery	5	22
30221	2020-02-10 23:14:48	2020-02-10	9	[{"id_menu":6,"count":1}]	11883	delivery	5	14
30222	2020-02-10 23:17:32	2020-02-10	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9398	delivery	5	22
30223	2020-02-10 23:34:27	2020-02-10	9	[{"id_menu":7,"count":3}]	11891	delivery	5	14
30224	2020-02-10 23:37:38	2020-02-10	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8865	delivery	5	48
30225	2020-02-10 23:53:39	2020-02-10	12	[{"id_menu":3,"count":1}]	11857	delivery	5	17
30226	2020-02-11 00:00:27	2020-02-11	9	[{"id_menu":6,"count":2}]	1315	delivery	5	14
30227	2020-02-11 00:11:34	2020-02-11	8	[{"id_menu":5,"count":1}]	180	delivery	5	13
30228	2020-02-11 00:13:46	2020-02-11	9	[{"id_menu":6,"count":1}]	1727	pick-up	0	9
30229	2020-02-11 00:18:47	2020-02-11	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	7706	pick-up	0	29
30230	2020-02-11 00:22:52	2020-02-11	12	[{"id_menu":3,"count":1}]	4411	pick-up	0	12
30231	2020-02-11 00:27:54	2020-02-11	12	[{"id_menu":1,"count":1}]	2072	pick-up	0	12
30232	2020-02-11 00:30:33	2020-02-11	14	[{"id_menu":2,"count":1}]	2397	pick-up	0	14
30233	2020-02-11 00:34:13	2020-02-11	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	11989	delivery	5	26
30234	2020-02-11 00:44:54	2020-02-11	12	[{"id_menu":1,"count":1}]	1455	pick-up	0	12
30235	2020-02-11 00:48:59	2020-02-11	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	4546	pick-up	0	30
30236	2020-02-11 00:49:53	2020-02-11	17	[{"id_menu":4,"count":1}]	4804	pick-up	0	17
30237	2020-02-11 00:56:58	2020-02-11	12	[{"id_menu":3,"count":1}]	11956	delivery	5	17
30238	2020-02-11 01:07:42	2020-02-11	9	[{"id_menu":7,"count":1}]	2856	pick-up	0	9
30239	2020-02-11 01:17:35	2020-02-11	9	[{"id_menu":6,"count":3}]	11932	delivery	5	14
30240	2020-02-11 01:30:29	2020-02-11	9	[{"id_menu":7,"count":1}]	1536	pick-up	0	9
30241	2020-02-11 01:30:44	2020-02-11	12	[{"id_menu":1,"count":1}]	6758	pick-up	0	12
30242	2020-02-11 01:34:39	2020-02-11	17	[{"id_menu":4,"count":1}]	9200	delivery	5	22
30243	2020-02-11 01:45:06	2020-02-11	9	[{"id_menu":7,"count":1}]	11925	delivery	5	14
30244	2020-02-11 01:46:08	2020-02-11	9	[{"id_menu":6,"count":1}]	5311	pick-up	0	9
30245	2020-02-11 01:52:32	2020-02-11	9	[{"id_menu":7,"count":1}]	11881	delivery	5	14
30246	2020-02-11 01:59:06	2020-02-11	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5242	pick-up	0	40
30247	2020-02-11 02:00:34	2020-02-11	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	7710	pick-up	0	21
30248	2020-02-11 02:03:25	2020-02-11	14	[{"id_menu":2,"count":1}]	8064	delivery	5	19
30249	2020-02-11 02:08:37	2020-02-11	14	[{"id_menu":2,"count":2}]	526	delivery	5	19
30250	2020-02-11 02:19:03	2020-02-11	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	11937	delivery	5	40
30251	2020-02-11 02:32:21	2020-02-11	12	[{"id_menu":1,"count":1}]	11992	pick-up	0	12
30252	2020-02-11 02:36:58	2020-02-11	9	[{"id_menu":7,"count":1}]	1821	pick-up	0	9
30253	2020-02-11 02:38:11	2020-02-11	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	10792	delivery	5	31
30254	2020-02-11 02:38:33	2020-02-11	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11947	delivery	5	45
30255	2020-02-11 02:44:46	2020-02-11	9	[{"id_menu":7,"count":2}]	5977	delivery	5	14
30256	2020-02-11 02:50:30	2020-02-11	12	[{"id_menu":3,"count":1}]	2828	pick-up	0	12
30257	2020-02-11 02:54:46	2020-02-11	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3534	delivery	5	42
30258	2020-02-11 02:56:48	2020-02-11	9	[{"id_menu":6,"count":1}]	11965	delivery	5	14
30259	2020-02-11 02:57:12	2020-02-11	8	[{"id_menu":5,"count":1}]	9761	delivery	5	13
30260	2020-02-11 03:02:54	2020-02-11	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	4637	pick-up	0	23
30261	2020-02-11 03:03:58	2020-02-11	14	[{"id_menu":2,"count":1}]	2179	delivery	5	19
30262	2020-02-11 03:06:57	2020-02-11	8	[{"id_menu":5,"count":1}]	11942	delivery	5	13
30263	2020-02-11 03:23:05	2020-02-11	12	[{"id_menu":3,"count":1}]	4994	delivery	5	17
30264	2020-02-11 03:25:40	2020-02-11	14	[{"id_menu":2,"count":1}]	4242	pick-up	0	14
30265	2020-02-11 03:45:37	2020-02-11	12	[{"id_menu":1,"count":1}]	8847	delivery	5	17
30266	2020-02-11 03:52:50	2020-02-11	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4590	pick-up	0	31
30267	2020-02-11 03:53:25	2020-02-11	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	11914	pick-up	0	37
30268	2020-02-11 04:07:51	2020-02-11	12	[{"id_menu":1,"count":1}]	11957	delivery	5	17
30269	2020-02-11 04:10:56	2020-02-11	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	479	delivery	5	23
30270	2020-02-11 04:19:01	2020-02-11	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	11958	delivery	5	29
30271	2020-02-11 04:19:31	2020-02-11	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	8052	delivery	5	34
30272	2020-02-11 04:21:01	2020-02-11	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	399	pick-up	0	20
30273	2020-02-11 04:34:50	2020-02-11	9	[{"id_menu":7,"count":1}]	11919	delivery	5	14
30274	2020-02-11 04:37:42	2020-02-11	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	3481	pick-up	0	29
30275	2020-02-11 04:53:10	2020-02-11	8	[{"id_menu":5,"count":1}]	4098	delivery	5	13
30276	2020-02-11 05:01:27	2020-02-11	14	[{"id_menu":2,"count":1}]	6221	pick-up	0	14
30277	2020-02-11 05:09:22	2020-02-11	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	7261	delivery	5	22
30278	2020-02-11 05:10:55	2020-02-11	9	[{"id_menu":6,"count":1}]	749	pick-up	0	9
30279	2020-02-11 05:24:07	2020-02-11	9	[{"id_menu":6,"count":2}]	11998	delivery	5	14
30280	2020-02-11 05:24:15	2020-02-11	17	[{"id_menu":4,"count":1}]	6901	delivery	5	22
30281	2020-02-11 05:32:57	2020-02-11	14	[{"id_menu":2,"count":1}]	5354	pick-up	0	14
30282	2020-02-11 05:33:19	2020-02-11	9	[{"id_menu":6,"count":1}]	8873	pick-up	0	9
30283	2020-02-11 06:06:50	2020-02-11	12	[{"id_menu":1,"count":1}]	6248	delivery	5	17
30284	2020-02-11 06:13:02	2020-02-11	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2024	pick-up	0	21
30285	2020-02-11 06:14:21	2020-02-11	9	[{"id_menu":7,"count":1}]	5893	pick-up	0	9
30286	2020-02-11 06:20:44	2020-02-11	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4599	delivery	5	38
30287	2020-02-11 06:21:01	2020-02-11	12	[{"id_menu":1,"count":2}]	11939	delivery	5	17
30288	2020-02-11 06:24:05	2020-02-11	12	[{"id_menu":3,"count":1}]	11945	delivery	5	17
30289	2020-02-11 06:31:21	2020-02-11	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2894	delivery	5	22
30290	2020-02-11 06:47:23	2020-02-11	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11929	delivery	5	34
30291	2020-02-11 06:51:16	2020-02-11	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7903	delivery	5	54
30292	2020-02-11 07:01:54	2020-02-11	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	917	delivery	5	37
30293	2020-02-11 07:06:53	2020-02-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	11971	delivery	5	28
30294	2020-02-11 07:10:22	2020-02-11	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	5082	pick-up	0	20
30295	2020-02-11 07:17:39	2020-02-11	17	[{"id_menu":4,"count":1}]	11991	delivery	5	22
30296	2020-02-11 07:22:58	2020-02-11	9	[{"id_menu":7,"count":1}]	6489	delivery	5	14
30297	2020-02-11 07:25:16	2020-02-11	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	11997	delivery	5	25
30298	2020-02-11 07:41:02	2020-02-11	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	5767	delivery	5	40
30299	2020-02-11 07:47:58	2020-02-11	9	[{"id_menu":6,"count":1}]	11948	delivery	5	14
30300	2020-02-11 07:51:56	2020-02-11	38	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	4389	delivery	5	43
30301	2020-02-11 07:58:49	2020-02-11	17	[{"id_menu":4,"count":1}]	11915	pick-up	0	17
30302	2020-02-11 07:59:12	2020-02-11	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7513	delivery	5	43
30303	2020-02-11 08:06:34	2020-02-11	9	[{"id_menu":6,"count":1}]	11955	delivery	5	14
30304	2020-02-11 08:08:29	2020-02-11	9	[{"id_menu":7,"count":1}]	9381	delivery	5	14
30305	2020-02-11 08:17:02	2020-02-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	3761	delivery	5	22
30306	2020-02-11 08:20:38	2020-02-11	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	7795	delivery	5	39
30307	2020-02-11 08:21:47	2020-02-11	14	[{"id_menu":2,"count":1}]	10436	pick-up	0	14
30308	2020-02-11 08:33:15	2020-02-11	9	[{"id_menu":6,"count":1}]	390	pick-up	0	9
30309	2020-02-11 08:34:07	2020-02-11	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	5642	pick-up	0	21
30310	2020-02-11 08:34:39	2020-02-11	17	[{"id_menu":4,"count":1}]	4629	pick-up	0	17
30311	2020-02-11 08:44:21	2020-02-11	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	10151	delivery	5	26
30312	2020-02-11 09:07:38	2020-02-11	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	7834	pick-up	0	20
30313	2020-02-11 09:12:46	2020-02-11	9	[{"id_menu":7,"count":1}]	11936	delivery	5	14
30314	2020-02-11 09:13:40	2020-02-11	9	[{"id_menu":7,"count":1}]	7279	delivery	5	14
30315	2020-02-11 09:26:26	2020-02-11	12	[{"id_menu":1,"count":1}]	3803	delivery	5	17
30316	2020-02-11 09:26:29	2020-02-11	14	[{"id_menu":2,"count":1}]	11534	delivery	5	19
30317	2020-02-11 09:27:24	2020-02-11	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2561	pick-up	0	26
30318	2020-02-11 09:27:30	2020-02-11	14	[{"id_menu":2,"count":1}]	11911	delivery	5	19
30319	2020-02-11 09:38:34	2020-02-11	9	[{"id_menu":7,"count":1}]	9433	delivery	5	14
30320	2020-02-11 09:41:28	2020-02-11	17	[{"id_menu":4,"count":1}]	8298	pick-up	0	17
30321	2020-02-11 09:43:56	2020-02-11	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1176	pick-up	0	29
30322	2020-02-11 09:58:49	2020-02-11	14	[{"id_menu":2,"count":1}]	11982	delivery	5	19
30323	2020-02-11 10:03:35	2020-02-11	12	[{"id_menu":1,"count":1}]	11969	pick-up	0	12
30324	2020-02-11 10:12:03	2020-02-11	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	4838	pick-up	0	20
30325	2020-02-11 10:16:55	2020-02-11	12	[{"id_menu":1,"count":1}]	1627	delivery	5	17
30326	2020-02-11 10:17:00	2020-02-11	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6355	delivery	5	36
30327	2020-02-11 10:22:46	2020-02-11	9	[{"id_menu":6,"count":1}]	11927	delivery	5	14
30328	2020-02-11 10:27:57	2020-02-11	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	6787	delivery	5	34
30329	2020-02-11 10:36:28	2020-02-11	9	[{"id_menu":7,"count":1}]	11950	delivery	5	14
30330	2020-02-11 10:38:21	2020-02-11	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	12000	delivery	5	30
30331	2020-02-11 10:44:09	2020-02-11	12	[{"id_menu":1,"count":1}]	9965	delivery	5	17
30332	2020-02-11 10:47:38	2020-02-11	9	[{"id_menu":6,"count":1}]	1512	delivery	5	14
30333	2020-02-11 10:48:05	2020-02-11	12	[{"id_menu":1,"count":1}]	7745	pick-up	0	12
30334	2020-02-11 10:49:13	2020-02-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7691	delivery	5	28
30335	2020-02-11 10:50:59	2020-02-11	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	11920	delivery	5	31
30336	2020-02-11 10:51:07	2020-02-11	14	[{"id_menu":2,"count":2}]	3002	pick-up	0	14
30337	2020-02-11 10:58:48	2020-02-11	14	[{"id_menu":2,"count":1}]	3432	delivery	5	19
30338	2020-02-11 11:03:39	2020-02-11	8	[{"id_menu":5,"count":1}]	11978	delivery	5	13
30339	2020-02-11 11:06:19	2020-02-11	8	[{"id_menu":5,"count":1}]	5958	delivery	5	13
30340	2020-02-11 11:06:26	2020-02-11	14	[{"id_menu":2,"count":1}]	8295	delivery	5	19
30341	2020-02-11 11:09:22	2020-02-11	12	[{"id_menu":1,"count":1}]	11961	delivery	5	17
30342	2020-02-11 11:26:32	2020-02-11	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	52	pick-up	0	21
30343	2020-02-11 11:29:21	2020-02-11	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	5097	delivery	5	26
30344	2020-02-11 11:35:37	2020-02-11	14	[{"id_menu":2,"count":1}]	2101	pick-up	0	14
30345	2020-02-11 11:40:01	2020-02-11	9	[{"id_menu":6,"count":1}]	6703	pick-up	0	9
30346	2020-02-11 11:43:33	2020-02-11	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3067	delivery	5	57
30347	2020-02-11 11:46:35	2020-02-11	9	[{"id_menu":6,"count":1}]	8675	delivery	5	14
30348	2020-02-11 11:49:30	2020-02-11	17	[{"id_menu":4,"count":1}]	5970	pick-up	0	17
30349	2020-02-11 12:18:26	2020-02-11	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2928	delivery	5	27
30350	2020-02-11 12:25:44	2020-02-11	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7153	delivery	5	34
30351	2020-02-11 12:31:18	2020-02-11	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8146	pick-up	0	26
30352	2020-02-11 12:56:01	2020-02-11	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7227	delivery	5	43
30353	2020-02-11 12:57:28	2020-02-11	17	[{"id_menu":4,"count":1}]	563	delivery	5	22
30354	2020-02-11 13:03:09	2020-02-11	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	8435	delivery	5	31
30355	2020-02-11 13:36:40	2020-02-11	12	[{"id_menu":1,"count":1}]	11987	pick-up	0	12
30356	2020-02-11 13:36:55	2020-02-11	14	[{"id_menu":2,"count":1}]	832	pick-up	0	14
30357	2020-02-11 13:54:26	2020-02-11	9	[{"id_menu":6,"count":1}]	6648	delivery	5	14
30358	2020-02-11 13:57:44	2020-02-11	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	3768	delivery	5	22
30359	2020-02-11 14:02:45	2020-02-11	17	[{"id_menu":4,"count":1}]	11940	pick-up	0	17
30360	2020-02-11 14:07:46	2020-02-11	8	[{"id_menu":5,"count":1}]	11995	delivery	5	13
30361	2020-02-11 14:11:14	2020-02-11	9	[{"id_menu":6,"count":1}]	715	pick-up	0	9
30362	2020-02-11 14:15:29	2020-02-11	8	[{"id_menu":5,"count":1}]	2153	delivery	5	13
30363	2020-02-11 14:16:41	2020-02-11	14	[{"id_menu":2,"count":1}]	11779	pick-up	0	14
30364	2020-02-11 14:21:20	2020-02-11	9	[{"id_menu":6,"count":1}]	11938	delivery	5	14
30365	2020-02-11 14:26:38	2020-02-11	12	[{"id_menu":3,"count":1}]	636	delivery	5	17
30366	2020-02-11 14:30:28	2020-02-11	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3367	delivery	5	31
30367	2020-02-11 14:39:44	2020-02-11	9	[{"id_menu":7,"count":2}]	6116	delivery	5	14
30368	2020-02-11 15:27:31	2020-02-11	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	11928	delivery	5	25
30369	2020-02-11 15:31:02	2020-02-11	9	[{"id_menu":6,"count":2}]	11984	delivery	5	14
30370	2020-02-11 15:36:23	2020-02-11	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	11905	delivery	5	36
30371	2020-02-11 15:44:06	2020-02-11	8	[{"id_menu":5,"count":1}]	381	pick-up	0	8
30372	2020-02-11 15:44:59	2020-02-11	17	[{"id_menu":4,"count":1}]	4648	pick-up	0	17
30373	2020-02-11 15:47:45	2020-02-11	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	8877	delivery	5	31
30374	2020-02-11 16:12:36	2020-02-11	9	[{"id_menu":6,"count":1}]	2770	pick-up	0	9
30375	2020-02-11 16:13:24	2020-02-11	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	7277	delivery	5	34
30376	2020-02-11 16:14:24	2020-02-11	14	[{"id_menu":2,"count":1}]	6683	delivery	5	19
30377	2020-02-11 16:25:43	2020-02-11	9	[{"id_menu":7,"count":1}]	8227	delivery	5	14
30378	2020-02-11 16:32:45	2020-02-11	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9011	delivery	5	31
30379	2020-02-11 16:32:48	2020-02-11	46	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	6448	delivery	5	51
30380	2020-02-11 16:50:16	2020-02-11	12	[{"id_menu":3,"count":1}]	8071	delivery	5	17
30381	2020-02-11 16:54:05	2020-02-11	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	11898	pick-up	0	24
30382	2020-02-11 16:58:53	2020-02-11	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11941	delivery	5	52
30383	2020-02-11 17:03:46	2020-02-11	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	9701	delivery	5	26
30384	2020-02-11 17:11:46	2020-02-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	10267	delivery	5	28
30385	2020-02-11 17:15:54	2020-02-11	9	[{"id_menu":7,"count":1}]	11922	delivery	5	14
30386	2020-02-11 17:18:21	2020-02-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	11985	delivery	5	23
30387	2020-02-11 17:26:32	2020-02-11	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	11968	delivery	5	31
30388	2020-02-11 17:27:14	2020-02-11	12	[{"id_menu":3,"count":1}]	11896	pick-up	0	12
30389	2020-02-11 17:39:35	2020-02-11	9	[{"id_menu":7,"count":1}]	868	delivery	5	14
30390	2020-02-11 18:16:02	2020-02-11	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2594	pick-up	0	38
30391	2020-02-11 18:21:14	2020-02-11	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	11407	delivery	5	46
30392	2020-02-11 18:25:31	2020-02-11	8	[{"id_menu":5,"count":1}]	11906	delivery	5	13
30393	2020-02-11 18:27:06	2020-02-11	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	11735	delivery	5	31
30394	2020-02-11 18:27:12	2020-02-11	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1005	delivery	5	37
30395	2020-02-11 18:28:51	2020-02-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1457	delivery	5	22
30396	2020-02-11 18:30:29	2020-02-11	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8341	pick-up	0	17
30397	2020-02-11 18:33:18	2020-02-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	11977	delivery	5	28
30398	2020-02-11 18:41:51	2020-02-11	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	11972	delivery	5	36
30399	2020-02-11 18:48:22	2020-02-11	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	11964	delivery	5	40
30400	2020-02-11 18:59:23	2020-02-11	12	[{"id_menu":3,"count":1}]	8372	pick-up	0	12
30401	2020-02-11 19:05:31	2020-02-11	17	[{"id_menu":4,"count":1}]	9784	delivery	5	22
30402	2020-02-11 19:19:23	2020-02-11	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	29	delivery	5	28
30403	2020-02-11 19:20:17	2020-02-11	9	[{"id_menu":6,"count":1}]	6798	delivery	5	14
30404	2020-02-11 19:23:12	2020-02-11	14	[{"id_menu":2,"count":1}]	5041	pick-up	0	14
30405	2020-02-11 19:28:43	2020-02-11	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4358	delivery	5	30
30406	2020-02-11 19:30:35	2020-02-11	12	[{"id_menu":1,"count":1}]	8600	delivery	5	17
30407	2020-02-11 19:34:38	2020-02-11	9	[{"id_menu":6,"count":2}]	11993	delivery	5	14
30408	2020-02-11 19:49:36	2020-02-11	14	[{"id_menu":2,"count":1}]	11975	delivery	5	19
30409	2020-02-11 19:57:16	2020-02-11	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11979	delivery	5	45
30410	2020-02-11 20:16:45	2020-02-11	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	11913	delivery	5	40
30411	2020-02-11 20:19:02	2020-02-11	14	[{"id_menu":2,"count":1}]	5920	delivery	5	19
30412	2020-02-11 20:24:41	2020-02-11	9	[{"id_menu":6,"count":1}]	11931	delivery	5	14
30413	2020-02-11 20:31:20	2020-02-11	14	[{"id_menu":2,"count":1}]	11926	pick-up	0	14
30414	2020-02-11 20:39:21	2020-02-11	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8727	delivery	5	43
30415	2020-02-11 21:12:13	2020-02-11	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	9954	delivery	5	31
30416	2020-02-11 21:32:55	2020-02-11	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	11960	pick-up	0	21
30417	2020-02-11 21:48:43	2020-02-11	9	[{"id_menu":6,"count":1}]	10264	pick-up	0	9
30418	2020-02-11 21:49:50	2020-02-11	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	11897	delivery	5	31
30419	2020-02-11 21:49:59	2020-02-11	9	[{"id_menu":6,"count":1}]	8550	pick-up	0	9
30420	2020-02-11 22:03:32	2020-02-11	9	[{"id_menu":7,"count":1}]	11901	delivery	5	14
30421	2020-02-11 22:12:11	2020-02-11	12	[{"id_menu":3,"count":1}]	11983	delivery	5	17
30422	2020-02-11 22:13:51	2020-02-11	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	11930	pick-up	0	31
30423	2020-02-11 22:16:48	2020-02-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11921	delivery	5	23
30424	2020-02-11 22:32:13	2020-02-11	12	[{"id_menu":1,"count":1}]	11934	delivery	5	17
30425	2020-02-11 22:36:04	2020-02-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11973	delivery	5	22
30426	2020-02-11 22:37:47	2020-02-11	17	[{"id_menu":4,"count":1}]	11976	delivery	5	22
30427	2020-02-11 22:43:54	2020-02-11	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	11946	pick-up	0	21
30428	2020-02-11 22:50:45	2020-02-11	12	[{"id_menu":3,"count":1}]	7204	delivery	5	17
30429	2020-02-11 22:56:16	2020-02-11	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	6998	delivery	5	26
30430	2020-02-11 22:58:26	2020-02-11	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	11912	delivery	5	37
30431	2020-02-11 23:15:42	2020-02-11	14	[{"id_menu":2,"count":1}]	7431	delivery	5	19
30432	2020-02-11 23:18:58	2020-02-11	9	[{"id_menu":6,"count":1}]	964	delivery	5	14
30433	2020-02-11 23:19:43	2020-02-11	12	[{"id_menu":3,"count":1}]	5668	pick-up	0	12
30434	2020-02-11 23:33:32	2020-02-11	9	[{"id_menu":7,"count":1}]	5493	delivery	5	14
30435	2020-02-11 23:37:36	2020-02-11	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1597	delivery	5	34
30436	2020-02-11 23:48:11	2020-02-11	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11899	delivery	5	34
30437	2020-02-11 23:51:33	2020-02-11	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6202	pick-up	0	26
30438	2020-02-11 23:56:57	2020-02-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	11963	pick-up	0	23
30439	2020-02-11 23:58:09	2020-02-11	8	[{"id_menu":5,"count":1}]	11967	delivery	5	13
30440	2020-02-12 00:03:35	2020-02-12	12	[{"id_menu":3,"count":1}]	7772	pick-up	0	12
30441	2020-02-12 00:19:28	2020-02-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	12078	delivery	5	28
30442	2020-02-12 00:21:23	2020-02-12	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	44	pick-up	0	24
30443	2020-02-12 00:22:28	2020-02-12	12	[{"id_menu":3,"count":1}]	8395	pick-up	0	12
30444	2020-02-12 00:26:22	2020-02-12	12	[{"id_menu":1,"count":1}]	6247	delivery	5	17
30445	2020-02-12 00:35:10	2020-02-12	12	[{"id_menu":1,"count":1}]	12007	delivery	5	17
30446	2020-02-12 00:35:36	2020-02-12	14	[{"id_menu":2,"count":1}]	12001	delivery	5	19
30447	2020-02-12 00:35:55	2020-02-12	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12044	delivery	5	43
30448	2020-02-12 00:37:25	2020-02-12	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	9271	delivery	5	34
30449	2020-02-12 00:40:45	2020-02-12	9	[{"id_menu":6,"count":1}]	12094	delivery	5	14
30450	2020-02-12 00:52:05	2020-02-12	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	4042	pick-up	0	26
30451	2020-02-12 01:02:49	2020-02-12	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	12033	delivery	5	27
30452	2020-02-12 01:03:48	2020-02-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12039	delivery	5	22
30453	2020-02-12 01:08:08	2020-02-12	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	12084	delivery	5	34
30454	2020-02-12 01:15:26	2020-02-12	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	4309	pick-up	0	29
30455	2020-02-12 01:17:40	2020-02-12	14	[{"id_menu":2,"count":1}]	12054	delivery	5	19
30456	2020-02-12 01:26:11	2020-02-12	17	[{"id_menu":4,"count":1}]	11433	delivery	5	22
30457	2020-02-12 01:37:27	2020-02-12	8	[{"id_menu":5,"count":1}]	12093	delivery	5	13
30458	2020-02-12 01:38:43	2020-02-12	14	[{"id_menu":2,"count":1}]	2847	pick-up	0	14
30459	2020-02-12 01:53:00	2020-02-12	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	12057	delivery	5	31
30460	2020-02-12 02:04:38	2020-02-12	12	[{"id_menu":1,"count":1}]	1093	pick-up	0	12
30461	2020-02-12 02:10:23	2020-02-12	9	[{"id_menu":6,"count":1}]	8061	delivery	5	14
30462	2020-02-12 02:22:23	2020-02-12	9	[{"id_menu":6,"count":1}]	7051	delivery	5	14
30463	2020-02-12 02:28:47	2020-02-12	9	[{"id_menu":6,"count":1}]	12081	delivery	5	14
30464	2020-02-12 02:33:03	2020-02-12	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1369	pick-up	0	20
30465	2020-02-12 02:43:02	2020-02-12	9	[{"id_menu":7,"count":1}]	3823	delivery	5	14
30466	2020-02-12 02:44:39	2020-02-12	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1860	pick-up	0	29
30467	2020-02-12 02:46:14	2020-02-12	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	10820	delivery	5	28
30468	2020-02-12 03:01:43	2020-02-12	12	[{"id_menu":1,"count":1}]	140	pick-up	0	12
30469	2020-02-12 03:04:30	2020-02-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	11342	delivery	5	31
30470	2020-02-12 03:04:59	2020-02-12	8	[{"id_menu":5,"count":1}]	10864	delivery	5	13
30471	2020-02-12 03:06:19	2020-02-12	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	12056	delivery	5	26
30472	2020-02-12 03:07:29	2020-02-12	9	[{"id_menu":7,"count":1}]	4216	delivery	5	14
30473	2020-02-12 03:10:31	2020-02-12	14	[{"id_menu":2,"count":1}]	10738	pick-up	0	14
30474	2020-02-12 03:26:22	2020-02-12	12	[{"id_menu":3,"count":1}]	11262	pick-up	0	12
30475	2020-02-12 03:26:23	2020-02-12	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2100	pick-up	0	35
30476	2020-02-12 03:46:16	2020-02-12	8	[{"id_menu":5,"count":1}]	12040	delivery	5	13
30477	2020-02-12 03:47:47	2020-02-12	9	[{"id_menu":7,"count":1}]	1676	pick-up	0	9
30478	2020-02-12 03:53:10	2020-02-12	9	[{"id_menu":7,"count":1}]	12046	delivery	5	14
30479	2020-02-12 04:06:24	2020-02-12	9	[{"id_menu":7,"count":1}]	2107	delivery	5	14
30480	2020-02-12 04:06:26	2020-02-12	9	[{"id_menu":7,"count":1}]	10525	pick-up	0	9
30481	2020-02-12 04:06:55	2020-02-12	9	[{"id_menu":6,"count":1}]	7821	delivery	5	14
30482	2020-02-12 04:13:53	2020-02-12	9	[{"id_menu":7,"count":1}]	12019	pick-up	0	9
30483	2020-02-12 04:16:32	2020-02-12	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3	pick-up	0	21
30484	2020-02-12 04:18:54	2020-02-12	38	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8781	delivery	5	43
30485	2020-02-12 04:29:47	2020-02-12	8	[{"id_menu":5,"count":1}]	12025	delivery	5	13
30486	2020-02-12 04:29:56	2020-02-12	9	[{"id_menu":6,"count":1}]	9861	delivery	5	14
30487	2020-02-12 04:38:59	2020-02-12	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	12087	delivery	5	34
30488	2020-02-12 04:40:41	2020-02-12	14	[{"id_menu":2,"count":2}]	12020	delivery	5	19
30489	2020-02-12 04:42:02	2020-02-12	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	10926	delivery	5	27
30490	2020-02-12 04:42:17	2020-02-12	17	[{"id_menu":4,"count":1}]	8074	delivery	5	22
30491	2020-02-12 04:52:56	2020-02-12	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	12005	delivery	5	30
30492	2020-02-12 04:57:05	2020-02-12	9	[{"id_menu":7,"count":1}]	3824	delivery	5	14
30493	2020-02-12 05:04:51	2020-02-12	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7767	delivery	5	40
30494	2020-02-12 05:04:51	2020-02-12	8	[{"id_menu":5,"count":1}]	4929	pick-up	0	8
30495	2020-02-12 05:05:47	2020-02-12	12	[{"id_menu":1,"count":1}]	11777	delivery	5	17
30496	2020-02-12 05:13:11	2020-02-12	9	[{"id_menu":7,"count":1}]	12018	delivery	5	14
30497	2020-02-12 05:24:54	2020-02-12	9	[{"id_menu":6,"count":1}]	12031	pick-up	0	9
30498	2020-02-12 05:29:06	2020-02-12	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6359	pick-up	0	25
30499	2020-02-12 05:29:55	2020-02-12	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	10968	pick-up	0	26
30500	2020-02-12 05:33:51	2020-02-12	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	12030	delivery	5	40
30501	2020-02-12 05:42:51	2020-02-12	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	12061	delivery	5	40
30502	2020-02-12 05:43:07	2020-02-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	232	pick-up	0	26
30503	2020-02-12 05:54:38	2020-02-12	8	[{"id_menu":5,"count":1}]	3493	delivery	5	13
30504	2020-02-12 05:59:13	2020-02-12	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12089	delivery	5	31
30505	2020-02-12 06:02:06	2020-02-12	12	[{"id_menu":1,"count":1}]	12002	delivery	5	17
30506	2020-02-12 06:02:50	2020-02-12	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	8638	pick-up	0	21
30507	2020-02-12 06:04:57	2020-02-12	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	12013	delivery	5	40
30508	2020-02-12 06:10:39	2020-02-12	12	[{"id_menu":3,"count":1}]	12058	delivery	5	17
30509	2020-02-12 06:11:03	2020-02-12	12	[{"id_menu":3,"count":1}]	12077	delivery	5	17
30510	2020-02-12 06:13:02	2020-02-12	9	[{"id_menu":7,"count":1}]	4737	delivery	5	14
30511	2020-02-12 06:14:52	2020-02-12	9	[{"id_menu":6,"count":1}]	12063	delivery	5	14
30512	2020-02-12 06:17:53	2020-02-12	12	[{"id_menu":1,"count":1}]	2453	pick-up	0	12
30513	2020-02-12 06:21:41	2020-02-12	12	[{"id_menu":1,"count":1}]	5297	delivery	5	17
30514	2020-02-12 06:21:55	2020-02-12	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12073	delivery	5	51
30515	2020-02-12 06:27:22	2020-02-12	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4121	pick-up	0	46
30516	2020-02-12 06:30:59	2020-02-12	29	[{"id_menu":3,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7132	delivery	5	34
30517	2020-02-12 06:32:16	2020-02-12	9	[{"id_menu":7,"count":1}]	309	pick-up	0	9
30518	2020-02-12 06:32:47	2020-02-12	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7094	pick-up	0	43
30519	2020-02-12 06:33:06	2020-02-12	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9097	pick-up	0	25
30520	2020-02-12 06:48:46	2020-02-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1670	delivery	5	31
30521	2020-02-12 06:59:24	2020-02-12	17	[{"id_menu":4,"count":1}]	8003	pick-up	0	17
30522	2020-02-12 07:09:38	2020-02-12	9	[{"id_menu":6,"count":1}]	12076	delivery	5	14
30523	2020-02-12 07:10:58	2020-02-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12071	delivery	5	31
30524	2020-02-12 07:18:26	2020-02-12	12	[{"id_menu":3,"count":1}]	5559	pick-up	0	12
30525	2020-02-12 07:25:00	2020-02-12	12	[{"id_menu":1,"count":1}]	11156	pick-up	0	12
30526	2020-02-12 07:29:22	2020-02-12	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2965	delivery	5	40
30527	2020-02-12 07:31:37	2020-02-12	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9447	delivery	5	39
30528	2020-02-12 07:45:14	2020-02-12	14	[{"id_menu":2,"count":1}]	8670	pick-up	0	14
30529	2020-02-12 07:52:57	2020-02-12	17	[{"id_menu":4,"count":1}]	12070	pick-up	0	17
30530	2020-02-12 08:05:28	2020-02-12	14	[{"id_menu":2,"count":1}]	2303	delivery	5	19
30531	2020-02-12 08:07:19	2020-02-12	17	[{"id_menu":4,"count":1}]	6987	pick-up	0	17
30532	2020-02-12 08:18:28	2020-02-12	17	[{"id_menu":4,"count":1}]	11493	pick-up	0	17
30533	2020-02-12 08:19:23	2020-02-12	9	[{"id_menu":6,"count":1}]	12008	delivery	5	14
30534	2020-02-12 08:19:56	2020-02-12	9	[{"id_menu":6,"count":1}]	12049	delivery	5	14
30535	2020-02-12 08:22:24	2020-02-12	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	12062	delivery	5	25
30536	2020-02-12 08:38:09	2020-02-12	9	[{"id_menu":7,"count":1}]	3033	pick-up	0	9
30537	2020-02-12 08:39:10	2020-02-12	9	[{"id_menu":7,"count":1}]	12026	pick-up	0	9
30538	2020-02-12 08:53:19	2020-02-12	14	[{"id_menu":2,"count":1}]	8731	delivery	5	19
30539	2020-02-12 08:55:53	2020-02-12	17	[{"id_menu":4,"count":1}]	11183	pick-up	0	17
30540	2020-02-12 09:02:57	2020-02-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":3}]	12032	delivery	5	23
30541	2020-02-12 09:04:58	2020-02-12	12	[{"id_menu":1,"count":1}]	1313	pick-up	0	12
30542	2020-02-12 09:06:10	2020-02-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12053	pick-up	0	26
30543	2020-02-12 09:14:06	2020-02-12	8	[{"id_menu":5,"count":1}]	1983	pick-up	0	8
30544	2020-02-12 09:22:27	2020-02-12	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	4080	delivery	5	22
30545	2020-02-12 09:24:22	2020-02-12	12	[{"id_menu":3,"count":1}]	536	pick-up	0	12
30546	2020-02-12 09:28:48	2020-02-12	8	[{"id_menu":5,"count":1}]	947	pick-up	0	8
30547	2020-02-12 09:31:47	2020-02-12	14	[{"id_menu":2,"count":1}]	12080	delivery	5	19
30548	2020-02-12 09:45:48	2020-02-12	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	11720	delivery	5	40
30549	2020-02-12 09:51:03	2020-02-12	17	[{"id_menu":4,"count":1}]	4280	delivery	5	22
30550	2020-02-12 09:53:45	2020-02-12	17	[{"id_menu":4,"count":1}]	8019	pick-up	0	17
30551	2020-02-12 09:54:31	2020-02-12	14	[{"id_menu":2,"count":1}]	12090	delivery	5	19
30552	2020-02-12 09:57:42	2020-02-12	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	12074	delivery	5	31
30553	2020-02-12 10:05:21	2020-02-12	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	12051	delivery	5	34
30554	2020-02-12 10:10:17	2020-02-12	14	[{"id_menu":2,"count":1}]	6622	pick-up	0	14
30555	2020-02-12 10:25:47	2020-02-12	12	[{"id_menu":1,"count":1}]	3439	delivery	5	17
30556	2020-02-12 10:26:09	2020-02-12	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	12069	delivery	5	42
30557	2020-02-12 10:39:31	2020-02-12	12	[{"id_menu":1,"count":1}]	12075	pick-up	0	12
30558	2020-02-12 10:41:04	2020-02-12	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	8770	delivery	5	27
30559	2020-02-12 10:42:11	2020-02-12	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	12048	delivery	5	36
30560	2020-02-12 10:45:47	2020-02-12	9	[{"id_menu":6,"count":1}]	12055	delivery	5	14
30561	2020-02-12 10:50:33	2020-02-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1639	pick-up	0	23
30562	2020-02-12 10:57:12	2020-02-12	8	[{"id_menu":5,"count":1}]	5466	pick-up	0	8
30563	2020-02-12 10:57:14	2020-02-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	9833	delivery	5	23
30564	2020-02-12 11:00:35	2020-02-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	8543	pick-up	0	26
30565	2020-02-12 11:10:21	2020-02-12	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3949	pick-up	0	31
30566	2020-02-12 11:13:31	2020-02-12	12	[{"id_menu":1,"count":1}]	1924	pick-up	0	12
30567	2020-02-12 11:15:21	2020-02-12	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	9905	delivery	5	43
30568	2020-02-12 11:24:38	2020-02-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	12015	delivery	5	28
30569	2020-02-12 11:26:39	2020-02-12	14	[{"id_menu":2,"count":1}]	12003	delivery	5	19
30570	2020-02-12 11:29:35	2020-02-12	14	[{"id_menu":2,"count":1}]	12059	delivery	5	19
30571	2020-02-12 11:39:41	2020-02-12	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3168	delivery	5	26
30572	2020-02-12 11:42:45	2020-02-12	8	[{"id_menu":5,"count":1}]	8372	delivery	5	13
30573	2020-02-12 11:44:19	2020-02-12	9	[{"id_menu":7,"count":1}]	6884	delivery	5	14
30574	2020-02-12 11:50:40	2020-02-12	8	[{"id_menu":5,"count":1}]	12066	delivery	5	13
30575	2020-02-12 12:17:21	2020-02-12	9	[{"id_menu":7,"count":1}]	12041	delivery	5	14
30576	2020-02-12 12:21:36	2020-02-12	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	184	pick-up	0	23
30577	2020-02-12 12:25:04	2020-02-12	8	[{"id_menu":5,"count":1}]	12011	delivery	5	13
30578	2020-02-12 12:40:53	2020-02-12	14	[{"id_menu":2,"count":1}]	1700	delivery	5	19
30579	2020-02-12 12:53:17	2020-02-12	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	704	pick-up	0	22
30580	2020-02-12 12:55:29	2020-02-12	12	[{"id_menu":3,"count":1}]	6790	delivery	5	17
30581	2020-02-12 12:58:15	2020-02-12	12	[{"id_menu":3,"count":1}]	12047	delivery	5	17
30582	2020-02-12 13:09:22	2020-02-12	8	[{"id_menu":5,"count":1}]	10516	delivery	5	13
30583	2020-02-12 13:09:58	2020-02-12	9	[{"id_menu":6,"count":1}]	5306	pick-up	0	9
30584	2020-02-12 13:13:55	2020-02-12	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12068	delivery	5	55
30585	2020-02-12 13:25:56	2020-02-12	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":2}]	6429	delivery	5	22
30586	2020-02-12 13:27:04	2020-02-12	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	925	pick-up	0	25
30587	2020-02-12 13:31:55	2020-02-12	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	11151	delivery	5	25
30588	2020-02-12 13:38:20	2020-02-12	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	12009	delivery	5	39
30589	2020-02-12 13:39:07	2020-02-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	9175	delivery	5	22
30590	2020-02-12 13:44:17	2020-02-12	17	[{"id_menu":4,"count":1}]	8542	delivery	5	22
30591	2020-02-12 13:48:04	2020-02-12	14	[{"id_menu":2,"count":1}]	12085	delivery	5	19
30592	2020-02-12 13:48:11	2020-02-12	9	[{"id_menu":6,"count":1}]	1979	pick-up	0	9
30593	2020-02-12 13:49:25	2020-02-12	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	12092	delivery	5	26
30594	2020-02-12 13:55:52	2020-02-12	8	[{"id_menu":5,"count":1}]	7465	delivery	5	13
30595	2020-02-12 13:57:02	2020-02-12	9	[{"id_menu":7,"count":2}]	4417	delivery	5	14
30596	2020-02-12 13:57:03	2020-02-12	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12034	delivery	5	34
30597	2020-02-12 13:58:59	2020-02-12	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9743	delivery	5	34
30598	2020-02-12 13:59:03	2020-02-12	12	[{"id_menu":1,"count":1}]	2523	pick-up	0	12
30599	2020-02-12 14:13:45	2020-02-12	17	[{"id_menu":4,"count":1}]	7428	delivery	5	22
30600	2020-02-12 14:18:33	2020-02-12	12	[{"id_menu":3,"count":1}]	9534	delivery	5	17
30601	2020-02-12 14:23:34	2020-02-12	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6444	delivery	5	22
30602	2020-02-12 14:44:00	2020-02-12	9	[{"id_menu":7,"count":1}]	12052	delivery	5	14
30603	2020-02-12 14:45:16	2020-02-12	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3030	delivery	5	37
30604	2020-02-12 14:52:00	2020-02-12	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1963	delivery	5	36
30605	2020-02-12 14:52:36	2020-02-12	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12036	delivery	5	35
30606	2020-02-12 15:13:47	2020-02-12	14	[{"id_menu":2,"count":1}]	12012	pick-up	0	14
30607	2020-02-12 15:14:44	2020-02-12	12	[{"id_menu":3,"count":1}]	6533	pick-up	0	12
30608	2020-02-12 15:22:13	2020-02-12	17	[{"id_menu":4,"count":1}]	7048	delivery	5	22
30609	2020-02-12 15:28:08	2020-02-12	9	[{"id_menu":7,"count":1}]	6965	pick-up	0	9
30610	2020-02-12 15:38:18	2020-02-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4898	delivery	5	23
30611	2020-02-12 15:52:30	2020-02-12	12	[{"id_menu":1,"count":1}]	10243	delivery	5	17
30612	2020-02-12 16:04:33	2020-02-12	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":2}]	12086	delivery	5	26
30613	2020-02-12 16:06:16	2020-02-12	9	[{"id_menu":7,"count":1}]	3326	delivery	5	14
30614	2020-02-12 16:15:01	2020-02-12	9	[{"id_menu":6,"count":1}]	7745	pick-up	0	9
30615	2020-02-12 16:22:27	2020-02-12	9	[{"id_menu":6,"count":1}]	12021	delivery	5	14
30616	2020-02-12 16:24:48	2020-02-12	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2009	pick-up	0	35
30617	2020-02-12 16:28:40	2020-02-12	17	[{"id_menu":4,"count":1}]	10263	delivery	5	22
30618	2020-02-12 16:29:06	2020-02-12	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":2}]	3007	delivery	5	31
30619	2020-02-12 16:38:53	2020-02-12	9	[{"id_menu":7,"count":1}]	4508	delivery	5	14
30620	2020-02-12 16:39:19	2020-02-12	9	[{"id_menu":6,"count":1}]	2826	pick-up	0	9
30621	2020-02-12 16:54:06	2020-02-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	12004	delivery	5	31
30622	2020-02-12 17:05:00	2020-02-12	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	7371	delivery	5	34
30623	2020-02-12 17:06:28	2020-02-12	17	[{"id_menu":4,"count":1}]	7260	delivery	5	22
30624	2020-02-12 17:11:37	2020-02-12	8	[{"id_menu":5,"count":1}]	665	delivery	5	13
30625	2020-02-12 17:18:00	2020-02-12	12	[{"id_menu":3,"count":1}]	12028	pick-up	0	12
30626	2020-02-12 17:23:18	2020-02-12	14	[{"id_menu":2,"count":1}]	1528	pick-up	0	14
30627	2020-02-12 17:26:47	2020-02-12	17	[{"id_menu":4,"count":1}]	4595	pick-up	0	17
30628	2020-02-12 17:37:04	2020-02-12	9	[{"id_menu":7,"count":1}]	5394	delivery	5	14
30629	2020-02-12 17:39:32	2020-02-12	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1531	pick-up	0	21
30630	2020-02-12 17:41:10	2020-02-12	9	[{"id_menu":7,"count":1}]	1199	pick-up	0	9
30631	2020-02-12 17:48:03	2020-02-12	12	[{"id_menu":3,"count":1}]	3320	pick-up	0	12
30632	2020-02-12 18:10:37	2020-02-12	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	8229	pick-up	0	21
30633	2020-02-12 18:16:47	2020-02-12	17	[{"id_menu":4,"count":1}]	3069	pick-up	0	17
30634	2020-02-12 18:17:57	2020-02-12	9	[{"id_menu":6,"count":1}]	6201	delivery	5	14
30635	2020-02-12 18:18:05	2020-02-12	9	[{"id_menu":7,"count":1}]	12024	delivery	5	14
30636	2020-02-12 18:21:34	2020-02-12	12	[{"id_menu":1,"count":1}]	1445	pick-up	0	12
30637	2020-02-12 18:27:22	2020-02-12	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	5047	pick-up	0	26
30638	2020-02-12 18:52:16	2020-02-12	12	[{"id_menu":1,"count":1}]	1092	pick-up	0	12
30639	2020-02-12 18:54:02	2020-02-12	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	11185	delivery	5	23
30640	2020-02-12 18:57:26	2020-02-12	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	6032	delivery	5	31
30641	2020-02-12 19:00:10	2020-02-12	9	[{"id_menu":7,"count":1}]	8017	delivery	5	14
30642	2020-02-12 19:01:36	2020-02-12	8	[{"id_menu":5,"count":1}]	12060	delivery	5	13
30643	2020-02-12 19:10:57	2020-02-12	14	[{"id_menu":2,"count":1}]	2868	delivery	5	19
30644	2020-02-12 19:11:03	2020-02-12	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	12022	delivery	5	26
30645	2020-02-12 19:11:14	2020-02-12	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1170	pick-up	0	21
30646	2020-02-12 19:20:30	2020-02-12	12	[{"id_menu":1,"count":1}]	11614	delivery	5	17
30647	2020-02-12 19:27:05	2020-02-12	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11152	delivery	5	39
30648	2020-02-12 19:27:30	2020-02-12	12	[{"id_menu":3,"count":1}]	401	delivery	5	17
30649	2020-02-12 19:33:59	2020-02-12	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1762	delivery	5	52
30650	2020-02-12 19:34:47	2020-02-12	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6326	delivery	5	34
30651	2020-02-12 19:37:15	2020-02-12	12	[{"id_menu":3,"count":1}]	3926	delivery	5	17
30652	2020-02-12 19:39:14	2020-02-12	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	11607	delivery	5	27
30653	2020-02-12 19:40:53	2020-02-12	12	[{"id_menu":3,"count":1}]	10798	pick-up	0	12
30654	2020-02-12 19:42:25	2020-02-12	9	[{"id_menu":7,"count":1}]	10961	delivery	5	14
30655	2020-02-12 19:44:28	2020-02-12	14	[{"id_menu":2,"count":1}]	10907	delivery	5	19
30656	2020-02-12 19:56:51	2020-02-12	17	[{"id_menu":4,"count":1}]	147	pick-up	0	17
30657	2020-02-12 19:58:52	2020-02-12	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	12038	delivery	5	40
30658	2020-02-12 20:03:14	2020-02-12	12	[{"id_menu":3,"count":1}]	12023	delivery	5	17
30659	2020-02-12 20:13:54	2020-02-12	9	[{"id_menu":7,"count":1}]	2004	pick-up	0	9
30660	2020-02-12 20:16:43	2020-02-12	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	8347	pick-up	0	21
30661	2020-02-12 20:17:46	2020-02-12	8	[{"id_menu":5,"count":1}]	11869	delivery	5	13
30662	2020-02-12 20:39:43	2020-02-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2417	delivery	5	23
30663	2020-02-12 20:40:02	2020-02-12	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	4393	delivery	5	25
30664	2020-02-12 20:42:50	2020-02-12	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	12065	delivery	5	25
30665	2020-02-12 20:52:45	2020-02-12	9	[{"id_menu":6,"count":1}]	3909	pick-up	0	9
30666	2020-02-12 20:59:38	2020-02-12	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	6513	delivery	5	22
30667	2020-02-12 21:00:37	2020-02-12	9	[{"id_menu":7,"count":1}]	4841	pick-up	0	9
30668	2020-02-12 21:02:49	2020-02-12	17	[{"id_menu":4,"count":1}]	12043	pick-up	0	17
30669	2020-02-12 21:19:34	2020-02-12	14	[{"id_menu":2,"count":1}]	4451	pick-up	0	14
30670	2020-02-12 21:26:56	2020-02-12	14	[{"id_menu":2,"count":1}]	2838	pick-up	0	14
30671	2020-02-12 21:36:06	2020-02-12	8	[{"id_menu":5,"count":1}]	3201	pick-up	0	8
30672	2020-02-12 21:37:18	2020-02-12	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10219	delivery	5	22
30673	2020-02-12 21:39:09	2020-02-12	14	[{"id_menu":2,"count":1}]	669	delivery	5	19
30674	2020-02-12 21:42:59	2020-02-12	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	12082	delivery	5	30
30675	2020-02-12 21:48:12	2020-02-12	9	[{"id_menu":6,"count":1}]	12027	delivery	5	14
30676	2020-02-12 22:00:07	2020-02-12	9	[{"id_menu":6,"count":1}]	5982	delivery	5	14
30677	2020-02-12 22:10:16	2020-02-12	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	11941	delivery	5	44
30678	2020-02-12 22:10:54	2020-02-12	9	[{"id_menu":7,"count":1}]	12035	pick-up	0	9
30679	2020-02-12 22:11:41	2020-02-12	9	[{"id_menu":6,"count":1}]	12064	delivery	5	14
30680	2020-02-12 22:14:48	2020-02-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	11005	delivery	5	28
30681	2020-02-12 22:25:27	2020-02-12	9	[{"id_menu":7,"count":1}]	9201	delivery	5	14
30682	2020-02-12 22:40:02	2020-02-12	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	8877	delivery	5	26
30683	2020-02-12 22:44:29	2020-02-12	14	[{"id_menu":2,"count":1}]	8322	pick-up	0	14
30684	2020-02-12 22:45:35	2020-02-12	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7064	delivery	5	31
30685	2020-02-12 22:48:41	2020-02-12	17	[{"id_menu":4,"count":1}]	3971	pick-up	0	17
30686	2020-02-12 22:51:46	2020-02-12	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11810	delivery	5	39
30687	2020-02-12 22:58:34	2020-02-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6807	pick-up	0	23
30688	2020-02-12 22:59:55	2020-02-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11317	delivery	5	23
30689	2020-02-12 23:09:47	2020-02-12	9	[{"id_menu":6,"count":1}]	5503	pick-up	0	9
30690	2020-02-12 23:14:46	2020-02-12	8	[{"id_menu":5,"count":1}]	10200	pick-up	0	8
30691	2020-02-12 23:21:19	2020-02-12	12	[{"id_menu":1,"count":1}]	109	pick-up	0	12
30692	2020-02-12 23:22:16	2020-02-12	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7888	delivery	5	40
30693	2020-02-12 23:26:29	2020-02-12	8	[{"id_menu":5,"count":1}]	12010	delivery	5	13
30694	2020-02-12 23:50:09	2020-02-12	8	[{"id_menu":5,"count":1}]	4286	delivery	5	13
30695	2020-02-13 00:00:40	2020-02-13	9	[{"id_menu":7,"count":1}]	10796	delivery	5	14
30696	2020-02-13 00:06:34	2020-02-13	12	[{"id_menu":1,"count":1}]	236	pick-up	0	12
30697	2020-02-13 00:10:00	2020-02-13	9	[{"id_menu":7,"count":1}]	2870	pick-up	0	9
30698	2020-02-13 00:11:55	2020-02-13	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	12201	delivery	5	35
30699	2020-02-13 00:16:25	2020-02-13	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	7158	delivery	5	25
30700	2020-02-13 00:46:50	2020-02-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	12107	delivery	5	36
30701	2020-02-13 00:58:22	2020-02-13	9	[{"id_menu":7,"count":1}]	12118	pick-up	0	9
30702	2020-02-13 01:03:20	2020-02-13	9	[{"id_menu":7,"count":1}]	12110	pick-up	0	9
30703	2020-02-13 01:05:46	2020-02-13	9	[{"id_menu":6,"count":3}]	12194	delivery	5	14
30704	2020-02-13 01:18:09	2020-02-13	14	[{"id_menu":2,"count":1}]	5526	pick-up	0	14
30705	2020-02-13 01:27:18	2020-02-13	9	[{"id_menu":6,"count":2}]	1241	pick-up	0	9
30706	2020-02-13 01:31:53	2020-02-13	17	[{"id_menu":4,"count":1}]	8712	pick-up	0	17
30707	2020-02-13 01:32:27	2020-02-13	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	11095	delivery	5	30
30708	2020-02-13 01:33:47	2020-02-13	9	[{"id_menu":7,"count":2}]	9334	delivery	5	14
30709	2020-02-13 01:34:01	2020-02-13	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3106	delivery	5	42
30710	2020-02-13 01:36:12	2020-02-13	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12114	delivery	5	35
30711	2020-02-13 01:36:15	2020-02-13	9	[{"id_menu":7,"count":1}]	1411	pick-up	0	9
30712	2020-02-13 01:41:18	2020-02-13	17	[{"id_menu":4,"count":2}]	4459	delivery	5	22
30713	2020-02-13 01:44:50	2020-02-13	14	[{"id_menu":2,"count":1}]	10602	delivery	5	19
30714	2020-02-13 01:45:42	2020-02-13	17	[{"id_menu":4,"count":1}]	2347	pick-up	0	17
30715	2020-02-13 02:02:55	2020-02-13	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12143	delivery	5	39
30716	2020-02-13 02:08:18	2020-02-13	14	[{"id_menu":2,"count":1}]	12150	delivery	5	19
30717	2020-02-13 02:12:58	2020-02-13	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	12204	delivery	5	31
30718	2020-02-13 02:31:38	2020-02-13	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12192	delivery	5	36
30719	2020-02-13 02:45:37	2020-02-13	12	[{"id_menu":1,"count":1}]	9269	pick-up	0	12
30720	2020-02-13 02:53:04	2020-02-13	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7951	delivery	5	57
30721	2020-02-13 02:55:22	2020-02-13	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12156	delivery	5	31
30722	2020-02-13 02:55:47	2020-02-13	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	11431	delivery	5	42
30723	2020-02-13 02:56:11	2020-02-13	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12149	delivery	5	31
30724	2020-02-13 02:56:52	2020-02-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12136	delivery	5	23
30725	2020-02-13 03:04:35	2020-02-13	17	[{"id_menu":4,"count":1}]	12177	pick-up	0	17
30726	2020-02-13 03:13:27	2020-02-13	14	[{"id_menu":2,"count":1}]	1850	pick-up	0	14
30727	2020-02-13 03:21:26	2020-02-13	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	12101	delivery	5	39
30728	2020-02-13 03:28:39	2020-02-13	9	[{"id_menu":7,"count":1}]	12108	delivery	5	14
30729	2020-02-13 03:29:07	2020-02-13	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	12103	delivery	5	31
30730	2020-02-13 03:30:35	2020-02-13	8	[{"id_menu":5,"count":1}]	6535	pick-up	0	8
30731	2020-02-13 03:32:48	2020-02-13	14	[{"id_menu":2,"count":1}]	207	pick-up	0	14
30732	2020-02-13 03:34:53	2020-02-13	14	[{"id_menu":2,"count":1}]	2497	pick-up	0	14
30733	2020-02-13 03:39:08	2020-02-13	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	5310	pick-up	0	21
30734	2020-02-13 03:40:54	2020-02-13	9	[{"id_menu":6,"count":1}]	5338	pick-up	0	9
30735	2020-02-13 03:51:57	2020-02-13	12	[{"id_menu":1,"count":1}]	12137	pick-up	0	12
30736	2020-02-13 03:58:14	2020-02-13	14	[{"id_menu":2,"count":1}]	5110	delivery	5	19
30737	2020-02-13 04:00:20	2020-02-13	17	[{"id_menu":4,"count":1}]	12100	delivery	5	22
30738	2020-02-13 04:19:43	2020-02-13	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6429	delivery	5	43
30739	2020-02-13 04:20:05	2020-02-13	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	12203	delivery	5	28
30740	2020-02-13 04:22:26	2020-02-13	12	[{"id_menu":3,"count":1}]	12183	pick-up	0	12
30741	2020-02-13 04:25:22	2020-02-13	17	[{"id_menu":4,"count":1}]	8943	delivery	5	22
30742	2020-02-13 04:27:43	2020-02-13	8	[{"id_menu":5,"count":1}]	12207	delivery	5	13
30743	2020-02-13 04:32:46	2020-02-13	14	[{"id_menu":2,"count":1}]	8100	delivery	5	19
30744	2020-02-13 04:33:37	2020-02-13	9	[{"id_menu":6,"count":1}]	5917	delivery	5	14
30745	2020-02-13 04:37:19	2020-02-13	17	[{"id_menu":4,"count":1}]	7486	delivery	5	22
30746	2020-02-13 04:39:31	2020-02-13	17	[{"id_menu":4,"count":1}]	12157	delivery	5	22
30747	2020-02-13 04:45:38	2020-02-13	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	12173	pick-up	0	21
30748	2020-02-13 04:46:19	2020-02-13	9	[{"id_menu":6,"count":1}]	12129	pick-up	0	9
30749	2020-02-13 04:46:43	2020-02-13	9	[{"id_menu":7,"count":1}]	12169	delivery	5	14
30750	2020-02-13 04:49:41	2020-02-13	12	[{"id_menu":1,"count":1}]	6247	pick-up	0	12
30751	2020-02-13 04:55:25	2020-02-13	8	[{"id_menu":5,"count":1}]	81	delivery	5	13
30752	2020-02-13 04:55:36	2020-02-13	9	[{"id_menu":6,"count":1}]	12212	delivery	5	14
30753	2020-02-13 04:57:01	2020-02-13	8	[{"id_menu":5,"count":1}]	4634	pick-up	0	8
30754	2020-02-13 04:57:09	2020-02-13	9	[{"id_menu":7,"count":1}]	10101	delivery	5	14
30755	2020-02-13 04:58:44	2020-02-13	17	[{"id_menu":4,"count":1}]	271	pick-up	0	17
30756	2020-02-13 05:09:42	2020-02-13	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	5518	delivery	5	30
30757	2020-02-13 05:15:20	2020-02-13	12	[{"id_menu":3,"count":1}]	134	pick-up	0	12
30758	2020-02-13 05:25:01	2020-02-13	9	[{"id_menu":6,"count":1}]	12190	delivery	5	14
30759	2020-02-13 05:37:21	2020-02-13	9	[{"id_menu":6,"count":1}]	9093	pick-up	0	9
30760	2020-02-13 05:48:01	2020-02-13	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12209	delivery	5	22
30761	2020-02-13 05:48:04	2020-02-13	17	[{"id_menu":4,"count":1}]	12200	delivery	5	22
30762	2020-02-13 05:49:35	2020-02-13	12	[{"id_menu":1,"count":1}]	12185	delivery	5	17
30763	2020-02-13 05:50:27	2020-02-13	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12174	delivery	5	39
30764	2020-02-13 05:54:56	2020-02-13	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3202	delivery	5	30
30765	2020-02-13 06:03:47	2020-02-13	8	[{"id_menu":5,"count":1}]	12198	delivery	5	13
30766	2020-02-13 06:18:48	2020-02-13	17	[{"id_menu":4,"count":1}]	1209	delivery	5	22
30767	2020-02-13 06:19:11	2020-02-13	9	[{"id_menu":7,"count":1}]	12099	pick-up	0	9
30768	2020-02-13 06:19:30	2020-02-13	9	[{"id_menu":6,"count":1}]	4984	pick-up	0	9
30769	2020-02-13 06:25:08	2020-02-13	14	[{"id_menu":2,"count":1}]	5183	delivery	5	19
30770	2020-02-13 06:27:13	2020-02-13	14	[{"id_menu":2,"count":1}]	7019	pick-up	0	14
30771	2020-02-13 06:27:33	2020-02-13	9	[{"id_menu":7,"count":1}]	7253	delivery	5	14
30772	2020-02-13 06:36:05	2020-02-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12164	delivery	5	23
30773	2020-02-13 06:48:50	2020-02-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	7204	delivery	5	23
30774	2020-02-13 07:27:28	2020-02-13	14	[{"id_menu":2,"count":1}]	12196	delivery	5	19
30775	2020-02-13 07:28:50	2020-02-13	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	6729	delivery	5	25
30776	2020-02-13 07:34:07	2020-02-13	17	[{"id_menu":4,"count":1}]	3190	pick-up	0	17
30777	2020-02-13 07:34:19	2020-02-13	8	[{"id_menu":5,"count":1}]	12148	delivery	5	13
30778	2020-02-13 07:40:52	2020-02-13	12	[{"id_menu":1,"count":1}]	12111	delivery	5	17
30779	2020-02-13 07:45:37	2020-02-13	14	[{"id_menu":2,"count":1}]	10480	delivery	5	19
30780	2020-02-13 07:51:25	2020-02-13	17	[{"id_menu":4,"count":1}]	8207	delivery	5	22
30781	2020-02-13 07:53:50	2020-02-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2384	pick-up	0	31
30782	2020-02-13 07:58:21	2020-02-13	8	[{"id_menu":5,"count":1}]	12178	delivery	5	13
30783	2020-02-13 08:02:41	2020-02-13	17	[{"id_menu":4,"count":1}]	12144	pick-up	0	17
30784	2020-02-13 08:03:10	2020-02-13	12	[{"id_menu":1,"count":1}]	4104	delivery	5	17
30785	2020-02-13 08:03:32	2020-02-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	12124	pick-up	0	31
30786	2020-02-13 08:06:50	2020-02-13	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8051	delivery	5	57
30787	2020-02-13 08:13:38	2020-02-13	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	12140	delivery	5	45
30788	2020-02-13 08:14:04	2020-02-13	9	[{"id_menu":7,"count":1}]	1760	pick-up	0	9
30789	2020-02-13 08:29:14	2020-02-13	12	[{"id_menu":1,"count":1}]	12151	delivery	5	17
30790	2020-02-13 08:31:16	2020-02-13	9	[{"id_menu":7,"count":1}]	7654	delivery	5	14
30791	2020-02-13 08:34:07	2020-02-13	12	[{"id_menu":3,"count":1}]	7527	pick-up	0	12
30792	2020-02-13 08:35:33	2020-02-13	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	3689	delivery	5	26
30793	2020-02-13 08:37:06	2020-02-13	9	[{"id_menu":7,"count":1}]	12130	delivery	5	14
30794	2020-02-13 08:37:22	2020-02-13	9	[{"id_menu":6,"count":2}]	9644	pick-up	0	9
30795	2020-02-13 08:41:35	2020-02-13	9	[{"id_menu":7,"count":1}]	9385	delivery	5	14
30796	2020-02-13 08:43:03	2020-02-13	12	[{"id_menu":1,"count":1}]	5286	delivery	5	17
30797	2020-02-13 08:43:23	2020-02-13	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6873	delivery	5	22
30798	2020-02-13 08:51:23	2020-02-13	9	[{"id_menu":7,"count":2}]	1198	delivery	5	14
30799	2020-02-13 08:52:50	2020-02-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	491	pick-up	0	18
30800	2020-02-13 08:52:59	2020-02-13	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	8045	delivery	5	26
30801	2020-02-13 08:55:31	2020-02-13	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	5257	pick-up	0	26
30802	2020-02-13 09:01:05	2020-02-13	8	[{"id_menu":5,"count":1}]	12181	delivery	5	13
30803	2020-02-13 09:01:08	2020-02-13	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	12123	delivery	5	25
30804	2020-02-13 09:06:05	2020-02-13	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3660	pick-up	0	30
30805	2020-02-13 09:16:48	2020-02-13	9	[{"id_menu":7,"count":1}]	1563	pick-up	0	9
30806	2020-02-13 09:21:58	2020-02-13	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	4342	pick-up	0	21
30807	2020-02-13 09:28:51	2020-02-13	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	5147	delivery	5	23
30808	2020-02-13 09:34:21	2020-02-13	30	[{"id_menu":1,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7049	delivery	5	35
30809	2020-02-13 09:46:38	2020-02-13	9	[{"id_menu":6,"count":1}]	8589	delivery	5	14
30810	2020-02-13 09:53:17	2020-02-13	12	[{"id_menu":3,"count":1}]	213	delivery	5	17
30811	2020-02-13 09:53:58	2020-02-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	7362	delivery	5	36
30812	2020-02-13 09:58:14	2020-02-13	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	5474	pick-up	0	26
30813	2020-02-13 10:04:33	2020-02-13	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	12105	delivery	5	26
30814	2020-02-13 10:11:54	2020-02-13	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	12132	delivery	5	26
30815	2020-02-13 10:13:58	2020-02-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	10697	pick-up	0	23
30816	2020-02-13 10:20:06	2020-02-13	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8588	delivery	5	31
30817	2020-02-13 10:20:10	2020-02-13	9	[{"id_menu":7,"count":2}]	2902	pick-up	0	9
30818	2020-02-13 10:20:42	2020-02-13	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12210	pick-up	0	26
30819	2020-02-13 10:22:01	2020-02-13	9	[{"id_menu":6,"count":1}]	4073	delivery	5	14
30820	2020-02-13 10:26:25	2020-02-13	14	[{"id_menu":2,"count":1}]	10560	delivery	5	19
30821	2020-02-13 10:33:33	2020-02-13	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	357	delivery	5	27
30822	2020-02-13 10:33:43	2020-02-13	9	[{"id_menu":7,"count":1}]	4100	delivery	5	14
30823	2020-02-13 10:38:46	2020-02-13	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12202	delivery	5	22
30824	2020-02-13 10:41:47	2020-02-13	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8730	pick-up	0	26
30825	2020-02-13 11:01:01	2020-02-13	9	[{"id_menu":6,"count":1}]	8884	delivery	5	14
30826	2020-02-13 11:05:52	2020-02-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12211	delivery	5	23
30827	2020-02-13 11:12:03	2020-02-13	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6869	pick-up	0	26
30828	2020-02-13 11:17:17	2020-02-13	9	[{"id_menu":7,"count":1}]	12135	delivery	5	14
30829	2020-02-13 11:18:58	2020-02-13	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	691	pick-up	0	23
30830	2020-02-13 11:22:13	2020-02-13	17	[{"id_menu":4,"count":1}]	12163	delivery	5	22
30831	2020-02-13 11:23:07	2020-02-13	9	[{"id_menu":6,"count":1}]	5930	delivery	5	14
30832	2020-02-13 11:26:36	2020-02-13	17	[{"id_menu":4,"count":1}]	12159	delivery	5	22
30833	2020-02-13 11:39:15	2020-02-13	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	2492	pick-up	0	26
30834	2020-02-13 11:42:45	2020-02-13	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8043	delivery	5	37
30835	2020-02-13 11:50:24	2020-02-13	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	12171	delivery	5	23
30836	2020-02-13 11:52:04	2020-02-13	9	[{"id_menu":7,"count":1}]	1557	pick-up	0	9
30837	2020-02-13 11:55:31	2020-02-13	9	[{"id_menu":7,"count":1}]	482	delivery	5	14
30838	2020-02-13 12:12:53	2020-02-13	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	9733	delivery	5	37
30839	2020-02-13 12:15:27	2020-02-13	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	12141	delivery	5	26
30840	2020-02-13 12:15:29	2020-02-13	9	[{"id_menu":6,"count":1}]	266	pick-up	0	9
30841	2020-02-13 12:19:45	2020-02-13	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1573	pick-up	0	43
30842	2020-02-13 12:20:40	2020-02-13	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	10272	delivery	5	26
30843	2020-02-13 12:20:48	2020-02-13	17	[{"id_menu":4,"count":1}]	779	delivery	5	22
30844	2020-02-13 12:29:39	2020-02-13	12	[{"id_menu":3,"count":1}]	6842	delivery	5	17
30845	2020-02-13 12:31:31	2020-02-13	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	6668	delivery	5	48
30846	2020-02-13 12:41:05	2020-02-13	9	[{"id_menu":6,"count":1}]	12097	delivery	5	14
30847	2020-02-13 12:41:58	2020-02-13	17	[{"id_menu":4,"count":1}]	3227	delivery	5	22
30848	2020-02-13 12:55:08	2020-02-13	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3885	delivery	5	39
30849	2020-02-13 12:57:08	2020-02-13	8	[{"id_menu":5,"count":1}]	8081	delivery	5	13
30850	2020-02-13 13:36:33	2020-02-13	14	[{"id_menu":2,"count":1}]	2232	delivery	5	19
30851	2020-02-13 13:39:14	2020-02-13	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2228	delivery	5	31
30852	2020-02-13 13:40:05	2020-02-13	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1088	pick-up	0	33
30853	2020-02-13 13:40:17	2020-02-13	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1255	pick-up	0	17
30854	2020-02-13 13:53:07	2020-02-13	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	12168	delivery	5	29
30855	2020-02-13 13:55:05	2020-02-13	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4867	pick-up	0	23
30856	2020-02-13 13:56:56	2020-02-13	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12160	delivery	5	22
30857	2020-02-13 14:09:23	2020-02-13	17	[{"id_menu":4,"count":1}]	2937	pick-up	0	17
30858	2020-02-13 14:18:33	2020-02-13	14	[{"id_menu":2,"count":1}]	12189	pick-up	0	14
30859	2020-02-13 14:31:10	2020-02-13	9	[{"id_menu":7,"count":1}]	7261	delivery	5	14
30860	2020-02-13 14:31:18	2020-02-13	9	[{"id_menu":7,"count":1}]	2916	pick-up	0	9
30861	2020-02-13 14:34:14	2020-02-13	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	739	delivery	5	25
30862	2020-02-13 14:49:26	2020-02-13	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12193	delivery	5	35
30863	2020-02-13 14:55:51	2020-02-13	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12176	delivery	5	53
30864	2020-02-13 15:04:22	2020-02-13	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1026	pick-up	0	20
30865	2020-02-13 15:04:40	2020-02-13	9	[{"id_menu":6,"count":1}]	5700	delivery	5	14
30866	2020-02-13 15:06:40	2020-02-13	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	11229	delivery	5	36
30867	2020-02-13 15:10:54	2020-02-13	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	12152	delivery	5	26
30868	2020-02-13 15:13:54	2020-02-13	9	[{"id_menu":6,"count":1}]	7448	delivery	5	14
30869	2020-02-13 15:13:58	2020-02-13	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	12180	delivery	5	39
30870	2020-02-13 15:17:18	2020-02-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5719	delivery	5	28
30871	2020-02-13 15:17:59	2020-02-13	9	[{"id_menu":6,"count":1}]	12158	delivery	5	14
30872	2020-02-13 15:25:03	2020-02-13	14	[{"id_menu":2,"count":1}]	722	delivery	5	19
30873	2020-02-13 15:55:40	2020-02-13	8	[{"id_menu":5,"count":1}]	12184	pick-up	0	8
30874	2020-02-13 15:58:41	2020-02-13	9	[{"id_menu":6,"count":1}]	12175	delivery	5	14
30875	2020-02-13 15:59:17	2020-02-13	12	[{"id_menu":3,"count":1}]	11717	delivery	5	17
30876	2020-02-13 16:08:00	2020-02-13	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1316	delivery	5	27
30877	2020-02-13 16:22:35	2020-02-13	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	12161	delivery	5	26
30878	2020-02-13 16:47:24	2020-02-13	8	[{"id_menu":5,"count":1}]	9017	pick-up	0	8
30879	2020-02-13 16:50:28	2020-02-13	17	[{"id_menu":4,"count":1}]	9688	delivery	5	22
30880	2020-02-13 16:53:21	2020-02-13	9	[{"id_menu":7,"count":1}]	12120	delivery	5	14
30881	2020-02-13 16:53:46	2020-02-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3314	pick-up	0	31
30882	2020-02-13 16:54:53	2020-02-13	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12116	delivery	5	57
30883	2020-02-13 16:56:24	2020-02-13	12	[{"id_menu":3,"count":1}]	37	delivery	5	17
30884	2020-02-13 16:56:46	2020-02-13	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12138	delivery	5	43
30885	2020-02-13 16:59:46	2020-02-13	9	[{"id_menu":6,"count":1}]	2072	pick-up	0	9
30886	2020-02-13 17:02:26	2020-02-13	8	[{"id_menu":5,"count":1}]	4582	delivery	5	13
30887	2020-02-13 17:04:25	2020-02-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12121	delivery	5	23
30888	2020-02-13 17:09:32	2020-02-13	9	[{"id_menu":6,"count":1}]	11721	delivery	5	14
30889	2020-02-13 17:15:14	2020-02-13	8	[{"id_menu":5,"count":3}]	3007	delivery	5	13
30890	2020-02-13 17:17:51	2020-02-13	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	10210	delivery	5	22
30891	2020-02-13 17:27:32	2020-02-13	14	[{"id_menu":2,"count":2}]	2713	pick-up	0	14
30892	2020-02-13 17:33:26	2020-02-13	12	[{"id_menu":1,"count":1}]	1787	pick-up	0	12
30893	2020-02-13 17:37:20	2020-02-13	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	8738	delivery	5	40
30894	2020-02-13 17:42:46	2020-02-13	14	[{"id_menu":2,"count":1}]	10875	pick-up	0	14
30895	2020-02-13 17:42:56	2020-02-13	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	1429	pick-up	0	30
30896	2020-02-13 17:51:48	2020-02-13	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	12127	delivery	5	28
30897	2020-02-13 17:57:54	2020-02-13	14	[{"id_menu":2,"count":1}]	2620	delivery	5	19
30898	2020-02-13 18:02:29	2020-02-13	12	[{"id_menu":1,"count":1}]	1835	pick-up	0	12
30899	2020-02-13 18:05:41	2020-02-13	8	[{"id_menu":5,"count":1}]	1258	pick-up	0	8
30900	2020-02-13 18:09:34	2020-02-13	8	[{"id_menu":5,"count":1}]	12182	delivery	5	13
30901	2020-02-13 18:11:51	2020-02-13	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12142	delivery	5	31
30902	2020-02-13 18:14:05	2020-02-13	9	[{"id_menu":6,"count":1}]	12195	pick-up	0	9
30903	2020-02-13 18:14:14	2020-02-13	9	[{"id_menu":7,"count":1}]	12170	delivery	5	14
30904	2020-02-13 18:17:59	2020-02-13	8	[{"id_menu":5,"count":1}]	12109	delivery	5	13
30905	2020-02-13 18:21:30	2020-02-13	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	5329	delivery	5	26
30906	2020-02-13 18:26:36	2020-02-13	14	[{"id_menu":2,"count":1}]	1885	pick-up	0	14
30907	2020-02-13 18:28:30	2020-02-13	17	[{"id_menu":4,"count":1}]	2444	delivery	5	22
30908	2020-02-13 18:29:31	2020-02-13	9	[{"id_menu":7,"count":1}]	2661	delivery	5	14
30909	2020-02-13 18:32:46	2020-02-13	14	[{"id_menu":2,"count":2}]	12165	delivery	5	19
30910	2020-02-13 18:41:50	2020-02-13	12	[{"id_menu":1,"count":1}]	3708	delivery	5	17
30911	2020-02-13 18:48:17	2020-02-13	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	12206	delivery	5	44
30912	2020-02-13 18:49:00	2020-02-13	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12098	delivery	5	22
30913	2020-02-13 18:56:47	2020-02-13	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12186	delivery	5	35
30914	2020-02-13 18:57:17	2020-02-13	9	[{"id_menu":7,"count":1}]	7476	delivery	5	14
30915	2020-02-13 18:59:11	2020-02-13	9	[{"id_menu":6,"count":1}]	12155	delivery	5	14
30916	2020-02-13 19:00:03	2020-02-13	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	12179	delivery	5	26
30917	2020-02-13 19:03:11	2020-02-13	8	[{"id_menu":5,"count":1}]	12115	delivery	5	13
30918	2020-02-13 19:03:13	2020-02-13	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11878	delivery	5	31
30919	2020-02-13 19:04:43	2020-02-13	17	[{"id_menu":4,"count":1}]	5194	pick-up	0	17
30920	2020-02-13 19:06:10	2020-02-13	9	[{"id_menu":6,"count":3}]	12146	delivery	5	14
30921	2020-02-13 19:15:50	2020-02-13	9	[{"id_menu":7,"count":2}]	12134	delivery	5	14
30922	2020-02-13 19:16:39	2020-02-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12191	delivery	5	23
30923	2020-02-13 19:38:43	2020-02-13	9	[{"id_menu":6,"count":1}]	9569	delivery	5	14
30924	2020-02-13 19:55:56	2020-02-13	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6591	pick-up	0	31
30925	2020-02-13 20:03:07	2020-02-13	14	[{"id_menu":2,"count":1}]	7572	pick-up	0	14
30926	2020-02-13 20:09:49	2020-02-13	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	12112	delivery	5	26
30927	2020-02-13 20:14:06	2020-02-13	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10679	pick-up	0	29
30928	2020-02-13 20:15:52	2020-02-13	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	12147	delivery	5	35
30929	2020-02-13 20:17:24	2020-02-13	12	[{"id_menu":1,"count":1}]	12166	pick-up	0	12
30930	2020-02-13 20:19:43	2020-02-13	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3473	delivery	5	45
30931	2020-02-13 20:22:11	2020-02-13	9	[{"id_menu":7,"count":1}]	8090	pick-up	0	9
30932	2020-02-13 20:25:21	2020-02-13	12	[{"id_menu":1,"count":1}]	12125	delivery	5	17
30933	2020-02-13 20:26:25	2020-02-13	9	[{"id_menu":7,"count":1}]	1025	delivery	5	14
30934	2020-02-13 20:26:34	2020-02-13	14	[{"id_menu":2,"count":2}]	12145	pick-up	0	14
30935	2020-02-13 20:30:29	2020-02-13	9	[{"id_menu":7,"count":1}]	228	pick-up	0	9
30936	2020-02-13 20:49:31	2020-02-13	12	[{"id_menu":1,"count":1}]	3168	pick-up	0	12
30937	2020-02-13 21:10:50	2020-02-13	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	396	pick-up	0	21
30938	2020-02-13 21:11:00	2020-02-13	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	12122	delivery	5	34
30939	2020-02-13 21:14:38	2020-02-13	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	12187	delivery	5	25
30940	2020-02-13 21:25:18	2020-02-13	12	[{"id_menu":3,"count":1}]	2301	pick-up	0	12
30941	2020-02-13 21:27:37	2020-02-13	12	[{"id_menu":1,"count":1}]	3940	pick-up	0	12
30942	2020-02-13 21:33:32	2020-02-13	9	[{"id_menu":7,"count":1}]	12188	delivery	5	14
30943	2020-02-13 21:39:09	2020-02-13	17	[{"id_menu":4,"count":1}]	3570	pick-up	0	17
30944	2020-02-13 21:45:28	2020-02-13	17	[{"id_menu":4,"count":1}]	3057	pick-up	0	17
30945	2020-02-13 21:47:44	2020-02-13	14	[{"id_menu":2,"count":1}]	1783	pick-up	0	14
30946	2020-02-13 21:52:13	2020-02-13	9	[{"id_menu":7,"count":1}]	8019	delivery	5	14
30947	2020-02-13 21:57:39	2020-02-13	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4818	delivery	5	40
30948	2020-02-13 22:13:24	2020-02-13	8	[{"id_menu":5,"count":1}]	3679	delivery	5	13
30949	2020-02-13 22:18:59	2020-02-13	9	[{"id_menu":6,"count":1}]	826	pick-up	0	9
30950	2020-02-13 22:47:35	2020-02-13	9	[{"id_menu":6,"count":1}]	7407	pick-up	0	9
30951	2020-02-13 22:55:47	2020-02-13	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	4072	pick-up	0	21
30952	2020-02-13 22:59:14	2020-02-13	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3127	delivery	5	39
30953	2020-02-13 23:03:20	2020-02-13	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2568	delivery	5	30
30954	2020-02-13 23:04:23	2020-02-13	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	8342	delivery	5	26
30955	2020-02-13 23:07:16	2020-02-13	17	[{"id_menu":4,"count":1}]	8260	pick-up	0	17
30956	2020-02-13 23:13:23	2020-02-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	5857	delivery	5	36
30957	2020-02-13 23:14:38	2020-02-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12167	delivery	5	23
30958	2020-02-13 23:14:59	2020-02-13	9	[{"id_menu":7,"count":1}]	211	pick-up	0	9
30959	2020-02-13 23:15:28	2020-02-13	9	[{"id_menu":6,"count":1}]	1174	delivery	5	14
30960	2020-02-13 23:16:00	2020-02-13	17	[{"id_menu":4,"count":1}]	6866	delivery	5	22
30961	2020-02-13 23:22:19	2020-02-13	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	9902	delivery	5	28
30962	2020-02-13 23:24:33	2020-02-13	17	[{"id_menu":4,"count":1}]	4284	delivery	5	22
30963	2020-02-13 23:30:38	2020-02-13	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	12205	pick-up	0	26
30964	2020-02-13 23:34:29	2020-02-13	12	[{"id_menu":3,"count":1}]	383	delivery	5	17
30965	2020-02-13 23:34:31	2020-02-13	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	12197	delivery	5	35
30966	2020-02-13 23:35:16	2020-02-13	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11306	delivery	5	31
30967	2020-02-13 23:35:19	2020-02-13	17	[{"id_menu":4,"count":1}]	1106	pick-up	0	17
30968	2020-02-13 23:35:41	2020-02-13	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1813	pick-up	0	34
30969	2020-02-13 23:38:12	2020-02-13	12	[{"id_menu":3,"count":1}]	11812	delivery	5	17
30970	2020-02-13 23:39:32	2020-02-13	9	[{"id_menu":7,"count":3}]	11512	delivery	5	14
30971	2020-02-14 00:04:54	2020-02-14	9	[{"id_menu":7,"count":1}]	2320	delivery	5	14
30972	2020-02-14 00:25:08	2020-02-14	8	[{"id_menu":5,"count":1}]	464	delivery	5	13
30973	2020-02-14 00:34:33	2020-02-14	8	[{"id_menu":5,"count":1}]	12279	delivery	5	13
30974	2020-02-14 00:41:48	2020-02-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8708	delivery	5	22
30975	2020-02-14 00:46:57	2020-02-14	14	[{"id_menu":2,"count":1}]	12284	delivery	5	19
30976	2020-02-14 00:57:07	2020-02-14	9	[{"id_menu":6,"count":1}]	4708	delivery	5	14
30977	2020-02-14 00:57:46	2020-02-14	14	[{"id_menu":2,"count":1}]	4470	pick-up	0	14
30978	2020-02-14 01:07:59	2020-02-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2447	delivery	5	36
30979	2020-02-14 01:08:11	2020-02-14	12	[{"id_menu":1,"count":1}]	1588	delivery	5	17
30980	2020-02-14 01:11:09	2020-02-14	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1095	pick-up	0	21
30981	2020-02-14 01:12:47	2020-02-14	12	[{"id_menu":3,"count":1}]	1470	pick-up	0	12
30982	2020-02-14 01:17:21	2020-02-14	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	12313	delivery	5	28
30983	2020-02-14 01:22:29	2020-02-14	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	4100	delivery	5	39
30984	2020-02-14 01:30:42	2020-02-14	17	[{"id_menu":4,"count":1}]	1924	delivery	5	22
30985	2020-02-14 01:32:29	2020-02-14	17	[{"id_menu":4,"count":1}]	12242	delivery	5	22
30986	2020-02-14 01:33:30	2020-02-14	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12243	delivery	5	40
30987	2020-02-14 01:36:07	2020-02-14	8	[{"id_menu":5,"count":1}]	395	delivery	5	13
30988	2020-02-14 01:39:55	2020-02-14	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	11715	pick-up	0	21
30989	2020-02-14 01:40:28	2020-02-14	17	[{"id_menu":4,"count":1}]	2807	pick-up	0	17
30990	2020-02-14 01:49:17	2020-02-14	9	[{"id_menu":6,"count":1}]	12248	delivery	5	14
30991	2020-02-14 01:55:10	2020-02-14	9	[{"id_menu":7,"count":1}]	3065	delivery	5	14
30992	2020-02-14 02:08:56	2020-02-14	9	[{"id_menu":6,"count":1}]	6533	pick-up	0	9
30993	2020-02-14 02:15:32	2020-02-14	17	[{"id_menu":4,"count":1}]	5038	delivery	5	22
30994	2020-02-14 02:32:43	2020-02-14	9	[{"id_menu":6,"count":1}]	12222	delivery	5	14
30995	2020-02-14 02:51:17	2020-02-14	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	12299	delivery	5	28
30996	2020-02-14 02:53:05	2020-02-14	9	[{"id_menu":6,"count":1}]	5138	pick-up	0	9
30997	2020-02-14 03:01:47	2020-02-14	17	[{"id_menu":4,"count":1}]	7875	delivery	5	22
30998	2020-02-14 03:04:17	2020-02-14	9	[{"id_menu":7,"count":2}]	11450	delivery	5	14
30999	2020-02-14 03:09:39	2020-02-14	9	[{"id_menu":7,"count":1}]	5387	delivery	5	14
31000	2020-02-14 03:15:03	2020-02-14	9	[{"id_menu":6,"count":1}]	12215	delivery	5	14
31001	2020-02-14 03:17:08	2020-02-14	8	[{"id_menu":5,"count":1}]	10090	delivery	5	13
31002	2020-02-14 03:29:25	2020-02-14	9	[{"id_menu":7,"count":1}]	2217	pick-up	0	9
31003	2020-02-14 03:33:30	2020-02-14	9	[{"id_menu":6,"count":1}]	12255	delivery	5	14
31004	2020-02-14 03:36:40	2020-02-14	9	[{"id_menu":7,"count":1}]	11485	delivery	5	14
31005	2020-02-14 03:41:28	2020-02-14	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	12314	delivery	5	30
31006	2020-02-14 03:51:59	2020-02-14	12	[{"id_menu":3,"count":1}]	4008	delivery	5	17
31007	2020-02-14 03:59:48	2020-02-14	12	[{"id_menu":3,"count":1}]	11183	pick-up	0	12
31008	2020-02-14 04:09:16	2020-02-14	9	[{"id_menu":6,"count":1}]	12251	delivery	5	14
31009	2020-02-14 04:12:09	2020-02-14	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8101	delivery	5	40
31010	2020-02-14 04:20:21	2020-02-14	14	[{"id_menu":2,"count":1}]	8106	delivery	5	19
31011	2020-02-14 04:32:22	2020-02-14	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2176	pick-up	0	35
31012	2020-02-14 04:33:15	2020-02-14	14	[{"id_menu":2,"count":1}]	12276	delivery	5	19
31013	2020-02-14 04:35:56	2020-02-14	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	12258	pick-up	0	29
31014	2020-02-14 04:36:18	2020-02-14	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	6274	delivery	5	46
31015	2020-02-14 04:39:03	2020-02-14	17	[{"id_menu":4,"count":1}]	12240	pick-up	0	17
31016	2020-02-14 04:39:58	2020-02-14	9	[{"id_menu":7,"count":1}]	586	delivery	5	14
31017	2020-02-14 04:45:02	2020-02-14	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	2705	delivery	5	22
31018	2020-02-14 04:48:48	2020-02-14	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	7760	delivery	5	26
31019	2020-02-14 04:48:53	2020-02-14	8	[{"id_menu":5,"count":1}]	12224	delivery	5	13
31020	2020-02-14 04:54:20	2020-02-14	9	[{"id_menu":7,"count":1}]	7306	pick-up	0	9
31021	2020-02-14 05:10:49	2020-02-14	14	[{"id_menu":2,"count":1}]	7515	delivery	5	19
31022	2020-02-14 05:15:49	2020-02-14	14	[{"id_menu":2,"count":1}]	12316	delivery	5	19
31023	2020-02-14 05:21:14	2020-02-14	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	12281	pick-up	0	25
31024	2020-02-14 05:22:23	2020-02-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	12267	delivery	5	28
31025	2020-02-14 05:25:39	2020-02-14	9	[{"id_menu":6,"count":1}]	1979	pick-up	0	9
31026	2020-02-14 05:32:20	2020-02-14	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10052	delivery	5	43
31027	2020-02-14 05:34:21	2020-02-14	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12311	delivery	5	31
31028	2020-02-14 05:45:42	2020-02-14	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11710	delivery	5	40
31029	2020-02-14 05:51:44	2020-02-14	14	[{"id_menu":2,"count":1}]	3238	delivery	5	19
31030	2020-02-14 05:56:30	2020-02-14	9	[{"id_menu":7,"count":1}]	1065	pick-up	0	9
31031	2020-02-14 06:03:44	2020-02-14	12	[{"id_menu":1,"count":1}]	10935	delivery	5	17
31032	2020-02-14 06:16:48	2020-02-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1656	pick-up	0	31
31033	2020-02-14 06:23:11	2020-02-14	12	[{"id_menu":3,"count":1}]	10480	pick-up	0	12
31034	2020-02-14 06:27:08	2020-02-14	9	[{"id_menu":6,"count":1}]	1219	delivery	5	14
31035	2020-02-14 06:27:38	2020-02-14	9	[{"id_menu":6,"count":1}]	12236	delivery	5	14
31036	2020-02-14 06:27:53	2020-02-14	14	[{"id_menu":2,"count":1}]	4754	delivery	5	19
31037	2020-02-14 06:29:47	2020-02-14	12	[{"id_menu":3,"count":1}]	256	delivery	5	17
31038	2020-02-14 06:34:15	2020-02-14	9	[{"id_menu":7,"count":1}]	12256	delivery	5	14
31039	2020-02-14 06:43:57	2020-02-14	8	[{"id_menu":5,"count":1}]	7807	delivery	5	13
31040	2020-02-14 07:00:15	2020-02-14	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	12228	delivery	5	22
31041	2020-02-14 07:01:29	2020-02-14	9	[{"id_menu":7,"count":1}]	4714	pick-up	0	9
31042	2020-02-14 07:08:16	2020-02-14	9	[{"id_menu":7,"count":1}]	12246	delivery	5	14
31043	2020-02-14 07:16:19	2020-02-14	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	5649	delivery	5	29
31044	2020-02-14 07:28:31	2020-02-14	9	[{"id_menu":7,"count":1}]	3512	pick-up	0	9
31045	2020-02-14 07:34:36	2020-02-14	12	[{"id_menu":3,"count":1}]	543	delivery	5	17
31046	2020-02-14 07:36:27	2020-02-14	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12312	delivery	5	36
31047	2020-02-14 07:44:49	2020-02-14	12	[{"id_menu":3,"count":1}]	12301	delivery	5	17
31048	2020-02-14 07:46:31	2020-02-14	9	[{"id_menu":7,"count":2}]	3102	delivery	5	14
31049	2020-02-14 07:50:37	2020-02-14	17	[{"id_menu":4,"count":1}]	3900	pick-up	0	17
31050	2020-02-14 07:52:23	2020-02-14	8	[{"id_menu":5,"count":1}]	11961	delivery	5	13
31051	2020-02-14 07:53:09	2020-02-14	12	[{"id_menu":3,"count":1}]	12250	delivery	5	17
31052	2020-02-14 07:55:24	2020-02-14	9	[{"id_menu":7,"count":1}]	1851	delivery	5	14
31053	2020-02-14 07:55:34	2020-02-14	9	[{"id_menu":6,"count":1}]	299	pick-up	0	9
31054	2020-02-14 07:59:37	2020-02-14	9	[{"id_menu":7,"count":1}]	12226	delivery	5	14
31055	2020-02-14 08:05:38	2020-02-14	9	[{"id_menu":7,"count":1}]	7122	delivery	5	14
31056	2020-02-14 08:10:09	2020-02-14	9	[{"id_menu":7,"count":1}]	12221	delivery	5	14
31057	2020-02-14 08:10:44	2020-02-14	14	[{"id_menu":2,"count":1}]	4898	delivery	5	19
31058	2020-02-14 08:15:17	2020-02-14	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12223	delivery	5	49
31059	2020-02-14 08:15:24	2020-02-14	9	[{"id_menu":7,"count":1}]	12288	delivery	5	14
31060	2020-02-14 08:16:34	2020-02-14	14	[{"id_menu":2,"count":1}]	12237	delivery	5	19
31061	2020-02-14 08:17:17	2020-02-14	12	[{"id_menu":3,"count":1}]	12277	delivery	5	17
31062	2020-02-14 08:22:44	2020-02-14	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12244	delivery	5	31
31063	2020-02-14 08:37:34	2020-02-14	14	[{"id_menu":2,"count":1}]	12305	pick-up	0	14
31064	2020-02-14 08:41:44	2020-02-14	8	[{"id_menu":5,"count":1}]	12275	delivery	5	13
31065	2020-02-14 08:47:20	2020-02-14	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	9303	pick-up	0	24
31066	2020-02-14 08:48:09	2020-02-14	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	6273	delivery	5	28
31067	2020-02-14 08:53:28	2020-02-14	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12309	delivery	5	22
31068	2020-02-14 08:58:54	2020-02-14	17	[{"id_menu":4,"count":1}]	1342	pick-up	0	17
31069	2020-02-14 09:04:05	2020-02-14	17	[{"id_menu":4,"count":1}]	10425	delivery	5	22
31070	2020-02-14 09:05:55	2020-02-14	9	[{"id_menu":6,"count":1}]	3872	delivery	5	14
31071	2020-02-14 09:07:49	2020-02-14	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8988	delivery	5	36
31072	2020-02-14 09:10:40	2020-02-14	9	[{"id_menu":6,"count":1}]	552	delivery	5	14
31073	2020-02-14 09:11:36	2020-02-14	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8944	delivery	5	37
31074	2020-02-14 09:12:21	2020-02-14	14	[{"id_menu":2,"count":1}]	12307	pick-up	0	14
31075	2020-02-14 09:18:37	2020-02-14	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8311	delivery	5	43
31076	2020-02-14 09:27:04	2020-02-14	34	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	12216	pick-up	0	34
31077	2020-02-14 09:30:19	2020-02-14	14	[{"id_menu":2,"count":1}]	12265	delivery	5	19
31078	2020-02-14 09:33:22	2020-02-14	12	[{"id_menu":1,"count":1}]	8276	delivery	5	17
31079	2020-02-14 09:35:07	2020-02-14	9	[{"id_menu":7,"count":1}]	12233	delivery	5	14
31080	2020-02-14 09:39:22	2020-02-14	17	[{"id_menu":4,"count":1}]	6565	pick-up	0	17
31081	2020-02-14 09:47:28	2020-02-14	14	[{"id_menu":2,"count":1}]	2123	delivery	5	19
31082	2020-02-14 09:55:20	2020-02-14	14	[{"id_menu":2,"count":1}]	12310	pick-up	0	14
31083	2020-02-14 10:00:23	2020-02-14	14	[{"id_menu":2,"count":1}]	12268	pick-up	0	14
31084	2020-02-14 10:12:19	2020-02-14	9	[{"id_menu":7,"count":1}]	4235	pick-up	0	9
31085	2020-02-14 10:34:39	2020-02-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2700	delivery	5	28
31086	2020-02-14 10:49:19	2020-02-14	12	[{"id_menu":3,"count":1}]	2474	delivery	5	17
31087	2020-02-14 10:58:33	2020-02-14	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	6552	pick-up	0	26
31088	2020-02-14 11:06:16	2020-02-14	14	[{"id_menu":2,"count":1}]	584	delivery	5	19
31089	2020-02-14 11:15:28	2020-02-14	9	[{"id_menu":7,"count":1}]	11343	pick-up	0	9
31090	2020-02-14 11:17:04	2020-02-14	12	[{"id_menu":3,"count":1}]	11554	pick-up	0	12
31091	2020-02-14 11:18:29	2020-02-14	12	[{"id_menu":3,"count":1}]	721	delivery	5	17
31092	2020-02-14 11:20:51	2020-02-14	8	[{"id_menu":5,"count":1}]	9106	pick-up	0	8
31093	2020-02-14 11:27:39	2020-02-14	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	12278	delivery	5	31
31094	2020-02-14 11:29:39	2020-02-14	17	[{"id_menu":5,"count":3},{"id_menu":7,"count":1}]	4808	delivery	5	22
31095	2020-02-14 11:33:53	2020-02-14	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	12320	delivery	5	27
31096	2020-02-14 11:36:39	2020-02-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	12290	delivery	5	28
31097	2020-02-14 11:54:14	2020-02-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10946	delivery	5	22
31098	2020-02-14 12:02:53	2020-02-14	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	5099	delivery	5	34
31099	2020-02-14 12:22:07	2020-02-14	26	[{"id_menu":4,"count":3},{"id_menu":6,"count":1}]	3705	delivery	5	31
31100	2020-02-14 12:22:52	2020-02-14	14	[{"id_menu":2,"count":2}]	12274	pick-up	0	14
31101	2020-02-14 12:30:58	2020-02-14	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	12287	delivery	5	48
31102	2020-02-14 12:44:41	2020-02-14	17	[{"id_menu":4,"count":1}]	12296	pick-up	0	17
31103	2020-02-14 13:02:06	2020-02-14	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	12300	delivery	5	30
31104	2020-02-14 13:04:27	2020-02-14	12	[{"id_menu":1,"count":1}]	10452	delivery	5	17
31105	2020-02-14 13:12:15	2020-02-14	12	[{"id_menu":1,"count":1}]	9204	pick-up	0	12
31106	2020-02-14 13:13:44	2020-02-14	8	[{"id_menu":5,"count":1}]	12264	delivery	5	13
31107	2020-02-14 13:20:31	2020-02-14	12	[{"id_menu":3,"count":1}]	925	pick-up	0	12
31108	2020-02-14 13:20:34	2020-02-14	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	2965	delivery	5	23
31109	2020-02-14 13:21:10	2020-02-14	9	[{"id_menu":6,"count":1}]	1522	pick-up	0	9
31110	2020-02-14 13:24:52	2020-02-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	12234	delivery	5	36
31111	2020-02-14 13:24:58	2020-02-14	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	5091	delivery	5	26
31112	2020-02-14 13:30:29	2020-02-14	17	[{"id_menu":4,"count":1}]	12319	delivery	5	22
31113	2020-02-14 13:36:36	2020-02-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	12235	pick-up	0	23
31114	2020-02-14 13:37:56	2020-02-14	9	[{"id_menu":7,"count":1}]	12217	delivery	5	14
31115	2020-02-14 13:43:36	2020-02-14	12	[{"id_menu":3,"count":1}]	12239	delivery	5	17
31116	2020-02-14 14:00:06	2020-02-14	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	12241	delivery	5	23
31117	2020-02-14 14:04:57	2020-02-14	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12269	delivery	5	34
31118	2020-02-14 14:11:38	2020-02-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	10819	pick-up	0	31
31119	2020-02-14 14:17:27	2020-02-14	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11187	delivery	5	40
31120	2020-02-14 14:21:55	2020-02-14	9	[{"id_menu":7,"count":1}]	2317	delivery	5	14
31121	2020-02-14 14:24:01	2020-02-14	17	[{"id_menu":4,"count":1}]	12231	delivery	5	22
31122	2020-02-14 14:29:38	2020-02-14	9	[{"id_menu":6,"count":1}]	9624	delivery	5	14
31123	2020-02-14 14:43:42	2020-02-14	12	[{"id_menu":1,"count":1}]	5318	delivery	5	17
31124	2020-02-14 14:48:59	2020-02-14	8	[{"id_menu":5,"count":1}]	12225	delivery	5	13
31125	2020-02-14 14:51:36	2020-02-14	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	12297	delivery	5	30
31126	2020-02-14 14:56:06	2020-02-14	14	[{"id_menu":2,"count":1}]	4870	delivery	5	19
31127	2020-02-14 15:09:13	2020-02-14	9	[{"id_menu":6,"count":1}]	12318	delivery	5	14
31128	2020-02-14 15:15:31	2020-02-14	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12315	delivery	5	31
31129	2020-02-14 15:18:56	2020-02-14	8	[{"id_menu":5,"count":1}]	7623	delivery	5	13
31130	2020-02-14 15:26:59	2020-02-14	12	[{"id_menu":3,"count":2}]	12263	delivery	5	17
31131	2020-02-14 15:28:39	2020-02-14	9	[{"id_menu":6,"count":1}]	12220	delivery	5	14
31132	2020-02-14 15:33:07	2020-02-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4090	delivery	5	36
31133	2020-02-14 15:43:24	2020-02-14	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	12230	delivery	5	25
31134	2020-02-14 15:53:41	2020-02-14	8	[{"id_menu":5,"count":1}]	12238	delivery	5	13
31135	2020-02-14 16:00:09	2020-02-14	9	[{"id_menu":7,"count":1}]	5616	pick-up	0	9
31136	2020-02-14 16:04:09	2020-02-14	14	[{"id_menu":2,"count":1}]	11615	pick-up	0	14
31137	2020-02-14 16:05:15	2020-02-14	14	[{"id_menu":2,"count":1}]	7864	delivery	5	19
31138	2020-02-14 16:10:25	2020-02-14	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	12260	delivery	5	23
31139	2020-02-14 16:17:50	2020-02-14	9	[{"id_menu":6,"count":1}]	12219	delivery	5	14
31140	2020-02-14 16:26:58	2020-02-14	12	[{"id_menu":1,"count":1}]	4081	pick-up	0	12
31141	2020-02-14 16:28:03	2020-02-14	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	748	delivery	5	26
31142	2020-02-14 16:32:47	2020-02-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	9788	pick-up	0	31
31143	2020-02-14 16:37:55	2020-02-14	12	[{"id_menu":3,"count":1}]	12270	delivery	5	17
31144	2020-02-14 16:42:29	2020-02-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	313	pick-up	0	31
31145	2020-02-14 16:54:01	2020-02-14	9	[{"id_menu":7,"count":3}]	12067	delivery	5	14
31146	2020-02-14 16:58:12	2020-02-14	8	[{"id_menu":5,"count":1}]	12283	delivery	5	13
31147	2020-02-14 16:58:57	2020-02-14	8	[{"id_menu":5,"count":1}]	12254	pick-up	0	8
31148	2020-02-14 17:01:28	2020-02-14	9	[{"id_menu":6,"count":1}]	8553	delivery	5	14
31149	2020-02-14 17:05:19	2020-02-14	8	[{"id_menu":5,"count":1}]	12285	delivery	5	13
31150	2020-02-14 17:10:46	2020-02-14	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	12291	delivery	5	31
31151	2020-02-14 17:11:56	2020-02-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1359	pick-up	0	31
31152	2020-02-14 17:13:01	2020-02-14	12	[{"id_menu":3,"count":1}]	11191	pick-up	0	12
31153	2020-02-14 17:14:00	2020-02-14	12	[{"id_menu":3,"count":1}]	11393	delivery	5	17
31154	2020-02-14 17:15:58	2020-02-14	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5306	pick-up	0	31
31155	2020-02-14 17:18:16	2020-02-14	9	[{"id_menu":6,"count":1}]	12289	delivery	5	14
31156	2020-02-14 17:24:25	2020-02-14	12	[{"id_menu":1,"count":1}]	7678	delivery	5	17
31157	2020-02-14 17:43:06	2020-02-14	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12282	delivery	5	43
31158	2020-02-14 17:57:24	2020-02-14	12	[{"id_menu":3,"count":1}]	12253	pick-up	0	12
31159	2020-02-14 17:57:35	2020-02-14	12	[{"id_menu":1,"count":1}]	4607	pick-up	0	12
31160	2020-02-14 18:04:08	2020-02-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9920	pick-up	0	17
31161	2020-02-14 18:08:52	2020-02-14	14	[{"id_menu":2,"count":2}]	12227	delivery	5	19
31162	2020-02-14 18:20:29	2020-02-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4578	delivery	5	36
31163	2020-02-14 18:31:19	2020-02-14	8	[{"id_menu":5,"count":1}]	10694	pick-up	0	8
31164	2020-02-14 18:31:39	2020-02-14	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2415	delivery	5	27
31165	2020-02-14 18:42:20	2020-02-14	14	[{"id_menu":2,"count":1}]	5691	delivery	5	19
31166	2020-02-14 18:43:04	2020-02-14	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	12286	delivery	5	34
31167	2020-02-14 18:50:27	2020-02-14	9	[{"id_menu":6,"count":1}]	7891	pick-up	0	9
31168	2020-02-14 18:59:51	2020-02-14	14	[{"id_menu":2,"count":1}]	4685	pick-up	0	14
31169	2020-02-14 19:05:14	2020-02-14	8	[{"id_menu":5,"count":1}]	12262	delivery	5	13
31170	2020-02-14 19:07:50	2020-02-14	9	[{"id_menu":7,"count":1}]	6883	delivery	5	14
31171	2020-02-14 19:09:13	2020-02-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12257	pick-up	0	26
31172	2020-02-14 19:11:30	2020-02-14	17	[{"id_menu":4,"count":1}]	5741	delivery	5	22
31173	2020-02-14 19:12:08	2020-02-14	12	[{"id_menu":3,"count":1}]	2275	pick-up	0	12
31174	2020-02-14 19:13:38	2020-02-14	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	12229	delivery	5	28
31175	2020-02-14 19:13:39	2020-02-14	8	[{"id_menu":5,"count":1}]	3521	delivery	5	13
31176	2020-02-14 19:25:10	2020-02-14	14	[{"id_menu":2,"count":1}]	4986	delivery	5	19
31177	2020-02-14 19:27:48	2020-02-14	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	9467	pick-up	0	20
31178	2020-02-14 19:31:11	2020-02-14	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	11746	delivery	5	22
31179	2020-02-14 19:32:12	2020-02-14	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	5407	delivery	5	26
31180	2020-02-14 19:35:41	2020-02-14	9	[{"id_menu":6,"count":1}]	2951	delivery	5	14
31181	2020-02-14 19:35:50	2020-02-14	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1566	pick-up	0	20
31248	2020-02-15 02:07:04	2020-02-15	14	[{"id_menu":2,"count":1}]	3054	delivery	5	19
31182	2020-02-14 19:39:19	2020-02-14	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8075	delivery	5	52
31183	2020-02-14 19:42:41	2020-02-14	8	[{"id_menu":5,"count":1}]	3494	pick-up	0	8
31184	2020-02-14 20:09:11	2020-02-14	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	5650	pick-up	0	25
31185	2020-02-14 20:09:50	2020-02-14	9	[{"id_menu":6,"count":1}]	5736	pick-up	0	9
31186	2020-02-14 20:10:49	2020-02-14	8	[{"id_menu":5,"count":1}]	5337	delivery	5	13
31187	2020-02-14 20:15:29	2020-02-14	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12214	delivery	5	37
31188	2020-02-14 20:16:43	2020-02-14	8	[{"id_menu":5,"count":1}]	12298	delivery	5	13
31189	2020-02-14 20:16:46	2020-02-14	9	[{"id_menu":6,"count":1}]	12308	delivery	5	14
31190	2020-02-14 20:26:43	2020-02-14	17	[{"id_menu":4,"count":1}]	10256	delivery	5	22
31191	2020-02-14 20:33:29	2020-02-14	12	[{"id_menu":1,"count":1}]	1462	pick-up	0	12
31192	2020-02-14 20:34:36	2020-02-14	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	12252	delivery	5	22
31193	2020-02-14 20:37:45	2020-02-14	8	[{"id_menu":5,"count":1}]	10760	pick-up	0	8
31194	2020-02-14 20:43:12	2020-02-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6994	pick-up	0	17
31195	2020-02-14 20:47:07	2020-02-14	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	12292	delivery	5	28
31196	2020-02-14 20:56:13	2020-02-14	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	11464	delivery	5	31
31197	2020-02-14 20:58:11	2020-02-14	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11981	delivery	5	36
31198	2020-02-14 20:59:03	2020-02-14	12	[{"id_menu":3,"count":1}]	599	pick-up	0	12
31199	2020-02-14 21:04:19	2020-02-14	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4072	pick-up	0	35
31200	2020-02-14 21:09:08	2020-02-14	12	[{"id_menu":1,"count":1}]	7705	pick-up	0	12
31201	2020-02-14 21:27:40	2020-02-14	12	[{"id_menu":1,"count":1}]	8190	delivery	5	17
31202	2020-02-14 21:31:10	2020-02-14	12	[{"id_menu":1,"count":1}]	201	pick-up	0	12
31203	2020-02-14 21:34:52	2020-02-14	17	[{"id_menu":4,"count":1}]	12218	delivery	5	22
31204	2020-02-14 21:35:30	2020-02-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1643	delivery	5	31
31205	2020-02-14 21:52:59	2020-02-14	12	[{"id_menu":3,"count":2}]	11296	delivery	5	17
31206	2020-02-14 21:53:59	2020-02-14	12	[{"id_menu":3,"count":1}]	1537	delivery	5	17
31207	2020-02-14 22:00:58	2020-02-14	14	[{"id_menu":2,"count":1}]	285	pick-up	0	14
31208	2020-02-14 22:25:12	2020-02-14	8	[{"id_menu":5,"count":1}]	2276	pick-up	0	8
31209	2020-02-14 22:32:26	2020-02-14	12	[{"id_menu":1,"count":1}]	3870	pick-up	0	12
31210	2020-02-14 22:40:25	2020-02-14	17	[{"id_menu":4,"count":1}]	1996	delivery	5	22
31211	2020-02-14 22:47:00	2020-02-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11250	delivery	5	31
31212	2020-02-14 22:57:16	2020-02-14	14	[{"id_menu":2,"count":2}]	12245	delivery	5	19
31213	2020-02-14 23:00:29	2020-02-14	9	[{"id_menu":7,"count":1}]	5933	pick-up	0	9
31214	2020-02-14 23:08:32	2020-02-14	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	235	delivery	5	23
31215	2020-02-14 23:13:01	2020-02-14	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12293	delivery	5	39
31216	2020-02-14 23:19:22	2020-02-14	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1018	delivery	5	22
31217	2020-02-14 23:25:11	2020-02-14	14	[{"id_menu":2,"count":1}]	12012	pick-up	0	14
31218	2020-02-14 23:27:59	2020-02-14	8	[{"id_menu":5,"count":1}]	11806	delivery	5	13
31219	2020-02-14 23:34:52	2020-02-14	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2228	pick-up	0	43
31220	2020-02-14 23:37:08	2020-02-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	213	pick-up	0	23
31221	2020-02-14 23:46:18	2020-02-14	17	[{"id_menu":4,"count":1}]	10393	pick-up	0	17
31222	2020-02-14 23:48:30	2020-02-14	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	9081	delivery	5	37
31223	2020-02-14 23:54:22	2020-02-14	12	[{"id_menu":3,"count":1}]	4231	delivery	5	17
31224	2020-02-14 23:57:12	2020-02-14	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12272	delivery	5	34
31225	2020-02-15 00:00:22	2020-02-15	17	[{"id_menu":4,"count":1}]	12418	delivery	5	22
31226	2020-02-15 00:01:40	2020-02-15	17	[{"id_menu":4,"count":1}]	1258	pick-up	0	17
31227	2020-02-15 00:02:51	2020-02-15	8	[{"id_menu":5,"count":1}]	10480	delivery	5	13
31228	2020-02-15 00:07:09	2020-02-15	9	[{"id_menu":7,"count":1}]	12343	delivery	5	14
31229	2020-02-15 00:23:49	2020-02-15	9	[{"id_menu":6,"count":1}]	11748	delivery	5	14
31230	2020-02-15 00:24:21	2020-02-15	9	[{"id_menu":7,"count":1}]	12339	delivery	5	14
31231	2020-02-15 00:38:16	2020-02-15	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	12416	pick-up	0	31
31232	2020-02-15 00:44:51	2020-02-15	17	[{"id_menu":4,"count":1}]	8019	pick-up	0	17
31233	2020-02-15 00:45:03	2020-02-15	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8486	delivery	5	34
31234	2020-02-15 00:45:50	2020-02-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7455	delivery	5	31
31235	2020-02-15 00:56:52	2020-02-15	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12345	delivery	5	31
31236	2020-02-15 01:03:57	2020-02-15	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	12362	pick-up	0	26
31237	2020-02-15 01:10:20	2020-02-15	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	12363	delivery	5	25
31238	2020-02-15 01:24:06	2020-02-15	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	7698	delivery	5	28
31239	2020-02-15 01:24:56	2020-02-15	12	[{"id_menu":1,"count":1}]	581	delivery	5	17
31240	2020-02-15 01:27:10	2020-02-15	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12374	delivery	5	37
31241	2020-02-15 01:39:34	2020-02-15	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1528	pick-up	0	17
31242	2020-02-15 01:50:07	2020-02-15	12	[{"id_menu":1,"count":1}]	2520	pick-up	0	12
31243	2020-02-15 01:50:30	2020-02-15	17	[{"id_menu":4,"count":1}]	12386	pick-up	0	17
31244	2020-02-15 01:54:14	2020-02-15	14	[{"id_menu":2,"count":1}]	12356	delivery	5	19
31245	2020-02-15 01:54:19	2020-02-15	43	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	12379	delivery	5	48
31246	2020-02-15 01:55:08	2020-02-15	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5087	delivery	5	31
31247	2020-02-15 02:03:56	2020-02-15	9	[{"id_menu":6,"count":1}]	8391	delivery	5	14
31249	2020-02-15 02:15:23	2020-02-15	17	[{"id_menu":4,"count":1}]	12417	delivery	5	22
31250	2020-02-15 02:35:55	2020-02-15	17	[{"id_menu":4,"count":2}]	7224	delivery	5	22
31251	2020-02-15 02:47:09	2020-02-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1303	pick-up	0	23
31252	2020-02-15 02:47:52	2020-02-15	14	[{"id_menu":2,"count":1}]	2472	pick-up	0	14
31253	2020-02-15 02:48:11	2020-02-15	9	[{"id_menu":7,"count":1}]	7383	pick-up	0	9
31254	2020-02-15 02:53:54	2020-02-15	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9412	delivery	5	52
31255	2020-02-15 02:58:34	2020-02-15	17	[{"id_menu":4,"count":1}]	3578	pick-up	0	17
31256	2020-02-15 02:58:58	2020-02-15	12	[{"id_menu":1,"count":1}]	71	pick-up	0	12
31257	2020-02-15 03:03:44	2020-02-15	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	12328	delivery	5	48
31258	2020-02-15 03:07:55	2020-02-15	8	[{"id_menu":5,"count":1}]	11789	delivery	5	13
31259	2020-02-15 03:09:14	2020-02-15	12	[{"id_menu":1,"count":1}]	7208	delivery	5	17
31260	2020-02-15 03:09:37	2020-02-15	14	[{"id_menu":2,"count":1}]	1681	delivery	5	19
31261	2020-02-15 03:09:43	2020-02-15	12	[{"id_menu":1,"count":1}]	12407	delivery	5	17
31262	2020-02-15 03:11:21	2020-02-15	9	[{"id_menu":7,"count":1}]	3863	pick-up	0	9
31263	2020-02-15 03:12:16	2020-02-15	9	[{"id_menu":7,"count":1}]	12330	delivery	5	14
31264	2020-02-15 03:15:21	2020-02-15	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	8503	delivery	5	26
31265	2020-02-15 03:27:14	2020-02-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	790	delivery	5	28
31266	2020-02-15 03:31:30	2020-02-15	9	[{"id_menu":6,"count":1}]	12415	pick-up	0	9
31267	2020-02-15 03:34:06	2020-02-15	14	[{"id_menu":2,"count":1}]	12354	delivery	5	19
31268	2020-02-15 03:38:58	2020-02-15	9	[{"id_menu":6,"count":1}]	12382	pick-up	0	9
31269	2020-02-15 03:49:59	2020-02-15	12	[{"id_menu":3,"count":2}]	6919	delivery	5	17
31270	2020-02-15 03:52:59	2020-02-15	9	[{"id_menu":7,"count":1}]	8448	pick-up	0	9
31271	2020-02-15 03:53:19	2020-02-15	9	[{"id_menu":6,"count":1}]	12355	delivery	5	14
31272	2020-02-15 03:53:59	2020-02-15	9	[{"id_menu":7,"count":1}]	12428	delivery	5	14
31273	2020-02-15 03:55:06	2020-02-15	9	[{"id_menu":7,"count":1}]	5945	pick-up	0	9
31274	2020-02-15 03:58:09	2020-02-15	9	[{"id_menu":7,"count":1}]	10091	delivery	5	14
31275	2020-02-15 04:01:20	2020-02-15	12	[{"id_menu":1,"count":1}]	12344	delivery	5	17
31276	2020-02-15 04:15:24	2020-02-15	17	[{"id_menu":4,"count":1}]	12327	delivery	5	22
31277	2020-02-15 04:21:15	2020-02-15	12	[{"id_menu":1,"count":1}]	985	pick-up	0	12
31278	2020-02-15 04:29:27	2020-02-15	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2068	pick-up	0	26
31279	2020-02-15 04:30:04	2020-02-15	12	[{"id_menu":3,"count":1}]	2052	delivery	5	17
31280	2020-02-15 04:32:30	2020-02-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7806	pick-up	0	23
31281	2020-02-15 04:45:04	2020-02-15	17	[{"id_menu":4,"count":1}]	8753	delivery	5	22
31282	2020-02-15 04:45:45	2020-02-15	17	[{"id_menu":4,"count":1}]	1095	delivery	5	22
31283	2020-02-15 04:52:04	2020-02-15	9	[{"id_menu":6,"count":2}]	7757	delivery	5	14
31284	2020-02-15 04:52:16	2020-02-15	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	7428	delivery	5	26
31285	2020-02-15 04:56:08	2020-02-15	9	[{"id_menu":7,"count":1}]	3558	delivery	5	14
31286	2020-02-15 04:57:01	2020-02-15	8	[{"id_menu":5,"count":1}]	12389	delivery	5	13
31287	2020-02-15 05:01:43	2020-02-15	9	[{"id_menu":6,"count":1}]	11331	delivery	5	14
31288	2020-02-15 05:02:47	2020-02-15	12	[{"id_menu":1,"count":1}]	12326	delivery	5	17
31289	2020-02-15 05:25:55	2020-02-15	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	12329	delivery	5	34
31290	2020-02-15 05:26:11	2020-02-15	9	[{"id_menu":7,"count":1}]	12368	delivery	5	14
31291	2020-02-15 05:33:18	2020-02-15	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10812	delivery	5	51
31292	2020-02-15 05:34:04	2020-02-15	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	12302	delivery	5	26
31293	2020-02-15 05:35:21	2020-02-15	17	[{"id_menu":4,"count":1}]	10228	delivery	5	22
31294	2020-02-15 05:36:38	2020-02-15	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	12409	delivery	5	27
31295	2020-02-15 05:50:34	2020-02-15	9	[{"id_menu":6,"count":1}]	12419	pick-up	0	9
31296	2020-02-15 05:59:20	2020-02-15	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	8357	delivery	5	36
31297	2020-02-15 06:05:46	2020-02-15	8	[{"id_menu":5,"count":1}]	6514	delivery	5	13
31298	2020-02-15 06:12:04	2020-02-15	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	6469	pick-up	0	26
31299	2020-02-15 06:13:48	2020-02-15	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	5886	delivery	5	22
31300	2020-02-15 06:28:14	2020-02-15	14	[{"id_menu":2,"count":1}]	12377	delivery	5	19
31301	2020-02-15 06:30:08	2020-02-15	9	[{"id_menu":7,"count":1}]	12338	delivery	5	14
31302	2020-02-15 06:40:39	2020-02-15	8	[{"id_menu":5,"count":2}]	10851	delivery	5	13
31303	2020-02-15 06:43:31	2020-02-15	17	[{"id_menu":4,"count":1}]	6860	pick-up	0	17
31304	2020-02-15 06:53:56	2020-02-15	9	[{"id_menu":7,"count":2}]	4622	delivery	5	14
31305	2020-02-15 06:54:01	2020-02-15	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	4223	pick-up	0	21
31306	2020-02-15 07:00:58	2020-02-15	12	[{"id_menu":3,"count":1}]	12420	pick-up	0	12
31307	2020-02-15 07:01:47	2020-02-15	14	[{"id_menu":2,"count":1}]	2415	pick-up	0	14
31308	2020-02-15 07:11:58	2020-02-15	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	6738	delivery	5	25
31309	2020-02-15 07:22:36	2020-02-15	8	[{"id_menu":5,"count":1}]	12359	delivery	5	13
31310	2020-02-15 07:25:42	2020-02-15	8	[{"id_menu":5,"count":1}]	12346	delivery	5	13
31311	2020-02-15 07:28:14	2020-02-15	9	[{"id_menu":6,"count":1}]	5960	delivery	5	14
31312	2020-02-15 07:29:14	2020-02-15	8	[{"id_menu":5,"count":1}]	7963	delivery	5	13
31313	2020-02-15 07:31:41	2020-02-15	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	12383	delivery	5	26
31314	2020-02-15 07:36:21	2020-02-15	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1684	delivery	5	25
31315	2020-02-15 07:39:36	2020-02-15	17	[{"id_menu":4,"count":1}]	6152	pick-up	0	17
31316	2020-02-15 07:55:36	2020-02-15	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	950	delivery	5	26
31317	2020-02-15 07:56:12	2020-02-15	12	[{"id_menu":1,"count":1}]	7407	delivery	5	17
31318	2020-02-15 07:57:16	2020-02-15	12	[{"id_menu":1,"count":1}]	9714	pick-up	0	12
31319	2020-02-15 08:16:50	2020-02-15	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4445	delivery	5	34
31320	2020-02-15 08:34:41	2020-02-15	17	[{"id_menu":4,"count":1}]	3997	delivery	5	22
31321	2020-02-15 08:40:11	2020-02-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12332	pick-up	0	18
31322	2020-02-15 08:47:11	2020-02-15	9	[{"id_menu":7,"count":1}]	3996	delivery	5	14
31323	2020-02-15 08:47:27	2020-02-15	8	[{"id_menu":5,"count":1}]	5508	pick-up	0	8
31324	2020-02-15 08:48:54	2020-02-15	14	[{"id_menu":2,"count":1}]	12392	delivery	5	19
31325	2020-02-15 09:05:55	2020-02-15	17	[{"id_menu":4,"count":1}]	5637	delivery	5	22
31326	2020-02-15 09:07:39	2020-02-15	17	[{"id_menu":4,"count":1}]	12396	delivery	5	22
31327	2020-02-15 09:11:20	2020-02-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3712	delivery	5	31
31328	2020-02-15 09:12:02	2020-02-15	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11846	delivery	5	43
31329	2020-02-15 09:12:33	2020-02-15	9	[{"id_menu":6,"count":1}]	12334	pick-up	0	9
31330	2020-02-15 09:17:16	2020-02-15	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	11969	pick-up	0	26
31331	2020-02-15 09:17:48	2020-02-15	9	[{"id_menu":7,"count":1}]	12393	pick-up	0	9
31332	2020-02-15 09:31:23	2020-02-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	10632	pick-up	0	23
31333	2020-02-15 09:36:11	2020-02-15	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	12371	delivery	5	23
31334	2020-02-15 10:09:01	2020-02-15	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9900	delivery	5	34
31335	2020-02-15 10:09:14	2020-02-15	14	[{"id_menu":2,"count":1}]	8173	delivery	5	19
31336	2020-02-15 10:14:00	2020-02-15	9	[{"id_menu":6,"count":2}]	12385	delivery	5	14
31337	2020-02-15 10:20:01	2020-02-15	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	649	delivery	5	26
31338	2020-02-15 10:20:34	2020-02-15	9	[{"id_menu":7,"count":1}]	8607	pick-up	0	9
31339	2020-02-15 10:24:42	2020-02-15	9	[{"id_menu":7,"count":1}]	12400	delivery	5	14
31340	2020-02-15 10:32:12	2020-02-15	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12365	delivery	5	43
31341	2020-02-15 10:33:04	2020-02-15	17	[{"id_menu":4,"count":1}]	12351	delivery	5	22
31342	2020-02-15 10:33:36	2020-02-15	14	[{"id_menu":2,"count":1}]	2706	delivery	5	19
31343	2020-02-15 10:33:43	2020-02-15	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	408	pick-up	0	20
31344	2020-02-15 10:34:33	2020-02-15	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6403	delivery	5	46
31345	2020-02-15 10:35:27	2020-02-15	12	[{"id_menu":3,"count":1}]	989	delivery	5	17
31346	2020-02-15 10:41:02	2020-02-15	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3692	delivery	5	40
31347	2020-02-15 10:45:15	2020-02-15	12	[{"id_menu":3,"count":1}]	5699	delivery	5	17
31348	2020-02-15 10:54:18	2020-02-15	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	10835	delivery	5	23
31349	2020-02-15 10:55:11	2020-02-15	14	[{"id_menu":2,"count":1}]	12421	delivery	5	19
31350	2020-02-15 10:59:09	2020-02-15	8	[{"id_menu":5,"count":1}]	12424	delivery	5	13
31351	2020-02-15 11:04:18	2020-02-15	8	[{"id_menu":5,"count":1}]	12422	delivery	5	13
31352	2020-02-15 11:05:03	2020-02-15	14	[{"id_menu":2,"count":1}]	3294	delivery	5	19
31353	2020-02-15 11:17:04	2020-02-15	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	12335	delivery	5	31
31354	2020-02-15 11:19:33	2020-02-15	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	11674	delivery	5	34
31355	2020-02-15 11:22:46	2020-02-15	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	12369	delivery	5	26
31356	2020-02-15 11:22:51	2020-02-15	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":2}]	12375	delivery	5	22
31357	2020-02-15 11:26:20	2020-02-15	9	[{"id_menu":6,"count":1}]	6969	delivery	5	14
31358	2020-02-15 11:32:17	2020-02-15	14	[{"id_menu":2,"count":1}]	8406	pick-up	0	14
31359	2020-02-15 11:40:28	2020-02-15	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12078	delivery	5	45
31360	2020-02-15 11:47:31	2020-02-15	14	[{"id_menu":2,"count":1}]	5106	delivery	5	19
31361	2020-02-15 11:50:15	2020-02-15	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	12323	delivery	5	26
31362	2020-02-15 11:56:28	2020-02-15	12	[{"id_menu":1,"count":1}]	5509	delivery	5	17
31363	2020-02-15 11:56:33	2020-02-15	17	[{"id_menu":4,"count":1}]	1018	delivery	5	22
31364	2020-02-15 12:00:41	2020-02-15	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12370	delivery	5	52
31365	2020-02-15 12:00:46	2020-02-15	8	[{"id_menu":5,"count":1}]	12381	delivery	5	13
31366	2020-02-15 12:06:59	2020-02-15	9	[{"id_menu":7,"count":1}]	12367	pick-up	0	9
31367	2020-02-15 12:14:10	2020-02-15	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10461	delivery	5	34
31368	2020-02-15 12:17:51	2020-02-15	8	[{"id_menu":5,"count":1}]	12429	pick-up	0	8
31369	2020-02-15 12:21:04	2020-02-15	9	[{"id_menu":7,"count":1}]	12423	delivery	5	14
31370	2020-02-15 12:57:08	2020-02-15	14	[{"id_menu":2,"count":1}]	2023	pick-up	0	14
31371	2020-02-15 12:59:50	2020-02-15	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1690	delivery	5	48
31372	2020-02-15 13:08:40	2020-02-15	12	[{"id_menu":3,"count":1}]	839	pick-up	0	12
31373	2020-02-15 13:09:15	2020-02-15	14	[{"id_menu":2,"count":1}]	229	delivery	5	19
31374	2020-02-15 13:09:37	2020-02-15	9	[{"id_menu":7,"count":1}]	12394	delivery	5	14
31375	2020-02-15 13:12:40	2020-02-15	8	[{"id_menu":5,"count":1}]	5329	delivery	5	13
31376	2020-02-15 13:15:30	2020-02-15	17	[{"id_menu":4,"count":1}]	4629	pick-up	0	17
31377	2020-02-15 13:17:02	2020-02-15	9	[{"id_menu":6,"count":1}]	3755	pick-up	0	9
31378	2020-02-15 13:17:22	2020-02-15	9	[{"id_menu":6,"count":1}]	12340	delivery	5	14
31379	2020-02-15 13:24:35	2020-02-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1760	delivery	5	28
31380	2020-02-15 13:25:32	2020-02-15	8	[{"id_menu":5,"count":1}]	12336	delivery	5	13
31381	2020-02-15 13:27:07	2020-02-15	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2608	pick-up	0	26
31382	2020-02-15 13:27:25	2020-02-15	8	[{"id_menu":5,"count":2}]	3119	delivery	5	13
31383	2020-02-15 13:28:37	2020-02-15	8	[{"id_menu":5,"count":1}]	12324	delivery	5	13
31384	2020-02-15 13:28:45	2020-02-15	12	[{"id_menu":3,"count":1}]	12376	delivery	5	17
31385	2020-02-15 13:30:09	2020-02-15	12	[{"id_menu":1,"count":1}]	8671	delivery	5	17
31386	2020-02-15 13:32:09	2020-02-15	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9552	delivery	5	22
31387	2020-02-15 13:33:10	2020-02-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	12263	delivery	5	28
31388	2020-02-15 13:37:37	2020-02-15	9	[{"id_menu":7,"count":1}]	10295	delivery	5	14
31389	2020-02-15 13:40:21	2020-02-15	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	9638	delivery	5	39
31390	2020-02-15 13:41:14	2020-02-15	9	[{"id_menu":7,"count":1}]	12364	delivery	5	14
31391	2020-02-15 13:41:58	2020-02-15	9	[{"id_menu":6,"count":1}]	12403	delivery	5	14
31392	2020-02-15 13:42:04	2020-02-15	14	[{"id_menu":2,"count":1}]	12348	delivery	5	19
31393	2020-02-15 13:48:05	2020-02-15	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1097	pick-up	0	29
31394	2020-02-15 13:48:13	2020-02-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	986	delivery	5	28
31395	2020-02-15 13:52:18	2020-02-15	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2530	pick-up	0	29
31396	2020-02-15 13:56:10	2020-02-15	9	[{"id_menu":6,"count":2}]	8434	delivery	5	14
31397	2020-02-15 13:56:51	2020-02-15	12	[{"id_menu":3,"count":1}]	12414	delivery	5	17
31398	2020-02-15 13:57:53	2020-02-15	17	[{"id_menu":4,"count":1}]	6618	delivery	5	22
31399	2020-02-15 14:00:20	2020-02-15	14	[{"id_menu":2,"count":1}]	240	pick-up	0	14
31400	2020-02-15 14:04:04	2020-02-15	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	7744	delivery	5	34
31401	2020-02-15 14:06:44	2020-02-15	12	[{"id_menu":1,"count":1}]	9355	pick-up	0	12
31402	2020-02-15 14:07:51	2020-02-15	17	[{"id_menu":4,"count":1}]	9973	delivery	5	22
31403	2020-02-15 14:16:09	2020-02-15	8	[{"id_menu":5,"count":1}]	12413	delivery	5	13
31404	2020-02-15 14:16:39	2020-02-15	8	[{"id_menu":5,"count":1}]	12384	delivery	5	13
31405	2020-02-15 14:18:54	2020-02-15	14	[{"id_menu":2,"count":1}]	12430	delivery	5	19
31406	2020-02-15 14:22:08	2020-02-15	12	[{"id_menu":1,"count":1}]	12427	pick-up	0	12
31407	2020-02-15 14:25:53	2020-02-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12322	delivery	5	23
31408	2020-02-15 14:35:45	2020-02-15	9	[{"id_menu":6,"count":1}]	6195	pick-up	0	9
31409	2020-02-15 14:39:43	2020-02-15	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12408	delivery	5	22
31410	2020-02-15 14:39:47	2020-02-15	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	2281	delivery	5	22
31411	2020-02-15 14:43:32	2020-02-15	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10241	delivery	5	51
31412	2020-02-15 14:44:41	2020-02-15	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12358	delivery	5	36
31413	2020-02-15 14:44:54	2020-02-15	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	11469	delivery	5	44
31414	2020-02-15 15:01:43	2020-02-15	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	12342	delivery	5	26
31415	2020-02-15 15:04:09	2020-02-15	12	[{"id_menu":3,"count":1}]	2735	pick-up	0	12
31416	2020-02-15 15:11:05	2020-02-15	14	[{"id_menu":2,"count":1}]	1753	pick-up	0	14
31417	2020-02-15 15:11:22	2020-02-15	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12405	delivery	5	43
31418	2020-02-15 15:15:57	2020-02-15	17	[{"id_menu":4,"count":1}]	3710	pick-up	0	17
31419	2020-02-15 15:20:28	2020-02-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12401	delivery	5	23
31420	2020-02-15 15:24:54	2020-02-15	12	[{"id_menu":1,"count":1}]	12380	delivery	5	17
31421	2020-02-15 15:26:49	2020-02-15	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	12349	delivery	5	36
31422	2020-02-15 15:29:15	2020-02-15	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	12378	delivery	5	31
31423	2020-02-15 15:33:03	2020-02-15	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12337	delivery	5	31
31424	2020-02-15 15:36:20	2020-02-15	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	4982	delivery	5	27
31425	2020-02-15 15:40:09	2020-02-15	14	[{"id_menu":2,"count":1}]	5382	delivery	5	19
31426	2020-02-15 15:42:18	2020-02-15	14	[{"id_menu":2,"count":1}]	5166	pick-up	0	14
31427	2020-02-15 15:45:01	2020-02-15	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	12360	delivery	5	23
31428	2020-02-15 15:53:41	2020-02-15	8	[{"id_menu":5,"count":1}]	11465	pick-up	0	8
31429	2020-02-15 15:54:19	2020-02-15	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	8115	pick-up	0	43
31430	2020-02-15 16:08:50	2020-02-15	21	[{"id_menu":1,"count":3},{"id_menu":6,"count":1}]	12325	delivery	5	26
31431	2020-02-15 16:14:10	2020-02-15	12	[{"id_menu":3,"count":1}]	5026	pick-up	0	12
31432	2020-02-15 16:19:55	2020-02-15	9	[{"id_menu":6,"count":4}]	12397	delivery	5	14
31433	2020-02-15 16:25:41	2020-02-15	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	12102	delivery	5	29
31434	2020-02-15 16:27:16	2020-02-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2933	delivery	5	28
31435	2020-02-15 16:27:47	2020-02-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	2715	pick-up	0	26
31436	2020-02-15 16:28:04	2020-02-15	12	[{"id_menu":1,"count":1}]	2985	pick-up	0	12
31437	2020-02-15 16:29:07	2020-02-15	12	[{"id_menu":1,"count":1}]	573	pick-up	0	12
31438	2020-02-15 16:32:52	2020-02-15	17	[{"id_menu":4,"count":1}]	12387	delivery	5	22
31439	2020-02-15 16:36:40	2020-02-15	9	[{"id_menu":6,"count":1}]	6296	delivery	5	14
31440	2020-02-15 16:52:28	2020-02-15	17	[{"id_menu":4,"count":1}]	10655	delivery	5	22
31441	2020-02-15 16:56:46	2020-02-15	14	[{"id_menu":2,"count":1}]	1934	pick-up	0	14
31442	2020-02-15 17:01:53	2020-02-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	8355	pick-up	0	23
31443	2020-02-15 17:02:26	2020-02-15	55	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	531	pick-up	0	55
31444	2020-02-15 17:08:06	2020-02-15	9	[{"id_menu":7,"count":1}]	12388	pick-up	0	9
31445	2020-02-15 17:35:11	2020-02-15	12	[{"id_menu":3,"count":1}]	7189	pick-up	0	12
31446	2020-02-15 17:38:45	2020-02-15	8	[{"id_menu":5,"count":1}]	12321	delivery	5	13
31447	2020-02-15 17:40:59	2020-02-15	12	[{"id_menu":1,"count":1}]	12372	delivery	5	17
31448	2020-02-15 17:41:44	2020-02-15	9	[{"id_menu":7,"count":1}]	12406	delivery	5	14
31449	2020-02-15 17:47:37	2020-02-15	9	[{"id_menu":6,"count":1}]	7690	pick-up	0	9
31450	2020-02-15 17:47:40	2020-02-15	9	[{"id_menu":6,"count":1}]	1155	delivery	5	14
31451	2020-02-15 17:49:07	2020-02-15	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	9846	pick-up	0	23
31452	2020-02-15 17:50:41	2020-02-15	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	12395	delivery	5	22
31453	2020-02-15 17:51:03	2020-02-15	9	[{"id_menu":6,"count":1}]	1002	pick-up	0	9
31454	2020-02-15 17:53:54	2020-02-15	14	[{"id_menu":2,"count":1}]	7388	delivery	5	19
31455	2020-02-15 17:58:22	2020-02-15	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1724	delivery	5	57
31456	2020-02-15 18:03:42	2020-02-15	9	[{"id_menu":6,"count":1}]	12341	pick-up	0	9
31457	2020-02-15 18:03:46	2020-02-15	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	11550	delivery	5	30
31458	2020-02-15 18:09:20	2020-02-15	9	[{"id_menu":6,"count":1}]	12425	delivery	5	14
31459	2020-02-15 18:12:30	2020-02-15	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2268	pick-up	0	31
31460	2020-02-15 18:19:19	2020-02-15	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7167	delivery	5	31
31461	2020-02-15 18:23:35	2020-02-15	9	[{"id_menu":7,"count":1}]	10797	delivery	5	14
31462	2020-02-15 18:28:40	2020-02-15	12	[{"id_menu":3,"count":1}]	1767	pick-up	0	12
31463	2020-02-15 18:32:57	2020-02-15	12	[{"id_menu":1,"count":1}]	12361	delivery	5	17
31464	2020-02-15 18:37:29	2020-02-15	12	[{"id_menu":3,"count":1}]	5183	delivery	5	17
31465	2020-02-15 18:43:23	2020-02-15	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	4485	delivery	5	35
31466	2020-02-15 18:47:41	2020-02-15	17	[{"id_menu":4,"count":1}]	2944	delivery	5	22
31467	2020-02-15 18:50:19	2020-02-15	9	[{"id_menu":6,"count":1}]	12390	delivery	5	14
31468	2020-02-15 18:52:48	2020-02-15	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12404	delivery	5	43
31469	2020-02-15 18:57:53	2020-02-15	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	12426	delivery	5	25
31470	2020-02-15 19:12:51	2020-02-15	55	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	12402	delivery	5	60
31471	2020-02-15 19:13:31	2020-02-15	12	[{"id_menu":3,"count":1}]	3940	pick-up	0	12
31472	2020-02-15 19:29:51	2020-02-15	8	[{"id_menu":5,"count":1}]	12353	delivery	5	13
31473	2020-02-15 19:36:55	2020-02-15	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	348	delivery	5	34
31474	2020-02-15 19:38:12	2020-02-15	12	[{"id_menu":3,"count":1}]	12333	delivery	5	17
31475	2020-02-15 19:41:09	2020-02-15	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6817	pick-up	0	35
31476	2020-02-15 19:56:07	2020-02-15	9	[{"id_menu":6,"count":1}]	2425	pick-up	0	9
31477	2020-02-15 20:08:44	2020-02-15	9	[{"id_menu":6,"count":1}]	5590	delivery	5	14
31478	2020-02-15 20:22:04	2020-02-15	8	[{"id_menu":5,"count":1}]	8698	delivery	5	13
31479	2020-02-15 20:22:41	2020-02-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2317	pick-up	0	23
31480	2020-02-15 20:26:32	2020-02-15	9	[{"id_menu":7,"count":1}]	3123	pick-up	0	9
31481	2020-02-15 20:31:51	2020-02-15	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	1325	delivery	5	35
31482	2020-02-15 20:33:05	2020-02-15	17	[{"id_menu":4,"count":1}]	3372	delivery	5	22
31483	2020-02-15 20:42:06	2020-02-15	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2124	delivery	5	34
31484	2020-02-15 20:43:44	2020-02-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1425	pick-up	0	26
31485	2020-02-15 20:44:57	2020-02-15	14	[{"id_menu":2,"count":1}]	4714	delivery	5	19
31486	2020-02-15 20:46:55	2020-02-15	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8923	pick-up	0	17
31487	2020-02-15 20:49:13	2020-02-15	9	[{"id_menu":6,"count":1}]	9356	pick-up	0	9
31488	2020-02-15 20:55:27	2020-02-15	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	10292	delivery	5	26
31489	2020-02-15 21:00:08	2020-02-15	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	12347	delivery	5	22
31490	2020-02-15 21:01:22	2020-02-15	12	[{"id_menu":1,"count":1}]	6235	delivery	5	17
31491	2020-02-15 21:04:50	2020-02-15	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	424	pick-up	0	31
31492	2020-02-15 21:06:23	2020-02-15	14	[{"id_menu":2,"count":1}]	788	pick-up	0	14
31493	2020-02-15 21:13:59	2020-02-15	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1986	delivery	5	39
31494	2020-02-15 21:14:51	2020-02-15	9	[{"id_menu":7,"count":1}]	1481	pick-up	0	9
31495	2020-02-15 21:14:54	2020-02-15	14	[{"id_menu":2,"count":1}]	5004	delivery	5	19
31496	2020-02-15 21:30:44	2020-02-15	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12350	pick-up	0	34
31497	2020-02-15 21:40:06	2020-02-15	14	[{"id_menu":2,"count":1}]	2066	pick-up	0	14
31498	2020-02-15 21:49:15	2020-02-15	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	123	pick-up	0	46
31499	2020-02-15 21:50:03	2020-02-15	9	[{"id_menu":6,"count":1}]	3146	delivery	5	14
31500	2020-02-15 21:51:16	2020-02-15	8	[{"id_menu":5,"count":2}]	3831	delivery	5	13
31501	2020-02-15 21:55:16	2020-02-15	9	[{"id_menu":7,"count":1}]	12331	delivery	5	14
31502	2020-02-15 21:55:51	2020-02-15	9	[{"id_menu":7,"count":1}]	2765	delivery	5	14
31503	2020-02-15 21:58:05	2020-02-15	17	[{"id_menu":4,"count":1}]	4836	delivery	5	22
31504	2020-02-15 22:01:40	2020-02-15	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	12391	delivery	5	28
31505	2020-02-15 22:12:15	2020-02-15	9	[{"id_menu":6,"count":1}]	9373	pick-up	0	9
31506	2020-02-15 22:15:48	2020-02-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9174	delivery	5	28
31507	2020-02-15 22:16:45	2020-02-15	9	[{"id_menu":7,"count":1}]	12412	delivery	5	14
31508	2020-02-15 22:17:32	2020-02-15	17	[{"id_menu":4,"count":1}]	12399	delivery	5	22
31509	2020-02-15 22:22:33	2020-02-15	9	[{"id_menu":7,"count":1}]	12373	pick-up	0	9
31510	2020-02-15 22:23:15	2020-02-15	12	[{"id_menu":3,"count":1}]	5820	pick-up	0	12
31511	2020-02-15 22:31:41	2020-02-15	17	[{"id_menu":4,"count":1}]	12357	delivery	5	22
31512	2020-02-15 22:52:54	2020-02-15	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11491	pick-up	0	17
31513	2020-02-15 22:55:44	2020-02-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3230	pick-up	0	26
31514	2020-02-15 22:57:20	2020-02-15	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	12398	delivery	5	26
31515	2020-02-15 23:02:29	2020-02-15	8	[{"id_menu":5,"count":1}]	10796	delivery	5	13
31516	2020-02-15 23:12:21	2020-02-15	12	[{"id_menu":3,"count":1}]	3916	pick-up	0	12
31517	2020-02-15 23:22:32	2020-02-15	9	[{"id_menu":6,"count":1}]	12352	delivery	5	14
31518	2020-02-15 23:35:39	2020-02-15	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	438	pick-up	0	24
31519	2020-02-15 23:43:03	2020-02-15	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	10116	delivery	5	27
31520	2020-02-15 23:53:38	2020-02-15	8	[{"id_menu":5,"count":2}]	12410	delivery	5	13
31521	2020-02-16 00:06:15	2020-02-16	9	[{"id_menu":7,"count":1}]	12532	pick-up	0	9
31522	2020-02-16 00:08:40	2020-02-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	12509	delivery	5	31
31523	2020-02-16 00:19:08	2020-02-16	12	[{"id_menu":1,"count":1}]	7815	pick-up	0	12
31524	2020-02-16 00:19:28	2020-02-16	8	[{"id_menu":5,"count":1}]	321	delivery	5	13
31525	2020-02-16 00:22:59	2020-02-16	12	[{"id_menu":3,"count":1}]	12499	delivery	5	17
31526	2020-02-16 00:24:19	2020-02-16	14	[{"id_menu":2,"count":1}]	12485	pick-up	0	14
31527	2020-02-16 00:24:46	2020-02-16	9	[{"id_menu":7,"count":2}]	7904	pick-up	0	9
31528	2020-02-16 00:26:11	2020-02-16	9	[{"id_menu":7,"count":1}]	7603	pick-up	0	9
31529	2020-02-16 00:26:19	2020-02-16	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	2909	delivery	5	31
31530	2020-02-16 00:27:03	2020-02-16	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1460	pick-up	0	21
31531	2020-02-16 00:37:57	2020-02-16	14	[{"id_menu":2,"count":1}]	273	delivery	5	19
31532	2020-02-16 00:39:46	2020-02-16	9	[{"id_menu":7,"count":1}]	5989	delivery	5	14
31533	2020-02-16 00:39:49	2020-02-16	9	[{"id_menu":6,"count":1}]	1963	delivery	5	14
31534	2020-02-16 00:48:54	2020-02-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	12508	delivery	5	28
31535	2020-02-16 00:54:35	2020-02-16	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	12531	delivery	5	39
31536	2020-02-16 00:57:36	2020-02-16	14	[{"id_menu":2,"count":1}]	6090	pick-up	0	14
31537	2020-02-16 01:01:00	2020-02-16	9	[{"id_menu":7,"count":1}]	12444	pick-up	0	9
31538	2020-02-16 01:10:30	2020-02-16	9	[{"id_menu":6,"count":1}]	3494	delivery	5	14
31539	2020-02-16 01:10:36	2020-02-16	9	[{"id_menu":7,"count":1}]	9915	delivery	5	14
31540	2020-02-16 01:12:13	2020-02-16	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	12473	pick-up	0	25
31541	2020-02-16 01:13:37	2020-02-16	17	[{"id_menu":4,"count":1}]	3940	pick-up	0	17
31542	2020-02-16 01:18:22	2020-02-16	9	[{"id_menu":6,"count":1}]	6201	delivery	5	14
31543	2020-02-16 01:19:10	2020-02-16	12	[{"id_menu":3,"count":1}]	9859	pick-up	0	12
31544	2020-02-16 01:24:18	2020-02-16	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7310	delivery	5	37
31545	2020-02-16 01:28:44	2020-02-16	12	[{"id_menu":1,"count":1}]	11269	delivery	5	17
31546	2020-02-16 01:35:33	2020-02-16	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	2054	delivery	5	31
31547	2020-02-16 01:40:09	2020-02-16	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11417	delivery	5	22
31548	2020-02-16 01:41:57	2020-02-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	12534	delivery	5	26
31549	2020-02-16 01:49:41	2020-02-16	8	[{"id_menu":5,"count":1}]	627	delivery	5	13
31550	2020-02-16 01:54:03	2020-02-16	9	[{"id_menu":6,"count":1}]	2594	pick-up	0	9
31551	2020-02-16 01:56:17	2020-02-16	12	[{"id_menu":3,"count":1}]	2715	pick-up	0	12
31552	2020-02-16 02:02:16	2020-02-16	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12338	delivery	5	39
31553	2020-02-16 02:11:54	2020-02-16	17	[{"id_menu":4,"count":1}]	10093	delivery	5	22
31554	2020-02-16 02:13:21	2020-02-16	9	[{"id_menu":6,"count":1}]	2000	pick-up	0	9
31555	2020-02-16 02:14:12	2020-02-16	17	[{"id_menu":4,"count":1}]	257	delivery	5	22
31556	2020-02-16 02:14:55	2020-02-16	9	[{"id_menu":7,"count":1}]	1649	pick-up	0	9
31557	2020-02-16 02:20:25	2020-02-16	12	[{"id_menu":1,"count":1}]	1406	pick-up	0	12
31558	2020-02-16 02:21:05	2020-02-16	9	[{"id_menu":6,"count":1}]	8616	delivery	5	14
31559	2020-02-16 02:21:57	2020-02-16	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":2}]	3883	delivery	5	28
31560	2020-02-16 02:23:40	2020-02-16	9	[{"id_menu":6,"count":1}]	12445	pick-up	0	9
31561	2020-02-16 02:24:59	2020-02-16	8	[{"id_menu":5,"count":1}]	4414	pick-up	0	8
31562	2020-02-16 02:33:31	2020-02-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7491	delivery	5	28
31563	2020-02-16 02:33:38	2020-02-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	12475	delivery	5	28
31564	2020-02-16 02:33:54	2020-02-16	14	[{"id_menu":2,"count":1}]	12520	delivery	5	19
31565	2020-02-16 02:47:25	2020-02-16	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	12512	delivery	5	27
31566	2020-02-16 02:48:30	2020-02-16	14	[{"id_menu":2,"count":1}]	12502	pick-up	0	14
31567	2020-02-16 02:56:14	2020-02-16	9	[{"id_menu":6,"count":1}]	9686	delivery	5	14
31568	2020-02-16 02:56:14	2020-02-16	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	8539	delivery	5	45
31569	2020-02-16 02:56:51	2020-02-16	12	[{"id_menu":1,"count":1}]	7746	pick-up	0	12
31570	2020-02-16 02:57:52	2020-02-16	8	[{"id_menu":5,"count":1}]	609	pick-up	0	8
31571	2020-02-16 03:15:12	2020-02-16	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	993	delivery	5	48
31572	2020-02-16 03:17:43	2020-02-16	9	[{"id_menu":6,"count":1}]	372	pick-up	0	9
31573	2020-02-16 03:22:11	2020-02-16	9	[{"id_menu":6,"count":2}]	9263	delivery	5	14
31574	2020-02-16 03:31:11	2020-02-16	12	[{"id_menu":3,"count":1}]	3578	pick-up	0	12
31575	2020-02-16 03:42:44	2020-02-16	17	[{"id_menu":4,"count":1}]	12478	delivery	5	22
31576	2020-02-16 03:42:44	2020-02-16	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7186	delivery	5	36
31577	2020-02-16 03:44:31	2020-02-16	14	[{"id_menu":2,"count":1}]	12503	delivery	5	19
31578	2020-02-16 03:46:46	2020-02-16	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4485	delivery	5	36
31579	2020-02-16 03:48:02	2020-02-16	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3261	delivery	5	37
31580	2020-02-16 03:49:11	2020-02-16	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12464	delivery	5	43
31581	2020-02-16 03:51:24	2020-02-16	9	[{"id_menu":7,"count":1}]	2190	delivery	5	14
31582	2020-02-16 03:52:04	2020-02-16	12	[{"id_menu":1,"count":1}]	12437	delivery	5	17
31583	2020-02-16 03:58:05	2020-02-16	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12488	delivery	5	45
31584	2020-02-16 04:08:20	2020-02-16	17	[{"id_menu":4,"count":1}]	12479	delivery	5	22
31585	2020-02-16 04:11:19	2020-02-16	14	[{"id_menu":2,"count":1}]	8229	pick-up	0	14
31586	2020-02-16 04:11:41	2020-02-16	9	[{"id_menu":7,"count":1}]	12495	pick-up	0	9
31587	2020-02-16 04:12:03	2020-02-16	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9365	delivery	5	42
31588	2020-02-16 04:13:27	2020-02-16	9	[{"id_menu":6,"count":1}]	5304	delivery	5	14
31589	2020-02-16 04:25:53	2020-02-16	14	[{"id_menu":2,"count":1}]	1119	pick-up	0	14
31590	2020-02-16 04:28:20	2020-02-16	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	3543	delivery	5	34
31591	2020-02-16 04:32:39	2020-02-16	14	[{"id_menu":2,"count":1}]	2602	pick-up	0	14
31592	2020-02-16 04:53:44	2020-02-16	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8050	delivery	5	35
31593	2020-02-16 04:54:03	2020-02-16	9	[{"id_menu":7,"count":1}]	12451	delivery	5	14
31594	2020-02-16 04:54:06	2020-02-16	12	[{"id_menu":1,"count":1}]	12481	delivery	5	17
31595	2020-02-16 05:03:55	2020-02-16	14	[{"id_menu":2,"count":2}]	1862	pick-up	0	14
31596	2020-02-16 05:08:32	2020-02-16	9	[{"id_menu":6,"count":1}]	12528	delivery	5	14
31597	2020-02-16 05:11:31	2020-02-16	17	[{"id_menu":4,"count":1}]	711	pick-up	0	17
31598	2020-02-16 05:15:31	2020-02-16	8	[{"id_menu":5,"count":1}]	10850	delivery	5	13
31599	2020-02-16 05:18:04	2020-02-16	14	[{"id_menu":2,"count":1}]	12467	delivery	5	19
31600	2020-02-16 05:22:32	2020-02-16	17	[{"id_menu":4,"count":1}]	1530	delivery	5	22
31601	2020-02-16 05:27:45	2020-02-16	9	[{"id_menu":7,"count":1}]	12470	delivery	5	14
31602	2020-02-16 05:29:02	2020-02-16	9	[{"id_menu":7,"count":2}]	1988	pick-up	0	9
31603	2020-02-16 05:31:52	2020-02-16	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	6055	delivery	5	40
31604	2020-02-16 05:35:22	2020-02-16	12	[{"id_menu":3,"count":1}]	7766	delivery	5	17
31605	2020-02-16 05:38:34	2020-02-16	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	5568	delivery	5	42
31606	2020-02-16 05:39:09	2020-02-16	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	10863	delivery	5	26
31607	2020-02-16 05:41:10	2020-02-16	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12477	delivery	5	22
31608	2020-02-16 05:44:15	2020-02-16	9	[{"id_menu":6,"count":1}]	764	delivery	5	14
31609	2020-02-16 05:51:25	2020-02-16	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	12510	delivery	5	35
31610	2020-02-16 05:53:48	2020-02-16	17	[{"id_menu":4,"count":1}]	12349	delivery	5	22
31611	2020-02-16 05:59:10	2020-02-16	12	[{"id_menu":3,"count":1}]	12436	delivery	5	17
31612	2020-02-16 06:07:35	2020-02-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	10129	delivery	5	22
31613	2020-02-16 06:13:08	2020-02-16	14	[{"id_menu":2,"count":2}]	8310	pick-up	0	14
31614	2020-02-16 06:16:16	2020-02-16	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10000	delivery	5	43
31615	2020-02-16 06:18:27	2020-02-16	9	[{"id_menu":7,"count":1}]	12463	pick-up	0	9
31616	2020-02-16 06:18:33	2020-02-16	12	[{"id_menu":1,"count":1}]	280	pick-up	0	12
31617	2020-02-16 06:25:03	2020-02-16	9	[{"id_menu":7,"count":2}]	6354	delivery	5	14
31618	2020-02-16 06:29:16	2020-02-16	9	[{"id_menu":6,"count":1}]	12518	delivery	5	14
31619	2020-02-16 06:29:40	2020-02-16	14	[{"id_menu":2,"count":1}]	1420	delivery	5	19
31620	2020-02-16 06:35:16	2020-02-16	12	[{"id_menu":1,"count":1}]	12449	delivery	5	17
31621	2020-02-16 06:36:39	2020-02-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2796	pick-up	0	23
31622	2020-02-16 06:40:16	2020-02-16	9	[{"id_menu":6,"count":1}]	12443	delivery	5	14
31623	2020-02-16 06:43:48	2020-02-16	12	[{"id_menu":3,"count":1}]	330	delivery	5	17
31624	2020-02-16 06:50:27	2020-02-16	9	[{"id_menu":7,"count":1}]	1180	pick-up	0	9
31625	2020-02-16 06:52:44	2020-02-16	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	12459	delivery	5	25
31626	2020-02-16 06:54:38	2020-02-16	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9660	delivery	5	30
31627	2020-02-16 06:56:21	2020-02-16	8	[{"id_menu":5,"count":1}]	1536	pick-up	0	8
31628	2020-02-16 07:00:17	2020-02-16	9	[{"id_menu":7,"count":1}]	3780	delivery	5	14
31629	2020-02-16 07:05:08	2020-02-16	12	[{"id_menu":3,"count":1}]	10011	delivery	5	17
31630	2020-02-16 07:05:16	2020-02-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	8149	delivery	5	28
31631	2020-02-16 07:06:44	2020-02-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	12535	delivery	5	28
31632	2020-02-16 07:07:02	2020-02-16	12	[{"id_menu":1,"count":1}]	3958	delivery	5	17
31633	2020-02-16 07:07:58	2020-02-16	12	[{"id_menu":1,"count":1}]	2276	delivery	5	17
31634	2020-02-16 07:11:20	2020-02-16	9	[{"id_menu":7,"count":1}]	12446	delivery	5	14
31635	2020-02-16 07:14:12	2020-02-16	9	[{"id_menu":7,"count":1}]	10349	delivery	5	14
31636	2020-02-16 07:17:52	2020-02-16	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	12452	delivery	5	34
31637	2020-02-16 07:20:26	2020-02-16	8	[{"id_menu":5,"count":1}]	12346	delivery	5	13
31638	2020-02-16 07:24:04	2020-02-16	12	[{"id_menu":1,"count":1}]	2762	pick-up	0	12
31639	2020-02-16 07:30:55	2020-02-16	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3730	pick-up	0	21
31640	2020-02-16 07:35:09	2020-02-16	17	[{"id_menu":4,"count":1}]	9296	delivery	5	22
31641	2020-02-16 07:36:32	2020-02-16	9	[{"id_menu":6,"count":1}]	10287	delivery	5	14
31642	2020-02-16 07:45:52	2020-02-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	11511	delivery	5	28
31643	2020-02-16 07:50:03	2020-02-16	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	12433	delivery	5	27
31644	2020-02-16 07:53:24	2020-02-16	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1291	pick-up	0	47
31645	2020-02-16 08:01:43	2020-02-16	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12483	delivery	5	55
31646	2020-02-16 08:07:09	2020-02-16	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3211	delivery	5	34
31647	2020-02-16 08:11:45	2020-02-16	14	[{"id_menu":2,"count":1}]	241	pick-up	0	14
31648	2020-02-16 08:14:31	2020-02-16	12	[{"id_menu":1,"count":1}]	2502	pick-up	0	12
31649	2020-02-16 08:16:17	2020-02-16	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	10337	delivery	5	30
31650	2020-02-16 08:20:35	2020-02-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	12088	delivery	5	28
31651	2020-02-16 08:21:47	2020-02-16	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9433	delivery	5	51
31652	2020-02-16 08:23:38	2020-02-16	17	[{"id_menu":4,"count":1}]	1592	pick-up	0	17
31653	2020-02-16 08:32:02	2020-02-16	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9554	delivery	5	39
31654	2020-02-16 08:38:00	2020-02-16	12	[{"id_menu":3,"count":1}]	2287	pick-up	0	12
31655	2020-02-16 08:51:08	2020-02-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12455	delivery	5	22
31656	2020-02-16 08:56:48	2020-02-16	9	[{"id_menu":6,"count":1}]	5097	delivery	5	14
31657	2020-02-16 09:02:08	2020-02-16	17	[{"id_menu":4,"count":1}]	8098	pick-up	0	17
31658	2020-02-16 09:08:48	2020-02-16	8	[{"id_menu":5,"count":2}]	7724	pick-up	0	8
31659	2020-02-16 09:19:34	2020-02-16	12	[{"id_menu":3,"count":1}]	2780	pick-up	0	12
31660	2020-02-16 09:22:45	2020-02-16	8	[{"id_menu":5,"count":1}]	2366	pick-up	0	8
31661	2020-02-16 09:23:00	2020-02-16	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	12523	delivery	5	22
31662	2020-02-16 09:23:04	2020-02-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":3}]	1179	delivery	5	28
31663	2020-02-16 09:27:52	2020-02-16	17	[{"id_menu":4,"count":1}]	2007	pick-up	0	17
31664	2020-02-16 09:28:32	2020-02-16	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12441	delivery	5	39
31665	2020-02-16 09:29:28	2020-02-16	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	5886	delivery	5	22
31666	2020-02-16 09:34:51	2020-02-16	8	[{"id_menu":5,"count":1}]	9040	pick-up	0	8
31667	2020-02-16 09:35:18	2020-02-16	14	[{"id_menu":2,"count":1}]	4369	delivery	5	19
31668	2020-02-16 09:38:16	2020-02-16	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2658	delivery	5	38
31669	2020-02-16 09:54:25	2020-02-16	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	12507	delivery	5	43
31670	2020-02-16 10:02:19	2020-02-16	8	[{"id_menu":5,"count":1}]	4546	pick-up	0	8
31671	2020-02-16 10:11:51	2020-02-16	12	[{"id_menu":1,"count":1}]	4463	pick-up	0	12
31672	2020-02-16 10:12:26	2020-02-16	9	[{"id_menu":6,"count":1}]	12442	delivery	5	14
31673	2020-02-16 10:22:28	2020-02-16	12	[{"id_menu":3,"count":1}]	6158	pick-up	0	12
31674	2020-02-16 10:23:27	2020-02-16	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	12469	delivery	5	27
31675	2020-02-16 10:23:32	2020-02-16	17	[{"id_menu":4,"count":1}]	12500	delivery	5	22
31676	2020-02-16 10:33:33	2020-02-16	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4160	delivery	5	34
31677	2020-02-16 10:42:26	2020-02-16	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3934	delivery	5	48
31678	2020-02-16 10:52:07	2020-02-16	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	5873	delivery	5	26
31679	2020-02-16 10:53:22	2020-02-16	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1832	delivery	5	36
31680	2020-02-16 10:55:13	2020-02-16	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5928	delivery	5	31
31681	2020-02-16 10:56:45	2020-02-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	8511	delivery	5	31
31682	2020-02-16 10:56:47	2020-02-16	12	[{"id_menu":3,"count":1}]	12466	pick-up	0	12
31683	2020-02-16 11:07:34	2020-02-16	9	[{"id_menu":7,"count":1}]	11146	pick-up	0	9
31684	2020-02-16 11:07:38	2020-02-16	9	[{"id_menu":7,"count":1}]	12460	delivery	5	14
31685	2020-02-16 11:09:23	2020-02-16	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3558	delivery	5	34
31686	2020-02-16 11:15:12	2020-02-16	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	10905	delivery	5	39
31687	2020-02-16 11:17:39	2020-02-16	14	[{"id_menu":2,"count":1}]	2415	pick-up	0	14
31688	2020-02-16 11:18:05	2020-02-16	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12480	delivery	5	54
31689	2020-02-16 11:21:06	2020-02-16	14	[{"id_menu":2,"count":2}]	10281	pick-up	0	14
31690	2020-02-16 11:25:21	2020-02-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	3870	pick-up	0	21
31691	2020-02-16 11:25:37	2020-02-16	9	[{"id_menu":7,"count":1}]	12519	delivery	5	14
31692	2020-02-16 11:28:05	2020-02-16	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2615	delivery	5	40
31693	2020-02-16 11:44:17	2020-02-16	9	[{"id_menu":6,"count":1}]	10436	delivery	5	14
31694	2020-02-16 11:53:43	2020-02-16	17	[{"id_menu":4,"count":1}]	2151	pick-up	0	17
31695	2020-02-16 11:56:18	2020-02-16	14	[{"id_menu":2,"count":1}]	12439	delivery	5	19
31696	2020-02-16 11:59:14	2020-02-16	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	12435	delivery	5	30
31697	2020-02-16 12:01:33	2020-02-16	9	[{"id_menu":6,"count":1}]	12440	delivery	5	14
31698	2020-02-16 12:01:58	2020-02-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	6364	pick-up	0	21
31699	2020-02-16 12:04:54	2020-02-16	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	12516	delivery	5	27
31700	2020-02-16 12:09:46	2020-02-16	9	[{"id_menu":6,"count":1}]	10136	delivery	5	14
31701	2020-02-16 12:11:34	2020-02-16	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	10394	pick-up	0	22
31702	2020-02-16 12:24:18	2020-02-16	14	[{"id_menu":2,"count":1}]	3113	delivery	5	19
31703	2020-02-16 12:25:44	2020-02-16	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	12482	delivery	5	26
31704	2020-02-16 12:27:10	2020-02-16	9	[{"id_menu":6,"count":1}]	12438	delivery	5	14
31705	2020-02-16 12:30:30	2020-02-16	8	[{"id_menu":5,"count":1}]	12486	pick-up	0	8
31706	2020-02-16 12:31:40	2020-02-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10427	delivery	5	31
31707	2020-02-16 12:39:59	2020-02-16	12	[{"id_menu":3,"count":1}]	12471	delivery	5	17
31708	2020-02-16 12:45:22	2020-02-16	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6981	delivery	5	30
31709	2020-02-16 12:47:53	2020-02-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9043	pick-up	0	26
31710	2020-02-16 12:49:53	2020-02-16	12	[{"id_menu":3,"count":1}]	3609	pick-up	0	12
31711	2020-02-16 12:51:07	2020-02-16	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8341	pick-up	0	30
31712	2020-02-16 12:51:38	2020-02-16	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	12530	delivery	5	42
31713	2020-02-16 12:59:14	2020-02-16	9	[{"id_menu":6,"count":1}]	7007	delivery	5	14
31714	2020-02-16 13:02:30	2020-02-16	9	[{"id_menu":7,"count":1}]	2965	delivery	5	14
31715	2020-02-16 13:04:01	2020-02-16	9	[{"id_menu":6,"count":2}]	12514	pick-up	0	9
31716	2020-02-16 13:04:45	2020-02-16	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11928	delivery	5	31
31717	2020-02-16 13:10:20	2020-02-16	9	[{"id_menu":6,"count":1}]	5117	delivery	5	14
31718	2020-02-16 13:11:35	2020-02-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11766	pick-up	0	26
31719	2020-02-16 13:12:39	2020-02-16	8	[{"id_menu":5,"count":1}]	3489	delivery	5	13
31720	2020-02-16 13:15:50	2020-02-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12492	delivery	5	23
31721	2020-02-16 13:26:40	2020-02-16	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9195	delivery	5	22
31722	2020-02-16 13:29:46	2020-02-16	12	[{"id_menu":1,"count":1}]	11334	pick-up	0	12
31723	2020-02-16 13:30:28	2020-02-16	14	[{"id_menu":2,"count":2}]	12458	delivery	5	19
31724	2020-02-16 13:35:32	2020-02-16	9	[{"id_menu":6,"count":1}]	12489	delivery	5	14
31725	2020-02-16 13:47:58	2020-02-16	12	[{"id_menu":1,"count":1}]	3858	pick-up	0	12
31726	2020-02-16 13:49:16	2020-02-16	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2431	pick-up	0	31
31727	2020-02-16 13:51:11	2020-02-16	14	[{"id_menu":2,"count":1}]	71	delivery	5	19
31728	2020-02-16 13:54:39	2020-02-16	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4914	delivery	5	48
31729	2020-02-16 13:58:50	2020-02-16	12	[{"id_menu":3,"count":1}]	5536	pick-up	0	12
31730	2020-02-16 14:04:29	2020-02-16	12	[{"id_menu":1,"count":1}]	9284	delivery	5	17
31731	2020-02-16 14:05:09	2020-02-16	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":2}]	12457	delivery	5	31
31732	2020-02-16 14:10:30	2020-02-16	12	[{"id_menu":3,"count":1}]	3066	pick-up	0	12
31733	2020-02-16 14:10:39	2020-02-16	8	[{"id_menu":5,"count":1}]	1266	pick-up	0	8
31734	2020-02-16 14:11:53	2020-02-16	12	[{"id_menu":1,"count":1}]	10448	delivery	5	17
31735	2020-02-16 14:13:41	2020-02-16	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8032	delivery	5	36
31736	2020-02-16 14:30:39	2020-02-16	8	[{"id_menu":5,"count":1}]	8328	delivery	5	13
31737	2020-02-16 14:35:26	2020-02-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	10073	pick-up	0	23
31738	2020-02-16 14:38:00	2020-02-16	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4592	delivery	5	48
31739	2020-02-16 14:46:09	2020-02-16	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1352	pick-up	0	29
31740	2020-02-16 14:47:30	2020-02-16	9	[{"id_menu":6,"count":1}]	12529	delivery	5	14
31741	2020-02-16 14:55:43	2020-02-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12454	delivery	5	23
31742	2020-02-16 14:56:34	2020-02-16	17	[{"id_menu":4,"count":1}]	12476	delivery	5	22
31743	2020-02-16 15:08:35	2020-02-16	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	12450	delivery	5	26
31744	2020-02-16 15:22:55	2020-02-16	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2332	delivery	5	40
31745	2020-02-16 15:23:18	2020-02-16	12	[{"id_menu":3,"count":1}]	2676	pick-up	0	12
31746	2020-02-16 15:23:30	2020-02-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	5194	pick-up	0	21
31747	2020-02-16 15:23:48	2020-02-16	17	[{"id_menu":4,"count":1}]	10151	pick-up	0	17
31748	2020-02-16 15:24:33	2020-02-16	9	[{"id_menu":6,"count":1}]	8323	pick-up	0	9
31749	2020-02-16 15:28:33	2020-02-16	12	[{"id_menu":3,"count":1}]	6711	pick-up	0	12
31750	2020-02-16 15:29:16	2020-02-16	9	[{"id_menu":7,"count":1}]	9125	pick-up	0	9
31751	2020-02-16 15:29:30	2020-02-16	9	[{"id_menu":6,"count":1}]	5065	delivery	5	14
31752	2020-02-16 15:44:52	2020-02-16	17	[{"id_menu":4,"count":1}]	2891	pick-up	0	17
31753	2020-02-16 15:45:33	2020-02-16	17	[{"id_menu":4,"count":1}]	7899	delivery	5	22
31754	2020-02-16 15:49:36	2020-02-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	12505	delivery	5	28
31755	2020-02-16 15:49:42	2020-02-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	12522	delivery	5	26
31756	2020-02-16 15:52:57	2020-02-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1283	delivery	5	31
31757	2020-02-16 15:55:37	2020-02-16	8	[{"id_menu":5,"count":2}]	12184	pick-up	0	8
31758	2020-02-16 15:57:56	2020-02-16	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11605	delivery	5	39
31759	2020-02-16 15:58:51	2020-02-16	9	[{"id_menu":6,"count":1}]	6658	pick-up	0	9
31760	2020-02-16 16:16:47	2020-02-16	9	[{"id_menu":6,"count":1}]	11002	delivery	5	14
31761	2020-02-16 16:18:26	2020-02-16	17	[{"id_menu":4,"count":1}]	11751	pick-up	0	17
31762	2020-02-16 16:20:51	2020-02-16	14	[{"id_menu":2,"count":1}]	3320	pick-up	0	14
31763	2020-02-16 16:28:07	2020-02-16	14	[{"id_menu":2,"count":1}]	5730	delivery	5	19
31764	2020-02-16 16:28:15	2020-02-16	12	[{"id_menu":3,"count":1}]	12490	delivery	5	17
31765	2020-02-16 16:30:15	2020-02-16	12	[{"id_menu":1,"count":1}]	2987	delivery	5	17
31766	2020-02-16 16:32:28	2020-02-16	12	[{"id_menu":1,"count":1}]	2358	delivery	5	17
31767	2020-02-16 16:34:17	2020-02-16	17	[{"id_menu":4,"count":1}]	3314	delivery	5	22
31768	2020-02-16 16:35:23	2020-02-16	12	[{"id_menu":1,"count":1}]	4068	delivery	5	17
31769	2020-02-16 16:35:40	2020-02-16	12	[{"id_menu":1,"count":1}]	12179	delivery	5	17
31770	2020-02-16 16:36:58	2020-02-16	17	[{"id_menu":4,"count":1}]	10622	delivery	5	22
31771	2020-02-16 16:42:47	2020-02-16	14	[{"id_menu":2,"count":1}]	12498	delivery	5	19
31772	2020-02-16 16:43:57	2020-02-16	17	[{"id_menu":4,"count":1}]	12506	delivery	5	22
31773	2020-02-16 16:50:32	2020-02-16	12	[{"id_menu":3,"count":1}]	7150	pick-up	0	12
31774	2020-02-16 16:55:44	2020-02-16	17	[{"id_menu":4,"count":1}]	11230	delivery	5	22
31775	2020-02-16 16:58:50	2020-02-16	17	[{"id_menu":4,"count":1}]	12501	delivery	5	22
31776	2020-02-16 17:01:16	2020-02-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7854	pick-up	0	23
31777	2020-02-16 17:01:34	2020-02-16	14	[{"id_menu":2,"count":1}]	12472	pick-up	0	14
31778	2020-02-16 17:02:44	2020-02-16	14	[{"id_menu":2,"count":1}]	1616	pick-up	0	14
31779	2020-02-16 17:03:26	2020-02-16	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	3532	pick-up	0	21
31780	2020-02-16 17:13:36	2020-02-16	17	[{"id_menu":4,"count":1}]	7913	delivery	5	22
31781	2020-02-16 17:14:16	2020-02-16	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	12456	delivery	5	27
31782	2020-02-16 17:16:11	2020-02-16	14	[{"id_menu":2,"count":1}]	11713	delivery	5	19
31783	2020-02-16 17:24:27	2020-02-16	9	[{"id_menu":6,"count":1}]	1800	delivery	5	14
31784	2020-02-16 17:26:23	2020-02-16	8	[{"id_menu":5,"count":1}]	8654	delivery	5	13
31785	2020-02-16 17:30:19	2020-02-16	14	[{"id_menu":2,"count":1}]	12533	pick-up	0	14
31786	2020-02-16 17:36:28	2020-02-16	12	[{"id_menu":3,"count":1}]	12210	pick-up	0	12
31787	2020-02-16 17:39:36	2020-02-16	30	[{"id_menu":1,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7660	delivery	5	35
31788	2020-02-16 17:41:50	2020-02-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1296	pick-up	0	26
31789	2020-02-16 17:44:12	2020-02-16	14	[{"id_menu":2,"count":1}]	11795	pick-up	0	14
31790	2020-02-16 17:46:38	2020-02-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	6457	delivery	5	26
31791	2020-02-16 17:50:36	2020-02-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	5391	delivery	5	26
31792	2020-02-16 17:51:27	2020-02-16	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	2736	pick-up	0	24
31793	2020-02-16 17:53:43	2020-02-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12448	delivery	5	23
31794	2020-02-16 17:57:42	2020-02-16	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2699	pick-up	0	40
31795	2020-02-16 17:58:42	2020-02-16	17	[{"id_menu":4,"count":1}]	8900	delivery	5	22
31796	2020-02-16 18:04:18	2020-02-16	14	[{"id_menu":2,"count":1}]	12493	pick-up	0	14
31797	2020-02-16 18:06:55	2020-02-16	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	12468	delivery	5	40
31798	2020-02-16 18:16:13	2020-02-16	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12517	delivery	5	39
31799	2020-02-16 18:20:52	2020-02-16	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7870	delivery	5	36
31800	2020-02-16 18:22:16	2020-02-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	11709	delivery	5	28
31801	2020-02-16 18:24:19	2020-02-16	12	[{"id_menu":1,"count":1}]	2813	pick-up	0	12
31802	2020-02-16 18:25:29	2020-02-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	11096	delivery	5	26
31803	2020-02-16 18:25:38	2020-02-16	9	[{"id_menu":7,"count":1}]	7313	delivery	5	14
31804	2020-02-16 18:26:28	2020-02-16	8	[{"id_menu":5,"count":1}]	6437	delivery	5	13
31805	2020-02-16 18:27:31	2020-02-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2783	pick-up	0	26
31806	2020-02-16 18:45:04	2020-02-16	14	[{"id_menu":2,"count":1}]	2311	delivery	5	19
31807	2020-02-16 18:47:25	2020-02-16	9	[{"id_menu":6,"count":1}]	12359	delivery	5	14
31808	2020-02-16 18:50:11	2020-02-16	17	[{"id_menu":4,"count":1}]	12525	pick-up	0	17
31809	2020-02-16 18:52:16	2020-02-16	17	[{"id_menu":4,"count":1}]	12491	delivery	5	22
31810	2020-02-16 18:57:01	2020-02-16	17	[{"id_menu":4,"count":1}]	8363	pick-up	0	17
31811	2020-02-16 18:58:47	2020-02-16	9	[{"id_menu":7,"count":1}]	11494	delivery	5	14
31812	2020-02-16 18:59:27	2020-02-16	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	6496	delivery	5	26
31813	2020-02-16 19:05:30	2020-02-16	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	3502	delivery	5	43
31814	2020-02-16 19:11:49	2020-02-16	17	[{"id_menu":4,"count":1}]	12461	delivery	5	22
31815	2020-02-16 19:14:03	2020-02-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10533	delivery	5	22
31816	2020-02-16 19:14:32	2020-02-16	9	[{"id_menu":6,"count":1}]	12447	delivery	5	14
31817	2020-02-16 19:26:51	2020-02-16	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1889	pick-up	0	21
31818	2020-02-16 19:28:49	2020-02-16	55	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	9977	pick-up	0	55
31819	2020-02-16 19:29:13	2020-02-16	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1468	delivery	5	26
31820	2020-02-16 19:34:49	2020-02-16	8	[{"id_menu":5,"count":1}]	12484	pick-up	0	8
31821	2020-02-16 19:38:06	2020-02-16	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	9164	delivery	5	36
31822	2020-02-16 19:45:02	2020-02-16	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	12521	delivery	5	25
31823	2020-02-16 19:46:35	2020-02-16	12	[{"id_menu":3,"count":1}]	8212	delivery	5	17
31824	2020-02-16 19:47:21	2020-02-16	9	[{"id_menu":7,"count":1}]	12513	delivery	5	14
31825	2020-02-16 19:59:23	2020-02-16	8	[{"id_menu":5,"count":1}]	12527	delivery	5	13
31826	2020-02-16 19:59:26	2020-02-16	14	[{"id_menu":2,"count":1}]	5413	pick-up	0	14
31827	2020-02-16 20:01:55	2020-02-16	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	4953	delivery	5	39
31828	2020-02-16 20:02:54	2020-02-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12496	delivery	5	31
31829	2020-02-16 20:03:40	2020-02-16	14	[{"id_menu":2,"count":2}]	3527	delivery	5	19
31830	2020-02-16 20:14:04	2020-02-16	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	5331	delivery	5	42
31831	2020-02-16 20:18:11	2020-02-16	9	[{"id_menu":7,"count":2}]	5758	pick-up	0	9
31832	2020-02-16 20:21:49	2020-02-16	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	6350	delivery	5	31
31833	2020-02-16 20:30:02	2020-02-16	9	[{"id_menu":7,"count":3}]	9039	delivery	5	14
31834	2020-02-16 20:30:31	2020-02-16	14	[{"id_menu":2,"count":1}]	12504	delivery	5	19
31835	2020-02-16 20:33:02	2020-02-16	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10488	delivery	5	57
31836	2020-02-16 20:35:45	2020-02-16	12	[{"id_menu":3,"count":1}]	399	pick-up	0	12
31837	2020-02-16 20:40:41	2020-02-16	14	[{"id_menu":2,"count":1}]	12431	pick-up	0	14
31838	2020-02-16 20:46:50	2020-02-16	9	[{"id_menu":7,"count":1}]	6809	delivery	5	14
31839	2020-02-16 20:47:24	2020-02-16	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10356	delivery	5	22
31840	2020-02-16 20:47:39	2020-02-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8386	delivery	5	31
31841	2020-02-16 20:49:16	2020-02-16	9	[{"id_menu":6,"count":1}]	790	pick-up	0	9
31842	2020-02-16 20:57:24	2020-02-16	14	[{"id_menu":2,"count":1}]	1239	pick-up	0	14
31843	2020-02-16 21:02:10	2020-02-16	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10354	delivery	5	43
31844	2020-02-16 21:02:13	2020-02-16	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	1044	pick-up	0	22
31845	2020-02-16 21:02:44	2020-02-16	9	[{"id_menu":7,"count":1}]	6247	pick-up	0	9
31846	2020-02-16 21:06:32	2020-02-16	9	[{"id_menu":6,"count":1}]	3028	delivery	5	14
31847	2020-02-16 21:06:43	2020-02-16	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	12524	delivery	5	42
31848	2020-02-16 21:10:23	2020-02-16	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	12526	pick-up	0	21
31849	2020-02-16 21:10:29	2020-02-16	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	12511	delivery	5	31
31850	2020-02-16 21:16:18	2020-02-16	8	[{"id_menu":5,"count":1}]	3863	delivery	5	13
31851	2020-02-16 21:16:54	2020-02-16	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	601	delivery	5	25
31852	2020-02-16 21:18:41	2020-02-16	9	[{"id_menu":6,"count":1}]	12434	delivery	5	14
31853	2020-02-16 21:30:54	2020-02-16	17	[{"id_menu":4,"count":1}]	12487	delivery	5	22
31854	2020-02-16 21:33:37	2020-02-16	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3634	pick-up	0	43
31855	2020-02-16 21:35:13	2020-02-16	14	[{"id_menu":2,"count":1}]	12020	delivery	5	19
31856	2020-02-16 21:39:17	2020-02-16	12	[{"id_menu":1,"count":1}]	1287	pick-up	0	12
31857	2020-02-16 21:45:06	2020-02-16	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	7197	delivery	5	22
31858	2020-02-16 21:45:25	2020-02-16	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2731	delivery	5	31
31859	2020-02-16 21:50:17	2020-02-16	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12515	delivery	5	36
31860	2020-02-16 21:58:01	2020-02-16	9	[{"id_menu":6,"count":1}]	8010	delivery	5	14
31861	2020-02-16 22:06:05	2020-02-16	9	[{"id_menu":7,"count":1}]	8799	delivery	5	14
31862	2020-02-16 22:07:16	2020-02-16	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	9955	delivery	5	26
31863	2020-02-16 22:09:42	2020-02-16	14	[{"id_menu":2,"count":1}]	171	delivery	5	19
31864	2020-02-16 22:11:39	2020-02-16	8	[{"id_menu":5,"count":1}]	1979	pick-up	0	8
31865	2020-02-16 22:22:16	2020-02-16	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	12465	pick-up	0	21
31866	2020-02-16 22:23:23	2020-02-16	9	[{"id_menu":7,"count":1}]	527	delivery	5	14
31867	2020-02-16 22:43:19	2020-02-16	14	[{"id_menu":2,"count":1}]	12474	delivery	5	19
31868	2020-02-16 22:49:30	2020-02-16	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2116	delivery	5	36
31869	2020-02-16 22:52:26	2020-02-16	9	[{"id_menu":7,"count":1}]	12497	delivery	5	14
31870	2020-02-16 22:53:45	2020-02-16	9	[{"id_menu":6,"count":1}]	4869	delivery	5	14
31871	2020-02-16 22:59:16	2020-02-16	9	[{"id_menu":7,"count":1}]	204	delivery	5	14
31872	2020-02-16 23:00:17	2020-02-16	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8653	delivery	5	45
31873	2020-02-16 23:17:18	2020-02-16	17	[{"id_menu":4,"count":1}]	12432	delivery	5	22
31874	2020-02-16 23:20:57	2020-02-16	8	[{"id_menu":5,"count":1}]	6633	delivery	5	13
31875	2020-02-16 23:22:29	2020-02-16	9	[{"id_menu":6,"count":1}]	12194	delivery	5	14
31876	2020-02-16 23:23:31	2020-02-16	14	[{"id_menu":2,"count":1}]	2870	delivery	5	19
31877	2020-02-16 23:24:14	2020-02-16	12	[{"id_menu":3,"count":3}]	12494	delivery	5	17
31878	2020-02-16 23:26:14	2020-02-16	8	[{"id_menu":5,"count":1}]	2277	pick-up	0	8
31879	2020-02-16 23:28:09	2020-02-16	14	[{"id_menu":2,"count":1}]	3980	delivery	5	19
31880	2020-02-16 23:34:25	2020-02-16	9	[{"id_menu":7,"count":1}]	7641	delivery	5	14
31881	2020-02-16 23:41:13	2020-02-16	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	654	delivery	5	57
31882	2020-02-16 23:42:44	2020-02-16	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12453	delivery	5	35
31883	2020-02-16 23:47:33	2020-02-16	12	[{"id_menu":3,"count":1}]	12462	delivery	5	17
31884	2020-02-16 23:53:46	2020-02-16	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11237	delivery	5	43
31885	2020-02-16 23:55:11	2020-02-16	17	[{"id_menu":4,"count":1}]	701	delivery	5	22
31886	2020-02-17 00:05:22	2020-02-17	14	[{"id_menu":2,"count":1}]	1375	pick-up	0	14
31887	2020-02-17 00:17:24	2020-02-17	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1168	delivery	5	26
31888	2020-02-17 00:31:53	2020-02-17	9	[{"id_menu":6,"count":1}]	6366	delivery	5	14
31889	2020-02-17 00:32:50	2020-02-17	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12576	delivery	5	36
31890	2020-02-17 00:34:08	2020-02-17	14	[{"id_menu":2,"count":1}]	12631	delivery	5	19
31891	2020-02-17 00:37:41	2020-02-17	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2215	delivery	5	40
31892	2020-02-17 00:40:00	2020-02-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	821	pick-up	0	26
31893	2020-02-17 00:58:55	2020-02-17	9	[{"id_menu":7,"count":1}]	4931	delivery	5	14
31894	2020-02-17 01:12:48	2020-02-17	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	12620	delivery	5	39
31895	2020-02-17 01:25:40	2020-02-17	12	[{"id_menu":1,"count":1}]	12626	delivery	5	17
31896	2020-02-17 01:30:17	2020-02-17	9	[{"id_menu":6,"count":1}]	1170	pick-up	0	9
31897	2020-02-17 01:50:39	2020-02-17	9	[{"id_menu":6,"count":1}]	6996	pick-up	0	9
31898	2020-02-17 02:08:21	2020-02-17	9	[{"id_menu":7,"count":1}]	10323	delivery	5	14
31899	2020-02-17 02:08:38	2020-02-17	14	[{"id_menu":2,"count":1}]	1693	pick-up	0	14
31900	2020-02-17 02:28:17	2020-02-17	9	[{"id_menu":6,"count":1}]	5178	delivery	5	14
31901	2020-02-17 02:33:30	2020-02-17	12	[{"id_menu":3,"count":1}]	12588	delivery	5	17
31902	2020-02-17 02:34:40	2020-02-17	9	[{"id_menu":6,"count":1}]	2855	delivery	5	14
31903	2020-02-17 02:39:55	2020-02-17	8	[{"id_menu":5,"count":1}]	286	delivery	5	13
31904	2020-02-17 02:43:18	2020-02-17	14	[{"id_menu":2,"count":1}]	1122	delivery	5	19
31905	2020-02-17 02:48:44	2020-02-17	17	[{"id_menu":4,"count":3}]	12611	delivery	5	22
31906	2020-02-17 02:52:24	2020-02-17	17	[{"id_menu":4,"count":1}]	3403	pick-up	0	17
31907	2020-02-17 02:57:59	2020-02-17	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	11754	pick-up	0	21
31908	2020-02-17 03:47:54	2020-02-17	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12641	delivery	5	22
31909	2020-02-17 03:54:03	2020-02-17	12	[{"id_menu":3,"count":1}]	5099	delivery	5	17
31910	2020-02-17 04:26:48	2020-02-17	8	[{"id_menu":5,"count":1}]	12551	delivery	5	13
31911	2020-02-17 04:28:32	2020-02-17	9	[{"id_menu":7,"count":1}]	2456	pick-up	0	9
31912	2020-02-17 04:31:59	2020-02-17	8	[{"id_menu":5,"count":1}]	552	pick-up	0	8
31913	2020-02-17 04:37:36	2020-02-17	8	[{"id_menu":5,"count":2}]	12601	delivery	5	13
31914	2020-02-17 04:38:57	2020-02-17	9	[{"id_menu":7,"count":1}]	12592	delivery	5	14
31915	2020-02-17 04:45:00	2020-02-17	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	9539	delivery	5	26
31916	2020-02-17 04:53:45	2020-02-17	14	[{"id_menu":2,"count":1}]	12602	pick-up	0	14
31917	2020-02-17 05:15:12	2020-02-17	17	[{"id_menu":4,"count":1}]	12546	delivery	5	22
31918	2020-02-17 05:15:37	2020-02-17	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	12560	delivery	5	36
31919	2020-02-17 05:19:22	2020-02-17	12	[{"id_menu":1,"count":1}]	12548	delivery	5	17
31920	2020-02-17 05:29:21	2020-02-17	9	[{"id_menu":6,"count":1}]	5796	delivery	5	14
31921	2020-02-17 05:32:09	2020-02-17	8	[{"id_menu":5,"count":1}]	11263	delivery	5	13
31922	2020-02-17 05:37:11	2020-02-17	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	123	delivery	5	26
31923	2020-02-17 05:40:19	2020-02-17	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1643	delivery	5	31
31924	2020-02-17 05:42:38	2020-02-17	9	[{"id_menu":7,"count":1}]	2865	delivery	5	14
31925	2020-02-17 05:56:48	2020-02-17	17	[{"id_menu":4,"count":1}]	1424	pick-up	0	17
31926	2020-02-17 06:05:26	2020-02-17	9	[{"id_menu":7,"count":1}]	3961	pick-up	0	9
31927	2020-02-17 06:12:22	2020-02-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12582	delivery	5	31
31928	2020-02-17 06:19:12	2020-02-17	14	[{"id_menu":2,"count":1}]	1778	pick-up	0	14
31929	2020-02-17 06:21:45	2020-02-17	9	[{"id_menu":7,"count":2}]	12647	delivery	5	14
31930	2020-02-17 06:22:49	2020-02-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2445	pick-up	0	18
31931	2020-02-17 06:26:55	2020-02-17	12	[{"id_menu":3,"count":1}]	1684	pick-up	0	12
31932	2020-02-17 06:28:53	2020-02-17	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3356	pick-up	0	31
31933	2020-02-17 06:37:06	2020-02-17	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7741	pick-up	0	31
31934	2020-02-17 06:58:53	2020-02-17	8	[{"id_menu":5,"count":1}]	1093	delivery	5	13
31935	2020-02-17 07:05:19	2020-02-17	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1322	delivery	5	26
31936	2020-02-17 07:25:47	2020-02-17	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1657	pick-up	0	21
31937	2020-02-17 07:28:15	2020-02-17	17	[{"id_menu":4,"count":1}]	12054	pick-up	0	17
31938	2020-02-17 08:01:45	2020-02-17	12	[{"id_menu":3,"count":1}]	2228	pick-up	0	12
31939	2020-02-17 08:21:19	2020-02-17	8	[{"id_menu":5,"count":1}]	3536	pick-up	0	8
31940	2020-02-17 08:27:08	2020-02-17	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	11612	delivery	5	30
31941	2020-02-17 08:31:09	2020-02-17	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3337	delivery	5	40
31942	2020-02-17 08:37:39	2020-02-17	9	[{"id_menu":7,"count":1}]	11491	pick-up	0	9
31943	2020-02-17 08:38:12	2020-02-17	9	[{"id_menu":6,"count":1}]	1107	pick-up	0	9
31944	2020-02-17 08:47:12	2020-02-17	12	[{"id_menu":3,"count":1}]	11401	pick-up	0	12
31945	2020-02-17 08:51:09	2020-02-17	12	[{"id_menu":3,"count":1}]	6644	delivery	5	17
31946	2020-02-17 08:58:13	2020-02-17	17	[{"id_menu":4,"count":1}]	12606	delivery	5	22
31947	2020-02-17 09:09:38	2020-02-17	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	12599	delivery	5	31
31948	2020-02-17 09:12:09	2020-02-17	12	[{"id_menu":3,"count":1}]	3657	pick-up	0	12
31949	2020-02-17 09:24:50	2020-02-17	14	[{"id_menu":2,"count":1}]	721	pick-up	0	14
31950	2020-02-17 09:25:33	2020-02-17	14	[{"id_menu":2,"count":1}]	12541	pick-up	0	14
31951	2020-02-17 09:30:13	2020-02-17	17	[{"id_menu":4,"count":1}]	763	delivery	5	22
31952	2020-02-17 09:33:24	2020-02-17	17	[{"id_menu":4,"count":1}]	12549	delivery	5	22
31953	2020-02-17 09:46:15	2020-02-17	12	[{"id_menu":1,"count":1}]	12552	pick-up	0	12
31954	2020-02-17 09:54:10	2020-02-17	12	[{"id_menu":1,"count":1}]	7165	delivery	5	17
31955	2020-02-17 09:55:53	2020-02-17	9	[{"id_menu":7,"count":1}]	12584	delivery	5	14
31956	2020-02-17 10:07:09	2020-02-17	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6144	delivery	5	35
31957	2020-02-17 10:10:36	2020-02-17	12	[{"id_menu":3,"count":1}]	7556	pick-up	0	12
31958	2020-02-17 10:26:41	2020-02-17	17	[{"id_menu":4,"count":1}]	2868	delivery	5	22
31959	2020-02-17 10:32:45	2020-02-17	14	[{"id_menu":2,"count":1}]	12591	delivery	5	19
31960	2020-02-17 10:33:22	2020-02-17	9	[{"id_menu":6,"count":1}]	12570	delivery	5	14
31961	2020-02-17 10:33:35	2020-02-17	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	7163	delivery	5	37
31962	2020-02-17 10:36:17	2020-02-17	14	[{"id_menu":2,"count":1}]	5968	delivery	5	19
31963	2020-02-17 11:03:19	2020-02-17	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	12645	delivery	5	52
31964	2020-02-17 11:03:26	2020-02-17	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	12545	delivery	5	25
31965	2020-02-17 11:04:12	2020-02-17	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	11771	delivery	5	31
31966	2020-02-17 11:05:15	2020-02-17	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":3}]	11331	delivery	5	22
31967	2020-02-17 11:14:46	2020-02-17	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	527	pick-up	0	31
31968	2020-02-17 11:17:11	2020-02-17	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2314	pick-up	0	31
31969	2020-02-17 11:20:53	2020-02-17	9	[{"id_menu":6,"count":1}]	12632	delivery	5	14
31970	2020-02-17 11:33:58	2020-02-17	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12536	delivery	5	22
31971	2020-02-17 11:41:27	2020-02-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	8435	delivery	5	31
31972	2020-02-17 11:50:32	2020-02-17	9	[{"id_menu":6,"count":2}]	7159	delivery	5	14
31973	2020-02-17 11:51:54	2020-02-17	12	[{"id_menu":1,"count":1}]	10740	delivery	5	17
31974	2020-02-17 12:03:00	2020-02-17	8	[{"id_menu":5,"count":1}]	8234	delivery	5	13
31975	2020-02-17 12:16:07	2020-02-17	17	[{"id_menu":4,"count":1}]	5169	pick-up	0	17
31976	2020-02-17 12:16:32	2020-02-17	14	[{"id_menu":2,"count":1}]	1095	delivery	5	19
31977	2020-02-17 12:21:17	2020-02-17	8	[{"id_menu":5,"count":1}]	8848	delivery	5	13
31978	2020-02-17 12:21:59	2020-02-17	9	[{"id_menu":7,"count":1}]	3857	pick-up	0	9
31979	2020-02-17 12:23:09	2020-02-17	14	[{"id_menu":2,"count":1}]	3293	delivery	5	19
31980	2020-02-17 12:31:09	2020-02-17	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	12608	delivery	5	48
31981	2020-02-17 12:35:01	2020-02-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6396	pick-up	0	18
31982	2020-02-17 12:46:34	2020-02-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6790	pick-up	0	26
31983	2020-02-17 12:49:24	2020-02-17	9	[{"id_menu":6,"count":1}]	2916	pick-up	0	9
31984	2020-02-17 12:50:06	2020-02-17	8	[{"id_menu":5,"count":2}]	12615	delivery	5	13
31985	2020-02-17 12:50:23	2020-02-17	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3840	pick-up	0	35
31986	2020-02-17 13:07:37	2020-02-17	8	[{"id_menu":5,"count":1}]	9969	pick-up	0	8
31987	2020-02-17 13:09:08	2020-02-17	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	8856	delivery	5	26
31988	2020-02-17 13:18:47	2020-02-17	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12204	delivery	5	43
31989	2020-02-17 13:19:37	2020-02-17	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	12644	delivery	5	26
31990	2020-02-17 13:22:12	2020-02-17	9	[{"id_menu":7,"count":1}]	3695	delivery	5	14
31991	2020-02-17 13:40:21	2020-02-17	9	[{"id_menu":7,"count":1}]	12542	delivery	5	14
31992	2020-02-17 14:02:32	2020-02-17	9	[{"id_menu":7,"count":1}]	6953	delivery	5	14
31993	2020-02-17 14:11:57	2020-02-17	14	[{"id_menu":2,"count":1}]	12564	delivery	5	19
31994	2020-02-17 14:15:12	2020-02-17	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7109	delivery	5	53
31995	2020-02-17 14:18:15	2020-02-17	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2717	delivery	5	34
31996	2020-02-17 14:18:22	2020-02-17	8	[{"id_menu":5,"count":1}]	12610	delivery	5	13
31997	2020-02-17 14:35:20	2020-02-17	12	[{"id_menu":3,"count":1}]	12569	delivery	5	17
31998	2020-02-17 14:43:08	2020-02-17	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9513	delivery	5	22
31999	2020-02-17 14:53:58	2020-02-17	14	[{"id_menu":2,"count":1}]	12633	delivery	5	19
32000	2020-02-17 15:06:15	2020-02-17	8	[{"id_menu":5,"count":1}]	12558	pick-up	0	8
32001	2020-02-17 15:06:27	2020-02-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2523	delivery	5	28
32002	2020-02-17 15:22:36	2020-02-17	8	[{"id_menu":5,"count":1}]	12642	delivery	5	13
32003	2020-02-17 15:32:52	2020-02-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7514	delivery	5	28
32004	2020-02-17 15:43:08	2020-02-17	8	[{"id_menu":5,"count":1}]	12575	pick-up	0	8
32005	2020-02-17 15:47:20	2020-02-17	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12617	delivery	5	35
32006	2020-02-17 16:01:54	2020-02-17	14	[{"id_menu":2,"count":1}]	7928	delivery	5	19
32007	2020-02-17 16:15:39	2020-02-17	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12585	pick-up	0	38
32008	2020-02-17 16:28:11	2020-02-17	17	[{"id_menu":4,"count":1}]	5701	pick-up	0	17
32009	2020-02-17 16:28:56	2020-02-17	12	[{"id_menu":1,"count":1}]	3998	delivery	5	17
32010	2020-02-17 16:30:16	2020-02-17	12	[{"id_menu":3,"count":1}]	12590	delivery	5	17
32011	2020-02-17 16:41:47	2020-02-17	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10287	pick-up	0	29
32012	2020-02-17 16:48:01	2020-02-17	14	[{"id_menu":2,"count":1}]	2659	pick-up	0	14
32013	2020-02-17 16:55:35	2020-02-17	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2125	delivery	5	30
32014	2020-02-17 17:17:10	2020-02-17	14	[{"id_menu":2,"count":1}]	12578	pick-up	0	14
32015	2020-02-17 17:17:37	2020-02-17	9	[{"id_menu":7,"count":1}]	12565	delivery	5	14
32016	2020-02-17 17:17:48	2020-02-17	9	[{"id_menu":6,"count":1}]	12623	pick-up	0	9
32017	2020-02-17 17:17:52	2020-02-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	158	pick-up	0	23
32018	2020-02-17 17:31:26	2020-02-17	12	[{"id_menu":1,"count":1}]	2413	pick-up	0	12
32019	2020-02-17 17:57:47	2020-02-17	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	12643	delivery	5	26
32020	2020-02-17 17:59:55	2020-02-17	9	[{"id_menu":7,"count":1}]	8240	pick-up	0	9
32021	2020-02-17 18:05:55	2020-02-17	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	401	pick-up	0	21
32022	2020-02-17 18:28:37	2020-02-17	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7925	delivery	5	37
32023	2020-02-17 18:34:07	2020-02-17	14	[{"id_menu":2,"count":1}]	12605	delivery	5	19
32024	2020-02-17 18:34:28	2020-02-17	9	[{"id_menu":7,"count":1}]	3281	delivery	5	14
32025	2020-02-17 18:35:22	2020-02-17	17	[{"id_menu":4,"count":1}]	12574	delivery	5	22
32026	2020-02-17 18:37:03	2020-02-17	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	12636	delivery	5	48
32027	2020-02-17 18:59:34	2020-02-17	12	[{"id_menu":3,"count":1}]	3268	pick-up	0	12
32028	2020-02-17 18:59:45	2020-02-17	14	[{"id_menu":2,"count":1}]	1176	pick-up	0	14
32029	2020-02-17 19:02:35	2020-02-17	9	[{"id_menu":6,"count":1}]	11454	delivery	5	14
32030	2020-02-17 19:14:06	2020-02-17	12	[{"id_menu":1,"count":1}]	1155	pick-up	0	12
32031	2020-02-17 19:15:09	2020-02-17	14	[{"id_menu":2,"count":1}]	12593	pick-up	0	14
32032	2020-02-17 19:39:20	2020-02-17	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	12594	delivery	5	29
32033	2020-02-17 19:42:13	2020-02-17	17	[{"id_menu":4,"count":1}]	11191	pick-up	0	17
32034	2020-02-17 19:42:49	2020-02-17	9	[{"id_menu":7,"count":1}]	2552	pick-up	0	9
32035	2020-02-17 19:44:09	2020-02-17	14	[{"id_menu":2,"count":1}]	8811	pick-up	0	14
32036	2020-02-17 19:51:00	2020-02-17	14	[{"id_menu":2,"count":1}]	12637	delivery	5	19
32037	2020-02-17 19:58:21	2020-02-17	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	6201	delivery	5	31
32038	2020-02-17 20:08:41	2020-02-17	12	[{"id_menu":1,"count":2}]	9086	pick-up	0	12
32039	2020-02-17 20:16:21	2020-02-17	12	[{"id_menu":1,"count":1}]	8705	delivery	5	17
32040	2020-02-17 20:16:50	2020-02-17	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2392	delivery	5	48
32041	2020-02-17 20:18:03	2020-02-17	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	9818	delivery	5	44
32042	2020-02-17 20:18:24	2020-02-17	17	[{"id_menu":4,"count":1}]	2095	pick-up	0	17
32043	2020-02-17 20:26:32	2020-02-17	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2651	pick-up	0	22
32044	2020-02-17 20:41:11	2020-02-17	14	[{"id_menu":2,"count":1}]	956	pick-up	0	14
32045	2020-02-17 20:45:43	2020-02-17	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	8884	delivery	5	26
32046	2020-02-17 20:58:27	2020-02-17	8	[{"id_menu":5,"count":1}]	11779	pick-up	0	8
32047	2020-02-17 21:04:17	2020-02-17	12	[{"id_menu":3,"count":1}]	8355	pick-up	0	12
32048	2020-02-17 21:17:38	2020-02-17	17	[{"id_menu":4,"count":1}]	12567	delivery	5	22
32049	2020-02-17 21:18:31	2020-02-17	12	[{"id_menu":3,"count":1}]	5784	delivery	5	17
32050	2020-02-17 21:23:04	2020-02-17	17	[{"id_menu":4,"count":1}]	942	delivery	5	22
32051	2020-02-17 21:27:58	2020-02-17	14	[{"id_menu":2,"count":1}]	10376	delivery	5	19
32052	2020-02-17 21:33:07	2020-02-17	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12628	delivery	5	34
32053	2020-02-17 21:34:38	2020-02-17	17	[{"id_menu":4,"count":1}]	762	pick-up	0	17
32054	2020-02-17 21:35:48	2020-02-17	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11947	delivery	5	43
32055	2020-02-17 21:43:57	2020-02-17	12	[{"id_menu":3,"count":1}]	3751	delivery	5	17
32056	2020-02-17 22:17:52	2020-02-17	9	[{"id_menu":7,"count":1}]	2083	pick-up	0	9
32057	2020-02-17 22:32:15	2020-02-17	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1145	pick-up	0	25
32058	2020-02-17 22:56:54	2020-02-17	12	[{"id_menu":3,"count":1}]	6535	pick-up	0	12
32059	2020-02-17 23:07:11	2020-02-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12596	delivery	5	23
32060	2020-02-17 23:07:51	2020-02-17	14	[{"id_menu":2,"count":1}]	3971	pick-up	0	14
32061	2020-02-17 23:09:38	2020-02-17	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	10755	pick-up	0	31
32062	2020-02-17 23:09:48	2020-02-17	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12597	delivery	5	37
32063	2020-02-17 23:17:07	2020-02-17	9	[{"id_menu":6,"count":1}]	8783	delivery	5	14
32064	2020-02-17 23:21:16	2020-02-17	12	[{"id_menu":1,"count":2}]	5203	pick-up	0	12
32065	2020-02-17 23:24:28	2020-02-17	9	[{"id_menu":7,"count":1}]	1481	pick-up	0	9
32066	2020-02-17 23:41:47	2020-02-17	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":2}]	1627	pick-up	0	25
32067	2020-02-17 23:51:26	2020-02-17	9	[{"id_menu":7,"count":2}]	12555	delivery	5	14
32068	2020-02-17 23:52:29	2020-02-17	12	[{"id_menu":1,"count":1}]	1673	delivery	5	17
32069	2020-02-18 00:17:38	2020-02-18	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	12691	delivery	5	26
32070	2020-02-18 00:18:30	2020-02-18	9	[{"id_menu":7,"count":1}]	7032	pick-up	0	9
32071	2020-02-18 00:21:51	2020-02-18	12	[{"id_menu":3,"count":1}]	1429	pick-up	0	12
32072	2020-02-18 01:07:20	2020-02-18	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	10612	delivery	5	34
32073	2020-02-18 01:12:43	2020-02-18	12	[{"id_menu":3,"count":1}]	12172	delivery	5	17
32074	2020-02-18 01:18:25	2020-02-18	14	[{"id_menu":2,"count":1}]	11760	delivery	5	19
32075	2020-02-18 01:32:14	2020-02-18	14	[{"id_menu":2,"count":1}]	12667	delivery	5	19
32076	2020-02-18 01:35:23	2020-02-18	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	12714	delivery	5	36
32077	2020-02-18 01:36:43	2020-02-18	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	4605	delivery	5	28
32078	2020-02-18 01:47:58	2020-02-18	14	[{"id_menu":2,"count":1}]	5487	delivery	5	19
32079	2020-02-18 01:49:42	2020-02-18	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	12692	delivery	5	27
32080	2020-02-18 01:50:52	2020-02-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	9623	delivery	5	22
32081	2020-02-18 01:58:39	2020-02-18	14	[{"id_menu":2,"count":1}]	5645	delivery	5	19
32082	2020-02-18 01:59:52	2020-02-18	22	[{"id_menu":2,"count":3},{"id_menu":5,"count":1}]	12713	delivery	5	27
32083	2020-02-18 02:03:48	2020-02-18	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10071	delivery	5	45
32084	2020-02-18 02:09:05	2020-02-18	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	7691	pick-up	0	29
32085	2020-02-18 02:26:20	2020-02-18	14	[{"id_menu":2,"count":1}]	1956	pick-up	0	14
32086	2020-02-18 02:34:16	2020-02-18	9	[{"id_menu":7,"count":1}]	12675	pick-up	0	9
32087	2020-02-18 02:40:04	2020-02-18	9	[{"id_menu":6,"count":1}]	8454	pick-up	0	9
32088	2020-02-18 02:47:11	2020-02-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12709	pick-up	0	17
32089	2020-02-18 02:49:23	2020-02-18	12	[{"id_menu":3,"count":1}]	10427	delivery	5	17
32090	2020-02-18 02:50:45	2020-02-18	17	[{"id_menu":4,"count":1}]	12657	delivery	5	22
32091	2020-02-18 03:15:35	2020-02-18	14	[{"id_menu":2,"count":1}]	1054	delivery	5	19
32092	2020-02-18 03:28:51	2020-02-18	9	[{"id_menu":6,"count":2}]	11554	delivery	5	14
32093	2020-02-18 03:32:14	2020-02-18	8	[{"id_menu":5,"count":1}]	12690	pick-up	0	8
32094	2020-02-18 03:32:45	2020-02-18	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	12706	pick-up	0	21
32095	2020-02-18 03:35:04	2020-02-18	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11922	delivery	5	22
32096	2020-02-18 03:41:07	2020-02-18	8	[{"id_menu":5,"count":1}]	7680	delivery	5	13
32097	2020-02-18 03:52:28	2020-02-18	9	[{"id_menu":6,"count":2}]	11220	delivery	5	14
32098	2020-02-18 03:52:33	2020-02-18	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	8152	pick-up	0	31
32099	2020-02-18 04:04:43	2020-02-18	12	[{"id_menu":1,"count":1}]	11969	pick-up	0	12
32100	2020-02-18 04:05:23	2020-02-18	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2604	pick-up	0	26
32101	2020-02-18 04:11:50	2020-02-18	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	10663	delivery	5	34
32102	2020-02-18 04:17:25	2020-02-18	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12730	delivery	5	45
32103	2020-02-18 04:27:53	2020-02-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	12677	delivery	5	23
32104	2020-02-18 04:28:55	2020-02-18	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	12679	delivery	5	22
32105	2020-02-18 04:45:24	2020-02-18	9	[{"id_menu":6,"count":1}]	6429	delivery	5	14
32106	2020-02-18 04:53:35	2020-02-18	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6629	delivery	5	35
32107	2020-02-18 04:54:04	2020-02-18	9	[{"id_menu":6,"count":1}]	6282	pick-up	0	9
32108	2020-02-18 04:59:30	2020-02-18	30	[{"id_menu":3,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12676	delivery	5	35
32109	2020-02-18 05:04:07	2020-02-18	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	12649	delivery	5	28
32110	2020-02-18 05:04:43	2020-02-18	17	[{"id_menu":4,"count":1}]	12735	delivery	5	22
32111	2020-02-18 05:06:47	2020-02-18	17	[{"id_menu":4,"count":1}]	12720	delivery	5	22
32112	2020-02-18 05:18:48	2020-02-18	9	[{"id_menu":7,"count":1}]	1085	pick-up	0	9
32113	2020-02-18 05:20:17	2020-02-18	17	[{"id_menu":4,"count":1}]	822	pick-up	0	17
32114	2020-02-18 05:23:09	2020-02-18	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":2}]	71	pick-up	0	20
32115	2020-02-18 05:24:57	2020-02-18	9	[{"id_menu":6,"count":1}]	12685	delivery	5	14
32116	2020-02-18 05:49:26	2020-02-18	12	[{"id_menu":3,"count":1}]	2713	pick-up	0	12
32117	2020-02-18 06:03:55	2020-02-18	9	[{"id_menu":7,"count":1}]	5386	delivery	5	14
32118	2020-02-18 06:06:52	2020-02-18	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	11826	delivery	5	39
32119	2020-02-18 06:08:08	2020-02-18	12	[{"id_menu":3,"count":1}]	2443	pick-up	0	12
32120	2020-02-18 06:11:15	2020-02-18	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	236	delivery	5	26
32121	2020-02-18 06:17:53	2020-02-18	8	[{"id_menu":5,"count":1}]	12008	delivery	5	13
32122	2020-02-18 06:22:42	2020-02-18	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7918	delivery	5	42
32123	2020-02-18 06:22:50	2020-02-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	12146	delivery	5	28
32124	2020-02-18 06:25:00	2020-02-18	9	[{"id_menu":6,"count":1}]	11186	delivery	5	14
32125	2020-02-18 06:28:44	2020-02-18	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12185	delivery	5	43
32126	2020-02-18 06:31:00	2020-02-18	8	[{"id_menu":5,"count":1}]	2401	pick-up	0	8
32127	2020-02-18 06:32:48	2020-02-18	9	[{"id_menu":6,"count":1}]	12662	delivery	5	14
32128	2020-02-18 06:41:27	2020-02-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7132	delivery	5	28
32129	2020-02-18 06:43:18	2020-02-18	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	12724	delivery	5	40
32130	2020-02-18 07:19:35	2020-02-18	9	[{"id_menu":7,"count":1}]	4573	delivery	5	14
32131	2020-02-18 07:30:04	2020-02-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	12651	delivery	5	28
32132	2020-02-18 07:45:03	2020-02-18	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	3932	delivery	5	26
32133	2020-02-18 07:50:59	2020-02-18	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	6421	delivery	5	31
32134	2020-02-18 07:59:57	2020-02-18	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	840	delivery	5	34
32135	2020-02-18 08:02:39	2020-02-18	17	[{"id_menu":4,"count":1}]	2886	pick-up	0	17
32136	2020-02-18 08:05:01	2020-02-18	8	[{"id_menu":5,"count":1}]	12655	pick-up	0	8
32137	2020-02-18 08:09:51	2020-02-18	12	[{"id_menu":1,"count":1}]	12695	pick-up	0	12
32138	2020-02-18 08:10:04	2020-02-18	14	[{"id_menu":2,"count":1}]	12673	delivery	5	19
32139	2020-02-18 08:14:21	2020-02-18	14	[{"id_menu":2,"count":1}]	10598	pick-up	0	14
32140	2020-02-18 08:21:15	2020-02-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	12661	delivery	5	28
32141	2020-02-18 08:30:49	2020-02-18	9	[{"id_menu":7,"count":1}]	6232	delivery	5	14
32142	2020-02-18 08:44:03	2020-02-18	9	[{"id_menu":6,"count":1}]	5238	pick-up	0	9
32143	2020-02-18 08:59:29	2020-02-18	14	[{"id_menu":2,"count":1}]	12736	delivery	5	19
32144	2020-02-18 09:10:25	2020-02-18	17	[{"id_menu":4,"count":1}]	9869	delivery	5	22
32145	2020-02-18 09:12:15	2020-02-18	9	[{"id_menu":6,"count":1}]	124	pick-up	0	9
32146	2020-02-18 09:15:07	2020-02-18	9	[{"id_menu":7,"count":1}]	2552	pick-up	0	9
32147	2020-02-18 09:21:31	2020-02-18	9	[{"id_menu":7,"count":1}]	6366	delivery	5	14
32148	2020-02-18 09:39:10	2020-02-18	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	10159	delivery	5	31
32149	2020-02-18 09:48:48	2020-02-18	9	[{"id_menu":6,"count":1}]	6691	delivery	5	14
32150	2020-02-18 09:50:48	2020-02-18	12	[{"id_menu":1,"count":1}]	11946	pick-up	0	12
32151	2020-02-18 10:18:16	2020-02-18	9	[{"id_menu":7,"count":1}]	7183	delivery	5	14
32152	2020-02-18 10:26:59	2020-02-18	8	[{"id_menu":5,"count":1}]	2771	pick-up	0	8
32153	2020-02-18 10:29:53	2020-02-18	8	[{"id_menu":5,"count":1}]	11860	delivery	5	13
32154	2020-02-18 10:32:35	2020-02-18	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12725	delivery	5	53
32155	2020-02-18 10:34:16	2020-02-18	17	[{"id_menu":4,"count":1}]	12688	pick-up	0	17
32156	2020-02-18 10:38:24	2020-02-18	9	[{"id_menu":7,"count":1}]	924	pick-up	0	9
32157	2020-02-18 10:39:11	2020-02-18	17	[{"id_menu":4,"count":1}]	12668	delivery	5	22
32158	2020-02-18 10:48:02	2020-02-18	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	8773	delivery	5	26
32159	2020-02-18 10:54:21	2020-02-18	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	12682	pick-up	0	31
32160	2020-02-18 11:01:23	2020-02-18	14	[{"id_menu":2,"count":1}]	12648	pick-up	0	14
32161	2020-02-18 11:04:45	2020-02-18	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	12663	pick-up	0	41
32162	2020-02-18 11:10:16	2020-02-18	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	11065	delivery	5	27
32163	2020-02-18 11:13:31	2020-02-18	9	[{"id_menu":7,"count":1}]	10706	pick-up	0	9
32164	2020-02-18 11:25:25	2020-02-18	12	[{"id_menu":1,"count":1}]	12541	pick-up	0	12
32165	2020-02-18 11:27:30	2020-02-18	17	[{"id_menu":4,"count":1}]	6548	pick-up	0	17
32166	2020-02-18 12:00:53	2020-02-18	8	[{"id_menu":5,"count":1}]	880	delivery	5	13
32167	2020-02-18 12:02:04	2020-02-18	12	[{"id_menu":3,"count":1}]	8543	pick-up	0	12
32168	2020-02-18 12:03:59	2020-02-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	157	delivery	5	28
32169	2020-02-18 12:05:43	2020-02-18	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9077	delivery	5	42
32170	2020-02-18 12:05:57	2020-02-18	9	[{"id_menu":7,"count":1}]	12722	delivery	5	14
32171	2020-02-18 12:07:18	2020-02-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	12710	delivery	5	28
32172	2020-02-18 12:11:22	2020-02-18	17	[{"id_menu":4,"count":1}]	1862	pick-up	0	17
32173	2020-02-18 12:15:33	2020-02-18	9	[{"id_menu":6,"count":1}]	12650	delivery	5	14
32174	2020-02-18 12:25:29	2020-02-18	12	[{"id_menu":1,"count":1}]	359	pick-up	0	12
32175	2020-02-18 12:31:06	2020-02-18	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1712	delivery	5	40
32176	2020-02-18 12:32:04	2020-02-18	9	[{"id_menu":6,"count":1}]	12670	delivery	5	14
32177	2020-02-18 12:33:07	2020-02-18	12	[{"id_menu":3,"count":1}]	10394	delivery	5	17
32178	2020-02-18 12:37:17	2020-02-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	12728	delivery	5	23
32179	2020-02-18 12:47:05	2020-02-18	14	[{"id_menu":2,"count":1}]	2398	pick-up	0	14
32180	2020-02-18 12:49:03	2020-02-18	14	[{"id_menu":2,"count":1}]	5228	pick-up	0	14
32181	2020-02-18 12:59:34	2020-02-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7017	pick-up	0	23
32182	2020-02-18 13:04:13	2020-02-18	17	[{"id_menu":4,"count":1}]	7527	delivery	5	22
32183	2020-02-18 13:20:05	2020-02-18	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7544	delivery	5	31
32184	2020-02-18 13:22:43	2020-02-18	17	[{"id_menu":4,"count":1}]	12693	delivery	5	22
32185	2020-02-18 13:39:13	2020-02-18	17	[{"id_menu":4,"count":1}]	8545	delivery	5	22
32186	2020-02-18 13:42:47	2020-02-18	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2386	delivery	5	40
32187	2020-02-18 13:53:07	2020-02-18	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8651	delivery	5	43
32188	2020-02-18 13:55:35	2020-02-18	12	[{"id_menu":1,"count":1}]	9252	pick-up	0	12
32189	2020-02-18 14:15:58	2020-02-18	9	[{"id_menu":7,"count":1}]	12684	delivery	5	14
32190	2020-02-18 14:25:22	2020-02-18	9	[{"id_menu":6,"count":1}]	12727	delivery	5	14
32191	2020-02-18 14:28:17	2020-02-18	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12700	delivery	5	35
32192	2020-02-18 14:34:33	2020-02-18	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	8375	pick-up	0	21
32193	2020-02-18 14:39:47	2020-02-18	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12607	delivery	5	35
32194	2020-02-18 14:49:18	2020-02-18	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8367	delivery	5	30
32195	2020-02-18 14:51:50	2020-02-18	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	12674	delivery	5	26
32196	2020-02-18 14:52:21	2020-02-18	17	[{"id_menu":4,"count":1}]	12718	pick-up	0	17
32197	2020-02-18 15:03:36	2020-02-18	9	[{"id_menu":7,"count":1}]	3637	pick-up	0	9
32198	2020-02-18 15:08:21	2020-02-18	9	[{"id_menu":6,"count":1}]	3066	pick-up	0	9
32199	2020-02-18 15:24:44	2020-02-18	9	[{"id_menu":7,"count":1}]	12697	delivery	5	14
32200	2020-02-18 15:36:59	2020-02-18	9	[{"id_menu":7,"count":1}]	8693	delivery	5	14
32201	2020-02-18 15:42:28	2020-02-18	9	[{"id_menu":6,"count":1}]	2540	delivery	5	14
32202	2020-02-18 15:56:59	2020-02-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11211	delivery	5	22
32203	2020-02-18 15:58:40	2020-02-18	9	[{"id_menu":6,"count":1}]	12665	delivery	5	14
32204	2020-02-18 16:06:12	2020-02-18	12	[{"id_menu":1,"count":1}]	8246	delivery	5	17
32205	2020-02-18 16:11:37	2020-02-18	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12043	pick-up	0	30
32206	2020-02-18 16:13:57	2020-02-18	9	[{"id_menu":6,"count":1}]	9020	pick-up	0	9
32207	2020-02-18 16:15:38	2020-02-18	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1037	pick-up	0	34
32208	2020-02-18 16:17:41	2020-02-18	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	9884	delivery	5	29
32209	2020-02-18 16:23:31	2020-02-18	14	[{"id_menu":2,"count":1}]	9304	pick-up	0	14
32210	2020-02-18 16:35:54	2020-02-18	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8084	delivery	5	31
32211	2020-02-18 16:38:46	2020-02-18	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12723	delivery	5	22
32212	2020-02-18 16:45:15	2020-02-18	8	[{"id_menu":5,"count":1}]	536	delivery	5	13
32213	2020-02-18 16:46:26	2020-02-18	12	[{"id_menu":1,"count":1}]	6652	delivery	5	17
32214	2020-02-18 17:00:35	2020-02-18	12	[{"id_menu":3,"count":1}]	3037	delivery	5	17
32215	2020-02-18 17:01:25	2020-02-18	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4673	pick-up	0	26
32216	2020-02-18 17:02:10	2020-02-18	12	[{"id_menu":1,"count":2}]	9308	pick-up	0	12
32217	2020-02-18 17:10:55	2020-02-18	12	[{"id_menu":1,"count":1}]	11866	delivery	5	17
32218	2020-02-18 17:23:07	2020-02-18	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4007	pick-up	0	32
32219	2020-02-18 17:27:53	2020-02-18	9	[{"id_menu":7,"count":1}]	9356	delivery	5	14
32220	2020-02-18 17:28:05	2020-02-18	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4586	delivery	5	34
32221	2020-02-18 17:28:37	2020-02-18	9	[{"id_menu":6,"count":1}]	4021	pick-up	0	9
32222	2020-02-18 17:28:45	2020-02-18	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	1044	pick-up	0	26
32223	2020-02-18 17:30:41	2020-02-18	14	[{"id_menu":2,"count":1}]	139	pick-up	0	14
32224	2020-02-18 17:31:28	2020-02-18	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	8090	pick-up	0	29
32225	2020-02-18 17:43:50	2020-02-18	8	[{"id_menu":5,"count":1}]	12702	delivery	5	13
32226	2020-02-18 17:44:26	2020-02-18	9	[{"id_menu":7,"count":1}]	2719	delivery	5	14
32227	2020-02-18 17:57:51	2020-02-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3126	delivery	5	23
32228	2020-02-18 18:02:47	2020-02-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	790	delivery	5	28
32229	2020-02-18 18:25:09	2020-02-18	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12659	delivery	5	31
32230	2020-02-18 18:29:09	2020-02-18	17	[{"id_menu":4,"count":1}]	2564	delivery	5	22
32231	2020-02-18 18:29:45	2020-02-18	12	[{"id_menu":1,"count":1}]	6388	delivery	5	17
32232	2020-02-18 18:47:33	2020-02-18	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	5994	delivery	5	31
32233	2020-02-18 18:56:11	2020-02-18	12	[{"id_menu":3,"count":1}]	6796	pick-up	0	12
32234	2020-02-18 18:59:44	2020-02-18	12	[{"id_menu":3,"count":1}]	6248	delivery	5	17
32235	2020-02-18 19:05:35	2020-02-18	12	[{"id_menu":1,"count":1}]	12733	delivery	5	17
32236	2020-02-18 19:18:28	2020-02-18	9	[{"id_menu":7,"count":1}]	2889	pick-up	0	9
32237	2020-02-18 19:22:27	2020-02-18	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7502	delivery	5	31
32238	2020-02-18 19:29:39	2020-02-18	9	[{"id_menu":6,"count":1}]	12654	pick-up	0	9
32239	2020-02-18 19:38:55	2020-02-18	9	[{"id_menu":7,"count":1}]	3387	delivery	5	14
32240	2020-02-18 19:52:00	2020-02-18	8	[{"id_menu":5,"count":1}]	12231	delivery	5	13
32241	2020-02-18 20:08:18	2020-02-18	8	[{"id_menu":5,"count":1}]	1317	pick-up	0	8
32242	2020-02-18 20:14:30	2020-02-18	8	[{"id_menu":5,"count":1}]	12652	delivery	5	13
32243	2020-02-18 20:20:44	2020-02-18	9	[{"id_menu":6,"count":2}]	1684	delivery	5	14
32244	2020-02-18 20:29:34	2020-02-18	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	12660	delivery	5	40
32245	2020-02-18 20:35:32	2020-02-18	14	[{"id_menu":2,"count":1}]	4964	delivery	5	19
32246	2020-02-18 20:44:17	2020-02-18	9	[{"id_menu":6,"count":3}]	12737	delivery	5	14
32247	2020-02-18 20:55:20	2020-02-18	12	[{"id_menu":3,"count":1}]	4132	pick-up	0	12
32248	2020-02-18 21:11:38	2020-02-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1303	pick-up	0	23
32249	2020-02-18 21:19:39	2020-02-18	9	[{"id_menu":6,"count":1}]	9888	delivery	5	14
32250	2020-02-18 21:22:50	2020-02-18	8	[{"id_menu":5,"count":1}]	12707	delivery	5	13
32251	2020-02-18 21:31:17	2020-02-18	17	[{"id_menu":4,"count":1}]	4206	pick-up	0	17
32252	2020-02-18 21:32:22	2020-02-18	12	[{"id_menu":3,"count":1}]	9195	delivery	5	17
32253	2020-02-18 21:33:31	2020-02-18	12	[{"id_menu":1,"count":1}]	173	pick-up	0	12
32254	2020-02-18 21:34:39	2020-02-18	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12666	delivery	5	39
32255	2020-02-18 21:40:17	2020-02-18	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	4561	delivery	5	40
32256	2020-02-18 21:42:21	2020-02-18	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	12681	delivery	5	40
32257	2020-02-18 21:43:15	2020-02-18	8	[{"id_menu":5,"count":1}]	3529	pick-up	0	8
32258	2020-02-18 21:43:45	2020-02-18	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3382	delivery	5	52
32259	2020-02-18 21:46:32	2020-02-18	9	[{"id_menu":7,"count":1}]	5915	delivery	5	14
32260	2020-02-18 21:47:03	2020-02-18	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	5447	pick-up	0	18
32261	2020-02-18 21:56:49	2020-02-18	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	4904	pick-up	0	38
32262	2020-02-18 21:57:23	2020-02-18	8	[{"id_menu":5,"count":1}]	4714	pick-up	0	8
32263	2020-02-18 22:14:39	2020-02-18	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	12734	delivery	5	26
32264	2020-02-18 22:15:37	2020-02-18	9	[{"id_menu":7,"count":1}]	12699	delivery	5	14
32265	2020-02-18 22:17:24	2020-02-18	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	9728	delivery	5	27
32266	2020-02-18 22:28:26	2020-02-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	12721	delivery	5	28
32267	2020-02-18 22:29:31	2020-02-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	12729	delivery	5	22
32268	2020-02-18 22:38:44	2020-02-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	12738	pick-up	0	23
32269	2020-02-18 22:38:48	2020-02-18	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	9534	delivery	5	31
32270	2020-02-18 23:03:33	2020-02-18	14	[{"id_menu":2,"count":1}]	47	pick-up	0	14
32271	2020-02-18 23:15:58	2020-02-18	12	[{"id_menu":3,"count":1}]	7294	delivery	5	17
32272	2020-02-18 23:17:58	2020-02-18	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	12658	delivery	5	31
32273	2020-02-18 23:28:59	2020-02-18	14	[{"id_menu":2,"count":1}]	2821	pick-up	0	14
32274	2020-02-18 23:35:04	2020-02-18	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8561	pick-up	0	35
32275	2020-02-18 23:50:59	2020-02-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5676	delivery	5	28
32276	2020-02-18 23:56:08	2020-02-18	12	[{"id_menu":1,"count":1}]	3701	pick-up	0	12
32277	2020-02-19 00:01:39	2020-02-19	8	[{"id_menu":5,"count":1}]	4586	delivery	5	13
32278	2020-02-19 00:02:13	2020-02-19	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12758	delivery	5	39
32279	2020-02-19 00:08:33	2020-02-19	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	9192	delivery	5	26
32280	2020-02-19 00:08:58	2020-02-19	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10375	delivery	5	31
32281	2020-02-19 00:10:35	2020-02-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	5123	delivery	5	28
32282	2020-02-19 00:25:31	2020-02-19	14	[{"id_menu":2,"count":1}]	8298	pick-up	0	14
32283	2020-02-19 00:25:36	2020-02-19	9	[{"id_menu":7,"count":1}]	10340	delivery	5	14
32284	2020-02-19 00:26:45	2020-02-19	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	11507	delivery	5	23
32285	2020-02-19 00:30:17	2020-02-19	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	12825	delivery	5	31
32286	2020-02-19 00:33:40	2020-02-19	9	[{"id_menu":6,"count":1}]	2002	delivery	5	14
32287	2020-02-19 00:40:11	2020-02-19	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	10209	pick-up	0	29
32288	2020-02-19 00:50:47	2020-02-19	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	4767	pick-up	0	26
32289	2020-02-19 00:51:47	2020-02-19	14	[{"id_menu":2,"count":1}]	1885	delivery	5	19
32290	2020-02-19 01:06:41	2020-02-19	8	[{"id_menu":5,"count":1}]	3568	delivery	5	13
32291	2020-02-19 01:07:16	2020-02-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3153	pick-up	0	17
32292	2020-02-19 01:13:13	2020-02-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3636	delivery	5	31
32293	2020-02-19 01:24:22	2020-02-19	9	[{"id_menu":6,"count":1}]	8748	pick-up	0	9
32294	2020-02-19 01:27:03	2020-02-19	9	[{"id_menu":6,"count":1}]	9053	pick-up	0	9
32295	2020-02-19 01:27:39	2020-02-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1215	pick-up	0	17
32296	2020-02-19 01:31:00	2020-02-19	12	[{"id_menu":1,"count":1}]	1345	pick-up	0	12
32297	2020-02-19 01:31:53	2020-02-19	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	12777	delivery	5	30
32298	2020-02-19 01:46:07	2020-02-19	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12839	delivery	5	31
32299	2020-02-19 01:47:34	2020-02-19	17	[{"id_menu":4,"count":1}]	12757	delivery	5	22
32300	2020-02-19 01:58:28	2020-02-19	9	[{"id_menu":6,"count":1}]	6410	pick-up	0	9
32301	2020-02-19 01:58:43	2020-02-19	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	12822	delivery	5	34
32302	2020-02-19 02:03:47	2020-02-19	12	[{"id_menu":1,"count":1}]	12807	delivery	5	17
32303	2020-02-19 02:04:47	2020-02-19	9	[{"id_menu":6,"count":1}]	12763	delivery	5	14
32304	2020-02-19 02:07:18	2020-02-19	9	[{"id_menu":7,"count":1}]	7653	delivery	5	14
32305	2020-02-19 02:11:18	2020-02-19	9	[{"id_menu":7,"count":1}]	6996	pick-up	0	9
32306	2020-02-19 02:15:13	2020-02-19	12	[{"id_menu":1,"count":1}]	12800	delivery	5	17
32307	2020-02-19 02:22:55	2020-02-19	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	7666	delivery	5	26
32308	2020-02-19 02:25:49	2020-02-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	12810	delivery	5	22
32309	2020-02-19 02:26:56	2020-02-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12823	delivery	5	31
32310	2020-02-19 02:35:22	2020-02-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	7338	delivery	5	22
32311	2020-02-19 02:38:55	2020-02-19	14	[{"id_menu":2,"count":1}]	5194	pick-up	0	14
32312	2020-02-19 02:42:01	2020-02-19	9	[{"id_menu":6,"count":2}]	9825	delivery	5	14
32313	2020-02-19 02:44:53	2020-02-19	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	22	pick-up	0	21
32314	2020-02-19 02:49:11	2020-02-19	14	[{"id_menu":2,"count":1}]	8789	delivery	5	19
32315	2020-02-19 03:09:50	2020-02-19	9	[{"id_menu":6,"count":1}]	10579	pick-up	0	9
32316	2020-02-19 03:18:18	2020-02-19	9	[{"id_menu":7,"count":1}]	6844	pick-up	0	9
32317	2020-02-19 03:20:53	2020-02-19	9	[{"id_menu":6,"count":1}]	6668	delivery	5	14
32318	2020-02-19 03:23:50	2020-02-19	17	[{"id_menu":4,"count":1}]	12802	pick-up	0	17
32319	2020-02-19 03:27:24	2020-02-19	9	[{"id_menu":6,"count":1}]	3393	delivery	5	14
32320	2020-02-19 03:38:14	2020-02-19	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	12744	delivery	5	34
32321	2020-02-19 03:39:43	2020-02-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7898	pick-up	0	31
32322	2020-02-19 04:02:46	2020-02-19	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3173	delivery	5	43
32323	2020-02-19 04:04:09	2020-02-19	14	[{"id_menu":2,"count":1}]	719	pick-up	0	14
32324	2020-02-19 04:13:09	2020-02-19	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	12788	delivery	5	56
32325	2020-02-19 04:17:35	2020-02-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	12837	delivery	5	28
32326	2020-02-19 04:23:00	2020-02-19	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	2189	pick-up	0	20
32327	2020-02-19 04:36:19	2020-02-19	9	[{"id_menu":6,"count":1}]	3031	pick-up	0	9
32328	2020-02-19 04:44:41	2020-02-19	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3558	delivery	5	31
32329	2020-02-19 04:47:13	2020-02-19	9	[{"id_menu":6,"count":1}]	12772	delivery	5	14
32330	2020-02-19 04:48:05	2020-02-19	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4797	delivery	5	51
32331	2020-02-19 04:51:53	2020-02-19	14	[{"id_menu":2,"count":1}]	2691	delivery	5	19
32332	2020-02-19 04:53:12	2020-02-19	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5509	delivery	5	40
32333	2020-02-19 04:55:43	2020-02-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9976	delivery	5	22
32334	2020-02-19 05:06:39	2020-02-19	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	1183	delivery	5	22
32335	2020-02-19 05:08:43	2020-02-19	8	[{"id_menu":5,"count":1}]	888	pick-up	0	8
32336	2020-02-19 05:09:28	2020-02-19	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1746	pick-up	0	26
32337	2020-02-19 05:10:22	2020-02-19	8	[{"id_menu":5,"count":1}]	83	pick-up	0	8
32338	2020-02-19 05:28:45	2020-02-19	14	[{"id_menu":2,"count":1}]	12835	delivery	5	19
32339	2020-02-19 05:34:23	2020-02-19	12	[{"id_menu":1,"count":1}]	236	delivery	5	17
32340	2020-02-19 05:36:28	2020-02-19	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	12833	delivery	5	44
32341	2020-02-19 05:37:41	2020-02-19	12	[{"id_menu":3,"count":1}]	548	delivery	5	17
32342	2020-02-19 05:49:38	2020-02-19	14	[{"id_menu":2,"count":1}]	8457	pick-up	0	14
32343	2020-02-19 05:50:31	2020-02-19	12	[{"id_menu":3,"count":1}]	4395	pick-up	0	12
32344	2020-02-19 05:51:34	2020-02-19	12	[{"id_menu":3,"count":1}]	4060	delivery	5	17
32345	2020-02-19 05:54:49	2020-02-19	17	[{"id_menu":4,"count":1}]	3863	pick-up	0	17
32346	2020-02-19 05:56:09	2020-02-19	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12814	delivery	5	57
32347	2020-02-19 05:56:14	2020-02-19	8	[{"id_menu":5,"count":1}]	12506	pick-up	0	8
32348	2020-02-19 05:57:41	2020-02-19	12	[{"id_menu":3,"count":2}]	9793	delivery	5	17
32349	2020-02-19 05:58:47	2020-02-19	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	11615	delivery	5	34
32350	2020-02-19 06:00:57	2020-02-19	9	[{"id_menu":6,"count":1}]	2545	pick-up	0	9
32351	2020-02-19 06:23:54	2020-02-19	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":3}]	12848	delivery	5	26
32352	2020-02-19 06:24:23	2020-02-19	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12805	delivery	5	45
32353	2020-02-19 06:28:25	2020-02-19	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8026	delivery	5	37
32354	2020-02-19 06:30:38	2020-02-19	8	[{"id_menu":5,"count":1}]	12817	delivery	5	13
32355	2020-02-19 06:33:01	2020-02-19	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	7019	pick-up	0	21
32356	2020-02-19 06:33:41	2020-02-19	14	[{"id_menu":2,"count":1}]	12794	delivery	5	19
32357	2020-02-19 06:33:45	2020-02-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12836	pick-up	0	17
32358	2020-02-19 06:36:36	2020-02-19	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	12824	delivery	5	25
32359	2020-02-19 06:41:11	2020-02-19	8	[{"id_menu":5,"count":1}]	6221	pick-up	0	8
32360	2020-02-19 06:45:38	2020-02-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7041	delivery	5	22
32361	2020-02-19 06:48:21	2020-02-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	9929	delivery	5	28
32362	2020-02-19 06:49:49	2020-02-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12770	delivery	5	22
32363	2020-02-19 06:52:49	2020-02-19	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	12811	delivery	5	26
32364	2020-02-19 06:55:44	2020-02-19	17	[{"id_menu":4,"count":1}]	12749	pick-up	0	17
32365	2020-02-19 07:05:48	2020-02-19	17	[{"id_menu":4,"count":1}]	11126	delivery	5	22
32366	2020-02-19 07:10:24	2020-02-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12793	delivery	5	22
32367	2020-02-19 07:16:14	2020-02-19	14	[{"id_menu":2,"count":1}]	2179	pick-up	0	14
32368	2020-02-19 07:25:38	2020-02-19	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1581	pick-up	0	26
32369	2020-02-19 07:32:50	2020-02-19	14	[{"id_menu":2,"count":1}]	841	delivery	5	19
32370	2020-02-19 07:39:46	2020-02-19	14	[{"id_menu":2,"count":1}]	12754	delivery	5	19
32371	2020-02-19 07:41:19	2020-02-19	9	[{"id_menu":6,"count":3}]	3246	delivery	5	14
32372	2020-02-19 07:54:13	2020-02-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	418	pick-up	0	23
32373	2020-02-19 07:59:27	2020-02-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4136	delivery	5	22
32374	2020-02-19 08:06:44	2020-02-19	12	[{"id_menu":3,"count":1}]	3447	delivery	5	17
32375	2020-02-19 08:08:09	2020-02-19	9	[{"id_menu":6,"count":1}]	189	delivery	5	14
32376	2020-02-19 08:09:38	2020-02-19	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2216	pick-up	0	29
32377	2020-02-19 08:15:56	2020-02-19	8	[{"id_menu":5,"count":1}]	3180	delivery	5	13
32378	2020-02-19 08:23:33	2020-02-19	9	[{"id_menu":6,"count":1}]	5537	delivery	5	14
32379	2020-02-19 08:33:30	2020-02-19	14	[{"id_menu":2,"count":1}]	12747	delivery	5	19
32380	2020-02-19 08:39:27	2020-02-19	9	[{"id_menu":7,"count":1}]	12773	delivery	5	14
32381	2020-02-19 08:47:38	2020-02-19	14	[{"id_menu":2,"count":1}]	1944	pick-up	0	14
32382	2020-02-19 09:00:05	2020-02-19	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	11840	delivery	5	40
32383	2020-02-19 09:02:00	2020-02-19	9	[{"id_menu":7,"count":1}]	12249	delivery	5	14
32384	2020-02-19 09:08:29	2020-02-19	17	[{"id_menu":4,"count":1}]	12576	delivery	5	22
32385	2020-02-19 09:12:01	2020-02-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1343	pick-up	0	31
32386	2020-02-19 09:15:07	2020-02-19	8	[{"id_menu":5,"count":1}]	10528	delivery	5	13
32387	2020-02-19 09:17:35	2020-02-19	12	[{"id_menu":3,"count":2}]	8050	delivery	5	17
32388	2020-02-19 09:24:08	2020-02-19	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9798	delivery	5	49
32389	2020-02-19 09:31:25	2020-02-19	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":2}]	8887	pick-up	0	17
32390	2020-02-19 09:32:59	2020-02-19	12	[{"id_menu":3,"count":1}]	12764	delivery	5	17
32391	2020-02-19 09:54:50	2020-02-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7574	pick-up	0	18
32392	2020-02-19 09:58:19	2020-02-19	9	[{"id_menu":6,"count":1}]	6753	delivery	5	14
32393	2020-02-19 09:58:44	2020-02-19	12	[{"id_menu":3,"count":1}]	12806	delivery	5	17
32394	2020-02-19 09:59:38	2020-02-19	9	[{"id_menu":6,"count":1}]	12745	delivery	5	14
32395	2020-02-19 10:01:06	2020-02-19	31	[{"id_menu":2,"count":3},{"id_menu":4,"count":1}]	7150	delivery	5	36
32396	2020-02-19 10:01:42	2020-02-19	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	2434	delivery	5	29
32397	2020-02-19 10:03:31	2020-02-19	8	[{"id_menu":5,"count":1}]	3271	pick-up	0	8
32398	2020-02-19 10:05:51	2020-02-19	9	[{"id_menu":6,"count":2}]	144	delivery	5	14
32399	2020-02-19 10:11:13	2020-02-19	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	10033	delivery	5	27
32400	2020-02-19 10:13:03	2020-02-19	9	[{"id_menu":7,"count":1}]	12109	delivery	5	14
32401	2020-02-19 10:14:56	2020-02-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":3}]	11834	delivery	5	36
32402	2020-02-19 10:17:33	2020-02-19	14	[{"id_menu":2,"count":1}]	11531	pick-up	0	14
32403	2020-02-19 10:23:10	2020-02-19	30	[{"id_menu":1,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12827	delivery	5	35
32404	2020-02-19 10:23:38	2020-02-19	12	[{"id_menu":1,"count":1}]	11116	pick-up	0	12
32405	2020-02-19 10:29:17	2020-02-19	9	[{"id_menu":6,"count":1}]	2679	delivery	5	14
32406	2020-02-19 10:41:02	2020-02-19	14	[{"id_menu":2,"count":1}]	4599	delivery	5	19
32407	2020-02-19 10:41:31	2020-02-19	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	9335	delivery	5	26
32408	2020-02-19 10:42:18	2020-02-19	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	12783	delivery	5	26
32409	2020-02-19 10:57:40	2020-02-19	9	[{"id_menu":6,"count":1}]	1241	pick-up	0	9
32410	2020-02-19 11:00:43	2020-02-19	9	[{"id_menu":7,"count":1}]	11867	delivery	5	14
32411	2020-02-19 11:01:59	2020-02-19	9	[{"id_menu":6,"count":1}]	6243	pick-up	0	9
32412	2020-02-19 11:05:14	2020-02-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2422	delivery	5	22
32413	2020-02-19 11:07:44	2020-02-19	9	[{"id_menu":6,"count":1}]	7983	delivery	5	14
32414	2020-02-19 11:12:32	2020-02-19	14	[{"id_menu":2,"count":1}]	730	delivery	5	19
32415	2020-02-19 11:17:52	2020-02-19	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	12761	delivery	5	56
32416	2020-02-19 11:26:17	2020-02-19	9	[{"id_menu":6,"count":1}]	3949	pick-up	0	9
32417	2020-02-19 11:27:02	2020-02-19	12	[{"id_menu":1,"count":1}]	12089	delivery	5	17
32418	2020-02-19 11:28:08	2020-02-19	14	[{"id_menu":2,"count":1}]	3077	pick-up	0	14
32419	2020-02-19 11:36:40	2020-02-19	9	[{"id_menu":6,"count":1}]	12828	pick-up	0	9
32420	2020-02-19 11:37:20	2020-02-19	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1549	pick-up	0	35
32421	2020-02-19 11:42:08	2020-02-19	9	[{"id_menu":6,"count":1}]	7773	delivery	5	14
32422	2020-02-19 11:48:54	2020-02-19	12	[{"id_menu":3,"count":1}]	778	pick-up	0	12
32423	2020-02-19 12:03:29	2020-02-19	12	[{"id_menu":3,"count":1}]	12784	pick-up	0	12
32424	2020-02-19 12:05:32	2020-02-19	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	12750	delivery	5	22
32425	2020-02-19 12:09:37	2020-02-19	14	[{"id_menu":2,"count":1}]	12792	delivery	5	19
32426	2020-02-19 12:13:27	2020-02-19	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3314	delivery	5	26
32427	2020-02-19 12:17:55	2020-02-19	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3443	delivery	5	37
32428	2020-02-19 12:18:28	2020-02-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2835	delivery	5	22
32429	2020-02-19 12:23:53	2020-02-19	9	[{"id_menu":7,"count":1}]	12796	delivery	5	14
32430	2020-02-19 12:24:27	2020-02-19	12	[{"id_menu":3,"count":1}]	466	delivery	5	17
32431	2020-02-19 12:27:21	2020-02-19	12	[{"id_menu":3,"count":1}]	1513	delivery	5	17
32432	2020-02-19 12:28:05	2020-02-19	14	[{"id_menu":2,"count":1}]	12844	delivery	5	19
32433	2020-02-19 12:34:13	2020-02-19	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	12791	pick-up	0	38
32434	2020-02-19 12:39:58	2020-02-19	12	[{"id_menu":3,"count":1}]	3372	delivery	5	17
32435	2020-02-19 12:43:08	2020-02-19	9	[{"id_menu":7,"count":1}]	12829	delivery	5	14
32436	2020-02-19 12:50:04	2020-02-19	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1317	pick-up	0	29
32437	2020-02-19 12:54:09	2020-02-19	9	[{"id_menu":6,"count":1}]	12742	pick-up	0	9
32438	2020-02-19 13:04:33	2020-02-19	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	9015	delivery	5	31
32439	2020-02-19 13:08:27	2020-02-19	12	[{"id_menu":1,"count":1}]	3480	pick-up	0	12
32440	2020-02-19 13:13:53	2020-02-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	10878	delivery	5	23
32441	2020-02-19 13:17:25	2020-02-19	8	[{"id_menu":5,"count":1}]	12743	delivery	5	13
32442	2020-02-19 13:19:52	2020-02-19	8	[{"id_menu":5,"count":1}]	12801	delivery	5	13
32443	2020-02-19 13:23:11	2020-02-19	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	11735	delivery	5	26
32444	2020-02-19 13:30:00	2020-02-19	17	[{"id_menu":4,"count":1}]	12808	pick-up	0	17
32445	2020-02-19 13:36:12	2020-02-19	9	[{"id_menu":6,"count":1}]	5367	pick-up	0	9
32446	2020-02-19 13:45:34	2020-02-19	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	11962	delivery	5	26
32447	2020-02-19 13:46:26	2020-02-19	23	[{"id_menu":2,"count":3},{"id_menu":7,"count":1}]	1076	pick-up	0	23
32448	2020-02-19 13:47:32	2020-02-19	8	[{"id_menu":5,"count":1}]	12845	delivery	5	13
32449	2020-02-19 13:48:49	2020-02-19	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	12803	delivery	5	26
32450	2020-02-19 13:50:54	2020-02-19	9	[{"id_menu":7,"count":1}]	11887	pick-up	0	9
32451	2020-02-19 14:02:12	2020-02-19	9	[{"id_menu":7,"count":1}]	8986	delivery	5	14
32452	2020-02-19 14:07:20	2020-02-19	9	[{"id_menu":7,"count":1}]	6989	delivery	5	14
32453	2020-02-19 14:07:36	2020-02-19	12	[{"id_menu":1,"count":1}]	11896	pick-up	0	12
32454	2020-02-19 14:09:50	2020-02-19	8	[{"id_menu":5,"count":1}]	12849	delivery	5	13
32455	2020-02-19 14:11:23	2020-02-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	12843	delivery	5	36
32456	2020-02-19 14:23:33	2020-02-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12767	pick-up	0	17
32457	2020-02-19 14:29:57	2020-02-19	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	12769	delivery	5	25
32458	2020-02-19 14:30:55	2020-02-19	9	[{"id_menu":7,"count":1}]	376	pick-up	0	9
32459	2020-02-19 14:35:30	2020-02-19	17	[{"id_menu":4,"count":1}]	2271	delivery	5	22
32460	2020-02-19 14:47:13	2020-02-19	14	[{"id_menu":2,"count":1}]	12821	delivery	5	19
32461	2020-02-19 15:06:54	2020-02-19	9	[{"id_menu":7,"count":2}]	12751	delivery	5	14
32462	2020-02-19 15:16:56	2020-02-19	12	[{"id_menu":3,"count":1}]	10867	pick-up	0	12
32463	2020-02-19 15:23:34	2020-02-19	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	199	delivery	5	26
32464	2020-02-19 15:35:31	2020-02-19	12	[{"id_menu":3,"count":1}]	2579	pick-up	0	12
32465	2020-02-19 15:41:00	2020-02-19	14	[{"id_menu":2,"count":1}]	4673	pick-up	0	14
32466	2020-02-19 15:44:38	2020-02-19	8	[{"id_menu":5,"count":1}]	3579	delivery	5	13
32467	2020-02-19 15:47:10	2020-02-19	12	[{"id_menu":1,"count":1}]	12813	delivery	5	17
32468	2020-02-19 15:50:06	2020-02-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1352	delivery	5	31
32469	2020-02-19 16:00:43	2020-02-19	9	[{"id_menu":7,"count":1}]	9244	pick-up	0	9
32470	2020-02-19 16:02:20	2020-02-19	17	[{"id_menu":4,"count":1}]	1375	delivery	5	22
32471	2020-02-19 16:04:49	2020-02-19	9	[{"id_menu":6,"count":1}]	527	pick-up	0	9
32472	2020-02-19 16:07:19	2020-02-19	17	[{"id_menu":4,"count":1}]	5149	pick-up	0	17
32473	2020-02-19 16:10:22	2020-02-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11061	pick-up	0	26
32474	2020-02-19 16:14:43	2020-02-19	17	[{"id_menu":4,"count":1}]	11756	delivery	5	22
32475	2020-02-19 16:15:46	2020-02-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5970	pick-up	0	18
32476	2020-02-19 16:19:00	2020-02-19	8	[{"id_menu":5,"count":1}]	12831	delivery	5	13
32477	2020-02-19 16:26:54	2020-02-19	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	5169	pick-up	0	35
32478	2020-02-19 16:29:28	2020-02-19	14	[{"id_menu":2,"count":1}]	10629	delivery	5	19
32479	2020-02-19 16:30:55	2020-02-19	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6187	delivery	5	56
32480	2020-02-19 16:33:27	2020-02-19	12	[{"id_menu":1,"count":1}]	12755	delivery	5	17
32481	2020-02-19 16:34:22	2020-02-19	9	[{"id_menu":6,"count":1}]	5046	delivery	5	14
32482	2020-02-19 16:39:22	2020-02-19	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	12798	delivery	5	31
32483	2020-02-19 16:46:37	2020-02-19	17	[{"id_menu":4,"count":1}]	3155	pick-up	0	17
32484	2020-02-19 17:06:19	2020-02-19	17	[{"id_menu":4,"count":1}]	12519	delivery	5	22
32485	2020-02-19 17:11:00	2020-02-19	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2838	delivery	5	27
32486	2020-02-19 17:19:49	2020-02-19	12	[{"id_menu":3,"count":1}]	10005	delivery	5	17
32487	2020-02-19 17:22:24	2020-02-19	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	5668	delivery	5	26
32488	2020-02-19 17:24:03	2020-02-19	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	2176	delivery	5	39
32489	2020-02-19 17:26:36	2020-02-19	12	[{"id_menu":3,"count":1}]	7010	pick-up	0	12
32490	2020-02-19 17:28:24	2020-02-19	9	[{"id_menu":6,"count":1}]	500	delivery	5	14
32491	2020-02-19 17:29:09	2020-02-19	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	2654	pick-up	0	24
32492	2020-02-19 17:35:27	2020-02-19	8	[{"id_menu":5,"count":1}]	714	pick-up	0	8
32493	2020-02-19 17:38:39	2020-02-19	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	826	pick-up	0	25
32494	2020-02-19 17:46:11	2020-02-19	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	12766	delivery	5	26
32495	2020-02-19 17:47:17	2020-02-19	17	[{"id_menu":4,"count":1}]	4800	pick-up	0	17
32496	2020-02-19 17:49:26	2020-02-19	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	12787	delivery	5	26
32497	2020-02-19 17:54:12	2020-02-19	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11018	delivery	5	43
32498	2020-02-19 17:59:22	2020-02-19	17	[{"id_menu":4,"count":1}]	12780	delivery	5	22
32499	2020-02-19 18:00:47	2020-02-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3493	delivery	5	28
32500	2020-02-19 18:01:18	2020-02-19	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10565	delivery	5	55
32501	2020-02-19 18:01:34	2020-02-19	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	12809	delivery	5	26
32502	2020-02-19 18:16:36	2020-02-19	9	[{"id_menu":7,"count":1}]	4820	delivery	5	14
32503	2020-02-19 18:20:43	2020-02-19	12	[{"id_menu":1,"count":1}]	4451	delivery	5	17
32504	2020-02-19 18:30:27	2020-02-19	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	12756	delivery	5	46
32505	2020-02-19 18:41:07	2020-02-19	12	[{"id_menu":3,"count":1}]	12816	delivery	5	17
32506	2020-02-19 18:44:12	2020-02-19	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	12842	delivery	5	48
32507	2020-02-19 18:57:30	2020-02-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8922	delivery	5	22
32508	2020-02-19 19:07:59	2020-02-19	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12818	delivery	5	34
32509	2020-02-19 19:13:40	2020-02-19	9	[{"id_menu":6,"count":2}]	6369	pick-up	0	9
32510	2020-02-19 19:26:25	2020-02-19	12	[{"id_menu":1,"count":1}]	4640	pick-up	0	12
32511	2020-02-19 19:34:20	2020-02-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	740	pick-up	0	23
32512	2020-02-19 19:43:31	2020-02-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4628	delivery	5	36
32513	2020-02-19 19:46:22	2020-02-19	8	[{"id_menu":5,"count":1}]	12785	delivery	5	13
32514	2020-02-19 19:47:23	2020-02-19	14	[{"id_menu":2,"count":1}]	1119	pick-up	0	14
32515	2020-02-19 19:47:50	2020-02-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	11270	delivery	5	28
32516	2020-02-19 19:48:53	2020-02-19	17	[{"id_menu":4,"count":1}]	12847	delivery	5	22
32517	2020-02-19 19:50:43	2020-02-19	9	[{"id_menu":7,"count":1}]	7630	pick-up	0	9
32518	2020-02-19 19:51:28	2020-02-19	8	[{"id_menu":5,"count":1}]	5542	delivery	5	13
32519	2020-02-19 19:52:45	2020-02-19	8	[{"id_menu":5,"count":2}]	10822	delivery	5	13
32520	2020-02-19 20:04:54	2020-02-19	9	[{"id_menu":7,"count":1}]	9352	delivery	5	14
32521	2020-02-19 20:14:18	2020-02-19	9	[{"id_menu":6,"count":1}]	12846	pick-up	0	9
32522	2020-02-19 20:15:20	2020-02-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2221	pick-up	0	23
32523	2020-02-19 20:18:33	2020-02-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2317	pick-up	0	31
32524	2020-02-19 20:23:34	2020-02-19	14	[{"id_menu":2,"count":2}]	4874	pick-up	0	14
32525	2020-02-19 20:29:42	2020-02-19	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5485	delivery	5	43
32526	2020-02-19 20:34:01	2020-02-19	9	[{"id_menu":6,"count":1}]	11359	delivery	5	14
32527	2020-02-19 20:39:43	2020-02-19	12	[{"id_menu":1,"count":1}]	3671	pick-up	0	12
32528	2020-02-19 20:41:29	2020-02-19	12	[{"id_menu":3,"count":1}]	12840	pick-up	0	12
32529	2020-02-19 20:46:26	2020-02-19	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12320	delivery	5	51
32530	2020-02-19 20:53:10	2020-02-19	14	[{"id_menu":2,"count":1}]	10389	pick-up	0	14
32531	2020-02-19 20:55:42	2020-02-19	14	[{"id_menu":2,"count":1}]	12789	delivery	5	19
32532	2020-02-19 21:02:39	2020-02-19	14	[{"id_menu":2,"count":1}]	11913	delivery	5	19
32533	2020-02-19 21:05:12	2020-02-19	9	[{"id_menu":7,"count":1}]	11628	delivery	5	14
32534	2020-02-19 21:09:32	2020-02-19	12	[{"id_menu":3,"count":1}]	3851	pick-up	0	12
32535	2020-02-19 21:16:48	2020-02-19	14	[{"id_menu":2,"count":1}]	5985	delivery	5	19
32536	2020-02-19 21:16:57	2020-02-19	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	10740	delivery	5	25
32537	2020-02-19 21:26:09	2020-02-19	26	[{"id_menu":4,"count":3},{"id_menu":7,"count":1}]	12838	delivery	5	31
32538	2020-02-19 21:33:39	2020-02-19	17	[{"id_menu":4,"count":1}]	1592	delivery	5	22
32539	2020-02-19 21:34:37	2020-02-19	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12790	delivery	5	34
32540	2020-02-19 21:34:40	2020-02-19	17	[{"id_menu":4,"count":1}]	11326	pick-up	0	17
32541	2020-02-19 21:36:45	2020-02-19	14	[{"id_menu":2,"count":1}]	12753	delivery	5	19
32542	2020-02-19 21:46:48	2020-02-19	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	5591	delivery	5	26
32543	2020-02-19 22:01:43	2020-02-19	8	[{"id_menu":5,"count":1}]	1683	pick-up	0	8
32544	2020-02-19 22:08:21	2020-02-19	9	[{"id_menu":7,"count":1}]	12841	delivery	5	14
32545	2020-02-19 22:19:19	2020-02-19	14	[{"id_menu":2,"count":1}]	6533	delivery	5	19
32546	2020-02-19 22:20:19	2020-02-19	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12760	delivery	5	48
32547	2020-02-19 22:22:16	2020-02-19	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	105	pick-up	0	24
32548	2020-02-19 22:24:54	2020-02-19	9	[{"id_menu":6,"count":1}]	10868	delivery	5	14
32549	2020-02-19 22:28:41	2020-02-19	9	[{"id_menu":6,"count":1}]	8029	delivery	5	14
32550	2020-02-19 22:30:15	2020-02-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12306	delivery	5	22
32551	2020-02-19 22:40:54	2020-02-19	14	[{"id_menu":2,"count":1}]	12804	delivery	5	19
32552	2020-02-19 22:41:39	2020-02-19	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7438	delivery	5	35
32553	2020-02-19 22:54:59	2020-02-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12830	delivery	5	31
32554	2020-02-19 22:55:53	2020-02-19	17	[{"id_menu":4,"count":2}]	12832	pick-up	0	17
32555	2020-02-19 22:58:28	2020-02-19	9	[{"id_menu":7,"count":1}]	12775	delivery	5	14
32556	2020-02-19 23:08:55	2020-02-19	8	[{"id_menu":5,"count":1}]	4388	delivery	5	13
32557	2020-02-19 23:21:17	2020-02-19	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8798	delivery	5	34
32558	2020-02-19 23:33:39	2020-02-19	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	6689	delivery	5	31
32559	2020-02-19 23:35:47	2020-02-19	17	[{"id_menu":4,"count":1}]	9308	pick-up	0	17
32560	2020-02-19 23:38:41	2020-02-19	9	[{"id_menu":7,"count":1}]	12768	delivery	5	14
32561	2020-02-19 23:50:59	2020-02-19	8	[{"id_menu":5,"count":1}]	11215	delivery	5	13
32562	2020-02-19 23:57:39	2020-02-19	9	[{"id_menu":6,"count":1}]	609	pick-up	0	9
32563	2020-02-19 23:58:09	2020-02-19	9	[{"id_menu":7,"count":1}]	883	pick-up	0	9
32564	2020-02-20 00:00:27	2020-02-20	9	[{"id_menu":6,"count":1}]	10948	delivery	5	14
32565	2020-02-20 00:08:54	2020-02-20	14	[{"id_menu":2,"count":1}]	361	delivery	5	19
32566	2020-02-20 00:15:26	2020-02-20	12	[{"id_menu":1,"count":1}]	4206	pick-up	0	12
32567	2020-02-20 00:16:45	2020-02-20	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	12855	pick-up	0	24
32568	2020-02-20 00:17:51	2020-02-20	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2398	pick-up	0	35
32569	2020-02-20 00:21:39	2020-02-20	8	[{"id_menu":5,"count":1}]	8256	delivery	5	13
32570	2020-02-20 00:23:15	2020-02-20	39	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8970	delivery	5	44
32571	2020-02-20 00:28:20	2020-02-20	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7491	delivery	5	39
32572	2020-02-20 00:48:02	2020-02-20	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	204	pick-up	0	17
32573	2020-02-20 00:57:29	2020-02-20	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1379	pick-up	0	33
32574	2020-02-20 00:57:48	2020-02-20	14	[{"id_menu":2,"count":1}]	4519	delivery	5	19
32575	2020-02-20 00:59:29	2020-02-20	8	[{"id_menu":5,"count":1}]	6676	delivery	5	13
32576	2020-02-20 01:03:48	2020-02-20	14	[{"id_menu":2,"count":1}]	9195	delivery	5	19
32577	2020-02-20 01:04:26	2020-02-20	8	[{"id_menu":5,"count":1}]	10951	delivery	5	13
32578	2020-02-20 01:05:02	2020-02-20	14	[{"id_menu":2,"count":1}]	11495	pick-up	0	14
32579	2020-02-20 01:05:50	2020-02-20	9	[{"id_menu":6,"count":1}]	4489	delivery	5	14
32580	2020-02-20 01:11:37	2020-02-20	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	285	delivery	5	36
32581	2020-02-20 01:18:59	2020-02-20	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8236	delivery	5	34
32582	2020-02-20 01:30:01	2020-02-20	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	12530	delivery	5	48
32583	2020-02-20 01:32:43	2020-02-20	17	[{"id_menu":4,"count":1}]	2261	pick-up	0	17
32584	2020-02-20 01:42:57	2020-02-20	9	[{"id_menu":6,"count":1}]	2027	delivery	5	14
32585	2020-02-20 01:44:08	2020-02-20	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	12899	delivery	5	30
32586	2020-02-20 01:44:30	2020-02-20	32	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	10740	delivery	5	37
32587	2020-02-20 01:46:31	2020-02-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	5242	delivery	5	28
32588	2020-02-20 01:52:02	2020-02-20	9	[{"id_menu":7,"count":1}]	8910	delivery	5	14
32589	2020-02-20 01:57:27	2020-02-20	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	12889	pick-up	0	35
32590	2020-02-20 01:59:34	2020-02-20	12	[{"id_menu":3,"count":1}]	12929	pick-up	0	12
32591	2020-02-20 02:00:09	2020-02-20	41	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	12571	delivery	5	46
32592	2020-02-20 02:09:11	2020-02-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12922	delivery	5	23
32593	2020-02-20 02:15:19	2020-02-20	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	8799	pick-up	0	29
32594	2020-02-20 02:17:15	2020-02-20	17	[{"id_menu":4,"count":1}]	2802	delivery	5	22
32595	2020-02-20 02:17:37	2020-02-20	12	[{"id_menu":1,"count":1}]	3174	pick-up	0	12
32596	2020-02-20 02:21:28	2020-02-20	30	[{"id_menu":1,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12880	delivery	5	35
32597	2020-02-20 02:36:34	2020-02-20	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	12775	delivery	5	39
32598	2020-02-20 02:39:03	2020-02-20	14	[{"id_menu":2,"count":1}]	2190	pick-up	0	14
32599	2020-02-20 02:45:29	2020-02-20	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	12920	delivery	5	31
32600	2020-02-20 02:45:44	2020-02-20	9	[{"id_menu":6,"count":1}]	12853	delivery	5	14
32601	2020-02-20 02:47:06	2020-02-20	9	[{"id_menu":6,"count":1}]	5451	delivery	5	14
32602	2020-02-20 02:55:23	2020-02-20	12	[{"id_menu":1,"count":1}]	12884	delivery	5	17
32603	2020-02-20 03:11:54	2020-02-20	9	[{"id_menu":6,"count":1}]	4312	pick-up	0	9
32604	2020-02-20 03:15:31	2020-02-20	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	12877	pick-up	0	25
32605	2020-02-20 03:32:32	2020-02-20	8	[{"id_menu":5,"count":1}]	927	delivery	5	13
32606	2020-02-20 03:37:57	2020-02-20	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	4170	pick-up	0	29
32607	2020-02-20 03:43:34	2020-02-20	9	[{"id_menu":7,"count":1}]	4010	delivery	5	14
32608	2020-02-20 03:55:01	2020-02-20	9	[{"id_menu":7,"count":2}]	7834	pick-up	0	9
32609	2020-02-20 03:56:20	2020-02-20	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	12873	delivery	5	27
32610	2020-02-20 04:07:20	2020-02-20	8	[{"id_menu":5,"count":1}]	397	delivery	5	13
32611	2020-02-20 04:13:23	2020-02-20	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10354	delivery	5	49
32612	2020-02-20 04:18:46	2020-02-20	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	12883	pick-up	0	21
32613	2020-02-20 04:36:24	2020-02-20	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	11962	delivery	5	39
32614	2020-02-20 04:42:10	2020-02-20	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	2251	pick-up	0	26
32615	2020-02-20 04:42:21	2020-02-20	9	[{"id_menu":6,"count":2}]	8176	delivery	5	14
32616	2020-02-20 04:44:52	2020-02-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":3}]	8460	delivery	5	28
32617	2020-02-20 04:45:15	2020-02-20	8	[{"id_menu":5,"count":1}]	5192	delivery	5	13
32618	2020-02-20 04:55:24	2020-02-20	8	[{"id_menu":5,"count":1}]	12894	delivery	5	13
32619	2020-02-20 05:00:31	2020-02-20	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	12882	delivery	5	36
32620	2020-02-20 05:17:06	2020-02-20	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	12850	delivery	5	28
32621	2020-02-20 05:19:28	2020-02-20	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3509	delivery	5	22
32622	2020-02-20 05:21:20	2020-02-20	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	12905	delivery	5	25
32623	2020-02-20 05:29:12	2020-02-20	9	[{"id_menu":7,"count":2}]	2556	delivery	5	14
32624	2020-02-20 05:32:14	2020-02-20	17	[{"id_menu":4,"count":1}]	9602	pick-up	0	17
32625	2020-02-20 05:35:29	2020-02-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12924	delivery	5	23
32626	2020-02-20 05:39:16	2020-02-20	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	12863	delivery	5	25
32627	2020-02-20 05:42:21	2020-02-20	8	[{"id_menu":5,"count":1}]	3565	delivery	5	13
32628	2020-02-20 05:47:37	2020-02-20	12	[{"id_menu":3,"count":1}]	6869	pick-up	0	12
32629	2020-02-20 05:56:45	2020-02-20	12	[{"id_menu":3,"count":1}]	4413	delivery	5	17
32630	2020-02-20 06:04:14	2020-02-20	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12297	delivery	5	40
32631	2020-02-20 06:21:57	2020-02-20	9	[{"id_menu":7,"count":1}]	8071	pick-up	0	9
32632	2020-02-20 06:30:46	2020-02-20	9	[{"id_menu":6,"count":1}]	1290	pick-up	0	9
32633	2020-02-20 06:33:02	2020-02-20	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	12935	delivery	5	26
32634	2020-02-20 06:33:12	2020-02-20	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1331	pick-up	0	24
32635	2020-02-20 06:40:22	2020-02-20	9	[{"id_menu":7,"count":1}]	12872	delivery	5	14
32636	2020-02-20 06:42:22	2020-02-20	9	[{"id_menu":6,"count":1}]	12896	pick-up	0	9
32637	2020-02-20 06:54:42	2020-02-20	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3977	delivery	5	26
32638	2020-02-20 06:56:08	2020-02-20	14	[{"id_menu":2,"count":1}]	12908	delivery	5	19
32639	2020-02-20 07:03:39	2020-02-20	8	[{"id_menu":5,"count":1}]	880	delivery	5	13
32640	2020-02-20 07:11:08	2020-02-20	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12344	delivery	5	57
32641	2020-02-20 07:12:51	2020-02-20	17	[{"id_menu":4,"count":1}]	3301	delivery	5	22
32642	2020-02-20 07:14:18	2020-02-20	14	[{"id_menu":2,"count":1}]	10982	delivery	5	19
32643	2020-02-20 07:30:22	2020-02-20	9	[{"id_menu":7,"count":1}]	12474	pick-up	0	9
32644	2020-02-20 07:33:15	2020-02-20	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9034	delivery	5	34
32645	2020-02-20 07:41:35	2020-02-20	8	[{"id_menu":5,"count":1}]	7349	delivery	5	13
32646	2020-02-20 07:48:18	2020-02-20	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	3293	delivery	5	28
32647	2020-02-20 07:52:51	2020-02-20	14	[{"id_menu":2,"count":1}]	12913	delivery	5	19
32648	2020-02-20 07:54:28	2020-02-20	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7694	delivery	5	31
32649	2020-02-20 07:56:04	2020-02-20	8	[{"id_menu":5,"count":1}]	7891	delivery	5	13
32650	2020-02-20 08:15:59	2020-02-20	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2894	delivery	5	26
32651	2020-02-20 08:24:32	2020-02-20	12	[{"id_menu":3,"count":1}]	6046	pick-up	0	12
32652	2020-02-20 08:27:58	2020-02-20	17	[{"id_menu":4,"count":1}]	11039	delivery	5	22
32653	2020-02-20 08:29:47	2020-02-20	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12881	delivery	5	43
32654	2020-02-20 08:30:15	2020-02-20	17	[{"id_menu":4,"count":1}]	8730	delivery	5	22
32655	2020-02-20 09:14:26	2020-02-20	12	[{"id_menu":3,"count":1}]	2291	pick-up	0	12
32656	2020-02-20 09:18:01	2020-02-20	17	[{"id_menu":4,"count":1}]	9793	pick-up	0	17
32657	2020-02-20 09:45:27	2020-02-20	8	[{"id_menu":5,"count":1}]	12934	delivery	5	13
32658	2020-02-20 09:46:38	2020-02-20	9	[{"id_menu":6,"count":1}]	12937	delivery	5	14
32659	2020-02-20 09:49:45	2020-02-20	17	[{"id_menu":4,"count":1}]	12921	delivery	5	22
32660	2020-02-20 09:55:47	2020-02-20	12	[{"id_menu":3,"count":1}]	3401	delivery	5	17
32661	2020-02-20 09:56:46	2020-02-20	9	[{"id_menu":7,"count":1}]	4969	delivery	5	14
32662	2020-02-20 09:56:52	2020-02-20	14	[{"id_menu":2,"count":1}]	11893	delivery	5	19
32663	2020-02-20 09:57:59	2020-02-20	9	[{"id_menu":7,"count":1}]	609	pick-up	0	9
32664	2020-02-20 09:58:35	2020-02-20	8	[{"id_menu":5,"count":1}]	12868	delivery	5	13
32665	2020-02-20 10:00:33	2020-02-20	9	[{"id_menu":7,"count":1}]	12886	delivery	5	14
32666	2020-02-20 10:00:52	2020-02-20	12	[{"id_menu":3,"count":1}]	7623	delivery	5	17
32667	2020-02-20 10:05:11	2020-02-20	12	[{"id_menu":3,"count":1}]	1528	pick-up	0	12
32668	2020-02-20 10:15:28	2020-02-20	12	[{"id_menu":3,"count":1}]	12670	delivery	5	17
32669	2020-02-20 10:20:09	2020-02-20	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	12916	delivery	5	34
32670	2020-02-20 10:20:45	2020-02-20	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1534	pick-up	0	26
32671	2020-02-20 10:22:28	2020-02-20	9	[{"id_menu":7,"count":1}]	2140	pick-up	0	9
32672	2020-02-20 10:26:26	2020-02-20	12	[{"id_menu":1,"count":1}]	1681	delivery	5	17
32673	2020-02-20 10:41:54	2020-02-20	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	12860	delivery	5	25
32674	2020-02-20 10:53:52	2020-02-20	8	[{"id_menu":5,"count":1}]	12918	delivery	5	13
32675	2020-02-20 10:56:17	2020-02-20	14	[{"id_menu":2,"count":1}]	8651	delivery	5	19
32676	2020-02-20 10:56:56	2020-02-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12914	delivery	5	23
32677	2020-02-20 11:07:52	2020-02-20	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	10151	pick-up	0	26
32678	2020-02-20 11:16:53	2020-02-20	12	[{"id_menu":1,"count":1}]	8905	pick-up	0	12
32679	2020-02-20 11:20:36	2020-02-20	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	12864	delivery	5	45
32680	2020-02-20 11:28:33	2020-02-20	9	[{"id_menu":6,"count":1}]	12907	delivery	5	14
32681	2020-02-20 11:34:29	2020-02-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4690	pick-up	0	23
32682	2020-02-20 11:38:38	2020-02-20	9	[{"id_menu":7,"count":1}]	12900	delivery	5	14
32683	2020-02-20 11:46:04	2020-02-20	14	[{"id_menu":2,"count":1}]	1896	delivery	5	19
32684	2020-02-20 11:51:10	2020-02-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	12532	pick-up	0	23
32685	2020-02-20 12:05:36	2020-02-20	12	[{"id_menu":1,"count":1}]	1212	pick-up	0	12
32686	2020-02-20 12:06:13	2020-02-20	12	[{"id_menu":1,"count":1}]	12919	pick-up	0	12
32687	2020-02-20 12:08:49	2020-02-20	17	[{"id_menu":4,"count":1}]	12139	pick-up	0	17
32688	2020-02-20 12:14:47	2020-02-20	14	[{"id_menu":2,"count":1}]	12939	delivery	5	19
32689	2020-02-20 12:19:53	2020-02-20	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12581	delivery	5	53
32690	2020-02-20 12:21:55	2020-02-20	9	[{"id_menu":7,"count":1}]	9762	delivery	5	14
32691	2020-02-20 12:24:24	2020-02-20	9	[{"id_menu":7,"count":1}]	12887	delivery	5	14
32692	2020-02-20 12:25:10	2020-02-20	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	299	delivery	5	26
32693	2020-02-20 12:34:18	2020-02-20	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	6377	delivery	5	36
32694	2020-02-20 12:37:00	2020-02-20	9	[{"id_menu":7,"count":1}]	6182	pick-up	0	9
32695	2020-02-20 12:37:02	2020-02-20	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	1170	delivery	5	29
32696	2020-02-20 12:37:23	2020-02-20	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12685	delivery	5	31
32697	2020-02-20 12:45:51	2020-02-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	10670	delivery	5	23
32698	2020-02-20 12:51:37	2020-02-20	14	[{"id_menu":2,"count":1}]	2477	pick-up	0	14
32699	2020-02-20 12:52:37	2020-02-20	9	[{"id_menu":7,"count":1}]	2290	pick-up	0	9
32700	2020-02-20 12:57:54	2020-02-20	9	[{"id_menu":7,"count":2}]	12852	delivery	5	14
32701	2020-02-20 13:11:05	2020-02-20	17	[{"id_menu":4,"count":1}]	1307	pick-up	0	17
32702	2020-02-20 13:14:39	2020-02-20	17	[{"id_menu":4,"count":1}]	358	pick-up	0	17
32703	2020-02-20 13:17:09	2020-02-20	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	9579	delivery	5	30
32704	2020-02-20 13:18:16	2020-02-20	17	[{"id_menu":4,"count":1}]	12869	delivery	5	22
32705	2020-02-20 13:26:39	2020-02-20	12	[{"id_menu":1,"count":1}]	8382	delivery	5	17
32706	2020-02-20 13:33:54	2020-02-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	10095	delivery	5	28
32707	2020-02-20 13:37:46	2020-02-20	9	[{"id_menu":7,"count":1}]	12891	delivery	5	14
32708	2020-02-20 13:43:42	2020-02-20	14	[{"id_menu":2,"count":1}]	4904	pick-up	0	14
32709	2020-02-20 13:48:21	2020-02-20	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":3}]	12926	delivery	5	26
32710	2020-02-20 13:55:52	2020-02-20	17	[{"id_menu":4,"count":1}]	1649	pick-up	0	17
32711	2020-02-20 14:06:12	2020-02-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	11695	delivery	5	28
32712	2020-02-20 14:10:56	2020-02-20	12	[{"id_menu":3,"count":2}]	10400	pick-up	0	12
32713	2020-02-20 14:14:34	2020-02-20	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10235	delivery	5	31
32714	2020-02-20 14:33:02	2020-02-20	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	8961	delivery	5	34
32715	2020-02-20 14:35:26	2020-02-20	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6081	delivery	5	44
32716	2020-02-20 14:39:38	2020-02-20	9	[{"id_menu":6,"count":1}]	382	pick-up	0	9
32717	2020-02-20 14:41:56	2020-02-20	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	2633	pick-up	0	20
32718	2020-02-20 14:49:41	2020-02-20	9	[{"id_menu":6,"count":1}]	12915	delivery	5	14
32719	2020-02-20 14:52:48	2020-02-20	17	[{"id_menu":4,"count":1}]	12938	delivery	5	22
32720	2020-02-20 14:59:23	2020-02-20	9	[{"id_menu":7,"count":1}]	4428	pick-up	0	9
32721	2020-02-20 15:01:49	2020-02-20	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	10452	delivery	5	31
32722	2020-02-20 15:03:50	2020-02-20	9	[{"id_menu":7,"count":1}]	4562	pick-up	0	9
32723	2020-02-20 15:18:18	2020-02-20	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	12885	delivery	5	22
32724	2020-02-20 15:31:31	2020-02-20	14	[{"id_menu":2,"count":1}]	12858	pick-up	0	14
32725	2020-02-20 15:32:43	2020-02-20	9	[{"id_menu":6,"count":1}]	12856	pick-up	0	9
32726	2020-02-20 15:36:21	2020-02-20	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12878	delivery	5	53
32727	2020-02-20 16:02:46	2020-02-20	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	12107	delivery	5	40
32728	2020-02-20 16:05:08	2020-02-20	8	[{"id_menu":5,"count":1}]	1847	pick-up	0	8
32729	2020-02-20 16:06:00	2020-02-20	14	[{"id_menu":2,"count":1}]	68	delivery	5	19
32730	2020-02-20 16:10:08	2020-02-20	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7279	delivery	5	48
32731	2020-02-20 16:21:09	2020-02-20	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	8676	delivery	5	34
32732	2020-02-20 16:33:43	2020-02-20	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	12925	delivery	5	40
32733	2020-02-20 16:36:39	2020-02-20	9	[{"id_menu":7,"count":1}]	2780	delivery	5	14
32734	2020-02-20 16:39:50	2020-02-20	9	[{"id_menu":7,"count":1}]	4824	delivery	5	14
32735	2020-02-20 16:41:46	2020-02-20	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	177	pick-up	0	26
32736	2020-02-20 16:42:40	2020-02-20	8	[{"id_menu":5,"count":1}]	12862	delivery	5	13
32737	2020-02-20 16:47:07	2020-02-20	9	[{"id_menu":7,"count":1}]	1695	delivery	5	14
32738	2020-02-20 16:57:22	2020-02-20	9	[{"id_menu":7,"count":1}]	573	delivery	5	14
32739	2020-02-20 16:58:40	2020-02-20	9	[{"id_menu":6,"count":1}]	7451	delivery	5	14
32740	2020-02-20 17:01:54	2020-02-20	9	[{"id_menu":6,"count":2}]	6790	pick-up	0	9
32741	2020-02-20 17:13:11	2020-02-20	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12854	delivery	5	40
32742	2020-02-20 17:13:53	2020-02-20	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11576	delivery	5	53
32743	2020-02-20 17:14:39	2020-02-20	12	[{"id_menu":1,"count":1}]	12902	delivery	5	17
32744	2020-02-20 17:14:55	2020-02-20	9	[{"id_menu":6,"count":1}]	7217	delivery	5	14
32745	2020-02-20 17:33:10	2020-02-20	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12857	delivery	5	39
32746	2020-02-20 17:45:31	2020-02-20	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12897	delivery	5	39
32747	2020-02-20 17:47:06	2020-02-20	14	[{"id_menu":2,"count":1}]	10903	delivery	5	19
32748	2020-02-20 17:59:34	2020-02-20	17	[{"id_menu":4,"count":1}]	8193	delivery	5	22
32749	2020-02-20 18:04:50	2020-02-20	14	[{"id_menu":2,"count":1}]	12866	delivery	5	19
32750	2020-02-20 18:05:03	2020-02-20	9	[{"id_menu":6,"count":1}]	10209	delivery	5	14
32751	2020-02-20 18:06:39	2020-02-20	8	[{"id_menu":5,"count":1}]	8585	delivery	5	13
32752	2020-02-20 18:13:42	2020-02-20	17	[{"id_menu":4,"count":1}]	4411	delivery	5	22
32753	2020-02-20 18:34:56	2020-02-20	9	[{"id_menu":7,"count":1}]	12909	delivery	5	14
32754	2020-02-20 18:38:26	2020-02-20	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7459	delivery	5	36
32755	2020-02-20 18:40:17	2020-02-20	8	[{"id_menu":5,"count":1}]	12936	delivery	5	13
32756	2020-02-20 18:41:33	2020-02-20	9	[{"id_menu":6,"count":1}]	12137	pick-up	0	9
32757	2020-02-20 18:41:46	2020-02-20	12	[{"id_menu":1,"count":1}]	2081	delivery	5	17
32758	2020-02-20 18:46:17	2020-02-20	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7521	delivery	5	36
32759	2020-02-20 18:50:08	2020-02-20	9	[{"id_menu":6,"count":1}]	9193	pick-up	0	9
32760	2020-02-20 18:55:38	2020-02-20	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	7541	delivery	5	31
32761	2020-02-20 18:59:19	2020-02-20	12	[{"id_menu":3,"count":2}]	12933	delivery	5	17
32762	2020-02-20 19:05:39	2020-02-20	9	[{"id_menu":7,"count":1}]	12917	delivery	5	14
32763	2020-02-20 19:08:14	2020-02-20	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	12888	delivery	5	40
32764	2020-02-20 19:16:03	2020-02-20	9	[{"id_menu":7,"count":1}]	5110	delivery	5	14
32765	2020-02-20 19:17:11	2020-02-20	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2576	pick-up	0	21
32766	2020-02-20 19:21:57	2020-02-20	12	[{"id_menu":1,"count":1}]	11732	pick-up	0	12
32767	2020-02-20 19:23:20	2020-02-20	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3380	pick-up	0	21
32768	2020-02-20 19:33:49	2020-02-20	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1302	pick-up	0	20
32769	2020-02-20 19:34:22	2020-02-20	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	3309	pick-up	0	21
32770	2020-02-20 19:36:12	2020-02-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	12870	delivery	5	28
32771	2020-02-20 19:46:24	2020-02-20	9	[{"id_menu":6,"count":1}]	12903	delivery	5	14
32772	2020-02-20 19:53:17	2020-02-20	9	[{"id_menu":6,"count":1}]	1696	pick-up	0	9
32773	2020-02-20 20:06:47	2020-02-20	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	12874	delivery	5	26
32774	2020-02-20 20:10:15	2020-02-20	12	[{"id_menu":3,"count":1}]	3868	pick-up	0	12
32775	2020-02-20 20:21:50	2020-02-20	12	[{"id_menu":3,"count":1}]	6310	delivery	5	17
32776	2020-02-20 20:24:41	2020-02-20	9	[{"id_menu":7,"count":1}]	2275	delivery	5	14
32777	2020-02-20 20:25:29	2020-02-20	17	[{"id_menu":4,"count":1}]	271	pick-up	0	17
32778	2020-02-20 20:35:33	2020-02-20	9	[{"id_menu":6,"count":1}]	506	pick-up	0	9
32779	2020-02-20 20:41:23	2020-02-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12875	delivery	5	22
32780	2020-02-20 20:41:48	2020-02-20	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2446	pick-up	0	26
32781	2020-02-20 20:51:42	2020-02-20	8	[{"id_menu":5,"count":1}]	6883	delivery	5	13
32782	2020-02-20 20:54:49	2020-02-20	9	[{"id_menu":7,"count":1}]	5698	delivery	5	14
32783	2020-02-20 20:54:56	2020-02-20	9	[{"id_menu":6,"count":1}]	6689	pick-up	0	9
32784	2020-02-20 20:58:59	2020-02-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12906	delivery	5	23
32785	2020-02-20 21:01:44	2020-02-20	17	[{"id_menu":4,"count":1}]	954	delivery	5	22
32786	2020-02-20 21:02:33	2020-02-20	12	[{"id_menu":1,"count":1}]	2272	pick-up	0	12
32787	2020-02-20 21:04:11	2020-02-20	8	[{"id_menu":5,"count":1}]	3106	delivery	5	13
32854	2020-02-21 04:10:20	2020-02-21	9	[{"id_menu":7,"count":1}]	8702	delivery	5	14
32788	2020-02-20 21:07:41	2020-02-20	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8361	delivery	5	31
32789	2020-02-20 21:10:00	2020-02-20	8	[{"id_menu":5,"count":1}]	11825	delivery	5	13
32790	2020-02-20 21:11:16	2020-02-20	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12893	delivery	5	31
32791	2020-02-20 21:18:35	2020-02-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8765	delivery	5	23
32792	2020-02-20 21:29:02	2020-02-20	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1117	delivery	5	37
32793	2020-02-20 21:38:52	2020-02-20	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	12876	delivery	5	40
32794	2020-02-20 21:42:26	2020-02-20	14	[{"id_menu":2,"count":1}]	8123	delivery	5	19
32795	2020-02-20 21:42:33	2020-02-20	9	[{"id_menu":6,"count":1}]	12923	pick-up	0	9
32796	2020-02-20 21:49:21	2020-02-20	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	12932	delivery	5	31
32797	2020-02-20 21:51:08	2020-02-20	14	[{"id_menu":2,"count":1}]	798	pick-up	0	14
32798	2020-02-20 21:55:01	2020-02-20	14	[{"id_menu":2,"count":1}]	9191	pick-up	0	14
32799	2020-02-20 22:02:21	2020-02-20	12	[{"id_menu":3,"count":1}]	12930	delivery	5	17
32800	2020-02-20 22:11:57	2020-02-20	14	[{"id_menu":2,"count":1}]	6248	delivery	5	19
32801	2020-02-20 22:14:43	2020-02-20	9	[{"id_menu":6,"count":1}]	8574	pick-up	0	9
32802	2020-02-20 22:16:11	2020-02-20	9	[{"id_menu":7,"count":1}]	11562	delivery	5	14
32803	2020-02-20 22:27:28	2020-02-20	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12931	pick-up	0	38
32804	2020-02-20 22:28:42	2020-02-20	17	[{"id_menu":4,"count":1}]	4400	delivery	5	22
32805	2020-02-20 22:40:03	2020-02-20	14	[{"id_menu":2,"count":1}]	9625	pick-up	0	14
32806	2020-02-20 22:49:00	2020-02-20	14	[{"id_menu":2,"count":1}]	7075	pick-up	0	14
32807	2020-02-20 22:49:24	2020-02-20	12	[{"id_menu":3,"count":1}]	12681	delivery	5	17
32808	2020-02-20 22:56:44	2020-02-20	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	552	delivery	5	22
32809	2020-02-20 23:00:08	2020-02-20	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	12904	delivery	5	40
32810	2020-02-20 23:20:42	2020-02-20	14	[{"id_menu":2,"count":1}]	6302	delivery	5	19
32811	2020-02-20 23:22:54	2020-02-20	9	[{"id_menu":7,"count":1}]	3061	delivery	5	14
32812	2020-02-20 23:22:56	2020-02-20	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	9097	pick-up	0	29
32813	2020-02-20 23:28:19	2020-02-20	14	[{"id_menu":2,"count":1}]	8234	delivery	5	19
32814	2020-02-20 23:28:27	2020-02-20	8	[{"id_menu":5,"count":1}]	12927	delivery	5	13
32815	2020-02-20 23:42:59	2020-02-20	17	[{"id_menu":4,"count":1}]	11237	delivery	5	22
32816	2020-02-20 23:47:15	2020-02-20	14	[{"id_menu":2,"count":1}]	12861	delivery	5	19
32817	2020-02-20 23:55:36	2020-02-20	12	[{"id_menu":1,"count":1}]	716	pick-up	0	12
32818	2020-02-20 23:58:03	2020-02-20	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10527	delivery	5	34
32819	2020-02-21 00:01:51	2020-02-21	9	[{"id_menu":6,"count":1}]	5629	delivery	5	14
32820	2020-02-21 00:10:11	2020-02-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	12940	delivery	5	28
32821	2020-02-21 00:11:49	2020-02-21	9	[{"id_menu":7,"count":1}]	5485	delivery	5	14
32822	2020-02-21 00:24:24	2020-02-21	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	13030	delivery	5	40
32823	2020-02-21 00:25:58	2020-02-21	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	440	delivery	5	40
32824	2020-02-21 00:31:12	2020-02-21	9	[{"id_menu":6,"count":1}]	9455	delivery	5	14
32825	2020-02-21 00:36:36	2020-02-21	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	5318	pick-up	0	20
32826	2020-02-21 00:44:24	2020-02-21	12	[{"id_menu":1,"count":1}]	9404	pick-up	0	12
32827	2020-02-21 00:55:37	2020-02-21	17	[{"id_menu":4,"count":1}]	4963	pick-up	0	17
32828	2020-02-21 00:59:22	2020-02-21	14	[{"id_menu":2,"count":1}]	4193	pick-up	0	14
32829	2020-02-21 01:03:28	2020-02-21	12	[{"id_menu":3,"count":1}]	4167	pick-up	0	12
32830	2020-02-21 01:08:44	2020-02-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7912	delivery	5	28
32831	2020-02-21 01:11:56	2020-02-21	17	[{"id_menu":4,"count":1}]	13003	delivery	5	22
32832	2020-02-21 01:36:07	2020-02-21	9	[{"id_menu":7,"count":1}]	13005	delivery	5	14
32833	2020-02-21 01:44:01	2020-02-21	9	[{"id_menu":6,"count":1}]	6293	delivery	5	14
32834	2020-02-21 01:50:59	2020-02-21	8	[{"id_menu":5,"count":1}]	2881	pick-up	0	8
32835	2020-02-21 01:52:04	2020-02-21	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	10909	delivery	5	36
32836	2020-02-21 01:55:55	2020-02-21	9	[{"id_menu":7,"count":1}]	3640	pick-up	0	9
32837	2020-02-21 02:03:57	2020-02-21	9	[{"id_menu":6,"count":1}]	12986	delivery	5	14
32838	2020-02-21 02:18:43	2020-02-21	12	[{"id_menu":3,"count":1}]	12988	delivery	5	17
32839	2020-02-21 02:31:40	2020-02-21	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1735	delivery	5	26
32840	2020-02-21 02:35:24	2020-02-21	9	[{"id_menu":7,"count":1}]	972	delivery	5	14
32841	2020-02-21 02:41:30	2020-02-21	12	[{"id_menu":1,"count":1}]	13024	delivery	5	17
32842	2020-02-21 02:41:55	2020-02-21	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7743	delivery	5	53
32843	2020-02-21 03:24:02	2020-02-21	9	[{"id_menu":6,"count":1}]	12990	pick-up	0	9
32844	2020-02-21 03:27:45	2020-02-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3688	delivery	5	28
32845	2020-02-21 03:37:56	2020-02-21	9	[{"id_menu":7,"count":1}]	7465	pick-up	0	9
32846	2020-02-21 03:43:20	2020-02-21	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	11983	delivery	5	39
32847	2020-02-21 03:43:38	2020-02-21	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	688	pick-up	0	39
32848	2020-02-21 03:44:55	2020-02-21	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1830	delivery	5	26
32849	2020-02-21 03:48:55	2020-02-21	17	[{"id_menu":4,"count":1}]	13009	delivery	5	22
32850	2020-02-21 03:56:28	2020-02-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	1457	delivery	5	23
32851	2020-02-21 03:58:24	2020-02-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6453	delivery	5	28
32852	2020-02-21 03:59:32	2020-02-21	17	[{"id_menu":4,"count":1}]	12965	pick-up	0	17
32853	2020-02-21 04:00:44	2020-02-21	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	318	delivery	5	40
32855	2020-02-21 04:20:08	2020-02-21	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	5888	delivery	5	43
32856	2020-02-21 04:24:16	2020-02-21	9	[{"id_menu":7,"count":1}]	13017	delivery	5	14
32857	2020-02-21 04:34:44	2020-02-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11792	delivery	5	31
32858	2020-02-21 04:39:20	2020-02-21	14	[{"id_menu":2,"count":1}]	313	pick-up	0	14
32859	2020-02-21 04:40:00	2020-02-21	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	12989	delivery	5	34
32860	2020-02-21 04:41:13	2020-02-21	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9052	delivery	5	45
32861	2020-02-21 04:46:43	2020-02-21	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	12012	pick-up	0	20
32862	2020-02-21 04:57:00	2020-02-21	9	[{"id_menu":7,"count":1}]	12963	delivery	5	14
32863	2020-02-21 05:03:08	2020-02-21	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6037	pick-up	0	38
32864	2020-02-21 05:04:49	2020-02-21	9	[{"id_menu":7,"count":1}]	4786	delivery	5	14
32865	2020-02-21 05:08:31	2020-02-21	9	[{"id_menu":7,"count":1}]	10256	delivery	5	14
32866	2020-02-21 05:11:06	2020-02-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	13022	delivery	5	31
32867	2020-02-21 05:11:21	2020-02-21	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	10706	delivery	5	26
32868	2020-02-21 05:16:04	2020-02-21	14	[{"id_menu":2,"count":1}]	1597	pick-up	0	14
32869	2020-02-21 05:18:06	2020-02-21	17	[{"id_menu":4,"count":1}]	7271	delivery	5	22
32870	2020-02-21 05:28:50	2020-02-21	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10952	delivery	5	39
32871	2020-02-21 05:33:08	2020-02-21	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	6305	delivery	5	27
32872	2020-02-21 05:34:26	2020-02-21	12	[{"id_menu":3,"count":1}]	2928	pick-up	0	12
32873	2020-02-21 05:48:18	2020-02-21	9	[{"id_menu":6,"count":1}]	2039	delivery	5	14
32874	2020-02-21 05:49:02	2020-02-21	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	13010	delivery	5	40
32875	2020-02-21 05:49:31	2020-02-21	17	[{"id_menu":4,"count":1}]	13025	pick-up	0	17
32876	2020-02-21 05:56:34	2020-02-21	9	[{"id_menu":6,"count":1}]	4552	delivery	5	14
32877	2020-02-21 05:58:01	2020-02-21	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1118	pick-up	0	29
32878	2020-02-21 05:59:08	2020-02-21	9	[{"id_menu":7,"count":1}]	12961	delivery	5	14
32879	2020-02-21 06:05:11	2020-02-21	12	[{"id_menu":1,"count":1}]	9198	pick-up	0	12
32880	2020-02-21 06:05:21	2020-02-21	12	[{"id_menu":3,"count":1}]	1282	delivery	5	17
32881	2020-02-21 06:13:23	2020-02-21	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	13020	delivery	5	43
32882	2020-02-21 06:34:02	2020-02-21	23	[{"id_menu":2,"count":3},{"id_menu":6,"count":1}]	12952	delivery	5	28
32883	2020-02-21 06:49:08	2020-02-21	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	12981	delivery	5	23
32884	2020-02-21 06:52:52	2020-02-21	9	[{"id_menu":6,"count":1}]	3111	delivery	5	14
32885	2020-02-21 06:59:53	2020-02-21	12	[{"id_menu":1,"count":1}]	12895	delivery	5	17
32886	2020-02-21 07:05:09	2020-02-21	12	[{"id_menu":3,"count":1}]	1369	delivery	5	17
32887	2020-02-21 07:07:33	2020-02-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13012	delivery	5	22
32888	2020-02-21 07:25:01	2020-02-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	10108	delivery	5	28
32889	2020-02-21 07:32:18	2020-02-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	717	pick-up	0	17
32890	2020-02-21 07:34:09	2020-02-21	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1289	pick-up	0	21
32891	2020-02-21 07:34:40	2020-02-21	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	7650	delivery	5	25
32892	2020-02-21 07:55:08	2020-02-21	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	10142	delivery	5	23
32893	2020-02-21 07:56:30	2020-02-21	9	[{"id_menu":6,"count":1}]	1018	delivery	5	14
32894	2020-02-21 07:56:36	2020-02-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	537	delivery	5	28
32895	2020-02-21 08:10:11	2020-02-21	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12283	pick-up	0	31
32896	2020-02-21 08:18:05	2020-02-21	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	5020	delivery	5	26
32897	2020-02-21 08:20:07	2020-02-21	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	3222	pick-up	0	30
32898	2020-02-21 08:21:21	2020-02-21	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3987	pick-up	0	40
32899	2020-02-21 08:24:37	2020-02-21	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	10815	delivery	5	28
32900	2020-02-21 08:34:53	2020-02-21	17	[{"id_menu":4,"count":1}]	3242	pick-up	0	17
32901	2020-02-21 08:39:10	2020-02-21	14	[{"id_menu":2,"count":1}]	3084	delivery	5	19
32902	2020-02-21 08:55:07	2020-02-21	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4704	delivery	5	35
32903	2020-02-21 09:04:41	2020-02-21	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12109	delivery	5	40
32904	2020-02-21 09:11:52	2020-02-21	12	[{"id_menu":3,"count":1}]	715	pick-up	0	12
32905	2020-02-21 09:13:51	2020-02-21	14	[{"id_menu":2,"count":1}]	806	delivery	5	19
32906	2020-02-21 09:20:26	2020-02-21	17	[{"id_menu":4,"count":1}]	853	delivery	5	22
32907	2020-02-21 09:24:08	2020-02-21	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13004	delivery	5	37
32908	2020-02-21 09:27:00	2020-02-21	9	[{"id_menu":6,"count":2}]	13016	delivery	5	14
32909	2020-02-21 09:35:19	2020-02-21	9	[{"id_menu":6,"count":1}]	8568	delivery	5	14
32910	2020-02-21 09:45:14	2020-02-21	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2139	pick-up	0	29
32911	2020-02-21 10:04:31	2020-02-21	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12974	delivery	5	55
32912	2020-02-21 10:32:54	2020-02-21	9	[{"id_menu":7,"count":1}]	11636	delivery	5	14
32913	2020-02-21 10:51:12	2020-02-21	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	5979	delivery	5	48
32914	2020-02-21 10:56:49	2020-02-21	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	12948	delivery	5	31
32915	2020-02-21 10:58:08	2020-02-21	14	[{"id_menu":2,"count":1}]	10505	delivery	5	19
32916	2020-02-21 11:02:28	2020-02-21	12	[{"id_menu":3,"count":1}]	905	delivery	5	17
32917	2020-02-21 11:03:16	2020-02-21	12	[{"id_menu":3,"count":1}]	6715	delivery	5	17
32918	2020-02-21 11:11:17	2020-02-21	14	[{"id_menu":2,"count":1}]	10589	pick-up	0	14
32919	2020-02-21 11:11:30	2020-02-21	9	[{"id_menu":7,"count":1}]	9043	pick-up	0	9
32920	2020-02-21 11:25:37	2020-02-21	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	1076	delivery	5	26
32921	2020-02-21 11:31:29	2020-02-21	12	[{"id_menu":1,"count":1}]	7217	delivery	5	17
32922	2020-02-21 11:32:02	2020-02-21	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	13008	delivery	5	45
32923	2020-02-21 11:33:27	2020-02-21	12	[{"id_menu":1,"count":1}]	837	pick-up	0	12
32924	2020-02-21 11:34:21	2020-02-21	17	[{"id_menu":4,"count":1}]	12336	delivery	5	22
32925	2020-02-21 11:35:30	2020-02-21	8	[{"id_menu":5,"count":1}]	3952	delivery	5	13
32926	2020-02-21 11:38:50	2020-02-21	14	[{"id_menu":2,"count":1}]	2091	pick-up	0	14
32927	2020-02-21 11:54:02	2020-02-21	8	[{"id_menu":5,"count":1}]	13018	delivery	5	13
32928	2020-02-21 11:56:54	2020-02-21	8	[{"id_menu":5,"count":1}]	3343	delivery	5	13
32929	2020-02-21 11:59:05	2020-02-21	9	[{"id_menu":6,"count":1}]	2843	delivery	5	14
32930	2020-02-21 12:03:00	2020-02-21	8	[{"id_menu":5,"count":2}]	12953	delivery	5	13
32931	2020-02-21 12:10:54	2020-02-21	49	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8121	delivery	5	54
32932	2020-02-21 12:15:33	2020-02-21	12	[{"id_menu":1,"count":1}]	4137	delivery	5	17
32933	2020-02-21 12:24:38	2020-02-21	9	[{"id_menu":7,"count":1}]	1168	pick-up	0	9
32934	2020-02-21 12:24:49	2020-02-21	12	[{"id_menu":1,"count":1}]	10632	pick-up	0	12
32935	2020-02-21 12:38:30	2020-02-21	14	[{"id_menu":2,"count":1}]	3988	delivery	5	19
32936	2020-02-21 12:38:34	2020-02-21	9	[{"id_menu":7,"count":1}]	3601	pick-up	0	9
32937	2020-02-21 12:39:31	2020-02-21	9	[{"id_menu":6,"count":1}]	13019	pick-up	0	9
32938	2020-02-21 12:45:39	2020-02-21	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	12945	delivery	5	25
32939	2020-02-21 12:58:46	2020-02-21	39	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10717	pick-up	0	39
32940	2020-02-21 13:00:55	2020-02-21	9	[{"id_menu":6,"count":1}]	2591	pick-up	0	9
32941	2020-02-21 13:16:05	2020-02-21	9	[{"id_menu":7,"count":1}]	1053	delivery	5	14
32942	2020-02-21 13:28:35	2020-02-21	8	[{"id_menu":5,"count":1}]	12959	delivery	5	13
32943	2020-02-21 13:39:33	2020-02-21	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	12985	delivery	5	48
32944	2020-02-21 13:47:34	2020-02-21	12	[{"id_menu":3,"count":1}]	12541	pick-up	0	12
32945	2020-02-21 13:49:21	2020-02-21	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	12983	delivery	5	26
32946	2020-02-21 13:59:09	2020-02-21	14	[{"id_menu":2,"count":1}]	2955	delivery	5	19
32947	2020-02-21 13:59:52	2020-02-21	9	[{"id_menu":7,"count":1}]	12958	pick-up	0	9
32948	2020-02-21 13:59:59	2020-02-21	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10366	delivery	5	53
32949	2020-02-21 14:19:45	2020-02-21	9	[{"id_menu":6,"count":1}]	5786	delivery	5	14
32950	2020-02-21 14:32:52	2020-02-21	12	[{"id_menu":1,"count":1}]	6765	delivery	5	17
32951	2020-02-21 14:35:41	2020-02-21	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1526	pick-up	0	22
32952	2020-02-21 14:37:38	2020-02-21	9	[{"id_menu":7,"count":1}]	7069	delivery	5	14
32953	2020-02-21 14:39:16	2020-02-21	14	[{"id_menu":2,"count":1}]	2579	delivery	5	19
32954	2020-02-21 14:40:22	2020-02-21	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	12941	delivery	5	34
32955	2020-02-21 14:44:34	2020-02-21	9	[{"id_menu":6,"count":1}]	12238	delivery	5	14
32956	2020-02-21 15:11:21	2020-02-21	8	[{"id_menu":5,"count":1}]	10802	delivery	5	13
32957	2020-02-21 15:13:07	2020-02-21	9	[{"id_menu":7,"count":1}]	13015	delivery	5	14
32958	2020-02-21 15:14:13	2020-02-21	12	[{"id_menu":3,"count":1}]	2055	delivery	5	17
32959	2020-02-21 15:22:14	2020-02-21	14	[{"id_menu":2,"count":1}]	2307	pick-up	0	14
32960	2020-02-21 15:22:50	2020-02-21	12	[{"id_menu":3,"count":1}]	12943	delivery	5	17
32961	2020-02-21 15:26:45	2020-02-21	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5585	delivery	5	34
32962	2020-02-21 15:32:45	2020-02-21	12	[{"id_menu":1,"count":1}]	113	delivery	5	17
32963	2020-02-21 15:35:13	2020-02-21	9	[{"id_menu":7,"count":1}]	12975	delivery	5	14
32964	2020-02-21 15:49:51	2020-02-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11431	delivery	5	22
32965	2020-02-21 16:04:44	2020-02-21	17	[{"id_menu":4,"count":1}]	4598	delivery	5	22
32966	2020-02-21 16:14:31	2020-02-21	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1233	pick-up	0	34
32967	2020-02-21 16:16:22	2020-02-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11616	delivery	5	31
32968	2020-02-21 16:20:50	2020-02-21	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6811	delivery	5	45
32969	2020-02-21 16:20:56	2020-02-21	9	[{"id_menu":7,"count":1}]	12966	delivery	5	14
32970	2020-02-21 16:25:12	2020-02-21	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	957	pick-up	0	25
32971	2020-02-21 16:25:29	2020-02-21	17	[{"id_menu":4,"count":1}]	12980	delivery	5	22
32972	2020-02-21 16:37:36	2020-02-21	12	[{"id_menu":3,"count":1}]	1409	pick-up	0	12
32973	2020-02-21 16:42:39	2020-02-21	9	[{"id_menu":6,"count":1}]	1528	pick-up	0	9
32974	2020-02-21 16:45:09	2020-02-21	9	[{"id_menu":7,"count":1}]	12984	delivery	5	14
32975	2020-02-21 16:45:58	2020-02-21	14	[{"id_menu":2,"count":1}]	41	pick-up	0	14
32976	2020-02-21 16:50:07	2020-02-21	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	12996	delivery	5	25
32977	2020-02-21 16:53:47	2020-02-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5640	delivery	5	22
32978	2020-02-21 16:56:59	2020-02-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	354	delivery	5	28
32979	2020-02-21 16:58:05	2020-02-21	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11457	delivery	5	34
32980	2020-02-21 16:59:26	2020-02-21	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1751	pick-up	0	26
32981	2020-02-21 17:03:36	2020-02-21	9	[{"id_menu":6,"count":1}]	2898	pick-up	0	9
32982	2020-02-21 17:16:33	2020-02-21	9	[{"id_menu":6,"count":1}]	8873	pick-up	0	9
32983	2020-02-21 17:17:54	2020-02-21	9	[{"id_menu":6,"count":1}]	3173	delivery	5	14
32984	2020-02-21 17:21:11	2020-02-21	9	[{"id_menu":6,"count":1}]	12977	delivery	5	14
32985	2020-02-21 17:23:36	2020-02-21	9	[{"id_menu":7,"count":1}]	12956	delivery	5	14
32986	2020-02-21 17:24:15	2020-02-21	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	4495	delivery	5	26
32987	2020-02-21 17:34:23	2020-02-21	29	[{"id_menu":3,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11187	delivery	5	34
32988	2020-02-21 17:39:04	2020-02-21	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	12982	pick-up	0	29
32989	2020-02-21 17:43:22	2020-02-21	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	12964	delivery	5	26
32990	2020-02-21 17:45:53	2020-02-21	8	[{"id_menu":5,"count":2}]	8668	pick-up	0	8
32991	2020-02-21 17:48:18	2020-02-21	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13021	delivery	5	43
32992	2020-02-21 17:52:55	2020-02-21	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5613	delivery	5	34
32993	2020-02-21 17:57:06	2020-02-21	12	[{"id_menu":3,"count":1}]	13013	pick-up	0	12
32994	2020-02-21 17:59:14	2020-02-21	14	[{"id_menu":2,"count":3}]	5191	delivery	5	19
32995	2020-02-21 18:00:59	2020-02-21	17	[{"id_menu":4,"count":1}]	12947	delivery	5	22
32996	2020-02-21 18:04:38	2020-02-21	9	[{"id_menu":7,"count":1}]	12954	delivery	5	14
32997	2020-02-21 18:29:05	2020-02-21	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	4274	pick-up	0	20
32998	2020-02-21 18:33:04	2020-02-21	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	7951	delivery	5	43
32999	2020-02-21 18:47:27	2020-02-21	8	[{"id_menu":5,"count":1}]	6698	delivery	5	13
33000	2020-02-21 18:51:56	2020-02-21	9	[{"id_menu":7,"count":1}]	12998	delivery	5	14
33001	2020-02-21 18:56:58	2020-02-21	9	[{"id_menu":6,"count":1}]	12960	delivery	5	14
33002	2020-02-21 19:07:51	2020-02-21	17	[{"id_menu":4,"count":1}]	381	pick-up	0	17
33003	2020-02-21 19:08:56	2020-02-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4235	pick-up	0	18
33004	2020-02-21 19:20:00	2020-02-21	8	[{"id_menu":5,"count":1}]	13023	delivery	5	13
33005	2020-02-21 19:26:50	2020-02-21	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	13014	delivery	5	34
33006	2020-02-21 19:35:21	2020-02-21	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	13002	delivery	5	25
33007	2020-02-21 19:43:42	2020-02-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8187	delivery	5	22
33008	2020-02-21 19:43:56	2020-02-21	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12864	delivery	5	57
33009	2020-02-21 19:45:48	2020-02-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2263	delivery	5	31
33010	2020-02-21 19:46:16	2020-02-21	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2482	pick-up	0	35
33011	2020-02-21 19:50:41	2020-02-21	12	[{"id_menu":3,"count":1}]	154	delivery	5	17
33012	2020-02-21 19:54:47	2020-02-21	17	[{"id_menu":5,"count":3},{"id_menu":6,"count":1}]	5274	delivery	5	22
33013	2020-02-21 19:57:36	2020-02-21	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12949	delivery	5	48
33014	2020-02-21 19:58:57	2020-02-21	17	[{"id_menu":4,"count":1}]	12944	delivery	5	22
33015	2020-02-21 20:01:08	2020-02-21	9	[{"id_menu":6,"count":1}]	10184	delivery	5	14
33016	2020-02-21 20:07:15	2020-02-21	9	[{"id_menu":7,"count":1}]	1967	pick-up	0	9
33017	2020-02-21 20:07:25	2020-02-21	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	13011	delivery	5	39
33018	2020-02-21 20:15:25	2020-02-21	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12979	delivery	5	43
33019	2020-02-21 20:16:04	2020-02-21	8	[{"id_menu":5,"count":1}]	5428	delivery	5	13
33020	2020-02-21 20:17:51	2020-02-21	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11596	delivery	5	37
33021	2020-02-21 20:20:06	2020-02-21	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10458	delivery	5	39
33022	2020-02-21 20:25:33	2020-02-21	14	[{"id_menu":2,"count":2}]	7496	pick-up	0	14
33023	2020-02-21 20:33:22	2020-02-21	9	[{"id_menu":6,"count":1}]	2078	pick-up	0	9
33024	2020-02-21 20:34:29	2020-02-21	9	[{"id_menu":6,"count":1}]	12968	delivery	5	14
33025	2020-02-21 20:36:03	2020-02-21	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3835	delivery	5	35
33026	2020-02-21 20:36:42	2020-02-21	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	12971	delivery	5	25
33027	2020-02-21 20:40:22	2020-02-21	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	12129	pick-up	0	29
33028	2020-02-21 20:41:40	2020-02-21	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10367	delivery	5	40
33029	2020-02-21 20:43:03	2020-02-21	8	[{"id_menu":5,"count":1}]	12942	delivery	5	13
33030	2020-02-21 20:48:51	2020-02-21	9	[{"id_menu":6,"count":1}]	12962	pick-up	0	9
33031	2020-02-21 20:51:38	2020-02-21	17	[{"id_menu":4,"count":1}]	13027	delivery	5	22
33032	2020-02-21 21:02:01	2020-02-21	8	[{"id_menu":5,"count":1}]	12951	delivery	5	13
33033	2020-02-21 21:03:02	2020-02-21	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":2}]	9440	delivery	5	31
33034	2020-02-21 21:03:02	2020-02-21	9	[{"id_menu":7,"count":2}]	4418	delivery	5	14
33035	2020-02-21 21:15:41	2020-02-21	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	13007	pick-up	0	35
33036	2020-02-21 21:28:53	2020-02-21	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12760	delivery	5	36
33037	2020-02-21 21:29:37	2020-02-21	9	[{"id_menu":6,"count":1}]	1507	delivery	5	14
33038	2020-02-21 21:37:11	2020-02-21	17	[{"id_menu":4,"count":1}]	13000	delivery	5	22
33039	2020-02-21 21:41:06	2020-02-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":3}]	12991	delivery	5	23
33040	2020-02-21 21:42:27	2020-02-21	9	[{"id_menu":6,"count":1}]	3271	delivery	5	14
33041	2020-02-21 21:50:17	2020-02-21	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	12934	delivery	5	26
33042	2020-02-21 22:01:35	2020-02-21	14	[{"id_menu":2,"count":2}]	612	pick-up	0	14
33043	2020-02-21 22:09:40	2020-02-21	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	9746	delivery	5	30
33044	2020-02-21 22:15:39	2020-02-21	8	[{"id_menu":5,"count":1}]	350	pick-up	0	8
33045	2020-02-21 22:28:11	2020-02-21	9	[{"id_menu":6,"count":2}]	12599	delivery	5	14
33046	2020-02-21 22:34:54	2020-02-21	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":2}]	10167	delivery	5	22
33047	2020-02-21 22:37:48	2020-02-21	12	[{"id_menu":3,"count":1}]	2526	delivery	5	17
33048	2020-02-21 22:43:24	2020-02-21	14	[{"id_menu":2,"count":1}]	916	pick-up	0	14
33049	2020-02-21 22:47:33	2020-02-21	9	[{"id_menu":7,"count":1}]	13006	delivery	5	14
33050	2020-02-21 22:54:42	2020-02-21	9	[{"id_menu":6,"count":1}]	12993	delivery	5	14
33051	2020-02-21 22:58:23	2020-02-21	8	[{"id_menu":5,"count":1}]	10179	delivery	5	13
33052	2020-02-21 23:00:49	2020-02-21	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3174	pick-up	0	21
33053	2020-02-21 23:01:58	2020-02-21	12	[{"id_menu":3,"count":1}]	12976	delivery	5	17
33054	2020-02-21 23:05:08	2020-02-21	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12994	delivery	5	57
33055	2020-02-21 23:09:03	2020-02-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3838	delivery	5	28
33056	2020-02-21 23:15:02	2020-02-21	17	[{"id_menu":4,"count":1}]	13026	pick-up	0	17
33057	2020-02-21 23:17:14	2020-02-21	9	[{"id_menu":6,"count":1}]	1684	pick-up	0	9
33058	2020-02-21 23:22:34	2020-02-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3730	pick-up	0	18
33059	2020-02-21 23:38:26	2020-02-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	12995	delivery	5	28
33060	2020-02-21 23:42:37	2020-02-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	11586	delivery	5	28
33061	2020-02-21 23:46:51	2020-02-21	9	[{"id_menu":6,"count":1}]	12950	delivery	5	14
33062	2020-02-21 23:51:42	2020-02-21	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1700	pick-up	0	38
33063	2020-02-21 23:59:48	2020-02-21	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	13028	pick-up	0	26
33064	2020-02-22 00:06:30	2020-02-22	17	[{"id_menu":4,"count":1}]	3420	pick-up	0	17
33065	2020-02-22 00:07:56	2020-02-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	382	delivery	5	22
33066	2020-02-22 00:12:03	2020-02-22	14	[{"id_menu":2,"count":1}]	13104	delivery	5	19
33067	2020-02-22 00:12:37	2020-02-22	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	13142	delivery	5	34
33068	2020-02-22 00:19:29	2020-02-22	8	[{"id_menu":5,"count":1}]	3227	pick-up	0	8
33069	2020-02-22 00:20:11	2020-02-22	9	[{"id_menu":6,"count":1}]	6328	pick-up	0	9
33070	2020-02-22 00:21:14	2020-02-22	12	[{"id_menu":3,"count":2}]	11026	pick-up	0	12
33071	2020-02-22 00:27:34	2020-02-22	9	[{"id_menu":7,"count":1}]	13086	delivery	5	14
33072	2020-02-22 00:29:41	2020-02-22	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13032	delivery	5	34
33073	2020-02-22 00:35:44	2020-02-22	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	4301	delivery	5	26
33074	2020-02-22 00:36:02	2020-02-22	9	[{"id_menu":7,"count":2}]	4198	delivery	5	14
33075	2020-02-22 00:48:07	2020-02-22	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	13120	pick-up	0	35
33076	2020-02-22 00:48:51	2020-02-22	14	[{"id_menu":2,"count":1}]	623	delivery	5	19
33077	2020-02-22 00:52:32	2020-02-22	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	111	delivery	5	29
33078	2020-02-22 00:54:19	2020-02-22	14	[{"id_menu":2,"count":1}]	931	pick-up	0	14
33079	2020-02-22 01:01:07	2020-02-22	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2392	pick-up	0	26
33080	2020-02-22 01:06:39	2020-02-22	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	3052	pick-up	0	23
33081	2020-02-22 01:07:40	2020-02-22	12	[{"id_menu":3,"count":1}]	1295	pick-up	0	12
33082	2020-02-22 01:11:31	2020-02-22	8	[{"id_menu":5,"count":1}]	10645	delivery	5	13
33083	2020-02-22 01:14:22	2020-02-22	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":2}]	5034	delivery	5	31
33084	2020-02-22 01:15:59	2020-02-22	14	[{"id_menu":2,"count":1}]	13162	delivery	5	19
33085	2020-02-22 01:23:13	2020-02-22	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	315	pick-up	0	21
33086	2020-02-22 01:23:43	2020-02-22	12	[{"id_menu":3,"count":1}]	4536	pick-up	0	12
33087	2020-02-22 01:28:59	2020-02-22	17	[{"id_menu":4,"count":1}]	13109	delivery	5	22
33088	2020-02-22 01:31:36	2020-02-22	8	[{"id_menu":5,"count":1}]	13066	delivery	5	13
33089	2020-02-22 01:32:43	2020-02-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7815	pick-up	0	18
33090	2020-02-22 01:32:48	2020-02-22	8	[{"id_menu":5,"count":1}]	13139	pick-up	0	8
33091	2020-02-22 01:33:42	2020-02-22	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10211	delivery	5	35
33092	2020-02-22 01:34:05	2020-02-22	14	[{"id_menu":2,"count":1}]	1585	pick-up	0	14
33093	2020-02-22 01:36:24	2020-02-22	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	9581	delivery	5	26
33094	2020-02-22 01:39:10	2020-02-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6186	pick-up	0	23
33095	2020-02-22 01:40:12	2020-02-22	9	[{"id_menu":7,"count":1}]	13042	delivery	5	14
33096	2020-02-22 01:46:11	2020-02-22	8	[{"id_menu":5,"count":1}]	13097	delivery	5	13
33097	2020-02-22 01:47:35	2020-02-22	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10389	pick-up	0	31
33098	2020-02-22 02:05:22	2020-02-22	9	[{"id_menu":7,"count":1}]	13138	delivery	5	14
33099	2020-02-22 02:06:32	2020-02-22	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	5273	delivery	5	26
33100	2020-02-22 02:13:11	2020-02-22	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9052	delivery	5	36
33101	2020-02-22 02:15:18	2020-02-22	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3792	delivery	5	43
33102	2020-02-22 02:18:46	2020-02-22	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13137	delivery	5	31
33103	2020-02-22 02:27:10	2020-02-22	17	[{"id_menu":4,"count":1}]	11554	pick-up	0	17
33104	2020-02-22 02:28:46	2020-02-22	8	[{"id_menu":5,"count":1}]	2592	delivery	5	13
33105	2020-02-22 02:31:31	2020-02-22	9	[{"id_menu":7,"count":1}]	7517	pick-up	0	9
33106	2020-02-22 02:33:00	2020-02-22	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1700	delivery	5	31
33107	2020-02-22 02:37:21	2020-02-22	9	[{"id_menu":7,"count":1}]	13059	delivery	5	14
33108	2020-02-22 02:38:20	2020-02-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13143	delivery	5	23
33109	2020-02-22 02:42:04	2020-02-22	8	[{"id_menu":5,"count":1}]	9248	delivery	5	13
33110	2020-02-22 02:43:47	2020-02-22	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13160	delivery	5	22
33111	2020-02-22 02:49:39	2020-02-22	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3611	delivery	5	39
33112	2020-02-22 03:00:01	2020-02-22	12	[{"id_menu":1,"count":1}]	6386	delivery	5	17
33113	2020-02-22 03:00:09	2020-02-22	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	4374	delivery	5	22
33114	2020-02-22 03:13:05	2020-02-22	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	6645	pick-up	0	21
33115	2020-02-22 03:15:20	2020-02-22	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":2}]	9227	delivery	5	22
33116	2020-02-22 03:23:06	2020-02-22	17	[{"id_menu":4,"count":1}]	451	pick-up	0	17
33117	2020-02-22 03:28:39	2020-02-22	12	[{"id_menu":1,"count":1}]	2317	pick-up	0	12
33118	2020-02-22 03:32:57	2020-02-22	17	[{"id_menu":4,"count":1}]	2252	delivery	5	22
33119	2020-02-22 03:34:35	2020-02-22	9	[{"id_menu":6,"count":1}]	2438	pick-up	0	9
33120	2020-02-22 03:43:29	2020-02-22	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	10097	delivery	5	29
33121	2020-02-22 03:50:14	2020-02-22	9	[{"id_menu":7,"count":1}]	3085	pick-up	0	9
33122	2020-02-22 03:52:55	2020-02-22	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	13117	delivery	5	34
33123	2020-02-22 04:05:22	2020-02-22	14	[{"id_menu":2,"count":1}]	7247	delivery	5	19
33124	2020-02-22 04:06:02	2020-02-22	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	5768	delivery	5	26
33125	2020-02-22 04:09:36	2020-02-22	9	[{"id_menu":7,"count":1}]	10578	delivery	5	14
33126	2020-02-22 04:19:01	2020-02-22	12	[{"id_menu":1,"count":2}]	703	delivery	5	17
33127	2020-02-22 04:22:37	2020-02-22	17	[{"id_menu":4,"count":1}]	13158	delivery	5	22
33128	2020-02-22 04:28:45	2020-02-22	9	[{"id_menu":6,"count":1}]	13047	delivery	5	14
33129	2020-02-22 04:29:25	2020-02-22	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	10528	delivery	5	40
33130	2020-02-22 04:31:24	2020-02-22	17	[{"id_menu":4,"count":1}]	5933	pick-up	0	17
33131	2020-02-22 04:32:40	2020-02-22	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3483	pick-up	0	22
33132	2020-02-22 04:35:00	2020-02-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11315	delivery	5	23
33133	2020-02-22 04:37:34	2020-02-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13068	pick-up	0	18
33134	2020-02-22 04:44:31	2020-02-22	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	13046	delivery	5	36
33135	2020-02-22 04:46:09	2020-02-22	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13169	delivery	5	35
33136	2020-02-22 05:02:58	2020-02-22	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	8853	pick-up	0	35
33137	2020-02-22 05:05:33	2020-02-22	14	[{"id_menu":2,"count":1}]	7611	delivery	5	19
33138	2020-02-22 05:06:57	2020-02-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13164	delivery	5	23
33139	2020-02-22 05:09:21	2020-02-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	13129	delivery	5	22
33140	2020-02-22 05:17:09	2020-02-22	9	[{"id_menu":7,"count":2}]	4379	delivery	5	14
33141	2020-02-22 05:18:17	2020-02-22	12	[{"id_menu":1,"count":1}]	2384	delivery	5	17
33142	2020-02-22 05:21:10	2020-02-22	9	[{"id_menu":7,"count":1}]	6744	delivery	5	14
33143	2020-02-22 05:27:55	2020-02-22	14	[{"id_menu":2,"count":1}]	2893	delivery	5	19
33144	2020-02-22 05:30:37	2020-02-22	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	6015	delivery	5	40
33145	2020-02-22 05:37:51	2020-02-22	12	[{"id_menu":3,"count":1}]	124	pick-up	0	12
33146	2020-02-22 05:41:56	2020-02-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2827	delivery	5	36
33147	2020-02-22 05:43:10	2020-02-22	8	[{"id_menu":5,"count":1}]	10850	delivery	5	13
33148	2020-02-22 05:43:57	2020-02-22	9	[{"id_menu":7,"count":1}]	8887	pick-up	0	9
33149	2020-02-22 05:45:16	2020-02-22	12	[{"id_menu":3,"count":1}]	5701	pick-up	0	12
33150	2020-02-22 05:45:59	2020-02-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13044	delivery	5	22
33151	2020-02-22 05:50:01	2020-02-22	9	[{"id_menu":6,"count":1}]	13146	delivery	5	14
33152	2020-02-22 05:53:53	2020-02-22	9	[{"id_menu":7,"count":1}]	2932	pick-up	0	9
33153	2020-02-22 05:55:51	2020-02-22	12	[{"id_menu":3,"count":1}]	4357	delivery	5	17
33154	2020-02-22 05:59:23	2020-02-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6565	delivery	5	36
33155	2020-02-22 06:01:39	2020-02-22	9	[{"id_menu":6,"count":1}]	5388	delivery	5	14
33156	2020-02-22 06:09:49	2020-02-22	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	13035	delivery	5	27
33157	2020-02-22 06:12:16	2020-02-22	12	[{"id_menu":1,"count":1}]	13106	delivery	5	17
33158	2020-02-22 06:14:47	2020-02-22	9	[{"id_menu":6,"count":1}]	2567	pick-up	0	9
33159	2020-02-22 06:18:16	2020-02-22	9	[{"id_menu":6,"count":1}]	2112	pick-up	0	9
33160	2020-02-22 06:33:02	2020-02-22	14	[{"id_menu":2,"count":1}]	10954	pick-up	0	14
33161	2020-02-22 06:46:34	2020-02-22	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	13094	delivery	5	43
33162	2020-02-22 06:55:19	2020-02-22	12	[{"id_menu":3,"count":2}]	6469	pick-up	0	12
33163	2020-02-22 07:05:45	2020-02-22	9	[{"id_menu":6,"count":1}]	4816	pick-up	0	9
33164	2020-02-22 07:06:21	2020-02-22	12	[{"id_menu":3,"count":1}]	2538	delivery	5	17
33165	2020-02-22 07:08:00	2020-02-22	14	[{"id_menu":2,"count":1}]	11555	delivery	5	19
33166	2020-02-22 07:09:08	2020-02-22	14	[{"id_menu":2,"count":1}]	13167	delivery	5	19
33167	2020-02-22 07:21:21	2020-02-22	14	[{"id_menu":2,"count":1}]	7603	pick-up	0	14
33168	2020-02-22 07:22:16	2020-02-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3547	pick-up	0	31
33169	2020-02-22 07:22:35	2020-02-22	14	[{"id_menu":2,"count":2}]	12393	delivery	5	19
33170	2020-02-22 07:22:36	2020-02-22	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	3621	pick-up	0	26
33171	2020-02-22 07:25:13	2020-02-22	12	[{"id_menu":1,"count":1}]	12648	pick-up	0	12
33172	2020-02-22 07:26:54	2020-02-22	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	13039	delivery	5	26
33173	2020-02-22 07:27:14	2020-02-22	9	[{"id_menu":7,"count":1}]	9750	delivery	5	14
33174	2020-02-22 07:29:21	2020-02-22	17	[{"id_menu":4,"count":1}]	13159	delivery	5	22
33175	2020-02-22 07:31:58	2020-02-22	8	[{"id_menu":5,"count":1}]	6470	pick-up	0	8
33176	2020-02-22 07:32:47	2020-02-22	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	11578	delivery	5	25
33177	2020-02-22 07:33:43	2020-02-22	8	[{"id_menu":5,"count":1}]	2320	pick-up	0	8
33178	2020-02-22 07:38:27	2020-02-22	9	[{"id_menu":7,"count":1}]	13088	delivery	5	14
33179	2020-02-22 07:42:12	2020-02-22	8	[{"id_menu":5,"count":1}]	1053	pick-up	0	8
33180	2020-02-22 07:51:46	2020-02-22	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	13033	pick-up	0	29
33181	2020-02-22 08:01:44	2020-02-22	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	9307	delivery	5	43
33182	2020-02-22 08:03:57	2020-02-22	17	[{"id_menu":4,"count":1}]	13170	delivery	5	22
33183	2020-02-22 08:07:44	2020-02-22	17	[{"id_menu":4,"count":1}]	10768	delivery	5	22
33184	2020-02-22 08:15:56	2020-02-22	14	[{"id_menu":2,"count":1}]	322	pick-up	0	14
33185	2020-02-22 08:20:34	2020-02-22	14	[{"id_menu":2,"count":1}]	13166	pick-up	0	14
33186	2020-02-22 08:25:27	2020-02-22	17	[{"id_menu":4,"count":1}]	12282	delivery	5	22
33187	2020-02-22 08:27:37	2020-02-22	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	5945	pick-up	0	38
33188	2020-02-22 08:28:05	2020-02-22	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	7750	delivery	5	43
33189	2020-02-22 08:33:18	2020-02-22	9	[{"id_menu":6,"count":1}]	4482	delivery	5	14
33190	2020-02-22 08:34:16	2020-02-22	8	[{"id_menu":5,"count":1}]	3451	pick-up	0	8
33191	2020-02-22 08:38:48	2020-02-22	9	[{"id_menu":6,"count":1}]	3555	delivery	5	14
33192	2020-02-22 08:42:13	2020-02-22	12	[{"id_menu":1,"count":1}]	13134	delivery	5	17
33193	2020-02-22 08:57:03	2020-02-22	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	13037	delivery	5	40
33194	2020-02-22 08:57:28	2020-02-22	12	[{"id_menu":1,"count":1}]	8014	pick-up	0	12
33195	2020-02-22 08:57:28	2020-02-22	12	[{"id_menu":1,"count":1}]	13133	pick-up	0	12
33196	2020-02-22 08:57:39	2020-02-22	12	[{"id_menu":3,"count":1}]	13096	delivery	5	17
33197	2020-02-22 09:13:39	2020-02-22	17	[{"id_menu":4,"count":2}]	1282	delivery	5	22
33198	2020-02-22 09:14:07	2020-02-22	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	13115	delivery	5	31
33199	2020-02-22 09:24:25	2020-02-22	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	13031	delivery	5	45
33200	2020-02-22 09:35:04	2020-02-22	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7983	pick-up	0	32
33201	2020-02-22 09:48:32	2020-02-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	13034	delivery	5	28
33202	2020-02-22 09:48:39	2020-02-22	12	[{"id_menu":1,"count":1}]	4870	pick-up	0	12
33203	2020-02-22 09:50:05	2020-02-22	9	[{"id_menu":7,"count":1}]	8987	delivery	5	14
33204	2020-02-22 09:53:09	2020-02-22	9	[{"id_menu":6,"count":1}]	9334	delivery	5	14
33205	2020-02-22 09:53:57	2020-02-22	9	[{"id_menu":6,"count":1}]	13087	delivery	5	14
33206	2020-02-22 09:54:29	2020-02-22	9	[{"id_menu":7,"count":1}]	13060	delivery	5	14
33207	2020-02-22 09:58:50	2020-02-22	12	[{"id_menu":3,"count":1}]	13116	delivery	5	17
33208	2020-02-22 10:00:07	2020-02-22	12	[{"id_menu":1,"count":1}]	2053	delivery	5	17
33209	2020-02-22 10:07:15	2020-02-22	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13149	delivery	5	31
33210	2020-02-22 10:14:19	2020-02-22	12	[{"id_menu":1,"count":1}]	177	pick-up	0	12
33211	2020-02-22 10:17:06	2020-02-22	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	13111	delivery	5	45
33212	2020-02-22 10:23:03	2020-02-22	8	[{"id_menu":5,"count":1}]	10055	pick-up	0	8
33213	2020-02-22 10:23:08	2020-02-22	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3370	delivery	5	37
33214	2020-02-22 10:24:09	2020-02-22	9	[{"id_menu":7,"count":1}]	5985	delivery	5	14
33215	2020-02-22 10:25:00	2020-02-22	12	[{"id_menu":1,"count":1}]	4960	pick-up	0	12
33216	2020-02-22 10:33:07	2020-02-22	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3634	pick-up	0	25
33217	2020-02-22 10:35:42	2020-02-22	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	13150	delivery	5	27
33218	2020-02-22 10:44:36	2020-02-22	12	[{"id_menu":1,"count":1}]	2747	pick-up	0	12
33219	2020-02-22 10:44:51	2020-02-22	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	13098	delivery	5	43
33220	2020-02-22 10:44:51	2020-02-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	13099	delivery	5	36
33221	2020-02-22 11:07:08	2020-02-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13041	delivery	5	22
33222	2020-02-22 11:16:07	2020-02-22	9	[{"id_menu":6,"count":1}]	13140	delivery	5	14
33223	2020-02-22 11:27:47	2020-02-22	14	[{"id_menu":2,"count":1}]	13070	delivery	5	19
33224	2020-02-22 11:29:11	2020-02-22	12	[{"id_menu":1,"count":1}]	7158	delivery	5	17
33225	2020-02-22 11:35:36	2020-02-22	9	[{"id_menu":7,"count":1}]	1773	pick-up	0	9
33226	2020-02-22 11:37:34	2020-02-22	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	8307	delivery	5	26
33227	2020-02-22 11:42:05	2020-02-22	8	[{"id_menu":5,"count":1}]	5648	pick-up	0	8
33228	2020-02-22 11:44:12	2020-02-22	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	13050	pick-up	0	25
33229	2020-02-22 12:00:55	2020-02-22	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":3}]	8212	delivery	5	31
33230	2020-02-22 12:06:47	2020-02-22	14	[{"id_menu":2,"count":1}]	9733	delivery	5	19
33231	2020-02-22 12:12:18	2020-02-22	9	[{"id_menu":7,"count":1}]	13136	pick-up	0	9
33232	2020-02-22 12:22:23	2020-02-22	9	[{"id_menu":6,"count":1}]	1729	pick-up	0	9
33233	2020-02-22 12:23:57	2020-02-22	12	[{"id_menu":1,"count":1}]	10436	delivery	5	17
33234	2020-02-22 12:26:33	2020-02-22	17	[{"id_menu":4,"count":1}]	13063	delivery	5	22
33235	2020-02-22 12:26:41	2020-02-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4691	delivery	5	23
33236	2020-02-22 12:29:54	2020-02-22	8	[{"id_menu":5,"count":1}]	13090	delivery	5	13
33237	2020-02-22 12:31:09	2020-02-22	17	[{"id_menu":4,"count":2}]	13081	delivery	5	22
33238	2020-02-22 12:31:32	2020-02-22	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	13155	pick-up	0	26
33239	2020-02-22 12:33:17	2020-02-22	9	[{"id_menu":7,"count":1}]	832	delivery	5	14
33240	2020-02-22 12:34:58	2020-02-22	9	[{"id_menu":6,"count":1}]	13157	delivery	5	14
33241	2020-02-22 12:38:43	2020-02-22	22	[{"id_menu":2,"count":3},{"id_menu":5,"count":1}]	13148	pick-up	0	22
33242	2020-02-22 12:47:26	2020-02-22	14	[{"id_menu":2,"count":1}]	13075	delivery	5	19
33243	2020-02-22 12:48:44	2020-02-22	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	7020	delivery	5	31
33244	2020-02-22 12:54:45	2020-02-22	17	[{"id_menu":4,"count":1}]	13074	delivery	5	22
33245	2020-02-22 12:55:34	2020-02-22	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13114	delivery	5	52
33246	2020-02-22 12:57:29	2020-02-22	9	[{"id_menu":7,"count":1}]	10180	delivery	5	14
33247	2020-02-22 12:58:46	2020-02-22	12	[{"id_menu":1,"count":1}]	13112	pick-up	0	12
33248	2020-02-22 13:06:10	2020-02-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	10799	delivery	5	36
33249	2020-02-22 13:15:16	2020-02-22	8	[{"id_menu":5,"count":1}]	13091	delivery	5	13
33250	2020-02-22 13:17:10	2020-02-22	12	[{"id_menu":3,"count":1}]	13126	delivery	5	17
33251	2020-02-22 13:18:11	2020-02-22	12	[{"id_menu":1,"count":1}]	9983	pick-up	0	12
33252	2020-02-22 13:21:36	2020-02-22	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13119	delivery	5	39
33253	2020-02-22 13:22:25	2020-02-22	9	[{"id_menu":6,"count":1}]	13121	delivery	5	14
33254	2020-02-22 13:33:25	2020-02-22	12	[{"id_menu":3,"count":1}]	13080	delivery	5	17
33255	2020-02-22 13:34:54	2020-02-22	8	[{"id_menu":5,"count":2}]	13130	delivery	5	13
33256	2020-02-22 13:42:40	2020-02-22	9	[{"id_menu":7,"count":1}]	7515	delivery	5	14
33257	2020-02-22 13:46:54	2020-02-22	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5183	delivery	5	34
33258	2020-02-22 13:51:21	2020-02-22	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7688	delivery	5	43
33259	2020-02-22 14:05:47	2020-02-22	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8535	delivery	5	31
33260	2020-02-22 14:06:31	2020-02-22	9	[{"id_menu":6,"count":1}]	1627	delivery	5	14
33261	2020-02-22 14:07:04	2020-02-22	9	[{"id_menu":7,"count":1}]	13045	delivery	5	14
33262	2020-02-22 14:08:01	2020-02-22	8	[{"id_menu":5,"count":1}]	1343	delivery	5	13
33263	2020-02-22 14:17:00	2020-02-22	12	[{"id_menu":1,"count":2}]	2247	pick-up	0	12
33264	2020-02-22 14:18:47	2020-02-22	12	[{"id_menu":1,"count":1}]	2401	delivery	5	17
33265	2020-02-22 14:21:35	2020-02-22	17	[{"id_menu":4,"count":1}]	2505	pick-up	0	17
33266	2020-02-22 14:21:39	2020-02-22	26	[{"id_menu":4,"count":3},{"id_menu":6,"count":1}]	13051	delivery	5	31
33267	2020-02-22 14:22:00	2020-02-22	9	[{"id_menu":6,"count":1}]	13093	delivery	5	14
33268	2020-02-22 14:26:10	2020-02-22	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5048	pick-up	0	26
33269	2020-02-22 14:26:18	2020-02-22	14	[{"id_menu":2,"count":1}]	10496	pick-up	0	14
33270	2020-02-22 14:27:10	2020-02-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	8254	delivery	5	28
33271	2020-02-22 14:27:10	2020-02-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	13040	delivery	5	23
33272	2020-02-22 14:27:18	2020-02-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	1687	pick-up	0	31
33273	2020-02-22 14:35:28	2020-02-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13101	delivery	5	23
33274	2020-02-22 14:36:53	2020-02-22	9	[{"id_menu":6,"count":1}]	13154	delivery	5	14
33275	2020-02-22 14:40:03	2020-02-22	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	13107	delivery	5	25
33276	2020-02-22 14:46:08	2020-02-22	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7524	delivery	5	43
33277	2020-02-22 15:01:40	2020-02-22	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	13118	delivery	5	25
33278	2020-02-22 15:02:33	2020-02-22	9	[{"id_menu":6,"count":1}]	4309	delivery	5	14
33279	2020-02-22 15:06:46	2020-02-22	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	13127	delivery	5	26
33280	2020-02-22 15:09:16	2020-02-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13105	delivery	5	23
33281	2020-02-22 15:12:41	2020-02-22	9	[{"id_menu":7,"count":1}]	7387	delivery	5	14
33282	2020-02-22 15:14:30	2020-02-22	12	[{"id_menu":1,"count":1}]	4296	delivery	5	17
33283	2020-02-22 15:16:32	2020-02-22	9	[{"id_menu":7,"count":1}]	11187	delivery	5	14
33284	2020-02-22 15:19:05	2020-02-22	17	[{"id_menu":4,"count":1}]	13092	pick-up	0	17
33285	2020-02-22 15:28:51	2020-02-22	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5099	pick-up	0	17
33286	2020-02-22 15:39:13	2020-02-22	9	[{"id_menu":6,"count":1}]	12586	delivery	5	14
33287	2020-02-22 15:41:57	2020-02-22	8	[{"id_menu":5,"count":1}]	6074	pick-up	0	8
33288	2020-02-22 15:44:20	2020-02-22	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	170	pick-up	0	37
33289	2020-02-22 15:59:28	2020-02-22	17	[{"id_menu":4,"count":1}]	7814	pick-up	0	17
33290	2020-02-22 15:59:48	2020-02-22	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	13062	pick-up	0	29
33291	2020-02-22 16:09:45	2020-02-22	14	[{"id_menu":2,"count":1}]	13038	delivery	5	19
33292	2020-02-22 16:09:56	2020-02-22	12	[{"id_menu":3,"count":1}]	2799	pick-up	0	12
33293	2020-02-22 16:10:25	2020-02-22	14	[{"id_menu":2,"count":1}]	13082	delivery	5	19
33294	2020-02-22 16:24:00	2020-02-22	12	[{"id_menu":3,"count":1}]	13055	pick-up	0	12
33295	2020-02-22 16:24:25	2020-02-22	9	[{"id_menu":7,"count":3}]	11835	delivery	5	14
33296	2020-02-22 16:24:26	2020-02-22	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13161	delivery	5	37
33297	2020-02-22 16:28:30	2020-02-22	8	[{"id_menu":5,"count":1}]	2783	delivery	5	13
33298	2020-02-22 16:34:36	2020-02-22	9	[{"id_menu":6,"count":1}]	13089	delivery	5	14
33299	2020-02-22 16:46:19	2020-02-22	9	[{"id_menu":7,"count":3}]	5630	delivery	5	14
33300	2020-02-22 16:48:13	2020-02-22	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13123	delivery	5	36
33301	2020-02-22 16:51:55	2020-02-22	14	[{"id_menu":2,"count":2}]	1760	pick-up	0	14
33302	2020-02-22 16:58:20	2020-02-22	12	[{"id_menu":1,"count":1}]	13079	delivery	5	17
33303	2020-02-22 16:58:58	2020-02-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11447	delivery	5	23
33304	2020-02-22 16:59:21	2020-02-22	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12067	delivery	5	31
33305	2020-02-22 17:03:26	2020-02-22	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10870	pick-up	0	25
33306	2020-02-22 17:10:18	2020-02-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3540	delivery	5	36
33307	2020-02-22 17:10:39	2020-02-22	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13057	pick-up	0	38
33308	2020-02-22 17:11:21	2020-02-22	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	13122	delivery	5	27
33309	2020-02-22 17:15:51	2020-02-22	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8584	delivery	5	31
33310	2020-02-22 17:16:05	2020-02-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7268	delivery	5	28
33311	2020-02-22 17:20:12	2020-02-22	8	[{"id_menu":5,"count":1}]	4710	delivery	5	13
33312	2020-02-22 17:26:55	2020-02-22	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	12240	delivery	5	44
33313	2020-02-22 17:31:49	2020-02-22	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8636	delivery	5	37
33314	2020-02-22 17:35:11	2020-02-22	12	[{"id_menu":3,"count":2}]	13043	delivery	5	17
33315	2020-02-22 17:35:16	2020-02-22	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13165	delivery	5	40
33316	2020-02-22 17:51:01	2020-02-22	9	[{"id_menu":6,"count":1}]	6873	delivery	5	14
33317	2020-02-22 17:55:30	2020-02-22	12	[{"id_menu":3,"count":1}]	13077	delivery	5	17
33318	2020-02-22 17:59:29	2020-02-22	14	[{"id_menu":2,"count":1}]	10541	delivery	5	19
33319	2020-02-22 18:06:42	2020-02-22	17	[{"id_menu":4,"count":1}]	1015	pick-up	0	17
33320	2020-02-22 18:10:24	2020-02-22	14	[{"id_menu":2,"count":1}]	1138	pick-up	0	14
33321	2020-02-22 18:15:44	2020-02-22	9	[{"id_menu":7,"count":1}]	6678	delivery	5	14
33322	2020-02-22 18:19:10	2020-02-22	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	5633	delivery	5	31
33323	2020-02-22 18:19:59	2020-02-22	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3941	delivery	5	39
33324	2020-02-22 18:29:00	2020-02-22	9	[{"id_menu":6,"count":1}]	13053	delivery	5	14
33325	2020-02-22 18:31:22	2020-02-22	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	6871	delivery	5	26
33326	2020-02-22 18:31:23	2020-02-22	12	[{"id_menu":1,"count":1}]	13048	delivery	5	17
33327	2020-02-22 18:34:00	2020-02-22	14	[{"id_menu":2,"count":1}]	13110	pick-up	0	14
33328	2020-02-22 18:38:18	2020-02-22	12	[{"id_menu":1,"count":1}]	3870	pick-up	0	12
33329	2020-02-22 18:44:47	2020-02-22	8	[{"id_menu":5,"count":1}]	67	pick-up	0	8
33330	2020-02-22 18:45:40	2020-02-22	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	13147	delivery	5	23
33331	2020-02-22 18:46:48	2020-02-22	9	[{"id_menu":6,"count":1}]	13168	delivery	5	14
33332	2020-02-22 18:47:10	2020-02-22	12	[{"id_menu":1,"count":1}]	13141	delivery	5	17
33333	2020-02-22 18:47:12	2020-02-22	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5310	pick-up	0	17
33334	2020-02-22 18:51:58	2020-02-22	14	[{"id_menu":2,"count":1}]	1645	pick-up	0	14
33335	2020-02-22 18:54:34	2020-02-22	14	[{"id_menu":2,"count":1}]	13067	delivery	5	19
33336	2020-02-22 18:56:05	2020-02-22	14	[{"id_menu":2,"count":1}]	2752	pick-up	0	14
33337	2020-02-22 18:59:11	2020-02-22	12	[{"id_menu":1,"count":1}]	1556	pick-up	0	12
33338	2020-02-22 19:02:38	2020-02-22	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13084	delivery	5	45
33339	2020-02-22 19:06:44	2020-02-22	12	[{"id_menu":1,"count":1}]	6238	delivery	5	17
33340	2020-02-22 19:07:10	2020-02-22	9	[{"id_menu":6,"count":1}]	7676	delivery	5	14
33341	2020-02-22 19:11:17	2020-02-22	9	[{"id_menu":7,"count":1}]	11619	pick-up	0	9
33342	2020-02-22 19:12:11	2020-02-22	12	[{"id_menu":3,"count":1}]	3228	delivery	5	17
33343	2020-02-22 19:22:12	2020-02-22	9	[{"id_menu":6,"count":1}]	13058	delivery	5	14
33344	2020-02-22 19:26:13	2020-02-22	8	[{"id_menu":5,"count":1}]	9337	pick-up	0	8
33345	2020-02-22 19:36:03	2020-02-22	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11217	delivery	5	39
33346	2020-02-22 19:37:01	2020-02-22	9	[{"id_menu":6,"count":2}]	293	pick-up	0	9
33347	2020-02-22 19:42:12	2020-02-22	17	[{"id_menu":4,"count":1}]	5816	pick-up	0	17
33348	2020-02-22 19:43:38	2020-02-22	8	[{"id_menu":5,"count":1}]	9432	delivery	5	13
33349	2020-02-22 19:48:57	2020-02-22	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2810	pick-up	0	21
33350	2020-02-22 19:49:08	2020-02-22	8	[{"id_menu":5,"count":1}]	1113	pick-up	0	8
33351	2020-02-22 19:50:56	2020-02-22	9	[{"id_menu":6,"count":2}]	12163	delivery	5	14
33352	2020-02-22 19:51:21	2020-02-22	9	[{"id_menu":6,"count":1}]	12764	delivery	5	14
33353	2020-02-22 19:54:36	2020-02-22	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	9163	delivery	5	34
33354	2020-02-22 19:54:51	2020-02-22	8	[{"id_menu":5,"count":1}]	13036	delivery	5	13
33355	2020-02-22 19:59:15	2020-02-22	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	13124	pick-up	0	26
33356	2020-02-22 20:02:34	2020-02-22	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3054	delivery	5	31
33357	2020-02-22 20:02:59	2020-02-22	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	13095	delivery	5	22
33358	2020-02-22 20:12:33	2020-02-22	14	[{"id_menu":2,"count":1}]	10209	pick-up	0	14
33359	2020-02-22 20:16:12	2020-02-22	17	[{"id_menu":4,"count":1}]	13049	delivery	5	22
33360	2020-02-22 20:19:40	2020-02-22	12	[{"id_menu":1,"count":1}]	141	pick-up	0	12
33361	2020-02-22 20:20:59	2020-02-22	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	13052	delivery	5	37
33362	2020-02-22 20:22:34	2020-02-22	14	[{"id_menu":2,"count":1}]	13163	delivery	5	19
33363	2020-02-22 20:24:27	2020-02-22	8	[{"id_menu":5,"count":1}]	8394	pick-up	0	8
33364	2020-02-22 20:24:41	2020-02-22	12	[{"id_menu":3,"count":1}]	10277	delivery	5	17
33365	2020-02-22 20:32:20	2020-02-22	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13069	delivery	5	35
33366	2020-02-22 20:36:34	2020-02-22	17	[{"id_menu":4,"count":1}]	2187	delivery	5	22
33367	2020-02-22 20:47:19	2020-02-22	9	[{"id_menu":6,"count":1}]	13071	delivery	5	14
33368	2020-02-22 20:50:18	2020-02-22	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	6641	pick-up	0	24
33369	2020-02-22 20:50:23	2020-02-22	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	13073	delivery	5	27
33370	2020-02-22 20:56:08	2020-02-22	9	[{"id_menu":6,"count":1}]	1684	pick-up	0	9
33371	2020-02-22 21:03:00	2020-02-22	12	[{"id_menu":3,"count":1}]	13054	pick-up	0	12
33372	2020-02-22 21:04:06	2020-02-22	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13103	delivery	5	34
33373	2020-02-22 21:05:55	2020-02-22	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11287	pick-up	0	26
33374	2020-02-22 21:07:00	2020-02-22	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	9103	delivery	5	57
33375	2020-02-22 21:11:11	2020-02-22	8	[{"id_menu":5,"count":1}]	552	pick-up	0	8
33376	2020-02-22 21:17:44	2020-02-22	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3640	delivery	5	26
33377	2020-02-22 21:19:50	2020-02-22	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	13100	delivery	5	43
33378	2020-02-22 21:21:10	2020-02-22	14	[{"id_menu":2,"count":1}]	13125	delivery	5	19
33379	2020-02-22 21:25:18	2020-02-22	12	[{"id_menu":1,"count":1}]	13132	pick-up	0	12
33380	2020-02-22 21:26:50	2020-02-22	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	13156	delivery	5	26
33381	2020-02-22 21:36:04	2020-02-22	17	[{"id_menu":4,"count":1}]	13061	delivery	5	22
33382	2020-02-22 21:36:58	2020-02-22	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13056	delivery	5	51
33383	2020-02-22 21:38:54	2020-02-22	17	[{"id_menu":4,"count":1}]	10281	pick-up	0	17
33384	2020-02-22 21:41:40	2020-02-22	12	[{"id_menu":1,"count":1}]	2843	delivery	5	17
33385	2020-02-22 21:41:53	2020-02-22	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8847	delivery	5	57
33386	2020-02-22 21:48:10	2020-02-22	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	13113	pick-up	0	26
33387	2020-02-22 21:49:40	2020-02-22	14	[{"id_menu":2,"count":1}]	9767	delivery	5	19
33388	2020-02-22 21:59:01	2020-02-22	17	[{"id_menu":4,"count":1}]	10951	pick-up	0	17
33389	2020-02-22 22:01:59	2020-02-22	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	4006	delivery	5	31
33390	2020-02-22 22:03:48	2020-02-22	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	11040	delivery	5	34
33391	2020-02-22 22:12:48	2020-02-22	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13102	delivery	5	35
33392	2020-02-22 22:18:20	2020-02-22	9	[{"id_menu":6,"count":1}]	13078	delivery	5	14
33393	2020-02-22 22:23:20	2020-02-22	12	[{"id_menu":1,"count":1}]	5979	delivery	5	17
33394	2020-02-22 22:54:19	2020-02-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2232	delivery	5	22
33395	2020-02-22 23:05:50	2020-02-22	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6439	pick-up	0	26
33396	2020-02-22 23:05:52	2020-02-22	9	[{"id_menu":6,"count":1}]	13064	delivery	5	14
33397	2020-02-22 23:10:15	2020-02-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3000	delivery	5	28
33398	2020-02-22 23:18:37	2020-02-22	14	[{"id_menu":2,"count":1}]	7074	pick-up	0	14
33399	2020-02-22 23:19:14	2020-02-22	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2380	pick-up	0	22
33400	2020-02-22 23:20:04	2020-02-22	17	[{"id_menu":4,"count":1}]	13128	delivery	5	22
33401	2020-02-22 23:20:21	2020-02-22	17	[{"id_menu":4,"count":1}]	3507	delivery	5	22
33402	2020-02-22 23:20:23	2020-02-22	9	[{"id_menu":7,"count":1}]	13151	pick-up	0	9
33403	2020-02-22 23:25:30	2020-02-22	14	[{"id_menu":2,"count":1}]	3123	delivery	5	19
33404	2020-02-22 23:28:56	2020-02-22	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13072	delivery	5	39
33405	2020-02-22 23:39:15	2020-02-22	12	[{"id_menu":1,"count":1}]	7550	pick-up	0	12
33406	2020-02-22 23:46:04	2020-02-22	14	[{"id_menu":2,"count":1}]	3444	pick-up	0	14
33407	2020-02-22 23:46:12	2020-02-22	12	[{"id_menu":1,"count":1}]	3113	pick-up	0	12
33408	2020-02-22 23:59:51	2020-02-22	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	3629	delivery	5	27
33409	2020-02-23 00:01:04	2020-02-23	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	13231	delivery	5	25
33410	2020-02-23 00:02:07	2020-02-23	8	[{"id_menu":5,"count":1}]	11280	delivery	5	13
33411	2020-02-23 00:05:51	2020-02-23	12	[{"id_menu":3,"count":1}]	7407	pick-up	0	12
33412	2020-02-23 00:08:13	2020-02-23	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1228	pick-up	0	22
33413	2020-02-23 00:10:08	2020-02-23	12	[{"id_menu":1,"count":2}]	3065	pick-up	0	12
33414	2020-02-23 00:14:03	2020-02-23	12	[{"id_menu":1,"count":1}]	6092	pick-up	0	12
33415	2020-02-23 00:15:55	2020-02-23	17	[{"id_menu":4,"count":1}]	1379	delivery	5	22
33416	2020-02-23 00:15:57	2020-02-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13184	delivery	5	23
33417	2020-02-23 00:21:19	2020-02-23	9	[{"id_menu":6,"count":1}]	2027	delivery	5	14
33418	2020-02-23 00:35:23	2020-02-23	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	6962	pick-up	0	35
33419	2020-02-23 00:35:53	2020-02-23	14	[{"id_menu":2,"count":1}]	7181	delivery	5	19
33420	2020-02-23 00:40:27	2020-02-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	10717	pick-up	0	21
33421	2020-02-23 00:47:50	2020-02-23	9	[{"id_menu":7,"count":1}]	1244	pick-up	0	9
33422	2020-02-23 00:58:40	2020-02-23	12	[{"id_menu":1,"count":1}]	13279	delivery	5	17
33423	2020-02-23 01:02:36	2020-02-23	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13239	delivery	5	22
33424	2020-02-23 01:02:52	2020-02-23	9	[{"id_menu":7,"count":1}]	11961	delivery	5	14
33425	2020-02-23 01:06:03	2020-02-23	17	[{"id_menu":4,"count":1}]	13281	delivery	5	22
33426	2020-02-23 01:07:11	2020-02-23	8	[{"id_menu":5,"count":1}]	9267	delivery	5	13
33427	2020-02-23 01:09:16	2020-02-23	8	[{"id_menu":5,"count":1}]	13228	delivery	5	13
33428	2020-02-23 01:14:55	2020-02-23	17	[{"id_menu":4,"count":1}]	13207	delivery	5	22
33429	2020-02-23 01:15:02	2020-02-23	17	[{"id_menu":4,"count":1}]	6156	pick-up	0	17
33430	2020-02-23 01:16:01	2020-02-23	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13295	delivery	5	34
33431	2020-02-23 01:21:46	2020-02-23	14	[{"id_menu":2,"count":1}]	1077	delivery	5	19
33432	2020-02-23 01:24:27	2020-02-23	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	995	delivery	5	54
33433	2020-02-23 01:26:05	2020-02-23	9	[{"id_menu":6,"count":1}]	21	delivery	5	14
33434	2020-02-23 01:35:34	2020-02-23	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	13248	delivery	5	40
33435	2020-02-23 01:35:56	2020-02-23	17	[{"id_menu":4,"count":1}]	13233	pick-up	0	17
33436	2020-02-23 01:38:10	2020-02-23	9	[{"id_menu":7,"count":1}]	13243	delivery	5	14
33437	2020-02-23 01:39:40	2020-02-23	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	13190	delivery	5	22
33438	2020-02-23 01:45:10	2020-02-23	14	[{"id_menu":2,"count":1}]	6248	pick-up	0	14
33439	2020-02-23 01:45:48	2020-02-23	17	[{"id_menu":4,"count":1}]	765	pick-up	0	17
33440	2020-02-23 01:53:42	2020-02-23	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13217	delivery	5	39
33441	2020-02-23 01:57:56	2020-02-23	14	[{"id_menu":2,"count":1}]	8366	delivery	5	19
33442	2020-02-23 01:59:15	2020-02-23	9	[{"id_menu":6,"count":1}]	13257	delivery	5	14
33443	2020-02-23 02:06:55	2020-02-23	9	[{"id_menu":7,"count":1}]	9304	pick-up	0	9
33444	2020-02-23 02:08:06	2020-02-23	8	[{"id_menu":5,"count":1}]	13274	pick-up	0	8
33445	2020-02-23 02:08:28	2020-02-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":3}]	5082	delivery	5	31
33446	2020-02-23 02:13:07	2020-02-23	9	[{"id_menu":7,"count":1}]	4622	delivery	5	14
33447	2020-02-23 02:18:30	2020-02-23	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6800	delivery	5	31
33448	2020-02-23 02:29:21	2020-02-23	17	[{"id_menu":4,"count":1}]	506	pick-up	0	17
33449	2020-02-23 02:31:56	2020-02-23	14	[{"id_menu":2,"count":1}]	11365	delivery	5	19
33450	2020-02-23 02:32:36	2020-02-23	8	[{"id_menu":5,"count":1}]	4786	delivery	5	13
33451	2020-02-23 02:40:20	2020-02-23	9	[{"id_menu":7,"count":1}]	13204	delivery	5	14
33452	2020-02-23 02:41:28	2020-02-23	9	[{"id_menu":6,"count":1}]	13251	delivery	5	14
33453	2020-02-23 02:42:57	2020-02-23	12	[{"id_menu":1,"count":2}]	4583	pick-up	0	12
33454	2020-02-23 02:43:04	2020-02-23	12	[{"id_menu":1,"count":1}]	9	pick-up	0	12
33455	2020-02-23 02:43:17	2020-02-23	17	[{"id_menu":4,"count":1}]	13	pick-up	0	17
33456	2020-02-23 02:48:21	2020-02-23	14	[{"id_menu":2,"count":1}]	13203	delivery	5	19
33457	2020-02-23 02:50:25	2020-02-23	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	13245	pick-up	0	20
33458	2020-02-23 02:52:13	2020-02-23	14	[{"id_menu":2,"count":1}]	8002	delivery	5	19
33459	2020-02-23 02:52:18	2020-02-23	8	[{"id_menu":5,"count":1}]	10816	delivery	5	13
33460	2020-02-23 02:53:24	2020-02-23	9	[{"id_menu":7,"count":1}]	5913	pick-up	0	9
33461	2020-02-23 02:58:38	2020-02-23	9	[{"id_menu":7,"count":1}]	3600	pick-up	0	9
33462	2020-02-23 03:05:07	2020-02-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	13256	pick-up	0	23
33463	2020-02-23 03:09:12	2020-02-23	9	[{"id_menu":6,"count":1}]	2572	delivery	5	14
33464	2020-02-23 03:11:04	2020-02-23	9	[{"id_menu":6,"count":1}]	6385	pick-up	0	9
33465	2020-02-23 03:11:31	2020-02-23	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	13288	pick-up	0	21
33466	2020-02-23 03:14:40	2020-02-23	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	10968	delivery	5	36
33467	2020-02-23 03:16:09	2020-02-23	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	13199	pick-up	0	21
33468	2020-02-23 03:16:43	2020-02-23	12	[{"id_menu":1,"count":1}]	691	delivery	5	17
33469	2020-02-23 03:19:00	2020-02-23	9	[{"id_menu":7,"count":1}]	9093	pick-up	0	9
33470	2020-02-23 03:24:36	2020-02-23	8	[{"id_menu":5,"count":1}]	2823	delivery	5	13
33471	2020-02-23 03:26:01	2020-02-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	13262	delivery	5	28
33472	2020-02-23 03:28:12	2020-02-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	11981	delivery	5	28
33473	2020-02-23 03:29:01	2020-02-23	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	9339	delivery	5	39
33474	2020-02-23 03:31:09	2020-02-23	14	[{"id_menu":2,"count":1}]	13173	delivery	5	19
33475	2020-02-23 03:31:44	2020-02-23	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	13177	delivery	5	22
33476	2020-02-23 03:37:29	2020-02-23	12	[{"id_menu":1,"count":1}]	13282	delivery	5	17
33477	2020-02-23 03:40:05	2020-02-23	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13266	delivery	5	22
33478	2020-02-23 03:50:41	2020-02-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	8628	delivery	5	28
33479	2020-02-23 03:52:33	2020-02-23	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	6990	delivery	5	25
33480	2020-02-23 03:59:00	2020-02-23	17	[{"id_menu":4,"count":1}]	5041	delivery	5	22
33481	2020-02-23 04:02:31	2020-02-23	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	352	pick-up	0	38
33482	2020-02-23 04:09:24	2020-02-23	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	1093	pick-up	0	17
33483	2020-02-23 04:23:44	2020-02-23	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	13283	delivery	5	46
33484	2020-02-23 04:24:15	2020-02-23	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	1095	pick-up	0	26
33485	2020-02-23 04:25:05	2020-02-23	17	[{"id_menu":4,"count":1}]	386	pick-up	0	17
33486	2020-02-23 04:28:27	2020-02-23	12	[{"id_menu":3,"count":2}]	5131	pick-up	0	12
33487	2020-02-23 04:28:28	2020-02-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2882	delivery	5	28
33488	2020-02-23 04:31:28	2020-02-23	14	[{"id_menu":2,"count":3}]	13218	delivery	5	19
33489	2020-02-23 04:32:40	2020-02-23	8	[{"id_menu":5,"count":1}]	4436	delivery	5	13
33490	2020-02-23 04:44:29	2020-02-23	12	[{"id_menu":3,"count":1}]	9171	pick-up	0	12
33491	2020-02-23 04:46:07	2020-02-23	17	[{"id_menu":4,"count":1}]	8104	delivery	5	22
33492	2020-02-23 04:53:33	2020-02-23	12	[{"id_menu":3,"count":1}]	13221	delivery	5	17
33493	2020-02-23 04:59:22	2020-02-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	7502	pick-up	0	26
33494	2020-02-23 04:59:44	2020-02-23	12	[{"id_menu":1,"count":1}]	13249	delivery	5	17
33495	2020-02-23 04:59:51	2020-02-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3779	delivery	5	22
33496	2020-02-23 05:00:20	2020-02-23	14	[{"id_menu":2,"count":3}]	8230	delivery	5	19
33497	2020-02-23 05:04:02	2020-02-23	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13210	delivery	5	45
33498	2020-02-23 05:06:25	2020-02-23	12	[{"id_menu":1,"count":1}]	13301	delivery	5	17
33499	2020-02-23 05:06:42	2020-02-23	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	3052	delivery	5	27
33500	2020-02-23 05:07:29	2020-02-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1241	pick-up	0	26
33501	2020-02-23 05:07:38	2020-02-23	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13181	delivery	5	35
33502	2020-02-23 05:15:41	2020-02-23	9	[{"id_menu":7,"count":1}]	7216	delivery	5	14
33503	2020-02-23 05:15:53	2020-02-23	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	247	delivery	5	27
33504	2020-02-23 05:18:36	2020-02-23	9	[{"id_menu":6,"count":1}]	13255	delivery	5	14
33505	2020-02-23 05:26:01	2020-02-23	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4578	delivery	5	34
33506	2020-02-23 05:26:02	2020-02-23	17	[{"id_menu":4,"count":1}]	3720	pick-up	0	17
33507	2020-02-23 05:27:07	2020-02-23	9	[{"id_menu":7,"count":1}]	10923	delivery	5	14
33508	2020-02-23 05:38:17	2020-02-23	14	[{"id_menu":2,"count":1}]	13229	pick-up	0	14
33509	2020-02-23 05:41:29	2020-02-23	8	[{"id_menu":5,"count":1}]	9081	delivery	5	13
33510	2020-02-23 05:47:19	2020-02-23	9	[{"id_menu":6,"count":1}]	6675	delivery	5	14
33511	2020-02-23 05:48:58	2020-02-23	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	4060	delivery	5	34
33512	2020-02-23 05:50:57	2020-02-23	14	[{"id_menu":2,"count":1}]	13253	delivery	5	19
33513	2020-02-23 05:54:15	2020-02-23	9	[{"id_menu":6,"count":1}]	6631	pick-up	0	9
33514	2020-02-23 05:58:41	2020-02-23	8	[{"id_menu":5,"count":1}]	13234	pick-up	0	8
33515	2020-02-23 05:59:21	2020-02-23	9	[{"id_menu":6,"count":1}]	4130	pick-up	0	9
33516	2020-02-23 06:00:26	2020-02-23	8	[{"id_menu":5,"count":1}]	13222	delivery	5	13
33517	2020-02-23 06:11:13	2020-02-23	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	12823	delivery	5	26
33518	2020-02-23 06:15:30	2020-02-23	17	[{"id_menu":4,"count":1}]	74	pick-up	0	17
33519	2020-02-23 06:18:22	2020-02-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11818	pick-up	0	18
33520	2020-02-23 06:24:42	2020-02-23	14	[{"id_menu":2,"count":2}]	4122	pick-up	0	14
33521	2020-02-23 06:26:56	2020-02-23	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3382	pick-up	0	29
33522	2020-02-23 06:33:41	2020-02-23	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4054	delivery	5	27
33523	2020-02-23 06:47:05	2020-02-23	12	[{"id_menu":1,"count":1}]	6913	delivery	5	17
33524	2020-02-23 06:50:24	2020-02-23	12	[{"id_menu":3,"count":1}]	2426	pick-up	0	12
33525	2020-02-23 06:50:35	2020-02-23	9	[{"id_menu":6,"count":1}]	3575	delivery	5	14
33526	2020-02-23 07:02:13	2020-02-23	17	[{"id_menu":4,"count":1}]	8155	delivery	5	22
33527	2020-02-23 07:05:55	2020-02-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13198	delivery	5	22
33528	2020-02-23 07:08:18	2020-02-23	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	707	pick-up	0	35
33529	2020-02-23 07:09:51	2020-02-23	9	[{"id_menu":6,"count":1}]	1664	delivery	5	14
33530	2020-02-23 07:10:39	2020-02-23	17	[{"id_menu":4,"count":1}]	13105	delivery	5	22
33531	2020-02-23 07:12:04	2020-02-23	9	[{"id_menu":7,"count":1}]	7219	pick-up	0	9
33532	2020-02-23 07:12:09	2020-02-23	9	[{"id_menu":7,"count":1}]	11764	pick-up	0	9
33533	2020-02-23 07:14:18	2020-02-23	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2710	delivery	5	31
33534	2020-02-23 07:17:51	2020-02-23	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13278	pick-up	0	44
33535	2020-02-23 07:22:42	2020-02-23	12	[{"id_menu":3,"count":1}]	6499	delivery	5	17
33536	2020-02-23 07:23:36	2020-02-23	8	[{"id_menu":5,"count":1}]	972	delivery	5	13
33537	2020-02-23 07:24:44	2020-02-23	9	[{"id_menu":6,"count":1}]	6230	delivery	5	14
33538	2020-02-23 07:44:38	2020-02-23	14	[{"id_menu":2,"count":1}]	13254	delivery	5	19
33539	2020-02-23 07:48:06	2020-02-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2450	pick-up	0	26
33540	2020-02-23 07:50:52	2020-02-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":3}]	13237	delivery	5	28
33541	2020-02-23 07:56:32	2020-02-23	12	[{"id_menu":3,"count":1}]	1105	delivery	5	17
33542	2020-02-23 07:58:58	2020-02-23	8	[{"id_menu":5,"count":1}]	2627	delivery	5	13
33543	2020-02-23 08:01:35	2020-02-23	12	[{"id_menu":3,"count":1}]	1226	pick-up	0	12
33544	2020-02-23 08:06:26	2020-02-23	9	[{"id_menu":7,"count":1}]	13242	delivery	5	14
33545	2020-02-23 08:12:31	2020-02-23	14	[{"id_menu":2,"count":1}]	9891	delivery	5	19
33546	2020-02-23 08:15:51	2020-02-23	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1440	pick-up	0	29
33547	2020-02-23 08:17:09	2020-02-23	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	6371	pick-up	0	24
33548	2020-02-23 08:24:45	2020-02-23	12	[{"id_menu":1,"count":1}]	2110	pick-up	0	12
33549	2020-02-23 08:25:21	2020-02-23	12	[{"id_menu":3,"count":1}]	1357	delivery	5	17
33550	2020-02-23 08:28:15	2020-02-23	12	[{"id_menu":1,"count":1}]	2796	pick-up	0	12
33551	2020-02-23 08:29:42	2020-02-23	17	[{"id_menu":4,"count":2}]	227	delivery	5	22
33552	2020-02-23 08:30:41	2020-02-23	9	[{"id_menu":6,"count":3}]	13201	delivery	5	14
33553	2020-02-23 08:34:56	2020-02-23	9	[{"id_menu":6,"count":1}]	8000	delivery	5	14
33554	2020-02-23 08:35:16	2020-02-23	9	[{"id_menu":6,"count":1}]	13191	delivery	5	14
33555	2020-02-23 08:37:28	2020-02-23	12	[{"id_menu":1,"count":2}]	10134	delivery	5	17
33556	2020-02-23 08:38:39	2020-02-23	8	[{"id_menu":5,"count":1}]	13296	delivery	5	13
33557	2020-02-23 08:39:10	2020-02-23	17	[{"id_menu":4,"count":1}]	4041	pick-up	0	17
33558	2020-02-23 08:41:38	2020-02-23	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	13244	delivery	5	34
33559	2020-02-23 08:46:35	2020-02-23	9	[{"id_menu":6,"count":1}]	2613	pick-up	0	9
33560	2020-02-23 08:47:38	2020-02-23	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	10662	delivery	5	27
33561	2020-02-23 08:52:31	2020-02-23	17	[{"id_menu":4,"count":1}]	8068	pick-up	0	17
33562	2020-02-23 08:54:20	2020-02-23	8	[{"id_menu":5,"count":1}]	10366	delivery	5	13
33563	2020-02-23 08:58:15	2020-02-23	12	[{"id_menu":1,"count":1}]	9707	pick-up	0	12
33564	2020-02-23 09:02:30	2020-02-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1813	pick-up	0	26
33565	2020-02-23 09:03:09	2020-02-23	17	[{"id_menu":4,"count":1}]	1387	pick-up	0	17
33566	2020-02-23 09:09:49	2020-02-23	8	[{"id_menu":5,"count":1}]	11066	pick-up	0	8
33567	2020-02-23 09:17:26	2020-02-23	14	[{"id_menu":2,"count":1}]	489	pick-up	0	14
33568	2020-02-23 09:19:37	2020-02-23	14	[{"id_menu":2,"count":1}]	3390	delivery	5	19
33569	2020-02-23 09:23:27	2020-02-23	17	[{"id_menu":4,"count":1}]	13200	pick-up	0	17
33570	2020-02-23 09:27:03	2020-02-23	17	[{"id_menu":4,"count":1}]	11491	pick-up	0	17
33571	2020-02-23 09:30:25	2020-02-23	17	[{"id_menu":4,"count":1}]	3784	delivery	5	22
33572	2020-02-23 09:37:30	2020-02-23	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	13271	pick-up	0	25
33573	2020-02-23 09:52:54	2020-02-23	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	601	pick-up	0	17
33574	2020-02-23 09:54:08	2020-02-23	9	[{"id_menu":7,"count":1}]	12873	pick-up	0	9
33575	2020-02-23 09:57:37	2020-02-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1143	pick-up	0	26
33576	2020-02-23 09:58:18	2020-02-23	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	6028	delivery	5	25
33577	2020-02-23 10:00:22	2020-02-23	14	[{"id_menu":2,"count":1}]	12246	delivery	5	19
33578	2020-02-23 10:10:27	2020-02-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	13232	pick-up	0	26
33579	2020-02-23 10:15:54	2020-02-23	9	[{"id_menu":7,"count":1}]	3420	pick-up	0	9
33580	2020-02-23 10:17:18	2020-02-23	12	[{"id_menu":3,"count":1}]	13062	delivery	5	17
33581	2020-02-23 10:18:46	2020-02-23	9	[{"id_menu":7,"count":1}]	8211	delivery	5	14
33582	2020-02-23 10:19:50	2020-02-23	9	[{"id_menu":7,"count":1}]	2706	pick-up	0	9
33583	2020-02-23 10:24:34	2020-02-23	17	[{"id_menu":4,"count":1}]	5292	pick-up	0	17
33584	2020-02-23 10:28:38	2020-02-23	8	[{"id_menu":5,"count":1}]	13219	delivery	5	13
33585	2020-02-23 10:31:34	2020-02-23	17	[{"id_menu":4,"count":1}]	2068	pick-up	0	17
33586	2020-02-23 10:31:51	2020-02-23	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	13236	delivery	5	27
33587	2020-02-23 10:35:34	2020-02-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13209	delivery	5	23
33588	2020-02-23 10:36:22	2020-02-23	8	[{"id_menu":5,"count":1}]	13202	delivery	5	13
33589	2020-02-23 10:37:57	2020-02-23	14	[{"id_menu":2,"count":1}]	13185	delivery	5	19
33590	2020-02-23 10:59:47	2020-02-23	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	13206	delivery	5	31
33591	2020-02-23 11:04:35	2020-02-23	9	[{"id_menu":6,"count":1}]	13264	pick-up	0	9
33592	2020-02-23 11:10:19	2020-02-23	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	12185	delivery	5	27
33593	2020-02-23 11:11:25	2020-02-23	14	[{"id_menu":2,"count":1}]	12846	delivery	5	19
33594	2020-02-23 11:12:48	2020-02-23	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3732	delivery	5	36
33595	2020-02-23 11:12:54	2020-02-23	8	[{"id_menu":5,"count":1}]	8952	delivery	5	13
33596	2020-02-23 11:16:56	2020-02-23	12	[{"id_menu":3,"count":1}]	13302	delivery	5	17
33597	2020-02-23 11:20:34	2020-02-23	14	[{"id_menu":2,"count":1}]	13230	delivery	5	19
33598	2020-02-23 11:21:27	2020-02-23	17	[{"id_menu":4,"count":1}]	2850	delivery	5	22
33599	2020-02-23 11:21:31	2020-02-23	17	[{"id_menu":4,"count":1}]	13223	delivery	5	22
33600	2020-02-23 11:32:23	2020-02-23	8	[{"id_menu":5,"count":1}]	5568	delivery	5	13
33601	2020-02-23 11:35:22	2020-02-23	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	13289	pick-up	0	21
33602	2020-02-23 11:36:09	2020-02-23	9	[{"id_menu":7,"count":1}]	13250	delivery	5	14
33603	2020-02-23 11:36:56	2020-02-23	12	[{"id_menu":1,"count":1}]	11735	delivery	5	17
33604	2020-02-23 11:37:52	2020-02-23	12	[{"id_menu":3,"count":1}]	13225	delivery	5	17
33605	2020-02-23 11:39:29	2020-02-23	17	[{"id_menu":4,"count":1}]	1313	pick-up	0	17
33606	2020-02-23 11:45:54	2020-02-23	17	[{"id_menu":4,"count":1}]	13187	delivery	5	22
33607	2020-02-23 11:48:03	2020-02-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1638	delivery	5	26
33608	2020-02-23 11:49:37	2020-02-23	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	13292	delivery	5	48
33609	2020-02-23 11:56:01	2020-02-23	8	[{"id_menu":5,"count":1}]	12141	delivery	5	13
33610	2020-02-23 12:06:49	2020-02-23	14	[{"id_menu":2,"count":1}]	13220	delivery	5	19
33611	2020-02-23 12:07:05	2020-02-23	17	[{"id_menu":4,"count":1}]	11832	delivery	5	22
33612	2020-02-23 12:07:19	2020-02-23	9	[{"id_menu":7,"count":1}]	9923	delivery	5	14
33613	2020-02-23 12:16:09	2020-02-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7241	delivery	5	28
33614	2020-02-23 12:21:25	2020-02-23	8	[{"id_menu":5,"count":1}]	5875	pick-up	0	8
33615	2020-02-23 12:23:38	2020-02-23	9	[{"id_menu":7,"count":1}]	13012	delivery	5	14
33616	2020-02-23 12:24:57	2020-02-23	9	[{"id_menu":6,"count":1}]	2123	pick-up	0	9
33617	2020-02-23 12:28:16	2020-02-23	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9166	delivery	5	31
33618	2020-02-23 12:38:02	2020-02-23	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13175	delivery	5	54
33619	2020-02-23 12:40:06	2020-02-23	12	[{"id_menu":1,"count":1}]	12043	delivery	5	17
33620	2020-02-23 12:41:33	2020-02-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	4685	pick-up	0	21
33621	2020-02-23 12:43:32	2020-02-23	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	7288	delivery	5	30
33622	2020-02-23 12:46:32	2020-02-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13259	delivery	5	31
33623	2020-02-23 13:00:55	2020-02-23	8	[{"id_menu":5,"count":1}]	13276	delivery	5	13
33624	2020-02-23 13:07:51	2020-02-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5308	pick-up	0	23
33625	2020-02-23 13:11:39	2020-02-23	12	[{"id_menu":1,"count":1}]	13224	delivery	5	17
33626	2020-02-23 13:14:56	2020-02-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	807	pick-up	0	23
33627	2020-02-23 13:19:35	2020-02-23	14	[{"id_menu":2,"count":3}]	13188	delivery	5	19
33628	2020-02-23 13:19:48	2020-02-23	12	[{"id_menu":1,"count":1}]	11189	pick-up	0	12
33629	2020-02-23 13:20:06	2020-02-23	9	[{"id_menu":7,"count":1}]	6884	delivery	5	14
33630	2020-02-23 13:20:24	2020-02-23	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5621	delivery	5	43
33631	2020-02-23 13:22:38	2020-02-23	9	[{"id_menu":6,"count":1}]	3939	delivery	5	14
33632	2020-02-23 13:23:02	2020-02-23	17	[{"id_menu":4,"count":1}]	13285	delivery	5	22
33633	2020-02-23 13:27:36	2020-02-23	17	[{"id_menu":4,"count":1}]	4783	pick-up	0	17
33634	2020-02-23 13:33:41	2020-02-23	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13176	delivery	5	45
33635	2020-02-23 13:36:57	2020-02-23	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	13227	delivery	5	35
33636	2020-02-23 13:40:08	2020-02-23	9	[{"id_menu":7,"count":1}]	13299	delivery	5	14
33637	2020-02-23 13:43:49	2020-02-23	17	[{"id_menu":4,"count":1}]	9017	pick-up	0	17
33638	2020-02-23 13:45:04	2020-02-23	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13178	delivery	5	45
33639	2020-02-23 13:53:42	2020-02-23	14	[{"id_menu":2,"count":1}]	13240	pick-up	0	14
33640	2020-02-23 13:54:20	2020-02-23	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13235	delivery	5	36
33641	2020-02-23 14:02:38	2020-02-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	4696	delivery	5	28
33642	2020-02-23 14:07:33	2020-02-23	12	[{"id_menu":3,"count":1}]	11795	pick-up	0	12
33643	2020-02-23 14:10:03	2020-02-23	17	[{"id_menu":4,"count":1}]	13275	pick-up	0	17
33644	2020-02-23 14:13:50	2020-02-23	17	[{"id_menu":4,"count":1}]	6238	pick-up	0	17
33645	2020-02-23 14:17:11	2020-02-23	8	[{"id_menu":5,"count":1}]	13180	delivery	5	13
33646	2020-02-23 14:34:40	2020-02-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	13211	delivery	5	26
33647	2020-02-23 14:48:14	2020-02-23	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	13252	delivery	5	48
33648	2020-02-23 14:48:55	2020-02-23	9	[{"id_menu":7,"count":2}]	13269	delivery	5	14
33649	2020-02-23 14:49:19	2020-02-23	8	[{"id_menu":5,"count":1}]	5430	delivery	5	13
33650	2020-02-23 14:49:44	2020-02-23	9	[{"id_menu":7,"count":1}]	13216	delivery	5	14
33651	2020-02-23 14:49:44	2020-02-23	9	[{"id_menu":7,"count":1}]	13293	delivery	5	14
33652	2020-02-23 14:51:59	2020-02-23	12	[{"id_menu":3,"count":1}]	4756	delivery	5	17
33653	2020-02-23 14:58:05	2020-02-23	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7369	delivery	5	35
33654	2020-02-23 15:04:15	2020-02-23	14	[{"id_menu":2,"count":1}]	10017	delivery	5	19
33655	2020-02-23 15:07:44	2020-02-23	9	[{"id_menu":6,"count":1}]	8873	delivery	5	14
33656	2020-02-23 15:10:58	2020-02-23	14	[{"id_menu":2,"count":1}]	1299	pick-up	0	14
33657	2020-02-23 15:15:05	2020-02-23	8	[{"id_menu":5,"count":1}]	3055	delivery	5	13
33658	2020-02-23 15:15:40	2020-02-23	9	[{"id_menu":7,"count":1}]	5730	delivery	5	14
33659	2020-02-23 15:16:48	2020-02-23	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	13261	delivery	5	31
33660	2020-02-23 15:17:04	2020-02-23	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	10518	delivery	5	40
33661	2020-02-23 15:19:48	2020-02-23	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	2604	pick-up	0	20
33662	2020-02-23 15:23:28	2020-02-23	14	[{"id_menu":2,"count":1}]	4962	delivery	5	19
33663	2020-02-23 15:24:30	2020-02-23	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	13120	delivery	5	30
33664	2020-02-23 15:25:21	2020-02-23	9	[{"id_menu":7,"count":1}]	13263	delivery	5	14
33665	2020-02-23 15:28:41	2020-02-23	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3996	delivery	5	34
33666	2020-02-23 15:34:15	2020-02-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	11751	pick-up	0	21
33667	2020-02-23 15:39:46	2020-02-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6137	pick-up	0	31
33668	2020-02-23 15:41:30	2020-02-23	9	[{"id_menu":7,"count":2}]	13291	delivery	5	14
33669	2020-02-23 15:52:45	2020-02-23	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10882	pick-up	0	43
33670	2020-02-23 15:59:01	2020-02-23	9	[{"id_menu":6,"count":1}]	13174	delivery	5	14
33671	2020-02-23 15:59:57	2020-02-23	9	[{"id_menu":7,"count":1}]	13214	delivery	5	14
33672	2020-02-23 16:02:25	2020-02-23	17	[{"id_menu":4,"count":1}]	10804	delivery	5	22
33673	2020-02-23 16:03:46	2020-02-23	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5912	delivery	5	36
33674	2020-02-23 16:04:39	2020-02-23	9	[{"id_menu":7,"count":1}]	5009	pick-up	0	9
33675	2020-02-23 16:04:51	2020-02-23	9	[{"id_menu":6,"count":1}]	5576	delivery	5	14
33676	2020-02-23 16:04:57	2020-02-23	14	[{"id_menu":2,"count":2}]	381	pick-up	0	14
33677	2020-02-23 16:06:15	2020-02-23	9	[{"id_menu":6,"count":1}]	13258	delivery	5	14
33678	2020-02-23 16:08:05	2020-02-23	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	13192	delivery	5	43
33679	2020-02-23 16:12:55	2020-02-23	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13212	delivery	5	37
33680	2020-02-23 16:15:22	2020-02-23	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	13208	pick-up	0	39
33681	2020-02-23 16:17:36	2020-02-23	14	[{"id_menu":2,"count":1}]	4438	delivery	5	19
33682	2020-02-23 16:19:04	2020-02-23	14	[{"id_menu":2,"count":1}]	13300	delivery	5	19
33683	2020-02-23 16:33:01	2020-02-23	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1183	delivery	5	31
33684	2020-02-23 16:38:45	2020-02-23	9	[{"id_menu":6,"count":1}]	11073	delivery	5	14
33685	2020-02-23 16:40:18	2020-02-23	17	[{"id_menu":4,"count":1}]	7159	pick-up	0	17
33686	2020-02-23 16:40:35	2020-02-23	8	[{"id_menu":5,"count":1}]	6453	delivery	5	13
33687	2020-02-23 16:43:47	2020-02-23	9	[{"id_menu":6,"count":1}]	13286	delivery	5	14
33688	2020-02-23 16:51:06	2020-02-23	9	[{"id_menu":7,"count":2}]	10064	delivery	5	14
33689	2020-02-23 16:56:52	2020-02-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4459	delivery	5	28
33690	2020-02-23 17:02:25	2020-02-23	9	[{"id_menu":7,"count":1}]	4363	pick-up	0	9
33691	2020-02-23 17:09:12	2020-02-23	14	[{"id_menu":2,"count":1}]	2128	pick-up	0	14
33692	2020-02-23 17:10:42	2020-02-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	11674	delivery	5	31
33693	2020-02-23 17:10:46	2020-02-23	17	[{"id_menu":4,"count":1}]	3399	pick-up	0	17
33694	2020-02-23 17:11:46	2020-02-23	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	5491	delivery	5	26
33695	2020-02-23 17:13:57	2020-02-23	9	[{"id_menu":7,"count":1}]	207	pick-up	0	9
33696	2020-02-23 17:14:13	2020-02-23	9	[{"id_menu":7,"count":1}]	1754	delivery	5	14
33697	2020-02-23 17:20:18	2020-02-23	9	[{"id_menu":6,"count":1}]	13215	pick-up	0	9
33698	2020-02-23 17:25:27	2020-02-23	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	11683	delivery	5	34
33699	2020-02-23 17:27:30	2020-02-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	13290	delivery	5	28
33700	2020-02-23 17:47:42	2020-02-23	9	[{"id_menu":7,"count":1}]	2261	pick-up	0	9
33701	2020-02-23 17:50:10	2020-02-23	9	[{"id_menu":6,"count":1}]	5666	delivery	5	14
33702	2020-02-23 17:51:55	2020-02-23	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9971	delivery	5	34
33703	2020-02-23 17:53:13	2020-02-23	41	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2943	pick-up	0	41
33704	2020-02-23 18:00:47	2020-02-23	14	[{"id_menu":2,"count":1}]	2384	delivery	5	19
33705	2020-02-23 18:04:45	2020-02-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	13238	delivery	5	31
33706	2020-02-23 18:05:05	2020-02-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13287	delivery	5	31
33707	2020-02-23 18:05:28	2020-02-23	12	[{"id_menu":1,"count":1}]	13298	pick-up	0	12
33708	2020-02-23 18:05:55	2020-02-23	14	[{"id_menu":2,"count":1}]	13189	delivery	5	19
33709	2020-02-23 18:13:51	2020-02-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	13196	delivery	5	36
33710	2020-02-23 18:15:26	2020-02-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	13241	delivery	5	23
33711	2020-02-23 18:22:12	2020-02-23	12	[{"id_menu":1,"count":1}]	13197	pick-up	0	12
33712	2020-02-23 18:24:04	2020-02-23	8	[{"id_menu":5,"count":1}]	13134	pick-up	0	8
33713	2020-02-23 18:25:25	2020-02-23	9	[{"id_menu":6,"count":1}]	12978	delivery	5	14
33714	2020-02-23 18:31:27	2020-02-23	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3527	delivery	5	22
33715	2020-02-23 18:33:45	2020-02-23	8	[{"id_menu":5,"count":1}]	3241	delivery	5	13
33716	2020-02-23 18:35:41	2020-02-23	8	[{"id_menu":5,"count":1}]	4509	delivery	5	13
33717	2020-02-23 18:36:33	2020-02-23	8	[{"id_menu":5,"count":1}]	13246	delivery	5	13
33718	2020-02-23 18:39:42	2020-02-23	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	7414	pick-up	0	35
33719	2020-02-23 18:40:14	2020-02-23	17	[{"id_menu":4,"count":1}]	1559	pick-up	0	17
33720	2020-02-23 18:47:12	2020-02-23	12	[{"id_menu":1,"count":1}]	2317	pick-up	0	12
33721	2020-02-23 18:50:18	2020-02-23	9	[{"id_menu":6,"count":1}]	1491	pick-up	0	9
33722	2020-02-23 18:50:43	2020-02-23	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6580	delivery	5	34
33723	2020-02-23 18:54:55	2020-02-23	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	13172	delivery	5	42
33724	2020-02-23 18:58:30	2020-02-23	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13179	delivery	5	45
33725	2020-02-23 18:58:46	2020-02-23	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4680	delivery	5	37
33726	2020-02-23 19:00:46	2020-02-23	9	[{"id_menu":6,"count":2}]	5099	delivery	5	14
33727	2020-02-23 19:01:53	2020-02-23	12	[{"id_menu":3,"count":1}]	13277	delivery	5	17
33728	2020-02-23 19:06:51	2020-02-23	9	[{"id_menu":7,"count":1}]	2705	delivery	5	14
33729	2020-02-23 19:08:49	2020-02-23	9	[{"id_menu":7,"count":1}]	10863	delivery	5	14
33730	2020-02-23 19:09:21	2020-02-23	9	[{"id_menu":6,"count":1}]	13297	delivery	5	14
33731	2020-02-23 19:11:35	2020-02-23	9	[{"id_menu":7,"count":1}]	13195	delivery	5	14
33732	2020-02-23 19:11:50	2020-02-23	8	[{"id_menu":5,"count":1}]	13205	delivery	5	13
33733	2020-02-23 19:13:27	2020-02-23	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	7094	pick-up	0	29
33734	2020-02-23 19:19:06	2020-02-23	14	[{"id_menu":2,"count":1}]	5681	delivery	5	19
33735	2020-02-23 19:36:13	2020-02-23	14	[{"id_menu":2,"count":1}]	13154	delivery	5	19
33736	2020-02-23 19:39:50	2020-02-23	17	[{"id_menu":4,"count":1}]	2442	pick-up	0	17
33737	2020-02-23 19:43:38	2020-02-23	12	[{"id_menu":1,"count":1}]	8600	delivery	5	17
33738	2020-02-23 19:53:23	2020-02-23	17	[{"id_menu":4,"count":1}]	13194	delivery	5	22
33739	2020-02-23 19:56:16	2020-02-23	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	13182	delivery	5	44
33740	2020-02-23 19:57:00	2020-02-23	9	[{"id_menu":7,"count":1}]	13186	delivery	5	14
33741	2020-02-23 20:03:32	2020-02-23	8	[{"id_menu":5,"count":1}]	3512	delivery	5	13
33742	2020-02-23 20:05:12	2020-02-23	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8404	delivery	5	40
33743	2020-02-23 20:07:31	2020-02-23	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	3371	delivery	5	26
33744	2020-02-23 20:13:39	2020-02-23	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	11318	pick-up	0	29
33745	2020-02-23 20:14:58	2020-02-23	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	12377	delivery	5	23
33746	2020-02-23 20:20:39	2020-02-23	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	3558	delivery	5	43
33747	2020-02-23 20:32:35	2020-02-23	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	12292	delivery	5	27
33748	2020-02-23 20:48:40	2020-02-23	8	[{"id_menu":5,"count":1}]	440	delivery	5	13
33749	2020-02-23 20:54:11	2020-02-23	14	[{"id_menu":2,"count":1}]	7050	pick-up	0	14
33750	2020-02-23 20:57:55	2020-02-23	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2728	pick-up	0	31
33751	2020-02-23 20:58:06	2020-02-23	17	[{"id_menu":4,"count":1}]	3384	pick-up	0	17
33752	2020-02-23 21:00:00	2020-02-23	12	[{"id_menu":3,"count":1}]	547	delivery	5	17
33753	2020-02-23 21:02:35	2020-02-23	9	[{"id_menu":7,"count":2}]	4958	delivery	5	14
33754	2020-02-23 21:04:38	2020-02-23	8	[{"id_menu":5,"count":1}]	4139	pick-up	0	8
33755	2020-02-23 21:09:06	2020-02-23	12	[{"id_menu":3,"count":1}]	12782	delivery	5	17
33756	2020-02-23 21:15:07	2020-02-23	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	8884	delivery	5	26
33757	2020-02-23 21:17:01	2020-02-23	9	[{"id_menu":6,"count":1}]	2934	delivery	5	14
33758	2020-02-23 21:21:12	2020-02-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3153	pick-up	0	23
33759	2020-02-23 21:27:07	2020-02-23	8	[{"id_menu":5,"count":1}]	4170	pick-up	0	8
33760	2020-02-23 21:37:54	2020-02-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2980	pick-up	0	21
33761	2020-02-23 21:38:52	2020-02-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	13193	pick-up	0	23
33762	2020-02-23 21:43:05	2020-02-23	14	[{"id_menu":2,"count":1}]	13272	delivery	5	19
33763	2020-02-23 21:46:30	2020-02-23	12	[{"id_menu":3,"count":1}]	5961	pick-up	0	12
33764	2020-02-23 21:49:15	2020-02-23	14	[{"id_menu":2,"count":1}]	9320	pick-up	0	14
33765	2020-02-23 21:49:33	2020-02-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9859	delivery	5	28
33766	2020-02-23 21:56:48	2020-02-23	17	[{"id_menu":4,"count":1}]	13284	delivery	5	22
33767	2020-02-23 22:00:26	2020-02-23	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	13009	delivery	5	23
33768	2020-02-23 22:07:37	2020-02-23	9	[{"id_menu":6,"count":1}]	13280	delivery	5	14
33769	2020-02-23 22:08:52	2020-02-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7791	delivery	5	28
33770	2020-02-23 22:16:17	2020-02-23	8	[{"id_menu":5,"count":1}]	1526	pick-up	0	8
33771	2020-02-23 22:20:07	2020-02-23	17	[{"id_menu":4,"count":1}]	1158	delivery	5	22
33772	2020-02-23 22:22:56	2020-02-23	12	[{"id_menu":1,"count":1}]	721	pick-up	0	12
33773	2020-02-23 22:28:58	2020-02-23	9	[{"id_menu":6,"count":1}]	13260	pick-up	0	9
33774	2020-02-23 22:36:59	2020-02-23	8	[{"id_menu":5,"count":1}]	9944	delivery	5	13
33775	2020-02-23 22:39:27	2020-02-23	17	[{"id_menu":4,"count":1}]	6009	pick-up	0	17
33776	2020-02-23 22:40:43	2020-02-23	9	[{"id_menu":7,"count":1}]	5786	delivery	5	14
33777	2020-02-23 22:43:08	2020-02-23	8	[{"id_menu":5,"count":1}]	13213	delivery	5	13
33778	2020-02-23 22:44:29	2020-02-23	9	[{"id_menu":6,"count":2}]	4628	delivery	5	14
33779	2020-02-23 22:44:44	2020-02-23	17	[{"id_menu":4,"count":1}]	232	pick-up	0	17
33780	2020-02-23 22:46:43	2020-02-23	14	[{"id_menu":2,"count":1}]	6617	pick-up	0	14
33781	2020-02-23 22:48:44	2020-02-23	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	2951	delivery	5	29
33782	2020-02-23 23:04:01	2020-02-23	14	[{"id_menu":2,"count":1}]	6383	delivery	5	19
33783	2020-02-23 23:06:56	2020-02-23	12	[{"id_menu":1,"count":1}]	360	pick-up	0	12
33784	2020-02-23 23:11:01	2020-02-23	12	[{"id_menu":3,"count":1}]	575	pick-up	0	12
33785	2020-02-23 23:13:16	2020-02-23	8	[{"id_menu":5,"count":1}]	12321	delivery	5	13
33786	2020-02-23 23:13:23	2020-02-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	13226	delivery	5	28
33787	2020-02-23 23:17:10	2020-02-23	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	13183	delivery	5	36
33788	2020-02-23 23:17:26	2020-02-23	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	9633	delivery	5	38
33789	2020-02-23 23:22:52	2020-02-23	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8469	delivery	5	34
33790	2020-02-23 23:23:22	2020-02-23	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	13247	delivery	5	30
33791	2020-02-23 23:29:02	2020-02-23	9	[{"id_menu":6,"count":1}]	13265	delivery	5	14
33792	2020-02-23 23:34:27	2020-02-23	12	[{"id_menu":1,"count":1}]	13273	delivery	5	17
33793	2020-02-23 23:36:12	2020-02-23	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	8597	delivery	5	39
33794	2020-02-23 23:36:23	2020-02-23	9	[{"id_menu":7,"count":1}]	1604	pick-up	0	9
33795	2020-02-23 23:40:23	2020-02-23	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4605	delivery	5	39
33796	2020-02-23 23:40:35	2020-02-23	9	[{"id_menu":7,"count":1}]	12388	pick-up	0	9
33797	2020-02-23 23:41:45	2020-02-23	14	[{"id_menu":2,"count":1}]	13267	pick-up	0	14
33798	2020-02-23 23:49:14	2020-02-23	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	13268	delivery	5	25
33799	2020-02-23 23:57:30	2020-02-23	9	[{"id_menu":7,"count":1}]	6380	delivery	5	14
33800	2020-02-24 00:00:11	2020-02-24	9	[{"id_menu":6,"count":1}]	13393	delivery	5	14
33801	2020-02-24 00:01:28	2020-02-24	17	[{"id_menu":4,"count":1}]	13334	pick-up	0	17
33802	2020-02-24 00:03:27	2020-02-24	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	6243	delivery	5	34
33803	2020-02-24 00:27:00	2020-02-24	8	[{"id_menu":5,"count":1}]	4079	delivery	5	13
33804	2020-02-24 00:30:39	2020-02-24	12	[{"id_menu":1,"count":1}]	3405	delivery	5	17
33805	2020-02-24 00:38:52	2020-02-24	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	8230	delivery	5	22
33806	2020-02-24 00:41:07	2020-02-24	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	13362	delivery	5	40
33807	2020-02-24 00:43:08	2020-02-24	14	[{"id_menu":2,"count":1}]	4571	pick-up	0	14
33808	2020-02-24 00:46:15	2020-02-24	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13322	delivery	5	40
33809	2020-02-24 00:47:46	2020-02-24	9	[{"id_menu":6,"count":1}]	12719	delivery	5	14
33810	2020-02-24 00:50:17	2020-02-24	9	[{"id_menu":7,"count":1}]	13357	delivery	5	14
33811	2020-02-24 00:54:48	2020-02-24	17	[{"id_menu":5,"count":3},{"id_menu":6,"count":1}]	13404	delivery	5	22
33812	2020-02-24 00:58:07	2020-02-24	9	[{"id_menu":6,"count":1}]	1379	delivery	5	14
33813	2020-02-24 01:07:50	2020-02-24	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	13368	delivery	5	44
33814	2020-02-24 01:11:34	2020-02-24	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4622	delivery	5	48
33815	2020-02-24 01:17:47	2020-02-24	14	[{"id_menu":2,"count":1}]	13348	delivery	5	19
33816	2020-02-24 01:21:27	2020-02-24	14	[{"id_menu":2,"count":3}]	13337	pick-up	0	14
33817	2020-02-24 01:32:08	2020-02-24	9	[{"id_menu":7,"count":1}]	13389	pick-up	0	9
33818	2020-02-24 01:32:59	2020-02-24	8	[{"id_menu":5,"count":1}]	13379	delivery	5	13
33819	2020-02-24 01:37:37	2020-02-24	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	10851	delivery	5	26
33820	2020-02-24 02:02:24	2020-02-24	9	[{"id_menu":7,"count":1}]	2799	pick-up	0	9
33821	2020-02-24 02:02:27	2020-02-24	8	[{"id_menu":5,"count":1}]	721	delivery	5	13
33822	2020-02-24 02:20:13	2020-02-24	12	[{"id_menu":3,"count":1}]	5019	pick-up	0	12
33823	2020-02-24 02:20:56	2020-02-24	9	[{"id_menu":6,"count":1}]	11681	delivery	5	14
33824	2020-02-24 02:25:55	2020-02-24	14	[{"id_menu":2,"count":1}]	1226	pick-up	0	14
33825	2020-02-24 02:36:08	2020-02-24	17	[{"id_menu":4,"count":1}]	13370	pick-up	0	17
33826	2020-02-24 02:46:41	2020-02-24	17	[{"id_menu":4,"count":1}]	123	delivery	5	22
33827	2020-02-24 02:49:00	2020-02-24	17	[{"id_menu":4,"count":1}]	13380	delivery	5	22
33828	2020-02-24 03:11:21	2020-02-24	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	5630	delivery	5	26
33829	2020-02-24 03:13:34	2020-02-24	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	5164	delivery	5	34
33830	2020-02-24 03:14:52	2020-02-24	9	[{"id_menu":7,"count":1}]	4960	pick-up	0	9
33831	2020-02-24 03:14:59	2020-02-24	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13415	delivery	5	40
33832	2020-02-24 03:31:41	2020-02-24	17	[{"id_menu":4,"count":1}]	1916	pick-up	0	17
33833	2020-02-24 03:43:03	2020-02-24	8	[{"id_menu":5,"count":1}]	771	delivery	5	13
33834	2020-02-24 03:55:25	2020-02-24	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	12132	delivery	5	42
33835	2020-02-24 04:07:14	2020-02-24	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13365	delivery	5	37
33836	2020-02-24 04:10:59	2020-02-24	9	[{"id_menu":6,"count":1}]	12159	delivery	5	14
33837	2020-02-24 04:20:50	2020-02-24	14	[{"id_menu":2,"count":1}]	13418	delivery	5	19
33838	2020-02-24 04:44:11	2020-02-24	8	[{"id_menu":5,"count":1}]	13405	delivery	5	13
33839	2020-02-24 04:45:13	2020-02-24	9	[{"id_menu":7,"count":1}]	10828	pick-up	0	9
33840	2020-02-24 04:48:47	2020-02-24	12	[{"id_menu":1,"count":1}]	13351	delivery	5	17
33841	2020-02-24 04:53:02	2020-02-24	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13344	delivery	5	34
33842	2020-02-24 04:58:28	2020-02-24	8	[{"id_menu":5,"count":1}]	13361	delivery	5	13
33843	2020-02-24 05:00:39	2020-02-24	9	[{"id_menu":6,"count":1}]	13406	delivery	5	14
33844	2020-02-24 05:04:32	2020-02-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13392	delivery	5	22
33845	2020-02-24 05:08:54	2020-02-24	9	[{"id_menu":6,"count":1}]	5485	delivery	5	14
33846	2020-02-24 05:14:41	2020-02-24	17	[{"id_menu":4,"count":1}]	1174	pick-up	0	17
33847	2020-02-24 05:19:00	2020-02-24	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11987	pick-up	0	26
33848	2020-02-24 05:19:41	2020-02-24	8	[{"id_menu":5,"count":1}]	786	pick-up	0	8
33849	2020-02-24 05:52:45	2020-02-24	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	8361	delivery	5	22
33850	2020-02-24 06:22:23	2020-02-24	9	[{"id_menu":7,"count":1}]	13382	delivery	5	14
33851	2020-02-24 06:22:35	2020-02-24	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	13386	delivery	5	26
33852	2020-02-24 06:24:51	2020-02-24	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	602	delivery	5	40
33853	2020-02-24 06:25:09	2020-02-24	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9218	delivery	5	34
33854	2020-02-24 06:31:07	2020-02-24	9	[{"id_menu":6,"count":1}]	13272	delivery	5	14
33855	2020-02-24 06:46:27	2020-02-24	55	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2744	pick-up	0	55
33856	2020-02-24 06:47:43	2020-02-24	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4818	delivery	5	39
33857	2020-02-24 06:56:07	2020-02-24	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9808	delivery	5	34
33858	2020-02-24 06:58:20	2020-02-24	9	[{"id_menu":7,"count":1}]	7934	pick-up	0	9
33859	2020-02-24 07:12:58	2020-02-24	12	[{"id_menu":3,"count":1}]	8705	delivery	5	17
33860	2020-02-24 07:18:49	2020-02-24	12	[{"id_menu":3,"count":1}]	4090	delivery	5	17
33861	2020-02-24 07:19:18	2020-02-24	17	[{"id_menu":4,"count":1}]	10142	pick-up	0	17
33862	2020-02-24 07:21:00	2020-02-24	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	3393	delivery	5	26
33863	2020-02-24 07:27:57	2020-02-24	8	[{"id_menu":5,"count":1}]	13387	delivery	5	13
33864	2020-02-24 07:28:04	2020-02-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	5744	delivery	5	28
33865	2020-02-24 08:02:32	2020-02-24	9	[{"id_menu":7,"count":1}]	7475	delivery	5	14
33866	2020-02-24 08:08:25	2020-02-24	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13425	delivery	5	31
33867	2020-02-24 08:12:23	2020-02-24	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	7908	delivery	5	25
33868	2020-02-24 08:21:02	2020-02-24	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	13353	delivery	5	25
33869	2020-02-24 08:38:01	2020-02-24	9	[{"id_menu":6,"count":1}]	13396	delivery	5	14
33870	2020-02-24 08:40:39	2020-02-24	17	[{"id_menu":4,"count":1}]	2309	pick-up	0	17
33871	2020-02-24 08:41:55	2020-02-24	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6328	pick-up	0	31
33872	2020-02-24 08:57:45	2020-02-24	9	[{"id_menu":7,"count":1}]	12322	delivery	5	14
33873	2020-02-24 09:00:27	2020-02-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	13409	delivery	5	23
33874	2020-02-24 09:04:53	2020-02-24	9	[{"id_menu":6,"count":1}]	2310	pick-up	0	9
33875	2020-02-24 09:16:46	2020-02-24	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	10872	delivery	5	29
33876	2020-02-24 09:29:54	2020-02-24	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5201	pick-up	0	17
33877	2020-02-24 09:30:29	2020-02-24	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	5318	pick-up	0	21
33878	2020-02-24 09:32:56	2020-02-24	8	[{"id_menu":5,"count":1}]	8057	pick-up	0	8
33879	2020-02-24 09:40:42	2020-02-24	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	13319	pick-up	0	26
33880	2020-02-24 09:40:42	2020-02-24	17	[{"id_menu":4,"count":1}]	13355	delivery	5	22
33881	2020-02-24 09:44:04	2020-02-24	9	[{"id_menu":7,"count":1}]	2193	delivery	5	14
33882	2020-02-24 09:50:33	2020-02-24	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	4479	pick-up	0	29
33883	2020-02-24 09:58:44	2020-02-24	12	[{"id_menu":1,"count":1}]	13376	delivery	5	17
33884	2020-02-24 10:06:22	2020-02-24	9	[{"id_menu":6,"count":1}]	13420	delivery	5	14
33885	2020-02-24 10:11:42	2020-02-24	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13333	delivery	5	48
33886	2020-02-24 10:22:35	2020-02-24	9	[{"id_menu":6,"count":1}]	13371	delivery	5	14
33887	2020-02-24 10:32:20	2020-02-24	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	13345	delivery	5	31
33888	2020-02-24 11:17:37	2020-02-24	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	13331	delivery	5	42
33889	2020-02-24 11:29:04	2020-02-24	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	13349	pick-up	0	35
33890	2020-02-24 11:39:59	2020-02-24	17	[{"id_menu":4,"count":1}]	11254	delivery	5	22
33891	2020-02-24 11:54:46	2020-02-24	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	13383	delivery	5	57
33892	2020-02-24 11:59:48	2020-02-24	8	[{"id_menu":5,"count":1}]	13364	delivery	5	13
33893	2020-02-24 12:41:15	2020-02-24	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	286	pick-up	0	40
33894	2020-02-24 12:48:20	2020-02-24	9	[{"id_menu":7,"count":1}]	13320	pick-up	0	9
33895	2020-02-24 12:51:21	2020-02-24	14	[{"id_menu":2,"count":1}]	1367	pick-up	0	14
33896	2020-02-24 13:01:27	2020-02-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13411	delivery	5	22
33897	2020-02-24 13:06:03	2020-02-24	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	11671	delivery	5	48
33898	2020-02-24 13:24:11	2020-02-24	9	[{"id_menu":6,"count":1}]	4541	delivery	5	14
33899	2020-02-24 13:24:23	2020-02-24	9	[{"id_menu":7,"count":1}]	3598	delivery	5	14
33900	2020-02-24 13:26:08	2020-02-24	17	[{"id_menu":4,"count":1}]	5483	pick-up	0	17
33901	2020-02-24 13:33:14	2020-02-24	12	[{"id_menu":1,"count":1}]	13414	delivery	5	17
33902	2020-02-24 13:46:54	2020-02-24	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	6609	delivery	5	31
33903	2020-02-24 14:12:49	2020-02-24	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1833	pick-up	0	21
33904	2020-02-24 14:14:39	2020-02-24	17	[{"id_menu":4,"count":1}]	13378	delivery	5	22
33905	2020-02-24 14:28:16	2020-02-24	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	13326	delivery	5	22
33906	2020-02-24 14:30:30	2020-02-24	9	[{"id_menu":6,"count":1}]	13342	pick-up	0	9
33907	2020-02-24 14:32:22	2020-02-24	9	[{"id_menu":7,"count":1}]	7137	delivery	5	14
33908	2020-02-24 14:56:17	2020-02-24	17	[{"id_menu":4,"count":1}]	12623	pick-up	0	17
33909	2020-02-24 15:14:32	2020-02-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9359	delivery	5	22
33910	2020-02-24 15:17:14	2020-02-24	9	[{"id_menu":7,"count":1}]	10039	pick-up	0	9
33911	2020-02-24 15:18:13	2020-02-24	17	[{"id_menu":4,"count":1}]	13395	delivery	5	22
33912	2020-02-24 15:22:05	2020-02-24	9	[{"id_menu":7,"count":1}]	13402	delivery	5	14
33913	2020-02-24 15:23:11	2020-02-24	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13424	delivery	5	47
33914	2020-02-24 15:33:00	2020-02-24	14	[{"id_menu":2,"count":1}]	2618	delivery	5	19
33915	2020-02-24 15:33:02	2020-02-24	9	[{"id_menu":6,"count":1}]	11316	delivery	5	14
33916	2020-02-24 15:56:55	2020-02-24	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13399	delivery	5	31
33917	2020-02-24 15:59:43	2020-02-24	9	[{"id_menu":7,"count":1}]	12474	pick-up	0	9
33918	2020-02-24 16:04:27	2020-02-24	14	[{"id_menu":2,"count":1}]	12150	pick-up	0	14
33919	2020-02-24 16:04:33	2020-02-24	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	3201	delivery	5	29
33920	2020-02-24 16:11:38	2020-02-24	12	[{"id_menu":3,"count":1}]	13317	pick-up	0	12
33921	2020-02-24 16:12:33	2020-02-24	9	[{"id_menu":7,"count":1}]	13416	delivery	5	14
33922	2020-02-24 16:36:55	2020-02-24	9	[{"id_menu":7,"count":1}]	10135	delivery	5	14
33923	2020-02-24 16:37:41	2020-02-24	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2731	delivery	5	25
33924	2020-02-24 16:40:50	2020-02-24	9	[{"id_menu":6,"count":1}]	763	delivery	5	14
33925	2020-02-24 16:49:49	2020-02-24	9	[{"id_menu":6,"count":1}]	3699	delivery	5	14
33926	2020-02-24 16:54:57	2020-02-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1681	pick-up	0	23
33927	2020-02-24 17:00:28	2020-02-24	8	[{"id_menu":5,"count":1}]	13417	delivery	5	13
33928	2020-02-24 17:12:00	2020-02-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13310	delivery	5	22
33929	2020-02-24 17:15:00	2020-02-24	14	[{"id_menu":2,"count":1}]	991	pick-up	0	14
33930	2020-02-24 17:30:05	2020-02-24	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	315	pick-up	0	40
33931	2020-02-24 17:42:17	2020-02-24	14	[{"id_menu":2,"count":1}]	6950	pick-up	0	14
33932	2020-02-24 17:51:43	2020-02-24	9	[{"id_menu":7,"count":1}]	13338	delivery	5	14
33933	2020-02-24 17:53:08	2020-02-24	14	[{"id_menu":2,"count":1}]	11046	delivery	5	19
33934	2020-02-24 17:58:59	2020-02-24	9	[{"id_menu":6,"count":2}]	1968	delivery	5	14
33935	2020-02-24 18:07:21	2020-02-24	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	5306	pick-up	0	31
33936	2020-02-24 18:11:22	2020-02-24	12	[{"id_menu":1,"count":1}]	582	pick-up	0	12
33937	2020-02-24 18:19:13	2020-02-24	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	3017	delivery	5	26
33938	2020-02-24 18:20:14	2020-02-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10799	delivery	5	23
33939	2020-02-24 18:23:12	2020-02-24	9	[{"id_menu":6,"count":1}]	13324	pick-up	0	9
33940	2020-02-24 18:24:12	2020-02-24	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	13347	delivery	5	29
33941	2020-02-24 18:25:25	2020-02-24	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2552	pick-up	0	26
33942	2020-02-24 18:30:20	2020-02-24	8	[{"id_menu":5,"count":1}]	2699	delivery	5	13
33943	2020-02-24 18:39:15	2020-02-24	9	[{"id_menu":6,"count":1}]	4941	delivery	5	14
33944	2020-02-24 18:41:46	2020-02-24	9	[{"id_menu":7,"count":1}]	13403	delivery	5	14
33945	2020-02-24 18:43:09	2020-02-24	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4655	delivery	5	30
33946	2020-02-24 18:43:51	2020-02-24	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3106	delivery	5	40
33947	2020-02-24 18:46:46	2020-02-24	17	[{"id_menu":4,"count":1}]	6642	delivery	5	22
33948	2020-02-24 18:50:37	2020-02-24	9	[{"id_menu":7,"count":1}]	7514	delivery	5	14
33949	2020-02-24 19:11:12	2020-02-24	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	13327	delivery	5	39
33950	2020-02-24 19:15:55	2020-02-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5236	delivery	5	28
33951	2020-02-24 19:24:44	2020-02-24	17	[{"id_menu":4,"count":1}]	2332	delivery	5	22
33952	2020-02-24 19:30:47	2020-02-24	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1813	pick-up	0	21
33953	2020-02-24 19:32:06	2020-02-24	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	7083	pick-up	0	21
33954	2020-02-24 19:44:19	2020-02-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	5325	delivery	5	28
33955	2020-02-24 19:56:39	2020-02-24	9	[{"id_menu":7,"count":1}]	12169	delivery	5	14
33956	2020-02-24 19:58:02	2020-02-24	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	4024	delivery	5	34
33957	2020-02-24 20:13:19	2020-02-24	8	[{"id_menu":5,"count":1}]	1202	pick-up	0	8
33958	2020-02-24 20:30:39	2020-02-24	8	[{"id_menu":5,"count":1}]	13401	delivery	5	13
33959	2020-02-24 20:34:42	2020-02-24	9	[{"id_menu":7,"count":1}]	13366	delivery	5	14
33960	2020-02-24 20:35:37	2020-02-24	12	[{"id_menu":3,"count":1}]	7398	delivery	5	17
33961	2020-02-24 20:43:05	2020-02-24	12	[{"id_menu":1,"count":1}]	6664	delivery	5	17
33962	2020-02-24 20:44:54	2020-02-24	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13354	delivery	5	39
33963	2020-02-24 20:46:07	2020-02-24	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2182	delivery	5	34
33964	2020-02-24 20:49:45	2020-02-24	12	[{"id_menu":3,"count":1}]	6145	delivery	5	17
33965	2020-02-24 20:51:40	2020-02-24	14	[{"id_menu":2,"count":1}]	13374	delivery	5	19
33966	2020-02-24 20:58:39	2020-02-24	8	[{"id_menu":5,"count":1}]	13419	delivery	5	13
33967	2020-02-24 21:01:11	2020-02-24	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	10321	delivery	5	26
33968	2020-02-24 21:02:09	2020-02-24	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	10795	delivery	5	31
33969	2020-02-24 21:03:50	2020-02-24	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3286	delivery	5	43
33970	2020-02-24 21:05:01	2020-02-24	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	5837	delivery	5	27
33971	2020-02-24 21:05:52	2020-02-24	8	[{"id_menu":5,"count":1}]	1334	pick-up	0	8
33972	2020-02-24 21:06:45	2020-02-24	14	[{"id_menu":2,"count":1}]	1569	pick-up	0	14
33973	2020-02-24 21:15:02	2020-02-24	9	[{"id_menu":7,"count":1}]	4956	pick-up	0	9
33974	2020-02-24 21:19:48	2020-02-24	17	[{"id_menu":4,"count":2}]	7760	pick-up	0	17
33975	2020-02-24 21:21:18	2020-02-24	8	[{"id_menu":5,"count":1}]	7691	delivery	5	13
33976	2020-02-24 21:37:52	2020-02-24	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	13388	delivery	5	29
33977	2020-02-24 21:52:57	2020-02-24	12	[{"id_menu":3,"count":1}]	10745	delivery	5	17
33978	2020-02-24 21:54:07	2020-02-24	9	[{"id_menu":6,"count":1}]	13358	pick-up	0	9
33979	2020-02-24 22:06:21	2020-02-24	8	[{"id_menu":5,"count":2}]	13413	delivery	5	13
33980	2020-02-24 22:15:33	2020-02-24	9	[{"id_menu":6,"count":1}]	6652	delivery	5	14
33981	2020-02-24 22:25:55	2020-02-24	8	[{"id_menu":5,"count":1}]	13394	delivery	5	13
33982	2020-02-24 22:27:03	2020-02-24	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	13329	delivery	5	31
33983	2020-02-24 22:32:49	2020-02-24	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	10018	delivery	5	25
33984	2020-02-24 22:39:56	2020-02-24	8	[{"id_menu":5,"count":1}]	5735	delivery	5	13
33985	2020-02-24 22:43:27	2020-02-24	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	13343	delivery	5	34
33986	2020-02-24 22:46:35	2020-02-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	13385	delivery	5	28
33987	2020-02-24 22:58:22	2020-02-24	17	[{"id_menu":4,"count":1}]	11158	delivery	5	22
33988	2020-02-24 23:15:48	2020-02-24	8	[{"id_menu":5,"count":1}]	13391	pick-up	0	8
33989	2020-02-24 23:22:45	2020-02-24	12	[{"id_menu":1,"count":1}]	3864	delivery	5	17
33990	2020-02-24 23:33:45	2020-02-24	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	552	pick-up	0	29
33991	2020-02-24 23:34:36	2020-02-24	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	10729	delivery	5	35
33992	2020-02-24 23:43:56	2020-02-24	14	[{"id_menu":2,"count":1}]	2603	delivery	5	19
33993	2020-02-24 23:48:11	2020-02-24	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	13363	delivery	5	34
33994	2020-02-24 23:49:39	2020-02-24	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	9449	delivery	5	31
33995	2020-02-24 23:58:34	2020-02-24	9	[{"id_menu":7,"count":1}]	13318	delivery	5	14
33996	2020-02-25 00:04:42	2020-02-25	12	[{"id_menu":3,"count":1}]	8261	pick-up	0	12
33997	2020-02-25 00:07:42	2020-02-25	14	[{"id_menu":2,"count":1}]	7727	delivery	5	19
33998	2020-02-25 00:11:19	2020-02-25	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	12784	delivery	5	34
33999	2020-02-25 00:16:16	2020-02-25	9	[{"id_menu":7,"count":3}]	3467	delivery	5	14
34000	2020-02-25 00:17:01	2020-02-25	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	11010	pick-up	0	20
34001	2020-02-25 00:25:42	2020-02-25	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	12240	delivery	5	26
34002	2020-02-25 00:49:04	2020-02-25	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13457	delivery	5	22
34003	2020-02-25 00:51:25	2020-02-25	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13460	delivery	5	31
34004	2020-02-25 00:51:29	2020-02-25	14	[{"id_menu":2,"count":1}]	13172	delivery	5	19
34005	2020-02-25 00:54:04	2020-02-25	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	11225	pick-up	0	22
34006	2020-02-25 00:57:18	2020-02-25	14	[{"id_menu":2,"count":1}]	11357	delivery	5	19
34007	2020-02-25 00:57:37	2020-02-25	9	[{"id_menu":7,"count":1}]	13492	pick-up	0	9
34008	2020-02-25 01:01:58	2020-02-25	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	13520	delivery	5	23
34009	2020-02-25 01:04:43	2020-02-25	9	[{"id_menu":7,"count":1}]	13470	delivery	5	14
34010	2020-02-25 01:09:50	2020-02-25	17	[{"id_menu":4,"count":1}]	13454	delivery	5	22
34011	2020-02-25 01:10:20	2020-02-25	14	[{"id_menu":2,"count":1}]	5151	delivery	5	19
34012	2020-02-25 01:13:20	2020-02-25	9	[{"id_menu":7,"count":1}]	847	delivery	5	14
34013	2020-02-25 01:25:57	2020-02-25	12	[{"id_menu":1,"count":1}]	13444	delivery	5	17
34014	2020-02-25 01:40:26	2020-02-25	9	[{"id_menu":7,"count":1}]	2337	pick-up	0	9
34015	2020-02-25 01:43:40	2020-02-25	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	13430	delivery	5	31
34016	2020-02-25 01:46:27	2020-02-25	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13505	delivery	5	49
34017	2020-02-25 01:47:24	2020-02-25	12	[{"id_menu":3,"count":1}]	497	pick-up	0	12
34018	2020-02-25 01:48:57	2020-02-25	14	[{"id_menu":2,"count":1}]	4981	pick-up	0	14
34019	2020-02-25 01:58:37	2020-02-25	17	[{"id_menu":4,"count":1}]	10008	delivery	5	22
34020	2020-02-25 01:59:13	2020-02-25	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	12728	delivery	5	44
34021	2020-02-25 02:03:27	2020-02-25	12	[{"id_menu":1,"count":1}]	10225	delivery	5	17
34022	2020-02-25 02:25:32	2020-02-25	9	[{"id_menu":6,"count":1}]	6174	delivery	5	14
34023	2020-02-25 02:38:09	2020-02-25	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6013	delivery	5	28
34024	2020-02-25 02:40:53	2020-02-25	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4281	delivery	5	42
34025	2020-02-25 03:17:58	2020-02-25	9	[{"id_menu":7,"count":1}]	4796	delivery	5	14
34026	2020-02-25 03:18:28	2020-02-25	9	[{"id_menu":6,"count":1}]	7186	delivery	5	14
34027	2020-02-25 03:19:33	2020-02-25	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	9621	delivery	5	34
34028	2020-02-25 03:31:50	2020-02-25	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	13487	delivery	5	31
34029	2020-02-25 03:42:10	2020-02-25	12	[{"id_menu":1,"count":1}]	386	delivery	5	17
34030	2020-02-25 03:45:08	2020-02-25	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2867	pick-up	0	21
34031	2020-02-25 03:51:39	2020-02-25	12	[{"id_menu":3,"count":1}]	8142	delivery	5	17
34032	2020-02-25 04:00:55	2020-02-25	12	[{"id_menu":1,"count":1}]	13482	delivery	5	17
34033	2020-02-25 04:01:00	2020-02-25	12	[{"id_menu":1,"count":1}]	13500	delivery	5	17
34034	2020-02-25 04:01:16	2020-02-25	9	[{"id_menu":6,"count":1}]	13478	delivery	5	14
34035	2020-02-25 04:07:28	2020-02-25	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	13507	delivery	5	36
34036	2020-02-25 04:08:44	2020-02-25	9	[{"id_menu":7,"count":1}]	1429	delivery	5	14
34037	2020-02-25 04:23:29	2020-02-25	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13512	delivery	5	37
34038	2020-02-25 04:28:47	2020-02-25	8	[{"id_menu":5,"count":1}]	6941	pick-up	0	8
34039	2020-02-25 04:36:29	2020-02-25	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	8380	delivery	5	39
34040	2020-02-25 04:40:55	2020-02-25	8	[{"id_menu":5,"count":1}]	11671	delivery	5	13
34041	2020-02-25 04:44:25	2020-02-25	8	[{"id_menu":5,"count":1}]	12553	delivery	5	13
34042	2020-02-25 04:48:58	2020-02-25	9	[{"id_menu":7,"count":1}]	13449	delivery	5	14
34043	2020-02-25 04:53:07	2020-02-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	13484	delivery	5	28
34044	2020-02-25 04:56:50	2020-02-25	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2552	delivery	5	36
34045	2020-02-25 04:59:16	2020-02-25	17	[{"id_menu":4,"count":3}]	4442	delivery	5	22
34046	2020-02-25 05:03:03	2020-02-25	17	[{"id_menu":4,"count":1}]	13443	delivery	5	22
34047	2020-02-25 05:12:41	2020-02-25	9	[{"id_menu":6,"count":1}]	3688	delivery	5	14
34048	2020-02-25 05:14:21	2020-02-25	14	[{"id_menu":2,"count":1}]	13494	delivery	5	19
34049	2020-02-25 05:14:26	2020-02-25	9	[{"id_menu":6,"count":1}]	9193	pick-up	0	9
34050	2020-02-25 05:14:43	2020-02-25	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4078	delivery	5	36
34051	2020-02-25 05:15:03	2020-02-25	14	[{"id_menu":2,"count":1}]	1006	delivery	5	19
34052	2020-02-25 05:23:26	2020-02-25	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	6477	delivery	5	40
34053	2020-02-25 05:24:11	2020-02-25	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1032	pick-up	0	23
34054	2020-02-25 05:26:31	2020-02-25	14	[{"id_menu":2,"count":1}]	10839	pick-up	0	14
34055	2020-02-25 05:30:36	2020-02-25	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	6783	delivery	5	34
34056	2020-02-25 05:33:57	2020-02-25	9	[{"id_menu":7,"count":1}]	7693	delivery	5	14
34057	2020-02-25 05:42:44	2020-02-25	12	[{"id_menu":1,"count":1}]	13431	delivery	5	17
34058	2020-02-25 05:46:11	2020-02-25	14	[{"id_menu":2,"count":2}]	10939	pick-up	0	14
34059	2020-02-25 05:48:27	2020-02-25	12	[{"id_menu":1,"count":1}]	6497	pick-up	0	12
34060	2020-02-25 05:56:51	2020-02-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13486	delivery	5	23
34061	2020-02-25 06:13:05	2020-02-25	14	[{"id_menu":2,"count":1}]	13461	pick-up	0	14
34062	2020-02-25 06:20:42	2020-02-25	9	[{"id_menu":6,"count":1}]	5881	delivery	5	14
34063	2020-02-25 06:22:48	2020-02-25	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	486	pick-up	0	30
34064	2020-02-25 06:32:07	2020-02-25	12	[{"id_menu":3,"count":1}]	7168	delivery	5	17
34065	2020-02-25 06:34:06	2020-02-25	14	[{"id_menu":2,"count":1}]	1304	pick-up	0	14
34066	2020-02-25 06:35:00	2020-02-25	9	[{"id_menu":6,"count":2}]	13468	delivery	5	14
34067	2020-02-25 06:42:05	2020-02-25	8	[{"id_menu":5,"count":1}]	11441	delivery	5	13
34068	2020-02-25 06:45:18	2020-02-25	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4328	delivery	5	36
34069	2020-02-25 06:46:44	2020-02-25	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	13514	delivery	5	26
34070	2020-02-25 07:02:41	2020-02-25	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	10730	delivery	5	31
34071	2020-02-25 07:03:04	2020-02-25	9	[{"id_menu":6,"count":1}]	8029	delivery	5	14
34072	2020-02-25 07:11:32	2020-02-25	9	[{"id_menu":6,"count":1}]	13471	delivery	5	14
34073	2020-02-25 07:14:28	2020-02-25	17	[{"id_menu":4,"count":1}]	4533	pick-up	0	17
34074	2020-02-25 07:18:59	2020-02-25	8	[{"id_menu":5,"count":1}]	13481	delivery	5	13
34075	2020-02-25 07:19:23	2020-02-25	8	[{"id_menu":5,"count":3}]	13516	delivery	5	13
34076	2020-02-25 07:28:54	2020-02-25	12	[{"id_menu":1,"count":1}]	1523	delivery	5	17
34077	2020-02-25 07:52:57	2020-02-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1066	delivery	5	31
34078	2020-02-25 08:02:19	2020-02-25	14	[{"id_menu":2,"count":1}]	1368	pick-up	0	14
34079	2020-02-25 08:15:40	2020-02-25	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	6975	pick-up	0	20
34080	2020-02-25 08:24:48	2020-02-25	17	[{"id_menu":4,"count":1}]	12542	pick-up	0	17
34081	2020-02-25 08:36:03	2020-02-25	9	[{"id_menu":7,"count":1}]	11692	delivery	5	14
34082	2020-02-25 08:58:58	2020-02-25	9	[{"id_menu":6,"count":1}]	8791	pick-up	0	9
34083	2020-02-25 09:04:53	2020-02-25	9	[{"id_menu":7,"count":1}]	13509	delivery	5	14
34084	2020-02-25 09:21:32	2020-02-25	9	[{"id_menu":6,"count":1}]	8645	delivery	5	14
34085	2020-02-25 09:21:53	2020-02-25	14	[{"id_menu":2,"count":1}]	13502	pick-up	0	14
34086	2020-02-25 09:23:44	2020-02-25	9	[{"id_menu":7,"count":1}]	13496	delivery	5	14
34087	2020-02-25 09:26:31	2020-02-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13518	delivery	5	22
34088	2020-02-25 09:26:50	2020-02-25	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	6235	delivery	5	34
34089	2020-02-25 09:35:14	2020-02-25	12	[{"id_menu":1,"count":1}]	7920	delivery	5	17
34090	2020-02-25 09:50:21	2020-02-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":3}]	13485	delivery	5	31
34091	2020-02-25 10:02:41	2020-02-25	9	[{"id_menu":7,"count":1}]	5483	pick-up	0	9
34092	2020-02-25 10:04:32	2020-02-25	8	[{"id_menu":5,"count":1}]	13459	pick-up	0	8
34093	2020-02-25 10:15:32	2020-02-25	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10601	delivery	5	36
34094	2020-02-25 10:31:29	2020-02-25	9	[{"id_menu":6,"count":1}]	12197	delivery	5	14
34095	2020-02-25 10:34:29	2020-02-25	9	[{"id_menu":7,"count":1}]	6714	delivery	5	14
34096	2020-02-25 10:52:54	2020-02-25	9	[{"id_menu":6,"count":1}]	13442	pick-up	0	9
34097	2020-02-25 11:03:13	2020-02-25	9	[{"id_menu":7,"count":1}]	12572	delivery	5	14
34098	2020-02-25 11:14:16	2020-02-25	9	[{"id_menu":6,"count":1}]	9901	delivery	5	14
34099	2020-02-25 11:21:25	2020-02-25	9	[{"id_menu":7,"count":1}]	13522	pick-up	0	9
34100	2020-02-25 11:25:46	2020-02-25	9	[{"id_menu":6,"count":1}]	1862	delivery	5	14
34101	2020-02-25 11:49:02	2020-02-25	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	5806	delivery	5	26
34102	2020-02-25 11:53:12	2020-02-25	12	[{"id_menu":1,"count":1}]	13473	delivery	5	17
34103	2020-02-25 11:57:02	2020-02-25	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	11531	pick-up	0	20
34104	2020-02-25 11:59:39	2020-02-25	12	[{"id_menu":1,"count":1}]	4000	pick-up	0	12
34105	2020-02-25 12:12:24	2020-02-25	17	[{"id_menu":4,"count":1}]	7927	pick-up	0	17
34106	2020-02-25 12:29:42	2020-02-25	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	8893	delivery	5	26
34107	2020-02-25 12:30:39	2020-02-25	8	[{"id_menu":5,"count":1}]	13448	delivery	5	13
34108	2020-02-25 12:36:58	2020-02-25	9	[{"id_menu":7,"count":1}]	10759	delivery	5	14
34109	2020-02-25 12:37:57	2020-02-25	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	11728	delivery	5	26
34110	2020-02-25 12:44:14	2020-02-25	9	[{"id_menu":6,"count":1}]	11232	pick-up	0	9
34111	2020-02-25 12:49:24	2020-02-25	14	[{"id_menu":2,"count":1}]	98	delivery	5	19
34112	2020-02-25 12:58:46	2020-02-25	12	[{"id_menu":3,"count":1}]	13493	delivery	5	17
34113	2020-02-25 13:00:17	2020-02-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5737	delivery	5	28
34114	2020-02-25 13:19:20	2020-02-25	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	13439	delivery	5	30
34115	2020-02-25 13:36:43	2020-02-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13427	delivery	5	22
34116	2020-02-25 13:42:22	2020-02-25	14	[{"id_menu":2,"count":1}]	13508	delivery	5	19
34117	2020-02-25 13:48:14	2020-02-25	8	[{"id_menu":5,"count":1}]	880	delivery	5	13
34118	2020-02-25 13:50:34	2020-02-25	17	[{"id_menu":4,"count":1}]	6622	pick-up	0	17
34119	2020-02-25 13:56:01	2020-02-25	9	[{"id_menu":7,"count":1}]	13432	delivery	5	14
34120	2020-02-25 14:06:46	2020-02-25	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	12849	delivery	5	26
34121	2020-02-25 14:08:03	2020-02-25	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	13438	delivery	5	48
34122	2020-02-25 14:13:00	2020-02-25	14	[{"id_menu":2,"count":1}]	143	pick-up	0	14
34123	2020-02-25 14:14:45	2020-02-25	9	[{"id_menu":6,"count":1}]	2275	pick-up	0	9
34124	2020-02-25 14:38:32	2020-02-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	698	delivery	5	31
34125	2020-02-25 14:43:21	2020-02-25	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11839	delivery	5	43
34126	2020-02-25 14:50:09	2020-02-25	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	5645	delivery	5	36
34127	2020-02-25 14:57:07	2020-02-25	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	13465	delivery	5	29
34128	2020-02-25 14:59:57	2020-02-25	12	[{"id_menu":1,"count":1}]	13447	pick-up	0	12
34129	2020-02-25 15:23:27	2020-02-25	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5820	delivery	5	35
34130	2020-02-25 15:26:53	2020-02-25	12	[{"id_menu":1,"count":1}]	13523	delivery	5	17
34131	2020-02-25 15:44:41	2020-02-25	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2071	pick-up	0	21
34132	2020-02-25 15:45:57	2020-02-25	12	[{"id_menu":3,"count":1}]	13498	pick-up	0	12
34133	2020-02-25 15:53:38	2020-02-25	12	[{"id_menu":3,"count":1}]	6284	pick-up	0	12
34134	2020-02-25 15:58:27	2020-02-25	8	[{"id_menu":5,"count":2}]	10393	pick-up	0	8
34135	2020-02-25 16:01:02	2020-02-25	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13441	delivery	5	39
34136	2020-02-25 16:17:13	2020-02-25	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	13437	delivery	5	22
34137	2020-02-25 16:29:29	2020-02-25	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	6911	delivery	5	25
34138	2020-02-25 16:32:02	2020-02-25	9	[{"id_menu":6,"count":1}]	4102	pick-up	0	9
34139	2020-02-25 16:35:41	2020-02-25	9	[{"id_menu":7,"count":1}]	13490	delivery	5	14
34140	2020-02-25 16:46:28	2020-02-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	13497	pick-up	0	23
34141	2020-02-25 16:51:44	2020-02-25	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7258	delivery	5	34
34142	2020-02-25 17:06:29	2020-02-25	8	[{"id_menu":5,"count":1}]	13495	pick-up	0	8
34143	2020-02-25 17:10:58	2020-02-25	14	[{"id_menu":2,"count":1}]	7814	delivery	5	19
34144	2020-02-25 17:12:34	2020-02-25	14	[{"id_menu":2,"count":1}]	5444	pick-up	0	14
34145	2020-02-25 17:22:10	2020-02-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5656	delivery	5	22
34146	2020-02-25 17:22:34	2020-02-25	12	[{"id_menu":3,"count":1}]	13474	delivery	5	17
34147	2020-02-25 17:38:40	2020-02-25	17	[{"id_menu":4,"count":1}]	3228	pick-up	0	17
34148	2020-02-25 17:50:24	2020-02-25	9	[{"id_menu":7,"count":1}]	13450	pick-up	0	9
34149	2020-02-25 17:55:29	2020-02-25	9	[{"id_menu":6,"count":1}]	4247	delivery	5	14
34150	2020-02-25 17:59:20	2020-02-25	9	[{"id_menu":6,"count":1}]	5478	pick-up	0	9
34151	2020-02-25 18:07:00	2020-02-25	8	[{"id_menu":5,"count":1}]	8305	delivery	5	13
34152	2020-02-25 18:09:52	2020-02-25	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	6516	delivery	5	31
34153	2020-02-25 18:21:09	2020-02-25	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	13524	delivery	5	28
34154	2020-02-25 18:26:48	2020-02-25	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	13436	delivery	5	40
34155	2020-02-25 18:30:35	2020-02-25	9	[{"id_menu":7,"count":1}]	410	delivery	5	14
34156	2020-02-25 18:43:40	2020-02-25	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8307	delivery	5	28
34157	2020-02-25 18:46:35	2020-02-25	14	[{"id_menu":2,"count":1}]	13477	delivery	5	19
34158	2020-02-25 18:55:37	2020-02-25	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	13503	delivery	5	31
34159	2020-02-25 19:09:06	2020-02-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13489	delivery	5	22
34160	2020-02-25 19:12:53	2020-02-25	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	691	pick-up	0	31
34161	2020-02-25 19:15:15	2020-02-25	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13451	delivery	5	43
34162	2020-02-25 19:18:57	2020-02-25	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7476	delivery	5	35
34163	2020-02-25 19:19:25	2020-02-25	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6130	delivery	5	45
34164	2020-02-25 19:35:14	2020-02-25	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	507	delivery	5	23
34165	2020-02-25 19:38:29	2020-02-25	14	[{"id_menu":2,"count":1}]	13475	pick-up	0	14
34166	2020-02-25 19:42:17	2020-02-25	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3318	delivery	5	52
34167	2020-02-25 19:51:18	2020-02-25	8	[{"id_menu":5,"count":1}]	242	delivery	5	13
34168	2020-02-25 19:51:26	2020-02-25	9	[{"id_menu":7,"count":1}]	12022	delivery	5	14
34169	2020-02-25 19:56:45	2020-02-25	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9878	delivery	5	31
34170	2020-02-25 19:59:35	2020-02-25	17	[{"id_menu":4,"count":1}]	6221	delivery	5	22
34171	2020-02-25 20:09:48	2020-02-25	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	13526	delivery	5	26
34172	2020-02-25 20:21:04	2020-02-25	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	6918	delivery	5	27
34173	2020-02-25 20:29:50	2020-02-25	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	8311	delivery	5	43
34174	2020-02-25 20:35:07	2020-02-25	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	13491	delivery	5	26
34175	2020-02-25 20:46:15	2020-02-25	9	[{"id_menu":6,"count":1}]	10971	pick-up	0	9
34176	2020-02-25 20:46:46	2020-02-25	9	[{"id_menu":6,"count":2}]	13483	delivery	5	14
34177	2020-02-25 20:56:21	2020-02-25	9	[{"id_menu":7,"count":1}]	2569	pick-up	0	9
34178	2020-02-25 21:32:52	2020-02-25	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6104	delivery	5	37
34179	2020-02-25 21:38:34	2020-02-25	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	5751	delivery	5	40
34180	2020-02-25 21:38:58	2020-02-25	12	[{"id_menu":3,"count":1}]	226	pick-up	0	12
34181	2020-02-25 21:45:47	2020-02-25	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13462	delivery	5	45
34182	2020-02-25 21:46:29	2020-02-25	14	[{"id_menu":2,"count":1}]	264	delivery	5	19
34183	2020-02-25 21:52:13	2020-02-25	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	10365	delivery	5	29
34184	2020-02-25 22:06:47	2020-02-25	9	[{"id_menu":6,"count":1}]	13479	delivery	5	14
34185	2020-02-25 22:15:43	2020-02-25	14	[{"id_menu":2,"count":2}]	2352	pick-up	0	14
34186	2020-02-25 22:18:58	2020-02-25	17	[{"id_menu":4,"count":2}]	8837	delivery	5	22
34187	2020-02-25 22:21:08	2020-02-25	9	[{"id_menu":7,"count":1}]	5308	pick-up	0	9
34188	2020-02-25 22:32:44	2020-02-25	14	[{"id_menu":2,"count":1}]	10647	delivery	5	19
34189	2020-02-25 22:38:30	2020-02-25	8	[{"id_menu":5,"count":1}]	6150	delivery	5	13
34190	2020-02-25 22:56:08	2020-02-25	17	[{"id_menu":4,"count":1}]	13504	pick-up	0	17
34191	2020-02-25 22:57:08	2020-02-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4187	delivery	5	23
34192	2020-02-25 23:03:27	2020-02-25	9	[{"id_menu":7,"count":1}]	8226	delivery	5	14
34193	2020-02-25 23:13:25	2020-02-25	12	[{"id_menu":1,"count":1}]	5113	delivery	5	17
34194	2020-02-25 23:15:56	2020-02-25	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	7238	delivery	5	23
34195	2020-02-25 23:25:48	2020-02-25	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	13476	delivery	5	39
34196	2020-02-25 23:35:44	2020-02-25	17	[{"id_menu":4,"count":1}]	13435	delivery	5	22
34197	2020-02-25 23:35:50	2020-02-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13433	delivery	5	23
34198	2020-02-25 23:36:08	2020-02-25	8	[{"id_menu":5,"count":1}]	2252	pick-up	0	8
34199	2020-02-25 23:52:37	2020-02-25	9	[{"id_menu":6,"count":1}]	13501	delivery	5	14
34200	2020-02-25 23:55:07	2020-02-25	9	[{"id_menu":6,"count":1}]	519	delivery	5	14
34201	2020-02-26 00:07:26	2020-02-26	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7133	delivery	5	35
34202	2020-02-26 00:11:55	2020-02-26	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	9400	delivery	5	31
34203	2020-02-26 00:17:57	2020-02-26	12	[{"id_menu":1,"count":1}]	13562	delivery	5	17
34204	2020-02-26 00:25:55	2020-02-26	9	[{"id_menu":7,"count":1}]	13545	delivery	5	14
34205	2020-02-26 00:28:53	2020-02-26	14	[{"id_menu":2,"count":2}]	4946	delivery	5	19
34206	2020-02-26 00:37:38	2020-02-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	1429	delivery	5	22
34207	2020-02-26 00:41:19	2020-02-26	9	[{"id_menu":6,"count":1}]	2602	delivery	5	14
34208	2020-02-26 00:44:15	2020-02-26	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	8584	delivery	5	26
34209	2020-02-26 00:46:33	2020-02-26	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	3549	delivery	5	25
34210	2020-02-26 00:47:51	2020-02-26	9	[{"id_menu":6,"count":1}]	5552	delivery	5	14
34211	2020-02-26 00:48:46	2020-02-26	17	[{"id_menu":4,"count":1}]	9382	delivery	5	22
34212	2020-02-26 00:54:55	2020-02-26	8	[{"id_menu":5,"count":1}]	10469	delivery	5	13
34213	2020-02-26 00:56:26	2020-02-26	9	[{"id_menu":6,"count":1}]	13583	pick-up	0	9
34214	2020-02-26 01:14:10	2020-02-26	12	[{"id_menu":1,"count":1}]	13586	delivery	5	17
34215	2020-02-26 01:21:10	2020-02-26	14	[{"id_menu":2,"count":1}]	13564	delivery	5	19
34216	2020-02-26 01:31:02	2020-02-26	12	[{"id_menu":3,"count":1}]	7782	pick-up	0	12
34217	2020-02-26 01:38:17	2020-02-26	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4740	delivery	5	27
34218	2020-02-26 01:42:54	2020-02-26	8	[{"id_menu":5,"count":1}]	13548	pick-up	0	8
34219	2020-02-26 01:53:20	2020-02-26	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	13605	delivery	5	48
34220	2020-02-26 01:57:38	2020-02-26	14	[{"id_menu":2,"count":1}]	9193	delivery	5	19
34221	2020-02-26 02:14:27	2020-02-26	14	[{"id_menu":2,"count":1}]	7118	delivery	5	19
34222	2020-02-26 02:29:41	2020-02-26	9	[{"id_menu":6,"count":1}]	8726	delivery	5	14
34223	2020-02-26 02:39:30	2020-02-26	9	[{"id_menu":7,"count":1}]	11038	delivery	5	14
34224	2020-02-26 02:39:48	2020-02-26	8	[{"id_menu":5,"count":1}]	13619	delivery	5	13
34225	2020-02-26 02:42:51	2020-02-26	8	[{"id_menu":5,"count":1}]	2252	pick-up	0	8
34226	2020-02-26 02:49:06	2020-02-26	9	[{"id_menu":7,"count":1}]	10626	pick-up	0	9
34227	2020-02-26 02:50:35	2020-02-26	9	[{"id_menu":7,"count":1}]	13228	delivery	5	14
34228	2020-02-26 03:06:57	2020-02-26	12	[{"id_menu":3,"count":1}]	399	pick-up	0	12
34229	2020-02-26 03:11:35	2020-02-26	12	[{"id_menu":3,"count":1}]	3755	pick-up	0	12
34230	2020-02-26 03:13:23	2020-02-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2116	pick-up	0	23
34231	2020-02-26 03:17:58	2020-02-26	9	[{"id_menu":6,"count":1}]	13623	delivery	5	14
34232	2020-02-26 03:18:40	2020-02-26	14	[{"id_menu":2,"count":1}]	13565	delivery	5	19
34233	2020-02-26 03:20:45	2020-02-26	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	13570	delivery	5	34
34234	2020-02-26 03:35:48	2020-02-26	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	4166	pick-up	0	26
34235	2020-02-26 03:38:42	2020-02-26	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	13625	delivery	5	34
34236	2020-02-26 03:39:50	2020-02-26	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	12011	pick-up	0	35
34237	2020-02-26 03:46:03	2020-02-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8502	delivery	5	22
34238	2020-02-26 03:46:41	2020-02-26	9	[{"id_menu":7,"count":1}]	3530	delivery	5	14
34239	2020-02-26 04:14:15	2020-02-26	9	[{"id_menu":6,"count":1}]	7341	pick-up	0	9
34240	2020-02-26 04:16:10	2020-02-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13568	delivery	5	31
34241	2020-02-26 04:28:12	2020-02-26	9	[{"id_menu":6,"count":2}]	12677	delivery	5	14
34242	2020-02-26 04:31:46	2020-02-26	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	13551	delivery	5	31
34243	2020-02-26 04:37:55	2020-02-26	8	[{"id_menu":5,"count":1}]	11672	delivery	5	13
34244	2020-02-26 04:41:23	2020-02-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13610	delivery	5	31
34245	2020-02-26 05:03:46	2020-02-26	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13536	delivery	5	34
34246	2020-02-26 05:24:20	2020-02-26	8	[{"id_menu":5,"count":1}]	13559	delivery	5	13
34247	2020-02-26 05:26:49	2020-02-26	9	[{"id_menu":7,"count":1}]	6826	delivery	5	14
34248	2020-02-26 05:45:05	2020-02-26	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	13592	delivery	5	26
34249	2020-02-26 05:49:29	2020-02-26	12	[{"id_menu":3,"count":1}]	13600	delivery	5	17
34250	2020-02-26 05:50:26	2020-02-26	12	[{"id_menu":1,"count":1}]	7806	pick-up	0	12
34251	2020-02-26 05:58:17	2020-02-26	12	[{"id_menu":1,"count":1}]	5063	pick-up	0	12
34252	2020-02-26 06:04:46	2020-02-26	9	[{"id_menu":6,"count":1}]	12685	delivery	5	14
34253	2020-02-26 06:06:44	2020-02-26	9	[{"id_menu":6,"count":1}]	11048	delivery	5	14
34254	2020-02-26 06:07:47	2020-02-26	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7049	delivery	5	57
34255	2020-02-26 06:09:01	2020-02-26	9	[{"id_menu":7,"count":1}]	12159	delivery	5	14
34256	2020-02-26 06:22:40	2020-02-26	8	[{"id_menu":5,"count":1}]	9511	delivery	5	13
34257	2020-02-26 06:24:13	2020-02-26	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6133	delivery	5	46
34258	2020-02-26 06:26:05	2020-02-26	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	1978	pick-up	0	26
34259	2020-02-26 06:32:35	2020-02-26	17	[{"id_menu":4,"count":1}]	8126	delivery	5	22
34260	2020-02-26 06:36:27	2020-02-26	9	[{"id_menu":6,"count":1}]	13533	delivery	5	14
34261	2020-02-26 06:40:09	2020-02-26	12	[{"id_menu":1,"count":1}]	13560	delivery	5	17
34262	2020-02-26 06:49:47	2020-02-26	8	[{"id_menu":5,"count":1}]	9682	pick-up	0	8
34263	2020-02-26 06:57:43	2020-02-26	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	3129	delivery	5	36
34264	2020-02-26 06:58:52	2020-02-26	9	[{"id_menu":7,"count":1}]	3629	delivery	5	14
34265	2020-02-26 07:04:14	2020-02-26	8	[{"id_menu":5,"count":1}]	8109	pick-up	0	8
34266	2020-02-26 07:05:23	2020-02-26	12	[{"id_menu":3,"count":1}]	34	pick-up	0	12
34267	2020-02-26 07:10:30	2020-02-26	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1365	pick-up	0	26
34268	2020-02-26 07:15:28	2020-02-26	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	6136	delivery	5	31
34269	2020-02-26 07:15:35	2020-02-26	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12602	pick-up	0	38
34270	2020-02-26 07:22:33	2020-02-26	8	[{"id_menu":5,"count":1}]	13555	pick-up	0	8
34271	2020-02-26 07:28:10	2020-02-26	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9058	delivery	5	51
34272	2020-02-26 07:33:56	2020-02-26	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	13576	delivery	5	25
34273	2020-02-26 07:41:55	2020-02-26	9	[{"id_menu":7,"count":1}]	5768	delivery	5	14
34274	2020-02-26 07:44:39	2020-02-26	8	[{"id_menu":5,"count":2}]	7585	delivery	5	13
34275	2020-02-26 07:54:28	2020-02-26	12	[{"id_menu":1,"count":2}]	13572	delivery	5	17
34276	2020-02-26 08:06:03	2020-02-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	13542	pick-up	0	21
34277	2020-02-26 08:06:54	2020-02-26	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10653	delivery	5	43
34278	2020-02-26 08:11:10	2020-02-26	17	[{"id_menu":4,"count":1}]	240	delivery	5	22
34279	2020-02-26 08:28:14	2020-02-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	3883	delivery	5	23
34280	2020-02-26 08:44:03	2020-02-26	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	13544	delivery	5	39
34281	2020-02-26 08:49:25	2020-02-26	9	[{"id_menu":6,"count":1}]	9156	delivery	5	14
34282	2020-02-26 08:54:43	2020-02-26	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	4403	delivery	5	31
34283	2020-02-26 08:56:04	2020-02-26	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":2}]	13582	delivery	5	28
34284	2020-02-26 09:01:16	2020-02-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1867	pick-up	0	26
34285	2020-02-26 09:05:09	2020-02-26	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7342	delivery	5	30
34286	2020-02-26 09:06:34	2020-02-26	17	[{"id_menu":4,"count":1}]	13620	delivery	5	22
34287	2020-02-26 09:07:34	2020-02-26	9	[{"id_menu":7,"count":1}]	13552	delivery	5	14
34288	2020-02-26 09:10:12	2020-02-26	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13611	delivery	5	37
34289	2020-02-26 09:14:07	2020-02-26	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13612	delivery	5	34
34290	2020-02-26 09:18:51	2020-02-26	12	[{"id_menu":3,"count":1}]	13386	pick-up	0	12
34291	2020-02-26 09:19:41	2020-02-26	9	[{"id_menu":7,"count":4}]	3469	delivery	5	14
34292	2020-02-26 09:20:30	2020-02-26	9	[{"id_menu":7,"count":1}]	9077	delivery	5	14
34293	2020-02-26 09:20:55	2020-02-26	14	[{"id_menu":2,"count":1}]	6202	pick-up	0	14
34294	2020-02-26 09:31:46	2020-02-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1408	delivery	5	26
34295	2020-02-26 09:34:47	2020-02-26	14	[{"id_menu":2,"count":1}]	2939	delivery	5	19
34296	2020-02-26 09:44:54	2020-02-26	9	[{"id_menu":7,"count":2}]	13571	delivery	5	14
34297	2020-02-26 09:45:15	2020-02-26	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	13561	delivery	5	25
34298	2020-02-26 09:47:44	2020-02-26	14	[{"id_menu":2,"count":1}]	13607	delivery	5	19
34299	2020-02-26 09:51:30	2020-02-26	12	[{"id_menu":1,"count":1}]	743	pick-up	0	12
34300	2020-02-26 09:55:24	2020-02-26	9	[{"id_menu":6,"count":1}]	10983	pick-up	0	9
34301	2020-02-26 09:56:04	2020-02-26	14	[{"id_menu":2,"count":1}]	1353	pick-up	0	14
34302	2020-02-26 09:57:22	2020-02-26	9	[{"id_menu":7,"count":1}]	13585	delivery	5	14
34303	2020-02-26 09:57:40	2020-02-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13595	pick-up	0	18
34304	2020-02-26 10:07:23	2020-02-26	9	[{"id_menu":6,"count":2}]	7588	delivery	5	14
34305	2020-02-26 10:34:31	2020-02-26	8	[{"id_menu":5,"count":1}]	12053	pick-up	0	8
34306	2020-02-26 10:38:19	2020-02-26	12	[{"id_menu":3,"count":1}]	13603	delivery	5	17
34307	2020-02-26 10:38:59	2020-02-26	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	3238	delivery	5	25
34308	2020-02-26 10:39:26	2020-02-26	9	[{"id_menu":7,"count":1}]	8355	delivery	5	14
34309	2020-02-26 10:39:34	2020-02-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1760	pick-up	0	21
34310	2020-02-26 10:40:33	2020-02-26	9	[{"id_menu":6,"count":1}]	13593	pick-up	0	9
34311	2020-02-26 10:44:37	2020-02-26	14	[{"id_menu":2,"count":1}]	6372	pick-up	0	14
34312	2020-02-26 10:45:32	2020-02-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	13567	delivery	5	26
34313	2020-02-26 10:46:06	2020-02-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13624	delivery	5	22
34314	2020-02-26 10:46:28	2020-02-26	9	[{"id_menu":7,"count":1}]	13596	delivery	5	14
34315	2020-02-26 10:50:01	2020-02-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	10232	delivery	5	26
34316	2020-02-26 10:53:12	2020-02-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	86	pick-up	0	23
34317	2020-02-26 10:53:38	2020-02-26	12	[{"id_menu":3,"count":1}]	9043	delivery	5	17
34318	2020-02-26 11:11:03	2020-02-26	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	1826	pick-up	0	40
34319	2020-02-26 11:35:45	2020-02-26	8	[{"id_menu":5,"count":1}]	1905	pick-up	0	8
34320	2020-02-26 11:46:46	2020-02-26	17	[{"id_menu":4,"count":1}]	13543	delivery	5	22
34321	2020-02-26 11:48:55	2020-02-26	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7208	delivery	5	31
34322	2020-02-26 11:49:42	2020-02-26	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2450	pick-up	0	21
34323	2020-02-26 11:52:00	2020-02-26	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	13608	delivery	5	29
34324	2020-02-26 12:02:48	2020-02-26	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	13614	delivery	5	37
34325	2020-02-26 12:03:36	2020-02-26	14	[{"id_menu":2,"count":1}]	2827	pick-up	0	14
34326	2020-02-26 12:09:12	2020-02-26	12	[{"id_menu":1,"count":1}]	13532	delivery	5	17
34327	2020-02-26 12:11:13	2020-02-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	13579	delivery	5	26
34328	2020-02-26 12:13:59	2020-02-26	8	[{"id_menu":5,"count":1}]	13528	pick-up	0	8
34329	2020-02-26 12:14:14	2020-02-26	17	[{"id_menu":4,"count":1}]	13617	delivery	5	22
34330	2020-02-26 12:19:16	2020-02-26	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2907	delivery	5	31
34331	2020-02-26 12:19:25	2020-02-26	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13598	delivery	5	34
34332	2020-02-26 12:27:11	2020-02-26	14	[{"id_menu":2,"count":2}]	2821	delivery	5	19
34333	2020-02-26 12:31:24	2020-02-26	17	[{"id_menu":4,"count":1}]	4458	delivery	5	22
34334	2020-02-26 12:37:24	2020-02-26	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6521	delivery	5	31
34335	2020-02-26 12:47:09	2020-02-26	12	[{"id_menu":1,"count":2}]	2352	delivery	5	17
34336	2020-02-26 12:57:51	2020-02-26	9	[{"id_menu":6,"count":1}]	8397	delivery	5	14
34337	2020-02-26 13:01:06	2020-02-26	9	[{"id_menu":6,"count":1}]	9118	delivery	5	14
34338	2020-02-26 13:04:01	2020-02-26	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	12951	delivery	5	29
34339	2020-02-26 13:04:13	2020-02-26	43	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	13537	delivery	5	48
34340	2020-02-26 13:13:59	2020-02-26	9	[{"id_menu":7,"count":1}]	13597	delivery	5	14
34341	2020-02-26 13:21:52	2020-02-26	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	13538	delivery	5	31
34342	2020-02-26 13:25:31	2020-02-26	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	13580	delivery	5	26
34343	2020-02-26 13:29:31	2020-02-26	9	[{"id_menu":6,"count":1}]	4685	delivery	5	14
34344	2020-02-26 13:32:08	2020-02-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10676	delivery	5	23
34345	2020-02-26 13:33:15	2020-02-26	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	4595	delivery	5	34
34346	2020-02-26 13:34:08	2020-02-26	9	[{"id_menu":7,"count":1}]	13539	delivery	5	14
34347	2020-02-26 13:34:46	2020-02-26	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	13558	delivery	5	25
34348	2020-02-26 13:45:25	2020-02-26	14	[{"id_menu":2,"count":1}]	13575	delivery	5	19
34349	2020-02-26 13:53:23	2020-02-26	12	[{"id_menu":1,"count":1}]	3116	delivery	5	17
34350	2020-02-26 13:55:10	2020-02-26	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13546	delivery	5	43
34351	2020-02-26 14:03:21	2020-02-26	9	[{"id_menu":6,"count":2}]	6005	delivery	5	14
34352	2020-02-26 14:19:54	2020-02-26	12	[{"id_menu":1,"count":1}]	8873	delivery	5	17
34353	2020-02-26 14:38:11	2020-02-26	12	[{"id_menu":3,"count":1}]	3752	pick-up	0	12
34354	2020-02-26 14:49:41	2020-02-26	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2333	delivery	5	36
34355	2020-02-26 14:52:24	2020-02-26	9	[{"id_menu":6,"count":1}]	7591	pick-up	0	9
34356	2020-02-26 15:01:02	2020-02-26	9	[{"id_menu":7,"count":1}]	788	pick-up	0	9
34357	2020-02-26 15:04:40	2020-02-26	12	[{"id_menu":1,"count":1}]	12673	delivery	5	17
34358	2020-02-26 15:05:40	2020-02-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	12903	delivery	5	26
34359	2020-02-26 15:18:20	2020-02-26	9	[{"id_menu":7,"count":1}]	10980	delivery	5	14
34360	2020-02-26 15:39:25	2020-02-26	12	[{"id_menu":1,"count":1}]	7383	pick-up	0	12
34361	2020-02-26 15:43:42	2020-02-26	17	[{"id_menu":4,"count":1}]	2738	delivery	5	22
34362	2020-02-26 15:49:00	2020-02-26	9	[{"id_menu":6,"count":1}]	5640	delivery	5	14
34363	2020-02-26 15:49:32	2020-02-26	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	13594	delivery	5	31
34364	2020-02-26 15:50:36	2020-02-26	9	[{"id_menu":6,"count":1}]	2188	delivery	5	14
34365	2020-02-26 15:58:17	2020-02-26	8	[{"id_menu":5,"count":1}]	13569	delivery	5	13
34366	2020-02-26 15:58:35	2020-02-26	12	[{"id_menu":3,"count":1}]	295	delivery	5	17
34367	2020-02-26 16:00:46	2020-02-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	684	pick-up	0	23
34368	2020-02-26 16:06:30	2020-02-26	9	[{"id_menu":6,"count":1}]	13563	delivery	5	14
34369	2020-02-26 16:10:11	2020-02-26	14	[{"id_menu":2,"count":1}]	4109	pick-up	0	14
34370	2020-02-26 16:13:25	2020-02-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4495	delivery	5	28
34371	2020-02-26 16:16:53	2020-02-26	14	[{"id_menu":2,"count":1}]	7122	delivery	5	19
34372	2020-02-26 16:37:35	2020-02-26	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	8081	delivery	5	25
34373	2020-02-26 16:41:38	2020-02-26	12	[{"id_menu":3,"count":1}]	12871	pick-up	0	12
34374	2020-02-26 16:42:14	2020-02-26	12	[{"id_menu":3,"count":1}]	13626	delivery	5	17
34375	2020-02-26 16:42:27	2020-02-26	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8642	delivery	5	43
34376	2020-02-26 16:43:32	2020-02-26	12	[{"id_menu":1,"count":1}]	7650	delivery	5	17
34377	2020-02-26 16:44:16	2020-02-26	8	[{"id_menu":5,"count":1}]	4090	pick-up	0	8
34378	2020-02-26 16:47:10	2020-02-26	8	[{"id_menu":5,"count":1}]	11028	pick-up	0	8
34379	2020-02-26 16:51:34	2020-02-26	12	[{"id_menu":1,"count":1}]	13584	delivery	5	17
34380	2020-02-26 16:57:16	2020-02-26	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4544	delivery	5	48
34381	2020-02-26 16:58:50	2020-02-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	1229	delivery	5	22
34382	2020-02-26 17:01:26	2020-02-26	8	[{"id_menu":5,"count":1}]	2891	pick-up	0	8
34383	2020-02-26 17:03:16	2020-02-26	8	[{"id_menu":5,"count":1}]	9358	pick-up	0	8
34384	2020-02-26 17:19:12	2020-02-26	12	[{"id_menu":3,"count":1}]	10630	delivery	5	17
34385	2020-02-26 17:20:09	2020-02-26	17	[{"id_menu":4,"count":1}]	11040	pick-up	0	17
34386	2020-02-26 17:22:00	2020-02-26	17	[{"id_menu":4,"count":1}]	9161	delivery	5	22
34387	2020-02-26 17:28:01	2020-02-26	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6827	delivery	5	45
34388	2020-02-26 17:33:21	2020-02-26	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	13578	delivery	5	26
34389	2020-02-26 17:33:29	2020-02-26	17	[{"id_menu":4,"count":1}]	9040	pick-up	0	17
34390	2020-02-26 17:35:43	2020-02-26	8	[{"id_menu":5,"count":1}]	1552	pick-up	0	8
34391	2020-02-26 17:55:52	2020-02-26	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	13606	delivery	5	31
34392	2020-02-26 17:59:03	2020-02-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2231	pick-up	0	18
34393	2020-02-26 18:38:05	2020-02-26	17	[{"id_menu":4,"count":1}]	4943	delivery	5	22
34394	2020-02-26 18:39:34	2020-02-26	14	[{"id_menu":2,"count":1}]	13566	delivery	5	19
34395	2020-02-26 18:41:47	2020-02-26	12	[{"id_menu":1,"count":1}]	4287	delivery	5	17
34396	2020-02-26 18:42:30	2020-02-26	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	13622	delivery	5	23
34397	2020-02-26 18:45:04	2020-02-26	17	[{"id_menu":4,"count":1}]	13550	delivery	5	22
34398	2020-02-26 18:53:38	2020-02-26	14	[{"id_menu":2,"count":1}]	8457	delivery	5	19
34399	2020-02-26 19:09:58	2020-02-26	17	[{"id_menu":4,"count":1}]	4363	pick-up	0	17
34400	2020-02-26 19:15:02	2020-02-26	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13556	delivery	5	43
34401	2020-02-26 19:27:09	2020-02-26	12	[{"id_menu":1,"count":1}]	13621	delivery	5	17
34402	2020-02-26 19:31:18	2020-02-26	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	13534	delivery	5	39
34403	2020-02-26 19:33:11	2020-02-26	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2980	pick-up	0	26
34404	2020-02-26 19:34:57	2020-02-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13549	delivery	5	31
34405	2020-02-26 19:39:27	2020-02-26	8	[{"id_menu":5,"count":1}]	12906	delivery	5	13
34406	2020-02-26 19:41:05	2020-02-26	14	[{"id_menu":2,"count":1}]	5643	pick-up	0	14
34407	2020-02-26 19:41:41	2020-02-26	9	[{"id_menu":6,"count":1}]	1390	pick-up	0	9
34408	2020-02-26 19:49:33	2020-02-26	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3323	delivery	5	31
34409	2020-02-26 20:15:12	2020-02-26	9	[{"id_menu":7,"count":1}]	11405	delivery	5	14
34410	2020-02-26 20:20:05	2020-02-26	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1344	pick-up	0	20
34411	2020-02-26 20:23:34	2020-02-26	17	[{"id_menu":4,"count":1}]	9165	delivery	5	22
34412	2020-02-26 20:40:26	2020-02-26	14	[{"id_menu":2,"count":1}]	5082	pick-up	0	14
34413	2020-02-26 20:50:50	2020-02-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7709	delivery	5	22
34414	2020-02-26 20:53:26	2020-02-26	9	[{"id_menu":6,"count":1}]	13541	pick-up	0	9
34415	2020-02-26 21:02:02	2020-02-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9798	delivery	5	22
34416	2020-02-26 21:04:20	2020-02-26	14	[{"id_menu":2,"count":1}]	8590	delivery	5	19
34417	2020-02-26 21:11:35	2020-02-26	17	[{"id_menu":4,"count":1}]	13529	pick-up	0	17
34418	2020-02-26 21:15:02	2020-02-26	17	[{"id_menu":4,"count":1}]	552	pick-up	0	17
34419	2020-02-26 21:18:12	2020-02-26	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12981	delivery	5	31
34420	2020-02-26 21:21:04	2020-02-26	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10739	delivery	5	43
34421	2020-02-26 21:21:26	2020-02-26	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	13531	delivery	5	31
34422	2020-02-26 21:35:36	2020-02-26	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	5293	pick-up	0	29
34423	2020-02-26 21:39:16	2020-02-26	17	[{"id_menu":4,"count":1}]	11089	pick-up	0	17
34424	2020-02-26 21:47:00	2020-02-26	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	13553	delivery	5	37
34425	2020-02-26 21:48:17	2020-02-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12486	pick-up	0	17
34426	2020-02-26 21:51:20	2020-02-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13535	delivery	5	23
34427	2020-02-26 22:02:50	2020-02-26	9	[{"id_menu":7,"count":1}]	13574	delivery	5	14
34428	2020-02-26 22:03:21	2020-02-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13530	delivery	5	23
34429	2020-02-26 22:07:31	2020-02-26	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	12657	pick-up	0	25
34430	2020-02-26 22:08:00	2020-02-26	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	3177	pick-up	0	21
34431	2020-02-26 22:08:09	2020-02-26	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	341	pick-up	0	34
34432	2020-02-26 22:12:27	2020-02-26	9	[{"id_menu":7,"count":1}]	11156	pick-up	0	9
34433	2020-02-26 22:12:48	2020-02-26	33	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3833	delivery	5	38
34434	2020-02-26 22:16:37	2020-02-26	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	9337	pick-up	0	31
34435	2020-02-26 22:21:02	2020-02-26	9	[{"id_menu":6,"count":1}]	11143	delivery	5	14
34436	2020-02-26 22:22:00	2020-02-26	14	[{"id_menu":2,"count":1}]	13577	delivery	5	19
34437	2020-02-26 22:48:58	2020-02-26	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	11978	delivery	5	48
34438	2020-02-26 22:50:45	2020-02-26	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12307	pick-up	0	31
34439	2020-02-26 22:52:21	2020-02-26	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	949	delivery	5	34
34440	2020-02-26 23:00:10	2020-02-26	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	12764	delivery	5	26
34441	2020-02-26 23:09:27	2020-02-26	17	[{"id_menu":4,"count":1}]	2863	pick-up	0	17
34442	2020-02-26 23:16:45	2020-02-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	4646	delivery	5	22
34443	2020-02-26 23:26:10	2020-02-26	14	[{"id_menu":2,"count":1}]	13587	pick-up	0	14
34444	2020-02-26 23:32:19	2020-02-26	17	[{"id_menu":4,"count":1}]	13325	delivery	5	22
34445	2020-02-26 23:44:40	2020-02-26	9	[{"id_menu":6,"count":1}]	6727	delivery	5	14
34446	2020-02-26 23:47:35	2020-02-26	9	[{"id_menu":7,"count":1}]	1536	pick-up	0	9
34447	2020-02-26 23:51:47	2020-02-26	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	13615	delivery	5	31
34448	2020-02-27 00:03:08	2020-02-27	17	[{"id_menu":4,"count":1}]	13643	delivery	5	22
34449	2020-02-27 00:07:31	2020-02-27	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	820	pick-up	0	26
34450	2020-02-27 00:08:26	2020-02-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7709	delivery	5	23
34451	2020-02-27 00:11:32	2020-02-27	17	[{"id_menu":4,"count":1}]	13727	delivery	5	22
34452	2020-02-27 00:20:15	2020-02-27	14	[{"id_menu":2,"count":1}]	10517	delivery	5	19
34453	2020-02-27 00:25:40	2020-02-27	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	7888	delivery	5	25
34454	2020-02-27 00:28:46	2020-02-27	9	[{"id_menu":7,"count":1}]	11173	delivery	5	14
34455	2020-02-27 00:31:44	2020-02-27	9	[{"id_menu":6,"count":1}]	3604	delivery	5	14
34456	2020-02-27 00:32:46	2020-02-27	17	[{"id_menu":4,"count":1}]	207	pick-up	0	17
34457	2020-02-27 00:42:02	2020-02-27	12	[{"id_menu":1,"count":1}]	13632	delivery	5	17
34458	2020-02-27 00:45:28	2020-02-27	9	[{"id_menu":7,"count":1}]	1638	delivery	5	14
34459	2020-02-27 00:46:50	2020-02-27	9	[{"id_menu":7,"count":1}]	13735	delivery	5	14
34460	2020-02-27 00:52:10	2020-02-27	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	9506	delivery	5	45
34461	2020-02-27 00:54:17	2020-02-27	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13709	delivery	5	34
34462	2020-02-27 00:54:42	2020-02-27	17	[{"id_menu":4,"count":1}]	5411	delivery	5	22
34463	2020-02-27 00:56:44	2020-02-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	13658	pick-up	0	31
34464	2020-02-27 01:03:45	2020-02-27	14	[{"id_menu":2,"count":1}]	13718	delivery	5	19
34465	2020-02-27 01:05:18	2020-02-27	8	[{"id_menu":5,"count":1}]	5707	delivery	5	13
34466	2020-02-27 01:06:49	2020-02-27	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	439	pick-up	0	25
34467	2020-02-27 01:07:36	2020-02-27	8	[{"id_menu":5,"count":2}]	13677	pick-up	0	8
34468	2020-02-27 01:14:52	2020-02-27	9	[{"id_menu":6,"count":1}]	13669	pick-up	0	9
34469	2020-02-27 01:17:50	2020-02-27	9	[{"id_menu":7,"count":1}]	8747	pick-up	0	9
34470	2020-02-27 01:20:31	2020-02-27	14	[{"id_menu":2,"count":1}]	4577	pick-up	0	14
34471	2020-02-27 01:25:30	2020-02-27	30	[{"id_menu":3,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13708	delivery	5	35
34472	2020-02-27 01:33:49	2020-02-27	8	[{"id_menu":5,"count":1}]	13654	delivery	5	13
34473	2020-02-27 01:34:55	2020-02-27	14	[{"id_menu":2,"count":1}]	6843	pick-up	0	14
34474	2020-02-27 01:44:50	2020-02-27	9	[{"id_menu":7,"count":1}]	7045	delivery	5	14
34475	2020-02-27 01:53:43	2020-02-27	17	[{"id_menu":4,"count":1}]	11237	delivery	5	22
34476	2020-02-27 01:59:31	2020-02-27	9	[{"id_menu":7,"count":1}]	449	delivery	5	14
34477	2020-02-27 02:04:13	2020-02-27	8	[{"id_menu":5,"count":1}]	8963	delivery	5	13
34478	2020-02-27 02:09:30	2020-02-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	13579	delivery	5	36
34479	2020-02-27 02:12:57	2020-02-27	17	[{"id_menu":4,"count":1}]	7710	delivery	5	22
34480	2020-02-27 02:13:24	2020-02-27	9	[{"id_menu":7,"count":1}]	13678	delivery	5	14
34481	2020-02-27 02:14:37	2020-02-27	17	[{"id_menu":4,"count":1}]	13264	delivery	5	22
34482	2020-02-27 02:20:55	2020-02-27	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1483	delivery	5	36
34483	2020-02-27 02:25:52	2020-02-27	17	[{"id_menu":4,"count":1}]	4974	delivery	5	22
34484	2020-02-27 02:39:20	2020-02-27	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	4034	pick-up	0	31
34485	2020-02-27 02:40:14	2020-02-27	17	[{"id_menu":4,"count":1}]	13663	delivery	5	22
34486	2020-02-27 02:42:19	2020-02-27	17	[{"id_menu":4,"count":1}]	916	pick-up	0	17
34487	2020-02-27 02:42:39	2020-02-27	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	7573	delivery	5	40
34488	2020-02-27 02:57:19	2020-02-27	12	[{"id_menu":1,"count":1}]	13657	delivery	5	17
34489	2020-02-27 03:05:26	2020-02-27	12	[{"id_menu":3,"count":1}]	13734	delivery	5	17
34490	2020-02-27 03:05:28	2020-02-27	17	[{"id_menu":4,"count":1}]	6288	delivery	5	22
34491	2020-02-27 03:18:03	2020-02-27	12	[{"id_menu":3,"count":1}]	13370	delivery	5	17
34492	2020-02-27 03:20:34	2020-02-27	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2641	pick-up	0	31
34493	2020-02-27 03:29:19	2020-02-27	14	[{"id_menu":2,"count":1}]	13679	delivery	5	19
34494	2020-02-27 03:37:45	2020-02-27	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1554	delivery	5	34
34495	2020-02-27 03:44:37	2020-02-27	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	13731	pick-up	0	35
34496	2020-02-27 03:50:56	2020-02-27	14	[{"id_menu":2,"count":1}]	2041	pick-up	0	14
34497	2020-02-27 04:03:14	2020-02-27	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	13665	delivery	5	42
34498	2020-02-27 04:06:01	2020-02-27	9	[{"id_menu":7,"count":1}]	9607	delivery	5	14
34499	2020-02-27 04:07:15	2020-02-27	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13701	delivery	5	31
34500	2020-02-27 04:28:20	2020-02-27	9	[{"id_menu":7,"count":1}]	5995	pick-up	0	9
34501	2020-02-27 04:34:14	2020-02-27	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4870	pick-up	0	40
34502	2020-02-27 04:40:22	2020-02-27	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8521	pick-up	0	17
34503	2020-02-27 04:48:24	2020-02-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	5570	delivery	5	22
34504	2020-02-27 04:53:27	2020-02-27	17	[{"id_menu":4,"count":1}]	13648	pick-up	0	17
34505	2020-02-27 04:58:22	2020-02-27	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7979	delivery	5	40
34506	2020-02-27 05:01:44	2020-02-27	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	13702	delivery	5	37
34507	2020-02-27 05:06:40	2020-02-27	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	8916	pick-up	0	26
34508	2020-02-27 05:14:25	2020-02-27	12	[{"id_menu":1,"count":1}]	29	delivery	5	17
34509	2020-02-27 05:17:19	2020-02-27	14	[{"id_menu":2,"count":1}]	13650	delivery	5	19
34510	2020-02-27 05:17:27	2020-02-27	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1344	pick-up	0	26
34511	2020-02-27 05:18:33	2020-02-27	17	[{"id_menu":4,"count":1}]	36	delivery	5	22
34512	2020-02-27 05:22:09	2020-02-27	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	13717	delivery	5	40
34513	2020-02-27 05:28:10	2020-02-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	13666	delivery	5	36
34514	2020-02-27 05:28:27	2020-02-27	9	[{"id_menu":6,"count":1}]	9007	delivery	5	14
34515	2020-02-27 05:34:07	2020-02-27	8	[{"id_menu":5,"count":1}]	2008	delivery	5	13
34516	2020-02-27 05:40:36	2020-02-27	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13646	delivery	5	48
34517	2020-02-27 05:46:30	2020-02-27	8	[{"id_menu":5,"count":1}]	8298	pick-up	0	8
34518	2020-02-27 05:59:24	2020-02-27	14	[{"id_menu":2,"count":1}]	9941	delivery	5	19
34519	2020-02-27 06:00:35	2020-02-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3054	delivery	5	36
34520	2020-02-27 06:03:38	2020-02-27	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	13649	delivery	5	35
34521	2020-02-27 06:07:55	2020-02-27	8	[{"id_menu":5,"count":1}]	13667	delivery	5	13
34522	2020-02-27 06:12:21	2020-02-27	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13068	delivery	5	22
34523	2020-02-27 06:15:38	2020-02-27	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	13713	delivery	5	43
34524	2020-02-27 06:23:57	2020-02-27	9	[{"id_menu":6,"count":1}]	10680	delivery	5	14
34525	2020-02-27 06:24:53	2020-02-27	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11779	pick-up	0	30
34526	2020-02-27 06:25:56	2020-02-27	14	[{"id_menu":2,"count":1}]	376	pick-up	0	14
34527	2020-02-27 06:28:29	2020-02-27	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4736	delivery	5	35
34528	2020-02-27 06:41:02	2020-02-27	9	[{"id_menu":6,"count":1}]	13682	delivery	5	14
34529	2020-02-27 06:42:52	2020-02-27	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6773	delivery	5	45
34530	2020-02-27 06:43:35	2020-02-27	12	[{"id_menu":3,"count":1}]	113	delivery	5	17
34531	2020-02-27 06:46:33	2020-02-27	9	[{"id_menu":7,"count":1}]	13732	pick-up	0	9
34532	2020-02-27 06:59:09	2020-02-27	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	13335	pick-up	0	35
34533	2020-02-27 07:01:42	2020-02-27	17	[{"id_menu":4,"count":1}]	5232	pick-up	0	17
34534	2020-02-27 07:02:00	2020-02-27	14	[{"id_menu":2,"count":1}]	12506	delivery	5	19
34535	2020-02-27 07:03:06	2020-02-27	14	[{"id_menu":2,"count":1}]	6617	delivery	5	19
34536	2020-02-27 07:03:48	2020-02-27	17	[{"id_menu":4,"count":1}]	13645	delivery	5	22
34537	2020-02-27 07:06:04	2020-02-27	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	2016	pick-up	0	38
34538	2020-02-27 07:10:05	2020-02-27	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10712	delivery	5	52
34539	2020-02-27 07:14:50	2020-02-27	17	[{"id_menu":4,"count":1}]	13725	delivery	5	22
34540	2020-02-27 07:30:07	2020-02-27	12	[{"id_menu":3,"count":1}]	13728	delivery	5	17
34541	2020-02-27 07:30:23	2020-02-27	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	10008	pick-up	0	21
34542	2020-02-27 07:37:54	2020-02-27	14	[{"id_menu":2,"count":1}]	5430	delivery	5	19
34543	2020-02-27 07:41:31	2020-02-27	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	7404	pick-up	0	24
34544	2020-02-27 07:44:40	2020-02-27	12	[{"id_menu":1,"count":1}]	3459	pick-up	0	12
34545	2020-02-27 07:47:39	2020-02-27	14	[{"id_menu":2,"count":1}]	3293	delivery	5	19
34546	2020-02-27 07:53:20	2020-02-27	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	1821	pick-up	0	35
34547	2020-02-27 07:55:25	2020-02-27	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	13642	delivery	5	27
34548	2020-02-27 07:57:31	2020-02-27	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	13673	delivery	5	26
34549	2020-02-27 08:03:52	2020-02-27	12	[{"id_menu":1,"count":1}]	13641	pick-up	0	12
34550	2020-02-27 08:04:31	2020-02-27	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	8050	delivery	5	25
34551	2020-02-27 08:07:17	2020-02-27	9	[{"id_menu":7,"count":1}]	13664	delivery	5	14
34552	2020-02-27 08:10:12	2020-02-27	12	[{"id_menu":1,"count":1}]	7527	pick-up	0	12
34553	2020-02-27 08:13:21	2020-02-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1376	pick-up	0	17
34554	2020-02-27 08:17:12	2020-02-27	17	[{"id_menu":4,"count":1}]	13188	delivery	5	22
34555	2020-02-27 08:17:36	2020-02-27	17	[{"id_menu":4,"count":1}]	12655	pick-up	0	17
34556	2020-02-27 08:20:51	2020-02-27	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	4799	delivery	5	31
34557	2020-02-27 08:21:18	2020-02-27	12	[{"id_menu":1,"count":1}]	923	delivery	5	17
34558	2020-02-27 08:22:33	2020-02-27	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	10436	pick-up	0	21
34559	2020-02-27 08:28:32	2020-02-27	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	337	pick-up	0	39
34560	2020-02-27 08:31:34	2020-02-27	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1814	delivery	5	31
34561	2020-02-27 08:33:14	2020-02-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":3}]	13700	delivery	5	23
34562	2020-02-27 08:36:10	2020-02-27	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	7266	pick-up	0	29
34563	2020-02-27 08:39:58	2020-02-27	9	[{"id_menu":7,"count":1}]	4248	pick-up	0	9
34564	2020-02-27 08:40:46	2020-02-27	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	13693	delivery	5	48
34565	2020-02-27 08:47:51	2020-02-27	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	9894	delivery	5	31
34566	2020-02-27 08:53:29	2020-02-27	8	[{"id_menu":5,"count":1}]	13692	pick-up	0	8
34567	2020-02-27 08:57:31	2020-02-27	12	[{"id_menu":1,"count":1}]	13284	delivery	5	17
34568	2020-02-27 08:58:09	2020-02-27	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	11093	delivery	5	26
34569	2020-02-27 08:58:49	2020-02-27	12	[{"id_menu":1,"count":1}]	2504	pick-up	0	12
34570	2020-02-27 08:58:58	2020-02-27	9	[{"id_menu":7,"count":1}]	8166	delivery	5	14
34571	2020-02-27 09:01:06	2020-02-27	9	[{"id_menu":6,"count":1}]	11200	delivery	5	14
34572	2020-02-27 09:06:33	2020-02-27	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1353	pick-up	0	29
34573	2020-02-27 09:07:31	2020-02-27	14	[{"id_menu":2,"count":1}]	8866	delivery	5	19
34574	2020-02-27 09:11:36	2020-02-27	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	13672	delivery	5	26
34575	2020-02-27 09:13:39	2020-02-27	9	[{"id_menu":7,"count":1}]	13644	delivery	5	14
34576	2020-02-27 09:17:00	2020-02-27	9	[{"id_menu":6,"count":1}]	13703	delivery	5	14
34577	2020-02-27 09:18:54	2020-02-27	14	[{"id_menu":2,"count":1}]	13639	delivery	5	19
34578	2020-02-27 09:20:22	2020-02-27	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3129	delivery	5	34
34579	2020-02-27 09:23:49	2020-02-27	8	[{"id_menu":5,"count":1}]	13723	delivery	5	13
34580	2020-02-27 09:36:34	2020-02-27	12	[{"id_menu":1,"count":1}]	13655	delivery	5	17
34581	2020-02-27 09:36:51	2020-02-27	9	[{"id_menu":7,"count":1}]	523	delivery	5	14
34582	2020-02-27 09:39:34	2020-02-27	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	13652	delivery	5	26
34583	2020-02-27 09:44:21	2020-02-27	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	13697	delivery	5	31
34584	2020-02-27 09:44:59	2020-02-27	9	[{"id_menu":6,"count":1}]	13714	delivery	5	14
34585	2020-02-27 09:45:37	2020-02-27	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	3498	pick-up	0	25
34586	2020-02-27 09:49:39	2020-02-27	9	[{"id_menu":7,"count":1}]	11123	delivery	5	14
34587	2020-02-27 09:52:44	2020-02-27	9	[{"id_menu":7,"count":1}]	10073	pick-up	0	9
34588	2020-02-27 10:04:21	2020-02-27	14	[{"id_menu":2,"count":1}]	5070	pick-up	0	14
34589	2020-02-27 10:08:19	2020-02-27	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13634	delivery	5	34
34590	2020-02-27 10:29:04	2020-02-27	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6805	delivery	5	42
34591	2020-02-27 10:38:36	2020-02-27	17	[{"id_menu":4,"count":1}]	1435	delivery	5	22
34592	2020-02-27 10:39:58	2020-02-27	17	[{"id_menu":4,"count":1}]	6190	delivery	5	22
34593	2020-02-27 10:43:11	2020-02-27	12	[{"id_menu":1,"count":1}]	3094	pick-up	0	12
34594	2020-02-27 10:45:02	2020-02-27	9	[{"id_menu":7,"count":1}]	193	pick-up	0	9
34595	2020-02-27 10:46:30	2020-02-27	12	[{"id_menu":1,"count":1}]	1157	delivery	5	17
34596	2020-02-27 10:47:09	2020-02-27	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13689	delivery	5	46
34597	2020-02-27 10:48:27	2020-02-27	12	[{"id_menu":3,"count":1}]	11729	delivery	5	17
34598	2020-02-27 10:59:36	2020-02-27	9	[{"id_menu":7,"count":1}]	9875	pick-up	0	9
34599	2020-02-27 10:59:42	2020-02-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13716	delivery	5	22
34600	2020-02-27 11:00:51	2020-02-27	9	[{"id_menu":7,"count":1}]	11046	delivery	5	14
34601	2020-02-27 11:19:28	2020-02-27	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	552	delivery	5	49
34602	2020-02-27 11:21:50	2020-02-27	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12393	pick-up	0	31
34603	2020-02-27 11:22:30	2020-02-27	34	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	8538	delivery	5	39
34604	2020-02-27 11:32:06	2020-02-27	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13670	delivery	5	51
34605	2020-02-27 11:34:20	2020-02-27	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	9885	delivery	5	26
34606	2020-02-27 11:36:26	2020-02-27	9	[{"id_menu":7,"count":1}]	13660	delivery	5	14
34607	2020-02-27 11:37:45	2020-02-27	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	5993	delivery	5	28
34608	2020-02-27 11:41:44	2020-02-27	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	3423	delivery	5	39
34609	2020-02-27 12:00:57	2020-02-27	14	[{"id_menu":2,"count":1}]	7856	delivery	5	19
34610	2020-02-27 12:05:33	2020-02-27	12	[{"id_menu":3,"count":1}]	377	pick-up	0	12
34611	2020-02-27 12:07:53	2020-02-27	14	[{"id_menu":2,"count":1}]	10742	delivery	5	19
34612	2020-02-27 12:14:55	2020-02-27	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	6928	delivery	5	40
34613	2020-02-27 12:18:56	2020-02-27	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	8756	delivery	5	48
34614	2020-02-27 12:20:01	2020-02-27	14	[{"id_menu":2,"count":1}]	10200	pick-up	0	14
34615	2020-02-27 12:23:35	2020-02-27	23	[{"id_menu":2,"count":3},{"id_menu":7,"count":1}]	10438	delivery	5	28
34616	2020-02-27 12:25:51	2020-02-27	9	[{"id_menu":6,"count":1}]	709	pick-up	0	9
34617	2020-02-27 12:36:00	2020-02-27	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3499	delivery	5	27
34618	2020-02-27 12:41:28	2020-02-27	9	[{"id_menu":7,"count":1}]	13659	delivery	5	14
34619	2020-02-27 12:52:04	2020-02-27	17	[{"id_menu":4,"count":1}]	6695	delivery	5	22
34620	2020-02-27 12:53:04	2020-02-27	14	[{"id_menu":2,"count":1}]	1531	pick-up	0	14
34621	2020-02-27 13:08:19	2020-02-27	17	[{"id_menu":4,"count":2}]	5833	delivery	5	22
34622	2020-02-27 13:22:25	2020-02-27	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	13662	delivery	5	28
34623	2020-02-27 13:24:28	2020-02-27	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13691	delivery	5	36
34624	2020-02-27 13:25:20	2020-02-27	9	[{"id_menu":6,"count":1}]	13684	delivery	5	14
34625	2020-02-27 13:28:41	2020-02-27	12	[{"id_menu":1,"count":1}]	247	pick-up	0	12
34626	2020-02-27 13:33:30	2020-02-27	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	13680	delivery	5	42
34627	2020-02-27 13:43:47	2020-02-27	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	9737	delivery	5	26
34628	2020-02-27 13:58:27	2020-02-27	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12489	delivery	5	31
34629	2020-02-27 14:04:44	2020-02-27	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	13637	delivery	5	22
34630	2020-02-27 14:07:52	2020-02-27	8	[{"id_menu":5,"count":1}]	12210	pick-up	0	8
34631	2020-02-27 14:10:20	2020-02-27	9	[{"id_menu":7,"count":1}]	4922	pick-up	0	9
34632	2020-02-27 14:11:16	2020-02-27	14	[{"id_menu":2,"count":1}]	4166	delivery	5	19
34633	2020-02-27 14:11:22	2020-02-27	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	13303	delivery	5	28
34634	2020-02-27 14:17:03	2020-02-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	9631	pick-up	0	31
34635	2020-02-27 14:17:09	2020-02-27	8	[{"id_menu":5,"count":1}]	13674	delivery	5	13
34636	2020-02-27 14:23:07	2020-02-27	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	8243	delivery	5	34
34637	2020-02-27 14:30:54	2020-02-27	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	11172	delivery	5	28
34638	2020-02-27 14:35:16	2020-02-27	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	13647	delivery	5	31
34639	2020-02-27 14:37:04	2020-02-27	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7019	pick-up	0	52
34640	2020-02-27 14:43:16	2020-02-27	8	[{"id_menu":5,"count":1}]	3069	pick-up	0	8
34641	2020-02-27 14:56:26	2020-02-27	9	[{"id_menu":6,"count":1}]	8668	pick-up	0	9
34642	2020-02-27 14:58:18	2020-02-27	14	[{"id_menu":2,"count":1}]	9741	delivery	5	19
34643	2020-02-27 15:00:57	2020-02-27	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1650	pick-up	0	30
34644	2020-02-27 15:06:39	2020-02-27	14	[{"id_menu":2,"count":1}]	9427	delivery	5	19
34645	2020-02-27 15:09:22	2020-02-27	9	[{"id_menu":7,"count":1}]	1850	pick-up	0	9
34646	2020-02-27 15:29:07	2020-02-27	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13722	delivery	5	31
34647	2020-02-27 15:31:11	2020-02-27	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	7253	delivery	5	43
34648	2020-02-27 15:35:12	2020-02-27	12	[{"id_menu":3,"count":1}]	1685	pick-up	0	12
34649	2020-02-27 15:42:36	2020-02-27	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1245	pick-up	0	21
34650	2020-02-27 15:43:42	2020-02-27	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2021	delivery	5	43
34651	2020-02-27 15:46:58	2020-02-27	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1556	pick-up	0	25
34652	2020-02-27 15:57:12	2020-02-27	9	[{"id_menu":7,"count":3}]	2049	delivery	5	14
34653	2020-02-27 16:13:59	2020-02-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	13685	delivery	5	28
34654	2020-02-27 16:17:29	2020-02-27	14	[{"id_menu":2,"count":1}]	7925	delivery	5	19
34655	2020-02-27 16:18:22	2020-02-27	14	[{"id_menu":2,"count":1}]	8655	pick-up	0	14
34656	2020-02-27 16:18:27	2020-02-27	8	[{"id_menu":5,"count":1}]	3278	delivery	5	13
34657	2020-02-27 16:20:07	2020-02-27	17	[{"id_menu":4,"count":1}]	13733	delivery	5	22
34658	2020-02-27 16:21:24	2020-02-27	14	[{"id_menu":2,"count":1}]	5916	delivery	5	19
34659	2020-02-27 16:26:44	2020-02-27	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	13720	delivery	5	23
34660	2020-02-27 16:42:16	2020-02-27	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	11102	delivery	5	28
34661	2020-02-27 16:42:22	2020-02-27	14	[{"id_menu":2,"count":1}]	13694	delivery	5	19
34662	2020-02-27 16:42:26	2020-02-27	14	[{"id_menu":2,"count":1}]	1849	pick-up	0	14
34663	2020-02-27 16:43:00	2020-02-27	12	[{"id_menu":3,"count":1}]	7338	delivery	5	17
34664	2020-02-27 16:46:47	2020-02-27	9	[{"id_menu":7,"count":1}]	13687	delivery	5	14
34665	2020-02-27 17:05:33	2020-02-27	12	[{"id_menu":1,"count":1}]	13675	pick-up	0	12
34666	2020-02-27 17:10:56	2020-02-27	9	[{"id_menu":7,"count":1}]	10281	delivery	5	14
34667	2020-02-27 17:16:29	2020-02-27	9	[{"id_menu":6,"count":1}]	13633	delivery	5	14
34668	2020-02-27 17:18:15	2020-02-27	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	13631	delivery	5	26
34669	2020-02-27 17:19:10	2020-02-27	12	[{"id_menu":3,"count":1}]	2280	pick-up	0	12
34670	2020-02-27 17:21:12	2020-02-27	14	[{"id_menu":2,"count":1}]	1021	delivery	5	19
34671	2020-02-27 17:30:33	2020-02-27	9	[{"id_menu":7,"count":1}]	13696	pick-up	0	9
34672	2020-02-27 17:36:13	2020-02-27	9	[{"id_menu":6,"count":1}]	467	pick-up	0	9
34673	2020-02-27 17:43:57	2020-02-27	9	[{"id_menu":6,"count":1}]	11287	pick-up	0	9
34674	2020-02-27 17:46:29	2020-02-27	9	[{"id_menu":6,"count":1}]	6697	delivery	5	14
34675	2020-02-27 17:50:17	2020-02-27	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4689	delivery	5	48
34676	2020-02-27 17:51:40	2020-02-27	9	[{"id_menu":7,"count":1}]	13712	delivery	5	14
34677	2020-02-27 17:58:03	2020-02-27	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	4326	pick-up	0	29
34678	2020-02-27 17:59:48	2020-02-27	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	3482	delivery	5	27
34679	2020-02-27 18:11:24	2020-02-27	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1075	delivery	5	31
34680	2020-02-27 18:12:16	2020-02-27	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	13656	delivery	5	40
34681	2020-02-27 18:22:22	2020-02-27	14	[{"id_menu":2,"count":1}]	4967	pick-up	0	14
34682	2020-02-27 18:23:57	2020-02-27	14	[{"id_menu":2,"count":1}]	13715	delivery	5	19
34683	2020-02-27 18:28:11	2020-02-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13630	delivery	5	22
34684	2020-02-27 18:29:22	2020-02-27	8	[{"id_menu":5,"count":1}]	3996	delivery	5	13
34685	2020-02-27 18:30:34	2020-02-27	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2406	pick-up	0	26
34686	2020-02-27 18:30:39	2020-02-27	14	[{"id_menu":2,"count":1}]	6530	delivery	5	19
34687	2020-02-27 18:31:18	2020-02-27	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9001	delivery	5	48
34688	2020-02-27 18:35:59	2020-02-27	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	13698	delivery	5	27
34689	2020-02-27 18:44:47	2020-02-27	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":2}]	10589	pick-up	0	26
34690	2020-02-27 18:49:36	2020-02-27	12	[{"id_menu":3,"count":1}]	1929	delivery	5	17
34691	2020-02-27 19:02:58	2020-02-27	9	[{"id_menu":6,"count":1}]	9212	delivery	5	14
34692	2020-02-27 19:04:53	2020-02-27	14	[{"id_menu":2,"count":1}]	13651	pick-up	0	14
34693	2020-02-27 19:12:38	2020-02-27	9	[{"id_menu":6,"count":1}]	9017	pick-up	0	9
34694	2020-02-27 19:17:49	2020-02-27	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12172	delivery	5	34
34695	2020-02-27 19:22:59	2020-02-27	9	[{"id_menu":7,"count":1}]	13721	delivery	5	14
34696	2020-02-27 19:39:19	2020-02-27	17	[{"id_menu":4,"count":1}]	13707	pick-up	0	17
34697	2020-02-27 19:43:45	2020-02-27	8	[{"id_menu":5,"count":1}]	9014	delivery	5	13
34698	2020-02-27 19:44:04	2020-02-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	11247	pick-up	0	31
34699	2020-02-27 19:46:15	2020-02-27	9	[{"id_menu":6,"count":1}]	13629	delivery	5	14
34700	2020-02-27 19:46:36	2020-02-27	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	13706	delivery	5	34
34701	2020-02-27 19:52:03	2020-02-27	12	[{"id_menu":3,"count":1}]	5552	delivery	5	17
34702	2020-02-27 19:53:04	2020-02-27	17	[{"id_menu":4,"count":1}]	7899	delivery	5	22
34703	2020-02-27 19:54:29	2020-02-27	8	[{"id_menu":5,"count":1}]	3525	delivery	5	13
34704	2020-02-27 19:57:48	2020-02-27	9	[{"id_menu":6,"count":2}]	12038	delivery	5	14
34705	2020-02-27 19:59:22	2020-02-27	8	[{"id_menu":5,"count":1}]	6754	pick-up	0	8
34706	2020-02-27 19:59:30	2020-02-27	9	[{"id_menu":6,"count":1}]	12623	pick-up	0	9
34707	2020-02-27 20:01:44	2020-02-27	17	[{"id_menu":4,"count":1}]	1258	delivery	5	22
34708	2020-02-27 20:04:28	2020-02-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	13695	delivery	5	36
34709	2020-02-27 20:04:43	2020-02-27	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	13676	delivery	5	31
34710	2020-02-27 20:06:35	2020-02-27	14	[{"id_menu":2,"count":1}]	2894	pick-up	0	14
34711	2020-02-27 20:08:32	2020-02-27	9	[{"id_menu":7,"count":1}]	7250	pick-up	0	9
34712	2020-02-27 20:19:05	2020-02-27	9	[{"id_menu":7,"count":1}]	2373	delivery	5	14
34713	2020-02-27 20:23:35	2020-02-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13257	delivery	5	22
34714	2020-02-27 20:25:58	2020-02-27	17	[{"id_menu":4,"count":1}]	2052	delivery	5	22
34715	2020-02-27 20:27:51	2020-02-27	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13170	delivery	5	39
34716	2020-02-27 20:27:58	2020-02-27	17	[{"id_menu":4,"count":1}]	2510	delivery	5	22
34717	2020-02-27 20:30:05	2020-02-27	12	[{"id_menu":3,"count":1}]	13636	delivery	5	17
34718	2020-02-27 20:31:43	2020-02-27	12	[{"id_menu":1,"count":1}]	585	delivery	5	17
34719	2020-02-27 20:33:56	2020-02-27	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8110	delivery	5	43
34720	2020-02-27 20:48:24	2020-02-27	14	[{"id_menu":2,"count":1}]	7530	delivery	5	19
34721	2020-02-27 20:53:23	2020-02-27	9	[{"id_menu":6,"count":1}]	4420	delivery	5	14
34722	2020-02-27 20:55:55	2020-02-27	9	[{"id_menu":7,"count":1}]	13736	pick-up	0	9
34723	2020-02-27 20:57:25	2020-02-27	12	[{"id_menu":1,"count":1}]	9404	pick-up	0	12
34724	2020-02-27 20:58:29	2020-02-27	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11496	delivery	5	31
34725	2020-02-27 21:00:38	2020-02-27	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	13441	delivery	5	26
34726	2020-02-27 21:12:32	2020-02-27	14	[{"id_menu":2,"count":1}]	7975	delivery	5	19
34727	2020-02-27 21:14:10	2020-02-27	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	13101	delivery	5	30
34728	2020-02-27 21:16:13	2020-02-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	10142	pick-up	0	31
34729	2020-02-27 21:22:58	2020-02-27	9	[{"id_menu":7,"count":1}]	8798	delivery	5	14
34730	2020-02-27 21:31:33	2020-02-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	41	delivery	5	23
34731	2020-02-27 21:34:37	2020-02-27	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13719	delivery	5	34
34732	2020-02-27 21:35:47	2020-02-27	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1104	pick-up	0	38
34733	2020-02-27 21:56:41	2020-02-27	14	[{"id_menu":2,"count":2}]	8303	delivery	5	19
34734	2020-02-27 21:56:50	2020-02-27	12	[{"id_menu":3,"count":1}]	10147	pick-up	0	12
34735	2020-02-27 21:57:34	2020-02-27	17	[{"id_menu":4,"count":1}]	13699	delivery	5	22
34736	2020-02-27 22:05:33	2020-02-27	12	[{"id_menu":1,"count":1}]	1557	delivery	5	17
34737	2020-02-27 22:17:53	2020-02-27	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13688	delivery	5	36
34738	2020-02-27 22:18:53	2020-02-27	9	[{"id_menu":6,"count":1}]	13690	delivery	5	14
34739	2020-02-27 22:27:58	2020-02-27	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10156	delivery	5	46
34740	2020-02-27 22:29:40	2020-02-27	12	[{"id_menu":1,"count":1}]	6080	delivery	5	17
34741	2020-02-27 22:29:48	2020-02-27	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	6465	pick-up	0	21
34742	2020-02-27 22:33:24	2020-02-27	12	[{"id_menu":3,"count":1}]	7834	delivery	5	17
34743	2020-02-27 22:36:53	2020-02-27	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	12905	delivery	5	40
34744	2020-02-27 22:48:09	2020-02-27	14	[{"id_menu":2,"count":1}]	5963	pick-up	0	14
34745	2020-02-27 23:00:16	2020-02-27	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13726	delivery	5	34
34746	2020-02-27 23:14:48	2020-02-27	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11235	delivery	5	31
34747	2020-02-27 23:19:30	2020-02-27	14	[{"id_menu":2,"count":1}]	10580	pick-up	0	14
34748	2020-02-27 23:26:02	2020-02-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	5558	delivery	5	22
34749	2020-02-27 23:26:32	2020-02-27	14	[{"id_menu":2,"count":1}]	3048	pick-up	0	14
34750	2020-02-27 23:27:48	2020-02-27	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	10198	pick-up	0	26
34751	2020-02-27 23:36:35	2020-02-27	12	[{"id_menu":1,"count":1}]	11560	delivery	5	17
34752	2020-02-27 23:38:54	2020-02-27	12	[{"id_menu":3,"count":1}]	9294	delivery	5	17
34753	2020-02-27 23:42:00	2020-02-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7156	pick-up	0	31
34754	2020-02-28 00:06:08	2020-02-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	13748	delivery	5	31
34755	2020-02-28 00:09:56	2020-02-28	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	13753	delivery	5	28
34756	2020-02-28 00:13:58	2020-02-28	9	[{"id_menu":7,"count":1}]	7159	pick-up	0	9
34757	2020-02-28 00:16:55	2020-02-28	14	[{"id_menu":2,"count":1}]	464	pick-up	0	14
34758	2020-02-28 00:20:33	2020-02-28	9	[{"id_menu":6,"count":1}]	12935	delivery	5	14
34759	2020-02-28 00:27:23	2020-02-28	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	13851	pick-up	0	43
34760	2020-02-28 00:33:05	2020-02-28	8	[{"id_menu":5,"count":1}]	976	pick-up	0	8
34761	2020-02-28 00:39:20	2020-02-28	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	13779	delivery	5	34
34762	2020-02-28 00:46:17	2020-02-28	12	[{"id_menu":1,"count":1}]	13737	delivery	5	17
34763	2020-02-28 00:47:57	2020-02-28	9	[{"id_menu":6,"count":2}]	4946	delivery	5	14
34764	2020-02-28 00:51:19	2020-02-28	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	13769	delivery	5	26
34765	2020-02-28 00:51:24	2020-02-28	8	[{"id_menu":5,"count":1}]	7551	delivery	5	13
34766	2020-02-28 01:03:39	2020-02-28	8	[{"id_menu":5,"count":1}]	13819	delivery	5	13
34767	2020-02-28 01:06:02	2020-02-28	17	[{"id_menu":4,"count":1}]	13815	delivery	5	22
34768	2020-02-28 01:19:05	2020-02-28	17	[{"id_menu":4,"count":1}]	13846	delivery	5	22
34769	2020-02-28 01:24:16	2020-02-28	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	13771	pick-up	0	26
34770	2020-02-28 01:25:31	2020-02-28	9	[{"id_menu":7,"count":1}]	1091	delivery	5	14
34771	2020-02-28 01:31:36	2020-02-28	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11041	delivery	5	43
34772	2020-02-28 01:34:28	2020-02-28	12	[{"id_menu":1,"count":1}]	13756	delivery	5	17
34773	2020-02-28 01:41:50	2020-02-28	12	[{"id_menu":3,"count":1}]	13762	pick-up	0	12
34774	2020-02-28 01:50:13	2020-02-28	12	[{"id_menu":1,"count":1}]	5857	pick-up	0	12
34775	2020-02-28 01:52:27	2020-02-28	12	[{"id_menu":3,"count":1}]	834	pick-up	0	12
34776	2020-02-28 02:02:24	2020-02-28	14	[{"id_menu":2,"count":1}]	12095	delivery	5	19
34777	2020-02-28 02:13:50	2020-02-28	12	[{"id_menu":3,"count":1}]	3558	delivery	5	17
34778	2020-02-28 02:20:22	2020-02-28	14	[{"id_menu":2,"count":1}]	13761	delivery	5	19
34779	2020-02-28 02:30:25	2020-02-28	12	[{"id_menu":3,"count":1}]	7410	pick-up	0	12
34780	2020-02-28 02:35:17	2020-02-28	12	[{"id_menu":3,"count":1}]	13792	pick-up	0	12
34781	2020-02-28 02:36:10	2020-02-28	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	13751	pick-up	0	22
34782	2020-02-28 02:40:39	2020-02-28	12	[{"id_menu":1,"count":1}]	271	pick-up	0	12
34783	2020-02-28 02:43:51	2020-02-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	13808	delivery	5	23
34784	2020-02-28 02:45:51	2020-02-28	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":3}]	3434	delivery	5	28
34785	2020-02-28 02:56:08	2020-02-28	8	[{"id_menu":5,"count":1}]	13799	pick-up	0	8
34786	2020-02-28 03:07:57	2020-02-28	9	[{"id_menu":6,"count":1}]	13805	delivery	5	14
34787	2020-02-28 03:09:39	2020-02-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	13847	delivery	5	22
34788	2020-02-28 03:11:36	2020-02-28	9	[{"id_menu":6,"count":1}]	13775	delivery	5	14
34789	2020-02-28 03:12:09	2020-02-28	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	13760	delivery	5	46
34790	2020-02-28 03:17:57	2020-02-28	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1317	delivery	5	29
34791	2020-02-28 03:18:32	2020-02-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	10461	delivery	5	28
34792	2020-02-28 03:22:45	2020-02-28	17	[{"id_menu":4,"count":1}]	11006	delivery	5	22
34793	2020-02-28 03:23:15	2020-02-28	17	[{"id_menu":4,"count":1}]	2231	pick-up	0	17
34794	2020-02-28 03:45:49	2020-02-28	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13766	delivery	5	35
34795	2020-02-28 03:51:13	2020-02-28	12	[{"id_menu":1,"count":1}]	11944	pick-up	0	12
34796	2020-02-28 04:01:43	2020-02-28	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	11215	delivery	5	37
34797	2020-02-28 04:06:38	2020-02-28	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	5057	delivery	5	26
34798	2020-02-28 04:19:25	2020-02-28	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	13778	delivery	5	57
34799	2020-02-28 04:35:53	2020-02-28	41	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	13806	pick-up	0	41
34800	2020-02-28 04:44:14	2020-02-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13018	delivery	5	22
34801	2020-02-28 04:50:05	2020-02-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	13765	delivery	5	28
34802	2020-02-28 04:50:50	2020-02-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	883	pick-up	0	17
34803	2020-02-28 04:52:08	2020-02-28	12	[{"id_menu":1,"count":1}]	13774	delivery	5	17
34804	2020-02-28 04:53:35	2020-02-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4137	pick-up	0	18
34805	2020-02-28 04:53:40	2020-02-28	8	[{"id_menu":5,"count":1}]	13832	pick-up	0	8
34806	2020-02-28 05:02:33	2020-02-28	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1822	pick-up	0	35
34807	2020-02-28 05:04:27	2020-02-28	9	[{"id_menu":7,"count":1}]	2309	delivery	5	14
34808	2020-02-28 05:12:36	2020-02-28	8	[{"id_menu":5,"count":1}]	13809	pick-up	0	8
34809	2020-02-28 05:14:45	2020-02-28	12	[{"id_menu":3,"count":1}]	3099	delivery	5	17
34810	2020-02-28 05:17:37	2020-02-28	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	13852	pick-up	0	29
34811	2020-02-28 05:21:37	2020-02-28	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	13795	delivery	5	40
34812	2020-02-28 05:23:25	2020-02-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2838	pick-up	0	26
34813	2020-02-28 05:31:36	2020-02-28	12	[{"id_menu":1,"count":1}]	13843	delivery	5	17
34814	2020-02-28 05:34:08	2020-02-28	9	[{"id_menu":6,"count":1}]	13236	delivery	5	14
34815	2020-02-28 05:38:13	2020-02-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1104	pick-up	0	18
34816	2020-02-28 05:42:00	2020-02-28	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	6987	pick-up	0	21
34817	2020-02-28 05:50:07	2020-02-28	12	[{"id_menu":3,"count":1}]	5979	delivery	5	17
34818	2020-02-28 05:52:28	2020-02-28	9	[{"id_menu":7,"count":1}]	3711	pick-up	0	9
34819	2020-02-28 05:55:49	2020-02-28	9	[{"id_menu":6,"count":1}]	13828	delivery	5	14
34820	2020-02-28 06:14:47	2020-02-28	9	[{"id_menu":7,"count":1}]	3601	delivery	5	14
34821	2020-02-28 06:21:32	2020-02-28	9	[{"id_menu":6,"count":2}]	13823	delivery	5	14
34822	2020-02-28 06:22:36	2020-02-28	9	[{"id_menu":6,"count":1}]	2507	delivery	5	14
34823	2020-02-28 06:27:47	2020-02-28	8	[{"id_menu":5,"count":1}]	4817	delivery	5	13
34824	2020-02-28 06:27:50	2020-02-28	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	680	pick-up	0	34
34825	2020-02-28 06:32:04	2020-02-28	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1594	pick-up	0	23
34826	2020-02-28 06:34:48	2020-02-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	13812	delivery	5	22
34827	2020-02-28 06:35:52	2020-02-28	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1720	pick-up	0	21
34828	2020-02-28 06:47:19	2020-02-28	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9653	delivery	5	51
34829	2020-02-28 06:48:19	2020-02-28	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	6276	delivery	5	22
34830	2020-02-28 06:48:30	2020-02-28	14	[{"id_menu":2,"count":1}]	7304	pick-up	0	14
34831	2020-02-28 06:51:34	2020-02-28	17	[{"id_menu":4,"count":1}]	13115	delivery	5	22
34832	2020-02-28 06:54:30	2020-02-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	11507	delivery	5	31
34833	2020-02-28 06:55:09	2020-02-28	9	[{"id_menu":7,"count":1}]	13768	delivery	5	14
34834	2020-02-28 06:56:06	2020-02-28	9	[{"id_menu":6,"count":1}]	12506	pick-up	0	9
34835	2020-02-28 06:59:18	2020-02-28	9	[{"id_menu":7,"count":1}]	10479	pick-up	0	9
34836	2020-02-28 07:10:25	2020-02-28	17	[{"id_menu":4,"count":1}]	13772	pick-up	0	17
34837	2020-02-28 07:20:00	2020-02-28	9	[{"id_menu":6,"count":1}]	11269	delivery	5	14
34838	2020-02-28 07:31:45	2020-02-28	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	660	delivery	5	26
34839	2020-02-28 07:36:38	2020-02-28	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	11710	delivery	5	31
34840	2020-02-28 07:44:22	2020-02-28	9	[{"id_menu":7,"count":1}]	13194	delivery	5	14
34841	2020-02-28 07:49:35	2020-02-28	9	[{"id_menu":6,"count":1}]	13740	pick-up	0	9
34842	2020-02-28 07:49:45	2020-02-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13759	delivery	5	23
34843	2020-02-28 07:52:07	2020-02-28	8	[{"id_menu":5,"count":1}]	11348	delivery	5	13
34844	2020-02-28 07:58:42	2020-02-28	9	[{"id_menu":7,"count":1}]	13856	delivery	5	14
34845	2020-02-28 08:02:06	2020-02-28	14	[{"id_menu":2,"count":1}]	4996	pick-up	0	14
34846	2020-02-28 08:07:44	2020-02-28	9	[{"id_menu":6,"count":1}]	9686	delivery	5	14
34847	2020-02-28 08:08:07	2020-02-28	9	[{"id_menu":7,"count":1}]	13834	delivery	5	14
34848	2020-02-28 08:18:10	2020-02-28	14	[{"id_menu":2,"count":1}]	5473	pick-up	0	14
34849	2020-02-28 08:25:25	2020-02-28	17	[{"id_menu":4,"count":1}]	1693	pick-up	0	17
34850	2020-02-28 08:28:27	2020-02-28	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	7093	delivery	5	39
34851	2020-02-28 08:29:22	2020-02-28	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	8893	delivery	5	39
34852	2020-02-28 08:30:05	2020-02-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3838	delivery	5	23
34853	2020-02-28 08:37:00	2020-02-28	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	9171	pick-up	0	21
34854	2020-02-28 08:50:48	2020-02-28	9	[{"id_menu":6,"count":1}]	13757	pick-up	0	9
34855	2020-02-28 08:55:21	2020-02-28	9	[{"id_menu":7,"count":1}]	13763	delivery	5	14
34856	2020-02-28 09:00:07	2020-02-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	2917	pick-up	0	26
34857	2020-02-28 09:07:13	2020-02-28	14	[{"id_menu":2,"count":1}]	13741	pick-up	0	14
34858	2020-02-28 09:08:36	2020-02-28	17	[{"id_menu":4,"count":1}]	6410	pick-up	0	17
34859	2020-02-28 09:15:24	2020-02-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5476	delivery	5	23
34860	2020-02-28 09:15:37	2020-02-28	17	[{"id_menu":4,"count":1}]	10993	delivery	5	22
34861	2020-02-28 09:23:34	2020-02-28	9	[{"id_menu":6,"count":1}]	13749	delivery	5	14
34862	2020-02-28 09:26:41	2020-02-28	9	[{"id_menu":7,"count":1}]	13747	delivery	5	14
34863	2020-02-28 09:26:41	2020-02-28	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	13837	delivery	5	26
34864	2020-02-28 09:28:32	2020-02-28	9	[{"id_menu":7,"count":2}]	13776	delivery	5	14
34865	2020-02-28 09:34:36	2020-02-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	1293	delivery	5	22
34866	2020-02-28 09:38:19	2020-02-28	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	13855	pick-up	0	25
34867	2020-02-28 09:51:01	2020-02-28	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	13791	delivery	5	34
34868	2020-02-28 09:51:25	2020-02-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	96	pick-up	0	18
34869	2020-02-28 09:52:43	2020-02-28	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	367	delivery	5	27
34870	2020-02-28 09:54:03	2020-02-28	9	[{"id_menu":7,"count":1}]	12636	delivery	5	14
34871	2020-02-28 09:55:56	2020-02-28	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	13850	delivery	5	35
34872	2020-02-28 09:58:18	2020-02-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12580	delivery	5	22
34873	2020-02-28 10:05:09	2020-02-28	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	6076	delivery	5	35
34874	2020-02-28 10:08:39	2020-02-28	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	13794	delivery	5	43
34875	2020-02-28 10:09:03	2020-02-28	8	[{"id_menu":5,"count":1}]	9204	delivery	5	13
34876	2020-02-28 10:16:47	2020-02-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	4911	delivery	5	28
34877	2020-02-28 10:21:26	2020-02-28	9	[{"id_menu":6,"count":1}]	4258	delivery	5	14
34878	2020-02-28 10:32:29	2020-02-28	17	[{"id_menu":4,"count":1}]	11276	delivery	5	22
34879	2020-02-28 10:33:47	2020-02-28	14	[{"id_menu":2,"count":1}]	13848	delivery	5	19
34880	2020-02-28 10:39:14	2020-02-28	12	[{"id_menu":1,"count":1}]	9198	pick-up	0	12
34881	2020-02-28 10:41:52	2020-02-28	14	[{"id_menu":2,"count":1}]	2602	pick-up	0	14
34882	2020-02-28 10:57:22	2020-02-28	14	[{"id_menu":2,"count":1}]	3847	pick-up	0	14
34883	2020-02-28 11:01:16	2020-02-28	9	[{"id_menu":7,"count":2}]	13841	pick-up	0	9
34884	2020-02-28 11:08:07	2020-02-28	12	[{"id_menu":3,"count":1}]	12654	delivery	5	17
34885	2020-02-28 11:15:30	2020-02-28	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13813	delivery	5	45
34886	2020-02-28 11:26:49	2020-02-28	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	6798	pick-up	0	21
34887	2020-02-28 11:39:33	2020-02-28	17	[{"id_menu":4,"count":1}]	11554	delivery	5	22
34888	2020-02-28 11:40:30	2020-02-28	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6873	delivery	5	31
34889	2020-02-28 11:43:09	2020-02-28	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	5506	pick-up	0	31
34890	2020-02-28 11:45:22	2020-02-28	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	13786	delivery	5	36
34891	2020-02-28 11:51:05	2020-02-28	12	[{"id_menu":3,"count":1}]	1997	pick-up	0	12
34892	2020-02-28 11:53:38	2020-02-28	14	[{"id_menu":2,"count":1}]	12367	pick-up	0	14
34893	2020-02-28 12:05:06	2020-02-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13745	delivery	5	22
34894	2020-02-28 12:13:28	2020-02-28	14	[{"id_menu":2,"count":1}]	3752	pick-up	0	14
34895	2020-02-28 12:15:08	2020-02-28	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	13831	delivery	5	29
34896	2020-02-28 12:33:09	2020-02-28	12	[{"id_menu":1,"count":1}]	13752	delivery	5	17
34897	2020-02-28 12:35:39	2020-02-28	14	[{"id_menu":2,"count":1}]	13790	delivery	5	19
34898	2020-02-28 12:37:59	2020-02-28	9	[{"id_menu":7,"count":1}]	13839	delivery	5	14
34899	2020-02-28 12:38:48	2020-02-28	9	[{"id_menu":6,"count":1}]	11926	pick-up	0	9
34900	2020-02-28 12:43:02	2020-02-28	8	[{"id_menu":5,"count":1}]	3000	delivery	5	13
34901	2020-02-28 12:44:22	2020-02-28	14	[{"id_menu":2,"count":1}]	8716	pick-up	0	14
34902	2020-02-28 12:48:05	2020-02-28	12	[{"id_menu":1,"count":1}]	6664	delivery	5	17
34903	2020-02-28 12:50:31	2020-02-28	8	[{"id_menu":5,"count":1}]	7429	delivery	5	13
34904	2020-02-28 12:50:35	2020-02-28	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	10679	delivery	5	34
34905	2020-02-28 12:57:24	2020-02-28	9	[{"id_menu":7,"count":1}]	1881	pick-up	0	9
34906	2020-02-28 13:00:52	2020-02-28	8	[{"id_menu":5,"count":1}]	13798	delivery	5	13
34907	2020-02-28 13:02:05	2020-02-28	9	[{"id_menu":7,"count":2}]	4445	pick-up	0	9
34908	2020-02-28 13:06:27	2020-02-28	12	[{"id_menu":3,"count":1}]	408	pick-up	0	12
34909	2020-02-28 13:12:44	2020-02-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	13796	delivery	5	31
34910	2020-02-28 13:19:02	2020-02-28	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	7631	pick-up	0	29
34911	2020-02-28 13:22:21	2020-02-28	17	[{"id_menu":4,"count":1}]	5427	pick-up	0	17
34912	2020-02-28 13:23:07	2020-02-28	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	2050	pick-up	0	24
34913	2020-02-28 13:24:16	2020-02-28	14	[{"id_menu":2,"count":1}]	588	pick-up	0	14
34914	2020-02-28 13:24:48	2020-02-28	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11237	delivery	5	48
34915	2020-02-28 13:25:22	2020-02-28	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	8205	delivery	5	34
34916	2020-02-28 13:25:36	2020-02-28	8	[{"id_menu":5,"count":1}]	12896	pick-up	0	8
34917	2020-02-28 13:29:08	2020-02-28	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	8747	delivery	5	26
34918	2020-02-28 13:31:34	2020-02-28	12	[{"id_menu":1,"count":1}]	13738	delivery	5	17
34919	2020-02-28 13:39:35	2020-02-28	9	[{"id_menu":6,"count":1}]	66	pick-up	0	9
34920	2020-02-28 13:48:07	2020-02-28	12	[{"id_menu":1,"count":1}]	6720	delivery	5	17
34921	2020-02-28 14:01:57	2020-02-28	14	[{"id_menu":2,"count":1}]	13838	pick-up	0	14
34922	2020-02-28 14:03:34	2020-02-28	12	[{"id_menu":3,"count":1}]	1847	delivery	5	17
34923	2020-02-28 14:10:11	2020-02-28	12	[{"id_menu":1,"count":1}]	2434	pick-up	0	12
34924	2020-02-28 14:23:43	2020-02-28	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	6416	delivery	5	26
34925	2020-02-28 14:31:44	2020-02-28	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13788	delivery	5	45
34926	2020-02-28 14:43:58	2020-02-28	12	[{"id_menu":3,"count":1}]	3001	delivery	5	17
34927	2020-02-28 14:45:52	2020-02-28	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1273	pick-up	0	23
34928	2020-02-28 14:46:27	2020-02-28	9	[{"id_menu":7,"count":1}]	794	delivery	5	14
34929	2020-02-28 14:51:57	2020-02-28	9	[{"id_menu":7,"count":1}]	8874	delivery	5	14
34930	2020-02-28 14:54:58	2020-02-28	8	[{"id_menu":5,"count":1}]	13755	pick-up	0	8
34931	2020-02-28 15:03:45	2020-02-28	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	13797	delivery	5	31
34932	2020-02-28 15:12:55	2020-02-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	8187	delivery	5	22
34933	2020-02-28 15:19:10	2020-02-28	9	[{"id_menu":7,"count":1}]	6565	pick-up	0	9
34934	2020-02-28 15:27:03	2020-02-28	14	[{"id_menu":2,"count":1}]	13810	delivery	5	19
34935	2020-02-28 15:28:29	2020-02-28	9	[{"id_menu":7,"count":1}]	11502	delivery	5	14
34936	2020-02-28 15:30:00	2020-02-28	17	[{"id_menu":4,"count":1}]	13829	delivery	5	22
34937	2020-02-28 15:30:43	2020-02-28	12	[{"id_menu":3,"count":1}]	13835	delivery	5	17
34938	2020-02-28 15:39:44	2020-02-28	9	[{"id_menu":6,"count":1}]	13742	delivery	5	14
34939	2020-02-28 15:42:43	2020-02-28	9	[{"id_menu":7,"count":1}]	13854	delivery	5	14
34940	2020-02-28 15:46:10	2020-02-28	8	[{"id_menu":5,"count":1}]	13811	delivery	5	13
34941	2020-02-28 16:01:02	2020-02-28	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	13824	delivery	5	37
34942	2020-02-28 16:02:59	2020-02-28	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	10660	delivery	5	23
34943	2020-02-28 16:04:03	2020-02-28	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	2470	delivery	5	28
34944	2020-02-28 16:12:32	2020-02-28	12	[{"id_menu":3,"count":1}]	2574	delivery	5	17
34945	2020-02-28 16:15:02	2020-02-28	9	[{"id_menu":7,"count":1}]	140	pick-up	0	9
34946	2020-02-28 16:22:05	2020-02-28	17	[{"id_menu":4,"count":1}]	5332	delivery	5	22
34947	2020-02-28 16:27:41	2020-02-28	12	[{"id_menu":3,"count":1}]	2933	pick-up	0	12
34948	2020-02-28 16:28:50	2020-02-28	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3509	delivery	5	26
34949	2020-02-28 16:30:20	2020-02-28	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	13773	delivery	5	42
34950	2020-02-28 16:37:45	2020-02-28	12	[{"id_menu":1,"count":1}]	2477	pick-up	0	12
34951	2020-02-28 16:39:03	2020-02-28	9	[{"id_menu":6,"count":1}]	3347	delivery	5	14
34952	2020-02-28 16:45:02	2020-02-28	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	13803	delivery	5	25
34953	2020-02-28 16:49:02	2020-02-28	9	[{"id_menu":7,"count":1}]	314	delivery	5	14
34954	2020-02-28 16:49:23	2020-02-28	9	[{"id_menu":7,"count":2}]	8501	pick-up	0	9
34955	2020-02-28 16:51:11	2020-02-28	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13789	delivery	5	45
34956	2020-02-28 16:55:48	2020-02-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12266	delivery	5	22
34957	2020-02-28 16:57:30	2020-02-28	9	[{"id_menu":7,"count":1}]	13826	delivery	5	14
34958	2020-02-28 17:01:31	2020-02-28	17	[{"id_menu":4,"count":1}]	9737	delivery	5	22
34959	2020-02-28 17:01:48	2020-02-28	14	[{"id_menu":2,"count":1}]	13800	delivery	5	19
34960	2020-02-28 17:05:05	2020-02-28	17	[{"id_menu":4,"count":2}]	488	delivery	5	22
34961	2020-02-28 17:13:09	2020-02-28	17	[{"id_menu":4,"count":1}]	11896	pick-up	0	17
34962	2020-02-28 17:14:04	2020-02-28	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4213	pick-up	0	31
34963	2020-02-28 17:16:38	2020-02-28	12	[{"id_menu":1,"count":1}]	13426	delivery	5	17
34964	2020-02-28 17:31:20	2020-02-28	14	[{"id_menu":2,"count":1}]	10757	delivery	5	19
34965	2020-02-28 17:36:51	2020-02-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7186	delivery	5	23
34966	2020-02-28 17:58:07	2020-02-28	12	[{"id_menu":1,"count":1}]	13782	delivery	5	17
34967	2020-02-28 18:03:27	2020-02-28	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	1582	pick-up	0	29
34968	2020-02-28 18:05:03	2020-02-28	12	[{"id_menu":3,"count":1}]	2551	delivery	5	17
34969	2020-02-28 18:13:27	2020-02-28	8	[{"id_menu":5,"count":1}]	10840	pick-up	0	8
34970	2020-02-28 18:14:49	2020-02-28	12	[{"id_menu":3,"count":1}]	1041	pick-up	0	12
34971	2020-02-28 18:17:33	2020-02-28	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	11574	delivery	5	31
34972	2020-02-28 18:19:10	2020-02-28	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7125	delivery	5	28
34973	2020-02-28 18:25:12	2020-02-28	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	13758	delivery	5	27
34974	2020-02-28 18:35:24	2020-02-28	12	[{"id_menu":3,"count":1}]	970	pick-up	0	12
34975	2020-02-28 18:35:34	2020-02-28	12	[{"id_menu":1,"count":1}]	1044	pick-up	0	12
34976	2020-02-28 18:36:51	2020-02-28	9	[{"id_menu":7,"count":1}]	13802	delivery	5	14
34977	2020-02-28 18:46:41	2020-02-28	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	8106	delivery	5	40
34978	2020-02-28 18:53:40	2020-02-28	9	[{"id_menu":7,"count":1}]	13555	pick-up	0	9
34979	2020-02-28 18:55:47	2020-02-28	9	[{"id_menu":6,"count":1}]	4874	delivery	5	14
34980	2020-02-28 18:58:27	2020-02-28	17	[{"id_menu":4,"count":1}]	10403	pick-up	0	17
34981	2020-02-28 19:01:14	2020-02-28	9	[{"id_menu":7,"count":2}]	3059	delivery	5	14
34982	2020-02-28 19:01:15	2020-02-28	14	[{"id_menu":2,"count":1}]	9682	pick-up	0	14
34983	2020-02-28 19:13:06	2020-02-28	8	[{"id_menu":5,"count":1}]	8738	delivery	5	13
34984	2020-02-28 19:14:39	2020-02-28	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	6385	pick-up	0	23
34985	2020-02-28 19:18:21	2020-02-28	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	4605	delivery	5	28
34986	2020-02-28 19:21:20	2020-02-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9733	delivery	5	22
34987	2020-02-28 19:21:55	2020-02-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2023	pick-up	0	17
34988	2020-02-28 19:23:10	2020-02-28	9	[{"id_menu":7,"count":1}]	13827	delivery	5	14
34989	2020-02-28 19:27:01	2020-02-28	8	[{"id_menu":5,"count":1}]	13830	delivery	5	13
34990	2020-02-28 19:35:28	2020-02-28	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	13842	delivery	5	30
34991	2020-02-28 19:36:52	2020-02-28	17	[{"id_menu":4,"count":1}]	4711	pick-up	0	17
34992	2020-02-28 19:47:06	2020-02-28	12	[{"id_menu":1,"count":1}]	1058	pick-up	0	12
34993	2020-02-28 19:48:58	2020-02-28	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	7050	delivery	5	38
34994	2020-02-28 19:58:07	2020-02-28	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1860	pick-up	0	31
34995	2020-02-28 20:04:00	2020-02-28	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	13836	delivery	5	30
34996	2020-02-28 20:04:04	2020-02-28	17	[{"id_menu":4,"count":1}]	13814	delivery	5	22
34997	2020-02-28 20:10:47	2020-02-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2765	delivery	5	22
34998	2020-02-28 20:24:19	2020-02-28	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	13804	delivery	5	48
34999	2020-02-28 20:25:52	2020-02-28	12	[{"id_menu":3,"count":1}]	10867	pick-up	0	12
35000	2020-02-28 20:32:31	2020-02-28	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13743	delivery	5	48
35001	2020-02-28 20:38:24	2020-02-28	17	[{"id_menu":4,"count":1}]	13844	pick-up	0	17
35002	2020-02-28 20:40:02	2020-02-28	9	[{"id_menu":6,"count":1}]	2444	pick-up	0	9
35003	2020-02-28 20:49:25	2020-02-28	8	[{"id_menu":5,"count":1}]	8964	pick-up	0	8
35004	2020-02-28 20:52:34	2020-02-28	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":2}]	11983	delivery	5	26
35005	2020-02-28 20:59:52	2020-02-28	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	11596	delivery	5	56
35006	2020-02-28 21:04:25	2020-02-28	12	[{"id_menu":1,"count":1}]	13739	delivery	5	17
35007	2020-02-28 21:05:55	2020-02-28	8	[{"id_menu":5,"count":2}]	10153	delivery	5	13
35008	2020-02-28 21:13:17	2020-02-28	14	[{"id_menu":2,"count":1}]	2232	pick-up	0	14
35009	2020-02-28 21:16:19	2020-02-28	9	[{"id_menu":7,"count":1}]	3883	delivery	5	14
35010	2020-02-28 21:17:08	2020-02-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3944	pick-up	0	26
35011	2020-02-28 21:18:34	2020-02-28	9	[{"id_menu":6,"count":1}]	3971	pick-up	0	9
35012	2020-02-28 21:22:53	2020-02-28	14	[{"id_menu":2,"count":1}]	6419	delivery	5	19
35013	2020-02-28 21:42:28	2020-02-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8966	pick-up	0	17
35014	2020-02-28 21:45:19	2020-02-28	9	[{"id_menu":6,"count":1}]	2401	pick-up	0	9
35015	2020-02-28 21:46:57	2020-02-28	12	[{"id_menu":1,"count":1}]	13777	delivery	5	17
35016	2020-02-28 22:10:28	2020-02-28	17	[{"id_menu":4,"count":1}]	11239	pick-up	0	17
35017	2020-02-28 22:11:16	2020-02-28	14	[{"id_menu":2,"count":1}]	10196	delivery	5	19
35018	2020-02-28 22:14:27	2020-02-28	9	[{"id_menu":6,"count":1}]	13816	delivery	5	14
35019	2020-02-28 22:17:02	2020-02-28	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	641	delivery	5	39
35020	2020-02-28 22:29:59	2020-02-28	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	5939	pick-up	0	22
35021	2020-02-28 22:43:23	2020-02-28	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	13750	delivery	5	26
35022	2020-02-28 22:47:42	2020-02-28	12	[{"id_menu":3,"count":1}]	8202	delivery	5	17
35023	2020-02-28 22:51:07	2020-02-28	17	[{"id_menu":4,"count":1}]	1775	delivery	5	22
35024	2020-02-28 22:51:18	2020-02-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	1543	delivery	5	31
35025	2020-02-28 22:51:26	2020-02-28	14	[{"id_menu":2,"count":1}]	13807	delivery	5	19
35026	2020-02-28 22:52:35	2020-02-28	14	[{"id_menu":2,"count":1}]	10264	pick-up	0	14
35027	2020-02-28 22:52:44	2020-02-28	14	[{"id_menu":2,"count":1}]	13853	pick-up	0	14
35028	2020-02-28 22:57:34	2020-02-28	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2885	delivery	5	40
35029	2020-02-28 23:13:53	2020-02-28	9	[{"id_menu":7,"count":1}]	12853	delivery	5	14
35030	2020-02-28 23:15:09	2020-02-28	17	[{"id_menu":4,"count":1}]	10870	delivery	5	22
35031	2020-02-28 23:24:55	2020-02-28	8	[{"id_menu":5,"count":1}]	9072	delivery	5	13
35032	2020-02-28 23:27:37	2020-02-28	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7021	delivery	5	28
35033	2020-02-28 23:28:53	2020-02-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	154	pick-up	0	18
35034	2020-02-28 23:52:51	2020-02-28	12	[{"id_menu":1,"count":2}]	10625	delivery	5	17
35035	2020-02-29 00:02:28	2020-02-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	9435	delivery	5	28
35036	2020-02-29 00:02:46	2020-02-29	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	9081	delivery	5	36
35037	2020-02-29 00:03:15	2020-02-29	12	[{"id_menu":3,"count":1}]	3754	delivery	5	17
35038	2020-02-29 00:06:05	2020-02-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	10880	delivery	5	28
35039	2020-02-29 00:17:27	2020-02-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4846	pick-up	0	18
35040	2020-02-29 00:44:24	2020-02-29	9	[{"id_menu":6,"count":1}]	13881	delivery	5	14
35041	2020-02-29 00:50:09	2020-02-29	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	13862	delivery	5	28
35042	2020-02-29 00:57:48	2020-02-29	12	[{"id_menu":3,"count":1}]	11093	delivery	5	17
35043	2020-02-29 00:58:15	2020-02-29	12	[{"id_menu":1,"count":1}]	2153	pick-up	0	12
35044	2020-02-29 00:58:26	2020-02-29	9	[{"id_menu":7,"count":1}]	13950	pick-up	0	9
35045	2020-02-29 01:05:04	2020-02-29	12	[{"id_menu":1,"count":1}]	1245	pick-up	0	12
35046	2020-02-29 01:08:20	2020-02-29	9	[{"id_menu":7,"count":1}]	13911	delivery	5	14
35047	2020-02-29 01:08:44	2020-02-29	8	[{"id_menu":5,"count":1}]	8636	delivery	5	13
35048	2020-02-29 01:11:38	2020-02-29	9	[{"id_menu":6,"count":1}]	3494	pick-up	0	9
35049	2020-02-29 01:12:22	2020-02-29	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13962	delivery	5	37
35050	2020-02-29 01:14:23	2020-02-29	12	[{"id_menu":3,"count":1}]	453	pick-up	0	12
35119	2020-02-29 05:40:48	2020-02-29	9	[{"id_menu":7,"count":1}]	5542	delivery	5	14
35051	2020-02-29 01:19:59	2020-02-29	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	13931	delivery	5	40
35052	2020-02-29 01:24:27	2020-02-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	13894	delivery	5	31
35053	2020-02-29 01:24:48	2020-02-29	14	[{"id_menu":2,"count":1}]	13973	delivery	5	19
35054	2020-02-29 01:26:37	2020-02-29	17	[{"id_menu":4,"count":1}]	13920	pick-up	0	17
35055	2020-02-29 01:34:20	2020-02-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13934	delivery	5	36
35056	2020-02-29 01:43:20	2020-02-29	9	[{"id_menu":7,"count":1}]	13884	delivery	5	14
35057	2020-02-29 01:45:15	2020-02-29	12	[{"id_menu":3,"count":1}]	2867	pick-up	0	12
35058	2020-02-29 01:46:00	2020-02-29	9	[{"id_menu":6,"count":1}]	11629	delivery	5	14
35059	2020-02-29 01:52:08	2020-02-29	9	[{"id_menu":7,"count":1}]	1760	delivery	5	14
35060	2020-02-29 01:55:34	2020-02-29	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11763	delivery	5	43
35061	2020-02-29 02:01:49	2020-02-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7003	delivery	5	22
35062	2020-02-29 02:16:37	2020-02-29	9	[{"id_menu":7,"count":1}]	10672	delivery	5	14
35063	2020-02-29 02:18:16	2020-02-29	17	[{"id_menu":4,"count":1}]	10389	pick-up	0	17
35064	2020-02-29 02:26:08	2020-02-29	12	[{"id_menu":3,"count":1}]	13972	delivery	5	17
35065	2020-02-29 02:29:15	2020-02-29	8	[{"id_menu":5,"count":1}]	11795	pick-up	0	8
35066	2020-02-29 02:31:32	2020-02-29	12	[{"id_menu":3,"count":1}]	13945	pick-up	0	12
35067	2020-02-29 02:38:45	2020-02-29	12	[{"id_menu":3,"count":1}]	12138	delivery	5	17
35068	2020-02-29 02:41:06	2020-02-29	9	[{"id_menu":7,"count":1}]	2305	delivery	5	14
35069	2020-02-29 02:48:41	2020-02-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	563	delivery	5	28
35070	2020-02-29 02:57:41	2020-02-29	9	[{"id_menu":6,"count":1}]	13868	delivery	5	14
35071	2020-02-29 03:00:03	2020-02-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	13976	delivery	5	28
35072	2020-02-29 03:07:16	2020-02-29	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	10828	delivery	5	40
35073	2020-02-29 03:09:26	2020-02-29	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	5289	delivery	5	39
35074	2020-02-29 03:10:54	2020-02-29	14	[{"id_menu":2,"count":1}]	2272	delivery	5	19
35075	2020-02-29 03:11:05	2020-02-29	12	[{"id_menu":3,"count":1}]	1944	pick-up	0	12
35076	2020-02-29 03:11:30	2020-02-29	14	[{"id_menu":2,"count":1}]	3812	pick-up	0	14
35077	2020-02-29 03:11:53	2020-02-29	12	[{"id_menu":3,"count":1}]	11482	delivery	5	17
35078	2020-02-29 03:16:37	2020-02-29	9	[{"id_menu":7,"count":1}]	13982	delivery	5	14
35079	2020-02-29 03:22:15	2020-02-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8627	delivery	5	31
35080	2020-02-29 03:23:09	2020-02-29	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	13876	delivery	5	25
35081	2020-02-29 03:23:20	2020-02-29	12	[{"id_menu":3,"count":1}]	6617	pick-up	0	12
35082	2020-02-29 03:24:18	2020-02-29	14	[{"id_menu":2,"count":1}]	11957	delivery	5	19
35083	2020-02-29 03:34:00	2020-02-29	9	[{"id_menu":7,"count":1}]	13879	delivery	5	14
35084	2020-02-29 03:36:52	2020-02-29	9	[{"id_menu":6,"count":1}]	3006	delivery	5	14
35085	2020-02-29 03:43:05	2020-02-29	12	[{"id_menu":1,"count":1}]	8700	pick-up	0	12
35086	2020-02-29 03:51:55	2020-02-29	14	[{"id_menu":2,"count":1}]	13296	delivery	5	19
35087	2020-02-29 03:57:43	2020-02-29	17	[{"id_menu":4,"count":1}]	4104	delivery	5	22
35088	2020-02-29 03:59:38	2020-02-29	14	[{"id_menu":2,"count":1}]	233	pick-up	0	14
35089	2020-02-29 04:02:54	2020-02-29	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	11239	delivery	5	40
35090	2020-02-29 04:03:47	2020-02-29	12	[{"id_menu":1,"count":2}]	13930	delivery	5	17
35091	2020-02-29 04:06:47	2020-02-29	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7028	delivery	5	30
35092	2020-02-29 04:06:52	2020-02-29	17	[{"id_menu":4,"count":1}]	6666	delivery	5	22
35093	2020-02-29 04:10:30	2020-02-29	9	[{"id_menu":6,"count":1}]	5496	delivery	5	14
35094	2020-02-29 04:12:49	2020-02-29	17	[{"id_menu":4,"count":1}]	6941	delivery	5	22
35095	2020-02-29 04:14:23	2020-02-29	14	[{"id_menu":2,"count":1}]	5466	pick-up	0	14
35096	2020-02-29 04:16:26	2020-02-29	14	[{"id_menu":2,"count":1}]	13193	pick-up	0	14
35097	2020-02-29 04:26:30	2020-02-29	8	[{"id_menu":5,"count":1}]	8057	delivery	5	13
35098	2020-02-29 04:29:17	2020-02-29	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13958	delivery	5	54
35099	2020-02-29 04:30:50	2020-02-29	9	[{"id_menu":7,"count":1}]	13967	delivery	5	14
35100	2020-02-29 04:33:57	2020-02-29	14	[{"id_menu":2,"count":1}]	7428	delivery	5	19
35101	2020-02-29 04:34:21	2020-02-29	9	[{"id_menu":7,"count":1}]	13859	pick-up	0	9
35102	2020-02-29 04:34:23	2020-02-29	12	[{"id_menu":1,"count":1}]	12854	delivery	5	17
35103	2020-02-29 04:35:25	2020-02-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5707	delivery	5	22
35104	2020-02-29 04:38:11	2020-02-29	17	[{"id_menu":4,"count":1}]	1780	pick-up	0	17
35105	2020-02-29 04:43:03	2020-02-29	14	[{"id_menu":2,"count":1}]	13897	delivery	5	19
35106	2020-02-29 04:43:38	2020-02-29	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	13935	delivery	5	26
35107	2020-02-29 04:49:36	2020-02-29	17	[{"id_menu":4,"count":1}]	1309	pick-up	0	17
35108	2020-02-29 04:50:41	2020-02-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	7444	delivery	5	26
35109	2020-02-29 04:51:15	2020-02-29	12	[{"id_menu":3,"count":1}]	5134	pick-up	0	12
35110	2020-02-29 04:51:28	2020-02-29	9	[{"id_menu":7,"count":1}]	9542	pick-up	0	9
35111	2020-02-29 04:59:48	2020-02-29	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	612	pick-up	0	32
35112	2020-02-29 05:15:45	2020-02-29	17	[{"id_menu":4,"count":1}]	13883	pick-up	0	17
35113	2020-02-29 05:16:59	2020-02-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	11444	pick-up	0	22
35114	2020-02-29 05:18:12	2020-02-29	17	[{"id_menu":4,"count":1}]	6841	pick-up	0	17
35115	2020-02-29 05:24:58	2020-02-29	12	[{"id_menu":1,"count":1}]	154	pick-up	0	12
35116	2020-02-29 05:26:26	2020-02-29	33	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	5396	delivery	5	38
35117	2020-02-29 05:36:05	2020-02-29	9	[{"id_menu":6,"count":3}]	5762	delivery	5	14
35118	2020-02-29 05:37:00	2020-02-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	6090	pick-up	0	22
35120	2020-02-29 05:50:57	2020-02-29	17	[{"id_menu":4,"count":1}]	13885	delivery	5	22
35121	2020-02-29 06:05:53	2020-02-29	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	13987	delivery	5	40
35122	2020-02-29 06:09:27	2020-02-29	9	[{"id_menu":7,"count":1}]	2573	pick-up	0	9
35123	2020-02-29 06:10:04	2020-02-29	9	[{"id_menu":6,"count":1}]	13928	delivery	5	14
35124	2020-02-29 06:10:59	2020-02-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	13988	delivery	5	28
35125	2020-02-29 06:13:17	2020-02-29	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	13188	delivery	5	34
35126	2020-02-29 06:16:08	2020-02-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	9783	delivery	5	28
35127	2020-02-29 06:21:16	2020-02-29	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	13971	delivery	5	40
35128	2020-02-29 06:24:23	2020-02-29	17	[{"id_menu":4,"count":1}]	4157	pick-up	0	17
35129	2020-02-29 06:27:50	2020-02-29	9	[{"id_menu":6,"count":1}]	11254	delivery	5	14
35130	2020-02-29 06:31:42	2020-02-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7058	delivery	5	28
35131	2020-02-29 06:33:06	2020-02-29	12	[{"id_menu":1,"count":1}]	4854	delivery	5	17
35132	2020-02-29 06:38:19	2020-02-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	7387	delivery	5	22
35133	2020-02-29 06:38:50	2020-02-29	17	[{"id_menu":4,"count":1}]	8474	pick-up	0	17
35134	2020-02-29 06:47:02	2020-02-29	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	7050	pick-up	0	26
35135	2020-02-29 06:53:25	2020-02-29	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1705	pick-up	0	43
35136	2020-02-29 06:53:27	2020-02-29	14	[{"id_menu":2,"count":1}]	8205	delivery	5	19
35137	2020-02-29 06:54:56	2020-02-29	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	3298	delivery	5	36
35138	2020-02-29 07:00:54	2020-02-29	14	[{"id_menu":2,"count":1}]	13909	delivery	5	19
35139	2020-02-29 07:12:04	2020-02-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10517	delivery	5	23
35140	2020-02-29 07:12:24	2020-02-29	12	[{"id_menu":1,"count":1}]	10835	delivery	5	17
35141	2020-02-29 07:21:13	2020-02-29	12	[{"id_menu":1,"count":1}]	12124	delivery	5	17
35142	2020-02-29 07:21:13	2020-02-29	12	[{"id_menu":3,"count":1}]	1168	delivery	5	17
35143	2020-02-29 07:24:56	2020-02-29	12	[{"id_menu":3,"count":1}]	953	pick-up	0	12
35144	2020-02-29 07:25:25	2020-02-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4631	delivery	5	22
35145	2020-02-29 07:27:15	2020-02-29	14	[{"id_menu":2,"count":1}]	13957	pick-up	0	14
35146	2020-02-29 07:27:16	2020-02-29	12	[{"id_menu":3,"count":1}]	5958	pick-up	0	12
35147	2020-02-29 07:27:23	2020-02-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5857	pick-up	0	23
35148	2020-02-29 07:28:31	2020-02-29	12	[{"id_menu":3,"count":2}]	13936	delivery	5	17
35149	2020-02-29 07:29:01	2020-02-29	9	[{"id_menu":7,"count":1}]	13882	delivery	5	14
35150	2020-02-29 07:36:38	2020-02-29	14	[{"id_menu":2,"count":1}]	9688	pick-up	0	14
35151	2020-02-29 07:38:40	2020-02-29	9	[{"id_menu":7,"count":1}]	10156	delivery	5	14
35152	2020-02-29 07:38:50	2020-02-29	17	[{"id_menu":4,"count":1}]	13955	delivery	5	22
35153	2020-02-29 07:46:18	2020-02-29	12	[{"id_menu":3,"count":1}]	11736	pick-up	0	12
35154	2020-02-29 07:47:59	2020-02-29	9	[{"id_menu":7,"count":1}]	4436	pick-up	0	9
35155	2020-02-29 07:53:46	2020-02-29	9	[{"id_menu":7,"count":1}]	12240	pick-up	0	9
35156	2020-02-29 07:57:06	2020-02-29	9	[{"id_menu":7,"count":1}]	13906	delivery	5	14
35157	2020-02-29 08:04:28	2020-02-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13872	delivery	5	22
35158	2020-02-29 08:05:21	2020-02-29	9	[{"id_menu":6,"count":1}]	13656	pick-up	0	9
35159	2020-02-29 08:05:58	2020-02-29	14	[{"id_menu":2,"count":1}]	12827	delivery	5	19
35160	2020-02-29 08:06:34	2020-02-29	14	[{"id_menu":2,"count":1}]	8276	delivery	5	19
35161	2020-02-29 08:07:03	2020-02-29	12	[{"id_menu":3,"count":1}]	13942	delivery	5	17
35162	2020-02-29 08:12:37	2020-02-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	13870	delivery	5	36
35163	2020-02-29 08:18:03	2020-02-29	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5297	delivery	5	35
35164	2020-02-29 08:20:13	2020-02-29	12	[{"id_menu":1,"count":1}]	13863	delivery	5	17
35165	2020-02-29 08:24:47	2020-02-29	17	[{"id_menu":4,"count":2}]	7280	delivery	5	22
35166	2020-02-29 08:25:23	2020-02-29	9	[{"id_menu":6,"count":1}]	655	pick-up	0	9
35167	2020-02-29 08:29:57	2020-02-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4622	delivery	5	28
35168	2020-02-29 08:31:18	2020-02-29	14	[{"id_menu":2,"count":1}]	7766	pick-up	0	14
35169	2020-02-29 08:33:48	2020-02-29	12	[{"id_menu":3,"count":1}]	13901	delivery	5	17
35170	2020-02-29 08:41:44	2020-02-29	8	[{"id_menu":5,"count":1}]	13890	delivery	5	13
35171	2020-02-29 08:42:18	2020-02-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13865	delivery	5	23
35172	2020-02-29 08:51:56	2020-02-29	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	5095	delivery	5	31
35173	2020-02-29 08:52:22	2020-02-29	12	[{"id_menu":3,"count":1}]	11656	delivery	5	17
35174	2020-02-29 09:01:51	2020-02-29	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	9716	pick-up	0	31
35175	2020-02-29 09:03:20	2020-02-29	8	[{"id_menu":5,"count":2}]	9810	delivery	5	13
35176	2020-02-29 09:06:59	2020-02-29	12	[{"id_menu":3,"count":1}]	13799	pick-up	0	12
35177	2020-02-29 09:12:57	2020-02-29	9	[{"id_menu":6,"count":1}]	11491	pick-up	0	9
35178	2020-02-29 09:16:31	2020-02-29	9	[{"id_menu":7,"count":1}]	11739	delivery	5	14
35179	2020-02-29 09:21:18	2020-02-29	14	[{"id_menu":2,"count":1}]	11172	delivery	5	19
35180	2020-02-29 09:26:43	2020-02-29	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	13953	delivery	5	26
35181	2020-02-29 09:33:54	2020-02-29	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13929	delivery	5	31
35182	2020-02-29 09:35:12	2020-02-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13908	pick-up	0	18
35183	2020-02-29 09:46:44	2020-02-29	9	[{"id_menu":6,"count":1}]	12362	pick-up	0	9
35184	2020-02-29 09:54:56	2020-02-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	3165	delivery	5	26
35185	2020-02-29 09:55:37	2020-02-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":3}]	11382	delivery	5	22
35186	2020-02-29 09:55:48	2020-02-29	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	5440	pick-up	0	43
35187	2020-02-29 10:13:07	2020-02-29	14	[{"id_menu":2,"count":1}]	13954	delivery	5	19
35188	2020-02-29 10:25:34	2020-02-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13968	delivery	5	31
35189	2020-02-29 10:27:18	2020-02-29	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2647	delivery	5	37
35190	2020-02-29 10:27:22	2020-02-29	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	11973	delivery	5	26
35191	2020-02-29 10:34:27	2020-02-29	9	[{"id_menu":6,"count":1}]	13867	delivery	5	14
35192	2020-02-29 10:35:46	2020-02-29	9	[{"id_menu":6,"count":1}]	13889	delivery	5	14
35193	2020-02-29 10:35:51	2020-02-29	12	[{"id_menu":3,"count":1}]	13980	delivery	5	17
35194	2020-02-29 10:42:42	2020-02-29	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5385	delivery	5	39
35195	2020-02-29 10:42:59	2020-02-29	17	[{"id_menu":4,"count":1}]	9348	pick-up	0	17
35196	2020-02-29 10:44:20	2020-02-29	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11096	delivery	5	51
35197	2020-02-29 10:44:28	2020-02-29	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13975	delivery	5	31
35198	2020-02-29 11:00:11	2020-02-29	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13036	delivery	5	35
35199	2020-02-29 11:06:00	2020-02-29	12	[{"id_menu":3,"count":1}]	11402	delivery	5	17
35200	2020-02-29 11:07:05	2020-02-29	9	[{"id_menu":7,"count":1}]	6604	delivery	5	14
35201	2020-02-29 11:11:19	2020-02-29	17	[{"id_menu":4,"count":1}]	13910	pick-up	0	17
35202	2020-02-29 11:41:43	2020-02-29	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2110	delivery	5	30
35203	2020-02-29 11:45:58	2020-02-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	13974	delivery	5	26
35204	2020-02-29 11:53:58	2020-02-29	14	[{"id_menu":2,"count":1}]	2511	delivery	5	19
35205	2020-02-29 12:07:55	2020-02-29	8	[{"id_menu":5,"count":1}]	13964	delivery	5	13
35206	2020-02-29 12:12:45	2020-02-29	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	4090	pick-up	0	21
35207	2020-02-29 12:13:03	2020-02-29	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1156	pick-up	0	31
35208	2020-02-29 12:21:17	2020-02-29	14	[{"id_menu":2,"count":1}]	7427	delivery	5	19
35209	2020-02-29 12:22:29	2020-02-29	8	[{"id_menu":5,"count":1}]	13977	delivery	5	13
35210	2020-02-29 12:31:47	2020-02-29	9	[{"id_menu":6,"count":1}]	10575	delivery	5	14
35211	2020-02-29 12:43:42	2020-02-29	17	[{"id_menu":4,"count":1}]	13969	delivery	5	22
35212	2020-02-29 12:45:03	2020-02-29	9	[{"id_menu":6,"count":1}]	5538	pick-up	0	9
35213	2020-02-29 12:50:09	2020-02-29	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	13913	pick-up	0	21
35214	2020-02-29 12:52:05	2020-02-29	8	[{"id_menu":5,"count":1}]	6947	delivery	5	13
35215	2020-02-29 13:02:54	2020-02-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13956	delivery	5	23
35216	2020-02-29 13:04:05	2020-02-29	9	[{"id_menu":6,"count":2}]	3768	delivery	5	14
35217	2020-02-29 13:05:44	2020-02-29	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2378	pick-up	0	29
35218	2020-02-29 13:11:08	2020-02-29	17	[{"id_menu":4,"count":1}]	13922	delivery	5	22
35219	2020-02-29 13:21:45	2020-02-29	12	[{"id_menu":1,"count":1}]	9778	delivery	5	17
35220	2020-02-29 13:23:44	2020-02-29	9	[{"id_menu":7,"count":1}]	1618	pick-up	0	9
35221	2020-02-29 13:26:20	2020-02-29	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	13900	delivery	5	34
35222	2020-02-29 13:29:35	2020-02-29	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	7688	delivery	5	26
35223	2020-02-29 13:44:02	2020-02-29	12	[{"id_menu":3,"count":1}]	13981	delivery	5	17
35224	2020-02-29 13:46:36	2020-02-29	9	[{"id_menu":7,"count":1}]	9207	delivery	5	14
35225	2020-02-29 13:50:13	2020-02-29	12	[{"id_menu":1,"count":1}]	5232	pick-up	0	12
35226	2020-02-29 13:51:56	2020-02-29	12	[{"id_menu":3,"count":1}]	2891	delivery	5	17
35227	2020-02-29 13:54:03	2020-02-29	9	[{"id_menu":6,"count":1}]	12602	pick-up	0	9
35228	2020-02-29 14:15:57	2020-02-29	9	[{"id_menu":7,"count":1}]	2641	pick-up	0	9
35229	2020-02-29 14:19:19	2020-02-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13899	delivery	5	31
35230	2020-02-29 14:25:53	2020-02-29	14	[{"id_menu":2,"count":1}]	5318	delivery	5	19
35231	2020-02-29 14:26:23	2020-02-29	12	[{"id_menu":1,"count":1}]	13871	delivery	5	17
35232	2020-02-29 14:29:00	2020-02-29	9	[{"id_menu":6,"count":1}]	4021	pick-up	0	9
35233	2020-02-29 14:30:27	2020-02-29	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	9845	delivery	5	44
35234	2020-02-29 14:32:04	2020-02-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13544	delivery	5	22
35235	2020-02-29 14:41:34	2020-02-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	13943	delivery	5	26
35236	2020-02-29 14:59:07	2020-02-29	14	[{"id_menu":2,"count":1}]	13874	delivery	5	19
35237	2020-02-29 15:00:33	2020-02-29	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	13903	delivery	5	36
35238	2020-02-29 15:05:41	2020-02-29	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7358	delivery	5	35
35239	2020-02-29 15:19:24	2020-02-29	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	9420	pick-up	0	31
35240	2020-02-29 15:20:29	2020-02-29	8	[{"id_menu":5,"count":1}]	13952	delivery	5	13
35241	2020-02-29 15:23:55	2020-02-29	9	[{"id_menu":6,"count":1}]	3767	delivery	5	14
35242	2020-02-29 15:29:08	2020-02-29	9	[{"id_menu":6,"count":1}]	13432	delivery	5	14
35243	2020-02-29 15:31:34	2020-02-29	9	[{"id_menu":6,"count":1}]	10177	pick-up	0	9
35244	2020-02-29 15:32:33	2020-02-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	7431	delivery	5	23
35245	2020-02-29 15:36:32	2020-02-29	14	[{"id_menu":2,"count":1}]	1155	pick-up	0	14
35246	2020-02-29 15:40:19	2020-02-29	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13927	delivery	5	34
35247	2020-02-29 15:40:29	2020-02-29	9	[{"id_menu":6,"count":1}]	13946	delivery	5	14
35248	2020-02-29 15:41:01	2020-02-29	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3731	delivery	5	36
35249	2020-02-29 15:43:10	2020-02-29	8	[{"id_menu":5,"count":1}]	13919	delivery	5	13
35250	2020-02-29 15:44:47	2020-02-29	9	[{"id_menu":6,"count":1}]	13970	delivery	5	14
35251	2020-02-29 15:51:39	2020-02-29	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	3534	delivery	5	26
35252	2020-02-29 15:53:06	2020-02-29	14	[{"id_menu":2,"count":1}]	7696	delivery	5	19
35253	2020-02-29 15:53:40	2020-02-29	14	[{"id_menu":2,"count":1}]	8877	delivery	5	19
35254	2020-02-29 16:05:05	2020-02-29	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10321	delivery	5	39
35255	2020-02-29 16:05:19	2020-02-29	14	[{"id_menu":2,"count":1}]	2282	delivery	5	19
35256	2020-02-29 16:07:36	2020-02-29	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	13965	delivery	5	29
35257	2020-02-29 16:09:19	2020-02-29	14	[{"id_menu":2,"count":1}]	13875	delivery	5	19
35258	2020-02-29 16:09:35	2020-02-29	9	[{"id_menu":7,"count":1}]	13960	delivery	5	14
35259	2020-02-29 16:13:46	2020-02-29	17	[{"id_menu":4,"count":1}]	11183	delivery	5	22
35260	2020-02-29 16:16:02	2020-02-29	12	[{"id_menu":3,"count":1}]	8986	delivery	5	17
35261	2020-02-29 16:29:08	2020-02-29	8	[{"id_menu":5,"count":2}]	5861	delivery	5	13
35262	2020-02-29 16:38:45	2020-02-29	12	[{"id_menu":1,"count":1}]	13917	pick-up	0	12
35263	2020-02-29 16:39:23	2020-02-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10729	delivery	5	36
35264	2020-02-29 16:42:46	2020-02-29	9	[{"id_menu":7,"count":1}]	3545	delivery	5	14
35265	2020-02-29 16:52:20	2020-02-29	9	[{"id_menu":7,"count":1}]	13912	delivery	5	14
35266	2020-02-29 16:58:54	2020-02-29	14	[{"id_menu":2,"count":1}]	13891	delivery	5	19
35267	2020-02-29 16:59:09	2020-02-29	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13941	delivery	5	43
35268	2020-02-29 17:02:38	2020-02-29	14	[{"id_menu":2,"count":1}]	5856	pick-up	0	14
35269	2020-02-29 17:06:27	2020-02-29	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":2}]	5714	delivery	5	22
35270	2020-02-29 17:10:09	2020-02-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	11560	delivery	5	28
35271	2020-02-29 17:11:43	2020-02-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	6729	delivery	5	26
35272	2020-02-29 17:22:49	2020-02-29	9	[{"id_menu":7,"count":1}]	2806	delivery	5	14
35273	2020-02-29 17:23:55	2020-02-29	29	[{"id_menu":3,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13924	delivery	5	34
35274	2020-02-29 17:30:06	2020-02-29	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	3332	delivery	5	25
35275	2020-02-29 17:37:56	2020-02-29	12	[{"id_menu":1,"count":1}]	3069	pick-up	0	12
35276	2020-02-29 17:41:18	2020-02-29	9	[{"id_menu":7,"count":1}]	13986	delivery	5	14
35277	2020-02-29 17:44:45	2020-02-29	12	[{"id_menu":3,"count":1}]	12552	delivery	5	17
35278	2020-02-29 17:51:21	2020-02-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	6864	delivery	5	22
35279	2020-02-29 17:51:46	2020-02-29	12	[{"id_menu":3,"count":1}]	13951	pick-up	0	12
35280	2020-02-29 18:01:46	2020-02-29	14	[{"id_menu":2,"count":1}]	13923	pick-up	0	14
35281	2020-02-29 18:08:43	2020-02-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	696	delivery	5	26
35282	2020-02-29 18:13:49	2020-02-29	12	[{"id_menu":1,"count":1}]	13915	delivery	5	17
35283	2020-02-29 18:15:07	2020-02-29	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13959	delivery	5	40
35284	2020-02-29 18:17:34	2020-02-29	9	[{"id_menu":7,"count":1}]	10790	pick-up	0	9
35285	2020-02-29 18:21:52	2020-02-29	9	[{"id_menu":6,"count":1}]	4577	delivery	5	14
35286	2020-02-29 18:26:18	2020-02-29	9	[{"id_menu":7,"count":1}]	8722	delivery	5	14
35287	2020-02-29 18:28:37	2020-02-29	14	[{"id_menu":2,"count":1}]	7825	delivery	5	19
35288	2020-02-29 18:30:27	2020-02-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10807	pick-up	0	18
35289	2020-02-29 18:33:53	2020-02-29	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	13914	delivery	5	44
35290	2020-02-29 18:36:27	2020-02-29	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	13880	delivery	5	36
35291	2020-02-29 18:40:01	2020-02-29	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	13905	delivery	5	26
35292	2020-02-29 18:41:50	2020-02-29	17	[{"id_menu":4,"count":1}]	13939	pick-up	0	17
35293	2020-02-29 18:43:17	2020-02-29	12	[{"id_menu":3,"count":1}]	13933	delivery	5	17
35294	2020-02-29 18:43:22	2020-02-29	9	[{"id_menu":6,"count":1}]	373	delivery	5	14
35295	2020-02-29 18:46:03	2020-02-29	14	[{"id_menu":2,"count":1}]	13937	delivery	5	19
35296	2020-02-29 18:47:28	2020-02-29	12	[{"id_menu":1,"count":1}]	13979	delivery	5	17
35297	2020-02-29 18:52:39	2020-02-29	17	[{"id_menu":4,"count":1}]	2530	pick-up	0	17
35298	2020-02-29 18:56:19	2020-02-29	12	[{"id_menu":3,"count":1}]	2080	pick-up	0	12
35299	2020-02-29 18:56:20	2020-02-29	17	[{"id_menu":4,"count":1}]	7678	pick-up	0	17
35300	2020-02-29 18:58:34	2020-02-29	8	[{"id_menu":5,"count":2}]	13887	delivery	5	13
35301	2020-02-29 19:00:52	2020-02-29	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13948	delivery	5	37
35302	2020-02-29 19:05:51	2020-02-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13888	pick-up	0	17
35303	2020-02-29 19:07:38	2020-02-29	14	[{"id_menu":2,"count":1}]	13896	delivery	5	19
35304	2020-02-29 19:10:55	2020-02-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	6066	delivery	5	27
35305	2020-02-29 19:17:14	2020-02-29	8	[{"id_menu":5,"count":1}]	13961	delivery	5	13
35306	2020-02-29 19:21:37	2020-02-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13504	delivery	5	23
35307	2020-02-29 19:23:02	2020-02-29	17	[{"id_menu":4,"count":1}]	2440	delivery	5	22
35308	2020-02-29 19:25:39	2020-02-29	17	[{"id_menu":4,"count":1}]	6141	delivery	5	22
35309	2020-02-29 19:30:06	2020-02-29	12	[{"id_menu":3,"count":1}]	2424	delivery	5	17
35310	2020-02-29 19:30:44	2020-02-29	9	[{"id_menu":7,"count":1}]	13877	delivery	5	14
35311	2020-02-29 19:34:34	2020-02-29	9	[{"id_menu":7,"count":1}]	9794	delivery	5	14
35312	2020-02-29 19:40:31	2020-02-29	8	[{"id_menu":5,"count":1}]	13902	delivery	5	13
35313	2020-02-29 19:53:16	2020-02-29	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	8333	delivery	5	34
35314	2020-02-29 19:55:28	2020-02-29	9	[{"id_menu":6,"count":1}]	13963	pick-up	0	9
35315	2020-02-29 19:55:54	2020-02-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9645	delivery	5	31
35316	2020-02-29 19:55:57	2020-02-29	17	[{"id_menu":4,"count":2}]	13860	delivery	5	22
35317	2020-02-29 19:57:43	2020-02-29	9	[{"id_menu":6,"count":1}]	12254	delivery	5	14
35318	2020-02-29 19:59:32	2020-02-29	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10401	delivery	5	57
35319	2020-02-29 20:00:50	2020-02-29	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	13940	pick-up	0	29
35320	2020-02-29 20:04:32	2020-02-29	14	[{"id_menu":2,"count":1}]	7190	pick-up	0	14
35321	2020-02-29 20:05:15	2020-02-29	8	[{"id_menu":5,"count":1}]	9683	delivery	5	13
35322	2020-02-29 20:07:04	2020-02-29	17	[{"id_menu":4,"count":1}]	1391	delivery	5	22
35323	2020-02-29 20:08:23	2020-02-29	9	[{"id_menu":7,"count":1}]	13886	delivery	5	14
35324	2020-02-29 20:08:26	2020-02-29	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	3776	delivery	5	34
35325	2020-02-29 20:08:51	2020-02-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13944	delivery	5	36
35326	2020-02-29 20:12:24	2020-02-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	304	pick-up	0	17
35327	2020-02-29 20:15:05	2020-02-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	3688	delivery	5	26
35328	2020-02-29 20:19:25	2020-02-29	8	[{"id_menu":5,"count":1}]	701	pick-up	0	8
35329	2020-02-29 20:36:02	2020-02-29	14	[{"id_menu":2,"count":1}]	9059	pick-up	0	14
35330	2020-02-29 20:36:25	2020-02-29	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	5669	delivery	5	23
35331	2020-02-29 20:36:59	2020-02-29	8	[{"id_menu":5,"count":2}]	2828	pick-up	0	8
35332	2020-02-29 20:38:46	2020-02-29	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1902	delivery	5	30
35333	2020-02-29 20:40:00	2020-02-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":3}]	2819	delivery	5	27
35334	2020-02-29 20:40:45	2020-02-29	17	[{"id_menu":4,"count":1}]	7814	pick-up	0	17
35335	2020-02-29 20:44:57	2020-02-29	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	1316	delivery	5	26
35336	2020-02-29 20:51:08	2020-02-29	17	[{"id_menu":4,"count":1}]	13898	delivery	5	22
35337	2020-02-29 20:52:41	2020-02-29	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	13892	delivery	5	38
35338	2020-02-29 20:53:17	2020-02-29	12	[{"id_menu":3,"count":1}]	2714	delivery	5	17
35339	2020-02-29 20:58:15	2020-02-29	14	[{"id_menu":2,"count":1}]	5056	delivery	5	19
35340	2020-02-29 21:04:36	2020-02-29	9	[{"id_menu":7,"count":1}]	13985	delivery	5	14
35341	2020-02-29 21:05:05	2020-02-29	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	5301	delivery	5	38
35342	2020-02-29 21:06:59	2020-02-29	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12717	pick-up	0	35
35343	2020-02-29 21:08:33	2020-02-29	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	13966	delivery	5	27
35344	2020-02-29 21:08:45	2020-02-29	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	13983	delivery	5	31
35345	2020-02-29 21:12:00	2020-02-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4607	pick-up	0	23
35346	2020-02-29 21:14:54	2020-02-29	8	[{"id_menu":5,"count":1}]	9497	delivery	5	13
35347	2020-02-29 21:28:41	2020-02-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10494	delivery	5	23
35348	2020-02-29 21:31:39	2020-02-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7510	pick-up	0	18
35349	2020-02-29 21:32:34	2020-02-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7803	delivery	5	23
35350	2020-02-29 21:37:15	2020-02-29	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	13907	delivery	5	31
35351	2020-02-29 21:39:36	2020-02-29	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	788	pick-up	0	25
35352	2020-02-29 21:54:23	2020-02-29	12	[{"id_menu":1,"count":1}]	3906	pick-up	0	12
35353	2020-02-29 21:54:34	2020-02-29	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	11583	delivery	5	43
35354	2020-02-29 21:57:18	2020-02-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13921	delivery	5	36
35355	2020-02-29 22:03:00	2020-02-29	14	[{"id_menu":2,"count":1}]	13938	delivery	5	19
35356	2020-02-29 22:05:49	2020-02-29	14	[{"id_menu":2,"count":1}]	677	delivery	5	19
35357	2020-02-29 22:09:40	2020-02-29	9	[{"id_menu":6,"count":1}]	13861	delivery	5	14
35358	2020-02-29 22:09:57	2020-02-29	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13916	delivery	5	54
35359	2020-02-29 22:11:37	2020-02-29	14	[{"id_menu":2,"count":1}]	5135	delivery	5	19
35360	2020-02-29 22:22:28	2020-02-29	9	[{"id_menu":6,"count":1}]	8798	delivery	5	14
35361	2020-02-29 22:25:45	2020-02-29	17	[{"id_menu":4,"count":1}]	13949	delivery	5	22
35362	2020-02-29 22:26:29	2020-02-29	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5823	delivery	5	48
35363	2020-02-29 22:27:28	2020-02-29	17	[{"id_menu":4,"count":1}]	8815	delivery	5	22
35364	2020-02-29 22:28:33	2020-02-29	9	[{"id_menu":6,"count":1}]	13932	delivery	5	14
35365	2020-02-29 22:29:34	2020-02-29	9	[{"id_menu":7,"count":1}]	13878	delivery	5	14
35366	2020-02-29 22:34:44	2020-02-29	12	[{"id_menu":1,"count":1}]	1962	delivery	5	17
35367	2020-02-29 22:35:20	2020-02-29	9	[{"id_menu":6,"count":1}]	1485	pick-up	0	9
35368	2020-02-29 22:35:21	2020-02-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	271	pick-up	0	21
35369	2020-02-29 22:38:14	2020-02-29	17	[{"id_menu":4,"count":2}]	1929	pick-up	0	17
35370	2020-02-29 22:40:57	2020-02-29	8	[{"id_menu":5,"count":1}]	13410	pick-up	0	8
35371	2020-02-29 22:41:18	2020-02-29	8	[{"id_menu":5,"count":1}]	2187	pick-up	0	8
35372	2020-02-29 22:42:02	2020-02-29	9	[{"id_menu":7,"count":1}]	1224	delivery	5	14
35373	2020-02-29 22:54:21	2020-02-29	9	[{"id_menu":7,"count":1}]	13895	delivery	5	14
35374	2020-02-29 22:54:23	2020-02-29	9	[{"id_menu":6,"count":1}]	13869	delivery	5	14
35375	2020-02-29 22:54:24	2020-02-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	13667	delivery	5	26
35376	2020-02-29 22:56:47	2020-02-29	17	[{"id_menu":4,"count":1}]	8471	pick-up	0	17
35377	2020-02-29 22:57:07	2020-02-29	17	[{"id_menu":4,"count":1}]	9711	delivery	5	22
35378	2020-02-29 23:03:33	2020-02-29	9	[{"id_menu":6,"count":1}]	13904	delivery	5	14
35379	2020-02-29 23:05:07	2020-02-29	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7641	delivery	5	31
35380	2020-02-29 23:11:42	2020-02-29	9	[{"id_menu":7,"count":1}]	7623	delivery	5	14
35381	2020-02-29 23:11:51	2020-02-29	12	[{"id_menu":3,"count":1}]	207	pick-up	0	12
35382	2020-02-29 23:15:52	2020-02-29	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11283	delivery	5	37
35383	2020-02-29 23:17:46	2020-02-29	43	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	13984	pick-up	0	43
35384	2020-02-29 23:19:27	2020-02-29	9	[{"id_menu":7,"count":1}]	6549	delivery	5	14
35385	2020-02-29 23:20:41	2020-02-29	9	[{"id_menu":6,"count":1}]	13918	delivery	5	14
35386	2020-02-29 23:24:45	2020-02-29	8	[{"id_menu":5,"count":1}]	13170	delivery	5	13
35387	2020-02-29 23:29:50	2020-02-29	9	[{"id_menu":7,"count":1}]	13926	pick-up	0	9
35388	2020-02-29 23:29:54	2020-02-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13864	delivery	5	31
35389	2020-02-29 23:39:13	2020-02-29	9	[{"id_menu":6,"count":1}]	5311	delivery	5	14
35390	2020-02-29 23:45:40	2020-02-29	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	3211	delivery	5	25
35391	2020-02-29 23:49:19	2020-02-29	17	[{"id_menu":4,"count":1}]	1401	pick-up	0	17
35392	2020-02-29 23:53:50	2020-02-29	9	[{"id_menu":6,"count":1}]	7303	delivery	5	14
35393	2020-02-29 23:57:13	2020-02-29	9	[{"id_menu":6,"count":1}]	13873	pick-up	0	9
35394	2020-03-01 00:00:30	2020-03-01	8	[{"id_menu":5,"count":1}]	14069	delivery	5	13
35395	2020-03-01 00:01:16	2020-03-01	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6272	delivery	5	47
35396	2020-03-01 00:02:28	2020-03-01	12	[{"id_menu":3,"count":1}]	14010	pick-up	0	12
35397	2020-03-01 00:06:20	2020-03-01	8	[{"id_menu":5,"count":1}]	14093	delivery	5	13
35398	2020-03-01 00:08:57	2020-03-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	14002	pick-up	0	31
35399	2020-03-01 00:19:42	2020-03-01	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12823	delivery	5	31
35400	2020-03-01 00:20:44	2020-03-01	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	9300	delivery	5	28
35401	2020-03-01 00:22:39	2020-03-01	9	[{"id_menu":6,"count":1}]	10820	delivery	5	14
35402	2020-03-01 00:25:33	2020-03-01	12	[{"id_menu":3,"count":1}]	14012	pick-up	0	12
35403	2020-03-01 00:33:22	2020-03-01	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	12993	delivery	5	34
35404	2020-03-01 00:34:38	2020-03-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":3}]	6482	delivery	5	22
35405	2020-03-01 00:35:11	2020-03-01	12	[{"id_menu":1,"count":1}]	14036	delivery	5	17
35406	2020-03-01 00:35:13	2020-03-01	17	[{"id_menu":4,"count":1}]	14079	delivery	5	22
35407	2020-03-01 00:39:19	2020-03-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4846	delivery	5	31
35408	2020-03-01 00:40:12	2020-03-01	14	[{"id_menu":2,"count":1}]	457	pick-up	0	14
35409	2020-03-01 00:40:39	2020-03-01	8	[{"id_menu":5,"count":1}]	14045	delivery	5	13
35410	2020-03-01 00:41:50	2020-03-01	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9198	pick-up	0	48
35411	2020-03-01 00:56:18	2020-03-01	12	[{"id_menu":1,"count":1}]	2867	pick-up	0	12
35412	2020-03-01 00:57:47	2020-03-01	14	[{"id_menu":2,"count":1}]	1157	pick-up	0	14
35413	2020-03-01 01:00:57	2020-03-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6848	delivery	5	28
35414	2020-03-01 01:01:34	2020-03-01	8	[{"id_menu":5,"count":1}]	6511	pick-up	0	8
35415	2020-03-01 01:01:47	2020-03-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1313	pick-up	0	21
35416	2020-03-01 01:05:22	2020-03-01	14	[{"id_menu":2,"count":1}]	314	delivery	5	19
35417	2020-03-01 01:08:57	2020-03-01	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1295	pick-up	0	26
35418	2020-03-01 01:12:15	2020-03-01	12	[{"id_menu":3,"count":1}]	2470	pick-up	0	12
35419	2020-03-01 01:12:49	2020-03-01	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	14072	delivery	5	26
35420	2020-03-01 01:13:24	2020-03-01	12	[{"id_menu":3,"count":1}]	10694	pick-up	0	12
35421	2020-03-01 01:19:37	2020-03-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	12285	pick-up	0	23
35422	2020-03-01 01:20:54	2020-03-01	8	[{"id_menu":5,"count":1}]	9711	delivery	5	13
35423	2020-03-01 01:24:01	2020-03-01	17	[{"id_menu":4,"count":1}]	2889	delivery	5	22
35424	2020-03-01 01:24:33	2020-03-01	8	[{"id_menu":5,"count":1}]	4130	pick-up	0	8
35425	2020-03-01 01:30:21	2020-03-01	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	9913	pick-up	0	40
35426	2020-03-01 01:37:24	2020-03-01	9	[{"id_menu":6,"count":1}]	6429	delivery	5	14
35427	2020-03-01 01:41:27	2020-03-01	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6851	pick-up	0	44
35428	2020-03-01 01:43:07	2020-03-01	12	[{"id_menu":1,"count":1}]	12156	delivery	5	17
35429	2020-03-01 01:47:03	2020-03-01	9	[{"id_menu":6,"count":1}]	6799	delivery	5	14
35430	2020-03-01 01:54:53	2020-03-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	9525	delivery	5	28
35431	2020-03-01 01:58:16	2020-03-01	9	[{"id_menu":7,"count":1}]	1453	delivery	5	14
35432	2020-03-01 02:07:39	2020-03-01	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5767	delivery	5	37
35433	2020-03-01 02:10:27	2020-03-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	11507	delivery	5	28
35434	2020-03-01 02:14:31	2020-03-01	9	[{"id_menu":6,"count":1}]	8543	pick-up	0	9
35435	2020-03-01 02:20:33	2020-03-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	4836	delivery	5	26
35436	2020-03-01 02:22:18	2020-03-01	9	[{"id_menu":7,"count":2}]	2897	delivery	5	14
35437	2020-03-01 02:23:03	2020-03-01	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	13634	delivery	5	42
35438	2020-03-01 02:25:50	2020-03-01	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	2337	delivery	5	31
35439	2020-03-01 02:37:51	2020-03-01	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	14046	delivery	5	26
35440	2020-03-01 02:43:39	2020-03-01	9	[{"id_menu":7,"count":1}]	6975	pick-up	0	9
35441	2020-03-01 02:50:36	2020-03-01	9	[{"id_menu":6,"count":1}]	7279	delivery	5	14
35442	2020-03-01 02:52:10	2020-03-01	12	[{"id_menu":1,"count":3}]	11434	delivery	5	17
35443	2020-03-01 02:56:25	2020-03-01	9	[{"id_menu":6,"count":1}]	14095	delivery	5	14
35444	2020-03-01 02:59:59	2020-03-01	8	[{"id_menu":5,"count":1}]	707	pick-up	0	8
35445	2020-03-01 03:08:38	2020-03-01	8	[{"id_menu":5,"count":1}]	3570	pick-up	0	8
35446	2020-03-01 03:15:26	2020-03-01	14	[{"id_menu":2,"count":1}]	7718	pick-up	0	14
35447	2020-03-01 03:15:29	2020-03-01	14	[{"id_menu":2,"count":1}]	11449	pick-up	0	14
35448	2020-03-01 03:20:37	2020-03-01	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	13991	delivery	5	26
35449	2020-03-01 03:24:36	2020-03-01	17	[{"id_menu":4,"count":1}]	2878	delivery	5	22
35450	2020-03-01 03:24:57	2020-03-01	12	[{"id_menu":1,"count":1}]	1742	delivery	5	17
35451	2020-03-01 03:26:54	2020-03-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4589	delivery	5	23
35452	2020-03-01 03:29:35	2020-03-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13586	delivery	5	22
35453	2020-03-01 03:31:10	2020-03-01	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	14042	pick-up	0	21
35454	2020-03-01 03:34:48	2020-03-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	12274	delivery	5	36
35455	2020-03-01 03:38:39	2020-03-01	8	[{"id_menu":5,"count":1}]	12889	pick-up	0	8
35456	2020-03-01 03:39:00	2020-03-01	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5636	delivery	5	40
35457	2020-03-01 03:39:22	2020-03-01	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	11465	delivery	5	48
35458	2020-03-01 03:44:08	2020-03-01	17	[{"id_menu":4,"count":1}]	227	pick-up	0	17
35459	2020-03-01 03:46:50	2020-03-01	9	[{"id_menu":6,"count":1}]	13995	delivery	5	14
35460	2020-03-01 03:48:24	2020-03-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":3}]	5689	delivery	5	28
35461	2020-03-01 03:49:12	2020-03-01	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	13993	delivery	5	31
35462	2020-03-01 03:49:31	2020-03-01	14	[{"id_menu":2,"count":2}]	14081	pick-up	0	14
35463	2020-03-01 03:54:25	2020-03-01	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	14004	delivery	5	30
35464	2020-03-01 03:57:58	2020-03-01	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	397	delivery	5	57
35465	2020-03-01 03:58:56	2020-03-01	12	[{"id_menu":3,"count":1}]	6600	pick-up	0	12
35466	2020-03-01 04:04:46	2020-03-01	9	[{"id_menu":6,"count":1}]	4242	delivery	5	14
35467	2020-03-01 04:06:43	2020-03-01	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2556	pick-up	0	26
35468	2020-03-01 04:08:15	2020-03-01	12	[{"id_menu":1,"count":1}]	5916	delivery	5	17
35469	2020-03-01 04:12:01	2020-03-01	8	[{"id_menu":5,"count":1}]	14053	delivery	5	13
35470	2020-03-01 04:14:16	2020-03-01	9	[{"id_menu":6,"count":1}]	2641	pick-up	0	9
35471	2020-03-01 04:19:25	2020-03-01	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	14057	delivery	5	38
35472	2020-03-01 04:23:00	2020-03-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	11401	pick-up	0	23
35473	2020-03-01 04:28:03	2020-03-01	9	[{"id_menu":6,"count":1}]	6840	delivery	5	14
35474	2020-03-01 04:28:27	2020-03-01	17	[{"id_menu":4,"count":1}]	13303	delivery	5	22
35475	2020-03-01 04:32:46	2020-03-01	9	[{"id_menu":6,"count":1}]	12219	delivery	5	14
35476	2020-03-01 04:34:34	2020-03-01	9	[{"id_menu":7,"count":1}]	6427	delivery	5	14
35477	2020-03-01 04:38:30	2020-03-01	14	[{"id_menu":2,"count":1}]	447	pick-up	0	14
35478	2020-03-01 04:40:11	2020-03-01	17	[{"id_menu":4,"count":1}]	14077	delivery	5	22
35479	2020-03-01 04:48:47	2020-03-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7863	delivery	5	23
35480	2020-03-01 04:51:23	2020-03-01	12	[{"id_menu":3,"count":1}]	7413	delivery	5	17
35481	2020-03-01 04:58:57	2020-03-01	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	7169	delivery	5	26
35482	2020-03-01 05:01:12	2020-03-01	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2157	delivery	5	27
35483	2020-03-01 05:01:25	2020-03-01	12	[{"id_menu":1,"count":1}]	3633	delivery	5	17
35484	2020-03-01 05:09:55	2020-03-01	17	[{"id_menu":4,"count":1}]	7200	pick-up	0	17
35485	2020-03-01 05:12:47	2020-03-01	8	[{"id_menu":5,"count":1}]	14076	delivery	5	13
35486	2020-03-01 05:16:15	2020-03-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	9685	delivery	5	31
35487	2020-03-01 05:19:56	2020-03-01	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	8994	delivery	5	31
35488	2020-03-01 05:23:24	2020-03-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14084	delivery	5	22
35489	2020-03-01 05:29:15	2020-03-01	8	[{"id_menu":5,"count":1}]	4997	pick-up	0	8
35490	2020-03-01 05:31:12	2020-03-01	12	[{"id_menu":1,"count":1}]	14064	delivery	5	17
35491	2020-03-01 05:32:14	2020-03-01	17	[{"id_menu":4,"count":1}]	8487	delivery	5	22
35492	2020-03-01 05:32:15	2020-03-01	17	[{"id_menu":4,"count":1}]	6282	delivery	5	22
35493	2020-03-01 05:39:06	2020-03-01	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2615	pick-up	0	30
35494	2020-03-01 05:42:42	2020-03-01	14	[{"id_menu":2,"count":1}]	14080	delivery	5	19
35495	2020-03-01 05:43:13	2020-03-01	9	[{"id_menu":6,"count":1}]	12320	delivery	5	14
35496	2020-03-01 05:58:30	2020-03-01	9	[{"id_menu":6,"count":2}]	14043	delivery	5	14
35497	2020-03-01 06:00:10	2020-03-01	17	[{"id_menu":4,"count":1}]	8224	pick-up	0	17
35498	2020-03-01 06:05:05	2020-03-01	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	14009	delivery	5	26
35499	2020-03-01 06:07:49	2020-03-01	14	[{"id_menu":2,"count":1}]	12089	delivery	5	19
35500	2020-03-01 06:19:40	2020-03-01	14	[{"id_menu":2,"count":1}]	8372	pick-up	0	14
35501	2020-03-01 06:27:04	2020-03-01	9	[{"id_menu":7,"count":2}]	14032	pick-up	0	9
35502	2020-03-01 06:27:51	2020-03-01	9	[{"id_menu":6,"count":1}]	7019	delivery	5	14
35503	2020-03-01 06:27:53	2020-03-01	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	9181	delivery	5	26
35504	2020-03-01 06:27:57	2020-03-01	12	[{"id_menu":3,"count":1}]	5794	delivery	5	17
35505	2020-03-01 06:31:15	2020-03-01	9	[{"id_menu":6,"count":1}]	13657	delivery	5	14
35506	2020-03-01 06:31:35	2020-03-01	12	[{"id_menu":1,"count":1}]	14020	delivery	5	17
35507	2020-03-01 06:39:13	2020-03-01	12	[{"id_menu":3,"count":1}]	13358	delivery	5	17
35508	2020-03-01 06:40:54	2020-03-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9850	delivery	5	23
35509	2020-03-01 06:53:59	2020-03-01	14	[{"id_menu":2,"count":1}]	1137	pick-up	0	14
35510	2020-03-01 06:54:05	2020-03-01	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13990	delivery	5	48
35511	2020-03-01 06:57:47	2020-03-01	9	[{"id_menu":6,"count":1}]	3858	pick-up	0	9
35512	2020-03-01 06:57:56	2020-03-01	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2491	delivery	5	38
35513	2020-03-01 06:59:23	2020-03-01	9	[{"id_menu":6,"count":1}]	1461	pick-up	0	9
35514	2020-03-01 07:02:24	2020-03-01	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3417	delivery	5	26
35515	2020-03-01 07:04:17	2020-03-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	14087	delivery	5	28
35516	2020-03-01 07:09:54	2020-03-01	8	[{"id_menu":5,"count":1}]	14029	delivery	5	13
35517	2020-03-01 07:10:11	2020-03-01	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3784	delivery	5	45
35518	2020-03-01 07:15:12	2020-03-01	17	[{"id_menu":4,"count":1}]	596	pick-up	0	17
35519	2020-03-01 07:24:44	2020-03-01	17	[{"id_menu":4,"count":1}]	7800	pick-up	0	17
35520	2020-03-01 07:25:43	2020-03-01	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1633	pick-up	0	21
35521	2020-03-01 07:27:38	2020-03-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7912	delivery	5	23
35522	2020-03-01 07:32:37	2020-03-01	9	[{"id_menu":6,"count":1}]	14070	pick-up	0	9
35523	2020-03-01 07:41:37	2020-03-01	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	5220	delivery	5	42
35524	2020-03-01 07:43:47	2020-03-01	12	[{"id_menu":1,"count":1}]	13638	delivery	5	17
35525	2020-03-01 07:46:38	2020-03-01	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	13992	delivery	5	27
35526	2020-03-01 08:05:17	2020-03-01	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14055	delivery	5	45
35527	2020-03-01 08:07:57	2020-03-01	12	[{"id_menu":3,"count":1}]	7206	pick-up	0	12
35528	2020-03-01 08:13:13	2020-03-01	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2669	delivery	5	34
35529	2020-03-01 08:18:26	2020-03-01	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2339	pick-up	0	33
35530	2020-03-01 08:19:01	2020-03-01	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1839	pick-up	0	24
35531	2020-03-01 08:19:58	2020-03-01	9	[{"id_menu":7,"count":1}]	1353	delivery	5	14
35532	2020-03-01 08:25:35	2020-03-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14033	pick-up	0	17
35533	2020-03-01 08:26:10	2020-03-01	9	[{"id_menu":7,"count":1}]	3397	delivery	5	14
35534	2020-03-01 08:26:36	2020-03-01	9	[{"id_menu":6,"count":1}]	7674	delivery	5	14
35535	2020-03-01 08:29:37	2020-03-01	8	[{"id_menu":5,"count":1}]	14050	delivery	5	13
35536	2020-03-01 08:40:25	2020-03-01	8	[{"id_menu":5,"count":1}]	5346	delivery	5	13
35537	2020-03-01 08:40:54	2020-03-01	9	[{"id_menu":6,"count":1}]	6174	delivery	5	14
35538	2020-03-01 08:41:30	2020-03-01	8	[{"id_menu":5,"count":1}]	5970	delivery	5	13
35539	2020-03-01 08:46:20	2020-03-01	12	[{"id_menu":3,"count":1}]	7280	delivery	5	17
35540	2020-03-01 08:47:15	2020-03-01	12	[{"id_menu":3,"count":1}]	3527	delivery	5	17
35541	2020-03-01 08:50:14	2020-03-01	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14083	delivery	5	31
35542	2020-03-01 08:58:12	2020-03-01	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	11325	delivery	5	31
35543	2020-03-01 08:59:56	2020-03-01	9	[{"id_menu":6,"count":1}]	1080	pick-up	0	9
35544	2020-03-01 09:03:33	2020-03-01	8	[{"id_menu":5,"count":1}]	14035	delivery	5	13
35545	2020-03-01 09:05:51	2020-03-01	9	[{"id_menu":6,"count":1}]	10219	delivery	5	14
35546	2020-03-01 09:09:24	2020-03-01	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	13999	delivery	5	26
35547	2020-03-01 09:12:21	2020-03-01	17	[{"id_menu":4,"count":1}]	4137	pick-up	0	17
35548	2020-03-01 09:13:28	2020-03-01	9	[{"id_menu":6,"count":1}]	14026	delivery	5	14
35549	2020-03-01 09:14:41	2020-03-01	8	[{"id_menu":5,"count":1}]	13352	delivery	5	13
35550	2020-03-01 09:15:56	2020-03-01	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	12248	pick-up	0	26
35551	2020-03-01 09:19:11	2020-03-01	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8609	pick-up	0	25
35552	2020-03-01 09:21:11	2020-03-01	8	[{"id_menu":5,"count":1}]	3887	delivery	5	13
35553	2020-03-01 09:30:41	2020-03-01	17	[{"id_menu":4,"count":1}]	14062	delivery	5	22
35554	2020-03-01 09:32:39	2020-03-01	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	14074	delivery	5	40
35555	2020-03-01 09:33:06	2020-03-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	9816	pick-up	0	21
35556	2020-03-01 09:38:20	2020-03-01	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5982	delivery	5	42
35557	2020-03-01 09:44:13	2020-03-01	14	[{"id_menu":2,"count":1}]	14027	pick-up	0	14
35558	2020-03-01 09:46:31	2020-03-01	9	[{"id_menu":6,"count":1}]	7591	pick-up	0	9
35559	2020-03-01 09:51:25	2020-03-01	9	[{"id_menu":6,"count":1}]	14011	delivery	5	14
35560	2020-03-01 10:02:20	2020-03-01	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7293	delivery	5	49
35561	2020-03-01 10:03:09	2020-03-01	12	[{"id_menu":1,"count":1}]	3224	pick-up	0	12
35562	2020-03-01 10:03:23	2020-03-01	9	[{"id_menu":6,"count":1}]	13996	delivery	5	14
35563	2020-03-01 10:04:11	2020-03-01	9	[{"id_menu":7,"count":1}]	8437	pick-up	0	9
35564	2020-03-01 10:09:05	2020-03-01	9	[{"id_menu":6,"count":1}]	14047	delivery	5	14
35565	2020-03-01 10:17:26	2020-03-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	13989	delivery	5	31
35566	2020-03-01 10:17:48	2020-03-01	12	[{"id_menu":1,"count":1}]	7341	delivery	5	17
35567	2020-03-01 10:19:21	2020-03-01	17	[{"id_menu":4,"count":1}]	13256	delivery	5	22
35568	2020-03-01 10:28:03	2020-03-01	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	13102	delivery	5	27
35569	2020-03-01 10:28:51	2020-03-01	14	[{"id_menu":2,"count":1}]	13026	pick-up	0	14
35570	2020-03-01 10:30:03	2020-03-01	8	[{"id_menu":5,"count":1}]	1115	delivery	5	13
35571	2020-03-01 10:45:36	2020-03-01	17	[{"id_menu":4,"count":1}]	10281	delivery	5	22
35572	2020-03-01 10:47:34	2020-03-01	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	14039	delivery	5	25
35573	2020-03-01 10:48:09	2020-03-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	3031	delivery	5	26
35574	2020-03-01 10:48:21	2020-03-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14048	delivery	5	22
35575	2020-03-01 10:52:45	2020-03-01	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14100	delivery	5	37
35576	2020-03-01 10:55:09	2020-03-01	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	14030	delivery	5	39
35577	2020-03-01 10:57:52	2020-03-01	9	[{"id_menu":6,"count":1}]	14044	delivery	5	14
35578	2020-03-01 11:01:43	2020-03-01	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1424	delivery	5	34
35579	2020-03-01 11:05:34	2020-03-01	17	[{"id_menu":4,"count":1}]	6399	pick-up	0	17
35580	2020-03-01 11:10:56	2020-03-01	9	[{"id_menu":6,"count":1}]	4652	delivery	5	14
35581	2020-03-01 11:25:11	2020-03-01	8	[{"id_menu":5,"count":1}]	1557	pick-up	0	8
35582	2020-03-01 11:35:20	2020-03-01	14	[{"id_menu":2,"count":1}]	139	delivery	5	19
35583	2020-03-01 11:37:51	2020-03-01	8	[{"id_menu":5,"count":1}]	7409	delivery	5	13
35584	2020-03-01 11:39:10	2020-03-01	9	[{"id_menu":6,"count":1}]	2190	pick-up	0	9
35585	2020-03-01 11:39:52	2020-03-01	8	[{"id_menu":5,"count":1}]	8656	pick-up	0	8
35586	2020-03-01 11:40:47	2020-03-01	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	13106	delivery	5	40
35587	2020-03-01 11:44:58	2020-03-01	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	6409	delivery	5	26
35588	2020-03-01 11:46:13	2020-03-01	12	[{"id_menu":1,"count":1}]	1932	pick-up	0	12
35589	2020-03-01 11:47:45	2020-03-01	12	[{"id_menu":1,"count":1}]	3092	delivery	5	17
35590	2020-03-01 11:51:46	2020-03-01	9	[{"id_menu":7,"count":1}]	14054	pick-up	0	9
35591	2020-03-01 11:52:57	2020-03-01	8	[{"id_menu":5,"count":1}]	2420	pick-up	0	8
35592	2020-03-01 11:54:23	2020-03-01	14	[{"id_menu":2,"count":1}]	14056	delivery	5	19
35593	2020-03-01 11:55:28	2020-03-01	14	[{"id_menu":2,"count":1}]	1017	delivery	5	19
35594	2020-03-01 12:01:56	2020-03-01	14	[{"id_menu":2,"count":1}]	1255	pick-up	0	14
35595	2020-03-01 12:06:19	2020-03-01	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	14060	delivery	5	34
35596	2020-03-01 12:09:33	2020-03-01	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	1860	pick-up	0	25
35597	2020-03-01 12:13:19	2020-03-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6182	pick-up	0	23
35598	2020-03-01 12:19:20	2020-03-01	12	[{"id_menu":3,"count":1}]	7546	pick-up	0	12
35599	2020-03-01 12:20:04	2020-03-01	8	[{"id_menu":5,"count":1}]	6959	delivery	5	13
35600	2020-03-01 12:28:28	2020-03-01	17	[{"id_menu":4,"count":1}]	338	pick-up	0	17
35601	2020-03-01 12:33:37	2020-03-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2188	pick-up	0	23
35602	2020-03-01 12:42:00	2020-03-01	9	[{"id_menu":6,"count":1}]	5570	delivery	5	14
35603	2020-03-01 12:47:08	2020-03-01	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4170	delivery	5	31
35604	2020-03-01 12:50:00	2020-03-01	38	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	14098	delivery	5	43
35605	2020-03-01 12:54:50	2020-03-01	9	[{"id_menu":6,"count":1}]	14063	pick-up	0	9
35606	2020-03-01 12:57:33	2020-03-01	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2080	pick-up	0	26
35607	2020-03-01 12:59:54	2020-03-01	9	[{"id_menu":7,"count":1}]	10287	delivery	5	14
35608	2020-03-01 13:04:16	2020-03-01	9	[{"id_menu":7,"count":1}]	1638	delivery	5	14
35609	2020-03-01 13:05:42	2020-03-01	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	9536	delivery	5	31
35610	2020-03-01 13:09:28	2020-03-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	14067	delivery	5	28
35611	2020-03-01 13:14:37	2020-03-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11342	delivery	5	31
35612	2020-03-01 13:15:29	2020-03-01	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14021	delivery	5	34
35613	2020-03-01 13:16:42	2020-03-01	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3749	delivery	5	45
35614	2020-03-01 13:21:38	2020-03-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8394	pick-up	0	17
35615	2020-03-01 13:31:38	2020-03-01	12	[{"id_menu":1,"count":1}]	11390	pick-up	0	12
35616	2020-03-01 13:55:27	2020-03-01	14	[{"id_menu":2,"count":1}]	14040	delivery	5	19
35617	2020-03-01 14:00:55	2020-03-01	17	[{"id_menu":4,"count":1}]	7250	pick-up	0	17
35618	2020-03-01 14:03:29	2020-03-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5064	pick-up	0	18
35619	2020-03-01 14:04:36	2020-03-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	14082	delivery	5	28
35620	2020-03-01 14:06:01	2020-03-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	6589	delivery	5	26
35621	2020-03-01 14:11:02	2020-03-01	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14041	delivery	5	35
35622	2020-03-01 14:21:48	2020-03-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":3}]	14058	delivery	5	28
35623	2020-03-01 14:26:31	2020-03-01	12	[{"id_menu":1,"count":1}]	14075	delivery	5	17
35624	2020-03-01 14:28:28	2020-03-01	9	[{"id_menu":6,"count":1}]	3788	delivery	5	14
35625	2020-03-01 14:31:07	2020-03-01	12	[{"id_menu":1,"count":1}]	5048	pick-up	0	12
35626	2020-03-01 14:31:21	2020-03-01	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12954	delivery	5	37
35627	2020-03-01 14:32:07	2020-03-01	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	861	pick-up	0	21
35628	2020-03-01 14:33:52	2020-03-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8382	delivery	5	28
35629	2020-03-01 14:41:36	2020-03-01	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	184	pick-up	0	22
35630	2020-03-01 14:47:28	2020-03-01	12	[{"id_menu":3,"count":1}]	533	delivery	5	17
35631	2020-03-01 14:52:17	2020-03-01	9	[{"id_menu":7,"count":1}]	13733	pick-up	0	9
35632	2020-03-01 14:53:06	2020-03-01	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	372	pick-up	0	21
35633	2020-03-01 14:53:11	2020-03-01	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	8720	delivery	5	40
35634	2020-03-01 14:53:18	2020-03-01	9	[{"id_menu":6,"count":1}]	12565	delivery	5	14
35635	2020-03-01 14:54:02	2020-03-01	12	[{"id_menu":3,"count":2}]	2456	delivery	5	17
35636	2020-03-01 14:56:31	2020-03-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	617	delivery	5	22
35637	2020-03-01 15:03:21	2020-03-01	12	[{"id_menu":1,"count":1}]	13997	delivery	5	17
35638	2020-03-01 15:07:41	2020-03-01	17	[{"id_menu":4,"count":1}]	14017	delivery	5	22
35639	2020-03-01 15:07:45	2020-03-01	12	[{"id_menu":3,"count":1}]	14005	delivery	5	17
35640	2020-03-01 15:09:41	2020-03-01	17	[{"id_menu":4,"count":1}]	12676	delivery	5	22
35641	2020-03-01 15:16:22	2020-03-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14068	delivery	5	23
35642	2020-03-01 15:18:49	2020-03-01	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	3451	pick-up	0	26
35643	2020-03-01 15:23:29	2020-03-01	14	[{"id_menu":2,"count":1}]	9011	delivery	5	19
35644	2020-03-01 15:24:09	2020-03-01	14	[{"id_menu":2,"count":1}]	513	delivery	5	19
35645	2020-03-01 15:24:59	2020-03-01	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	5831	delivery	5	48
35646	2020-03-01 15:25:15	2020-03-01	17	[{"id_menu":4,"count":1}]	1344	delivery	5	22
35647	2020-03-01 15:26:00	2020-03-01	12	[{"id_menu":1,"count":1}]	6147	pick-up	0	12
35648	2020-03-01 15:27:05	2020-03-01	8	[{"id_menu":5,"count":1}]	5389	delivery	5	13
35649	2020-03-01 15:27:19	2020-03-01	12	[{"id_menu":3,"count":1}]	14088	delivery	5	17
35650	2020-03-01 15:30:06	2020-03-01	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13502	pick-up	0	38
35651	2020-03-01 15:33:47	2020-03-01	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	6051	delivery	5	26
35652	2020-03-01 15:42:34	2020-03-01	12	[{"id_menu":3,"count":1}]	2237	pick-up	0	12
35653	2020-03-01 15:46:27	2020-03-01	17	[{"id_menu":4,"count":1}]	6658	delivery	5	22
35654	2020-03-01 15:55:21	2020-03-01	9	[{"id_menu":6,"count":1}]	14001	delivery	5	14
35655	2020-03-01 15:59:02	2020-03-01	17	[{"id_menu":4,"count":1}]	7953	delivery	5	22
35656	2020-03-01 16:01:58	2020-03-01	8	[{"id_menu":5,"count":1}]	14019	delivery	5	13
35657	2020-03-01 16:02:31	2020-03-01	12	[{"id_menu":1,"count":1}]	8563	delivery	5	17
35658	2020-03-01 16:07:17	2020-03-01	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	12053	pick-up	0	26
35659	2020-03-01 16:08:18	2020-03-01	12	[{"id_menu":1,"count":1}]	7082	delivery	5	17
35660	2020-03-01 16:08:30	2020-03-01	14	[{"id_menu":2,"count":1}]	4020	delivery	5	19
35661	2020-03-01 16:08:38	2020-03-01	17	[{"id_menu":4,"count":1}]	1694	delivery	5	22
35662	2020-03-01 16:13:07	2020-03-01	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	3868	delivery	5	39
35663	2020-03-01 16:13:08	2020-03-01	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3131	delivery	5	38
35664	2020-03-01 16:17:38	2020-03-01	12	[{"id_menu":3,"count":1}]	10041	delivery	5	17
35665	2020-03-01 16:18:06	2020-03-01	12	[{"id_menu":1,"count":1}]	8275	delivery	5	17
35666	2020-03-01 16:28:19	2020-03-01	8	[{"id_menu":5,"count":1}]	4260	pick-up	0	8
35667	2020-03-01 16:30:55	2020-03-01	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	14085	delivery	5	25
35668	2020-03-01 16:33:07	2020-03-01	8	[{"id_menu":5,"count":1}]	3981	delivery	5	13
35669	2020-03-01 16:34:02	2020-03-01	9	[{"id_menu":7,"count":1}]	8758	pick-up	0	9
35670	2020-03-01 16:37:04	2020-03-01	17	[{"id_menu":4,"count":1}]	3385	pick-up	0	17
35671	2020-03-01 16:46:45	2020-03-01	9	[{"id_menu":7,"count":1}]	4021	pick-up	0	9
35672	2020-03-01 16:59:11	2020-03-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":3}]	9956	delivery	5	23
35673	2020-03-01 17:00:34	2020-03-01	9	[{"id_menu":6,"count":1}]	2069	pick-up	0	9
35674	2020-03-01 17:01:30	2020-03-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	12934	delivery	5	28
35675	2020-03-01 17:04:05	2020-03-01	12	[{"id_menu":1,"count":1}]	3693	pick-up	0	12
35676	2020-03-01 17:04:47	2020-03-01	8	[{"id_menu":5,"count":1}]	228	pick-up	0	8
35677	2020-03-01 17:06:17	2020-03-01	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	11219	delivery	5	26
35678	2020-03-01 17:25:06	2020-03-01	14	[{"id_menu":2,"count":1}]	9039	delivery	5	19
35679	2020-03-01 17:39:39	2020-03-01	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	7387	delivery	5	29
35680	2020-03-01 17:42:42	2020-03-01	14	[{"id_menu":2,"count":1}]	12739	pick-up	0	14
35681	2020-03-01 17:49:17	2020-03-01	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	14092	delivery	5	26
35682	2020-03-01 17:49:23	2020-03-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	14099	delivery	5	28
35683	2020-03-01 17:49:32	2020-03-01	12	[{"id_menu":3,"count":1}]	9667	pick-up	0	12
35684	2020-03-01 17:53:10	2020-03-01	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	10721	delivery	5	34
35685	2020-03-01 17:58:09	2020-03-01	9	[{"id_menu":6,"count":1}]	9942	delivery	5	14
35686	2020-03-01 18:05:24	2020-03-01	23	[{"id_menu":2,"count":3},{"id_menu":7,"count":1}]	5524	delivery	5	28
35687	2020-03-01 18:08:31	2020-03-01	14	[{"id_menu":2,"count":1}]	14024	delivery	5	19
35688	2020-03-01 18:10:07	2020-03-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4116	delivery	5	23
35689	2020-03-01 18:10:58	2020-03-01	14	[{"id_menu":2,"count":1}]	6733	pick-up	0	14
35690	2020-03-01 18:11:40	2020-03-01	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	1677	pick-up	0	22
35691	2020-03-01 18:12:25	2020-03-01	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14073	delivery	5	36
35692	2020-03-01 18:16:50	2020-03-01	9	[{"id_menu":7,"count":2}]	9266	delivery	5	14
35693	2020-03-01 18:17:03	2020-03-01	9	[{"id_menu":7,"count":1}]	5863	delivery	5	14
35694	2020-03-01 18:18:08	2020-03-01	9	[{"id_menu":7,"count":1}]	1784	delivery	5	14
35695	2020-03-01 18:21:52	2020-03-01	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	14094	delivery	5	31
35696	2020-03-01 18:26:50	2020-03-01	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1207	delivery	5	45
35697	2020-03-01 18:26:53	2020-03-01	17	[{"id_menu":4,"count":1}]	1379	pick-up	0	17
35698	2020-03-01 18:36:15	2020-03-01	9	[{"id_menu":7,"count":1}]	2149	pick-up	0	9
35699	2020-03-01 18:36:17	2020-03-01	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	9384	delivery	5	26
35700	2020-03-01 18:36:55	2020-03-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	14000	delivery	5	28
35701	2020-03-01 18:38:41	2020-03-01	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	8366	delivery	5	38
35702	2020-03-01 18:39:14	2020-03-01	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11150	delivery	5	35
35703	2020-03-01 18:43:56	2020-03-01	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14038	delivery	5	31
35704	2020-03-01 18:46:01	2020-03-01	14	[{"id_menu":2,"count":1}]	14065	pick-up	0	14
35705	2020-03-01 18:47:06	2020-03-01	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14022	delivery	5	51
35706	2020-03-01 18:47:25	2020-03-01	14	[{"id_menu":2,"count":1}]	1551	pick-up	0	14
35707	2020-03-01 18:48:55	2020-03-01	9	[{"id_menu":6,"count":1}]	1640	delivery	5	14
35708	2020-03-01 18:49:44	2020-03-01	17	[{"id_menu":4,"count":1}]	14025	pick-up	0	17
35709	2020-03-01 18:52:33	2020-03-01	8	[{"id_menu":5,"count":1}]	10709	delivery	5	13
35710	2020-03-01 19:00:21	2020-03-01	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	14031	delivery	5	39
35711	2020-03-01 19:07:17	2020-03-01	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	14013	pick-up	0	20
35712	2020-03-01 19:15:10	2020-03-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14007	delivery	5	22
35713	2020-03-01 19:16:29	2020-03-01	12	[{"id_menu":1,"count":1}]	1273	pick-up	0	12
35714	2020-03-01 19:18:14	2020-03-01	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	8910	delivery	5	26
35715	2020-03-01 19:18:33	2020-03-01	8	[{"id_menu":5,"count":2}]	1457	delivery	5	13
35716	2020-03-01 19:22:59	2020-03-01	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	12099	pick-up	0	26
35717	2020-03-01 19:27:26	2020-03-01	9	[{"id_menu":7,"count":1}]	14086	pick-up	0	9
35718	2020-03-01 19:27:32	2020-03-01	9	[{"id_menu":6,"count":1}]	8065	pick-up	0	9
35719	2020-03-01 19:29:37	2020-03-01	9	[{"id_menu":7,"count":1}]	10369	pick-up	0	9
35720	2020-03-01 19:36:06	2020-03-01	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14028	delivery	5	43
35721	2020-03-01 19:38:14	2020-03-01	9	[{"id_menu":7,"count":1}]	14096	delivery	5	14
35722	2020-03-01 19:42:01	2020-03-01	12	[{"id_menu":1,"count":1}]	12078	delivery	5	17
35723	2020-03-01 19:43:04	2020-03-01	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	9732	delivery	5	40
35724	2020-03-01 19:43:33	2020-03-01	9	[{"id_menu":6,"count":1}]	10968	pick-up	0	9
35725	2020-03-01 19:45:01	2020-03-01	9	[{"id_menu":6,"count":1}]	2894	delivery	5	14
35726	2020-03-01 19:50:06	2020-03-01	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	14052	pick-up	0	20
35727	2020-03-01 19:51:36	2020-03-01	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1618	delivery	5	31
35728	2020-03-01 19:55:13	2020-03-01	14	[{"id_menu":2,"count":1}]	4486	delivery	5	19
35729	2020-03-01 19:58:52	2020-03-01	14	[{"id_menu":2,"count":1}]	13998	delivery	5	19
35730	2020-03-01 19:59:57	2020-03-01	14	[{"id_menu":2,"count":1}]	14059	delivery	5	19
35731	2020-03-01 20:01:43	2020-03-01	9	[{"id_menu":7,"count":1}]	3010	delivery	5	14
35732	2020-03-01 20:02:04	2020-03-01	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7898	pick-up	0	25
35733	2020-03-01 20:03:21	2020-03-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	7768	delivery	5	22
35734	2020-03-01 20:05:17	2020-03-01	14	[{"id_menu":2,"count":1}]	1343	pick-up	0	14
35735	2020-03-01 20:06:39	2020-03-01	14	[{"id_menu":2,"count":1}]	11183	pick-up	0	14
35736	2020-03-01 20:07:10	2020-03-01	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1494	delivery	5	38
35737	2020-03-01 20:12:18	2020-03-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14023	delivery	5	23
35738	2020-03-01 20:15:51	2020-03-01	8	[{"id_menu":5,"count":1}]	5862	pick-up	0	8
35739	2020-03-01 20:16:53	2020-03-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	3051	pick-up	0	21
35740	2020-03-01 20:35:25	2020-03-01	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9780	delivery	5	36
35741	2020-03-01 20:37:46	2020-03-01	17	[{"id_menu":4,"count":1}]	14034	pick-up	0	17
35742	2020-03-01 20:38:46	2020-03-01	12	[{"id_menu":1,"count":1}]	4062	pick-up	0	12
35743	2020-03-01 20:39:47	2020-03-01	9	[{"id_menu":6,"count":1}]	14078	delivery	5	14
35744	2020-03-01 20:40:18	2020-03-01	9	[{"id_menu":7,"count":1}]	10870	delivery	5	14
35745	2020-03-01 20:40:54	2020-03-01	9	[{"id_menu":6,"count":1}]	14061	delivery	5	14
35746	2020-03-01 20:44:53	2020-03-01	17	[{"id_menu":4,"count":1}]	5720	delivery	5	22
35747	2020-03-01 20:49:53	2020-03-01	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	11117	delivery	5	26
35748	2020-03-01 20:49:56	2020-03-01	12	[{"id_menu":3,"count":1}]	659	pick-up	0	12
35749	2020-03-01 20:53:22	2020-03-01	8	[{"id_menu":5,"count":1}]	6623	delivery	5	13
35750	2020-03-01 20:56:47	2020-03-01	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	1144	pick-up	0	26
35751	2020-03-01 20:58:48	2020-03-01	9	[{"id_menu":7,"count":1}]	10706	pick-up	0	9
35752	2020-03-01 20:59:28	2020-03-01	9	[{"id_menu":7,"count":1}]	13630	delivery	5	14
35753	2020-03-01 21:03:42	2020-03-01	17	[{"id_menu":4,"count":1}]	2131	pick-up	0	17
35754	2020-03-01 21:08:34	2020-03-01	14	[{"id_menu":2,"count":1}]	14049	pick-up	0	14
35755	2020-03-01 21:12:15	2020-03-01	8	[{"id_menu":5,"count":1}]	12043	pick-up	0	8
35756	2020-03-01 21:23:09	2020-03-01	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	14089	pick-up	0	26
35757	2020-03-01 21:29:10	2020-03-01	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10284	delivery	5	30
35758	2020-03-01 21:30:25	2020-03-01	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	14066	pick-up	0	26
35759	2020-03-01 21:31:59	2020-03-01	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	10651	delivery	5	23
35760	2020-03-01 21:32:17	2020-03-01	12	[{"id_menu":3,"count":1}]	14071	delivery	5	17
35761	2020-03-01 21:33:48	2020-03-01	8	[{"id_menu":5,"count":1}]	13994	delivery	5	13
35762	2020-03-01 21:34:15	2020-03-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14090	delivery	5	23
35763	2020-03-01 21:35:46	2020-03-01	9	[{"id_menu":7,"count":1}]	14016	delivery	5	14
35764	2020-03-01 21:42:56	2020-03-01	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9356	pick-up	0	31
35765	2020-03-01 21:45:47	2020-03-01	12	[{"id_menu":1,"count":1}]	9910	delivery	5	17
35766	2020-03-01 21:49:33	2020-03-01	12	[{"id_menu":1,"count":1}]	6977	pick-up	0	12
35767	2020-03-01 21:50:33	2020-03-01	9	[{"id_menu":6,"count":1}]	11736	pick-up	0	9
35768	2020-03-01 21:52:33	2020-03-01	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	1044	pick-up	0	21
35769	2020-03-01 21:58:08	2020-03-01	14	[{"id_menu":2,"count":1}]	1902	delivery	5	19
35770	2020-03-01 22:02:15	2020-03-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4281	delivery	5	28
35771	2020-03-01 22:03:36	2020-03-01	14	[{"id_menu":2,"count":1}]	5598	delivery	5	19
35772	2020-03-01 22:07:58	2020-03-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	14097	delivery	5	26
35773	2020-03-01 22:08:33	2020-03-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4764	delivery	5	22
35774	2020-03-01 22:10:05	2020-03-01	14	[{"id_menu":2,"count":1}]	6331	pick-up	0	14
35775	2020-03-01 22:25:33	2020-03-01	14	[{"id_menu":2,"count":1}]	3983	delivery	5	19
35776	2020-03-01 22:29:48	2020-03-01	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2083	pick-up	0	29
35777	2020-03-01 22:32:23	2020-03-01	12	[{"id_menu":3,"count":1}]	5406	pick-up	0	12
35778	2020-03-01 22:42:35	2020-03-01	9	[{"id_menu":6,"count":1}]	6634	pick-up	0	9
35779	2020-03-01 22:42:56	2020-03-01	14	[{"id_menu":2,"count":1}]	14006	delivery	5	19
35780	2020-03-01 22:43:56	2020-03-01	9	[{"id_menu":7,"count":1}]	7528	delivery	5	14
35781	2020-03-01 22:55:45	2020-03-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8484	delivery	5	22
35782	2020-03-01 22:59:32	2020-03-01	12	[{"id_menu":3,"count":1}]	14018	delivery	5	17
35783	2020-03-01 23:16:35	2020-03-01	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3002	delivery	5	43
35784	2020-03-01 23:18:25	2020-03-01	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	14015	delivery	5	52
35785	2020-03-01 23:18:47	2020-03-01	9	[{"id_menu":6,"count":1}]	315	pick-up	0	9
35786	2020-03-01 23:19:33	2020-03-01	12	[{"id_menu":1,"count":1}]	14003	delivery	5	17
35787	2020-03-01 23:20:59	2020-03-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8068	pick-up	0	26
35788	2020-03-01 23:24:07	2020-03-01	12	[{"id_menu":1,"count":1}]	13151	delivery	5	17
35789	2020-03-01 23:24:14	2020-03-01	9	[{"id_menu":6,"count":1}]	5988	pick-up	0	9
35790	2020-03-01 23:24:25	2020-03-01	12	[{"id_menu":3,"count":1}]	313	pick-up	0	12
35791	2020-03-01 23:25:55	2020-03-01	9	[{"id_menu":6,"count":1}]	3931	pick-up	0	9
35792	2020-03-01 23:31:12	2020-03-01	9	[{"id_menu":6,"count":1}]	6734	pick-up	0	9
35793	2020-03-01 23:34:01	2020-03-01	9	[{"id_menu":6,"count":1}]	14091	pick-up	0	9
35794	2020-03-01 23:35:26	2020-03-01	14	[{"id_menu":2,"count":1}]	14014	delivery	5	19
35795	2020-03-01 23:36:16	2020-03-01	12	[{"id_menu":1,"count":1}]	13859	pick-up	0	12
35796	2020-03-01 23:41:36	2020-03-01	9	[{"id_menu":6,"count":1}]	2485	delivery	5	14
35797	2020-03-01 23:43:11	2020-03-01	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13827	delivery	5	31
35798	2020-03-01 23:50:26	2020-03-01	14	[{"id_menu":2,"count":1}]	464	pick-up	0	14
35799	2020-03-01 23:54:07	2020-03-01	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	14051	delivery	5	28
35800	2020-03-01 23:54:32	2020-03-01	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7119	pick-up	0	38
35801	2020-03-01 23:55:49	2020-03-01	9	[{"id_menu":6,"count":1}]	14008	pick-up	0	9
35802	2020-03-01 23:57:28	2020-03-01	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	13474	delivery	5	48
35803	2020-03-02 00:03:22	2020-03-02	8	[{"id_menu":5,"count":1}]	4090	pick-up	0	8
35804	2020-03-02 00:05:48	2020-03-02	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	4952	delivery	5	31
35805	2020-03-02 00:18:22	2020-03-02	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	8590	delivery	5	26
35806	2020-03-02 00:20:04	2020-03-02	17	[{"id_menu":4,"count":1}]	2416	delivery	5	22
35807	2020-03-02 00:30:56	2020-03-02	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	14113	delivery	5	28
35808	2020-03-02 00:32:36	2020-03-02	8	[{"id_menu":5,"count":1}]	3380	pick-up	0	8
35809	2020-03-02 00:59:15	2020-03-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6376	pick-up	0	26
35810	2020-03-02 01:01:29	2020-03-02	14	[{"id_menu":2,"count":1}]	9723	delivery	5	19
35811	2020-03-02 01:02:50	2020-03-02	17	[{"id_menu":4,"count":1}]	1732	pick-up	0	17
35812	2020-03-02 01:16:44	2020-03-02	9	[{"id_menu":7,"count":1}]	8625	pick-up	0	9
35813	2020-03-02 01:17:18	2020-03-02	9	[{"id_menu":7,"count":1}]	11988	delivery	5	14
35814	2020-03-02 01:41:36	2020-03-02	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11358	delivery	5	37
35815	2020-03-02 01:44:16	2020-03-02	17	[{"id_menu":4,"count":1}]	14130	delivery	5	22
35816	2020-03-02 01:45:15	2020-03-02	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14138	delivery	5	52
35817	2020-03-02 01:47:48	2020-03-02	9	[{"id_menu":6,"count":1}]	7542	delivery	5	14
35818	2020-03-02 01:58:14	2020-03-02	14	[{"id_menu":2,"count":1}]	14139	delivery	5	19
35819	2020-03-02 01:59:42	2020-03-02	17	[{"id_menu":4,"count":1}]	1536	delivery	5	22
35820	2020-03-02 02:00:12	2020-03-02	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":3}]	14160	delivery	5	26
35821	2020-03-02 02:12:10	2020-03-02	9	[{"id_menu":6,"count":1}]	3680	pick-up	0	9
35822	2020-03-02 02:17:08	2020-03-02	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	7086	delivery	5	34
35823	2020-03-02 02:30:37	2020-03-02	14	[{"id_menu":2,"count":2}]	2077	pick-up	0	14
35824	2020-03-02 02:34:23	2020-03-02	14	[{"id_menu":2,"count":1}]	1228	delivery	5	19
35825	2020-03-02 02:56:59	2020-03-02	9	[{"id_menu":7,"count":1}]	5574	delivery	5	14
35826	2020-03-02 02:58:07	2020-03-02	12	[{"id_menu":3,"count":1}]	11407	delivery	5	17
35827	2020-03-02 03:03:10	2020-03-02	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	10368	delivery	5	28
35828	2020-03-02 03:05:13	2020-03-02	9	[{"id_menu":6,"count":1}]	12981	delivery	5	14
35829	2020-03-02 03:06:55	2020-03-02	12	[{"id_menu":1,"count":1}]	2622	pick-up	0	12
35830	2020-03-02 03:09:09	2020-03-02	9	[{"id_menu":7,"count":1}]	11192	delivery	5	14
35831	2020-03-02 03:22:20	2020-03-02	8	[{"id_menu":5,"count":1}]	2641	pick-up	0	8
35832	2020-03-02 03:23:21	2020-03-02	8	[{"id_menu":5,"count":1}]	14154	delivery	5	13
35833	2020-03-02 03:26:33	2020-03-02	17	[{"id_menu":4,"count":1}]	9054	delivery	5	22
35834	2020-03-02 03:46:56	2020-03-02	12	[{"id_menu":1,"count":1}]	5361	pick-up	0	12
35835	2020-03-02 03:47:03	2020-03-02	9	[{"id_menu":6,"count":1}]	4545	delivery	5	14
35836	2020-03-02 03:47:24	2020-03-02	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2699	pick-up	0	21
35837	2020-03-02 04:00:34	2020-03-02	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	14109	delivery	5	31
35838	2020-03-02 04:01:59	2020-03-02	9	[{"id_menu":7,"count":1}]	9301	pick-up	0	9
35839	2020-03-02 04:07:59	2020-03-02	9	[{"id_menu":7,"count":1}]	14199	delivery	5	14
35840	2020-03-02 04:12:09	2020-03-02	12	[{"id_menu":1,"count":1}]	13522	pick-up	0	12
35841	2020-03-02 04:13:40	2020-03-02	14	[{"id_menu":2,"count":1}]	8629	delivery	5	19
35842	2020-03-02 04:14:38	2020-03-02	12	[{"id_menu":3,"count":1}]	6740	delivery	5	17
35843	2020-03-02 04:19:41	2020-03-02	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	12612	delivery	5	43
35844	2020-03-02 04:20:41	2020-03-02	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	14111	delivery	5	42
35845	2020-03-02 04:21:16	2020-03-02	14	[{"id_menu":2,"count":1}]	5811	pick-up	0	14
35846	2020-03-02 04:22:14	2020-03-02	9	[{"id_menu":7,"count":1}]	5317	delivery	5	14
35847	2020-03-02 04:27:25	2020-03-02	9	[{"id_menu":6,"count":4}]	14159	delivery	5	14
35848	2020-03-02 04:32:08	2020-03-02	12	[{"id_menu":1,"count":1}]	972	delivery	5	17
35849	2020-03-02 04:33:00	2020-03-02	8	[{"id_menu":5,"count":1}]	3290	delivery	5	13
35850	2020-03-02 04:39:54	2020-03-02	9	[{"id_menu":6,"count":1}]	14134	delivery	5	14
35851	2020-03-02 04:45:35	2020-03-02	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	14106	delivery	5	22
35852	2020-03-02 04:46:32	2020-03-02	9	[{"id_menu":6,"count":1}]	8704	delivery	5	14
35853	2020-03-02 04:54:53	2020-03-02	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2310	pick-up	0	34
35854	2020-03-02 05:08:50	2020-03-02	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	5648	pick-up	0	20
35855	2020-03-02 05:08:54	2020-03-02	9	[{"id_menu":7,"count":1}]	12124	pick-up	0	9
35856	2020-03-02 05:14:54	2020-03-02	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	14195	pick-up	0	21
35857	2020-03-02 05:21:26	2020-03-02	12	[{"id_menu":3,"count":1}]	1406	pick-up	0	12
35858	2020-03-02 05:44:06	2020-03-02	9	[{"id_menu":6,"count":1}]	8877	delivery	5	14
35859	2020-03-02 05:50:29	2020-03-02	8	[{"id_menu":5,"count":1}]	14135	delivery	5	13
35860	2020-03-02 05:54:43	2020-03-02	17	[{"id_menu":4,"count":1}]	14162	delivery	5	22
35861	2020-03-02 05:56:06	2020-03-02	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	5911	delivery	5	39
35862	2020-03-02 06:00:28	2020-03-02	12	[{"id_menu":1,"count":1}]	1649	pick-up	0	12
35863	2020-03-02 06:32:54	2020-03-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14132	delivery	5	31
35864	2020-03-02 06:34:23	2020-03-02	9	[{"id_menu":6,"count":1}]	14126	delivery	5	14
35865	2020-03-02 06:39:05	2020-03-02	9	[{"id_menu":6,"count":1}]	14191	pick-up	0	9
35866	2020-03-02 07:03:01	2020-03-02	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	7330	pick-up	0	18
35867	2020-03-02 07:47:09	2020-03-02	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	6498	delivery	5	40
35868	2020-03-02 07:55:39	2020-03-02	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14196	delivery	5	43
35869	2020-03-02 07:56:51	2020-03-02	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	14163	delivery	5	25
35870	2020-03-02 08:03:01	2020-03-02	8	[{"id_menu":5,"count":1}]	6	pick-up	0	8
35871	2020-03-02 08:21:03	2020-03-02	9	[{"id_menu":6,"count":1}]	12506	delivery	5	14
35872	2020-03-02 08:25:33	2020-03-02	17	[{"id_menu":4,"count":1}]	6282	pick-up	0	17
35873	2020-03-02 08:31:16	2020-03-02	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14145	delivery	5	48
35874	2020-03-02 08:31:42	2020-03-02	8	[{"id_menu":5,"count":1}]	9006	delivery	5	13
35875	2020-03-02 08:40:07	2020-03-02	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	2402	pick-up	0	20
35876	2020-03-02 08:43:40	2020-03-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4077	delivery	5	22
35877	2020-03-02 08:51:57	2020-03-02	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	14119	delivery	5	56
35878	2020-03-02 08:56:17	2020-03-02	9	[{"id_menu":7,"count":1}]	14165	delivery	5	14
35879	2020-03-02 09:05:31	2020-03-02	12	[{"id_menu":1,"count":1}]	6609	delivery	5	17
35880	2020-03-02 09:08:28	2020-03-02	14	[{"id_menu":2,"count":1}]	12894	delivery	5	19
35881	2020-03-02 09:27:30	2020-03-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	14117	delivery	5	23
35882	2020-03-02 09:33:13	2020-03-02	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	14174	delivery	5	25
35883	2020-03-02 09:52:54	2020-03-02	8	[{"id_menu":5,"count":1}]	4060	delivery	5	13
35884	2020-03-02 10:13:52	2020-03-02	12	[{"id_menu":1,"count":1}]	4395	pick-up	0	12
35885	2020-03-02 10:26:09	2020-03-02	9	[{"id_menu":6,"count":1}]	655	pick-up	0	9
35886	2020-03-02 10:28:19	2020-03-02	14	[{"id_menu":2,"count":1}]	3478	pick-up	0	14
35887	2020-03-02 10:35:11	2020-03-02	9	[{"id_menu":7,"count":1}]	14164	delivery	5	14
35888	2020-03-02 10:46:51	2020-03-02	14	[{"id_menu":2,"count":1}]	12282	delivery	5	19
35889	2020-03-02 10:49:19	2020-03-02	9	[{"id_menu":6,"count":1}]	14124	delivery	5	14
35890	2020-03-02 10:50:19	2020-03-02	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	13274	delivery	5	26
35891	2020-03-02 10:50:56	2020-03-02	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	5180	pick-up	0	21
35892	2020-03-02 11:06:31	2020-03-02	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2684	pick-up	0	38
35893	2020-03-02 11:12:51	2020-03-02	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	14179	delivery	5	31
35894	2020-03-02 11:19:42	2020-03-02	9	[{"id_menu":7,"count":1}]	1645	pick-up	0	9
35895	2020-03-02 11:29:03	2020-03-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	14141	delivery	5	23
35896	2020-03-02 11:34:47	2020-03-02	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	14202	delivery	5	35
35897	2020-03-02 11:41:36	2020-03-02	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	14178	delivery	5	31
35898	2020-03-02 11:42:57	2020-03-02	9	[{"id_menu":6,"count":1}]	14150	delivery	5	14
35899	2020-03-02 12:02:45	2020-03-02	9	[{"id_menu":7,"count":1}]	6990	pick-up	0	9
35900	2020-03-02 12:22:21	2020-03-02	14	[{"id_menu":2,"count":1}]	14146	pick-up	0	14
35901	2020-03-02 12:32:59	2020-03-02	12	[{"id_menu":3,"count":1}]	2797	delivery	5	17
35902	2020-03-02 12:34:28	2020-03-02	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9362	delivery	5	22
35903	2020-03-02 12:37:02	2020-03-02	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2753	delivery	5	34
35904	2020-03-02 12:43:34	2020-03-02	12	[{"id_menu":3,"count":1}]	4986	pick-up	0	12
35905	2020-03-02 12:47:22	2020-03-02	9	[{"id_menu":6,"count":1}]	14144	delivery	5	14
35906	2020-03-02 12:50:06	2020-03-02	9	[{"id_menu":6,"count":1}]	11532	delivery	5	14
35907	2020-03-02 12:58:51	2020-03-02	17	[{"id_menu":4,"count":1}]	3382	pick-up	0	17
35908	2020-03-02 13:05:37	2020-03-02	8	[{"id_menu":5,"count":1}]	7200	pick-up	0	8
35909	2020-03-02 13:09:14	2020-03-02	9	[{"id_menu":7,"count":1}]	3959	pick-up	0	9
35910	2020-03-02 13:10:30	2020-03-02	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	10783	pick-up	0	23
35911	2020-03-02 13:24:39	2020-03-02	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	786	pick-up	0	38
35912	2020-03-02 13:24:57	2020-03-02	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	9300	delivery	5	28
35913	2020-03-02 13:27:36	2020-03-02	8	[{"id_menu":5,"count":1}]	8394	pick-up	0	8
35914	2020-03-02 13:30:46	2020-03-02	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11083	pick-up	0	35
35915	2020-03-02 13:40:09	2020-03-02	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	37	delivery	5	29
35916	2020-03-02 13:45:53	2020-03-02	9	[{"id_menu":6,"count":1}]	489	delivery	5	14
35917	2020-03-02 13:48:54	2020-03-02	9	[{"id_menu":7,"count":1}]	14205	delivery	5	14
35918	2020-03-02 13:53:37	2020-03-02	29	[{"id_menu":3,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9325	delivery	5	34
35919	2020-03-02 13:54:08	2020-03-02	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	10702	delivery	5	43
35920	2020-03-02 13:56:47	2020-03-02	9	[{"id_menu":7,"count":1}]	14157	delivery	5	14
35921	2020-03-02 14:11:04	2020-03-02	14	[{"id_menu":2,"count":1}]	2827	pick-up	0	14
35922	2020-03-02 14:25:18	2020-03-02	12	[{"id_menu":3,"count":2}]	2760	pick-up	0	12
35923	2020-03-02 14:25:53	2020-03-02	12	[{"id_menu":1,"count":1}]	4132	pick-up	0	12
35924	2020-03-02 14:27:38	2020-03-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3363	delivery	5	22
35925	2020-03-02 14:41:31	2020-03-02	12	[{"id_menu":1,"count":1}]	2651	pick-up	0	12
35926	2020-03-02 14:43:25	2020-03-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14172	delivery	5	31
35927	2020-03-02 14:52:06	2020-03-02	8	[{"id_menu":5,"count":1}]	14116	pick-up	0	8
35928	2020-03-02 14:53:47	2020-03-02	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12057	delivery	5	22
35929	2020-03-02 15:01:57	2020-03-02	9	[{"id_menu":7,"count":1}]	4161	pick-up	0	9
35930	2020-03-02 15:05:29	2020-03-02	8	[{"id_menu":5,"count":1}]	13837	pick-up	0	8
35931	2020-03-02 15:13:33	2020-03-02	14	[{"id_menu":2,"count":1}]	743	pick-up	0	14
35932	2020-03-02 15:23:08	2020-03-02	9	[{"id_menu":7,"count":1}]	14197	delivery	5	14
35933	2020-03-02 15:25:33	2020-03-02	14	[{"id_menu":2,"count":1}]	2110	pick-up	0	14
35934	2020-03-02 15:28:25	2020-03-02	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	14104	delivery	5	30
35935	2020-03-02 15:41:24	2020-03-02	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2303	pick-up	0	17
35936	2020-03-02 15:44:03	2020-03-02	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2443	pick-up	0	29
35937	2020-03-02 15:46:30	2020-03-02	17	[{"id_menu":4,"count":1}]	5756	delivery	5	22
35938	2020-03-02 15:51:59	2020-03-02	9	[{"id_menu":7,"count":1}]	14167	delivery	5	14
35939	2020-03-02 15:52:58	2020-03-02	12	[{"id_menu":3,"count":1}]	6330	delivery	5	17
35940	2020-03-02 16:00:05	2020-03-02	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13041	delivery	5	22
35941	2020-03-02 16:04:37	2020-03-02	12	[{"id_menu":1,"count":1}]	14115	pick-up	0	12
35942	2020-03-02 16:18:34	2020-03-02	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	14102	delivery	5	31
35943	2020-03-02 16:26:21	2020-03-02	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	14140	delivery	5	28
35944	2020-03-02 16:30:53	2020-03-02	9	[{"id_menu":6,"count":1}]	4945	delivery	5	14
35945	2020-03-02 16:36:12	2020-03-02	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	4546	delivery	5	27
35946	2020-03-02 16:43:57	2020-03-02	12	[{"id_menu":1,"count":1}]	12966	delivery	5	17
35947	2020-03-02 16:47:31	2020-03-02	8	[{"id_menu":5,"count":1}]	14123	delivery	5	13
35948	2020-03-02 16:57:40	2020-03-02	14	[{"id_menu":2,"count":1}]	10709	delivery	5	19
35949	2020-03-02 17:07:49	2020-03-02	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1427	pick-up	0	21
35950	2020-03-02 17:12:05	2020-03-02	9	[{"id_menu":6,"count":1}]	7644	pick-up	0	9
35951	2020-03-02 17:23:59	2020-03-02	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1679	delivery	5	28
35952	2020-03-02 17:25:00	2020-03-02	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	10175	delivery	5	39
35953	2020-03-02 17:25:07	2020-03-02	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2003	pick-up	0	21
35954	2020-03-02 17:40:19	2020-03-02	17	[{"id_menu":4,"count":1}]	14136	delivery	5	22
35955	2020-03-02 17:44:31	2020-03-02	17	[{"id_menu":4,"count":1}]	9580	delivery	5	22
35956	2020-03-02 17:44:44	2020-03-02	12	[{"id_menu":1,"count":2}]	14189	pick-up	0	12
35957	2020-03-02 17:46:18	2020-03-02	8	[{"id_menu":5,"count":1}]	4624	pick-up	0	8
35958	2020-03-02 17:47:35	2020-03-02	14	[{"id_menu":2,"count":1}]	436	pick-up	0	14
35959	2020-03-02 17:54:57	2020-03-02	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3155	pick-up	0	46
35960	2020-03-02 17:56:38	2020-03-02	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	6302	delivery	5	27
35961	2020-03-02 17:57:42	2020-03-02	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4646	delivery	5	42
35962	2020-03-02 18:02:00	2020-03-02	17	[{"id_menu":4,"count":1}]	281	delivery	5	22
35963	2020-03-02 18:29:34	2020-03-02	9	[{"id_menu":6,"count":1}]	3089	pick-up	0	9
35964	2020-03-02 18:31:23	2020-03-02	8	[{"id_menu":5,"count":1}]	7963	pick-up	0	8
35965	2020-03-02 18:35:00	2020-03-02	14	[{"id_menu":2,"count":2}]	14192	pick-up	0	14
35966	2020-03-02 19:15:26	2020-03-02	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	8240	pick-up	0	22
35967	2020-03-02 19:18:02	2020-03-02	14	[{"id_menu":2,"count":2}]	13587	delivery	5	19
35968	2020-03-02 19:20:23	2020-03-02	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	13643	pick-up	0	26
35969	2020-03-02 19:24:33	2020-03-02	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10418	delivery	5	49
35970	2020-03-02 19:28:16	2020-03-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	14183	delivery	5	22
35971	2020-03-02 19:34:58	2020-03-02	12	[{"id_menu":3,"count":1}]	7472	delivery	5	17
35972	2020-03-02 19:38:24	2020-03-02	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	9908	delivery	5	25
35973	2020-03-02 19:47:28	2020-03-02	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14186	delivery	5	39
35974	2020-03-02 19:57:02	2020-03-02	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1317	pick-up	0	26
35975	2020-03-02 19:57:53	2020-03-02	8	[{"id_menu":5,"count":1}]	14148	pick-up	0	8
35976	2020-03-02 20:01:52	2020-03-02	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	14127	pick-up	0	22
35977	2020-03-02 20:16:27	2020-03-02	9	[{"id_menu":7,"count":1}]	10011	delivery	5	14
35978	2020-03-02 20:24:45	2020-03-02	9	[{"id_menu":7,"count":1}]	9190	pick-up	0	9
35979	2020-03-02 20:25:23	2020-03-02	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9994	delivery	5	54
35980	2020-03-02 20:31:23	2020-03-02	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14168	delivery	5	22
35981	2020-03-02 20:34:28	2020-03-02	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12204	delivery	5	35
35982	2020-03-02 20:41:55	2020-03-02	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3932	delivery	5	27
35983	2020-03-02 20:44:52	2020-03-02	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	2507	delivery	5	29
35984	2020-03-02 20:44:55	2020-03-02	12	[{"id_menu":1,"count":1}]	5255	delivery	5	17
35985	2020-03-02 20:49:38	2020-03-02	14	[{"id_menu":2,"count":1}]	3697	delivery	5	19
35986	2020-03-02 20:51:58	2020-03-02	17	[{"id_menu":4,"count":1}]	9977	delivery	5	22
35987	2020-03-02 21:01:42	2020-03-02	9	[{"id_menu":7,"count":1}]	147	pick-up	0	9
35988	2020-03-02 21:19:52	2020-03-02	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	14182	delivery	5	26
35989	2020-03-02 21:32:36	2020-03-02	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	14031	delivery	5	40
35990	2020-03-02 21:38:43	2020-03-02	9	[{"id_menu":7,"count":2}]	3679	delivery	5	14
35991	2020-03-02 21:42:42	2020-03-02	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3040	delivery	5	31
35992	2020-03-02 21:44:47	2020-03-02	9	[{"id_menu":6,"count":1}]	6113	delivery	5	14
35993	2020-03-02 21:48:08	2020-03-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4397	pick-up	0	23
35994	2020-03-02 21:57:08	2020-03-02	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	14153	delivery	5	26
35995	2020-03-02 21:58:14	2020-03-02	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	8955	delivery	5	52
35996	2020-03-02 22:01:34	2020-03-02	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4652	pick-up	0	34
35997	2020-03-02 22:06:51	2020-03-02	14	[{"id_menu":2,"count":1}]	5649	delivery	5	19
35998	2020-03-02 22:07:56	2020-03-02	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14207	delivery	5	35
35999	2020-03-02 22:10:46	2020-03-02	9	[{"id_menu":6,"count":1}]	14142	delivery	5	14
36000	2020-03-02 22:28:36	2020-03-02	12	[{"id_menu":1,"count":1}]	8184	delivery	5	17
36001	2020-03-02 22:40:26	2020-03-02	9	[{"id_menu":7,"count":2}]	13002	delivery	5	14
36002	2020-03-02 22:40:32	2020-03-02	9	[{"id_menu":7,"count":1}]	5889	delivery	5	14
36003	2020-03-02 23:00:01	2020-03-02	9	[{"id_menu":7,"count":1}]	11941	delivery	5	14
36004	2020-03-02 23:05:01	2020-03-02	9	[{"id_menu":7,"count":1}]	14128	delivery	5	14
36005	2020-03-02 23:05:10	2020-03-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	10221	delivery	5	28
36006	2020-03-02 23:21:21	2020-03-02	14	[{"id_menu":2,"count":1}]	14151	delivery	5	19
36007	2020-03-02 23:32:17	2020-03-02	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7943	delivery	5	30
36008	2020-03-02 23:34:38	2020-03-02	9	[{"id_menu":6,"count":3}]	14171	delivery	5	14
36009	2020-03-02 23:49:50	2020-03-02	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	10622	pick-up	0	22
36010	2020-03-03 00:07:32	2020-03-03	12	[{"id_menu":3,"count":1}]	13677	pick-up	0	12
36011	2020-03-03 00:08:42	2020-03-03	17	[{"id_menu":4,"count":1}]	14259	delivery	5	22
36012	2020-03-03 00:15:45	2020-03-03	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1563	pick-up	0	26
36013	2020-03-03 00:19:46	2020-03-03	8	[{"id_menu":5,"count":1}]	13015	delivery	5	13
36014	2020-03-03 00:31:51	2020-03-03	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14287	delivery	5	51
36015	2020-03-03 00:39:09	2020-03-03	12	[{"id_menu":1,"count":1}]	14213	delivery	5	17
36016	2020-03-03 00:59:21	2020-03-03	8	[{"id_menu":5,"count":1}]	2159	delivery	5	13
36017	2020-03-03 01:02:24	2020-03-03	12	[{"id_menu":3,"count":1}]	10968	delivery	5	17
36018	2020-03-03 01:02:43	2020-03-03	17	[{"id_menu":4,"count":1}]	1225	pick-up	0	17
36019	2020-03-03 01:10:13	2020-03-03	14	[{"id_menu":2,"count":1}]	7834	pick-up	0	14
36020	2020-03-03 01:13:34	2020-03-03	14	[{"id_menu":2,"count":1}]	13767	delivery	5	19
36021	2020-03-03 01:13:35	2020-03-03	9	[{"id_menu":6,"count":2}]	14212	delivery	5	14
36022	2020-03-03 01:16:30	2020-03-03	9	[{"id_menu":7,"count":1}]	3490	delivery	5	14
36023	2020-03-03 01:17:44	2020-03-03	8	[{"id_menu":5,"count":1}]	10650	delivery	5	13
36024	2020-03-03 01:18:59	2020-03-03	12	[{"id_menu":3,"count":1}]	1930	pick-up	0	12
36025	2020-03-03 01:29:19	2020-03-03	12	[{"id_menu":3,"count":1}]	14297	delivery	5	17
36026	2020-03-03 01:31:34	2020-03-03	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	13257	delivery	5	40
36027	2020-03-03 01:38:22	2020-03-03	8	[{"id_menu":5,"count":1}]	14296	delivery	5	13
36028	2020-03-03 01:41:08	2020-03-03	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	6987	pick-up	0	26
36029	2020-03-03 01:43:13	2020-03-03	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7444	delivery	5	28
36030	2020-03-03 01:46:52	2020-03-03	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	11491	pick-up	0	26
36031	2020-03-03 01:49:21	2020-03-03	12	[{"id_menu":3,"count":1}]	5149	delivery	5	17
36032	2020-03-03 01:49:52	2020-03-03	8	[{"id_menu":5,"count":1}]	14323	delivery	5	13
36033	2020-03-03 02:13:30	2020-03-03	12	[{"id_menu":1,"count":1}]	14325	delivery	5	17
36034	2020-03-03 02:22:32	2020-03-03	12	[{"id_menu":1,"count":1}]	11187	delivery	5	17
36035	2020-03-03 02:23:20	2020-03-03	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2633	delivery	5	26
36036	2020-03-03 02:23:53	2020-03-03	8	[{"id_menu":5,"count":2}]	205	pick-up	0	8
36037	2020-03-03 02:26:03	2020-03-03	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1993	pick-up	0	31
36038	2020-03-03 02:27:38	2020-03-03	14	[{"id_menu":2,"count":1}]	13690	pick-up	0	14
36039	2020-03-03 02:32:00	2020-03-03	12	[{"id_menu":3,"count":1}]	14224	delivery	5	17
36040	2020-03-03 02:37:24	2020-03-03	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14329	delivery	5	22
36041	2020-03-03 02:41:20	2020-03-03	12	[{"id_menu":1,"count":1}]	10354	delivery	5	17
36042	2020-03-03 02:42:57	2020-03-03	12	[{"id_menu":1,"count":1}]	2383	delivery	5	17
36043	2020-03-03 03:02:45	2020-03-03	14	[{"id_menu":2,"count":1}]	14220	delivery	5	19
36044	2020-03-03 03:12:31	2020-03-03	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	14294	delivery	5	36
36045	2020-03-03 03:12:41	2020-03-03	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	14251	delivery	5	36
36046	2020-03-03 03:14:33	2020-03-03	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	3804	delivery	5	28
36047	2020-03-03 03:18:02	2020-03-03	9	[{"id_menu":7,"count":1}]	2519	pick-up	0	9
36048	2020-03-03 03:21:39	2020-03-03	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	9061	pick-up	0	29
36049	2020-03-03 03:29:54	2020-03-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	14260	delivery	5	28
36050	2020-03-03 03:34:13	2020-03-03	12	[{"id_menu":3,"count":2}]	5811	pick-up	0	12
36051	2020-03-03 03:44:39	2020-03-03	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	2072	delivery	5	42
36052	2020-03-03 03:44:57	2020-03-03	12	[{"id_menu":3,"count":1}]	9808	delivery	5	17
36053	2020-03-03 03:51:18	2020-03-03	12	[{"id_menu":1,"count":1}]	7053	pick-up	0	12
36054	2020-03-03 03:51:21	2020-03-03	8	[{"id_menu":5,"count":1}]	8230	delivery	5	13
36055	2020-03-03 03:51:24	2020-03-03	17	[{"id_menu":4,"count":1}]	6977	pick-up	0	17
36056	2020-03-03 03:53:02	2020-03-03	9	[{"id_menu":6,"count":1}]	2295	pick-up	0	9
36057	2020-03-03 03:53:06	2020-03-03	8	[{"id_menu":5,"count":1}]	12532	delivery	5	13
36058	2020-03-03 03:56:29	2020-03-03	12	[{"id_menu":1,"count":1}]	12109	delivery	5	17
36059	2020-03-03 03:56:37	2020-03-03	9	[{"id_menu":6,"count":1}]	3662	delivery	5	14
36060	2020-03-03 04:08:08	2020-03-03	12	[{"id_menu":3,"count":1}]	5354	delivery	5	17
36061	2020-03-03 04:10:28	2020-03-03	9	[{"id_menu":7,"count":1}]	6937	delivery	5	14
36062	2020-03-03 04:11:33	2020-03-03	12	[{"id_menu":1,"count":1}]	7648	delivery	5	17
36063	2020-03-03 04:13:13	2020-03-03	9	[{"id_menu":7,"count":1}]	14279	delivery	5	14
36064	2020-03-03 04:16:54	2020-03-03	14	[{"id_menu":2,"count":1}]	7965	delivery	5	19
36065	2020-03-03 04:18:14	2020-03-03	12	[{"id_menu":1,"count":1}]	363	pick-up	0	12
36066	2020-03-03 04:21:14	2020-03-03	12	[{"id_menu":3,"count":1}]	14232	delivery	5	17
36067	2020-03-03 04:31:52	2020-03-03	9	[{"id_menu":7,"count":1}]	4673	pick-up	0	9
36068	2020-03-03 04:35:21	2020-03-03	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14317	delivery	5	36
36069	2020-03-03 04:39:48	2020-03-03	17	[{"id_menu":4,"count":1}]	7694	delivery	5	22
36070	2020-03-03 04:43:06	2020-03-03	8	[{"id_menu":5,"count":3}]	14237	delivery	5	13
36071	2020-03-03 04:45:04	2020-03-03	9	[{"id_menu":7,"count":1}]	3877	pick-up	0	9
36072	2020-03-03 04:47:15	2020-03-03	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1156	pick-up	0	22
36073	2020-03-03 04:51:42	2020-03-03	8	[{"id_menu":5,"count":1}]	10115	pick-up	0	8
36074	2020-03-03 04:51:57	2020-03-03	14	[{"id_menu":2,"count":1}]	14308	delivery	5	19
36075	2020-03-03 04:57:48	2020-03-03	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6075	delivery	5	23
36076	2020-03-03 05:04:00	2020-03-03	12	[{"id_menu":3,"count":1}]	1313	pick-up	0	12
36077	2020-03-03 05:08:26	2020-03-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14221	delivery	5	31
36078	2020-03-03 05:11:00	2020-03-03	17	[{"id_menu":4,"count":1}]	14299	pick-up	0	17
36079	2020-03-03 05:17:48	2020-03-03	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	14254	delivery	5	28
36080	2020-03-03 05:18:27	2020-03-03	8	[{"id_menu":5,"count":1}]	14283	pick-up	0	8
36081	2020-03-03 05:18:54	2020-03-03	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1594	pick-up	0	21
36082	2020-03-03 05:24:20	2020-03-03	14	[{"id_menu":2,"count":1}]	5506	delivery	5	19
36083	2020-03-03 05:29:37	2020-03-03	14	[{"id_menu":2,"count":1}]	14293	delivery	5	19
36084	2020-03-03 05:32:16	2020-03-03	17	[{"id_menu":4,"count":1}]	14262	delivery	5	22
36085	2020-03-03 05:37:18	2020-03-03	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	14315	pick-up	0	21
36086	2020-03-03 05:45:25	2020-03-03	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14288	delivery	5	31
36087	2020-03-03 05:45:40	2020-03-03	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	684	pick-up	0	25
36088	2020-03-03 05:55:26	2020-03-03	12	[{"id_menu":1,"count":1}]	10255	delivery	5	17
36089	2020-03-03 06:10:29	2020-03-03	8	[{"id_menu":5,"count":1}]	14240	delivery	5	13
36090	2020-03-03 06:16:14	2020-03-03	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	3864	pick-up	0	24
36091	2020-03-03 06:23:28	2020-03-03	12	[{"id_menu":3,"count":1}]	14236	delivery	5	17
36092	2020-03-03 06:27:23	2020-03-03	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	9671	delivery	5	22
36093	2020-03-03 06:28:47	2020-03-03	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	640	pick-up	0	21
36094	2020-03-03 06:31:12	2020-03-03	14	[{"id_menu":2,"count":1}]	13844	pick-up	0	14
36095	2020-03-03 06:34:10	2020-03-03	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2916	pick-up	0	26
36096	2020-03-03 06:39:22	2020-03-03	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	14257	delivery	5	30
36097	2020-03-03 06:45:16	2020-03-03	14	[{"id_menu":2,"count":1}]	1681	pick-up	0	14
36098	2020-03-03 07:00:45	2020-03-03	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1818	delivery	5	28
36099	2020-03-03 07:08:16	2020-03-03	8	[{"id_menu":5,"count":1}]	4539	delivery	5	13
36100	2020-03-03 07:16:24	2020-03-03	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14244	delivery	5	22
36101	2020-03-03 07:34:38	2020-03-03	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7888	delivery	5	35
36102	2020-03-03 07:40:25	2020-03-03	17	[{"id_menu":4,"count":1}]	14266	delivery	5	22
36103	2020-03-03 07:41:00	2020-03-03	9	[{"id_menu":6,"count":1}]	826	pick-up	0	9
36104	2020-03-03 07:44:35	2020-03-03	12	[{"id_menu":1,"count":1}]	1513	delivery	5	17
36105	2020-03-03 07:56:49	2020-03-03	12	[{"id_menu":1,"count":1}]	5551	pick-up	0	12
36106	2020-03-03 08:04:15	2020-03-03	9	[{"id_menu":6,"count":1}]	1617	pick-up	0	9
36107	2020-03-03 08:10:01	2020-03-03	14	[{"id_menu":2,"count":1}]	7290	delivery	5	19
36108	2020-03-03 08:17:56	2020-03-03	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	14311	delivery	5	38
36109	2020-03-03 08:19:21	2020-03-03	9	[{"id_menu":6,"count":1}]	14265	delivery	5	14
36110	2020-03-03 08:19:40	2020-03-03	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14255	delivery	5	37
36111	2020-03-03 08:22:07	2020-03-03	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	14219	delivery	5	43
36112	2020-03-03 08:24:08	2020-03-03	17	[{"id_menu":4,"count":1}]	14238	delivery	5	22
36113	2020-03-03 08:29:07	2020-03-03	14	[{"id_menu":2,"count":1}]	13697	delivery	5	19
36114	2020-03-03 08:56:08	2020-03-03	8	[{"id_menu":5,"count":1}]	14328	pick-up	0	8
36115	2020-03-03 08:56:33	2020-03-03	9	[{"id_menu":7,"count":1}]	3006	delivery	5	14
36116	2020-03-03 09:02:00	2020-03-03	14	[{"id_menu":2,"count":1}]	8655	pick-up	0	14
36117	2020-03-03 09:14:01	2020-03-03	12	[{"id_menu":3,"count":1}]	1296	pick-up	0	12
36118	2020-03-03 09:24:03	2020-03-03	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3958	delivery	5	51
36119	2020-03-03 09:25:40	2020-03-03	12	[{"id_menu":1,"count":1}]	1760	delivery	5	17
36120	2020-03-03 09:28:08	2020-03-03	9	[{"id_menu":7,"count":1}]	14261	pick-up	0	9
36121	2020-03-03 09:29:47	2020-03-03	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	14302	delivery	5	34
36122	2020-03-03 09:33:39	2020-03-03	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	10791	delivery	5	34
36123	2020-03-03 09:36:01	2020-03-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	14209	delivery	5	28
36124	2020-03-03 09:37:54	2020-03-03	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6472	delivery	5	45
36125	2020-03-03 09:44:26	2020-03-03	12	[{"id_menu":3,"count":1}]	11089	pick-up	0	12
36126	2020-03-03 09:46:27	2020-03-03	17	[{"id_menu":4,"count":1}]	14239	pick-up	0	17
36127	2020-03-03 09:56:31	2020-03-03	9	[{"id_menu":7,"count":1}]	9294	delivery	5	14
36128	2020-03-03 10:06:58	2020-03-03	9	[{"id_menu":6,"count":1}]	1076	pick-up	0	9
36129	2020-03-03 10:08:53	2020-03-03	8	[{"id_menu":5,"count":1}]	14320	delivery	5	13
36130	2020-03-03 10:15:02	2020-03-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	14228	delivery	5	28
36131	2020-03-03 10:22:39	2020-03-03	17	[{"id_menu":4,"count":1}]	14264	delivery	5	22
36132	2020-03-03 10:25:27	2020-03-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	891	delivery	5	31
36133	2020-03-03 10:28:05	2020-03-03	17	[{"id_menu":4,"count":1}]	777	delivery	5	22
36134	2020-03-03 10:29:01	2020-03-03	14	[{"id_menu":2,"count":1}]	14218	delivery	5	19
36135	2020-03-03 10:31:50	2020-03-03	12	[{"id_menu":3,"count":1}]	11357	pick-up	0	12
36136	2020-03-03 10:40:27	2020-03-03	17	[{"id_menu":4,"count":1}]	2959	pick-up	0	17
36137	2020-03-03 10:40:48	2020-03-03	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14292	delivery	5	51
36138	2020-03-03 10:47:45	2020-03-03	12	[{"id_menu":1,"count":1}]	1528	pick-up	0	12
36139	2020-03-03 10:48:36	2020-03-03	8	[{"id_menu":5,"count":1}]	2447	pick-up	0	8
36140	2020-03-03 10:57:39	2020-03-03	12	[{"id_menu":1,"count":1}]	4800	pick-up	0	12
36141	2020-03-03 10:58:01	2020-03-03	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	8718	delivery	5	26
36142	2020-03-03 11:05:55	2020-03-03	17	[{"id_menu":4,"count":1}]	4076	delivery	5	22
36143	2020-03-03 11:14:37	2020-03-03	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	14249	delivery	5	26
36144	2020-03-03 11:16:28	2020-03-03	9	[{"id_menu":6,"count":1}]	9106	pick-up	0	9
36145	2020-03-03 11:23:43	2020-03-03	12	[{"id_menu":1,"count":1}]	6464	delivery	5	17
36146	2020-03-03 11:25:59	2020-03-03	9	[{"id_menu":6,"count":1}]	12955	delivery	5	14
36147	2020-03-03 11:54:06	2020-03-03	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5170	delivery	5	40
36148	2020-03-03 11:59:40	2020-03-03	8	[{"id_menu":5,"count":2}]	88	delivery	5	13
36149	2020-03-03 12:07:43	2020-03-03	9	[{"id_menu":6,"count":1}]	628	delivery	5	14
36150	2020-03-03 12:11:29	2020-03-03	9	[{"id_menu":7,"count":1}]	14316	delivery	5	14
36151	2020-03-03 12:56:12	2020-03-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3000	pick-up	0	23
36152	2020-03-03 13:09:19	2020-03-03	8	[{"id_menu":5,"count":1}]	14324	delivery	5	13
36153	2020-03-03 13:10:34	2020-03-03	9	[{"id_menu":6,"count":1}]	14250	pick-up	0	9
36154	2020-03-03 13:23:20	2020-03-03	12	[{"id_menu":1,"count":1}]	4281	delivery	5	17
36155	2020-03-03 13:24:54	2020-03-03	12	[{"id_menu":1,"count":1}]	9626	delivery	5	17
36156	2020-03-03 13:26:46	2020-03-03	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	14234	delivery	5	26
36157	2020-03-03 13:27:50	2020-03-03	8	[{"id_menu":5,"count":1}]	14327	pick-up	0	8
36158	2020-03-03 13:30:10	2020-03-03	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10235	delivery	5	23
36159	2020-03-03 13:37:50	2020-03-03	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	14285	delivery	5	27
36160	2020-03-03 13:44:10	2020-03-03	9	[{"id_menu":6,"count":1}]	2276	pick-up	0	9
36161	2020-03-03 13:52:53	2020-03-03	8	[{"id_menu":5,"count":1}]	14321	delivery	5	13
36162	2020-03-03 13:54:07	2020-03-03	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12725	delivery	5	31
36163	2020-03-03 14:00:17	2020-03-03	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14230	delivery	5	43
36164	2020-03-03 14:04:39	2020-03-03	12	[{"id_menu":1,"count":1}]	10575	delivery	5	17
36165	2020-03-03 14:07:53	2020-03-03	12	[{"id_menu":3,"count":1}]	14222	delivery	5	17
36166	2020-03-03 14:15:10	2020-03-03	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1579	delivery	5	45
36167	2020-03-03 14:17:15	2020-03-03	9	[{"id_menu":6,"count":1}]	14284	pick-up	0	9
36168	2020-03-03 14:17:22	2020-03-03	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10429	delivery	5	31
36169	2020-03-03 14:19:20	2020-03-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5192	delivery	5	28
36170	2020-03-03 14:24:07	2020-03-03	8	[{"id_menu":5,"count":1}]	4007	delivery	5	13
36171	2020-03-03 14:26:54	2020-03-03	12	[{"id_menu":3,"count":1}]	14216	delivery	5	17
36172	2020-03-03 14:31:13	2020-03-03	12	[{"id_menu":1,"count":1}]	14211	delivery	5	17
36173	2020-03-03 14:41:27	2020-03-03	9	[{"id_menu":7,"count":1}]	6103	delivery	5	14
36174	2020-03-03 14:41:40	2020-03-03	12	[{"id_menu":1,"count":1}]	14314	pick-up	0	12
36175	2020-03-03 15:06:29	2020-03-03	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14286	delivery	5	37
36176	2020-03-03 15:11:08	2020-03-03	9	[{"id_menu":7,"count":1}]	8543	delivery	5	14
36177	2020-03-03 15:18:08	2020-03-03	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	12282	delivery	5	35
36178	2020-03-03 15:18:21	2020-03-03	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3127	delivery	5	28
36179	2020-03-03 15:24:29	2020-03-03	8	[{"id_menu":5,"count":1}]	14280	delivery	5	13
36180	2020-03-03 15:31:42	2020-03-03	12	[{"id_menu":1,"count":1}]	12600	delivery	5	17
36181	2020-03-03 15:34:35	2020-03-03	9	[{"id_menu":6,"count":1}]	14258	pick-up	0	9
36182	2020-03-03 15:35:11	2020-03-03	8	[{"id_menu":5,"count":1}]	14282	delivery	5	13
36183	2020-03-03 15:37:23	2020-03-03	14	[{"id_menu":2,"count":1}]	14217	delivery	5	19
36184	2020-03-03 15:38:22	2020-03-03	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	14248	delivery	5	30
36185	2020-03-03 15:42:30	2020-03-03	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6901	delivery	5	30
36186	2020-03-03 15:46:13	2020-03-03	12	[{"id_menu":3,"count":1}]	14243	delivery	5	17
36187	2020-03-03 15:49:32	2020-03-03	17	[{"id_menu":4,"count":1}]	575	pick-up	0	17
36188	2020-03-03 15:55:13	2020-03-03	12	[{"id_menu":3,"count":1}]	1559	pick-up	0	12
36189	2020-03-03 15:55:18	2020-03-03	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7564	delivery	5	40
36190	2020-03-03 15:59:08	2020-03-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2706	pick-up	0	23
36191	2020-03-03 16:13:38	2020-03-03	8	[{"id_menu":5,"count":1}]	4666	delivery	5	13
36192	2020-03-03 16:25:23	2020-03-03	9	[{"id_menu":7,"count":1}]	3927	pick-up	0	9
36193	2020-03-03 16:26:06	2020-03-03	14	[{"id_menu":2,"count":1}]	7323	delivery	5	19
36194	2020-03-03 16:42:25	2020-03-03	9	[{"id_menu":6,"count":1}]	7383	pick-up	0	9
36195	2020-03-03 17:05:48	2020-03-03	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1910	pick-up	0	24
36196	2020-03-03 17:24:15	2020-03-03	17	[{"id_menu":4,"count":1}]	5308	pick-up	0	17
36197	2020-03-03 17:39:22	2020-03-03	17	[{"id_menu":4,"count":1}]	14309	delivery	5	22
36198	2020-03-03 17:45:48	2020-03-03	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	9878	delivery	5	39
36199	2020-03-03 17:51:32	2020-03-03	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10542	delivery	5	22
36200	2020-03-03 17:52:56	2020-03-03	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	11261	delivery	5	27
36201	2020-03-03 17:54:21	2020-03-03	12	[{"id_menu":1,"count":1}]	546	delivery	5	17
36202	2020-03-03 18:01:04	2020-03-03	17	[{"id_menu":4,"count":2}]	749	delivery	5	22
36203	2020-03-03 18:03:26	2020-03-03	12	[{"id_menu":1,"count":1}]	14215	pick-up	0	12
36204	2020-03-03 18:09:53	2020-03-03	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2310	pick-up	0	21
36205	2020-03-03 18:11:26	2020-03-03	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	5431	delivery	5	22
36206	2020-03-03 18:17:05	2020-03-03	17	[{"id_menu":4,"count":1}]	13441	delivery	5	22
36207	2020-03-03 18:21:12	2020-03-03	9	[{"id_menu":7,"count":1}]	14227	delivery	5	14
36208	2020-03-03 18:25:05	2020-03-03	12	[{"id_menu":1,"count":1}]	3098	pick-up	0	12
36209	2020-03-03 18:25:28	2020-03-03	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14310	delivery	5	36
36210	2020-03-03 18:30:36	2020-03-03	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	14290	pick-up	0	37
36211	2020-03-03 18:37:59	2020-03-03	14	[{"id_menu":2,"count":1}]	14326	pick-up	0	14
36212	2020-03-03 18:51:23	2020-03-03	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	14322	delivery	5	34
36213	2020-03-03 18:54:47	2020-03-03	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	13636	delivery	5	40
36214	2020-03-03 18:55:33	2020-03-03	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	14306	delivery	5	30
36215	2020-03-03 19:09:32	2020-03-03	12	[{"id_menu":3,"count":1}]	13094	delivery	5	17
36216	2020-03-03 19:13:49	2020-03-03	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14281	delivery	5	23
36217	2020-03-03 19:21:30	2020-03-03	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	14269	delivery	5	26
36218	2020-03-03 19:24:44	2020-03-03	9	[{"id_menu":6,"count":1}]	12664	delivery	5	14
36219	2020-03-03 19:27:07	2020-03-03	14	[{"id_menu":2,"count":1}]	13097	delivery	5	19
36220	2020-03-03 19:28:44	2020-03-03	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2512	pick-up	0	29
36221	2020-03-03 19:33:41	2020-03-03	9	[{"id_menu":7,"count":1}]	8743	pick-up	0	9
36222	2020-03-03 19:41:08	2020-03-03	9	[{"id_menu":7,"count":2}]	14256	delivery	5	14
36223	2020-03-03 19:49:24	2020-03-03	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14305	delivery	5	22
36224	2020-03-03 19:54:51	2020-03-03	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	7853	delivery	5	26
36225	2020-03-03 20:07:48	2020-03-03	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	9244	pick-up	0	26
36226	2020-03-03 20:11:02	2020-03-03	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	14277	delivery	5	36
36227	2020-03-03 20:20:06	2020-03-03	12	[{"id_menu":1,"count":1}]	3851	delivery	5	17
36228	2020-03-03 20:28:34	2020-03-03	9	[{"id_menu":7,"count":1}]	2575	delivery	5	14
36229	2020-03-03 20:31:40	2020-03-03	12	[{"id_menu":3,"count":1}]	13334	pick-up	0	12
36230	2020-03-03 20:38:59	2020-03-03	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	5472	delivery	5	40
36231	2020-03-03 20:44:17	2020-03-03	8	[{"id_menu":5,"count":1}]	166	pick-up	0	8
36232	2020-03-03 20:52:18	2020-03-03	12	[{"id_menu":3,"count":1}]	1641	pick-up	0	12
36233	2020-03-03 20:55:56	2020-03-03	14	[{"id_menu":2,"count":1}]	8620	pick-up	0	14
36234	2020-03-03 20:59:39	2020-03-03	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	172	pick-up	0	18
36235	2020-03-03 21:04:16	2020-03-03	12	[{"id_menu":3,"count":1}]	10365	delivery	5	17
36236	2020-03-03 21:20:24	2020-03-03	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	14300	delivery	5	26
36237	2020-03-03 21:20:36	2020-03-03	14	[{"id_menu":2,"count":1}]	9925	delivery	5	19
36238	2020-03-03 21:21:34	2020-03-03	12	[{"id_menu":1,"count":1}]	3366	delivery	5	17
36239	2020-03-03 21:30:46	2020-03-03	9	[{"id_menu":7,"count":1}]	11289	pick-up	0	9
36240	2020-03-03 21:49:25	2020-03-03	17	[{"id_menu":4,"count":1}]	6207	delivery	5	22
36241	2020-03-03 21:59:56	2020-03-03	9	[{"id_menu":6,"count":1}]	3360	delivery	5	14
36242	2020-03-03 22:04:21	2020-03-03	17	[{"id_menu":4,"count":1}]	14276	delivery	5	22
36243	2020-03-03 22:07:13	2020-03-03	14	[{"id_menu":2,"count":1}]	14245	pick-up	0	14
36244	2020-03-03 22:24:16	2020-03-03	17	[{"id_menu":4,"count":1}]	11939	pick-up	0	17
36245	2020-03-03 22:24:40	2020-03-03	12	[{"id_menu":1,"count":1}]	14304	delivery	5	17
36246	2020-03-03 22:30:17	2020-03-03	14	[{"id_menu":2,"count":1}]	14079	delivery	5	19
36247	2020-03-03 22:35:43	2020-03-03	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	8595	pick-up	0	21
36248	2020-03-03 22:43:12	2020-03-03	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14253	delivery	5	36
36249	2020-03-03 22:43:17	2020-03-03	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4342	pick-up	0	22
36250	2020-03-03 22:48:49	2020-03-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4429	delivery	5	28
36251	2020-03-03 22:49:43	2020-03-03	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2193	pick-up	0	21
36252	2020-03-03 22:58:01	2020-03-03	9	[{"id_menu":7,"count":1}]	14246	delivery	5	14
36253	2020-03-03 23:01:21	2020-03-03	12	[{"id_menu":1,"count":1}]	8228	delivery	5	17
36254	2020-03-03 23:02:25	2020-03-03	12	[{"id_menu":3,"count":1}]	4094	pick-up	0	12
36255	2020-03-03 23:18:27	2020-03-03	9	[{"id_menu":6,"count":1}]	10526	delivery	5	14
36256	2020-03-03 23:19:39	2020-03-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8642	delivery	5	31
36257	2020-03-03 23:27:20	2020-03-03	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1314	pick-up	0	43
36258	2020-03-03 23:31:00	2020-03-03	12	[{"id_menu":3,"count":1}]	10033	delivery	5	17
36259	2020-03-03 23:32:52	2020-03-03	9	[{"id_menu":6,"count":1}]	10133	delivery	5	14
36260	2020-03-03 23:39:23	2020-03-03	8	[{"id_menu":5,"count":1}]	518	delivery	5	13
36261	2020-03-04 00:13:29	2020-03-04	9	[{"id_menu":6,"count":2}]	684	pick-up	0	9
36262	2020-03-04 00:24:46	2020-03-04	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	4309	pick-up	0	21
36263	2020-03-04 00:39:17	2020-03-04	17	[{"id_menu":4,"count":1}]	3102	delivery	5	22
36264	2020-03-04 00:42:00	2020-03-04	12	[{"id_menu":3,"count":1}]	11095	delivery	5	17
36265	2020-03-04 00:49:44	2020-03-04	12	[{"id_menu":3,"count":1}]	10394	pick-up	0	12
36266	2020-03-04 00:53:57	2020-03-04	17	[{"id_menu":4,"count":1}]	9847	pick-up	0	17
36267	2020-03-04 00:58:02	2020-03-04	14	[{"id_menu":2,"count":1}]	14331	delivery	5	19
36268	2020-03-04 00:58:47	2020-03-04	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	7777	delivery	5	31
36269	2020-03-04 01:31:17	2020-03-04	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	8737	delivery	5	31
36270	2020-03-04 01:40:47	2020-03-04	12	[{"id_menu":3,"count":1}]	1065	pick-up	0	12
36271	2020-03-04 01:43:56	2020-03-04	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	14382	delivery	5	36
36272	2020-03-04 01:59:07	2020-03-04	9	[{"id_menu":7,"count":1}]	14426	delivery	5	14
36273	2020-03-04 01:59:47	2020-03-04	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14333	delivery	5	36
36274	2020-03-04 02:18:38	2020-03-04	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	14420	delivery	5	29
36275	2020-03-04 02:25:53	2020-03-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	14397	delivery	5	28
36276	2020-03-04 02:26:14	2020-03-04	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	12129	pick-up	0	22
36277	2020-03-04 02:33:04	2020-03-04	14	[{"id_menu":2,"count":1}]	9765	delivery	5	19
36278	2020-03-04 02:34:25	2020-03-04	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	14408	delivery	5	43
36279	2020-03-04 02:35:25	2020-03-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	730	delivery	5	28
36280	2020-03-04 02:42:28	2020-03-04	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	14414	delivery	5	43
36281	2020-03-04 02:45:33	2020-03-04	12	[{"id_menu":3,"count":1}]	10287	delivery	5	17
36282	2020-03-04 02:48:06	2020-03-04	17	[{"id_menu":4,"count":1}]	2110	pick-up	0	17
36283	2020-03-04 03:00:04	2020-03-04	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3350	delivery	5	42
36284	2020-03-04 03:02:53	2020-03-04	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	14395	delivery	5	48
36285	2020-03-04 03:03:45	2020-03-04	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	295	pick-up	0	20
36286	2020-03-04 03:07:15	2020-03-04	12	[{"id_menu":3,"count":1}]	10387	delivery	5	17
36287	2020-03-04 03:09:07	2020-03-04	9	[{"id_menu":6,"count":1}]	13292	delivery	5	14
36288	2020-03-04 03:09:46	2020-03-04	17	[{"id_menu":4,"count":1}]	5214	delivery	5	22
36289	2020-03-04 03:17:46	2020-03-04	9	[{"id_menu":6,"count":3}]	14360	delivery	5	14
36290	2020-03-04 03:32:00	2020-03-04	17	[{"id_menu":4,"count":1}]	13662	pick-up	0	17
36291	2020-03-04 03:33:08	2020-03-04	8	[{"id_menu":5,"count":1}]	10655	delivery	5	13
36292	2020-03-04 03:34:18	2020-03-04	17	[{"id_menu":4,"count":1}]	4166	pick-up	0	17
36293	2020-03-04 03:35:19	2020-03-04	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	10706	pick-up	0	29
36294	2020-03-04 03:35:30	2020-03-04	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	6328	pick-up	0	21
36295	2020-03-04 03:38:50	2020-03-04	17	[{"id_menu":4,"count":1}]	64	delivery	5	22
36296	2020-03-04 03:38:51	2020-03-04	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	14406	delivery	5	46
36297	2020-03-04 03:39:26	2020-03-04	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14357	delivery	5	36
36298	2020-03-04 03:42:59	2020-03-04	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	14386	delivery	5	34
36299	2020-03-04 03:50:11	2020-03-04	14	[{"id_menu":2,"count":1}]	13409	delivery	5	19
36300	2020-03-04 03:54:11	2020-03-04	12	[{"id_menu":1,"count":1}]	12817	delivery	5	17
36301	2020-03-04 03:57:36	2020-03-04	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	3565	delivery	5	26
36302	2020-03-04 04:03:05	2020-03-04	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	14407	pick-up	0	21
36303	2020-03-04 04:05:10	2020-03-04	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10312	delivery	5	36
36304	2020-03-04 04:21:12	2020-03-04	14	[{"id_menu":2,"count":1}]	9014	delivery	5	19
36305	2020-03-04 04:27:51	2020-03-04	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	14428	delivery	5	37
36306	2020-03-04 04:28:16	2020-03-04	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	14337	delivery	5	22
36307	2020-03-04 04:30:15	2020-03-04	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	5428	delivery	5	26
36308	2020-03-04 04:36:18	2020-03-04	9	[{"id_menu":7,"count":1}]	2277	pick-up	0	9
36309	2020-03-04 04:46:25	2020-03-04	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14376	delivery	5	43
36310	2020-03-04 04:46:58	2020-03-04	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14373	delivery	5	22
36311	2020-03-04 04:57:00	2020-03-04	8	[{"id_menu":5,"count":1}]	12142	delivery	5	13
36312	2020-03-04 04:59:26	2020-03-04	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	14343	delivery	5	39
36313	2020-03-04 05:04:17	2020-03-04	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	14411	delivery	5	37
36314	2020-03-04 05:16:02	2020-03-04	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	5945	delivery	5	29
36315	2020-03-04 05:28:09	2020-03-04	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5048	pick-up	0	40
36316	2020-03-04 05:31:06	2020-03-04	12	[{"id_menu":3,"count":1}]	7189	delivery	5	17
36317	2020-03-04 05:37:32	2020-03-04	17	[{"id_menu":4,"count":1}]	11779	pick-up	0	17
36318	2020-03-04 05:55:38	2020-03-04	17	[{"id_menu":4,"count":1}]	2329	delivery	5	22
36319	2020-03-04 06:01:40	2020-03-04	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	12035	pick-up	0	21
36320	2020-03-04 06:08:24	2020-03-04	9	[{"id_menu":6,"count":1}]	7275	pick-up	0	9
36321	2020-03-04 06:15:10	2020-03-04	14	[{"id_menu":2,"count":2}]	2540	delivery	5	19
36322	2020-03-04 06:16:49	2020-03-04	8	[{"id_menu":5,"count":2}]	14366	delivery	5	13
36323	2020-03-04 06:19:39	2020-03-04	12	[{"id_menu":1,"count":1}]	1215	pick-up	0	12
36324	2020-03-04 06:23:33	2020-03-04	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	218	pick-up	0	26
36325	2020-03-04 06:30:17	2020-03-04	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	5979	delivery	5	40
36326	2020-03-04 06:32:11	2020-03-04	12	[{"id_menu":1,"count":1}]	6499	delivery	5	17
36327	2020-03-04 06:40:55	2020-03-04	14	[{"id_menu":2,"count":1}]	3473	delivery	5	19
36328	2020-03-04 06:43:39	2020-03-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	14394	delivery	5	28
36329	2020-03-04 06:45:44	2020-03-04	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	14368	delivery	5	26
36330	2020-03-04 06:50:55	2020-03-04	12	[{"id_menu":1,"count":1}]	14362	pick-up	0	12
36331	2020-03-04 06:52:00	2020-03-04	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13835	pick-up	0	17
36332	2020-03-04 07:00:09	2020-03-04	17	[{"id_menu":4,"count":1}]	12965	pick-up	0	17
36333	2020-03-04 07:02:13	2020-03-04	9	[{"id_menu":7,"count":1}]	5831	delivery	5	14
36334	2020-03-04 07:05:05	2020-03-04	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	4095	delivery	5	22
36335	2020-03-04 07:07:14	2020-03-04	12	[{"id_menu":1,"count":1}]	6163	pick-up	0	12
36336	2020-03-04 07:10:11	2020-03-04	9	[{"id_menu":6,"count":1}]	14361	delivery	5	14
36337	2020-03-04 07:24:32	2020-03-04	9	[{"id_menu":6,"count":1}]	14425	delivery	5	14
36338	2020-03-04 07:24:50	2020-03-04	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5935	delivery	5	39
36339	2020-03-04 07:33:26	2020-03-04	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4112	delivery	5	36
36340	2020-03-04 07:34:34	2020-03-04	14	[{"id_menu":2,"count":1}]	1715	pick-up	0	14
36341	2020-03-04 07:34:38	2020-03-04	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11760	delivery	5	35
36342	2020-03-04 07:38:17	2020-03-04	9	[{"id_menu":6,"count":2}]	948	pick-up	0	9
36343	2020-03-04 07:53:46	2020-03-04	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14398	delivery	5	34
36344	2020-03-04 07:54:22	2020-03-04	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	14415	delivery	5	23
36345	2020-03-04 08:00:51	2020-03-04	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	12835	delivery	5	22
36346	2020-03-04 08:14:16	2020-03-04	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	32	pick-up	0	29
36347	2020-03-04 08:27:32	2020-03-04	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	14424	delivery	5	26
36348	2020-03-04 08:28:35	2020-03-04	9	[{"id_menu":7,"count":1}]	8139	delivery	5	14
36349	2020-03-04 08:32:09	2020-03-04	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	14354	delivery	5	36
36350	2020-03-04 08:32:12	2020-03-04	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	14372	delivery	5	26
36351	2020-03-04 08:36:27	2020-03-04	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2940	delivery	5	27
36352	2020-03-04 08:38:41	2020-03-04	9	[{"id_menu":7,"count":1}]	14370	pick-up	0	9
36353	2020-03-04 08:43:03	2020-03-04	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":2}]	5144	pick-up	0	23
36354	2020-03-04 08:43:56	2020-03-04	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7815	pick-up	0	47
36355	2020-03-04 08:49:05	2020-03-04	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	5642	pick-up	0	22
36356	2020-03-04 09:01:18	2020-03-04	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5174	delivery	5	39
36357	2020-03-04 09:19:33	2020-03-04	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	14410	pick-up	0	31
36358	2020-03-04 09:22:37	2020-03-04	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14002	pick-up	0	30
36359	2020-03-04 09:22:43	2020-03-04	17	[{"id_menu":4,"count":1}]	13705	delivery	5	22
36360	2020-03-04 09:26:32	2020-03-04	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	14365	delivery	5	22
36361	2020-03-04 09:28:36	2020-03-04	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14375	delivery	5	43
36362	2020-03-04 09:28:40	2020-03-04	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":3}]	14349	delivery	5	26
36363	2020-03-04 09:29:01	2020-03-04	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	11491	pick-up	0	29
36364	2020-03-04 09:29:52	2020-03-04	9	[{"id_menu":7,"count":1}]	12836	pick-up	0	9
36365	2020-03-04 09:37:19	2020-03-04	17	[{"id_menu":4,"count":1}]	12127	delivery	5	22
36366	2020-03-04 09:38:41	2020-03-04	14	[{"id_menu":2,"count":1}]	6025	delivery	5	19
36367	2020-03-04 09:40:24	2020-03-04	9	[{"id_menu":6,"count":2}]	8743	pick-up	0	9
36368	2020-03-04 09:43:13	2020-03-04	9	[{"id_menu":6,"count":1}]	315	delivery	5	14
36369	2020-03-04 09:58:54	2020-03-04	17	[{"id_menu":4,"count":1}]	3399	delivery	5	22
36370	2020-03-04 10:01:41	2020-03-04	12	[{"id_menu":3,"count":1}]	12387	pick-up	0	12
36371	2020-03-04 10:21:55	2020-03-04	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	14388	delivery	5	34
36372	2020-03-04 10:23:29	2020-03-04	17	[{"id_menu":4,"count":1}]	13874	delivery	5	22
36373	2020-03-04 10:29:32	2020-03-04	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1343	delivery	5	26
36374	2020-03-04 10:46:57	2020-03-04	14	[{"id_menu":2,"count":1}]	1578	delivery	5	19
36375	2020-03-04 10:47:49	2020-03-04	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14346	pick-up	0	26
36376	2020-03-04 10:50:03	2020-03-04	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1999	delivery	5	26
36377	2020-03-04 10:52:30	2020-03-04	9	[{"id_menu":7,"count":1}]	14429	delivery	5	14
36378	2020-03-04 10:58:09	2020-03-04	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4837	delivery	5	22
36379	2020-03-04 11:03:02	2020-03-04	17	[{"id_menu":4,"count":1}]	7680	delivery	5	22
36380	2020-03-04 11:03:47	2020-03-04	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	5833	delivery	5	25
36381	2020-03-04 11:06:02	2020-03-04	14	[{"id_menu":2,"count":1}]	460	delivery	5	19
36382	2020-03-04 11:22:24	2020-03-04	9	[{"id_menu":6,"count":1}]	14385	pick-up	0	9
36383	2020-03-04 11:26:22	2020-03-04	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	360	pick-up	0	22
36384	2020-03-04 11:29:17	2020-03-04	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14381	delivery	5	31
36385	2020-03-04 11:30:56	2020-03-04	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14416	delivery	5	23
36386	2020-03-04 11:38:42	2020-03-04	8	[{"id_menu":5,"count":1}]	171	pick-up	0	8
36387	2020-03-04 11:38:44	2020-03-04	12	[{"id_menu":1,"count":1}]	14432	pick-up	0	12
36388	2020-03-04 12:05:15	2020-03-04	17	[{"id_menu":4,"count":1}]	1259	pick-up	0	17
36389	2020-03-04 12:12:45	2020-03-04	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14377	delivery	5	45
36390	2020-03-04 12:14:24	2020-03-04	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	12772	delivery	5	38
36391	2020-03-04 12:18:35	2020-03-04	12	[{"id_menu":1,"count":1}]	9758	delivery	5	17
36392	2020-03-04 12:20:36	2020-03-04	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	968	delivery	5	31
36393	2020-03-04 12:22:32	2020-03-04	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	14335	delivery	5	46
36394	2020-03-04 12:22:54	2020-03-04	9	[{"id_menu":6,"count":1}]	14348	delivery	5	14
36395	2020-03-04 12:23:11	2020-03-04	8	[{"id_menu":5,"count":1}]	127	delivery	5	13
36396	2020-03-04 12:27:30	2020-03-04	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	14413	delivery	5	26
36397	2020-03-04 12:28:36	2020-03-04	12	[{"id_menu":1,"count":1}]	8687	delivery	5	17
36398	2020-03-04 12:32:57	2020-03-04	9	[{"id_menu":6,"count":2}]	8020	delivery	5	14
36399	2020-03-04 12:38:00	2020-03-04	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14352	delivery	5	22
36400	2020-03-04 12:56:33	2020-03-04	8	[{"id_menu":5,"count":1}]	5458	pick-up	0	8
36401	2020-03-04 13:04:34	2020-03-04	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10688	delivery	5	45
36402	2020-03-04 13:12:46	2020-03-04	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	14350	delivery	5	40
36403	2020-03-04 13:22:17	2020-03-04	9	[{"id_menu":6,"count":1}]	2662	pick-up	0	9
36404	2020-03-04 13:27:23	2020-03-04	9	[{"id_menu":6,"count":1}]	11532	pick-up	0	9
36405	2020-03-04 13:31:20	2020-03-04	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	14358	pick-up	0	34
36406	2020-03-04 13:37:08	2020-03-04	9	[{"id_menu":6,"count":1}]	10927	delivery	5	14
36407	2020-03-04 13:39:02	2020-03-04	17	[{"id_menu":4,"count":1}]	7279	delivery	5	22
36408	2020-03-04 13:44:47	2020-03-04	12	[{"id_menu":1,"count":1}]	1930	delivery	5	17
36409	2020-03-04 13:46:00	2020-03-04	12	[{"id_menu":1,"count":2}]	14409	delivery	5	17
36410	2020-03-04 13:47:42	2020-03-04	14	[{"id_menu":2,"count":1}]	5149	pick-up	0	14
36411	2020-03-04 14:04:24	2020-03-04	17	[{"id_menu":4,"count":1}]	2891	pick-up	0	17
36412	2020-03-04 14:04:52	2020-03-04	8	[{"id_menu":5,"count":1}]	14202	delivery	5	13
36413	2020-03-04 14:07:01	2020-03-04	14	[{"id_menu":2,"count":1}]	5917	pick-up	0	14
36414	2020-03-04 14:15:57	2020-03-04	12	[{"id_menu":1,"count":1}]	14392	pick-up	0	12
36415	2020-03-04 14:25:53	2020-03-04	14	[{"id_menu":2,"count":1}]	14412	delivery	5	19
36416	2020-03-04 14:28:53	2020-03-04	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2418	pick-up	0	29
36417	2020-03-04 14:32:00	2020-03-04	12	[{"id_menu":3,"count":1}]	14390	delivery	5	17
36418	2020-03-04 14:39:50	2020-03-04	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	161	pick-up	0	20
36419	2020-03-04 14:41:05	2020-03-04	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	4782	delivery	5	26
36420	2020-03-04 14:43:53	2020-03-04	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1344	pick-up	0	21
36421	2020-03-04 14:48:40	2020-03-04	12	[{"id_menu":3,"count":1}]	14427	pick-up	0	12
36422	2020-03-04 14:49:26	2020-03-04	14	[{"id_menu":2,"count":2}]	6015	delivery	5	19
36423	2020-03-04 14:58:28	2020-03-04	9	[{"id_menu":7,"count":1}]	14380	delivery	5	14
36424	2020-03-04 14:59:51	2020-03-04	8	[{"id_menu":5,"count":1}]	14367	delivery	5	13
36425	2020-03-04 15:05:56	2020-03-04	9	[{"id_menu":6,"count":1}]	14417	delivery	5	14
36426	2020-03-04 15:10:53	2020-03-04	14	[{"id_menu":2,"count":1}]	749	delivery	5	19
36427	2020-03-04 15:16:40	2020-03-04	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14342	delivery	5	37
36428	2020-03-04 15:21:54	2020-03-04	12	[{"id_menu":3,"count":1}]	6870	delivery	5	17
36429	2020-03-04 15:27:54	2020-03-04	9	[{"id_menu":6,"count":1}]	14300	delivery	5	14
36430	2020-03-04 15:30:00	2020-03-04	17	[{"id_menu":4,"count":1}]	14405	delivery	5	22
36431	2020-03-04 15:30:47	2020-03-04	8	[{"id_menu":5,"count":1}]	13222	delivery	5	13
36432	2020-03-04 15:42:44	2020-03-04	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	13065	delivery	5	36
36433	2020-03-04 15:47:29	2020-03-04	12	[{"id_menu":3,"count":1}]	14353	delivery	5	17
36434	2020-03-04 16:04:15	2020-03-04	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	14418	delivery	5	30
36435	2020-03-04 16:07:25	2020-03-04	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12542	pick-up	0	26
36436	2020-03-04 16:07:49	2020-03-04	14	[{"id_menu":2,"count":1}]	14430	delivery	5	19
36437	2020-03-04 16:10:45	2020-03-04	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4089	pick-up	0	23
36438	2020-03-04 16:10:49	2020-03-04	14	[{"id_menu":2,"count":1}]	7221	delivery	5	19
36439	2020-03-04 16:11:32	2020-03-04	12	[{"id_menu":1,"count":1}]	14378	pick-up	0	12
36440	2020-03-04 16:16:29	2020-03-04	14	[{"id_menu":2,"count":1}]	3042	delivery	5	19
36441	2020-03-04 16:23:20	2020-03-04	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2619	delivery	5	34
36442	2020-03-04 16:24:16	2020-03-04	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	6326	delivery	5	35
36443	2020-03-04 16:25:22	2020-03-04	9	[{"id_menu":7,"count":1}]	8584	delivery	5	14
36444	2020-03-04 16:28:23	2020-03-04	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	10647	delivery	5	31
36445	2020-03-04 16:33:43	2020-03-04	17	[{"id_menu":4,"count":1}]	757	pick-up	0	17
36446	2020-03-04 16:33:50	2020-03-04	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":3}]	14400	delivery	5	26
36447	2020-03-04 16:37:05	2020-03-04	9	[{"id_menu":6,"count":1}]	3833	delivery	5	14
36448	2020-03-04 16:53:55	2020-03-04	9	[{"id_menu":6,"count":1}]	11267	delivery	5	14
36449	2020-03-04 17:05:27	2020-03-04	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2729	delivery	5	36
36450	2020-03-04 17:19:28	2020-03-04	12	[{"id_menu":3,"count":1}]	14399	pick-up	0	12
36451	2020-03-04 17:28:33	2020-03-04	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	563	pick-up	0	29
36452	2020-03-04 17:32:07	2020-03-04	12	[{"id_menu":1,"count":1}]	11080	pick-up	0	12
36453	2020-03-04 17:42:11	2020-03-04	9	[{"id_menu":7,"count":1}]	8448	pick-up	0	9
36454	2020-03-04 17:43:43	2020-03-04	12	[{"id_menu":3,"count":1}]	4495	delivery	5	17
36455	2020-03-04 17:45:09	2020-03-04	9	[{"id_menu":6,"count":1}]	14359	delivery	5	14
36456	2020-03-04 17:53:21	2020-03-04	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	5854	delivery	5	26
36457	2020-03-04 17:54:17	2020-03-04	8	[{"id_menu":5,"count":1}]	10951	pick-up	0	8
36458	2020-03-04 18:01:49	2020-03-04	9	[{"id_menu":6,"count":1}]	14345	delivery	5	14
36459	2020-03-04 18:10:36	2020-03-04	12	[{"id_menu":3,"count":1}]	14374	delivery	5	17
36460	2020-03-04 18:17:34	2020-03-04	8	[{"id_menu":5,"count":1}]	2332	delivery	5	13
36461	2020-03-04 18:19:19	2020-03-04	9	[{"id_menu":6,"count":1}]	14401	delivery	5	14
36462	2020-03-04 18:28:01	2020-03-04	12	[{"id_menu":1,"count":1}]	9443	delivery	5	17
36463	2020-03-04 18:30:14	2020-03-04	17	[{"id_menu":4,"count":1}]	2782	pick-up	0	17
36464	2020-03-04 18:40:55	2020-03-04	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13080	delivery	5	40
36465	2020-03-04 18:52:50	2020-03-04	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	5768	delivery	5	26
36466	2020-03-04 18:59:09	2020-03-04	8	[{"id_menu":5,"count":1}]	4276	delivery	5	13
36467	2020-03-04 19:03:19	2020-03-04	8	[{"id_menu":5,"count":1}]	7571	delivery	5	13
36468	2020-03-04 19:04:41	2020-03-04	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	13208	pick-up	0	23
36469	2020-03-04 19:32:49	2020-03-04	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	14363	delivery	5	36
36470	2020-03-04 19:38:15	2020-03-04	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2770	delivery	5	22
36471	2020-03-04 19:39:34	2020-03-04	17	[{"id_menu":4,"count":1}]	8369	delivery	5	22
36472	2020-03-04 19:39:36	2020-03-04	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	13535	delivery	5	40
36473	2020-03-04 19:45:37	2020-03-04	8	[{"id_menu":5,"count":1}]	3647	pick-up	0	8
36474	2020-03-04 20:00:56	2020-03-04	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13181	delivery	5	48
36475	2020-03-04 20:06:49	2020-03-04	8	[{"id_menu":5,"count":1}]	12011	pick-up	0	8
36476	2020-03-04 20:13:24	2020-03-04	8	[{"id_menu":5,"count":1}]	9115	pick-up	0	8
36477	2020-03-04 20:15:19	2020-03-04	9	[{"id_menu":7,"count":1}]	14387	delivery	5	14
36478	2020-03-04 20:21:37	2020-03-04	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	14431	delivery	5	26
36479	2020-03-04 20:25:03	2020-03-04	14	[{"id_menu":2,"count":1}]	4413	delivery	5	19
36480	2020-03-04 20:30:23	2020-03-04	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10902	delivery	5	22
36481	2020-03-04 20:34:47	2020-03-04	12	[{"id_menu":1,"count":1}]	14344	delivery	5	17
36482	2020-03-04 20:46:34	2020-03-04	17	[{"id_menu":4,"count":1}]	11089	pick-up	0	17
36483	2020-03-04 20:47:19	2020-03-04	17	[{"id_menu":4,"count":1}]	14396	delivery	5	22
36484	2020-03-04 20:50:15	2020-03-04	8	[{"id_menu":5,"count":1}]	14402	delivery	5	13
36485	2020-03-04 20:51:29	2020-03-04	8	[{"id_menu":5,"count":1}]	7172	delivery	5	13
36486	2020-03-04 20:56:28	2020-03-04	17	[{"id_menu":4,"count":1}]	7787	delivery	5	22
36487	2020-03-04 20:58:57	2020-03-04	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8674	delivery	5	35
36488	2020-03-04 21:17:45	2020-03-04	17	[{"id_menu":4,"count":1}]	14338	delivery	5	22
36489	2020-03-04 21:19:51	2020-03-04	14	[{"id_menu":2,"count":1}]	62	pick-up	0	14
36490	2020-03-04 21:37:03	2020-03-04	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14332	delivery	5	35
36491	2020-03-04 21:53:23	2020-03-04	9	[{"id_menu":6,"count":1}]	6617	delivery	5	14
36492	2020-03-04 22:13:20	2020-03-04	8	[{"id_menu":5,"count":1}]	14351	delivery	5	13
36493	2020-03-04 22:23:35	2020-03-04	17	[{"id_menu":4,"count":1}]	881	delivery	5	22
36494	2020-03-04 22:35:50	2020-03-04	9	[{"id_menu":6,"count":2}]	3171	delivery	5	14
36495	2020-03-04 22:39:50	2020-03-04	12	[{"id_menu":1,"count":1}]	1233	delivery	5	17
36496	2020-03-04 22:48:36	2020-03-04	8	[{"id_menu":5,"count":2}]	14419	delivery	5	13
36497	2020-03-04 22:49:33	2020-03-04	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1509	pick-up	0	31
36498	2020-03-04 22:55:01	2020-03-04	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	4326	pick-up	0	26
36499	2020-03-04 22:57:38	2020-03-04	12	[{"id_menu":1,"count":1}]	8451	delivery	5	17
36500	2020-03-04 23:00:53	2020-03-04	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2633	pick-up	0	22
36501	2020-03-04 23:05:40	2020-03-04	9	[{"id_menu":6,"count":1}]	3066	pick-up	0	9
36502	2020-03-04 23:07:42	2020-03-04	17	[{"id_menu":4,"count":1}]	12494	delivery	5	22
36503	2020-03-04 23:08:06	2020-03-04	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10408	delivery	5	31
36504	2020-03-04 23:12:43	2020-03-04	12	[{"id_menu":1,"count":1}]	14435	delivery	5	17
36505	2020-03-04 23:15:04	2020-03-04	12	[{"id_menu":1,"count":1}]	14369	delivery	5	17
36506	2020-03-04 23:26:00	2020-03-04	8	[{"id_menu":5,"count":1}]	6957	pick-up	0	8
36507	2020-03-04 23:27:17	2020-03-04	8	[{"id_menu":5,"count":1}]	11339	delivery	5	13
36508	2020-03-04 23:31:48	2020-03-04	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	14391	delivery	5	31
36509	2020-03-04 23:33:04	2020-03-04	17	[{"id_menu":4,"count":1}]	14371	pick-up	0	17
36510	2020-03-04 23:34:01	2020-03-04	12	[{"id_menu":3,"count":1}]	7682	delivery	5	17
36511	2020-03-04 23:36:39	2020-03-04	9	[{"id_menu":6,"count":1}]	8300	delivery	5	14
36512	2020-03-04 23:47:40	2020-03-04	9	[{"id_menu":6,"count":2}]	6137	pick-up	0	9
36513	2020-03-04 23:50:33	2020-03-04	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	14393	pick-up	0	38
36514	2020-03-04 23:58:04	2020-03-04	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5928	delivery	5	28
36515	2020-03-05 00:01:30	2020-03-05	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10676	delivery	5	40
36516	2020-03-05 00:05:22	2020-03-05	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	9265	pick-up	0	21
36517	2020-03-05 00:05:51	2020-03-05	9	[{"id_menu":6,"count":1}]	590	delivery	5	14
36518	2020-03-05 00:14:05	2020-03-05	17	[{"id_menu":4,"count":1}]	14473	delivery	5	22
36519	2020-03-05 00:21:08	2020-03-05	8	[{"id_menu":5,"count":1}]	9419	delivery	5	13
36520	2020-03-05 00:25:01	2020-03-05	12	[{"id_menu":1,"count":1}]	10863	delivery	5	17
36521	2020-03-05 00:26:26	2020-03-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2208	delivery	5	22
36522	2020-03-05 00:30:35	2020-03-05	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7968	delivery	5	22
36523	2020-03-05 00:33:39	2020-03-05	14	[{"id_menu":2,"count":1}]	2715	pick-up	0	14
36524	2020-03-05 00:34:08	2020-03-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	220	pick-up	0	26
36525	2020-03-05 00:47:21	2020-03-05	12	[{"id_menu":1,"count":1}]	12666	delivery	5	17
36526	2020-03-05 00:59:09	2020-03-05	9	[{"id_menu":6,"count":1}]	245	pick-up	0	9
36527	2020-03-05 01:06:28	2020-03-05	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	14522	delivery	5	26
36528	2020-03-05 01:10:48	2020-03-05	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	14306	delivery	5	40
36529	2020-03-05 01:15:28	2020-03-05	14	[{"id_menu":2,"count":1}]	374	delivery	5	19
36530	2020-03-05 01:16:07	2020-03-05	12	[{"id_menu":3,"count":1}]	14248	delivery	5	17
36531	2020-03-05 01:18:58	2020-03-05	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	7923	delivery	5	26
36532	2020-03-05 01:20:54	2020-03-05	9	[{"id_menu":6,"count":1}]	11525	delivery	5	14
36533	2020-03-05 01:27:25	2020-03-05	12	[{"id_menu":1,"count":1}]	3125	delivery	5	17
36534	2020-03-05 01:27:33	2020-03-05	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	14500	delivery	5	44
36535	2020-03-05 01:36:48	2020-03-05	9	[{"id_menu":7,"count":1}]	193	delivery	5	14
36536	2020-03-05 01:38:11	2020-03-05	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2623	delivery	5	26
36537	2020-03-05 01:47:23	2020-03-05	8	[{"id_menu":5,"count":1}]	9859	pick-up	0	8
36538	2020-03-05 01:53:55	2020-03-05	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	8832	delivery	5	31
36539	2020-03-05 02:03:38	2020-03-05	14	[{"id_menu":2,"count":1}]	3940	delivery	5	19
36540	2020-03-05 02:05:56	2020-03-05	9	[{"id_menu":7,"count":1}]	7256	delivery	5	14
36541	2020-03-05 02:15:21	2020-03-05	9	[{"id_menu":6,"count":1}]	14441	delivery	5	14
36542	2020-03-05 02:16:56	2020-03-05	9	[{"id_menu":6,"count":1}]	3863	pick-up	0	9
36543	2020-03-05 02:28:13	2020-03-05	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	14537	delivery	5	39
36544	2020-03-05 02:36:04	2020-03-05	12	[{"id_menu":3,"count":1}]	4050	pick-up	0	12
36545	2020-03-05 02:36:47	2020-03-05	14	[{"id_menu":2,"count":1}]	2712	delivery	5	19
36546	2020-03-05 02:41:14	2020-03-05	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	8655	delivery	5	27
36547	2020-03-05 02:44:24	2020-03-05	8	[{"id_menu":5,"count":1}]	14466	delivery	5	13
36548	2020-03-05 02:48:05	2020-03-05	12	[{"id_menu":1,"count":1}]	543	pick-up	0	12
36549	2020-03-05 02:53:59	2020-03-05	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	10710	delivery	5	31
36550	2020-03-05 03:03:38	2020-03-05	9	[{"id_menu":7,"count":1}]	14499	delivery	5	14
36551	2020-03-05 03:06:45	2020-03-05	21	[{"id_menu":3,"count":3},{"id_menu":7,"count":1}]	9554	delivery	5	26
36552	2020-03-05 03:09:28	2020-03-05	14	[{"id_menu":2,"count":1}]	3010	delivery	5	19
36553	2020-03-05 03:10:56	2020-03-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11183	pick-up	0	17
36554	2020-03-05 03:18:11	2020-03-05	14	[{"id_menu":2,"count":1}]	2239	delivery	5	19
36555	2020-03-05 03:29:33	2020-03-05	12	[{"id_menu":1,"count":1}]	10976	delivery	5	17
36556	2020-03-05 03:29:56	2020-03-05	14	[{"id_menu":2,"count":1}]	3222	pick-up	0	14
36557	2020-03-05 03:30:23	2020-03-05	8	[{"id_menu":5,"count":1}]	7196	delivery	5	13
36558	2020-03-05 03:35:21	2020-03-05	14	[{"id_menu":2,"count":1}]	14521	pick-up	0	14
36559	2020-03-05 03:39:02	2020-03-05	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13840	delivery	5	54
36560	2020-03-05 03:45:00	2020-03-05	17	[{"id_menu":4,"count":1}]	12578	delivery	5	22
36561	2020-03-05 03:48:47	2020-03-05	14	[{"id_menu":2,"count":1}]	14436	delivery	5	19
36562	2020-03-05 03:50:04	2020-03-05	9	[{"id_menu":7,"count":1}]	1083	delivery	5	14
36563	2020-03-05 03:52:00	2020-03-05	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	14481	delivery	5	26
36564	2020-03-05 03:54:06	2020-03-05	9	[{"id_menu":6,"count":1}]	8306	delivery	5	14
36565	2020-03-05 04:09:59	2020-03-05	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1976	delivery	5	31
36566	2020-03-05 04:10:32	2020-03-05	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	4363	delivery	5	43
36567	2020-03-05 04:16:04	2020-03-05	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3963	pick-up	0	51
36568	2020-03-05 04:17:37	2020-03-05	12	[{"id_menu":3,"count":1}]	13390	delivery	5	17
36569	2020-03-05 04:19:35	2020-03-05	14	[{"id_menu":2,"count":1}]	9312	delivery	5	19
36570	2020-03-05 04:21:53	2020-03-05	17	[{"id_menu":4,"count":1}]	972	delivery	5	22
36571	2020-03-05 04:24:17	2020-03-05	14	[{"id_menu":2,"count":1}]	6988	delivery	5	19
36572	2020-03-05 04:27:08	2020-03-05	12	[{"id_menu":1,"count":1}]	6222	delivery	5	17
36573	2020-03-05 04:28:26	2020-03-05	14	[{"id_menu":2,"count":1}]	9497	delivery	5	19
36574	2020-03-05 04:32:54	2020-03-05	14	[{"id_menu":2,"count":2}]	5857	pick-up	0	14
36575	2020-03-05 04:33:16	2020-03-05	9	[{"id_menu":6,"count":1}]	10639	delivery	5	14
36576	2020-03-05 04:40:53	2020-03-05	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	12565	delivery	5	26
36577	2020-03-05 04:51:57	2020-03-05	9	[{"id_menu":7,"count":1}]	12057	delivery	5	14
36578	2020-03-05 04:53:57	2020-03-05	17	[{"id_menu":4,"count":1}]	5891	delivery	5	22
36579	2020-03-05 04:57:24	2020-03-05	12	[{"id_menu":1,"count":1}]	14456	delivery	5	17
36580	2020-03-05 05:02:00	2020-03-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7019	delivery	5	28
36581	2020-03-05 05:02:09	2020-03-05	17	[{"id_menu":4,"count":1}]	5466	delivery	5	22
36582	2020-03-05 05:03:07	2020-03-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4636	delivery	5	23
36583	2020-03-05 05:05:45	2020-03-05	9	[{"id_menu":6,"count":1}]	14467	delivery	5	14
36584	2020-03-05 05:11:00	2020-03-05	14	[{"id_menu":2,"count":1}]	14509	pick-up	0	14
36585	2020-03-05 05:12:48	2020-03-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6826	delivery	5	23
36586	2020-03-05 05:27:45	2020-03-05	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4064	delivery	5	48
36587	2020-03-05 05:36:07	2020-03-05	9	[{"id_menu":7,"count":1}]	7139	delivery	5	14
36588	2020-03-05 05:37:04	2020-03-05	12	[{"id_menu":1,"count":1}]	6900	delivery	5	17
36589	2020-03-05 05:39:37	2020-03-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	14461	delivery	5	28
36590	2020-03-05 05:40:35	2020-03-05	17	[{"id_menu":4,"count":1}]	5404	pick-up	0	17
36591	2020-03-05 05:45:27	2020-03-05	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	14539	delivery	5	22
36592	2020-03-05 05:50:32	2020-03-05	8	[{"id_menu":5,"count":1}]	4357	delivery	5	13
36659	2020-03-05 10:53:44	2020-03-05	12	[{"id_menu":1,"count":2}]	14455	delivery	5	17
36593	2020-03-05 05:52:37	2020-03-05	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1749	delivery	5	36
36594	2020-03-05 05:56:31	2020-03-05	9	[{"id_menu":6,"count":1}]	13291	delivery	5	14
36595	2020-03-05 05:59:08	2020-03-05	9	[{"id_menu":6,"count":1}]	10956	pick-up	0	9
36596	2020-03-05 06:18:19	2020-03-05	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	11570	pick-up	0	34
36597	2020-03-05 06:19:07	2020-03-05	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	14530	delivery	5	25
36598	2020-03-05 06:31:24	2020-03-05	12	[{"id_menu":3,"count":1}]	1243	pick-up	0	12
36599	2020-03-05 06:33:15	2020-03-05	9	[{"id_menu":6,"count":1}]	14457	pick-up	0	9
36600	2020-03-05 06:35:10	2020-03-05	9	[{"id_menu":6,"count":1}]	6973	delivery	5	14
36601	2020-03-05 06:38:01	2020-03-05	39	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	13885	delivery	5	44
36602	2020-03-05 06:39:17	2020-03-05	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	5527	delivery	5	40
36603	2020-03-05 06:41:15	2020-03-05	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	13911	delivery	5	27
36604	2020-03-05 06:48:40	2020-03-05	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14484	delivery	5	39
36605	2020-03-05 06:59:58	2020-03-05	12	[{"id_menu":1,"count":1}]	6845	pick-up	0	12
36606	2020-03-05 07:01:58	2020-03-05	12	[{"id_menu":3,"count":1}]	13502	pick-up	0	12
36607	2020-03-05 07:03:34	2020-03-05	9	[{"id_menu":6,"count":1}]	7167	delivery	5	14
36608	2020-03-05 07:06:25	2020-03-05	14	[{"id_menu":2,"count":1}]	5430	pick-up	0	14
36609	2020-03-05 07:07:37	2020-03-05	14	[{"id_menu":2,"count":1}]	14437	delivery	5	19
36610	2020-03-05 07:12:55	2020-03-05	9	[{"id_menu":6,"count":1}]	4646	delivery	5	14
36611	2020-03-05 07:13:04	2020-03-05	8	[{"id_menu":5,"count":1}]	14527	delivery	5	13
36612	2020-03-05 07:13:49	2020-03-05	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	8785	delivery	5	34
36613	2020-03-05 07:14:45	2020-03-05	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	14506	delivery	5	26
36614	2020-03-05 07:21:46	2020-03-05	14	[{"id_menu":2,"count":1}]	2264	pick-up	0	14
36615	2020-03-05 07:22:04	2020-03-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4546	pick-up	0	23
36616	2020-03-05 07:28:36	2020-03-05	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14511	delivery	5	48
36617	2020-03-05 07:39:24	2020-03-05	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	4243	delivery	5	40
36618	2020-03-05 07:41:36	2020-03-05	17	[{"id_menu":4,"count":1}]	393	pick-up	0	17
36619	2020-03-05 07:42:27	2020-03-05	9	[{"id_menu":7,"count":2}]	9240	delivery	5	14
36620	2020-03-05 07:53:22	2020-03-05	12	[{"id_menu":1,"count":1}]	4436	delivery	5	17
36621	2020-03-05 08:01:47	2020-03-05	9	[{"id_menu":7,"count":1}]	14470	delivery	5	14
36622	2020-03-05 08:02:14	2020-03-05	17	[{"id_menu":4,"count":1}]	14475	delivery	5	22
36623	2020-03-05 08:04:34	2020-03-05	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	14488	delivery	5	26
36624	2020-03-05 08:11:56	2020-03-05	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6854	delivery	5	36
36625	2020-03-05 08:20:02	2020-03-05	14	[{"id_menu":2,"count":1}]	3172	pick-up	0	14
36626	2020-03-05 08:23:40	2020-03-05	14	[{"id_menu":2,"count":1}]	10258	delivery	5	19
36627	2020-03-05 08:24:28	2020-03-05	9	[{"id_menu":6,"count":1}]	14480	pick-up	0	9
36628	2020-03-05 08:27:33	2020-03-05	9	[{"id_menu":7,"count":1}]	14459	delivery	5	14
36629	2020-03-05 08:35:40	2020-03-05	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7995	delivery	5	35
36630	2020-03-05 08:36:37	2020-03-05	12	[{"id_menu":3,"count":1}]	11232	pick-up	0	12
36631	2020-03-05 08:40:28	2020-03-05	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	14517	delivery	5	31
36632	2020-03-05 08:44:18	2020-03-05	12	[{"id_menu":1,"count":1}]	1996	pick-up	0	12
36633	2020-03-05 08:57:40	2020-03-05	8	[{"id_menu":5,"count":1}]	10002	delivery	5	13
36634	2020-03-05 09:01:32	2020-03-05	9	[{"id_menu":6,"count":1}]	8964	pick-up	0	9
36635	2020-03-05 09:23:16	2020-03-05	9	[{"id_menu":7,"count":1}]	14538	delivery	5	14
36636	2020-03-05 09:26:22	2020-03-05	9	[{"id_menu":6,"count":1}]	14478	delivery	5	14
36637	2020-03-05 09:32:19	2020-03-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14427	pick-up	0	17
36638	2020-03-05 09:35:09	2020-03-05	12	[{"id_menu":1,"count":1}]	13713	delivery	5	17
36639	2020-03-05 09:36:17	2020-03-05	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	3227	pick-up	0	31
36640	2020-03-05 09:37:12	2020-03-05	17	[{"id_menu":4,"count":1}]	8753	delivery	5	22
36641	2020-03-05 09:43:11	2020-03-05	17	[{"id_menu":4,"count":1}]	5099	delivery	5	22
36642	2020-03-05 09:44:31	2020-03-05	9	[{"id_menu":6,"count":1}]	14534	delivery	5	14
36643	2020-03-05 09:57:40	2020-03-05	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14504	delivery	5	57
36644	2020-03-05 10:01:14	2020-03-05	14	[{"id_menu":2,"count":1}]	2242	pick-up	0	14
36645	2020-03-05 10:01:51	2020-03-05	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	14325	delivery	5	35
36646	2020-03-05 10:22:28	2020-03-05	17	[{"id_menu":4,"count":1}]	14532	delivery	5	22
36647	2020-03-05 10:23:48	2020-03-05	12	[{"id_menu":3,"count":1}]	11073	delivery	5	17
36648	2020-03-05 10:27:00	2020-03-05	12	[{"id_menu":3,"count":1}]	3314	delivery	5	17
36649	2020-03-05 10:29:35	2020-03-05	8	[{"id_menu":5,"count":1}]	2820	pick-up	0	8
36650	2020-03-05 10:30:16	2020-03-05	9	[{"id_menu":7,"count":1}]	14485	pick-up	0	9
36651	2020-03-05 10:31:09	2020-03-05	9	[{"id_menu":7,"count":1}]	12624	pick-up	0	9
36652	2020-03-05 10:33:45	2020-03-05	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	14516	delivery	5	45
36653	2020-03-05 10:34:20	2020-03-05	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	14446	delivery	5	22
36654	2020-03-05 10:34:55	2020-03-05	17	[{"id_menu":4,"count":1}]	11806	delivery	5	22
36655	2020-03-05 10:38:30	2020-03-05	14	[{"id_menu":2,"count":1}]	2899	delivery	5	19
36656	2020-03-05 10:43:54	2020-03-05	14	[{"id_menu":2,"count":1}]	8414	delivery	5	19
36657	2020-03-05 10:47:39	2020-03-05	8	[{"id_menu":5,"count":1}]	4464	delivery	5	13
36658	2020-03-05 10:53:39	2020-03-05	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	14501	pick-up	0	35
36660	2020-03-05 11:01:54	2020-03-05	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	7921	pick-up	0	26
36661	2020-03-05 11:03:53	2020-03-05	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	10566	delivery	5	28
36662	2020-03-05 11:06:31	2020-03-05	9	[{"id_menu":6,"count":1}]	8858	delivery	5	14
36663	2020-03-05 11:13:39	2020-03-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12885	delivery	5	31
36664	2020-03-05 11:20:09	2020-03-05	8	[{"id_menu":5,"count":1}]	11366	delivery	5	13
36665	2020-03-05 11:20:34	2020-03-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6565	delivery	5	31
36666	2020-03-05 11:22:56	2020-03-05	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	3585	delivery	5	26
36667	2020-03-05 11:28:00	2020-03-05	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	273	pick-up	0	21
36668	2020-03-05 11:33:34	2020-03-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14449	pick-up	0	18
36669	2020-03-05 11:38:05	2020-03-05	9	[{"id_menu":7,"count":1}]	1282	delivery	5	14
36670	2020-03-05 11:40:01	2020-03-05	12	[{"id_menu":1,"count":1}]	13348	delivery	5	17
36671	2020-03-05 11:52:30	2020-03-05	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	13656	pick-up	0	22
36672	2020-03-05 12:17:24	2020-03-05	9	[{"id_menu":6,"count":1}]	6123	delivery	5	14
36673	2020-03-05 12:22:51	2020-03-05	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	14508	delivery	5	36
36674	2020-03-05 12:42:29	2020-03-05	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	14486	delivery	5	31
36675	2020-03-05 12:48:58	2020-03-05	9	[{"id_menu":7,"count":1}]	14444	delivery	5	14
36676	2020-03-05 12:49:49	2020-03-05	14	[{"id_menu":2,"count":1}]	14458	delivery	5	19
36677	2020-03-05 12:51:35	2020-03-05	14	[{"id_menu":2,"count":1}]	197	pick-up	0	14
36678	2020-03-05 12:56:42	2020-03-05	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8176	delivery	5	28
36679	2020-03-05 12:59:33	2020-03-05	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	11222	delivery	5	30
36680	2020-03-05 13:02:49	2020-03-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2275	pick-up	0	26
36681	2020-03-05 13:04:43	2020-03-05	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2893	delivery	5	36
36682	2020-03-05 13:04:57	2020-03-05	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14498	delivery	5	45
36683	2020-03-05 13:12:16	2020-03-05	17	[{"id_menu":4,"count":1}]	10942	pick-up	0	17
36684	2020-03-05 13:14:08	2020-03-05	9	[{"id_menu":7,"count":1}]	14491	delivery	5	14
36685	2020-03-05 13:16:32	2020-03-05	12	[{"id_menu":1,"count":1}]	5869	delivery	5	17
36686	2020-03-05 13:18:05	2020-03-05	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4969	delivery	5	39
36687	2020-03-05 13:18:58	2020-03-05	9	[{"id_menu":7,"count":1}]	14443	delivery	5	14
36688	2020-03-05 13:21:33	2020-03-05	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	2691	delivery	5	29
36689	2020-03-05 13:28:33	2020-03-05	12	[{"id_menu":1,"count":1}]	6534	delivery	5	17
36690	2020-03-05 13:32:37	2020-03-05	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1958	delivery	5	48
36691	2020-03-05 13:37:20	2020-03-05	8	[{"id_menu":5,"count":1}]	14474	delivery	5	13
36692	2020-03-05 13:39:41	2020-03-05	9	[{"id_menu":6,"count":2}]	2771	pick-up	0	9
36693	2020-03-05 13:47:44	2020-03-05	9	[{"id_menu":6,"count":1}]	3897	delivery	5	14
36694	2020-03-05 13:51:06	2020-03-05	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	5111	delivery	5	48
36695	2020-03-05 13:58:56	2020-03-05	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	9695	delivery	5	25
36696	2020-03-05 13:59:14	2020-03-05	9	[{"id_menu":6,"count":1}]	7017	delivery	5	14
36697	2020-03-05 14:01:16	2020-03-05	14	[{"id_menu":2,"count":1}]	4800	pick-up	0	14
36698	2020-03-05 14:04:03	2020-03-05	8	[{"id_menu":5,"count":1}]	863	delivery	5	13
36699	2020-03-05 14:04:31	2020-03-05	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14448	delivery	5	36
36700	2020-03-05 14:04:40	2020-03-05	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	4161	pick-up	0	26
36701	2020-03-05 14:13:29	2020-03-05	14	[{"id_menu":2,"count":1}]	11567	delivery	5	19
36702	2020-03-05 14:16:11	2020-03-05	12	[{"id_menu":1,"count":1}]	12398	delivery	5	17
36703	2020-03-05 14:16:52	2020-03-05	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	9789	delivery	5	31
36704	2020-03-05 14:21:39	2020-03-05	14	[{"id_menu":2,"count":1}]	5947	delivery	5	19
36705	2020-03-05 14:29:08	2020-03-05	14	[{"id_menu":2,"count":1}]	14445	delivery	5	19
36706	2020-03-05 14:31:40	2020-03-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14439	delivery	5	22
36707	2020-03-05 14:44:49	2020-03-05	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12288	delivery	5	31
36708	2020-03-05 14:45:03	2020-03-05	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2884	delivery	5	31
36709	2020-03-05 14:51:08	2020-03-05	9	[{"id_menu":6,"count":1}]	14493	delivery	5	14
36710	2020-03-05 14:54:31	2020-03-05	17	[{"id_menu":4,"count":1}]	14454	delivery	5	22
36711	2020-03-05 15:06:25	2020-03-05	8	[{"id_menu":5,"count":1}]	3558	delivery	5	13
36712	2020-03-05 15:07:12	2020-03-05	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1427	delivery	5	31
36713	2020-03-05 15:11:57	2020-03-05	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	10717	pick-up	0	29
36714	2020-03-05 15:11:58	2020-03-05	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	4480	delivery	5	31
36715	2020-03-05 15:12:35	2020-03-05	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	4381	delivery	5	44
36716	2020-03-05 15:18:33	2020-03-05	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	11181	delivery	5	26
36717	2020-03-05 15:22:18	2020-03-05	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	62	pick-up	0	40
36718	2020-03-05 15:24:19	2020-03-05	9	[{"id_menu":6,"count":1}]	13972	delivery	5	14
36719	2020-03-05 15:27:18	2020-03-05	12	[{"id_menu":1,"count":2}]	10829	pick-up	0	12
36720	2020-03-05 15:27:20	2020-03-05	8	[{"id_menu":5,"count":1}]	14227	delivery	5	13
36721	2020-03-05 15:28:12	2020-03-05	9	[{"id_menu":7,"count":1}]	5314	pick-up	0	9
36722	2020-03-05 15:29:21	2020-03-05	9	[{"id_menu":7,"count":1}]	14472	pick-up	0	9
36723	2020-03-05 15:32:27	2020-03-05	17	[{"id_menu":4,"count":1}]	1093	delivery	5	22
36724	2020-03-05 15:34:02	2020-03-05	14	[{"id_menu":2,"count":1}]	14512	pick-up	0	14
36725	2020-03-05 15:35:34	2020-03-05	14	[{"id_menu":2,"count":1}]	8008	delivery	5	19
36726	2020-03-05 15:53:01	2020-03-05	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	14471	delivery	5	56
36727	2020-03-05 15:54:51	2020-03-05	9	[{"id_menu":7,"count":1}]	14502	delivery	5	14
36728	2020-03-05 15:56:04	2020-03-05	14	[{"id_menu":2,"count":1}]	10450	delivery	5	19
36729	2020-03-05 15:56:58	2020-03-05	9	[{"id_menu":7,"count":1}]	727	pick-up	0	9
36730	2020-03-05 15:58:33	2020-03-05	9	[{"id_menu":6,"count":1}]	13170	delivery	5	14
36731	2020-03-05 16:05:33	2020-03-05	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	14531	pick-up	0	26
36732	2020-03-05 16:10:32	2020-03-05	14	[{"id_menu":2,"count":1}]	1074	delivery	5	19
36733	2020-03-05 16:15:15	2020-03-05	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4298	delivery	5	35
36734	2020-03-05 16:16:26	2020-03-05	17	[{"id_menu":4,"count":1}]	8267	delivery	5	22
36735	2020-03-05 16:16:26	2020-03-05	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14495	delivery	5	37
36736	2020-03-05 16:31:00	2020-03-05	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	1095	pick-up	0	24
36737	2020-03-05 16:44:10	2020-03-05	8	[{"id_menu":5,"count":1}]	14469	delivery	5	13
36738	2020-03-05 16:45:11	2020-03-05	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	14525	delivery	5	23
36739	2020-03-05 16:50:15	2020-03-05	12	[{"id_menu":1,"count":1}]	12205	pick-up	0	12
36740	2020-03-05 16:57:38	2020-03-05	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	487	delivery	5	27
36741	2020-03-05 17:10:45	2020-03-05	9	[{"id_menu":7,"count":1}]	9388	delivery	5	14
36742	2020-03-05 17:11:48	2020-03-05	14	[{"id_menu":2,"count":1}]	13806	pick-up	0	14
36743	2020-03-05 17:15:49	2020-03-05	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	8126	delivery	5	31
36744	2020-03-05 17:16:27	2020-03-05	12	[{"id_menu":1,"count":1}]	6163	pick-up	0	12
36745	2020-03-05 17:23:09	2020-03-05	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	14529	delivery	5	28
36746	2020-03-05 17:26:10	2020-03-05	12	[{"id_menu":3,"count":1}]	5808	pick-up	0	12
36747	2020-03-05 17:28:38	2020-03-05	12	[{"id_menu":1,"count":1}]	12185	delivery	5	17
36748	2020-03-05 17:36:04	2020-03-05	9	[{"id_menu":7,"count":1}]	14515	delivery	5	14
36749	2020-03-05 17:42:13	2020-03-05	8	[{"id_menu":5,"count":1}]	14438	delivery	5	13
36750	2020-03-05 17:46:59	2020-03-05	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	3676	delivery	5	37
36751	2020-03-05 17:56:15	2020-03-05	9	[{"id_menu":6,"count":1}]	2752	delivery	5	14
36752	2020-03-05 17:57:13	2020-03-05	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12698	delivery	5	22
36753	2020-03-05 17:59:55	2020-03-05	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	14460	delivery	5	28
36754	2020-03-05 18:01:52	2020-03-05	9	[{"id_menu":6,"count":1}]	10381	pick-up	0	9
36755	2020-03-05 18:05:14	2020-03-05	9	[{"id_menu":6,"count":1}]	3351	delivery	5	14
36756	2020-03-05 18:05:17	2020-03-05	12	[{"id_menu":3,"count":2}]	13370	pick-up	0	12
36757	2020-03-05 18:08:10	2020-03-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	13692	pick-up	0	23
36758	2020-03-05 18:14:03	2020-03-05	14	[{"id_menu":2,"count":1}]	14477	delivery	5	19
36759	2020-03-05 18:17:00	2020-03-05	12	[{"id_menu":3,"count":1}]	5506	pick-up	0	12
36760	2020-03-05 18:24:57	2020-03-05	14	[{"id_menu":2,"count":1}]	14510	pick-up	0	14
36761	2020-03-05 18:30:21	2020-03-05	12	[{"id_menu":1,"count":1}]	10348	delivery	5	17
36762	2020-03-05 18:34:20	2020-03-05	12	[{"id_menu":3,"count":1}]	10019	pick-up	0	12
36763	2020-03-05 18:42:02	2020-03-05	12	[{"id_menu":1,"count":1}]	8163	pick-up	0	12
36764	2020-03-05 18:42:05	2020-03-05	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	9989	delivery	5	26
36765	2020-03-05 18:42:45	2020-03-05	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	7338	delivery	5	39
36766	2020-03-05 18:43:02	2020-03-05	8	[{"id_menu":5,"count":1}]	4667	delivery	5	13
36767	2020-03-05 18:49:48	2020-03-05	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	14533	delivery	5	30
36768	2020-03-05 18:53:48	2020-03-05	12	[{"id_menu":3,"count":1}]	3600	pick-up	0	12
36769	2020-03-05 19:00:57	2020-03-05	9	[{"id_menu":6,"count":1}]	12449	delivery	5	14
36770	2020-03-05 19:04:22	2020-03-05	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	14492	delivery	5	30
36771	2020-03-05 19:13:08	2020-03-05	14	[{"id_menu":2,"count":1}]	14489	delivery	5	19
36772	2020-03-05 19:21:14	2020-03-05	8	[{"id_menu":5,"count":1}]	14520	delivery	5	13
36773	2020-03-05 19:33:23	2020-03-05	12	[{"id_menu":3,"count":1}]	14536	delivery	5	17
36774	2020-03-05 19:36:16	2020-03-05	14	[{"id_menu":2,"count":1}]	6622	pick-up	0	14
36775	2020-03-05 19:38:41	2020-03-05	17	[{"id_menu":4,"count":1}]	14523	pick-up	0	17
36776	2020-03-05 19:44:25	2020-03-05	12	[{"id_menu":3,"count":1}]	5141	pick-up	0	12
36777	2020-03-05 19:46:48	2020-03-05	8	[{"id_menu":5,"count":1}]	4081	pick-up	0	8
36778	2020-03-05 19:49:20	2020-03-05	8	[{"id_menu":5,"count":1}]	14440	delivery	5	13
36779	2020-03-05 19:53:51	2020-03-05	17	[{"id_menu":4,"count":1}]	5950	delivery	5	22
36780	2020-03-05 19:53:56	2020-03-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	11105	delivery	5	28
36781	2020-03-05 20:01:42	2020-03-05	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6779	delivery	5	45
36782	2020-03-05 20:03:24	2020-03-05	9	[{"id_menu":7,"count":1}]	2123	pick-up	0	9
36783	2020-03-05 20:04:41	2020-03-05	12	[{"id_menu":3,"count":1}]	330	delivery	5	17
36784	2020-03-05 20:10:07	2020-03-05	17	[{"id_menu":4,"count":1}]	10151	delivery	5	22
36785	2020-03-05 20:38:06	2020-03-05	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7660	delivery	5	35
36786	2020-03-05 20:42:06	2020-03-05	9	[{"id_menu":6,"count":1}]	4676	delivery	5	14
36787	2020-03-05 20:47:53	2020-03-05	12	[{"id_menu":1,"count":1}]	2579	pick-up	0	12
36788	2020-03-05 20:48:50	2020-03-05	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12549	delivery	5	45
36789	2020-03-05 21:01:37	2020-03-05	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	14442	delivery	5	26
36790	2020-03-05 21:03:39	2020-03-05	12	[{"id_menu":3,"count":1}]	14468	pick-up	0	12
36791	2020-03-05 21:08:27	2020-03-05	12	[{"id_menu":1,"count":1}]	14462	pick-up	0	12
36792	2020-03-05 21:31:38	2020-03-05	9	[{"id_menu":6,"count":1}]	3493	delivery	5	14
36793	2020-03-05 21:33:24	2020-03-05	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14490	delivery	5	37
36794	2020-03-05 21:39:37	2020-03-05	14	[{"id_menu":2,"count":1}]	1241	pick-up	0	14
36795	2020-03-05 21:42:03	2020-03-05	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	8068	pick-up	0	31
36796	2020-03-05 21:47:47	2020-03-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	48	delivery	5	22
36797	2020-03-05 21:49:12	2020-03-05	9	[{"id_menu":7,"count":1}]	1343	delivery	5	14
36798	2020-03-05 21:50:59	2020-03-05	14	[{"id_menu":2,"count":1}]	2368	pick-up	0	14
36799	2020-03-05 21:55:00	2020-03-05	12	[{"id_menu":1,"count":1}]	3413	delivery	5	17
36800	2020-03-05 22:05:49	2020-03-05	8	[{"id_menu":5,"count":1}]	11039	delivery	5	13
36801	2020-03-05 22:21:18	2020-03-05	17	[{"id_menu":4,"count":1}]	14465	delivery	5	22
36802	2020-03-05 22:21:18	2020-03-05	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3487	pick-up	0	33
36803	2020-03-05 22:27:22	2020-03-05	8	[{"id_menu":5,"count":1}]	4735	pick-up	0	8
36804	2020-03-05 22:30:47	2020-03-05	17	[{"id_menu":4,"count":1}]	14451	pick-up	0	17
36805	2020-03-05 22:33:06	2020-03-05	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	14526	delivery	5	28
36806	2020-03-05 22:39:49	2020-03-05	9	[{"id_menu":6,"count":1}]	14452	delivery	5	14
36807	2020-03-05 22:44:39	2020-03-05	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14476	delivery	5	54
36808	2020-03-05 22:50:16	2020-03-05	17	[{"id_menu":4,"count":1}]	2536	pick-up	0	17
36809	2020-03-05 22:52:05	2020-03-05	17	[{"id_menu":4,"count":1}]	14519	delivery	5	22
36810	2020-03-05 22:59:33	2020-03-05	9	[{"id_menu":7,"count":1}]	3036	delivery	5	14
36811	2020-03-05 23:01:17	2020-03-05	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7421	delivery	5	55
36812	2020-03-05 23:14:33	2020-03-05	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	14463	pick-up	0	29
36813	2020-03-05 23:21:21	2020-03-05	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12792	delivery	5	54
36814	2020-03-05 23:22:02	2020-03-05	12	[{"id_menu":1,"count":1}]	9065	delivery	5	17
36815	2020-03-05 23:27:22	2020-03-05	17	[{"id_menu":4,"count":1}]	4257	pick-up	0	17
36816	2020-03-05 23:32:26	2020-03-05	12	[{"id_menu":3,"count":1}]	14524	pick-up	0	12
36817	2020-03-05 23:33:16	2020-03-05	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14513	delivery	5	36
36818	2020-03-05 23:35:46	2020-03-05	8	[{"id_menu":5,"count":1}]	14482	delivery	5	13
36819	2020-03-05 23:37:59	2020-03-05	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	9571	delivery	5	28
36820	2020-03-05 23:41:22	2020-03-05	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2058	pick-up	0	17
36821	2020-03-06 00:07:17	2020-03-06	17	[{"id_menu":4,"count":1}]	6761	delivery	5	22
36822	2020-03-06 00:08:18	2020-03-06	9	[{"id_menu":7,"count":1}]	4981	pick-up	0	9
36823	2020-03-06 00:11:15	2020-03-06	9	[{"id_menu":7,"count":1}]	2806	delivery	5	14
36824	2020-03-06 00:20:28	2020-03-06	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13974	delivery	5	22
36825	2020-03-06 00:23:30	2020-03-06	12	[{"id_menu":3,"count":1}]	6229	delivery	5	17
36826	2020-03-06 00:24:13	2020-03-06	12	[{"id_menu":3,"count":1}]	14559	delivery	5	17
36827	2020-03-06 00:27:32	2020-03-06	14	[{"id_menu":2,"count":2}]	8224	pick-up	0	14
36828	2020-03-06 00:29:43	2020-03-06	17	[{"id_menu":4,"count":1}]	1274	delivery	5	22
36829	2020-03-06 00:41:51	2020-03-06	9	[{"id_menu":7,"count":1}]	12210	pick-up	0	9
36830	2020-03-06 00:43:48	2020-03-06	14	[{"id_menu":2,"count":1}]	1093	delivery	5	19
36831	2020-03-06 00:44:44	2020-03-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6664	delivery	5	28
36832	2020-03-06 01:04:11	2020-03-06	12	[{"id_menu":1,"count":1}]	14572	delivery	5	17
36833	2020-03-06 01:18:08	2020-03-06	14	[{"id_menu":2,"count":1}]	14669	delivery	5	19
36834	2020-03-06 01:21:06	2020-03-06	9	[{"id_menu":6,"count":1}]	14662	pick-up	0	9
36835	2020-03-06 01:21:14	2020-03-06	9	[{"id_menu":6,"count":1}]	11447	delivery	5	14
36836	2020-03-06 01:23:55	2020-03-06	9	[{"id_menu":6,"count":1}]	9747	delivery	5	14
36837	2020-03-06 01:26:53	2020-03-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	14552	delivery	5	28
36838	2020-03-06 01:39:54	2020-03-06	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	3741	pick-up	0	22
36839	2020-03-06 01:45:09	2020-03-06	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14554	delivery	5	35
36840	2020-03-06 01:47:25	2020-03-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	12207	delivery	5	28
36841	2020-03-06 02:01:43	2020-03-06	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	13498	pick-up	0	26
36842	2020-03-06 02:06:57	2020-03-06	12	[{"id_menu":1,"count":1}]	1934	pick-up	0	12
36843	2020-03-06 02:12:45	2020-03-06	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14586	delivery	5	45
36844	2020-03-06 02:13:28	2020-03-06	9	[{"id_menu":6,"count":2}]	429	delivery	5	14
36845	2020-03-06 02:13:39	2020-03-06	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14616	pick-up	0	40
36846	2020-03-06 02:21:10	2020-03-06	9	[{"id_menu":6,"count":1}]	5141	delivery	5	14
36847	2020-03-06 02:21:20	2020-03-06	9	[{"id_menu":6,"count":2}]	1545	delivery	5	14
36848	2020-03-06 02:37:37	2020-03-06	9	[{"id_menu":6,"count":1}]	9171	pick-up	0	9
36849	2020-03-06 02:42:34	2020-03-06	17	[{"id_menu":4,"count":1}]	12935	delivery	5	22
36850	2020-03-06 02:42:56	2020-03-06	12	[{"id_menu":3,"count":1}]	14668	delivery	5	17
36851	2020-03-06 02:47:44	2020-03-06	8	[{"id_menu":5,"count":1}]	14643	delivery	5	13
36852	2020-03-06 02:48:34	2020-03-06	8	[{"id_menu":5,"count":1}]	7334	delivery	5	13
36853	2020-03-06 02:50:13	2020-03-06	14	[{"id_menu":2,"count":1}]	14541	delivery	5	19
36854	2020-03-06 02:53:17	2020-03-06	9	[{"id_menu":6,"count":1}]	3113	delivery	5	14
36855	2020-03-06 02:56:40	2020-03-06	9	[{"id_menu":6,"count":1}]	10865	delivery	5	14
36856	2020-03-06 02:57:09	2020-03-06	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	14580	delivery	5	26
36857	2020-03-06 03:00:57	2020-03-06	17	[{"id_menu":4,"count":1}]	8670	pick-up	0	17
36858	2020-03-06 03:04:54	2020-03-06	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14571	delivery	5	43
36859	2020-03-06 03:06:52	2020-03-06	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1208	pick-up	0	23
36860	2020-03-06 03:07:52	2020-03-06	17	[{"id_menu":4,"count":1}]	5581	delivery	5	22
36861	2020-03-06 03:07:55	2020-03-06	9	[{"id_menu":6,"count":1}]	8448	pick-up	0	9
36862	2020-03-06 03:13:05	2020-03-06	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	14666	delivery	5	30
36863	2020-03-06 03:32:25	2020-03-06	9	[{"id_menu":6,"count":1}]	5390	delivery	5	14
36864	2020-03-06 03:39:13	2020-03-06	9	[{"id_menu":6,"count":1}]	9733	delivery	5	14
36865	2020-03-06 03:39:41	2020-03-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1343	pick-up	0	23
36866	2020-03-06 03:46:15	2020-03-06	9	[{"id_menu":6,"count":1}]	13418	delivery	5	14
36867	2020-03-06 03:51:44	2020-03-06	30	[{"id_menu":1,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9969	pick-up	0	30
36868	2020-03-06 03:52:37	2020-03-06	17	[{"id_menu":4,"count":1}]	13334	pick-up	0	17
36869	2020-03-06 03:58:38	2020-03-06	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14545	delivery	5	52
36870	2020-03-06 03:59:43	2020-03-06	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	2734	delivery	5	30
36871	2020-03-06 04:01:07	2020-03-06	9	[{"id_menu":6,"count":2}]	11601	pick-up	0	9
36872	2020-03-06 04:08:20	2020-03-06	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	784	pick-up	0	26
36873	2020-03-06 04:11:17	2020-03-06	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	5933	pick-up	0	20
36874	2020-03-06 04:26:31	2020-03-06	9	[{"id_menu":6,"count":2}]	4377	delivery	5	14
36875	2020-03-06 04:26:42	2020-03-06	14	[{"id_menu":2,"count":1}]	9308	delivery	5	19
36876	2020-03-06 04:38:11	2020-03-06	14	[{"id_menu":2,"count":1}]	7688	delivery	5	19
36877	2020-03-06 04:46:31	2020-03-06	9	[{"id_menu":6,"count":2}]	14663	delivery	5	14
36878	2020-03-06 04:51:17	2020-03-06	12	[{"id_menu":1,"count":1}]	3031	delivery	5	17
36879	2020-03-06 04:55:23	2020-03-06	14	[{"id_menu":2,"count":1}]	14644	delivery	5	19
36880	2020-03-06 05:01:52	2020-03-06	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3812	pick-up	0	35
36881	2020-03-06 05:02:33	2020-03-06	8	[{"id_menu":5,"count":1}]	14637	delivery	5	13
36882	2020-03-06 05:10:36	2020-03-06	12	[{"id_menu":3,"count":1}]	359	delivery	5	17
36883	2020-03-06 05:10:49	2020-03-06	17	[{"id_menu":4,"count":1}]	9562	pick-up	0	17
36884	2020-03-06 05:11:01	2020-03-06	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	14597	delivery	5	36
36885	2020-03-06 05:11:18	2020-03-06	14	[{"id_menu":2,"count":1}]	3210	delivery	5	19
36886	2020-03-06 05:12:29	2020-03-06	14	[{"id_menu":2,"count":1}]	13173	pick-up	0	14
36887	2020-03-06 05:16:25	2020-03-06	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	14567	delivery	5	26
36888	2020-03-06 05:22:12	2020-03-06	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	14027	pick-up	0	31
36889	2020-03-06 05:26:58	2020-03-06	12	[{"id_menu":3,"count":1}]	352	delivery	5	17
36890	2020-03-06 05:39:20	2020-03-06	8	[{"id_menu":5,"count":1}]	14625	delivery	5	13
36891	2020-03-06 05:42:59	2020-03-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	11000	delivery	5	28
36892	2020-03-06 05:43:46	2020-03-06	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4802	delivery	5	40
36893	2020-03-06 05:53:30	2020-03-06	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	4735	pick-up	0	29
36894	2020-03-06 06:03:02	2020-03-06	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	9107	pick-up	0	26
36895	2020-03-06 06:03:34	2020-03-06	17	[{"id_menu":4,"count":1}]	14619	pick-up	0	17
36896	2020-03-06 06:04:06	2020-03-06	9	[{"id_menu":6,"count":1}]	5387	pick-up	0	9
36897	2020-03-06 06:04:35	2020-03-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1668	delivery	5	28
36898	2020-03-06 06:09:29	2020-03-06	30	[{"id_menu":3,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14611	delivery	5	35
36899	2020-03-06 06:18:23	2020-03-06	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	8148	pick-up	0	26
36900	2020-03-06 06:19:10	2020-03-06	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7131	delivery	5	23
36901	2020-03-06 06:26:27	2020-03-06	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14602	delivery	5	49
36902	2020-03-06 06:26:59	2020-03-06	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	8816	pick-up	0	21
36903	2020-03-06 06:35:38	2020-03-06	8	[{"id_menu":5,"count":1}]	8249	delivery	5	13
36904	2020-03-06 06:36:00	2020-03-06	12	[{"id_menu":3,"count":1}]	5783	pick-up	0	12
36905	2020-03-06 06:36:24	2020-03-06	17	[{"id_menu":4,"count":1}]	12713	delivery	5	22
36906	2020-03-06 06:42:27	2020-03-06	8	[{"id_menu":5,"count":1}]	3817	pick-up	0	8
36907	2020-03-06 06:46:59	2020-03-06	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	14631	delivery	5	22
36908	2020-03-06 06:51:38	2020-03-06	8	[{"id_menu":5,"count":1}]	2838	pick-up	0	8
36909	2020-03-06 06:51:38	2020-03-06	14	[{"id_menu":2,"count":1}]	14558	pick-up	0	14
36910	2020-03-06 06:53:36	2020-03-06	12	[{"id_menu":1,"count":1}]	7151	pick-up	0	12
36911	2020-03-06 07:01:35	2020-03-06	12	[{"id_menu":3,"count":1}]	3747	pick-up	0	12
36912	2020-03-06 07:05:31	2020-03-06	8	[{"id_menu":5,"count":1}]	14591	delivery	5	13
36913	2020-03-06 07:09:25	2020-03-06	17	[{"id_menu":4,"count":1}]	603	pick-up	0	17
36914	2020-03-06 07:43:46	2020-03-06	9	[{"id_menu":7,"count":1}]	3404	delivery	5	14
36915	2020-03-06 07:56:34	2020-03-06	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	13400	pick-up	0	21
36916	2020-03-06 07:57:43	2020-03-06	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14651	delivery	5	45
36917	2020-03-06 08:13:16	2020-03-06	9	[{"id_menu":6,"count":1}]	14589	delivery	5	14
36918	2020-03-06 08:17:33	2020-03-06	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	5743	delivery	5	34
36919	2020-03-06 08:28:09	2020-03-06	9	[{"id_menu":6,"count":2}]	14659	delivery	5	14
36920	2020-03-06 08:28:29	2020-03-06	9	[{"id_menu":6,"count":1}]	9716	delivery	5	14
36921	2020-03-06 08:34:20	2020-03-06	9	[{"id_menu":6,"count":1}]	13425	delivery	5	14
36922	2020-03-06 08:35:24	2020-03-06	9	[{"id_menu":6,"count":1}]	14639	delivery	5	14
36923	2020-03-06 08:38:09	2020-03-06	9	[{"id_menu":6,"count":1}]	6383	delivery	5	14
36924	2020-03-06 08:44:49	2020-03-06	9	[{"id_menu":6,"count":1}]	14670	delivery	5	14
36925	2020-03-06 08:53:06	2020-03-06	17	[{"id_menu":4,"count":1}]	14391	pick-up	0	17
36926	2020-03-06 09:02:27	2020-03-06	14	[{"id_menu":2,"count":1}]	12646	delivery	5	19
36927	2020-03-06 09:02:46	2020-03-06	12	[{"id_menu":3,"count":1}]	14562	delivery	5	17
36928	2020-03-06 09:20:27	2020-03-06	12	[{"id_menu":3,"count":1}]	8657	pick-up	0	12
36929	2020-03-06 09:28:45	2020-03-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	677	pick-up	0	23
36930	2020-03-06 09:56:02	2020-03-06	12	[{"id_menu":1,"count":1}]	11172	delivery	5	17
36931	2020-03-06 10:15:59	2020-03-06	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14630	delivery	5	52
36932	2020-03-06 10:16:38	2020-03-06	9	[{"id_menu":6,"count":1}]	14564	delivery	5	14
36933	2020-03-06 10:17:50	2020-03-06	17	[{"id_menu":4,"count":1}]	11531	pick-up	0	17
36934	2020-03-06 10:22:55	2020-03-06	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	14613	delivery	5	23
36935	2020-03-06 10:23:29	2020-03-06	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1695	delivery	5	27
36936	2020-03-06 10:31:57	2020-03-06	12	[{"id_menu":3,"count":1}]	14629	delivery	5	17
36937	2020-03-06 10:34:10	2020-03-06	9	[{"id_menu":7,"count":1}]	14596	delivery	5	14
36938	2020-03-06 10:35:34	2020-03-06	9	[{"id_menu":6,"count":1}]	14577	delivery	5	14
36939	2020-03-06 10:38:40	2020-03-06	17	[{"id_menu":4,"count":1}]	14622	pick-up	0	17
36940	2020-03-06 10:49:37	2020-03-06	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	14609	delivery	5	34
36941	2020-03-06 10:50:14	2020-03-06	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	5289	delivery	5	40
36942	2020-03-06 11:02:04	2020-03-06	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	14628	pick-up	0	23
36943	2020-03-06 11:07:13	2020-03-06	9	[{"id_menu":7,"count":1}]	5648	pick-up	0	9
36944	2020-03-06 11:15:26	2020-03-06	12	[{"id_menu":1,"count":1}]	601	pick-up	0	12
36945	2020-03-06 11:16:00	2020-03-06	12	[{"id_menu":1,"count":1}]	3293	delivery	5	17
36946	2020-03-06 11:17:30	2020-03-06	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	14605	delivery	5	40
36947	2020-03-06 11:39:28	2020-03-06	9	[{"id_menu":7,"count":2}]	13081	delivery	5	14
36948	2020-03-06 11:40:46	2020-03-06	14	[{"id_menu":2,"count":1}]	14578	pick-up	0	14
36949	2020-03-06 11:47:15	2020-03-06	17	[{"id_menu":4,"count":1}]	711	pick-up	0	17
36950	2020-03-06 11:47:25	2020-03-06	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	3403	pick-up	0	29
36951	2020-03-06 11:50:58	2020-03-06	17	[{"id_menu":4,"count":1}]	10452	delivery	5	22
36952	2020-03-06 11:53:53	2020-03-06	12	[{"id_menu":1,"count":1}]	13409	delivery	5	17
36953	2020-03-06 11:55:46	2020-03-06	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	9312	delivery	5	37
36954	2020-03-06 11:58:11	2020-03-06	9	[{"id_menu":7,"count":1}]	11543	delivery	5	14
36955	2020-03-06 12:03:50	2020-03-06	9	[{"id_menu":7,"count":2}]	14540	delivery	5	14
36956	2020-03-06 12:21:46	2020-03-06	9	[{"id_menu":6,"count":1}]	11232	delivery	5	14
36957	2020-03-06 12:32:21	2020-03-06	12	[{"id_menu":1,"count":1}]	3887	delivery	5	17
36958	2020-03-06 12:38:56	2020-03-06	12	[{"id_menu":1,"count":1}]	13669	pick-up	0	12
36959	2020-03-06 12:54:41	2020-03-06	8	[{"id_menu":5,"count":1}]	14633	delivery	5	13
36960	2020-03-06 12:54:44	2020-03-06	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	14587	delivery	5	23
36961	2020-03-06 12:56:18	2020-03-06	8	[{"id_menu":5,"count":1}]	13010	delivery	5	13
36962	2020-03-06 12:59:23	2020-03-06	12	[{"id_menu":3,"count":1}]	138	delivery	5	17
36963	2020-03-06 13:11:41	2020-03-06	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	13668	delivery	5	39
36964	2020-03-06 13:13:11	2020-03-06	12	[{"id_menu":1,"count":1}]	3238	delivery	5	17
36965	2020-03-06 13:16:27	2020-03-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	14314	pick-up	0	23
36966	2020-03-06 13:17:58	2020-03-06	12	[{"id_menu":1,"count":1}]	9557	delivery	5	17
36967	2020-03-06 13:27:45	2020-03-06	12	[{"id_menu":1,"count":1}]	14584	delivery	5	17
36968	2020-03-06 13:28:04	2020-03-06	14	[{"id_menu":2,"count":2}]	5945	pick-up	0	14
36969	2020-03-06 13:37:37	2020-03-06	9	[{"id_menu":6,"count":1}]	13582	delivery	5	14
36970	2020-03-06 13:38:27	2020-03-06	9	[{"id_menu":7,"count":1}]	9176	delivery	5	14
36971	2020-03-06 13:41:12	2020-03-06	14	[{"id_menu":2,"count":1}]	14603	pick-up	0	14
36972	2020-03-06 13:47:06	2020-03-06	14	[{"id_menu":2,"count":1}]	14658	delivery	5	19
36973	2020-03-06 13:53:04	2020-03-06	8	[{"id_menu":5,"count":1}]	14123	delivery	5	13
36974	2020-03-06 13:55:44	2020-03-06	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1821	pick-up	0	23
36975	2020-03-06 13:57:21	2020-03-06	17	[{"id_menu":4,"count":1}]	1902	pick-up	0	17
36976	2020-03-06 13:58:39	2020-03-06	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	10444	delivery	5	40
36977	2020-03-06 14:01:41	2020-03-06	8	[{"id_menu":5,"count":1}]	14047	delivery	5	13
36978	2020-03-06 14:03:44	2020-03-06	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1072	pick-up	0	20
36979	2020-03-06 14:04:19	2020-03-06	9	[{"id_menu":7,"count":1}]	6444	delivery	5	14
36980	2020-03-06 14:24:33	2020-03-06	9	[{"id_menu":7,"count":1}]	14549	pick-up	0	9
36981	2020-03-06 14:27:20	2020-03-06	14	[{"id_menu":2,"count":1}]	10954	pick-up	0	14
36982	2020-03-06 14:29:23	2020-03-06	9	[{"id_menu":6,"count":1}]	14543	delivery	5	14
36983	2020-03-06 14:30:08	2020-03-06	14	[{"id_menu":2,"count":2}]	14576	delivery	5	19
36984	2020-03-06 14:32:35	2020-03-06	12	[{"id_menu":3,"count":1}]	233	pick-up	0	12
36985	2020-03-06 14:51:30	2020-03-06	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9568	delivery	5	48
36986	2020-03-06 14:58:43	2020-03-06	14	[{"id_menu":2,"count":1}]	12605	delivery	5	19
36987	2020-03-06 15:00:33	2020-03-06	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	14624	pick-up	0	26
36988	2020-03-06 15:12:58	2020-03-06	14	[{"id_menu":2,"count":1}]	14588	delivery	5	19
36989	2020-03-06 15:17:36	2020-03-06	8	[{"id_menu":5,"count":1}]	14595	delivery	5	13
36990	2020-03-06 15:24:37	2020-03-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3788	delivery	5	28
36991	2020-03-06 15:30:24	2020-03-06	12	[{"id_menu":1,"count":1}]	1314	pick-up	0	12
36992	2020-03-06 15:32:23	2020-03-06	17	[{"id_menu":4,"count":2}]	10265	delivery	5	22
36993	2020-03-06 15:36:13	2020-03-06	9	[{"id_menu":6,"count":2}]	12621	delivery	5	14
36994	2020-03-06 15:39:03	2020-03-06	17	[{"id_menu":4,"count":1}]	11822	delivery	5	22
36995	2020-03-06 15:52:58	2020-03-06	17	[{"id_menu":4,"count":1}]	2377	delivery	5	22
36996	2020-03-06 15:53:27	2020-03-06	12	[{"id_menu":1,"count":3}]	4592	delivery	5	17
36997	2020-03-06 15:54:12	2020-03-06	9	[{"id_menu":7,"count":1}]	10802	delivery	5	14
36998	2020-03-06 15:55:52	2020-03-06	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1344	delivery	5	25
36999	2020-03-06 15:57:28	2020-03-06	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	14565	delivery	5	40
37000	2020-03-06 16:04:35	2020-03-06	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2228	pick-up	0	29
37001	2020-03-06 16:12:32	2020-03-06	9	[{"id_menu":7,"count":1}]	7824	delivery	5	14
37002	2020-03-06 16:14:55	2020-03-06	12	[{"id_menu":1,"count":1}]	8414	delivery	5	17
37003	2020-03-06 16:23:47	2020-03-06	9	[{"id_menu":6,"count":1}]	13715	delivery	5	14
37004	2020-03-06 16:24:23	2020-03-06	8	[{"id_menu":5,"count":1}]	7566	pick-up	0	8
37005	2020-03-06 16:25:39	2020-03-06	14	[{"id_menu":2,"count":1}]	2932	pick-up	0	14
37006	2020-03-06 16:28:03	2020-03-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	14566	delivery	5	28
37007	2020-03-06 16:36:41	2020-03-06	9	[{"id_menu":7,"count":1}]	2053	pick-up	0	9
37008	2020-03-06 16:41:48	2020-03-06	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	14632	delivery	5	28
37009	2020-03-06 16:55:49	2020-03-06	9	[{"id_menu":7,"count":1}]	11887	pick-up	0	9
37010	2020-03-06 17:00:34	2020-03-06	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	12388	pick-up	0	31
37011	2020-03-06 17:04:14	2020-03-06	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	14590	delivery	5	43
37012	2020-03-06 17:07:29	2020-03-06	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	3711	pick-up	0	17
37013	2020-03-06 17:10:41	2020-03-06	17	[{"id_menu":4,"count":1}]	14660	delivery	5	22
37014	2020-03-06 17:11:26	2020-03-06	17	[{"id_menu":4,"count":1}]	12842	delivery	5	22
37015	2020-03-06 17:20:57	2020-03-06	9	[{"id_menu":7,"count":1}]	3303	pick-up	0	9
37016	2020-03-06 17:22:00	2020-03-06	14	[{"id_menu":2,"count":2}]	1667	pick-up	0	14
37017	2020-03-06 17:24:02	2020-03-06	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14627	delivery	5	23
37018	2020-03-06 17:30:25	2020-03-06	9	[{"id_menu":7,"count":1}]	2281	delivery	5	14
37019	2020-03-06 17:31:37	2020-03-06	12	[{"id_menu":1,"count":1}]	1216	delivery	5	17
37020	2020-03-06 17:42:56	2020-03-06	8	[{"id_menu":5,"count":1}]	14570	pick-up	0	8
37021	2020-03-06 17:45:47	2020-03-06	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	14598	delivery	5	36
37022	2020-03-06 17:57:27	2020-03-06	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	1626	delivery	5	37
37023	2020-03-06 17:57:41	2020-03-06	17	[{"id_menu":4,"count":1}]	11574	delivery	5	22
37024	2020-03-06 18:01:21	2020-03-06	12	[{"id_menu":3,"count":1}]	5883	delivery	5	17
37025	2020-03-06 18:03:58	2020-03-06	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	14647	delivery	5	40
37026	2020-03-06 18:19:53	2020-03-06	17	[{"id_menu":4,"count":1}]	6447	delivery	5	22
37027	2020-03-06 18:24:26	2020-03-06	14	[{"id_menu":2,"count":1}]	4123	pick-up	0	14
37028	2020-03-06 18:28:38	2020-03-06	9	[{"id_menu":6,"count":1}]	10478	delivery	5	14
37029	2020-03-06 18:33:19	2020-03-06	8	[{"id_menu":5,"count":1}]	1961	pick-up	0	8
37030	2020-03-06 19:02:22	2020-03-06	12	[{"id_menu":1,"count":1}]	14654	delivery	5	17
37031	2020-03-06 19:04:39	2020-03-06	9	[{"id_menu":6,"count":1}]	6046	delivery	5	14
37032	2020-03-06 19:14:04	2020-03-06	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	5599	delivery	5	22
37033	2020-03-06 19:20:51	2020-03-06	9	[{"id_menu":7,"count":1}]	3099	delivery	5	14
37034	2020-03-06 19:26:11	2020-03-06	12	[{"id_menu":1,"count":1}]	4100	delivery	5	17
37035	2020-03-06 19:31:21	2020-03-06	17	[{"id_menu":4,"count":1}]	14664	delivery	5	22
37036	2020-03-06 19:32:58	2020-03-06	17	[{"id_menu":4,"count":1}]	68	pick-up	0	17
37037	2020-03-06 19:37:58	2020-03-06	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3898	pick-up	0	17
37038	2020-03-06 19:38:22	2020-03-06	12	[{"id_menu":1,"count":1}]	8100	delivery	5	17
37039	2020-03-06 19:41:55	2020-03-06	14	[{"id_menu":2,"count":1}]	6873	delivery	5	19
37040	2020-03-06 19:52:00	2020-03-06	9	[{"id_menu":6,"count":1}]	14025	pick-up	0	9
37041	2020-03-06 19:52:15	2020-03-06	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3621	pick-up	0	26
37042	2020-03-06 20:07:10	2020-03-06	9	[{"id_menu":7,"count":1}]	4479	pick-up	0	9
37043	2020-03-06 20:09:39	2020-03-06	9	[{"id_menu":7,"count":1}]	14581	delivery	5	14
37044	2020-03-06 20:10:46	2020-03-06	9	[{"id_menu":7,"count":1}]	7051	delivery	5	14
37045	2020-03-06 20:11:49	2020-03-06	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	9214	delivery	5	26
37046	2020-03-06 20:27:01	2020-03-06	9	[{"id_menu":6,"count":1}]	6475	delivery	5	14
37047	2020-03-06 20:27:17	2020-03-06	9	[{"id_menu":6,"count":2}]	14614	delivery	5	14
37048	2020-03-06 20:29:08	2020-03-06	9	[{"id_menu":6,"count":1}]	8546	delivery	5	14
37049	2020-03-06 20:29:22	2020-03-06	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	7620	delivery	5	37
37050	2020-03-06 20:33:18	2020-03-06	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	14480	delivery	5	34
37051	2020-03-06 20:33:28	2020-03-06	8	[{"id_menu":5,"count":1}]	14599	delivery	5	13
37052	2020-03-06 20:33:41	2020-03-06	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	14638	delivery	5	31
37053	2020-03-06 20:41:33	2020-03-06	9	[{"id_menu":6,"count":1}]	14583	pick-up	0	9
37054	2020-03-06 20:45:09	2020-03-06	14	[{"id_menu":2,"count":1}]	10261	delivery	5	19
37055	2020-03-06 20:47:51	2020-03-06	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	3889	delivery	5	40
37056	2020-03-06 20:59:38	2020-03-06	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	821	pick-up	0	31
37057	2020-03-06 20:59:45	2020-03-06	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	10273	pick-up	0	43
37058	2020-03-06 21:05:26	2020-03-06	12	[{"id_menu":3,"count":1}]	6501	pick-up	0	12
37059	2020-03-06 21:05:33	2020-03-06	14	[{"id_menu":2,"count":1}]	11215	delivery	5	19
37060	2020-03-06 21:07:12	2020-03-06	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	14617	delivery	5	26
37061	2020-03-06 21:12:28	2020-03-06	14	[{"id_menu":2,"count":1}]	14594	delivery	5	19
37062	2020-03-06 21:18:46	2020-03-06	9	[{"id_menu":6,"count":1}]	14290	pick-up	0	9
37063	2020-03-06 21:28:56	2020-03-06	12	[{"id_menu":1,"count":1}]	14593	pick-up	0	12
37064	2020-03-06 21:29:33	2020-03-06	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	6301	pick-up	0	21
37065	2020-03-06 21:37:27	2020-03-06	17	[{"id_menu":4,"count":1}]	14620	delivery	5	22
37066	2020-03-06 21:39:39	2020-03-06	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4857	delivery	5	37
37067	2020-03-06 21:41:27	2020-03-06	17	[{"id_menu":4,"count":1}]	12527	pick-up	0	17
37068	2020-03-06 21:46:11	2020-03-06	9	[{"id_menu":6,"count":1}]	10105	delivery	5	14
37069	2020-03-06 21:49:14	2020-03-06	12	[{"id_menu":3,"count":1}]	14642	pick-up	0	12
37070	2020-03-06 21:51:54	2020-03-06	17	[{"id_menu":4,"count":1}]	14634	delivery	5	22
37071	2020-03-06 21:55:39	2020-03-06	12	[{"id_menu":1,"count":1}]	14671	pick-up	0	12
37072	2020-03-06 21:57:24	2020-03-06	17	[{"id_menu":4,"count":1}]	659	delivery	5	22
37073	2020-03-06 21:57:26	2020-03-06	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":2}]	12664	delivery	5	22
37074	2020-03-06 21:57:36	2020-03-06	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	12824	delivery	5	37
37075	2020-03-06 22:02:45	2020-03-06	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10032	delivery	5	31
37076	2020-03-06 22:08:26	2020-03-06	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14563	delivery	5	31
37077	2020-03-06 22:09:25	2020-03-06	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	12805	delivery	5	25
37078	2020-03-06 22:15:15	2020-03-06	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	4024	delivery	5	26
37079	2020-03-06 22:33:03	2020-03-06	12	[{"id_menu":3,"count":1}]	14646	delivery	5	17
37080	2020-03-06 22:34:51	2020-03-06	17	[{"id_menu":4,"count":1}]	14579	delivery	5	22
37081	2020-03-06 22:36:25	2020-03-06	14	[{"id_menu":2,"count":1}]	452	pick-up	0	14
37082	2020-03-06 22:43:05	2020-03-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	12345	delivery	5	28
37083	2020-03-06 22:47:22	2020-03-06	17	[{"id_menu":4,"count":1}]	14665	delivery	5	22
37084	2020-03-06 22:48:54	2020-03-06	9	[{"id_menu":6,"count":1}]	12384	delivery	5	14
37085	2020-03-06 22:54:44	2020-03-06	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	5886	delivery	5	26
37086	2020-03-06 22:58:10	2020-03-06	9	[{"id_menu":6,"count":1}]	14661	pick-up	0	9
37087	2020-03-06 23:02:53	2020-03-06	12	[{"id_menu":3,"count":1}]	9775	delivery	5	17
37088	2020-03-06 23:03:57	2020-03-06	8	[{"id_menu":5,"count":1}]	2821	pick-up	0	8
37089	2020-03-06 23:09:15	2020-03-06	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	14582	delivery	5	25
37090	2020-03-06 23:11:23	2020-03-06	12	[{"id_menu":1,"count":1}]	14568	delivery	5	17
37091	2020-03-06 23:12:57	2020-03-06	9	[{"id_menu":6,"count":1}]	14547	delivery	5	14
37092	2020-03-06 23:14:20	2020-03-06	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	11142	delivery	5	30
37093	2020-03-06 23:15:13	2020-03-06	14	[{"id_menu":2,"count":1}]	13540	delivery	5	19
37094	2020-03-06 23:15:28	2020-03-06	8	[{"id_menu":5,"count":1}]	14592	delivery	5	13
37095	2020-03-06 23:19:36	2020-03-06	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	9069	delivery	5	34
37096	2020-03-06 23:27:44	2020-03-06	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	14556	delivery	5	22
37097	2020-03-06 23:29:54	2020-03-06	9	[{"id_menu":7,"count":1}]	14561	delivery	5	14
37098	2020-03-06 23:40:37	2020-03-06	9	[{"id_menu":7,"count":1}]	14621	delivery	5	14
37099	2020-03-06 23:43:05	2020-03-06	9	[{"id_menu":7,"count":2}]	14553	delivery	5	14
37100	2020-03-06 23:53:31	2020-03-06	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4841	delivery	5	36
37101	2020-03-06 23:53:55	2020-03-06	8	[{"id_menu":5,"count":1}]	8797	delivery	5	13
37102	2020-03-06 23:55:25	2020-03-06	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	14551	delivery	5	26
37103	2020-03-07 00:00:35	2020-03-07	12	[{"id_menu":3,"count":1}]	5201	pick-up	0	12
37104	2020-03-07 00:01:51	2020-03-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14770	delivery	5	22
37105	2020-03-07 00:02:35	2020-03-07	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	9728	delivery	5	34
37106	2020-03-07 00:03:31	2020-03-07	17	[{"id_menu":4,"count":1}]	14145	delivery	5	22
37107	2020-03-07 00:04:19	2020-03-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1570	delivery	5	28
37108	2020-03-07 00:20:02	2020-03-07	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	304	pick-up	0	20
37109	2020-03-07 00:20:43	2020-03-07	17	[{"id_menu":4,"count":1}]	1854	delivery	5	22
37110	2020-03-07 00:23:13	2020-03-07	8	[{"id_menu":5,"count":1}]	3705	delivery	5	13
37111	2020-03-07 00:24:35	2020-03-07	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	4404	delivery	5	31
37112	2020-03-07 00:25:49	2020-03-07	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	14738	delivery	5	37
37113	2020-03-07 00:34:08	2020-03-07	12	[{"id_menu":1,"count":1}]	8797	delivery	5	17
37114	2020-03-07 00:34:21	2020-03-07	14	[{"id_menu":2,"count":1}]	14696	delivery	5	19
37115	2020-03-07 00:35:47	2020-03-07	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	8583	delivery	5	30
37116	2020-03-07 00:38:39	2020-03-07	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	3395	pick-up	0	21
37117	2020-03-07 00:39:20	2020-03-07	8	[{"id_menu":5,"count":1}]	13708	delivery	5	13
37118	2020-03-07 00:41:33	2020-03-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	3064	delivery	5	23
37119	2020-03-07 01:09:04	2020-03-07	14	[{"id_menu":2,"count":1}]	2094	pick-up	0	14
37120	2020-03-07 01:11:28	2020-03-07	12	[{"id_menu":1,"count":1}]	14751	delivery	5	17
37121	2020-03-07 01:22:55	2020-03-07	14	[{"id_menu":2,"count":1}]	6502	delivery	5	19
37122	2020-03-07 01:27:11	2020-03-07	12	[{"id_menu":3,"count":1}]	3260	pick-up	0	12
37123	2020-03-07 01:27:39	2020-03-07	8	[{"id_menu":5,"count":1}]	14312	pick-up	0	8
37124	2020-03-07 01:27:59	2020-03-07	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	14731	delivery	5	43
37125	2020-03-07 01:34:05	2020-03-07	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	14703	delivery	5	31
37126	2020-03-07 01:36:06	2020-03-07	8	[{"id_menu":5,"count":1}]	14795	delivery	5	13
37127	2020-03-07 01:36:40	2020-03-07	9	[{"id_menu":7,"count":1}]	6147	pick-up	0	9
37128	2020-03-07 01:42:10	2020-03-07	9	[{"id_menu":7,"count":1}]	14802	delivery	5	14
37129	2020-03-07 01:45:57	2020-03-07	9	[{"id_menu":7,"count":1}]	4760	delivery	5	14
37130	2020-03-07 01:49:13	2020-03-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	9072	delivery	5	28
37131	2020-03-07 01:52:03	2020-03-07	9	[{"id_menu":7,"count":1}]	4967	pick-up	0	9
37132	2020-03-07 02:07:07	2020-03-07	9	[{"id_menu":7,"count":1}]	14698	delivery	5	14
37133	2020-03-07 02:09:34	2020-03-07	17	[{"id_menu":4,"count":1}]	14774	pick-up	0	17
37134	2020-03-07 02:22:03	2020-03-07	8	[{"id_menu":5,"count":1}]	14792	delivery	5	13
37135	2020-03-07 02:22:11	2020-03-07	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13667	delivery	5	45
37136	2020-03-07 02:25:54	2020-03-07	8	[{"id_menu":5,"count":1}]	9688	pick-up	0	8
37137	2020-03-07 02:29:02	2020-03-07	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4069	delivery	5	22
37138	2020-03-07 02:41:29	2020-03-07	9	[{"id_menu":6,"count":1}]	6729	delivery	5	14
37139	2020-03-07 02:43:10	2020-03-07	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	14769	delivery	5	34
37140	2020-03-07 02:45:29	2020-03-07	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":2}]	14175	delivery	5	26
37141	2020-03-07 02:47:30	2020-03-07	9	[{"id_menu":7,"count":1}]	13180	delivery	5	14
37142	2020-03-07 02:49:51	2020-03-07	12	[{"id_menu":1,"count":1}]	14699	delivery	5	17
37143	2020-03-07 02:49:55	2020-03-07	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10576	delivery	5	30
37144	2020-03-07 02:55:00	2020-03-07	9	[{"id_menu":6,"count":1}]	14707	delivery	5	14
37145	2020-03-07 02:57:52	2020-03-07	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3509	pick-up	0	22
37146	2020-03-07 02:59:13	2020-03-07	9	[{"id_menu":6,"count":1}]	14752	delivery	5	14
37147	2020-03-07 03:00:55	2020-03-07	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	14779	delivery	5	22
37148	2020-03-07 03:03:04	2020-03-07	12	[{"id_menu":1,"count":1}]	9422	delivery	5	17
37149	2020-03-07 03:03:36	2020-03-07	14	[{"id_menu":2,"count":2}]	10224	pick-up	0	14
37150	2020-03-07 03:10:16	2020-03-07	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2630	pick-up	0	17
37151	2020-03-07 03:11:48	2020-03-07	14	[{"id_menu":2,"count":3}]	11639	delivery	5	19
37152	2020-03-07 03:18:53	2020-03-07	9	[{"id_menu":7,"count":1}]	3115	delivery	5	14
37153	2020-03-07 03:19:09	2020-03-07	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14784	delivery	5	35
37154	2020-03-07 03:22:26	2020-03-07	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3636	pick-up	0	22
37155	2020-03-07 03:27:20	2020-03-07	9	[{"id_menu":7,"count":2}]	14753	delivery	5	14
37156	2020-03-07 03:36:05	2020-03-07	9	[{"id_menu":6,"count":1}]	3289	pick-up	0	9
37157	2020-03-07 03:38:35	2020-03-07	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	8629	pick-up	0	31
37158	2020-03-07 03:40:30	2020-03-07	9	[{"id_menu":6,"count":1}]	14677	delivery	5	14
37159	2020-03-07 03:50:30	2020-03-07	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14720	delivery	5	36
37160	2020-03-07 03:53:57	2020-03-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":3}]	8325	delivery	5	28
37161	2020-03-07 03:56:24	2020-03-07	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	14732	delivery	5	56
37162	2020-03-07 03:57:09	2020-03-07	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6609	pick-up	0	26
37163	2020-03-07 03:57:34	2020-03-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14718	delivery	5	22
37164	2020-03-07 03:57:43	2020-03-07	12	[{"id_menu":1,"count":1}]	9337	pick-up	0	12
37165	2020-03-07 03:58:48	2020-03-07	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	10264	delivery	5	35
37166	2020-03-07 03:59:18	2020-03-07	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13236	delivery	5	35
37167	2020-03-07 04:02:00	2020-03-07	17	[{"id_menu":4,"count":1}]	14676	delivery	5	22
37168	2020-03-07 04:03:30	2020-03-07	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14692	delivery	5	35
37169	2020-03-07 04:04:31	2020-03-07	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	6754	pick-up	0	22
37170	2020-03-07 04:05:38	2020-03-07	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	4937	pick-up	0	26
37171	2020-03-07 04:05:53	2020-03-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	14749	delivery	5	26
37172	2020-03-07 04:06:39	2020-03-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	313	pick-up	0	18
37173	2020-03-07 04:11:13	2020-03-07	14	[{"id_menu":2,"count":1}]	11534	pick-up	0	14
37174	2020-03-07 04:12:44	2020-03-07	9	[{"id_menu":7,"count":2}]	14799	delivery	5	14
37175	2020-03-07 04:17:24	2020-03-07	14	[{"id_menu":2,"count":1}]	11954	delivery	5	19
37176	2020-03-07 04:22:02	2020-03-07	9	[{"id_menu":7,"count":1}]	5963	delivery	5	14
37177	2020-03-07 04:27:29	2020-03-07	9	[{"id_menu":7,"count":2}]	6589	pick-up	0	9
37178	2020-03-07 04:27:46	2020-03-07	14	[{"id_menu":2,"count":1}]	14675	delivery	5	19
37179	2020-03-07 04:34:17	2020-03-07	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	14763	delivery	5	29
37180	2020-03-07 04:39:37	2020-03-07	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14746	delivery	5	39
37181	2020-03-07 04:40:33	2020-03-07	14	[{"id_menu":2,"count":1}]	14713	delivery	5	19
37182	2020-03-07 04:44:02	2020-03-07	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	14758	delivery	5	28
37183	2020-03-07 04:44:40	2020-03-07	17	[{"id_menu":4,"count":1}]	1432	pick-up	0	17
37184	2020-03-07 04:50:06	2020-03-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	9154	pick-up	0	23
37185	2020-03-07 04:55:44	2020-03-07	14	[{"id_menu":2,"count":1}]	14733	delivery	5	19
37186	2020-03-07 04:56:34	2020-03-07	21	[{"id_menu":3,"count":3},{"id_menu":7,"count":1}]	9990	pick-up	0	21
37187	2020-03-07 05:00:05	2020-03-07	9	[{"id_menu":6,"count":1}]	597	delivery	5	14
37188	2020-03-07 05:04:13	2020-03-07	8	[{"id_menu":5,"count":1}]	3412	delivery	5	13
37189	2020-03-07 05:07:03	2020-03-07	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	179	delivery	5	43
37190	2020-03-07 05:09:26	2020-03-07	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7119	pick-up	0	40
37191	2020-03-07 05:17:29	2020-03-07	12	[{"id_menu":3,"count":2}]	9300	delivery	5	17
37192	2020-03-07 05:18:13	2020-03-07	8	[{"id_menu":5,"count":1}]	3280	delivery	5	13
37193	2020-03-07 05:18:40	2020-03-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	5090	pick-up	0	21
37194	2020-03-07 05:19:25	2020-03-07	8	[{"id_menu":5,"count":1}]	997	delivery	5	13
37195	2020-03-07 05:22:28	2020-03-07	9	[{"id_menu":7,"count":2}]	14729	delivery	5	14
37196	2020-03-07 05:26:38	2020-03-07	9	[{"id_menu":6,"count":1}]	8946	delivery	5	14
37197	2020-03-07 05:32:20	2020-03-07	9	[{"id_menu":6,"count":1}]	4016	delivery	5	14
37198	2020-03-07 05:33:40	2020-03-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11744	delivery	5	22
37199	2020-03-07 05:48:32	2020-03-07	12	[{"id_menu":1,"count":1}]	10133	delivery	5	17
37200	2020-03-07 06:05:40	2020-03-07	14	[{"id_menu":2,"count":2}]	5255	pick-up	0	14
37201	2020-03-07 06:11:02	2020-03-07	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	14768	delivery	5	30
37202	2020-03-07 06:12:55	2020-03-07	8	[{"id_menu":5,"count":1}]	8182	delivery	5	13
37203	2020-03-07 06:19:41	2020-03-07	14	[{"id_menu":2,"count":1}]	12962	pick-up	0	14
37204	2020-03-07 06:20:38	2020-03-07	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	14685	pick-up	0	21
37205	2020-03-07 06:26:17	2020-03-07	9	[{"id_menu":6,"count":1}]	14691	delivery	5	14
37206	2020-03-07 06:27:45	2020-03-07	9	[{"id_menu":6,"count":1}]	8300	pick-up	0	9
37207	2020-03-07 06:29:44	2020-03-07	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3570	pick-up	0	26
37208	2020-03-07 06:30:20	2020-03-07	9	[{"id_menu":7,"count":1}]	9387	pick-up	0	9
37209	2020-03-07 06:34:03	2020-03-07	9	[{"id_menu":7,"count":1}]	11693	delivery	5	14
37210	2020-03-07 06:38:41	2020-03-07	8	[{"id_menu":5,"count":1}]	11254	delivery	5	13
37211	2020-03-07 06:39:28	2020-03-07	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	7186	pick-up	0	21
37212	2020-03-07 06:48:12	2020-03-07	12	[{"id_menu":1,"count":1}]	12268	pick-up	0	12
37213	2020-03-07 06:48:30	2020-03-07	12	[{"id_menu":1,"count":1}]	1212	delivery	5	17
37214	2020-03-07 06:52:26	2020-03-07	9	[{"id_menu":6,"count":1}]	1589	pick-up	0	9
37215	2020-03-07 06:54:19	2020-03-07	9	[{"id_menu":7,"count":1}]	1996	pick-up	0	9
37216	2020-03-07 07:06:53	2020-03-07	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	7216	delivery	5	31
37217	2020-03-07 07:07:25	2020-03-07	8	[{"id_menu":5,"count":1}]	14705	delivery	5	13
37218	2020-03-07 07:12:08	2020-03-07	9	[{"id_menu":6,"count":1}]	11812	delivery	5	14
37219	2020-03-07 07:13:09	2020-03-07	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1442	pick-up	0	31
37220	2020-03-07 07:27:41	2020-03-07	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7387	delivery	5	45
37221	2020-03-07 07:31:26	2020-03-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	13844	pick-up	0	23
37222	2020-03-07 07:33:32	2020-03-07	17	[{"id_menu":4,"count":1}]	14725	delivery	5	22
37223	2020-03-07 07:35:52	2020-03-07	17	[{"id_menu":4,"count":1}]	8506	delivery	5	22
37224	2020-03-07 07:42:57	2020-03-07	17	[{"id_menu":4,"count":1}]	14797	pick-up	0	17
37225	2020-03-07 07:45:51	2020-03-07	8	[{"id_menu":5,"count":1}]	6079	delivery	5	13
37226	2020-03-07 07:47:39	2020-03-07	17	[{"id_menu":4,"count":1}]	14776	delivery	5	22
37227	2020-03-07 07:57:33	2020-03-07	17	[{"id_menu":4,"count":1}]	2068	pick-up	0	17
37228	2020-03-07 07:57:57	2020-03-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14724	delivery	5	23
37229	2020-03-07 07:58:36	2020-03-07	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	14674	delivery	5	45
37230	2020-03-07 08:17:32	2020-03-07	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2413	pick-up	0	22
37231	2020-03-07 08:19:18	2020-03-07	9	[{"id_menu":6,"count":1}]	3870	pick-up	0	9
37232	2020-03-07 08:19:21	2020-03-07	9	[{"id_menu":6,"count":1}]	14790	delivery	5	14
37233	2020-03-07 08:20:00	2020-03-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":3}]	14142	delivery	5	26
37234	2020-03-07 08:22:53	2020-03-07	9	[{"id_menu":7,"count":1}]	6081	pick-up	0	9
37235	2020-03-07 08:24:50	2020-03-07	14	[{"id_menu":2,"count":1}]	14772	delivery	5	19
37236	2020-03-07 08:28:31	2020-03-07	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	10553	delivery	5	31
37237	2020-03-07 08:32:41	2020-03-07	12	[{"id_menu":1,"count":1}]	4780	delivery	5	17
37238	2020-03-07 08:42:34	2020-03-07	9	[{"id_menu":7,"count":1}]	7015	delivery	5	14
37239	2020-03-07 08:44:08	2020-03-07	12	[{"id_menu":1,"count":1}]	14754	delivery	5	17
37240	2020-03-07 08:44:50	2020-03-07	17	[{"id_menu":4,"count":1}]	2442	pick-up	0	17
37241	2020-03-07 08:48:50	2020-03-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	14777	delivery	5	28
37242	2020-03-07 08:49:43	2020-03-07	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10640	pick-up	0	25
37243	2020-03-07 08:51:03	2020-03-07	9	[{"id_menu":7,"count":1}]	10200	pick-up	0	9
37244	2020-03-07 08:54:42	2020-03-07	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	14794	delivery	5	26
37245	2020-03-07 08:57:28	2020-03-07	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	14742	delivery	5	29
37246	2020-03-07 08:59:13	2020-03-07	9	[{"id_menu":6,"count":1}]	14788	delivery	5	14
37247	2020-03-07 09:07:29	2020-03-07	8	[{"id_menu":5,"count":1}]	14711	delivery	5	13
37248	2020-03-07 09:08:03	2020-03-07	12	[{"id_menu":1,"count":1}]	14693	pick-up	0	12
37249	2020-03-07 09:09:52	2020-03-07	17	[{"id_menu":4,"count":1}]	7415	delivery	5	22
37250	2020-03-07 09:11:07	2020-03-07	9	[{"id_menu":6,"count":1}]	4489	delivery	5	14
37251	2020-03-07 09:23:52	2020-03-07	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11172	delivery	5	31
37252	2020-03-07 09:33:57	2020-03-07	17	[{"id_menu":4,"count":1}]	4634	pick-up	0	17
37253	2020-03-07 09:36:03	2020-03-07	9	[{"id_menu":6,"count":1}]	1322	delivery	5	14
37254	2020-03-07 09:39:52	2020-03-07	9	[{"id_menu":7,"count":1}]	14216	delivery	5	14
37255	2020-03-07 09:45:25	2020-03-07	17	[{"id_menu":4,"count":1}]	2641	pick-up	0	17
37256	2020-03-07 09:49:15	2020-03-07	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	12532	delivery	5	34
37257	2020-03-07 09:50:48	2020-03-07	14	[{"id_menu":2,"count":1}]	6065	delivery	5	19
37258	2020-03-07 09:52:06	2020-03-07	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	14762	delivery	5	37
37259	2020-03-07 09:57:08	2020-03-07	9	[{"id_menu":6,"count":1}]	3817	delivery	5	14
37260	2020-03-07 10:02:34	2020-03-07	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	14717	delivery	5	38
37261	2020-03-07 10:10:08	2020-03-07	12	[{"id_menu":3,"count":1}]	12129	delivery	5	17
37262	2020-03-07 10:10:28	2020-03-07	12	[{"id_menu":3,"count":1}]	4081	delivery	5	17
37263	2020-03-07 10:10:48	2020-03-07	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	7163	delivery	5	34
37264	2020-03-07 10:13:31	2020-03-07	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	14662	pick-up	0	22
37265	2020-03-07 10:14:46	2020-03-07	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3910	delivery	5	37
37266	2020-03-07 10:26:04	2020-03-07	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	9616	delivery	5	26
37267	2020-03-07 10:27:06	2020-03-07	17	[{"id_menu":4,"count":1}]	12420	delivery	5	22
37268	2020-03-07 10:34:33	2020-03-07	12	[{"id_menu":1,"count":1}]	12338	delivery	5	17
37269	2020-03-07 10:41:15	2020-03-07	17	[{"id_menu":4,"count":2}]	11367	delivery	5	22
37270	2020-03-07 10:43:38	2020-03-07	12	[{"id_menu":1,"count":1}]	8148	pick-up	0	12
37271	2020-03-07 10:55:27	2020-03-07	9	[{"id_menu":6,"count":1}]	1528	delivery	5	14
37272	2020-03-07 10:55:56	2020-03-07	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	12440	delivery	5	31
37273	2020-03-07 10:58:32	2020-03-07	14	[{"id_menu":2,"count":1}]	14726	delivery	5	19
37274	2020-03-07 11:03:38	2020-03-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	14781	delivery	5	28
37275	2020-03-07 11:05:28	2020-03-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13669	pick-up	0	17
37276	2020-03-07 11:11:39	2020-03-07	14	[{"id_menu":2,"count":1}]	14735	pick-up	0	14
37277	2020-03-07 11:13:13	2020-03-07	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9677	delivery	5	48
37278	2020-03-07 11:16:58	2020-03-07	17	[{"id_menu":4,"count":1}]	14782	pick-up	0	17
37279	2020-03-07 11:22:14	2020-03-07	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14744	delivery	5	46
37280	2020-03-07 11:22:25	2020-03-07	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	6941	pick-up	0	26
37281	2020-03-07 11:25:57	2020-03-07	8	[{"id_menu":5,"count":1}]	14252	pick-up	0	8
37282	2020-03-07 11:34:12	2020-03-07	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14730	delivery	5	40
37283	2020-03-07 11:34:50	2020-03-07	14	[{"id_menu":2,"count":1}]	5169	pick-up	0	14
37284	2020-03-07 11:38:10	2020-03-07	17	[{"id_menu":4,"count":1}]	8632	pick-up	0	17
37285	2020-03-07 11:43:00	2020-03-07	8	[{"id_menu":5,"count":1}]	12442	pick-up	0	8
37286	2020-03-07 11:43:43	2020-03-07	8	[{"id_menu":5,"count":1}]	14750	delivery	5	13
37287	2020-03-07 11:44:32	2020-03-07	8	[{"id_menu":5,"count":2}]	5846	delivery	5	13
37288	2020-03-07 11:52:33	2020-03-07	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	14715	delivery	5	25
37289	2020-03-07 11:52:40	2020-03-07	9	[{"id_menu":6,"count":1}]	5811	delivery	5	14
37290	2020-03-07 11:54:01	2020-03-07	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	13230	delivery	5	26
37291	2020-03-07 11:54:35	2020-03-07	9	[{"id_menu":6,"count":1}]	14700	delivery	5	14
37292	2020-03-07 11:56:29	2020-03-07	14	[{"id_menu":2,"count":2}]	9125	pick-up	0	14
37293	2020-03-07 11:59:43	2020-03-07	17	[{"id_menu":4,"count":1}]	6331	delivery	5	22
37294	2020-03-07 12:08:48	2020-03-07	9	[{"id_menu":7,"count":1}]	14683	delivery	5	14
37295	2020-03-07 12:08:51	2020-03-07	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2908	delivery	5	39
37296	2020-03-07 12:12:31	2020-03-07	9	[{"id_menu":6,"count":1}]	12823	delivery	5	14
37297	2020-03-07 12:13:54	2020-03-07	9	[{"id_menu":7,"count":1}]	14786	delivery	5	14
37298	2020-03-07 12:17:18	2020-03-07	9	[{"id_menu":7,"count":1}]	11442	delivery	5	14
37299	2020-03-07 12:17:57	2020-03-07	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":3}]	14745	delivery	5	22
37300	2020-03-07 12:19:19	2020-03-07	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	742	pick-up	0	30
37301	2020-03-07 12:24:39	2020-03-07	12	[{"id_menu":1,"count":1}]	13681	delivery	5	17
37302	2020-03-07 12:25:48	2020-03-07	8	[{"id_menu":5,"count":1}]	9003	delivery	5	13
37303	2020-03-07 12:36:21	2020-03-07	17	[{"id_menu":4,"count":1}]	14679	delivery	5	22
37304	2020-03-07 12:38:51	2020-03-07	9	[{"id_menu":7,"count":1}]	3700	delivery	5	14
37305	2020-03-07 12:41:53	2020-03-07	9	[{"id_menu":7,"count":1}]	11287	delivery	5	14
37306	2020-03-07 12:44:22	2020-03-07	9	[{"id_menu":7,"count":1}]	6123	delivery	5	14
37307	2020-03-07 12:45:28	2020-03-07	12	[{"id_menu":3,"count":2}]	5350	pick-up	0	12
37308	2020-03-07 12:45:30	2020-03-07	14	[{"id_menu":2,"count":1}]	2141	pick-up	0	14
37309	2020-03-07 12:54:21	2020-03-07	14	[{"id_menu":2,"count":1}]	5064	delivery	5	19
37310	2020-03-07 12:55:11	2020-03-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	9103	delivery	5	26
37311	2020-03-07 13:05:43	2020-03-07	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14748	delivery	5	43
37312	2020-03-07 13:11:34	2020-03-07	17	[{"id_menu":4,"count":1}]	4821	delivery	5	22
37313	2020-03-07 13:14:23	2020-03-07	8	[{"id_menu":5,"count":1}]	14791	pick-up	0	8
37314	2020-03-07 13:14:55	2020-03-07	17	[{"id_menu":4,"count":1}]	11043	pick-up	0	17
37315	2020-03-07 13:18:40	2020-03-07	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14680	delivery	5	46
37316	2020-03-07 13:22:44	2020-03-07	12	[{"id_menu":1,"count":1}]	14681	pick-up	0	12
37317	2020-03-07 13:36:38	2020-03-07	14	[{"id_menu":2,"count":1}]	2619	pick-up	0	14
37318	2020-03-07 13:40:42	2020-03-07	17	[{"id_menu":4,"count":1}]	14673	pick-up	0	17
37319	2020-03-07 13:42:10	2020-03-07	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	3012	pick-up	0	23
37320	2020-03-07 13:52:05	2020-03-07	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1379	pick-up	0	40
37321	2020-03-07 13:52:44	2020-03-07	14	[{"id_menu":2,"count":1}]	14764	pick-up	0	14
37322	2020-03-07 13:53:42	2020-03-07	9	[{"id_menu":7,"count":1}]	5794	delivery	5	14
37323	2020-03-07 14:01:27	2020-03-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	733	delivery	5	23
37324	2020-03-07 14:02:31	2020-03-07	9	[{"id_menu":6,"count":1}]	13302	delivery	5	14
37325	2020-03-07 14:03:20	2020-03-07	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	14766	delivery	5	48
37326	2020-03-07 14:05:53	2020-03-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1961	delivery	5	28
37327	2020-03-07 14:09:55	2020-03-07	9	[{"id_menu":6,"count":1}]	1861	delivery	5	14
37328	2020-03-07 14:11:49	2020-03-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	14773	delivery	5	23
37329	2020-03-07 14:20:22	2020-03-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	8286	pick-up	0	23
37330	2020-03-07 14:27:57	2020-03-07	9	[{"id_menu":7,"count":1}]	14757	delivery	5	14
37331	2020-03-07 14:29:54	2020-03-07	12	[{"id_menu":1,"count":1}]	7215	delivery	5	17
37332	2020-03-07 14:31:06	2020-03-07	9	[{"id_menu":6,"count":1}]	14787	delivery	5	14
37333	2020-03-07 14:38:57	2020-03-07	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14765	delivery	5	48
37334	2020-03-07 14:45:58	2020-03-07	14	[{"id_menu":2,"count":1}]	14684	delivery	5	19
37335	2020-03-07 14:46:39	2020-03-07	8	[{"id_menu":5,"count":1}]	7444	delivery	5	13
37336	2020-03-07 14:59:44	2020-03-07	12	[{"id_menu":3,"count":1}]	527	pick-up	0	12
37337	2020-03-07 15:00:58	2020-03-07	9	[{"id_menu":6,"count":1}]	14771	pick-up	0	9
37338	2020-03-07 15:15:41	2020-03-07	17	[{"id_menu":4,"count":1}]	11749	delivery	5	22
37339	2020-03-07 15:17:17	2020-03-07	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14747	delivery	5	35
37340	2020-03-07 15:28:30	2020-03-07	17	[{"id_menu":4,"count":1}]	11298	delivery	5	22
37341	2020-03-07 15:29:57	2020-03-07	9	[{"id_menu":7,"count":1}]	14801	pick-up	0	9
37342	2020-03-07 15:30:22	2020-03-07	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	14789	delivery	5	30
37343	2020-03-07 15:33:13	2020-03-07	9	[{"id_menu":7,"count":1}]	14737	delivery	5	14
37344	2020-03-07 15:44:28	2020-03-07	14	[{"id_menu":2,"count":1}]	13951	pick-up	0	14
37345	2020-03-07 15:46:39	2020-03-07	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	14686	delivery	5	23
37346	2020-03-07 15:51:06	2020-03-07	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	14678	delivery	5	31
37347	2020-03-07 15:52:25	2020-03-07	12	[{"id_menu":3,"count":1}]	14704	delivery	5	17
37348	2020-03-07 15:56:44	2020-03-07	9	[{"id_menu":7,"count":1}]	3146	pick-up	0	9
37349	2020-03-07 16:01:54	2020-03-07	9	[{"id_menu":7,"count":1}]	5948	delivery	5	14
37350	2020-03-07 16:06:35	2020-03-07	12	[{"id_menu":3,"count":1}]	14783	delivery	5	17
37351	2020-03-07 16:22:12	2020-03-07	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12942	delivery	5	31
37352	2020-03-07 16:28:59	2020-03-07	8	[{"id_menu":5,"count":1}]	10951	delivery	5	13
37353	2020-03-07 16:29:25	2020-03-07	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	14796	delivery	5	26
37354	2020-03-07 16:36:34	2020-03-07	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1555	pick-up	0	21
37355	2020-03-07 16:45:00	2020-03-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	575	pick-up	0	23
37356	2020-03-07 16:45:55	2020-03-07	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	14127	pick-up	0	20
37357	2020-03-07 16:46:20	2020-03-07	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14719	delivery	5	48
37358	2020-03-07 16:47:55	2020-03-07	12	[{"id_menu":1,"count":1}]	11017	delivery	5	17
37359	2020-03-07 16:51:06	2020-03-07	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7603	pick-up	0	37
37360	2020-03-07 17:00:31	2020-03-07	8	[{"id_menu":5,"count":1}]	10734	delivery	5	13
37361	2020-03-07 17:04:53	2020-03-07	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	14761	delivery	5	40
37362	2020-03-07 17:17:01	2020-03-07	9	[{"id_menu":7,"count":1}]	14694	delivery	5	14
37363	2020-03-07 17:20:49	2020-03-07	9	[{"id_menu":6,"count":1}]	11961	delivery	5	14
37364	2020-03-07 17:21:03	2020-03-07	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3414	pick-up	0	22
37365	2020-03-07 17:27:29	2020-03-07	9	[{"id_menu":7,"count":1}]	11651	delivery	5	14
37366	2020-03-07 17:28:50	2020-03-07	8	[{"id_menu":5,"count":1}]	11289	pick-up	0	8
37367	2020-03-07 17:37:47	2020-03-07	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	1694	delivery	5	44
37368	2020-03-07 17:38:15	2020-03-07	17	[{"id_menu":4,"count":1}]	5308	delivery	5	22
37369	2020-03-07 17:53:53	2020-03-07	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	14723	delivery	5	34
37370	2020-03-07 17:54:47	2020-03-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	11231	delivery	5	26
37371	2020-03-07 18:04:18	2020-03-07	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	7815	pick-up	0	37
37372	2020-03-07 18:10:28	2020-03-07	14	[{"id_menu":2,"count":1}]	12576	delivery	5	19
37373	2020-03-07 18:23:47	2020-03-07	9	[{"id_menu":7,"count":1}]	14756	pick-up	0	9
37374	2020-03-07 18:26:47	2020-03-07	8	[{"id_menu":5,"count":1}]	11380	pick-up	0	8
37375	2020-03-07 18:35:55	2020-03-07	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	14739	delivery	5	39
37376	2020-03-07 18:41:47	2020-03-07	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8403	delivery	5	34
37377	2020-03-07 18:44:19	2020-03-07	8	[{"id_menu":5,"count":1}]	14697	delivery	5	13
37378	2020-03-07 18:52:06	2020-03-07	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3546	delivery	5	26
37379	2020-03-07 18:54:19	2020-03-07	17	[{"id_menu":4,"count":1}]	14710	pick-up	0	17
37380	2020-03-07 19:00:26	2020-03-07	12	[{"id_menu":3,"count":1}]	5188	delivery	5	17
37381	2020-03-07 19:08:06	2020-03-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	12647	delivery	5	28
37382	2020-03-07 19:08:39	2020-03-07	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	14716	delivery	5	25
37383	2020-03-07 19:12:09	2020-03-07	12	[{"id_menu":3,"count":1}]	14778	delivery	5	17
37384	2020-03-07 19:29:53	2020-03-07	8	[{"id_menu":5,"count":1}]	14793	delivery	5	13
37385	2020-03-07 19:31:12	2020-03-07	9	[{"id_menu":7,"count":2}]	7971	delivery	5	14
37386	2020-03-07 19:37:43	2020-03-07	12	[{"id_menu":1,"count":1}]	14714	pick-up	0	12
37387	2020-03-07 19:41:55	2020-03-07	9	[{"id_menu":6,"count":1}]	1700	pick-up	0	9
37388	2020-03-07 19:44:06	2020-03-07	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14709	delivery	5	31
37389	2020-03-07 20:03:24	2020-03-07	12	[{"id_menu":1,"count":1}]	4486	pick-up	0	12
37390	2020-03-07 20:06:47	2020-03-07	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	14741	delivery	5	40
37391	2020-03-07 20:15:02	2020-03-07	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	14695	delivery	5	35
37392	2020-03-07 20:24:39	2020-03-07	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	13324	pick-up	0	29
37393	2020-03-07 20:26:25	2020-03-07	14	[{"id_menu":2,"count":1}]	4889	delivery	5	19
37394	2020-03-07 20:27:23	2020-03-07	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	13613	delivery	5	34
37395	2020-03-07 20:32:53	2020-03-07	8	[{"id_menu":5,"count":1}]	14727	delivery	5	13
37396	2020-03-07 20:38:01	2020-03-07	12	[{"id_menu":3,"count":2}]	14798	delivery	5	17
37397	2020-03-07 20:38:35	2020-03-07	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	10066	delivery	5	29
37398	2020-03-07 20:41:32	2020-03-07	9	[{"id_menu":7,"count":1}]	14775	delivery	5	14
37399	2020-03-07 20:41:50	2020-03-07	17	[{"id_menu":4,"count":1}]	3320	pick-up	0	17
37400	2020-03-07 20:57:19	2020-03-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	14800	delivery	5	26
37401	2020-03-07 20:57:32	2020-03-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	14712	delivery	5	28
37402	2020-03-07 20:58:01	2020-03-07	9	[{"id_menu":7,"count":1}]	12590	delivery	5	14
37403	2020-03-07 21:00:16	2020-03-07	9	[{"id_menu":7,"count":1}]	14740	delivery	5	14
37404	2020-03-07 21:01:51	2020-03-07	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14090	delivery	5	36
37405	2020-03-07 21:01:58	2020-03-07	17	[{"id_menu":4,"count":1}]	11766	pick-up	0	17
37406	2020-03-07 21:04:46	2020-03-07	14	[{"id_menu":2,"count":1}]	11973	delivery	5	19
37407	2020-03-07 21:06:58	2020-03-07	12	[{"id_menu":1,"count":1}]	151	pick-up	0	12
37408	2020-03-07 21:11:53	2020-03-07	9	[{"id_menu":7,"count":1}]	4835	delivery	5	14
37409	2020-03-07 21:15:30	2020-03-07	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4841	pick-up	0	30
37410	2020-03-07 21:26:13	2020-03-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	3711	delivery	5	26
37411	2020-03-07 21:26:53	2020-03-07	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	9977	pick-up	0	29
37412	2020-03-07 21:28:51	2020-03-07	17	[{"id_menu":4,"count":1}]	5011	delivery	5	22
37413	2020-03-07 21:31:08	2020-03-07	9	[{"id_menu":7,"count":1}]	4281	delivery	5	14
37414	2020-03-07 21:32:14	2020-03-07	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	207	delivery	5	31
37415	2020-03-07 21:34:05	2020-03-07	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	14728	delivery	5	40
37416	2020-03-07 21:34:20	2020-03-07	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	9907	pick-up	0	32
37417	2020-03-07 21:34:35	2020-03-07	9	[{"id_menu":6,"count":1}]	3445	delivery	5	14
37418	2020-03-07 21:35:22	2020-03-07	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	14702	delivery	5	26
37419	2020-03-07 21:37:07	2020-03-07	14	[{"id_menu":2,"count":1}]	8219	pick-up	0	14
37420	2020-03-07 21:38:19	2020-03-07	14	[{"id_menu":2,"count":1}]	4800	delivery	5	19
37421	2020-03-07 21:43:31	2020-03-07	37	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1368	pick-up	0	37
37422	2020-03-07 21:55:09	2020-03-07	14	[{"id_menu":2,"count":1}]	12935	delivery	5	19
37423	2020-03-07 21:57:34	2020-03-07	9	[{"id_menu":7,"count":1}]	7648	delivery	5	14
37424	2020-03-07 22:03:40	2020-03-07	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	638	pick-up	0	29
37425	2020-03-07 22:07:09	2020-03-07	12	[{"id_menu":1,"count":1}]	9667	pick-up	0	12
37426	2020-03-07 22:08:29	2020-03-07	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	14354	delivery	5	35
37427	2020-03-07 22:09:40	2020-03-07	14	[{"id_menu":2,"count":1}]	2379	pick-up	0	14
37428	2020-03-07 22:09:53	2020-03-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7211	delivery	5	28
37429	2020-03-07 22:22:03	2020-03-07	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	14743	delivery	5	40
37430	2020-03-07 22:27:47	2020-03-07	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7053	delivery	5	57
37431	2020-03-07 22:30:11	2020-03-07	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5840	delivery	5	36
37432	2020-03-07 22:30:20	2020-03-07	33	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	14721	delivery	5	38
37433	2020-03-07 22:31:17	2020-03-07	12	[{"id_menu":1,"count":1}]	14706	pick-up	0	12
37434	2020-03-07 22:35:43	2020-03-07	14	[{"id_menu":2,"count":1}]	1046	pick-up	0	14
37435	2020-03-07 22:40:18	2020-03-07	9	[{"id_menu":6,"count":1}]	14785	delivery	5	14
37436	2020-03-07 22:55:01	2020-03-07	9	[{"id_menu":7,"count":1}]	14734	delivery	5	14
37437	2020-03-07 22:57:41	2020-03-07	9	[{"id_menu":6,"count":1}]	4980	delivery	5	14
37438	2020-03-07 22:59:15	2020-03-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10142	delivery	5	23
37439	2020-03-07 22:59:17	2020-03-07	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	14689	delivery	5	34
37440	2020-03-07 22:59:56	2020-03-07	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	14722	pick-up	0	21
37441	2020-03-07 23:01:11	2020-03-07	9	[{"id_menu":7,"count":1}]	14767	delivery	5	14
37442	2020-03-07 23:04:48	2020-03-07	14	[{"id_menu":2,"count":1}]	13898	delivery	5	19
37443	2020-03-07 23:06:05	2020-03-07	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	14736	delivery	5	26
37444	2020-03-07 23:06:51	2020-03-07	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14196	delivery	5	31
37445	2020-03-07 23:09:30	2020-03-07	12	[{"id_menu":1,"count":1}]	12694	delivery	5	17
37446	2020-03-07 23:13:29	2020-03-07	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	11582	delivery	5	25
37447	2020-03-07 23:17:37	2020-03-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14760	pick-up	0	18
37448	2020-03-07 23:19:22	2020-03-07	9	[{"id_menu":7,"count":1}]	5417	pick-up	0	9
37449	2020-03-07 23:19:40	2020-03-07	12	[{"id_menu":3,"count":1}]	14708	delivery	5	17
37450	2020-03-07 23:20:06	2020-03-07	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4370	pick-up	0	30
37451	2020-03-07 23:26:37	2020-03-07	9	[{"id_menu":7,"count":1}]	14682	delivery	5	14
37452	2020-03-07 23:29:16	2020-03-07	9	[{"id_menu":7,"count":1}]	14672	delivery	5	14
37453	2020-03-07 23:38:13	2020-03-07	12	[{"id_menu":1,"count":1}]	1527	delivery	5	17
37454	2020-03-07 23:40:39	2020-03-07	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3315	delivery	5	26
37455	2020-03-07 23:41:31	2020-03-07	14	[{"id_menu":2,"count":1}]	14688	pick-up	0	14
37456	2020-03-07 23:41:33	2020-03-07	9	[{"id_menu":7,"count":1}]	14687	delivery	5	14
37457	2020-03-07 23:47:02	2020-03-07	17	[{"id_menu":4,"count":1}]	12762	delivery	5	22
37458	2020-03-07 23:49:20	2020-03-07	17	[{"id_menu":4,"count":1}]	709	delivery	5	22
37459	2020-03-07 23:50:11	2020-03-07	9	[{"id_menu":7,"count":1}]	8813	delivery	5	14
37460	2020-03-07 23:50:31	2020-03-07	12	[{"id_menu":3,"count":2}]	3002	pick-up	0	12
37461	2020-03-07 23:55:28	2020-03-07	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14759	delivery	5	36
37462	2020-03-07 23:55:35	2020-03-07	9	[{"id_menu":7,"count":1}]	1798	pick-up	0	9
37463	2020-03-07 23:57:28	2020-03-07	12	[{"id_menu":3,"count":1}]	3069	pick-up	0	12
37464	2020-03-07 23:59:43	2020-03-07	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6296	delivery	5	43
37465	2020-03-08 00:00:20	2020-03-08	8	[{"id_menu":5,"count":1}]	8676	delivery	5	13
37466	2020-03-08 00:04:30	2020-03-08	39	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	980	pick-up	0	39
37467	2020-03-08 00:05:14	2020-03-08	12	[{"id_menu":1,"count":1}]	1398	pick-up	0	12
37468	2020-03-08 00:05:18	2020-03-08	9	[{"id_menu":6,"count":1}]	14840	pick-up	0	9
37469	2020-03-08 00:14:11	2020-03-08	17	[{"id_menu":4,"count":1}]	4852	pick-up	0	17
37470	2020-03-08 00:16:04	2020-03-08	14	[{"id_menu":2,"count":1}]	3148	pick-up	0	14
37471	2020-03-08 00:16:39	2020-03-08	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14870	delivery	5	48
37472	2020-03-08 00:18:00	2020-03-08	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	14805	delivery	5	36
37473	2020-03-08 00:19:55	2020-03-08	9	[{"id_menu":7,"count":1}]	9058	delivery	5	14
37474	2020-03-08 00:21:15	2020-03-08	9	[{"id_menu":6,"count":1}]	1424	pick-up	0	9
37475	2020-03-08 00:29:05	2020-03-08	8	[{"id_menu":5,"count":1}]	14920	delivery	5	13
37476	2020-03-08 00:42:17	2020-03-08	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6515	delivery	5	48
37477	2020-03-08 00:42:49	2020-03-08	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	9053	delivery	5	31
37478	2020-03-08 00:44:45	2020-03-08	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	8579	pick-up	0	40
37479	2020-03-08 00:48:06	2020-03-08	17	[{"id_menu":4,"count":1}]	12889	pick-up	0	17
37480	2020-03-08 00:55:05	2020-03-08	8	[{"id_menu":5,"count":2}]	14817	delivery	5	13
37481	2020-03-08 00:55:57	2020-03-08	9	[{"id_menu":6,"count":1}]	7854	pick-up	0	9
37482	2020-03-08 00:56:38	2020-03-08	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13907	delivery	5	34
37483	2020-03-08 01:00:48	2020-03-08	14	[{"id_menu":2,"count":1}]	5688	delivery	5	19
37484	2020-03-08 01:05:47	2020-03-08	12	[{"id_menu":1,"count":1}]	4425	delivery	5	17
37485	2020-03-08 01:06:12	2020-03-08	8	[{"id_menu":5,"count":1}]	1554	pick-up	0	8
37486	2020-03-08 01:07:45	2020-03-08	14	[{"id_menu":2,"count":1}]	14888	pick-up	0	14
37487	2020-03-08 01:10:47	2020-03-08	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12062	delivery	5	22
37488	2020-03-08 01:12:59	2020-03-08	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	14867	delivery	5	25
37489	2020-03-08 01:18:37	2020-03-08	9	[{"id_menu":7,"count":1}]	5311	pick-up	0	9
37490	2020-03-08 01:32:46	2020-03-08	9	[{"id_menu":7,"count":1}]	14905	delivery	5	14
37491	2020-03-08 01:34:43	2020-03-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	14857	delivery	5	28
37492	2020-03-08 01:35:52	2020-03-08	37	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	14897	delivery	5	42
37493	2020-03-08 01:42:52	2020-03-08	9	[{"id_menu":7,"count":1}]	1563	pick-up	0	9
37494	2020-03-08 01:44:51	2020-03-08	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	14836	delivery	5	26
37495	2020-03-08 01:50:16	2020-03-08	12	[{"id_menu":1,"count":1}]	11394	delivery	5	17
37496	2020-03-08 01:51:11	2020-03-08	9	[{"id_menu":6,"count":1}]	8139	delivery	5	14
37497	2020-03-08 01:58:15	2020-03-08	12	[{"id_menu":1,"count":1}]	7793	delivery	5	17
37498	2020-03-08 02:02:26	2020-03-08	17	[{"id_menu":4,"count":1}]	13410	delivery	5	22
37499	2020-03-08 02:06:32	2020-03-08	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14803	delivery	5	37
37500	2020-03-08 02:08:58	2020-03-08	14	[{"id_menu":2,"count":1}]	14826	delivery	5	19
37501	2020-03-08 02:10:11	2020-03-08	12	[{"id_menu":1,"count":1}]	1266	pick-up	0	12
37502	2020-03-08 02:11:04	2020-03-08	9	[{"id_menu":6,"count":1}]	14843	pick-up	0	9
37503	2020-03-08 02:11:50	2020-03-08	14	[{"id_menu":2,"count":1}]	8183	delivery	5	19
37504	2020-03-08 02:16:32	2020-03-08	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	8601	delivery	5	43
37505	2020-03-08 02:17:30	2020-03-08	14	[{"id_menu":2,"count":1}]	14007	delivery	5	19
37506	2020-03-08 02:21:55	2020-03-08	9	[{"id_menu":7,"count":1}]	14901	delivery	5	14
37507	2020-03-08 02:24:15	2020-03-08	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7887	delivery	5	45
37508	2020-03-08 02:26:10	2020-03-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7451	delivery	5	22
37509	2020-03-08 02:27:52	2020-03-08	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10914	delivery	5	45
37510	2020-03-08 02:34:18	2020-03-08	9	[{"id_menu":7,"count":1}]	10530	delivery	5	14
37511	2020-03-08 02:37:56	2020-03-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3253	delivery	5	28
37512	2020-03-08 02:41:38	2020-03-08	17	[{"id_menu":4,"count":1}]	2187	delivery	5	22
37513	2020-03-08 02:45:57	2020-03-08	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5730	delivery	5	43
37514	2020-03-08 02:46:41	2020-03-08	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	14821	delivery	5	29
37515	2020-03-08 02:48:24	2020-03-08	8	[{"id_menu":5,"count":1}]	5997	delivery	5	13
37516	2020-03-08 02:51:23	2020-03-08	9	[{"id_menu":7,"count":1}]	14876	delivery	5	14
37517	2020-03-08 02:53:31	2020-03-08	9	[{"id_menu":6,"count":1}]	5509	delivery	5	14
37518	2020-03-08 02:56:08	2020-03-08	12	[{"id_menu":3,"count":1}]	13267	pick-up	0	12
37519	2020-03-08 02:56:58	2020-03-08	25	[{"id_menu":4,"count":3},{"id_menu":5,"count":1}]	11320	delivery	5	30
37520	2020-03-08 02:59:07	2020-03-08	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2630	pick-up	0	21
37521	2020-03-08 03:03:36	2020-03-08	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	14824	delivery	5	26
37522	2020-03-08 03:04:59	2020-03-08	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8128	delivery	5	35
37523	2020-03-08 03:06:00	2020-03-08	14	[{"id_menu":2,"count":1}]	14919	delivery	5	19
37524	2020-03-08 03:06:44	2020-03-08	17	[{"id_menu":4,"count":1}]	14384	delivery	5	22
37525	2020-03-08 03:10:24	2020-03-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	10888	delivery	5	28
37526	2020-03-08 03:15:51	2020-03-08	9	[{"id_menu":7,"count":2}]	2672	delivery	5	14
37527	2020-03-08 03:17:38	2020-03-08	9	[{"id_menu":7,"count":1}]	236	pick-up	0	9
37528	2020-03-08 03:19:14	2020-03-08	12	[{"id_menu":1,"count":1}]	6591	pick-up	0	12
37529	2020-03-08 03:21:00	2020-03-08	14	[{"id_menu":2,"count":1}]	14823	pick-up	0	14
37530	2020-03-08 03:23:49	2020-03-08	12	[{"id_menu":1,"count":2}]	6617	delivery	5	17
37531	2020-03-08 03:23:52	2020-03-08	12	[{"id_menu":3,"count":1}]	1314	pick-up	0	12
37532	2020-03-08 03:26:39	2020-03-08	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11908	delivery	5	48
37533	2020-03-08 03:31:12	2020-03-08	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	14814	delivery	5	43
37534	2020-03-08 03:33:19	2020-03-08	9	[{"id_menu":6,"count":1}]	2726	pick-up	0	9
37535	2020-03-08 03:36:08	2020-03-08	9	[{"id_menu":7,"count":1}]	7293	delivery	5	14
37536	2020-03-08 03:36:47	2020-03-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	14715	delivery	5	22
37537	2020-03-08 03:43:57	2020-03-08	8	[{"id_menu":5,"count":1}]	9409	delivery	5	13
37538	2020-03-08 03:45:34	2020-03-08	12	[{"id_menu":1,"count":1}]	7150	pick-up	0	12
37539	2020-03-08 03:47:30	2020-03-08	14	[{"id_menu":2,"count":1}]	371	delivery	5	19
37540	2020-03-08 03:49:34	2020-03-08	9	[{"id_menu":6,"count":1}]	14890	delivery	5	14
37541	2020-03-08 03:49:38	2020-03-08	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	8457	delivery	5	34
37542	2020-03-08 03:53:34	2020-03-08	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2897	pick-up	0	17
37543	2020-03-08 04:04:43	2020-03-08	17	[{"id_menu":4,"count":1}]	14886	delivery	5	22
37544	2020-03-08 04:09:14	2020-03-08	8	[{"id_menu":5,"count":1}]	2871	delivery	5	13
37545	2020-03-08 04:16:36	2020-03-08	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2995	delivery	5	27
37546	2020-03-08 04:17:23	2020-03-08	9	[{"id_menu":7,"count":1}]	14829	delivery	5	14
37547	2020-03-08 04:19:07	2020-03-08	12	[{"id_menu":1,"count":1}]	11725	delivery	5	17
37548	2020-03-08 04:22:06	2020-03-08	9	[{"id_menu":6,"count":1}]	14909	delivery	5	14
37549	2020-03-08 04:22:31	2020-03-08	12	[{"id_menu":1,"count":1}]	14927	delivery	5	17
37550	2020-03-08 04:29:35	2020-03-08	8	[{"id_menu":5,"count":1}]	14811	delivery	5	13
37551	2020-03-08 04:31:23	2020-03-08	8	[{"id_menu":5,"count":1}]	6759	delivery	5	13
37552	2020-03-08 04:41:32	2020-03-08	9	[{"id_menu":7,"count":1}]	5430	delivery	5	14
37553	2020-03-08 04:41:59	2020-03-08	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14841	pick-up	0	30
37554	2020-03-08 04:52:52	2020-03-08	9	[{"id_menu":6,"count":1}]	5841	delivery	5	14
37555	2020-03-08 04:53:09	2020-03-08	9	[{"id_menu":7,"count":1}]	7001	delivery	5	14
37556	2020-03-08 04:59:11	2020-03-08	17	[{"id_menu":4,"count":1}]	12139	pick-up	0	17
37557	2020-03-08 05:02:43	2020-03-08	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5886	delivery	5	36
37558	2020-03-08 05:04:54	2020-03-08	14	[{"id_menu":2,"count":1}]	11248	delivery	5	19
37559	2020-03-08 05:05:27	2020-03-08	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	11892	delivery	5	29
37560	2020-03-08 05:08:25	2020-03-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2497	pick-up	0	23
37561	2020-03-08 05:12:41	2020-03-08	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	12514	pick-up	0	26
37562	2020-03-08 05:14:59	2020-03-08	9	[{"id_menu":6,"count":1}]	6302	delivery	5	14
37563	2020-03-08 05:22:47	2020-03-08	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10122	delivery	5	22
37564	2020-03-08 05:30:24	2020-03-08	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10518	delivery	5	36
37565	2020-03-08 05:32:44	2020-03-08	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9516	delivery	5	37
37566	2020-03-08 05:34:57	2020-03-08	8	[{"id_menu":5,"count":1}]	7094	pick-up	0	8
37567	2020-03-08 05:36:42	2020-03-08	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	14891	delivery	5	38
37568	2020-03-08 05:43:02	2020-03-08	9	[{"id_menu":6,"count":1}]	3684	delivery	5	14
37569	2020-03-08 05:52:58	2020-03-08	9	[{"id_menu":6,"count":1}]	281	delivery	5	14
37570	2020-03-08 05:56:50	2020-03-08	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	9513	delivery	5	31
37571	2020-03-08 06:04:20	2020-03-08	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	4060	delivery	5	25
37572	2020-03-08 06:05:55	2020-03-08	12	[{"id_menu":1,"count":1}]	14846	delivery	5	17
37573	2020-03-08 06:09:34	2020-03-08	12	[{"id_menu":1,"count":1}]	14910	delivery	5	17
37574	2020-03-08 06:11:26	2020-03-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	5427	pick-up	0	23
37575	2020-03-08 06:11:41	2020-03-08	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12180	delivery	5	43
37576	2020-03-08 06:14:42	2020-03-08	12	[{"id_menu":3,"count":1}]	7410	delivery	5	17
37577	2020-03-08 06:18:45	2020-03-08	14	[{"id_menu":2,"count":1}]	14908	delivery	5	19
37578	2020-03-08 06:19:29	2020-03-08	9	[{"id_menu":6,"count":1}]	8341	pick-up	0	9
37579	2020-03-08 06:21:09	2020-03-08	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14924	delivery	5	36
37580	2020-03-08 06:27:20	2020-03-08	12	[{"id_menu":3,"count":2}]	14871	pick-up	0	12
37581	2020-03-08 06:29:25	2020-03-08	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14809	delivery	5	35
37582	2020-03-08 06:33:37	2020-03-08	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3997	delivery	5	22
37583	2020-03-08 06:37:35	2020-03-08	14	[{"id_menu":2,"count":1}]	9995	delivery	5	19
37584	2020-03-08 06:41:23	2020-03-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8919	delivery	5	23
37585	2020-03-08 06:41:24	2020-03-08	8	[{"id_menu":5,"count":1}]	292	delivery	5	13
37586	2020-03-08 06:41:33	2020-03-08	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	8670	delivery	5	40
37587	2020-03-08 06:47:02	2020-03-08	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12287	delivery	5	35
37588	2020-03-08 06:54:29	2020-03-08	8	[{"id_menu":5,"count":1}]	10853	pick-up	0	8
37589	2020-03-08 06:55:43	2020-03-08	12	[{"id_menu":3,"count":1}]	14889	delivery	5	17
37590	2020-03-08 06:55:56	2020-03-08	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14869	delivery	5	43
37591	2020-03-08 07:07:10	2020-03-08	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14822	delivery	5	35
37592	2020-03-08 07:07:52	2020-03-08	8	[{"id_menu":5,"count":1}]	14930	delivery	5	13
37593	2020-03-08 07:09:41	2020-03-08	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	7530	delivery	5	26
37594	2020-03-08 07:15:52	2020-03-08	12	[{"id_menu":1,"count":1}]	7050	pick-up	0	12
37595	2020-03-08 07:16:04	2020-03-08	12	[{"id_menu":3,"count":1}]	12699	pick-up	0	12
37596	2020-03-08 07:17:34	2020-03-08	12	[{"id_menu":3,"count":1}]	1827	pick-up	0	12
37597	2020-03-08 07:19:28	2020-03-08	12	[{"id_menu":3,"count":1}]	9193	pick-up	0	12
37598	2020-03-08 07:19:51	2020-03-08	9	[{"id_menu":7,"count":1}]	2220	pick-up	0	9
37599	2020-03-08 07:21:07	2020-03-08	14	[{"id_menu":2,"count":1}]	1996	pick-up	0	14
37600	2020-03-08 07:23:28	2020-03-08	8	[{"id_menu":5,"count":1}]	14923	pick-up	0	8
37601	2020-03-08 07:26:26	2020-03-08	17	[{"id_menu":4,"count":1}]	14852	delivery	5	22
37602	2020-03-08 07:26:46	2020-03-08	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8468	delivery	5	39
37603	2020-03-08 07:28:21	2020-03-08	9	[{"id_menu":7,"count":1}]	4615	delivery	5	14
37604	2020-03-08 07:37:18	2020-03-08	17	[{"id_menu":4,"count":1}]	1864	delivery	5	22
37605	2020-03-08 07:42:40	2020-03-08	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14862	delivery	5	43
37606	2020-03-08 07:42:43	2020-03-08	9	[{"id_menu":6,"count":1}]	1992	pick-up	0	9
37607	2020-03-08 07:45:54	2020-03-08	17	[{"id_menu":4,"count":1}]	228	delivery	5	22
37608	2020-03-08 07:49:28	2020-03-08	9	[{"id_menu":6,"count":1}]	6758	pick-up	0	9
37609	2020-03-08 07:56:45	2020-03-08	14	[{"id_menu":2,"count":1}]	9749	delivery	5	19
37610	2020-03-08 07:58:04	2020-03-08	12	[{"id_menu":3,"count":1}]	2885	delivery	5	17
37611	2020-03-08 08:01:50	2020-03-08	9	[{"id_menu":7,"count":1}]	14850	delivery	5	14
37612	2020-03-08 08:06:07	2020-03-08	9	[{"id_menu":6,"count":1}]	5497	delivery	5	14
37613	2020-03-08 08:08:29	2020-03-08	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	10461	delivery	5	25
37614	2020-03-08 08:10:52	2020-03-08	9	[{"id_menu":7,"count":1}]	6175	delivery	5	14
37615	2020-03-08 08:14:28	2020-03-08	14	[{"id_menu":2,"count":1}]	14881	delivery	5	19
37616	2020-03-08 08:15:16	2020-03-08	9	[{"id_menu":6,"count":1}]	14918	pick-up	0	9
37617	2020-03-08 08:15:25	2020-03-08	17	[{"id_menu":4,"count":1}]	3956	delivery	5	22
37618	2020-03-08 08:17:11	2020-03-08	17	[{"id_menu":4,"count":3}]	2651	pick-up	0	17
37619	2020-03-08 08:20:07	2020-03-08	9	[{"id_menu":6,"count":1}]	14874	delivery	5	14
37620	2020-03-08 08:20:37	2020-03-08	8	[{"id_menu":5,"count":1}]	7430	pick-up	0	8
37621	2020-03-08 08:29:20	2020-03-08	9	[{"id_menu":6,"count":1}]	14355	delivery	5	14
37622	2020-03-08 08:29:28	2020-03-08	14	[{"id_menu":2,"count":1}]	14856	delivery	5	19
37623	2020-03-08 08:33:54	2020-03-08	9	[{"id_menu":7,"count":1}]	6134	pick-up	0	9
37624	2020-03-08 08:36:08	2020-03-08	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	14844	delivery	5	44
37625	2020-03-08 08:37:04	2020-03-08	9	[{"id_menu":6,"count":1}]	13275	delivery	5	14
37626	2020-03-08 08:47:35	2020-03-08	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14833	delivery	5	43
37627	2020-03-08 08:48:38	2020-03-08	17	[{"id_menu":4,"count":2}]	10679	pick-up	0	17
37628	2020-03-08 08:49:43	2020-03-08	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	10244	pick-up	0	31
37629	2020-03-08 08:50:44	2020-03-08	9	[{"id_menu":6,"count":1}]	9223	delivery	5	14
37630	2020-03-08 08:54:26	2020-03-08	9	[{"id_menu":7,"count":1}]	14827	delivery	5	14
37631	2020-03-08 08:57:37	2020-03-08	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	821	pick-up	0	29
37632	2020-03-08 09:02:50	2020-03-08	8	[{"id_menu":5,"count":1}]	14673	pick-up	0	8
37633	2020-03-08 09:04:35	2020-03-08	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	12907	delivery	5	28
37634	2020-03-08 09:12:11	2020-03-08	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	14815	delivery	5	26
37635	2020-03-08 09:12:55	2020-03-08	12	[{"id_menu":1,"count":1}]	14913	pick-up	0	12
37636	2020-03-08 09:13:00	2020-03-08	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	14900	delivery	5	26
37637	2020-03-08 09:13:05	2020-03-08	17	[{"id_menu":4,"count":1}]	4137	delivery	5	22
37638	2020-03-08 09:14:47	2020-03-08	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	8355	pick-up	0	29
37639	2020-03-08 09:17:38	2020-03-08	17	[{"id_menu":4,"count":1}]	184	pick-up	0	17
37640	2020-03-08 09:25:21	2020-03-08	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14853	delivery	5	34
37641	2020-03-08 09:33:55	2020-03-08	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14922	delivery	5	34
37642	2020-03-08 09:40:46	2020-03-08	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	14812	delivery	5	22
37643	2020-03-08 09:45:26	2020-03-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3851	pick-up	0	23
37644	2020-03-08 09:48:48	2020-03-08	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	14879	delivery	5	30
37645	2020-03-08 09:57:07	2020-03-08	9	[{"id_menu":6,"count":1}]	8220	delivery	5	14
37646	2020-03-08 09:58:52	2020-03-08	14	[{"id_menu":2,"count":1}]	2231	delivery	5	19
37647	2020-03-08 10:13:28	2020-03-08	8	[{"id_menu":5,"count":1}]	14851	pick-up	0	8
37648	2020-03-08 10:14:05	2020-03-08	12	[{"id_menu":3,"count":1}]	3634	pick-up	0	12
37649	2020-03-08 10:26:06	2020-03-08	8	[{"id_menu":5,"count":1}]	14819	delivery	5	13
37650	2020-03-08 10:26:43	2020-03-08	9	[{"id_menu":6,"count":1}]	5014	pick-up	0	9
37651	2020-03-08 10:33:50	2020-03-08	12	[{"id_menu":1,"count":1}]	1207	delivery	5	17
37652	2020-03-08 10:35:07	2020-03-08	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	14849	delivery	5	48
37653	2020-03-08 10:37:08	2020-03-08	9	[{"id_menu":6,"count":1}]	14860	delivery	5	14
37654	2020-03-08 10:37:45	2020-03-08	17	[{"id_menu":4,"count":1}]	12011	delivery	5	22
37655	2020-03-08 10:37:50	2020-03-08	17	[{"id_menu":4,"count":1}]	14838	delivery	5	22
37656	2020-03-08 10:40:11	2020-03-08	12	[{"id_menu":1,"count":1}]	2065	pick-up	0	12
37657	2020-03-08 10:40:14	2020-03-08	12	[{"id_menu":1,"count":1}]	9466	delivery	5	17
37658	2020-03-08 10:46:34	2020-03-08	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	14892	delivery	5	37
37659	2020-03-08 10:48:32	2020-03-08	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	14882	delivery	5	45
37660	2020-03-08 10:51:28	2020-03-08	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1023	delivery	5	26
37661	2020-03-08 10:54:36	2020-03-08	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2420	pick-up	0	26
37662	2020-03-08 11:01:27	2020-03-08	14	[{"id_menu":2,"count":1}]	471	delivery	5	19
37663	2020-03-08 11:03:59	2020-03-08	8	[{"id_menu":5,"count":2}]	7488	delivery	5	13
37664	2020-03-08 11:06:06	2020-03-08	8	[{"id_menu":5,"count":2}]	7934	pick-up	0	8
37665	2020-03-08 11:07:18	2020-03-08	9	[{"id_menu":6,"count":1}]	14842	delivery	5	14
37666	2020-03-08 11:07:38	2020-03-08	9	[{"id_menu":6,"count":1}]	14808	delivery	5	14
37667	2020-03-08 11:07:48	2020-03-08	14	[{"id_menu":2,"count":1}]	14710	pick-up	0	14
37668	2020-03-08 11:08:46	2020-03-08	17	[{"id_menu":4,"count":2}]	14559	pick-up	0	17
37669	2020-03-08 11:12:11	2020-03-08	12	[{"id_menu":3,"count":1}]	14898	pick-up	0	12
37670	2020-03-08 11:15:24	2020-03-08	8	[{"id_menu":5,"count":1}]	3949	pick-up	0	8
37671	2020-03-08 11:15:30	2020-03-08	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	14911	delivery	5	44
37672	2020-03-08 11:21:14	2020-03-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	14696	delivery	5	28
37673	2020-03-08 11:23:28	2020-03-08	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5668	pick-up	0	26
37674	2020-03-08 11:25:54	2020-03-08	9	[{"id_menu":6,"count":1}]	5808	pick-up	0	9
37675	2020-03-08 11:30:36	2020-03-08	12	[{"id_menu":1,"count":1}]	13904	delivery	5	17
37676	2020-03-08 11:32:19	2020-03-08	12	[{"id_menu":3,"count":1}]	8873	pick-up	0	12
37677	2020-03-08 11:35:50	2020-03-08	9	[{"id_menu":6,"count":1}]	757	pick-up	0	9
37678	2020-03-08 11:36:32	2020-03-08	12	[{"id_menu":1,"count":1}]	2662	delivery	5	17
37679	2020-03-08 11:39:44	2020-03-08	8	[{"id_menu":5,"count":1}]	13548	pick-up	0	8
37680	2020-03-08 11:42:14	2020-03-08	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	14672	delivery	5	38
37681	2020-03-08 11:44:31	2020-03-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1970	delivery	5	28
37682	2020-03-08 11:55:18	2020-03-08	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14165	delivery	5	35
37683	2020-03-08 11:55:31	2020-03-08	14	[{"id_menu":2,"count":1}]	6672	pick-up	0	14
37684	2020-03-08 11:55:45	2020-03-08	9	[{"id_menu":6,"count":1}]	14043	delivery	5	14
37685	2020-03-08 12:00:03	2020-03-08	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	14865	delivery	5	40
37686	2020-03-08 12:00:37	2020-03-08	14	[{"id_menu":2,"count":1}]	705	pick-up	0	14
37687	2020-03-08 12:00:58	2020-03-08	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	5501	delivery	5	25
37688	2020-03-08 12:11:17	2020-03-08	8	[{"id_menu":5,"count":1}]	269	delivery	5	13
37689	2020-03-08 12:11:21	2020-03-08	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11867	delivery	5	22
37690	2020-03-08 12:15:39	2020-03-08	17	[{"id_menu":4,"count":1}]	293	delivery	5	22
37691	2020-03-08 12:20:03	2020-03-08	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4989	delivery	5	54
37692	2020-03-08 12:22:14	2020-03-08	9	[{"id_menu":7,"count":1}]	13172	delivery	5	14
37693	2020-03-08 12:25:32	2020-03-08	9	[{"id_menu":7,"count":1}]	8261	pick-up	0	9
37694	2020-03-08 12:25:59	2020-03-08	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8539	delivery	5	40
37695	2020-03-08 12:32:04	2020-03-08	17	[{"id_menu":4,"count":2}]	3364	delivery	5	22
37696	2020-03-08 12:34:17	2020-03-08	8	[{"id_menu":5,"count":1}]	12565	delivery	5	13
37697	2020-03-08 12:35:15	2020-03-08	17	[{"id_menu":4,"count":1}]	1616	pick-up	0	17
37698	2020-03-08 12:41:41	2020-03-08	12	[{"id_menu":3,"count":1}]	14928	delivery	5	17
37699	2020-03-08 12:43:09	2020-03-08	8	[{"id_menu":5,"count":1}]	6245	delivery	5	13
37700	2020-03-08 12:53:45	2020-03-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2907	pick-up	0	23
37701	2020-03-08 13:04:58	2020-03-08	9	[{"id_menu":6,"count":1}]	5830	delivery	5	14
37702	2020-03-08 13:05:00	2020-03-08	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	14839	delivery	5	25
37703	2020-03-08 13:05:04	2020-03-08	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14820	delivery	5	22
37704	2020-03-08 13:15:53	2020-03-08	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1497	pick-up	0	26
37705	2020-03-08 13:29:21	2020-03-08	12	[{"id_menu":1,"count":1}]	10910	delivery	5	17
37706	2020-03-08 13:30:30	2020-03-08	17	[{"id_menu":4,"count":1}]	2386	delivery	5	22
37707	2020-03-08 13:31:24	2020-03-08	9	[{"id_menu":7,"count":1}]	2659	pick-up	0	9
37708	2020-03-08 13:32:19	2020-03-08	9	[{"id_menu":6,"count":2}]	1911	delivery	5	14
37709	2020-03-08 13:37:47	2020-03-08	9	[{"id_menu":7,"count":3}]	14864	delivery	5	14
37710	2020-03-08 13:38:41	2020-03-08	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4912	delivery	5	43
37711	2020-03-08 13:39:12	2020-03-08	17	[{"id_menu":4,"count":1}]	5286	pick-up	0	17
37712	2020-03-08 13:45:44	2020-03-08	9	[{"id_menu":6,"count":1}]	10589	pick-up	0	9
37713	2020-03-08 13:46:08	2020-03-08	9	[{"id_menu":6,"count":2}]	14068	delivery	5	14
37714	2020-03-08 13:46:54	2020-03-08	12	[{"id_menu":3,"count":1}]	5141	pick-up	0	12
37715	2020-03-08 13:52:17	2020-03-08	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	12232	delivery	5	26
37716	2020-03-08 13:56:27	2020-03-08	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	11163	delivery	5	31
37717	2020-03-08 13:58:49	2020-03-08	12	[{"id_menu":3,"count":1}]	5648	pick-up	0	12
37718	2020-03-08 14:02:45	2020-03-08	12	[{"id_menu":1,"count":1}]	2136	delivery	5	17
37719	2020-03-08 14:07:34	2020-03-08	14	[{"id_menu":2,"count":2}]	9288	pick-up	0	14
37720	2020-03-08 14:11:42	2020-03-08	9	[{"id_menu":7,"count":1}]	13552	delivery	5	14
37721	2020-03-08 14:15:42	2020-03-08	17	[{"id_menu":4,"count":1}]	10429	delivery	5	22
37722	2020-03-08 14:19:48	2020-03-08	9	[{"id_menu":7,"count":1}]	14735	delivery	5	14
37723	2020-03-08 14:20:14	2020-03-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6271	delivery	5	28
37724	2020-03-08 14:23:22	2020-03-08	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	14899	delivery	5	31
37725	2020-03-08 14:24:20	2020-03-08	12	[{"id_menu":3,"count":1}]	1742	pick-up	0	12
37726	2020-03-08 14:24:43	2020-03-08	9	[{"id_menu":6,"count":1}]	4820	delivery	5	14
37727	2020-03-08 14:31:21	2020-03-08	17	[{"id_menu":4,"count":1}]	3196	pick-up	0	17
37728	2020-03-08 14:46:55	2020-03-08	14	[{"id_menu":2,"count":1}]	11257	delivery	5	19
37729	2020-03-08 14:48:44	2020-03-08	12	[{"id_menu":3,"count":1}]	609	pick-up	0	12
37730	2020-03-08 14:49:26	2020-03-08	9	[{"id_menu":7,"count":1}]	14917	delivery	5	14
37731	2020-03-08 14:49:41	2020-03-08	9	[{"id_menu":7,"count":1}]	14861	delivery	5	14
37732	2020-03-08 14:53:58	2020-03-08	9	[{"id_menu":7,"count":1}]	14893	delivery	5	14
37733	2020-03-08 15:02:58	2020-03-08	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	13857	delivery	5	36
37734	2020-03-08 15:05:37	2020-03-08	9	[{"id_menu":7,"count":1}]	13863	delivery	5	14
37735	2020-03-08 15:08:05	2020-03-08	9	[{"id_menu":7,"count":1}]	6811	delivery	5	14
37736	2020-03-08 15:14:49	2020-03-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	14902	delivery	5	28
37737	2020-03-08 15:16:22	2020-03-08	9	[{"id_menu":6,"count":1}]	10729	delivery	5	14
37738	2020-03-08 15:17:04	2020-03-08	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14854	delivery	5	39
37739	2020-03-08 15:18:32	2020-03-08	14	[{"id_menu":2,"count":1}]	3971	pick-up	0	14
37740	2020-03-08 15:19:38	2020-03-08	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	12222	delivery	5	26
37741	2020-03-08 15:22:36	2020-03-08	9	[{"id_menu":7,"count":2}]	5478	delivery	5	14
37742	2020-03-08 15:22:38	2020-03-08	9	[{"id_menu":7,"count":1}]	4673	delivery	5	14
37743	2020-03-08 15:24:25	2020-03-08	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	13764	delivery	5	31
37744	2020-03-08 15:31:59	2020-03-08	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	14828	delivery	5	23
37745	2020-03-08 15:46:17	2020-03-08	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7766	pick-up	0	31
37746	2020-03-08 15:47:31	2020-03-08	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	3679	delivery	5	39
37747	2020-03-08 15:47:53	2020-03-08	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14806	delivery	5	36
37748	2020-03-08 15:52:18	2020-03-08	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1170	pick-up	0	30
37749	2020-03-08 15:52:21	2020-03-08	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7957	delivery	5	56
37750	2020-03-08 15:58:02	2020-03-08	12	[{"id_menu":3,"count":1}]	1627	pick-up	0	12
37751	2020-03-08 16:08:53	2020-03-08	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	775	delivery	5	36
37752	2020-03-08 16:12:19	2020-03-08	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11215	delivery	5	31
37753	2020-03-08 16:16:32	2020-03-08	12	[{"id_menu":1,"count":1}]	2274	pick-up	0	12
37754	2020-03-08 16:17:08	2020-03-08	17	[{"id_menu":4,"count":1}]	9766	delivery	5	22
37755	2020-03-08 16:19:01	2020-03-08	17	[{"id_menu":4,"count":1}]	14837	delivery	5	22
37756	2020-03-08 16:19:18	2020-03-08	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13770	delivery	5	22
37757	2020-03-08 16:21:55	2020-03-08	8	[{"id_menu":5,"count":1}]	8877	delivery	5	13
37758	2020-03-08 16:23:45	2020-03-08	12	[{"id_menu":1,"count":1}]	7361	delivery	5	17
37759	2020-03-08 16:30:15	2020-03-08	9	[{"id_menu":7,"count":1}]	14868	delivery	5	14
37760	2020-03-08 16:36:31	2020-03-08	14	[{"id_menu":2,"count":1}]	3433	pick-up	0	14
37761	2020-03-08 16:41:29	2020-03-08	14	[{"id_menu":2,"count":1}]	12046	delivery	5	19
37762	2020-03-08 16:50:06	2020-03-08	12	[{"id_menu":1,"count":1}]	3660	delivery	5	17
37763	2020-03-08 16:54:07	2020-03-08	12	[{"id_menu":3,"count":1}]	10200	delivery	5	17
37764	2020-03-08 16:54:55	2020-03-08	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7370	delivery	5	37
37765	2020-03-08 16:59:25	2020-03-08	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9869	delivery	5	45
37766	2020-03-08 17:00:35	2020-03-08	12	[{"id_menu":1,"count":1}]	14825	delivery	5	17
37767	2020-03-08 17:03:33	2020-03-08	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	4233	delivery	5	36
37768	2020-03-08 17:08:29	2020-03-08	9	[{"id_menu":7,"count":1}]	7912	delivery	5	14
37769	2020-03-08 17:15:13	2020-03-08	14	[{"id_menu":2,"count":1}]	14695	delivery	5	19
37770	2020-03-08 17:15:19	2020-03-08	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	9665	delivery	5	45
37771	2020-03-08 17:17:20	2020-03-08	14	[{"id_menu":2,"count":1}]	11510	delivery	5	19
37772	2020-03-08 17:18:04	2020-03-08	17	[{"id_menu":4,"count":1}]	3726	delivery	5	22
37773	2020-03-08 17:18:46	2020-03-08	12	[{"id_menu":1,"count":1}]	14894	delivery	5	17
37774	2020-03-08 17:19:53	2020-03-08	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14810	delivery	5	35
37775	2020-03-08 17:20:49	2020-03-08	12	[{"id_menu":1,"count":1}]	14921	delivery	5	17
37776	2020-03-08 17:22:44	2020-03-08	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	251	pick-up	0	29
37777	2020-03-08 17:23:34	2020-03-08	8	[{"id_menu":5,"count":1}]	14863	delivery	5	13
37778	2020-03-08 17:26:17	2020-03-08	14	[{"id_menu":2,"count":1}]	14858	pick-up	0	14
37779	2020-03-08 17:28:54	2020-03-08	8	[{"id_menu":5,"count":1}]	14830	delivery	5	13
37780	2020-03-08 17:30:09	2020-03-08	8	[{"id_menu":5,"count":1}]	14848	delivery	5	13
37781	2020-03-08 17:33:45	2020-03-08	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	14866	delivery	5	26
37782	2020-03-08 17:39:33	2020-03-08	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	6737	delivery	5	22
37783	2020-03-08 17:45:27	2020-03-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	10222	delivery	5	28
37784	2020-03-08 17:45:38	2020-03-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	14835	delivery	5	28
37785	2020-03-08 17:48:40	2020-03-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8687	delivery	5	23
37786	2020-03-08 17:49:10	2020-03-08	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	14807	delivery	5	43
37787	2020-03-08 17:56:06	2020-03-08	14	[{"id_menu":2,"count":1}]	14772	delivery	5	19
37788	2020-03-08 17:58:08	2020-03-08	8	[{"id_menu":5,"count":1}]	14877	pick-up	0	8
37789	2020-03-08 18:00:10	2020-03-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3048	delivery	5	28
37790	2020-03-08 18:00:39	2020-03-08	9	[{"id_menu":7,"count":1}]	14873	delivery	5	14
37791	2020-03-08 18:04:14	2020-03-08	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	14818	delivery	5	43
37792	2020-03-08 18:04:47	2020-03-08	9	[{"id_menu":6,"count":1}]	11625	delivery	5	14
37793	2020-03-08 18:06:53	2020-03-08	17	[{"id_menu":4,"count":1}]	14904	pick-up	0	17
37794	2020-03-08 18:11:18	2020-03-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1127	pick-up	0	23
37795	2020-03-08 18:19:25	2020-03-08	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1846	delivery	5	35
37796	2020-03-08 18:22:41	2020-03-08	9	[{"id_menu":7,"count":1}]	14263	delivery	5	14
37797	2020-03-08 18:25:52	2020-03-08	8	[{"id_menu":5,"count":1}]	5125	pick-up	0	8
37798	2020-03-08 18:27:23	2020-03-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	14883	delivery	5	28
37799	2020-03-08 18:29:24	2020-03-08	17	[{"id_menu":4,"count":1}]	13634	delivery	5	22
37800	2020-03-08 18:43:47	2020-03-08	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14896	delivery	5	31
37801	2020-03-08 18:45:20	2020-03-08	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	12770	delivery	5	30
37802	2020-03-08 18:49:54	2020-03-08	14	[{"id_menu":2,"count":1}]	9269	delivery	5	19
37803	2020-03-08 18:51:51	2020-03-08	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12081	delivery	5	31
37804	2020-03-08 18:53:30	2020-03-08	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	9603	pick-up	0	43
37805	2020-03-08 18:54:25	2020-03-08	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	887	delivery	5	22
37806	2020-03-08 18:55:55	2020-03-08	12	[{"id_menu":3,"count":1}]	14925	delivery	5	17
37807	2020-03-08 18:59:35	2020-03-08	14	[{"id_menu":2,"count":1}]	4546	pick-up	0	14
37808	2020-03-08 19:01:11	2020-03-08	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3810	delivery	5	51
37809	2020-03-08 19:04:18	2020-03-08	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	12681	delivery	5	31
37810	2020-03-08 19:06:54	2020-03-08	14	[{"id_menu":2,"count":1}]	2171	delivery	5	19
37811	2020-03-08 19:09:05	2020-03-08	17	[{"id_menu":4,"count":1}]	6232	pick-up	0	17
37812	2020-03-08 19:10:59	2020-03-08	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	14929	delivery	5	39
37813	2020-03-08 19:13:11	2020-03-08	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	6441	delivery	5	31
37814	2020-03-08 19:20:47	2020-03-08	12	[{"id_menu":1,"count":1}]	5829	pick-up	0	12
37815	2020-03-08 19:23:24	2020-03-08	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	14887	pick-up	0	24
37816	2020-03-08 19:25:34	2020-03-08	9	[{"id_menu":6,"count":1}]	3697	delivery	5	14
37817	2020-03-08 19:27:44	2020-03-08	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	9304	pick-up	0	29
37818	2020-03-08 19:39:07	2020-03-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3212	delivery	5	23
37819	2020-03-08 19:51:56	2020-03-08	9	[{"id_menu":7,"count":1}]	14855	delivery	5	14
37820	2020-03-08 19:52:46	2020-03-08	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	10196	delivery	5	40
37821	2020-03-08 19:59:10	2020-03-08	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	14906	pick-up	0	34
37822	2020-03-08 20:00:18	2020-03-08	8	[{"id_menu":5,"count":1}]	1373	pick-up	0	8
37823	2020-03-08 20:01:03	2020-03-08	12	[{"id_menu":1,"count":1}]	13675	delivery	5	17
37824	2020-03-08 20:07:24	2020-03-08	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9166	delivery	5	34
37825	2020-03-08 20:20:50	2020-03-08	12	[{"id_menu":1,"count":1}]	14885	pick-up	0	12
37826	2020-03-08 20:25:08	2020-03-08	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1306	delivery	5	26
37827	2020-03-08 20:25:30	2020-03-08	8	[{"id_menu":5,"count":1}]	4964	delivery	5	13
37828	2020-03-08 20:26:28	2020-03-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	12677	delivery	5	28
37829	2020-03-08 20:34:34	2020-03-08	9	[{"id_menu":6,"count":1}]	14804	delivery	5	14
37830	2020-03-08 20:36:14	2020-03-08	8	[{"id_menu":5,"count":1}]	13557	delivery	5	13
37831	2020-03-08 20:36:23	2020-03-08	17	[{"id_menu":4,"count":1}]	14708	delivery	5	22
37832	2020-03-08 20:38:11	2020-03-08	9	[{"id_menu":6,"count":1}]	14878	delivery	5	14
37833	2020-03-08 20:40:41	2020-03-08	8	[{"id_menu":5,"count":1}]	14907	delivery	5	13
37834	2020-03-08 20:41:49	2020-03-08	9	[{"id_menu":6,"count":1}]	14914	delivery	5	14
37835	2020-03-08 20:44:56	2020-03-08	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7308	delivery	5	37
37836	2020-03-08 20:45:24	2020-03-08	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14933	delivery	5	31
37837	2020-03-08 20:46:38	2020-03-08	9	[{"id_menu":7,"count":1}]	14884	pick-up	0	9
37838	2020-03-08 20:55:30	2020-03-08	17	[{"id_menu":4,"count":1}]	9065	pick-up	0	17
37839	2020-03-08 21:03:06	2020-03-08	12	[{"id_menu":1,"count":1}]	2432	delivery	5	17
37840	2020-03-08 21:04:30	2020-03-08	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	748	delivery	5	52
37841	2020-03-08 21:07:44	2020-03-08	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3965	delivery	5	31
37842	2020-03-08 21:09:22	2020-03-08	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	14926	pick-up	0	29
37843	2020-03-08 21:16:29	2020-03-08	17	[{"id_menu":4,"count":1}]	12851	pick-up	0	17
37844	2020-03-08 21:17:09	2020-03-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14831	delivery	5	23
37845	2020-03-08 21:19:46	2020-03-08	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11865	delivery	5	35
37846	2020-03-08 21:20:12	2020-03-08	8	[{"id_menu":5,"count":1}]	14932	delivery	5	13
37847	2020-03-08 21:24:18	2020-03-08	12	[{"id_menu":3,"count":1}]	14880	pick-up	0	12
37848	2020-03-08 21:27:03	2020-03-08	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	7206	delivery	5	39
37849	2020-03-08 21:27:54	2020-03-08	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2645	delivery	5	36
37850	2020-03-08 21:30:19	2020-03-08	9	[{"id_menu":7,"count":1}]	3754	pick-up	0	9
37851	2020-03-08 21:31:58	2020-03-08	9	[{"id_menu":6,"count":1}]	1015	pick-up	0	9
37852	2020-03-08 21:37:45	2020-03-08	8	[{"id_menu":5,"count":1}]	8450	delivery	5	13
37853	2020-03-08 21:39:04	2020-03-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	13060	delivery	5	28
37854	2020-03-08 21:40:21	2020-03-08	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	14872	delivery	5	36
37855	2020-03-08 21:42:08	2020-03-08	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14875	delivery	5	22
37856	2020-03-08 21:42:58	2020-03-08	9	[{"id_menu":6,"count":1}]	14816	delivery	5	14
37857	2020-03-08 21:44:00	2020-03-08	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	14895	delivery	5	23
37858	2020-03-08 21:58:35	2020-03-08	9	[{"id_menu":6,"count":1}]	14912	delivery	5	14
37859	2020-03-08 22:00:43	2020-03-08	9	[{"id_menu":6,"count":1}]	13844	pick-up	0	9
37860	2020-03-08 22:01:46	2020-03-08	12	[{"id_menu":3,"count":1}]	14832	delivery	5	17
37861	2020-03-08 22:04:26	2020-03-08	9	[{"id_menu":7,"count":1}]	4368	pick-up	0	9
37862	2020-03-08 22:06:41	2020-03-08	9	[{"id_menu":6,"count":1}]	14159	delivery	5	14
37863	2020-03-08 22:09:03	2020-03-08	12	[{"id_menu":3,"count":1}]	13259	delivery	5	17
37864	2020-03-08 22:16:26	2020-03-08	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	14813	delivery	5	42
37865	2020-03-08 22:17:13	2020-03-08	8	[{"id_menu":5,"count":1}]	12873	pick-up	0	8
37866	2020-03-08 22:23:15	2020-03-08	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	8986	delivery	5	39
37867	2020-03-08 22:26:06	2020-03-08	12	[{"id_menu":1,"count":1}]	2835	pick-up	0	12
37868	2020-03-08 22:28:16	2020-03-08	17	[{"id_menu":4,"count":1}]	12402	delivery	5	22
37869	2020-03-08 22:30:26	2020-03-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	14859	delivery	5	22
37870	2020-03-08 22:30:34	2020-03-08	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	5772	delivery	5	25
37871	2020-03-08 22:31:16	2020-03-08	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2308	pick-up	0	26
37872	2020-03-08 22:43:53	2020-03-08	14	[{"id_menu":2,"count":1}]	14915	delivery	5	19
37873	2020-03-08 22:44:01	2020-03-08	12	[{"id_menu":3,"count":1}]	4102	pick-up	0	12
37874	2020-03-08 22:51:28	2020-03-08	17	[{"id_menu":4,"count":1}]	2155	delivery	5	22
37875	2020-03-08 22:54:55	2020-03-08	9	[{"id_menu":7,"count":1}]	14845	pick-up	0	9
37876	2020-03-08 22:56:14	2020-03-08	8	[{"id_menu":5,"count":1}]	14931	delivery	5	13
37877	2020-03-08 22:58:11	2020-03-08	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11094	delivery	5	22
37878	2020-03-08 23:01:04	2020-03-08	12	[{"id_menu":3,"count":1}]	14847	delivery	5	17
37879	2020-03-08 23:04:08	2020-03-08	8	[{"id_menu":5,"count":1}]	14834	delivery	5	13
37880	2020-03-08 23:09:38	2020-03-08	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	7894	pick-up	0	21
37881	2020-03-08 23:15:22	2020-03-08	12	[{"id_menu":1,"count":1}]	13510	delivery	5	17
37882	2020-03-08 23:17:40	2020-03-08	9	[{"id_menu":6,"count":1}]	3988	delivery	5	14
37883	2020-03-08 23:22:45	2020-03-08	17	[{"id_menu":4,"count":1}]	7205	pick-up	0	17
37884	2020-03-08 23:27:54	2020-03-08	14	[{"id_menu":2,"count":2}]	6328	pick-up	0	14
37885	2020-03-08 23:32:10	2020-03-08	9	[{"id_menu":6,"count":1}]	8410	delivery	5	14
37886	2020-03-08 23:35:07	2020-03-08	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	2367	pick-up	0	21
37887	2020-03-08 23:36:50	2020-03-08	8	[{"id_menu":5,"count":1}]	294	pick-up	0	8
37888	2020-03-08 23:40:11	2020-03-08	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5584	delivery	5	34
37889	2020-03-08 23:40:41	2020-03-08	8	[{"id_menu":5,"count":1}]	14903	pick-up	0	8
37890	2020-03-08 23:43:47	2020-03-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3041	delivery	5	23
37891	2020-03-08 23:49:56	2020-03-08	12	[{"id_menu":1,"count":1}]	6241	delivery	5	17
37892	2020-03-08 23:54:43	2020-03-08	9	[{"id_menu":6,"count":1}]	14916	delivery	5	14
37893	2020-03-09 00:08:44	2020-03-09	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	7420	delivery	5	48
37894	2020-03-09 00:26:23	2020-03-09	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1450	pick-up	0	17
37895	2020-03-09 00:36:08	2020-03-09	9	[{"id_menu":6,"count":1}]	2963	delivery	5	14
37896	2020-03-09 00:40:32	2020-03-09	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3459	delivery	5	34
37897	2020-03-09 00:45:27	2020-03-09	9	[{"id_menu":6,"count":1}]	3885	delivery	5	14
37898	2020-03-09 00:59:58	2020-03-09	12	[{"id_menu":3,"count":1}]	14947	delivery	5	17
37899	2020-03-09 01:05:08	2020-03-09	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	15041	delivery	5	26
37900	2020-03-09 01:13:41	2020-03-09	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	5880	delivery	5	36
37901	2020-03-09 01:13:44	2020-03-09	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	5571	delivery	5	40
37902	2020-03-09 01:16:03	2020-03-09	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	1529	delivery	5	25
37903	2020-03-09 01:28:55	2020-03-09	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1289	delivery	5	34
37904	2020-03-09 01:36:48	2020-03-09	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	15032	delivery	5	43
37905	2020-03-09 01:38:31	2020-03-09	14	[{"id_menu":2,"count":1}]	14953	delivery	5	19
37906	2020-03-09 01:53:23	2020-03-09	9	[{"id_menu":7,"count":1}]	7293	delivery	5	14
37907	2020-03-09 01:59:51	2020-03-09	12	[{"id_menu":3,"count":2}]	2078	delivery	5	17
37908	2020-03-09 02:02:13	2020-03-09	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":2}]	10799	delivery	5	26
37909	2020-03-09 02:02:37	2020-03-09	12	[{"id_menu":1,"count":1}]	14950	delivery	5	17
37910	2020-03-09 02:10:55	2020-03-09	9	[{"id_menu":6,"count":1}]	6835	delivery	5	14
37911	2020-03-09 02:18:36	2020-03-09	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	13930	delivery	5	23
37912	2020-03-09 02:21:46	2020-03-09	9	[{"id_menu":7,"count":1}]	11000	delivery	5	14
37913	2020-03-09 02:31:52	2020-03-09	8	[{"id_menu":5,"count":1}]	15008	delivery	5	13
37914	2020-03-09 02:44:28	2020-03-09	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	15031	delivery	5	26
37915	2020-03-09 02:48:22	2020-03-09	14	[{"id_menu":2,"count":1}]	5064	delivery	5	19
37916	2020-03-09 02:51:01	2020-03-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7510	pick-up	0	17
37917	2020-03-09 02:51:08	2020-03-09	14	[{"id_menu":2,"count":1}]	10679	pick-up	0	14
37918	2020-03-09 02:53:10	2020-03-09	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14940	delivery	5	48
37919	2020-03-09 02:57:34	2020-03-09	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	15042	delivery	5	40
37920	2020-03-09 03:06:15	2020-03-09	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	14997	delivery	5	26
37921	2020-03-09 03:27:20	2020-03-09	8	[{"id_menu":5,"count":1}]	14974	delivery	5	13
37922	2020-03-09 03:33:42	2020-03-09	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5024	delivery	5	37
37923	2020-03-09 03:34:08	2020-03-09	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	8561	pick-up	0	31
37924	2020-03-09 03:37:58	2020-03-09	9	[{"id_menu":6,"count":1}]	15029	pick-up	0	9
37925	2020-03-09 03:38:03	2020-03-09	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	13507	delivery	5	36
37926	2020-03-09 03:48:09	2020-03-09	8	[{"id_menu":5,"count":1}]	7252	pick-up	0	8
37927	2020-03-09 04:09:12	2020-03-09	12	[{"id_menu":3,"count":1}]	11253	pick-up	0	12
37928	2020-03-09 04:12:32	2020-03-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14962	delivery	5	23
37929	2020-03-09 04:16:47	2020-03-09	9	[{"id_menu":6,"count":1}]	14970	pick-up	0	9
37930	2020-03-09 04:17:25	2020-03-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	14990	delivery	5	28
37931	2020-03-09 04:21:17	2020-03-09	9	[{"id_menu":7,"count":2}]	15012	delivery	5	14
37932	2020-03-09 04:33:27	2020-03-09	12	[{"id_menu":1,"count":1}]	14936	delivery	5	17
37933	2020-03-09 04:40:53	2020-03-09	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	3033	pick-up	0	37
37934	2020-03-09 04:48:33	2020-03-09	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	11311	delivery	5	26
37935	2020-03-09 05:07:23	2020-03-09	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14949	delivery	5	47
37936	2020-03-09 05:14:22	2020-03-09	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14942	delivery	5	22
37937	2020-03-09 05:18:24	2020-03-09	12	[{"id_menu":1,"count":1}]	8726	delivery	5	17
37938	2020-03-09 05:24:34	2020-03-09	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2662	delivery	5	26
37939	2020-03-09 05:24:40	2020-03-09	17	[{"id_menu":4,"count":1}]	14982	pick-up	0	17
37940	2020-03-09 05:24:48	2020-03-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12330	delivery	5	23
37941	2020-03-09 05:31:53	2020-03-09	8	[{"id_menu":5,"count":1}]	12054	pick-up	0	8
37942	2020-03-09 05:45:28	2020-03-09	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	13802	delivery	5	44
37943	2020-03-09 06:50:30	2020-03-09	17	[{"id_menu":4,"count":1}]	12361	delivery	5	22
37944	2020-03-09 06:52:32	2020-03-09	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	5641	delivery	5	25
37945	2020-03-09 07:01:14	2020-03-09	9	[{"id_menu":7,"count":2}]	9293	delivery	5	14
37946	2020-03-09 07:02:35	2020-03-09	14	[{"id_menu":2,"count":1}]	6265	pick-up	0	14
37947	2020-03-09 07:20:16	2020-03-09	12	[{"id_menu":3,"count":1}]	7980	delivery	5	17
37948	2020-03-09 07:32:30	2020-03-09	12	[{"id_menu":3,"count":1}]	9050	pick-up	0	12
37949	2020-03-09 07:47:23	2020-03-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4546	pick-up	0	18
37950	2020-03-09 07:48:56	2020-03-09	9	[{"id_menu":6,"count":1}]	15013	delivery	5	14
37951	2020-03-09 07:53:55	2020-03-09	12	[{"id_menu":1,"count":1}]	377	pick-up	0	12
37952	2020-03-09 07:54:13	2020-03-09	17	[{"id_menu":4,"count":1}]	5570	delivery	5	22
37953	2020-03-09 07:57:57	2020-03-09	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	13294	delivery	5	42
37954	2020-03-09 08:00:02	2020-03-09	9	[{"id_menu":6,"count":1}]	12057	delivery	5	14
37955	2020-03-09 08:08:14	2020-03-09	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	3655	delivery	5	42
37956	2020-03-09 08:10:43	2020-03-09	9	[{"id_menu":6,"count":1}]	2922	pick-up	0	9
37957	2020-03-09 08:22:42	2020-03-09	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	2611	pick-up	0	24
37958	2020-03-09 08:27:26	2020-03-09	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	15028	pick-up	0	29
37959	2020-03-09 08:32:43	2020-03-09	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	13202	delivery	5	25
37960	2020-03-09 08:47:58	2020-03-09	9	[{"id_menu":6,"count":1}]	15010	delivery	5	14
37961	2020-03-09 09:13:40	2020-03-09	14	[{"id_menu":2,"count":1}]	2659	pick-up	0	14
37962	2020-03-09 09:24:16	2020-03-09	17	[{"id_menu":4,"count":1}]	14975	pick-up	0	17
37963	2020-03-09 09:25:14	2020-03-09	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	15015	delivery	5	29
37964	2020-03-09 09:29:21	2020-03-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	8273	delivery	5	23
37965	2020-03-09 09:29:35	2020-03-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	536	pick-up	0	23
37966	2020-03-09 09:34:19	2020-03-09	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	13528	pick-up	0	33
37967	2020-03-09 09:38:50	2020-03-09	12	[{"id_menu":1,"count":1}]	2439	pick-up	0	12
37968	2020-03-09 09:47:39	2020-03-09	12	[{"id_menu":3,"count":1}]	6074	pick-up	0	12
37969	2020-03-09 09:59:40	2020-03-09	17	[{"id_menu":4,"count":1}]	1748	pick-up	0	17
37970	2020-03-09 10:00:44	2020-03-09	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	11686	pick-up	0	29
37971	2020-03-09 10:04:38	2020-03-09	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7770	delivery	5	35
37972	2020-03-09 10:20:59	2020-03-09	12	[{"id_menu":3,"count":1}]	14987	delivery	5	17
37973	2020-03-09 10:22:38	2020-03-09	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	5527	delivery	5	31
37974	2020-03-09 10:27:59	2020-03-09	17	[{"id_menu":4,"count":1}]	62	pick-up	0	17
37975	2020-03-09 10:28:43	2020-03-09	14	[{"id_menu":2,"count":1}]	3754	delivery	5	19
37976	2020-03-09 10:31:14	2020-03-09	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	8777	delivery	5	22
37977	2020-03-09 10:31:28	2020-03-09	12	[{"id_menu":1,"count":1}]	2655	pick-up	0	12
37978	2020-03-09 10:35:40	2020-03-09	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	4589	delivery	5	31
37979	2020-03-09 10:39:51	2020-03-09	12	[{"id_menu":1,"count":1}]	15030	delivery	5	17
37980	2020-03-09 10:49:24	2020-03-09	17	[{"id_menu":4,"count":1}]	14963	delivery	5	22
37981	2020-03-09 11:15:59	2020-03-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14943	delivery	5	23
37982	2020-03-09 11:16:04	2020-03-09	9	[{"id_menu":6,"count":1}]	6511	pick-up	0	9
37983	2020-03-09 11:32:05	2020-03-09	12	[{"id_menu":1,"count":1}]	12066	delivery	5	17
37984	2020-03-09 11:34:38	2020-03-09	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	14968	delivery	5	27
37985	2020-03-09 11:39:22	2020-03-09	9	[{"id_menu":7,"count":1}]	655	pick-up	0	9
37986	2020-03-09 11:51:00	2020-03-09	17	[{"id_menu":4,"count":1}]	3127	delivery	5	22
37987	2020-03-09 11:58:59	2020-03-09	9	[{"id_menu":7,"count":2}]	14960	delivery	5	14
37988	2020-03-09 12:07:22	2020-03-09	12	[{"id_menu":3,"count":1}]	1156	pick-up	0	12
37989	2020-03-09 12:24:37	2020-03-09	17	[{"id_menu":4,"count":1}]	13054	pick-up	0	17
37990	2020-03-09 12:40:40	2020-03-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	11560	delivery	5	28
37991	2020-03-09 13:15:43	2020-03-09	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	12130	delivery	5	25
37992	2020-03-09 13:18:26	2020-03-09	12	[{"id_menu":3,"count":1}]	15025	delivery	5	17
37993	2020-03-09 13:23:56	2020-03-09	9	[{"id_menu":7,"count":1}]	880	delivery	5	14
37994	2020-03-09 13:38:55	2020-03-09	9	[{"id_menu":7,"count":1}]	14977	delivery	5	14
37995	2020-03-09 13:48:15	2020-03-09	9	[{"id_menu":7,"count":1}]	13042	delivery	5	14
37996	2020-03-09 13:51:43	2020-03-09	9	[{"id_menu":7,"count":1}]	12293	delivery	5	14
37997	2020-03-09 13:58:32	2020-03-09	9	[{"id_menu":7,"count":1}]	2280	pick-up	0	9
37998	2020-03-09 13:59:28	2020-03-09	12	[{"id_menu":3,"count":1}]	2618	delivery	5	17
37999	2020-03-09 14:09:35	2020-03-09	9	[{"id_menu":7,"count":1}]	1581	delivery	5	14
38000	2020-03-09 14:34:24	2020-03-09	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3701	delivery	5	43
38001	2020-03-09 14:36:08	2020-03-09	17	[{"id_menu":4,"count":1}]	14027	pick-up	0	17
38002	2020-03-09 14:39:52	2020-03-09	12	[{"id_menu":1,"count":1}]	14934	delivery	5	17
38003	2020-03-09 14:55:01	2020-03-09	9	[{"id_menu":7,"count":1}]	7109	delivery	5	14
38004	2020-03-09 14:58:22	2020-03-09	17	[{"id_menu":4,"count":1}]	14386	delivery	5	22
38005	2020-03-09 15:04:59	2020-03-09	14	[{"id_menu":2,"count":1}]	12717	pick-up	0	14
38006	2020-03-09 15:18:30	2020-03-09	12	[{"id_menu":3,"count":1}]	9040	pick-up	0	12
38007	2020-03-09 15:27:41	2020-03-09	12	[{"id_menu":1,"count":1}]	15024	pick-up	0	12
38008	2020-03-09 15:31:03	2020-03-09	17	[{"id_menu":4,"count":1}]	15017	delivery	5	22
38009	2020-03-09 15:34:16	2020-03-09	9	[{"id_menu":6,"count":1}]	533	delivery	5	14
38010	2020-03-09 15:37:18	2020-03-09	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3210	delivery	5	34
38011	2020-03-09 15:45:07	2020-03-09	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15009	delivery	5	43
38012	2020-03-09 15:48:21	2020-03-09	12	[{"id_menu":1,"count":1}]	14995	delivery	5	17
38013	2020-03-09 15:55:04	2020-03-09	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2200	pick-up	0	29
38014	2020-03-09 15:55:50	2020-03-09	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	8052	delivery	5	31
38015	2020-03-09 15:58:31	2020-03-09	12	[{"id_menu":3,"count":1}]	2670	delivery	5	17
38016	2020-03-09 16:21:51	2020-03-09	9	[{"id_menu":7,"count":1}]	12455	delivery	5	14
38017	2020-03-09 16:37:29	2020-03-09	12	[{"id_menu":3,"count":1}]	1485	pick-up	0	12
38018	2020-03-09 16:38:20	2020-03-09	14	[{"id_menu":2,"count":1}]	6705	delivery	5	19
38019	2020-03-09 16:38:44	2020-03-09	17	[{"id_menu":4,"count":1}]	1456	pick-up	0	17
38020	2020-03-09 16:42:28	2020-03-09	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1257	delivery	5	37
38021	2020-03-09 16:49:28	2020-03-09	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15027	delivery	5	43
38022	2020-03-09 16:51:26	2020-03-09	49	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	14979	delivery	5	54
38023	2020-03-09 16:55:15	2020-03-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	4607	pick-up	0	23
38024	2020-03-09 16:55:17	2020-03-09	9	[{"id_menu":6,"count":1}]	15014	delivery	5	14
38025	2020-03-09 16:59:43	2020-03-09	12	[{"id_menu":1,"count":1}]	11276	delivery	5	17
38026	2020-03-09 17:00:03	2020-03-09	9	[{"id_menu":6,"count":1}]	4912	delivery	5	14
38027	2020-03-09 17:18:31	2020-03-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	14992	delivery	5	28
38028	2020-03-09 17:20:54	2020-03-09	12	[{"id_menu":3,"count":1}]	1211	delivery	5	17
38029	2020-03-09 17:27:45	2020-03-09	9	[{"id_menu":6,"count":2}]	14964	delivery	5	14
38030	2020-03-09 17:37:15	2020-03-09	12	[{"id_menu":3,"count":1}]	14954	delivery	5	17
38031	2020-03-09 17:48:33	2020-03-09	8	[{"id_menu":5,"count":1}]	2950	pick-up	0	8
38032	2020-03-09 17:52:35	2020-03-09	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3629	delivery	5	31
38033	2020-03-09 18:00:02	2020-03-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	11798	delivery	5	22
38034	2020-03-09 18:01:11	2020-03-09	9	[{"id_menu":6,"count":1}]	15021	pick-up	0	9
38035	2020-03-09 18:08:14	2020-03-09	12	[{"id_menu":1,"count":1}]	5194	delivery	5	17
38036	2020-03-09 18:09:20	2020-03-09	9	[{"id_menu":7,"count":1}]	14999	delivery	5	14
38037	2020-03-09 18:10:45	2020-03-09	14	[{"id_menu":2,"count":1}]	14938	delivery	5	19
38038	2020-03-09 18:20:24	2020-03-09	17	[{"id_menu":4,"count":1}]	14971	delivery	5	22
38039	2020-03-09 18:29:26	2020-03-09	9	[{"id_menu":6,"count":1}]	4804	delivery	5	14
38040	2020-03-09 18:33:03	2020-03-09	9	[{"id_menu":6,"count":1}]	8471	delivery	5	14
38041	2020-03-09 18:34:15	2020-03-09	9	[{"id_menu":7,"count":1}]	14959	delivery	5	14
38042	2020-03-09 18:44:42	2020-03-09	14	[{"id_menu":2,"count":1}]	4869	delivery	5	19
38043	2020-03-09 18:58:50	2020-03-09	12	[{"id_menu":1,"count":2}]	13504	delivery	5	17
38044	2020-03-09 19:03:45	2020-03-09	9	[{"id_menu":6,"count":1}]	15020	delivery	5	14
38045	2020-03-09 19:04:43	2020-03-09	8	[{"id_menu":5,"count":1}]	3635	pick-up	0	8
38046	2020-03-09 19:04:47	2020-03-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	14957	delivery	5	28
38047	2020-03-09 19:10:59	2020-03-09	8	[{"id_menu":5,"count":1}]	14998	pick-up	0	8
38048	2020-03-09 19:14:52	2020-03-09	8	[{"id_menu":5,"count":1}]	4295	pick-up	0	8
38049	2020-03-09 19:15:11	2020-03-09	12	[{"id_menu":3,"count":1}]	15002	delivery	5	17
38050	2020-03-09 19:43:14	2020-03-09	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13927	delivery	5	31
38051	2020-03-09 19:47:49	2020-03-09	8	[{"id_menu":5,"count":1}]	11870	pick-up	0	8
38052	2020-03-09 20:16:13	2020-03-09	12	[{"id_menu":1,"count":1}]	15022	delivery	5	17
38053	2020-03-09 20:18:59	2020-03-09	8	[{"id_menu":5,"count":2}]	12932	delivery	5	13
38054	2020-03-09 20:22:19	2020-03-09	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	736	delivery	5	43
38055	2020-03-09 20:25:27	2020-03-09	12	[{"id_menu":1,"count":1}]	14989	delivery	5	17
38056	2020-03-09 20:25:49	2020-03-09	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	2446	pick-up	0	29
38057	2020-03-09 20:31:50	2020-03-09	17	[{"id_menu":4,"count":1}]	5422	delivery	5	22
38058	2020-03-09 20:40:17	2020-03-09	9	[{"id_menu":7,"count":1}]	8665	delivery	5	14
38059	2020-03-09 20:42:12	2020-03-09	9	[{"id_menu":6,"count":1}]	15026	pick-up	0	9
38060	2020-03-09 20:45:06	2020-03-09	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	14879	delivery	5	35
38061	2020-03-09 20:49:05	2020-03-09	9	[{"id_menu":7,"count":1}]	337	delivery	5	14
38062	2020-03-09 20:50:28	2020-03-09	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2140	pick-up	0	39
38063	2020-03-09 20:57:20	2020-03-09	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	9817	pick-up	0	22
38064	2020-03-09 20:57:36	2020-03-09	9	[{"id_menu":7,"count":1}]	14958	delivery	5	14
38065	2020-03-09 20:58:10	2020-03-09	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	9855	delivery	5	31
38066	2020-03-09 21:08:30	2020-03-09	17	[{"id_menu":4,"count":1}]	6965	pick-up	0	17
38067	2020-03-09 21:17:20	2020-03-09	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1913	delivery	5	26
38068	2020-03-09 21:19:20	2020-03-09	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":3}]	9361	delivery	5	26
38069	2020-03-09 21:24:08	2020-03-09	12	[{"id_menu":1,"count":1}]	1460	delivery	5	17
38070	2020-03-09 21:50:06	2020-03-09	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	15037	delivery	5	34
38071	2020-03-09 21:57:49	2020-03-09	17	[{"id_menu":4,"count":1}]	14984	delivery	5	22
38072	2020-03-09 22:09:53	2020-03-09	8	[{"id_menu":5,"count":2}]	609	pick-up	0	8
38073	2020-03-09 22:24:19	2020-03-09	12	[{"id_menu":1,"count":1}]	14981	pick-up	0	12
38074	2020-03-09 22:24:38	2020-03-09	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	15000	delivery	5	25
38075	2020-03-09 22:44:07	2020-03-09	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	15018	delivery	5	44
38076	2020-03-09 22:52:52	2020-03-09	12	[{"id_menu":1,"count":1}]	13384	delivery	5	17
38077	2020-03-09 23:01:30	2020-03-09	14	[{"id_menu":2,"count":1}]	15040	pick-up	0	14
38078	2020-03-09 23:08:14	2020-03-09	9	[{"id_menu":7,"count":1}]	4051	pick-up	0	9
38079	2020-03-09 23:20:38	2020-03-09	17	[{"id_menu":4,"count":1}]	14692	delivery	5	22
38080	2020-03-09 23:28:27	2020-03-09	12	[{"id_menu":1,"count":1}]	12843	delivery	5	17
38081	2020-03-09 23:42:09	2020-03-09	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	8041	delivery	5	22
38082	2020-03-09 23:46:58	2020-03-09	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2440	delivery	5	31
38083	2020-03-10 00:02:33	2020-03-10	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	15179	delivery	5	23
38084	2020-03-10 00:10:53	2020-03-10	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15070	delivery	5	40
38085	2020-03-10 00:33:08	2020-03-10	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	15077	delivery	5	40
38086	2020-03-10 00:38:44	2020-03-10	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	15181	delivery	5	39
38087	2020-03-10 00:39:03	2020-03-10	14	[{"id_menu":2,"count":1}]	15072	delivery	5	19
38088	2020-03-10 00:43:17	2020-03-10	9	[{"id_menu":7,"count":1}]	11446	delivery	5	14
38089	2020-03-10 00:45:03	2020-03-10	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15096	delivery	5	40
38090	2020-03-10 00:48:25	2020-03-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4498	delivery	5	28
38091	2020-03-10 00:48:26	2020-03-10	12	[{"id_menu":1,"count":1}]	15105	delivery	5	17
38092	2020-03-10 00:51:42	2020-03-10	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	15082	pick-up	0	21
38093	2020-03-10 00:55:23	2020-03-10	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	10583	delivery	5	39
38094	2020-03-10 00:57:52	2020-03-10	14	[{"id_menu":2,"count":1}]	2232	pick-up	0	14
38095	2020-03-10 01:06:43	2020-03-10	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15119	delivery	5	48
38096	2020-03-10 01:19:16	2020-03-10	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	15080	delivery	5	25
38097	2020-03-10 01:20:40	2020-03-10	8	[{"id_menu":5,"count":1}]	4467	delivery	5	13
38098	2020-03-10 01:28:09	2020-03-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7303	delivery	5	23
38099	2020-03-10 01:33:06	2020-03-10	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15053	delivery	5	34
38100	2020-03-10 01:37:24	2020-03-10	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15103	delivery	5	22
38101	2020-03-10 01:44:21	2020-03-10	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	15065	delivery	5	34
38102	2020-03-10 01:52:35	2020-03-10	9	[{"id_menu":6,"count":2}]	2590	pick-up	0	9
38103	2020-03-10 01:53:28	2020-03-10	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	5138	pick-up	0	31
38104	2020-03-10 02:00:32	2020-03-10	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	10469	delivery	5	44
38105	2020-03-10 02:00:40	2020-03-10	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	8719	pick-up	0	31
38106	2020-03-10 02:02:59	2020-03-10	14	[{"id_menu":2,"count":2}]	3151	delivery	5	19
38107	2020-03-10 02:03:16	2020-03-10	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15142	delivery	5	35
38108	2020-03-10 02:16:26	2020-03-10	17	[{"id_menu":4,"count":1}]	5974	delivery	5	22
38109	2020-03-10 02:18:05	2020-03-10	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11232	pick-up	0	26
38110	2020-03-10 02:20:28	2020-03-10	9	[{"id_menu":6,"count":1}]	9920	pick-up	0	9
38111	2020-03-10 02:26:36	2020-03-10	9	[{"id_menu":7,"count":1}]	7456	delivery	5	14
38112	2020-03-10 02:34:06	2020-03-10	9	[{"id_menu":7,"count":1}]	15046	delivery	5	14
38113	2020-03-10 02:52:33	2020-03-10	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	15160	pick-up	0	31
38114	2020-03-10 02:57:16	2020-03-10	9	[{"id_menu":6,"count":1}]	2604	delivery	5	14
38115	2020-03-10 02:57:29	2020-03-10	14	[{"id_menu":2,"count":1}]	14143	delivery	5	19
38116	2020-03-10 03:05:32	2020-03-10	9	[{"id_menu":6,"count":1}]	9905	delivery	5	14
38117	2020-03-10 03:11:52	2020-03-10	9	[{"id_menu":6,"count":1}]	15048	pick-up	0	9
38118	2020-03-10 03:19:30	2020-03-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	15191	delivery	5	28
38119	2020-03-10 03:19:50	2020-03-10	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15054	delivery	5	40
38120	2020-03-10 03:19:53	2020-03-10	9	[{"id_menu":6,"count":1}]	11904	pick-up	0	9
38121	2020-03-10 03:19:56	2020-03-10	8	[{"id_menu":5,"count":1}]	15043	delivery	5	13
38122	2020-03-10 03:21:46	2020-03-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11495	pick-up	0	17
38123	2020-03-10 03:27:24	2020-03-10	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	15161	delivery	5	26
38124	2020-03-10 03:32:20	2020-03-10	14	[{"id_menu":2,"count":1}]	3534	delivery	5	19
38125	2020-03-10 03:36:34	2020-03-10	12	[{"id_menu":1,"count":1}]	15184	delivery	5	17
38126	2020-03-10 03:37:29	2020-03-10	17	[{"id_menu":4,"count":1}]	9220	delivery	5	22
38127	2020-03-10 03:48:11	2020-03-10	12	[{"id_menu":1,"count":1}]	81	delivery	5	17
38128	2020-03-10 03:54:22	2020-03-10	9	[{"id_menu":6,"count":1}]	4800	pick-up	0	9
38129	2020-03-10 03:54:27	2020-03-10	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	3370	delivery	5	27
38130	2020-03-10 03:54:50	2020-03-10	21	[{"id_menu":3,"count":3},{"id_menu":7,"count":1}]	12297	delivery	5	26
38131	2020-03-10 03:56:40	2020-03-10	9	[{"id_menu":6,"count":2}]	15130	delivery	5	14
38132	2020-03-10 04:01:52	2020-03-10	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2717	delivery	5	31
38133	2020-03-10 04:14:43	2020-03-10	17	[{"id_menu":4,"count":1}]	15185	delivery	5	22
38134	2020-03-10 04:25:48	2020-03-10	8	[{"id_menu":5,"count":1}]	15074	delivery	5	13
38135	2020-03-10 04:30:56	2020-03-10	12	[{"id_menu":1,"count":1}]	6114	delivery	5	17
38136	2020-03-10 04:39:46	2020-03-10	9	[{"id_menu":7,"count":1}]	15178	delivery	5	14
38137	2020-03-10 04:42:43	2020-03-10	37	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4440	pick-up	0	37
38138	2020-03-10 04:50:10	2020-03-10	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	11089	pick-up	0	21
38139	2020-03-10 04:52:48	2020-03-10	9	[{"id_menu":6,"count":1}]	11006	delivery	5	14
38140	2020-03-10 04:58:16	2020-03-10	9	[{"id_menu":7,"count":1}]	15152	delivery	5	14
38141	2020-03-10 04:58:37	2020-03-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15104	delivery	5	23
38142	2020-03-10 05:09:29	2020-03-10	12	[{"id_menu":3,"count":1}]	1309	pick-up	0	12
38143	2020-03-10 05:13:54	2020-03-10	8	[{"id_menu":5,"count":1}]	15045	delivery	5	13
38144	2020-03-10 05:19:14	2020-03-10	8	[{"id_menu":5,"count":1}]	12364	delivery	5	13
38145	2020-03-10 05:23:16	2020-03-10	12	[{"id_menu":3,"count":2}]	15109	pick-up	0	12
38146	2020-03-10 05:30:36	2020-03-10	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	14174	delivery	5	31
38147	2020-03-10 05:34:12	2020-03-10	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	12631	pick-up	0	21
38148	2020-03-10 05:46:40	2020-03-10	9	[{"id_menu":7,"count":1}]	15056	delivery	5	14
38149	2020-03-10 05:48:23	2020-03-10	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	15117	pick-up	0	31
38150	2020-03-10 05:53:38	2020-03-10	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	13837	delivery	5	27
38151	2020-03-10 06:07:19	2020-03-10	8	[{"id_menu":5,"count":1}]	15132	delivery	5	13
38152	2020-03-10 06:07:21	2020-03-10	8	[{"id_menu":5,"count":1}]	11589	delivery	5	13
38153	2020-03-10 06:07:30	2020-03-10	17	[{"id_menu":4,"count":1}]	13806	pick-up	0	17
38154	2020-03-10 06:20:40	2020-03-10	14	[{"id_menu":2,"count":1}]	15081	delivery	5	19
38155	2020-03-10 06:27:10	2020-03-10	12	[{"id_menu":3,"count":1}]	4634	delivery	5	17
38156	2020-03-10 06:31:22	2020-03-10	12	[{"id_menu":3,"count":1}]	5128	pick-up	0	12
38157	2020-03-10 06:36:54	2020-03-10	14	[{"id_menu":2,"count":1}]	13250	delivery	5	19
38158	2020-03-10 06:37:28	2020-03-10	8	[{"id_menu":5,"count":1}]	15165	delivery	5	13
38159	2020-03-10 06:42:36	2020-03-10	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3392	delivery	5	26
38160	2020-03-10 06:46:59	2020-03-10	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	293	pick-up	0	26
38161	2020-03-10 06:51:08	2020-03-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	73	delivery	5	28
38162	2020-03-10 06:59:51	2020-03-10	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	8025	pick-up	0	31
38163	2020-03-10 07:04:34	2020-03-10	12	[{"id_menu":1,"count":1}]	15073	delivery	5	17
38164	2020-03-10 07:05:43	2020-03-10	9	[{"id_menu":6,"count":1}]	145	pick-up	0	9
38165	2020-03-10 07:09:46	2020-03-10	14	[{"id_menu":2,"count":1}]	6134	pick-up	0	14
38166	2020-03-10 07:13:10	2020-03-10	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	10772	pick-up	0	20
38167	2020-03-10 07:19:14	2020-03-10	9	[{"id_menu":7,"count":1}]	9295	pick-up	0	9
38168	2020-03-10 07:27:55	2020-03-10	17	[{"id_menu":4,"count":1}]	10968	pick-up	0	17
38169	2020-03-10 07:34:02	2020-03-10	9	[{"id_menu":7,"count":1}]	15060	delivery	5	14
38170	2020-03-10 08:17:43	2020-03-10	12	[{"id_menu":1,"count":1}]	15101	delivery	5	17
38171	2020-03-10 08:28:27	2020-03-10	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	9813	pick-up	0	34
38172	2020-03-10 08:37:29	2020-03-10	9	[{"id_menu":7,"count":1}]	15079	delivery	5	14
38173	2020-03-10 08:41:39	2020-03-10	9	[{"id_menu":6,"count":1}]	3304	pick-up	0	9
38174	2020-03-10 08:45:11	2020-03-10	9	[{"id_menu":7,"count":1}]	7430	pick-up	0	9
38175	2020-03-10 08:46:29	2020-03-10	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10854	delivery	5	34
38176	2020-03-10 08:58:09	2020-03-10	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15149	delivery	5	48
38177	2020-03-10 09:02:56	2020-03-10	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12518	delivery	5	37
38178	2020-03-10 09:05:47	2020-03-10	14	[{"id_menu":2,"count":1}]	8728	delivery	5	19
38179	2020-03-10 09:09:32	2020-03-10	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	601	delivery	5	27
38180	2020-03-10 09:17:44	2020-03-10	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	15095	delivery	5	27
38181	2020-03-10 09:44:52	2020-03-10	12	[{"id_menu":3,"count":1}]	822	pick-up	0	12
38182	2020-03-10 09:47:18	2020-03-10	8	[{"id_menu":5,"count":1}]	12618	delivery	5	13
38183	2020-03-10 09:51:08	2020-03-10	14	[{"id_menu":2,"count":1}]	12541	pick-up	0	14
38184	2020-03-10 10:08:56	2020-03-10	14	[{"id_menu":2,"count":1}]	856	pick-up	0	14
38185	2020-03-10 10:09:08	2020-03-10	8	[{"id_menu":5,"count":1}]	11790	pick-up	0	8
38186	2020-03-10 10:14:13	2020-03-10	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	6396	delivery	5	31
38187	2020-03-10 10:23:24	2020-03-10	9	[{"id_menu":6,"count":1}]	15189	delivery	5	14
38188	2020-03-10 10:26:37	2020-03-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10331	pick-up	0	18
38189	2020-03-10 10:30:30	2020-03-10	9	[{"id_menu":7,"count":1}]	5092	delivery	5	14
38190	2020-03-10 10:34:07	2020-03-10	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	15144	delivery	5	46
38191	2020-03-10 10:35:28	2020-03-10	9	[{"id_menu":6,"count":4}]	15177	delivery	5	14
38192	2020-03-10 10:44:48	2020-03-10	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	295	pick-up	0	29
38193	2020-03-10 10:56:09	2020-03-10	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1727	pick-up	0	21
38194	2020-03-10 10:57:29	2020-03-10	17	[{"id_menu":4,"count":1}]	15187	pick-up	0	17
38195	2020-03-10 11:00:17	2020-03-10	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10154	delivery	5	45
38196	2020-03-10 11:03:24	2020-03-10	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11039	delivery	5	45
38197	2020-03-10 11:10:20	2020-03-10	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	15093	delivery	5	31
38198	2020-03-10 11:12:35	2020-03-10	17	[{"id_menu":4,"count":1}]	5361	pick-up	0	17
38199	2020-03-10 11:14:31	2020-03-10	9	[{"id_menu":7,"count":1}]	15166	delivery	5	14
38200	2020-03-10 11:17:47	2020-03-10	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15121	delivery	5	34
38201	2020-03-10 11:24:30	2020-03-10	9	[{"id_menu":6,"count":1}]	15086	delivery	5	14
38202	2020-03-10 11:26:02	2020-03-10	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6221	pick-up	0	40
38203	2020-03-10 11:30:52	2020-03-10	8	[{"id_menu":5,"count":1}]	15171	delivery	5	13
38204	2020-03-10 11:31:57	2020-03-10	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15134	delivery	5	22
38205	2020-03-10 11:45:40	2020-03-10	17	[{"id_menu":4,"count":1}]	433	pick-up	0	17
38206	2020-03-10 11:51:13	2020-03-10	9	[{"id_menu":6,"count":1}]	1815	pick-up	0	9
38207	2020-03-10 12:04:07	2020-03-10	9	[{"id_menu":6,"count":1}]	15133	delivery	5	14
38208	2020-03-10 12:07:02	2020-03-10	9	[{"id_menu":7,"count":1}]	15122	delivery	5	14
38209	2020-03-10 12:11:53	2020-03-10	12	[{"id_menu":3,"count":1}]	13649	delivery	5	17
38210	2020-03-10 12:30:28	2020-03-10	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2319	delivery	5	36
38211	2020-03-10 12:39:22	2020-03-10	12	[{"id_menu":1,"count":1}]	15180	delivery	5	17
38212	2020-03-10 12:43:23	2020-03-10	17	[{"id_menu":5,"count":3},{"id_menu":6,"count":1}]	15173	delivery	5	22
38213	2020-03-10 12:54:16	2020-03-10	9	[{"id_menu":6,"count":1}]	15087	delivery	5	14
38214	2020-03-10 13:01:35	2020-03-10	12	[{"id_menu":1,"count":1}]	10525	delivery	5	17
38215	2020-03-10 13:02:48	2020-03-10	14	[{"id_menu":2,"count":1}]	15155	delivery	5	19
38216	2020-03-10 13:05:31	2020-03-10	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	15114	delivery	5	31
38217	2020-03-10 13:14:21	2020-03-10	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15088	delivery	5	43
38218	2020-03-10 13:14:44	2020-03-10	12	[{"id_menu":1,"count":1}]	2021	pick-up	0	12
38219	2020-03-10 13:16:24	2020-03-10	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	14632	delivery	5	56
38220	2020-03-10 13:29:15	2020-03-10	12	[{"id_menu":3,"count":1}]	15102	delivery	5	17
38221	2020-03-10 13:30:05	2020-03-10	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1287	pick-up	0	21
38222	2020-03-10 13:34:42	2020-03-10	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11023	delivery	5	45
38223	2020-03-10 13:41:19	2020-03-10	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	9833	delivery	5	25
38224	2020-03-10 13:44:20	2020-03-10	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	15069	delivery	5	26
38225	2020-03-10 13:48:53	2020-03-10	17	[{"id_menu":4,"count":1}]	9334	delivery	5	22
38226	2020-03-10 13:50:07	2020-03-10	14	[{"id_menu":2,"count":1}]	749	delivery	5	19
38227	2020-03-10 13:53:45	2020-03-10	17	[{"id_menu":4,"count":1}]	13343	delivery	5	22
38228	2020-03-10 13:54:27	2020-03-10	9	[{"id_menu":6,"count":1}]	7899	delivery	5	14
38229	2020-03-10 14:00:01	2020-03-10	8	[{"id_menu":5,"count":1}]	15076	delivery	5	13
38230	2020-03-10 14:01:17	2020-03-10	8	[{"id_menu":5,"count":1}]	15066	delivery	5	13
38231	2020-03-10 14:17:25	2020-03-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15094	delivery	5	22
38232	2020-03-10 14:32:04	2020-03-10	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	3976	pick-up	0	35
38233	2020-03-10 14:35:32	2020-03-10	12	[{"id_menu":3,"count":1}]	6288	delivery	5	17
38234	2020-03-10 14:40:16	2020-03-10	12	[{"id_menu":3,"count":1}]	15111	delivery	5	17
38235	2020-03-10 14:42:36	2020-03-10	55	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	8275	delivery	5	60
38236	2020-03-10 14:46:37	2020-03-10	17	[{"id_menu":4,"count":1}]	9181	delivery	5	22
38237	2020-03-10 14:54:44	2020-03-10	12	[{"id_menu":1,"count":1}]	15051	delivery	5	17
38238	2020-03-10 14:55:19	2020-03-10	9	[{"id_menu":6,"count":1}]	11387	delivery	5	14
38239	2020-03-10 14:56:52	2020-03-10	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6682	delivery	5	37
38240	2020-03-10 14:58:01	2020-03-10	9	[{"id_menu":6,"count":1}]	15107	delivery	5	14
38241	2020-03-10 14:58:34	2020-03-10	9	[{"id_menu":7,"count":1}]	15147	delivery	5	14
38242	2020-03-10 15:01:16	2020-03-10	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1810	pick-up	0	35
38243	2020-03-10 15:16:13	2020-03-10	12	[{"id_menu":3,"count":1}]	15135	delivery	5	17
38244	2020-03-10 15:21:50	2020-03-10	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	15136	delivery	5	40
38245	2020-03-10 15:22:43	2020-03-10	12	[{"id_menu":3,"count":1}]	7098	delivery	5	17
38246	2020-03-10 15:24:36	2020-03-10	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	9073	pick-up	0	26
38247	2020-03-10 15:32:08	2020-03-10	9	[{"id_menu":6,"count":1}]	15124	delivery	5	14
38248	2020-03-10 15:38:04	2020-03-10	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15172	delivery	5	31
38249	2020-03-10 15:46:37	2020-03-10	17	[{"id_menu":4,"count":1}]	9554	delivery	5	22
38250	2020-03-10 15:51:05	2020-03-10	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	15128	delivery	5	26
38251	2020-03-10 16:02:38	2020-03-10	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8161	pick-up	0	49
38252	2020-03-10 16:28:13	2020-03-10	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10770	delivery	5	54
38253	2020-03-10 16:41:43	2020-03-10	9	[{"id_menu":6,"count":1}]	15092	delivery	5	14
38254	2020-03-10 16:49:03	2020-03-10	12	[{"id_menu":1,"count":1}]	15067	pick-up	0	12
38255	2020-03-10 16:49:30	2020-03-10	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	13634	delivery	5	36
38256	2020-03-10 16:57:44	2020-03-10	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	5570	delivery	5	52
38257	2020-03-10 17:03:38	2020-03-10	9	[{"id_menu":7,"count":1}]	2231	pick-up	0	9
38258	2020-03-10 17:17:05	2020-03-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	3446	delivery	5	22
38259	2020-03-10 17:17:56	2020-03-10	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	2984	delivery	5	26
38260	2020-03-10 17:20:13	2020-03-10	12	[{"id_menu":1,"count":1}]	1138	pick-up	0	12
38261	2020-03-10 17:28:43	2020-03-10	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9021	delivery	5	39
38262	2020-03-10 17:29:03	2020-03-10	14	[{"id_menu":2,"count":1}]	90	pick-up	0	14
38263	2020-03-10 17:41:40	2020-03-10	12	[{"id_menu":3,"count":1}]	6825	delivery	5	17
38264	2020-03-10 17:49:52	2020-03-10	14	[{"id_menu":2,"count":1}]	1429	pick-up	0	14
38265	2020-03-10 17:50:53	2020-03-10	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	8273	delivery	5	25
38266	2020-03-10 17:56:55	2020-03-10	14	[{"id_menu":2,"count":1}]	2320	delivery	5	19
38267	2020-03-10 18:01:52	2020-03-10	12	[{"id_menu":1,"count":1}]	5668	pick-up	0	12
38268	2020-03-10 18:14:55	2020-03-10	14	[{"id_menu":2,"count":1}]	1286	pick-up	0	14
38269	2020-03-10 18:21:57	2020-03-10	17	[{"id_menu":4,"count":1}]	15168	delivery	5	22
38270	2020-03-10 18:27:54	2020-03-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":3}]	15113	delivery	5	28
38271	2020-03-10 18:28:38	2020-03-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	8628	delivery	5	28
38272	2020-03-10 18:28:48	2020-03-10	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	3221	delivery	5	26
38273	2020-03-10 18:34:48	2020-03-10	12	[{"id_menu":3,"count":3}]	2373	pick-up	0	12
38274	2020-03-10 18:40:44	2020-03-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	11124	delivery	5	28
38275	2020-03-10 18:43:53	2020-03-10	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2653	pick-up	0	26
38276	2020-03-10 18:45:11	2020-03-10	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15084	delivery	5	43
38277	2020-03-10 18:51:51	2020-03-10	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	15163	delivery	5	26
38278	2020-03-10 18:53:27	2020-03-10	9	[{"id_menu":6,"count":1}]	15120	pick-up	0	9
38279	2020-03-10 19:08:15	2020-03-10	9	[{"id_menu":6,"count":1}]	15100	delivery	5	14
38280	2020-03-10 19:17:46	2020-03-10	9	[{"id_menu":6,"count":1}]	13028	pick-up	0	9
38281	2020-03-10 19:18:48	2020-03-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	13004	delivery	5	28
38282	2020-03-10 19:25:34	2020-03-10	9	[{"id_menu":7,"count":1}]	15091	delivery	5	14
38283	2020-03-10 19:28:00	2020-03-10	9	[{"id_menu":7,"count":1}]	41	delivery	5	14
38284	2020-03-10 19:31:42	2020-03-10	12	[{"id_menu":3,"count":1}]	832	delivery	5	17
38285	2020-03-10 19:38:37	2020-03-10	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14555	delivery	5	49
38286	2020-03-10 19:42:45	2020-03-10	12	[{"id_menu":3,"count":1}]	10349	delivery	5	17
38287	2020-03-10 19:45:36	2020-03-10	17	[{"id_menu":4,"count":1}]	15063	pick-up	0	17
38288	2020-03-10 19:45:45	2020-03-10	9	[{"id_menu":7,"count":1}]	7726	pick-up	0	9
38289	2020-03-10 19:53:26	2020-03-10	14	[{"id_menu":2,"count":1}]	3492	delivery	5	19
38290	2020-03-10 20:00:43	2020-03-10	8	[{"id_menu":5,"count":1}]	918	pick-up	0	8
38291	2020-03-10 20:08:02	2020-03-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7350	delivery	5	22
38292	2020-03-10 20:10:40	2020-03-10	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	6591	pick-up	0	24
38293	2020-03-10 20:16:12	2020-03-10	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9733	delivery	5	45
38294	2020-03-10 20:17:42	2020-03-10	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15090	pick-up	0	17
38295	2020-03-10 20:19:29	2020-03-10	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	8394	delivery	5	29
38296	2020-03-10 20:21:59	2020-03-10	8	[{"id_menu":5,"count":1}]	15186	pick-up	0	8
38297	2020-03-10 20:24:30	2020-03-10	9	[{"id_menu":6,"count":1}]	15085	delivery	5	14
38298	2020-03-10 20:25:36	2020-03-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15062	pick-up	0	17
38299	2020-03-10 20:34:39	2020-03-10	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4021	pick-up	0	38
38300	2020-03-10 20:38:09	2020-03-10	17	[{"id_menu":4,"count":1}]	15052	delivery	5	22
38301	2020-03-10 20:43:31	2020-03-10	8	[{"id_menu":5,"count":1}]	4555	delivery	5	13
38302	2020-03-10 20:50:29	2020-03-10	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	4836	delivery	5	23
38303	2020-03-10 20:52:54	2020-03-10	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15059	delivery	5	31
38304	2020-03-10 21:02:16	2020-03-10	8	[{"id_menu":5,"count":1}]	15115	delivery	5	13
38305	2020-03-10 21:05:58	2020-03-10	8	[{"id_menu":5,"count":1}]	12902	delivery	5	13
38306	2020-03-10 21:07:28	2020-03-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	13267	delivery	5	28
38307	2020-03-10 21:20:11	2020-03-10	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	4922	delivery	5	25
38308	2020-03-10 21:32:30	2020-03-10	9	[{"id_menu":7,"count":1}]	15050	delivery	5	14
38309	2020-03-10 21:33:46	2020-03-10	8	[{"id_menu":5,"count":1}]	11669	delivery	5	13
38310	2020-03-10 21:41:48	2020-03-10	9	[{"id_menu":6,"count":1}]	15169	delivery	5	14
38311	2020-03-10 21:42:38	2020-03-10	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15131	delivery	5	31
38312	2020-03-10 21:53:01	2020-03-10	12	[{"id_menu":3,"count":1}]	7225	delivery	5	17
38313	2020-03-10 21:53:11	2020-03-10	9	[{"id_menu":6,"count":1}]	10796	delivery	5	14
38314	2020-03-10 22:02:40	2020-03-10	17	[{"id_menu":4,"count":1}]	2339	pick-up	0	17
38315	2020-03-10 22:20:07	2020-03-10	17	[{"id_menu":4,"count":1}]	2792	pick-up	0	17
38316	2020-03-10 22:26:55	2020-03-10	9	[{"id_menu":7,"count":1}]	14947	pick-up	0	9
38317	2020-03-10 22:27:33	2020-03-10	9	[{"id_menu":7,"count":1}]	2418	pick-up	0	9
38318	2020-03-10 22:29:09	2020-03-10	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	15182	delivery	5	25
38319	2020-03-10 22:29:48	2020-03-10	9	[{"id_menu":7,"count":1}]	9369	delivery	5	14
38320	2020-03-10 22:39:18	2020-03-10	17	[{"id_menu":4,"count":1}]	9945	delivery	5	22
38321	2020-03-10 22:42:40	2020-03-10	17	[{"id_menu":4,"count":1}]	8065	pick-up	0	17
38322	2020-03-10 22:43:23	2020-03-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15127	delivery	5	23
38323	2020-03-10 22:48:51	2020-03-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	2951	delivery	5	22
38324	2020-03-10 22:52:48	2020-03-10	17	[{"id_menu":4,"count":1}]	15170	delivery	5	22
38325	2020-03-10 22:53:47	2020-03-10	9	[{"id_menu":6,"count":1}]	11183	pick-up	0	9
38326	2020-03-10 22:57:44	2020-03-10	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	13467	pick-up	0	26
38327	2020-03-10 23:07:29	2020-03-10	9	[{"id_menu":6,"count":2}]	15151	delivery	5	14
38328	2020-03-10 23:16:14	2020-03-10	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	15145	delivery	5	43
38329	2020-03-10 23:17:36	2020-03-10	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2401	pick-up	0	50
38330	2020-03-10 23:21:38	2020-03-10	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	15167	delivery	5	31
38331	2020-03-10 23:26:53	2020-03-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	15125	delivery	5	28
38332	2020-03-10 23:27:05	2020-03-10	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14944	delivery	5	34
38333	2020-03-10 23:32:43	2020-03-10	17	[{"id_menu":4,"count":1}]	15047	delivery	5	22
38334	2020-03-10 23:35:56	2020-03-10	14	[{"id_menu":2,"count":1}]	13651	pick-up	0	14
38335	2020-03-10 23:40:30	2020-03-10	8	[{"id_menu":5,"count":1}]	2094	delivery	5	13
38336	2020-03-10 23:51:27	2020-03-10	12	[{"id_menu":1,"count":1}]	15148	delivery	5	17
38337	2020-03-10 23:55:06	2020-03-10	17	[{"id_menu":4,"count":1}]	8227	pick-up	0	17
38338	2020-03-10 23:55:14	2020-03-10	9	[{"id_menu":7,"count":1}]	299	delivery	5	14
38339	2020-03-11 00:01:32	2020-03-11	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7454	delivery	5	30
38340	2020-03-11 00:22:12	2020-03-11	9	[{"id_menu":7,"count":1}]	15204	delivery	5	14
38341	2020-03-11 00:24:35	2020-03-11	9	[{"id_menu":6,"count":1}]	15221	pick-up	0	9
38342	2020-03-11 00:29:25	2020-03-11	8	[{"id_menu":5,"count":1}]	15223	pick-up	0	8
38343	2020-03-11 00:32:32	2020-03-11	14	[{"id_menu":2,"count":1}]	6173	pick-up	0	14
38344	2020-03-11 00:32:49	2020-03-11	12	[{"id_menu":1,"count":1}]	4174	delivery	5	17
38345	2020-03-11 00:48:24	2020-03-11	17	[{"id_menu":4,"count":1}]	3260	delivery	5	22
38346	2020-03-11 00:52:13	2020-03-11	12	[{"id_menu":3,"count":1}]	6568	delivery	5	17
38347	2020-03-11 00:53:58	2020-03-11	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6675	delivery	5	34
38348	2020-03-11 00:56:13	2020-03-11	9	[{"id_menu":6,"count":1}]	15290	delivery	5	14
38349	2020-03-11 01:00:48	2020-03-11	9	[{"id_menu":6,"count":1}]	12095	delivery	5	14
38350	2020-03-11 01:14:08	2020-03-11	9	[{"id_menu":6,"count":1}]	15230	delivery	5	14
38351	2020-03-11 01:27:41	2020-03-11	9	[{"id_menu":7,"count":1}]	15199	delivery	5	14
38352	2020-03-11 01:30:43	2020-03-11	9	[{"id_menu":7,"count":1}]	11272	delivery	5	14
38353	2020-03-11 01:34:35	2020-03-11	14	[{"id_menu":2,"count":2}]	11083	delivery	5	19
38354	2020-03-11 01:35:56	2020-03-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1944	pick-up	0	23
38355	2020-03-11 01:41:49	2020-03-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7796	delivery	5	23
38356	2020-03-11 01:43:47	2020-03-11	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11339	delivery	5	57
38357	2020-03-11 01:47:35	2020-03-11	14	[{"id_menu":2,"count":1}]	15241	delivery	5	19
38358	2020-03-11 01:48:48	2020-03-11	9	[{"id_menu":7,"count":1}]	6250	delivery	5	14
38359	2020-03-11 01:49:16	2020-03-11	8	[{"id_menu":5,"count":1}]	13221	delivery	5	13
38360	2020-03-11 01:53:35	2020-03-11	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	10254	delivery	5	26
38361	2020-03-11 02:01:35	2020-03-11	8	[{"id_menu":5,"count":1}]	11699	delivery	5	13
38362	2020-03-11 02:03:03	2020-03-11	14	[{"id_menu":2,"count":1}]	4414	pick-up	0	14
38363	2020-03-11 02:05:19	2020-03-11	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3878	delivery	5	40
38364	2020-03-11 02:22:10	2020-03-11	9	[{"id_menu":6,"count":1}]	4313	delivery	5	14
38365	2020-03-11 02:30:07	2020-03-11	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	6324	delivery	5	43
38366	2020-03-11 02:48:51	2020-03-11	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15303	delivery	5	31
38367	2020-03-11 03:00:59	2020-03-11	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	4960	pick-up	0	21
38368	2020-03-11 03:01:33	2020-03-11	9	[{"id_menu":6,"count":1}]	15301	delivery	5	14
38369	2020-03-11 03:22:16	2020-03-11	17	[{"id_menu":4,"count":1}]	15269	delivery	5	22
38370	2020-03-11 03:26:14	2020-03-11	17	[{"id_menu":4,"count":1}]	4238	pick-up	0	17
38371	2020-03-11 03:34:12	2020-03-11	17	[{"id_menu":4,"count":1}]	274	delivery	5	22
38372	2020-03-11 03:36:25	2020-03-11	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	9575	pick-up	0	26
38373	2020-03-11 03:37:17	2020-03-11	12	[{"id_menu":1,"count":1}]	15235	delivery	5	17
38374	2020-03-11 03:53:42	2020-03-11	14	[{"id_menu":2,"count":2}]	5519	pick-up	0	14
38375	2020-03-11 03:58:50	2020-03-11	14	[{"id_menu":2,"count":1}]	12905	pick-up	0	14
38376	2020-03-11 04:12:08	2020-03-11	14	[{"id_menu":2,"count":1}]	2470	pick-up	0	14
38377	2020-03-11 04:14:10	2020-03-11	12	[{"id_menu":3,"count":1}]	15262	delivery	5	17
38378	2020-03-11 04:14:31	2020-03-11	9	[{"id_menu":6,"count":1}]	12037	delivery	5	14
38379	2020-03-11 04:18:43	2020-03-11	8	[{"id_menu":5,"count":1}]	15198	delivery	5	13
38380	2020-03-11 04:40:01	2020-03-11	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3021	pick-up	0	26
38381	2020-03-11 04:47:09	2020-03-11	12	[{"id_menu":3,"count":1}]	15284	delivery	5	17
38382	2020-03-11 04:50:35	2020-03-11	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	9017	pick-up	0	26
38383	2020-03-11 04:59:38	2020-03-11	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15279	delivery	5	34
38384	2020-03-11 05:02:55	2020-03-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15233	delivery	5	22
38385	2020-03-11 05:05:26	2020-03-11	26	[{"id_menu":1,"count":3},{"id_menu":2,"count":1}]	3949	pick-up	0	26
38386	2020-03-11 05:10:15	2020-03-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5311	pick-up	0	17
38387	2020-03-11 05:10:49	2020-03-11	12	[{"id_menu":1,"count":1}]	15309	delivery	5	17
38388	2020-03-11 05:11:32	2020-03-11	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	8561	delivery	5	36
38389	2020-03-11 05:14:40	2020-03-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	13614	delivery	5	28
38390	2020-03-11 05:26:57	2020-03-11	17	[{"id_menu":4,"count":1}]	1914	pick-up	0	17
38391	2020-03-11 05:31:07	2020-03-11	37	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2862	pick-up	0	37
38392	2020-03-11 05:35:28	2020-03-11	9	[{"id_menu":7,"count":1}]	14	delivery	5	14
38393	2020-03-11 05:44:04	2020-03-11	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	13758	delivery	5	40
38394	2020-03-11 05:51:01	2020-03-11	12	[{"id_menu":3,"count":1}]	10330	pick-up	0	12
38395	2020-03-11 06:07:13	2020-03-11	17	[{"id_menu":4,"count":1}]	8145	delivery	5	22
38396	2020-03-11 06:07:14	2020-03-11	9	[{"id_menu":6,"count":1}]	3831	delivery	5	14
38397	2020-03-11 06:08:19	2020-03-11	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	12823	delivery	5	31
38398	2020-03-11 06:09:49	2020-03-11	9	[{"id_menu":7,"count":1}]	13911	pick-up	0	9
38399	2020-03-11 06:14:23	2020-03-11	9	[{"id_menu":7,"count":2}]	15296	delivery	5	14
38400	2020-03-11 06:14:30	2020-03-11	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15270	delivery	5	31
38401	2020-03-11 06:31:05	2020-03-11	14	[{"id_menu":2,"count":2}]	15234	delivery	5	19
38402	2020-03-11 06:36:37	2020-03-11	12	[{"id_menu":1,"count":1}]	1115	pick-up	0	12
38403	2020-03-11 06:40:56	2020-03-11	17	[{"id_menu":4,"count":1}]	15209	delivery	5	22
38404	2020-03-11 06:44:29	2020-03-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9823	delivery	5	23
38405	2020-03-11 07:29:17	2020-03-11	9	[{"id_menu":6,"count":1}]	2687	delivery	5	14
38406	2020-03-11 07:37:10	2020-03-11	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2272	pick-up	0	38
38407	2020-03-11 07:47:38	2020-03-11	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	15215	delivery	5	44
38408	2020-03-11 07:53:34	2020-03-11	9	[{"id_menu":7,"count":1}]	14131	delivery	5	14
38409	2020-03-11 08:00:26	2020-03-11	8	[{"id_menu":5,"count":1}]	1062	delivery	5	13
38410	2020-03-11 08:07:52	2020-03-11	17	[{"id_menu":4,"count":1}]	1263	pick-up	0	17
38411	2020-03-11 08:17:20	2020-03-11	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3314	pick-up	0	26
38412	2020-03-11 08:22:41	2020-03-11	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6430	delivery	5	55
38413	2020-03-11 08:30:29	2020-03-11	9	[{"id_menu":7,"count":1}]	15313	delivery	5	14
38414	2020-03-11 08:37:53	2020-03-11	14	[{"id_menu":2,"count":1}]	612	pick-up	0	14
38415	2020-03-11 08:40:44	2020-03-11	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9071	delivery	5	34
38416	2020-03-11 08:45:29	2020-03-11	9	[{"id_menu":7,"count":1}]	8912	delivery	5	14
38417	2020-03-11 08:52:13	2020-03-11	14	[{"id_menu":2,"count":1}]	13134	pick-up	0	14
38418	2020-03-11 08:52:22	2020-03-11	9	[{"id_menu":7,"count":1}]	15300	delivery	5	14
38419	2020-03-11 08:54:15	2020-03-11	8	[{"id_menu":5,"count":2}]	14645	delivery	5	13
38420	2020-03-11 08:55:32	2020-03-11	12	[{"id_menu":1,"count":1}]	15240	delivery	5	17
38421	2020-03-11 08:57:02	2020-03-11	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5723	pick-up	0	25
38422	2020-03-11 08:59:07	2020-03-11	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	15286	delivery	5	31
38423	2020-03-11 08:59:16	2020-03-11	9	[{"id_menu":6,"count":1}]	4805	delivery	5	14
38424	2020-03-11 09:06:09	2020-03-11	8	[{"id_menu":5,"count":1}]	14606	delivery	5	13
38425	2020-03-11 09:14:34	2020-03-11	9	[{"id_menu":7,"count":1}]	15246	delivery	5	14
38426	2020-03-11 09:26:43	2020-03-11	8	[{"id_menu":5,"count":1}]	15224	delivery	5	13
38427	2020-03-11 09:28:20	2020-03-11	14	[{"id_menu":2,"count":1}]	3755	pick-up	0	14
38428	2020-03-11 09:29:12	2020-03-11	12	[{"id_menu":3,"count":1}]	4789	pick-up	0	12
38429	2020-03-11 09:30:09	2020-03-11	12	[{"id_menu":1,"count":1}]	790	pick-up	0	12
38430	2020-03-11 09:37:24	2020-03-11	17	[{"id_menu":4,"count":1}]	1956	pick-up	0	17
38431	2020-03-11 09:38:23	2020-03-11	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	12187	delivery	5	36
38432	2020-03-11 09:45:13	2020-03-11	12	[{"id_menu":3,"count":1}]	5958	pick-up	0	12
38433	2020-03-11 09:45:28	2020-03-11	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	15228	delivery	5	26
38434	2020-03-11 09:49:11	2020-03-11	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15273	delivery	5	36
38435	2020-03-11 09:54:30	2020-03-11	9	[{"id_menu":6,"count":1}]	15214	delivery	5	14
38436	2020-03-11 09:54:44	2020-03-11	14	[{"id_menu":2,"count":1}]	9193	pick-up	0	14
38437	2020-03-11 09:58:43	2020-03-11	12	[{"id_menu":1,"count":1}]	7227	delivery	5	17
38438	2020-03-11 10:00:40	2020-03-11	9	[{"id_menu":6,"count":1}]	3198	pick-up	0	9
38439	2020-03-11 10:01:19	2020-03-11	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	15281	delivery	5	40
38440	2020-03-11 10:05:59	2020-03-11	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15203	delivery	5	45
38441	2020-03-11 10:07:40	2020-03-11	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13651	pick-up	0	26
38442	2020-03-11 10:11:36	2020-03-11	17	[{"id_menu":4,"count":1}]	7448	delivery	5	22
38443	2020-03-11 10:21:32	2020-03-11	9	[{"id_menu":6,"count":1}]	12237	delivery	5	14
38444	2020-03-11 10:27:25	2020-03-11	9	[{"id_menu":7,"count":1}]	2956	pick-up	0	9
38445	2020-03-11 10:31:39	2020-03-11	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	12849	delivery	5	26
38446	2020-03-11 10:34:11	2020-03-11	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6156	delivery	5	40
38447	2020-03-11 10:36:37	2020-03-11	14	[{"id_menu":2,"count":1}]	15201	delivery	5	19
38448	2020-03-11 10:36:58	2020-03-11	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	766	pick-up	0	31
38449	2020-03-11 10:46:13	2020-03-11	9	[{"id_menu":7,"count":1}]	15245	delivery	5	14
38450	2020-03-11 10:47:23	2020-03-11	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13929	delivery	5	34
38451	2020-03-11 10:49:23	2020-03-11	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	15310	delivery	5	31
38452	2020-03-11 10:51:23	2020-03-11	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	13391	delivery	5	36
38453	2020-03-11 10:53:46	2020-03-11	12	[{"id_menu":3,"count":1}]	15196	pick-up	0	12
38454	2020-03-11 11:04:17	2020-03-11	14	[{"id_menu":2,"count":1}]	5474	pick-up	0	14
38455	2020-03-11 11:04:41	2020-03-11	9	[{"id_menu":7,"count":1}]	5232	delivery	5	14
38456	2020-03-11 11:09:30	2020-03-11	14	[{"id_menu":2,"count":1}]	15237	delivery	5	19
38457	2020-03-11 11:20:18	2020-03-11	17	[{"id_menu":4,"count":1}]	15243	pick-up	0	17
38458	2020-03-11 11:22:20	2020-03-11	12	[{"id_menu":1,"count":1}]	13062	pick-up	0	12
38459	2020-03-11 11:28:53	2020-03-11	9	[{"id_menu":6,"count":1}]	15202	pick-up	0	9
38460	2020-03-11 11:42:59	2020-03-11	9	[{"id_menu":7,"count":1}]	15231	delivery	5	14
38461	2020-03-11 11:45:15	2020-03-11	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	15197	delivery	5	25
38462	2020-03-11 11:51:14	2020-03-11	9	[{"id_menu":7,"count":1}]	15206	pick-up	0	9
38463	2020-03-11 11:52:49	2020-03-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6282	pick-up	0	23
38464	2020-03-11 11:54:14	2020-03-11	14	[{"id_menu":2,"count":1}]	2394	delivery	5	19
38465	2020-03-11 11:56:19	2020-03-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	15285	pick-up	0	23
38466	2020-03-11 12:06:18	2020-03-11	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1761	delivery	5	26
38467	2020-03-11 12:12:03	2020-03-11	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2383	pick-up	0	29
38468	2020-03-11 12:20:36	2020-03-11	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	3659	delivery	5	26
38469	2020-03-11 12:21:29	2020-03-11	9	[{"id_menu":7,"count":1}]	3578	delivery	5	14
38470	2020-03-11 12:27:59	2020-03-11	12	[{"id_menu":1,"count":1}]	6962	pick-up	0	12
38471	2020-03-11 12:32:04	2020-03-11	9	[{"id_menu":7,"count":1}]	15264	pick-up	0	9
38472	2020-03-11 12:36:34	2020-03-11	8	[{"id_menu":5,"count":1}]	15283	delivery	5	13
38473	2020-03-11 12:49:21	2020-03-11	8	[{"id_menu":5,"count":1}]	5817	delivery	5	13
38474	2020-03-11 12:49:53	2020-03-11	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15255	delivery	5	35
38475	2020-03-11 12:50:03	2020-03-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14364	delivery	5	22
38476	2020-03-11 13:07:38	2020-03-11	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15256	delivery	5	34
38477	2020-03-11 13:10:55	2020-03-11	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15218	delivery	5	35
38478	2020-03-11 13:11:33	2020-03-11	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	8919	delivery	5	26
38479	2020-03-11 13:13:16	2020-03-11	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	177	pick-up	0	29
38480	2020-03-11 13:15:35	2020-03-11	8	[{"id_menu":5,"count":1}]	15216	delivery	5	13
38481	2020-03-11 13:15:50	2020-03-11	14	[{"id_menu":2,"count":1}]	15298	delivery	5	19
38482	2020-03-11 13:19:51	2020-03-11	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	15205	delivery	5	28
38483	2020-03-11 13:21:03	2020-03-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6056	delivery	5	28
38484	2020-03-11 13:26:24	2020-03-11	17	[{"id_menu":4,"count":1}]	13060	delivery	5	22
38485	2020-03-11 13:36:59	2020-03-11	17	[{"id_menu":4,"count":1}]	6039	pick-up	0	17
38486	2020-03-11 13:37:12	2020-03-11	17	[{"id_menu":4,"count":1}]	15244	delivery	5	22
38487	2020-03-11 13:48:37	2020-03-11	14	[{"id_menu":2,"count":1}]	1384	pick-up	0	14
38488	2020-03-11 13:54:49	2020-03-11	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	815	pick-up	0	20
38489	2020-03-11 13:59:26	2020-03-11	9	[{"id_menu":7,"count":1}]	15271	delivery	5	14
38490	2020-03-11 14:00:44	2020-03-11	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9158	delivery	5	22
38491	2020-03-11 14:01:09	2020-03-11	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	15288	delivery	5	26
38492	2020-03-11 14:05:28	2020-03-11	8	[{"id_menu":5,"count":1}]	1858	pick-up	0	8
38493	2020-03-11 14:05:50	2020-03-11	8	[{"id_menu":5,"count":1}]	7986	delivery	5	13
38494	2020-03-11 14:10:36	2020-03-11	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	6389	delivery	5	26
38495	2020-03-11 14:11:11	2020-03-11	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	15250	delivery	5	31
38496	2020-03-11 14:17:43	2020-03-11	12	[{"id_menu":1,"count":1}]	223	delivery	5	17
38497	2020-03-11 14:20:44	2020-03-11	12	[{"id_menu":1,"count":1}]	6885	pick-up	0	12
38498	2020-03-11 14:21:03	2020-03-11	12	[{"id_menu":1,"count":1}]	15305	delivery	5	17
38499	2020-03-11 14:21:21	2020-03-11	12	[{"id_menu":1,"count":1}]	14593	pick-up	0	12
38500	2020-03-11 14:25:07	2020-03-11	17	[{"id_menu":4,"count":1}]	476	delivery	5	22
38501	2020-03-11 14:26:58	2020-03-11	9	[{"id_menu":7,"count":4}]	15227	delivery	5	14
38502	2020-03-11 14:34:26	2020-03-11	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	2227	pick-up	0	26
38503	2020-03-11 14:35:11	2020-03-11	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	15307	delivery	5	25
38504	2020-03-11 14:39:40	2020-03-11	9	[{"id_menu":7,"count":1}]	4967	pick-up	0	9
38505	2020-03-11 15:04:13	2020-03-11	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	15217	delivery	5	34
38506	2020-03-11 15:22:08	2020-03-11	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12050	delivery	5	43
38507	2020-03-11 15:24:09	2020-03-11	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12110	delivery	5	36
38508	2020-03-11 15:26:34	2020-03-11	14	[{"id_menu":2,"count":1}]	15259	delivery	5	19
38509	2020-03-11 15:33:40	2020-03-11	9	[{"id_menu":6,"count":1}]	10389	delivery	5	14
38510	2020-03-11 15:37:51	2020-03-11	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3091	delivery	5	42
38511	2020-03-11 15:39:59	2020-03-11	9	[{"id_menu":7,"count":1}]	14252	pick-up	0	9
38512	2020-03-11 15:40:20	2020-03-11	14	[{"id_menu":2,"count":1}]	2413	pick-up	0	14
38513	2020-03-11 15:46:19	2020-03-11	9	[{"id_menu":6,"count":1}]	5571	delivery	5	14
38514	2020-03-11 15:52:08	2020-03-11	12	[{"id_menu":1,"count":1}]	15208	delivery	5	17
38515	2020-03-11 15:53:09	2020-03-11	12	[{"id_menu":3,"count":1}]	15210	delivery	5	17
38516	2020-03-11 15:53:26	2020-03-11	9	[{"id_menu":7,"count":1}]	6034	delivery	5	14
38517	2020-03-11 16:01:12	2020-03-11	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	11316	delivery	5	23
38518	2020-03-11 16:09:23	2020-03-11	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11943	delivery	5	40
38519	2020-03-11 16:10:03	2020-03-11	14	[{"id_menu":2,"count":1}]	4020	pick-up	0	14
38520	2020-03-11 16:14:41	2020-03-11	12	[{"id_menu":3,"count":1}]	14643	delivery	5	17
38521	2020-03-11 16:20:44	2020-03-11	17	[{"id_menu":4,"count":1}]	6248	pick-up	0	17
38522	2020-03-11 16:32:02	2020-03-11	9	[{"id_menu":6,"count":1}]	15267	delivery	5	14
38523	2020-03-11 16:33:17	2020-03-11	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	11919	delivery	5	28
38524	2020-03-11 16:37:08	2020-03-11	9	[{"id_menu":6,"count":1}]	11299	pick-up	0	9
38525	2020-03-11 16:37:34	2020-03-11	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7648	delivery	5	22
38526	2020-03-11 16:39:55	2020-03-11	9	[{"id_menu":7,"count":1}]	11420	delivery	5	14
38527	2020-03-11 16:43:02	2020-03-11	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10825	delivery	5	36
38528	2020-03-11 16:51:01	2020-03-11	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	15219	pick-up	0	21
38529	2020-03-11 17:05:47	2020-03-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13955	delivery	5	23
38530	2020-03-11 17:10:02	2020-03-11	38	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15268	delivery	5	43
38531	2020-03-11 17:10:19	2020-03-11	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15312	delivery	5	36
38532	2020-03-11 17:13:41	2020-03-11	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	4712	delivery	5	23
38533	2020-03-11 17:15:01	2020-03-11	8	[{"id_menu":5,"count":1}]	197	pick-up	0	8
38534	2020-03-11 17:15:02	2020-03-11	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	15263	delivery	5	44
38535	2020-03-11 17:15:09	2020-03-11	20	[{"id_menu":1,"count":3},{"id_menu":5,"count":1}]	468	pick-up	0	20
38536	2020-03-11 17:15:43	2020-03-11	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	13737	delivery	5	26
38537	2020-03-11 17:23:23	2020-03-11	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2392	pick-up	0	40
38538	2020-03-11 17:28:42	2020-03-11	17	[{"id_menu":4,"count":1}]	15265	delivery	5	22
38539	2020-03-11 17:29:46	2020-03-11	9	[{"id_menu":7,"count":1}]	8871	delivery	5	14
38540	2020-03-11 17:32:10	2020-03-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15292	pick-up	0	18
38541	2020-03-11 17:37:20	2020-03-11	14	[{"id_menu":2,"count":1}]	15194	pick-up	0	14
38542	2020-03-11 17:37:29	2020-03-11	8	[{"id_menu":5,"count":1}]	1657	delivery	5	13
38543	2020-03-11 17:45:21	2020-03-11	9	[{"id_menu":7,"count":1}]	15266	delivery	5	14
38544	2020-03-11 17:46:45	2020-03-11	9	[{"id_menu":6,"count":1}]	1386	delivery	5	14
38545	2020-03-11 17:51:42	2020-03-11	12	[{"id_menu":1,"count":1}]	15211	delivery	5	17
38546	2020-03-11 17:56:04	2020-03-11	9	[{"id_menu":6,"count":1}]	5941	pick-up	0	9
38547	2020-03-11 17:59:19	2020-03-11	9	[{"id_menu":7,"count":1}]	462	delivery	5	14
38548	2020-03-11 18:00:19	2020-03-11	9	[{"id_menu":7,"count":1}]	4850	pick-up	0	9
38549	2020-03-11 18:05:39	2020-03-11	9	[{"id_menu":6,"count":1}]	4261	pick-up	0	9
38550	2020-03-11 18:06:25	2020-03-11	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	12210	delivery	5	40
38551	2020-03-11 18:06:27	2020-03-11	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	15220	delivery	5	35
38552	2020-03-11 18:06:32	2020-03-11	17	[{"id_menu":4,"count":1}]	8405	delivery	5	22
38553	2020-03-11 18:09:55	2020-03-11	12	[{"id_menu":3,"count":1}]	2619	pick-up	0	12
38554	2020-03-11 18:20:41	2020-03-11	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	3736	pick-up	0	21
38555	2020-03-11 18:30:46	2020-03-11	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	15276	delivery	5	26
38556	2020-03-11 18:35:34	2020-03-11	12	[{"id_menu":1,"count":1}]	5009	pick-up	0	12
38557	2020-03-11 18:46:52	2020-03-11	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	9404	pick-up	0	23
38558	2020-03-11 18:56:25	2020-03-11	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10442	delivery	5	35
38559	2020-03-11 18:57:57	2020-03-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	15308	delivery	5	23
38560	2020-03-11 19:09:07	2020-03-11	14	[{"id_menu":2,"count":1}]	585	delivery	5	19
38561	2020-03-11 19:11:48	2020-03-11	12	[{"id_menu":3,"count":1}]	5430	pick-up	0	12
38562	2020-03-11 19:13:45	2020-03-11	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	15232	delivery	5	25
38563	2020-03-11 19:17:57	2020-03-11	8	[{"id_menu":5,"count":1}]	7729	pick-up	0	8
38564	2020-03-11 19:24:59	2020-03-11	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	15192	delivery	5	40
38565	2020-03-11 19:26:56	2020-03-11	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15299	delivery	5	43
38566	2020-03-11 19:27:06	2020-03-11	9	[{"id_menu":7,"count":1}]	3455	pick-up	0	9
38567	2020-03-11 19:30:38	2020-03-11	9	[{"id_menu":7,"count":1}]	13844	pick-up	0	9
38568	2020-03-11 19:33:20	2020-03-11	14	[{"id_menu":2,"count":1}]	6104	delivery	5	19
38569	2020-03-11 19:39:08	2020-03-11	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6624	delivery	5	31
38570	2020-03-11 19:41:04	2020-03-11	9	[{"id_menu":6,"count":1}]	15225	delivery	5	14
38571	2020-03-11 19:41:52	2020-03-11	17	[{"id_menu":4,"count":1}]	4116	delivery	5	22
38572	2020-03-11 19:42:38	2020-03-11	9	[{"id_menu":6,"count":1}]	15252	delivery	5	14
38573	2020-03-11 19:43:00	2020-03-11	14	[{"id_menu":2,"count":1}]	6536	delivery	5	19
38574	2020-03-11 19:44:00	2020-03-11	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	11953	delivery	5	25
38575	2020-03-11 19:47:48	2020-03-11	12	[{"id_menu":1,"count":1}]	1924	delivery	5	17
38576	2020-03-11 20:00:36	2020-03-11	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	15302	delivery	5	25
38577	2020-03-11 20:09:21	2020-03-11	14	[{"id_menu":2,"count":1}]	13197	pick-up	0	14
38578	2020-03-11 20:09:21	2020-03-11	14	[{"id_menu":2,"count":1}]	15287	delivery	5	19
38579	2020-03-11 20:09:26	2020-03-11	9	[{"id_menu":6,"count":1}]	10699	delivery	5	14
38580	2020-03-11 20:12:47	2020-03-11	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15275	delivery	5	37
38581	2020-03-11 20:18:37	2020-03-11	9	[{"id_menu":6,"count":1}]	7636	delivery	5	14
38582	2020-03-11 20:24:25	2020-03-11	8	[{"id_menu":5,"count":1}]	14023	delivery	5	13
38583	2020-03-11 20:26:33	2020-03-11	9	[{"id_menu":6,"count":1}]	15253	delivery	5	14
38584	2020-03-11 20:28:11	2020-03-11	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	10268	delivery	5	36
38585	2020-03-11 20:38:25	2020-03-11	9	[{"id_menu":6,"count":1}]	14373	delivery	5	14
38586	2020-03-11 20:39:44	2020-03-11	9	[{"id_menu":7,"count":1}]	3707	pick-up	0	9
38587	2020-03-11 20:43:38	2020-03-11	9	[{"id_menu":6,"count":2}]	15248	delivery	5	14
38588	2020-03-11 20:44:07	2020-03-11	17	[{"id_menu":4,"count":1}]	11732	pick-up	0	17
38589	2020-03-11 20:47:48	2020-03-11	9	[{"id_menu":7,"count":1}]	3320	pick-up	0	9
38590	2020-03-11 20:50:51	2020-03-11	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	802	pick-up	0	23
38591	2020-03-11 20:54:27	2020-03-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3002	delivery	5	28
38592	2020-03-11 20:54:43	2020-03-11	17	[{"id_menu":4,"count":1}]	546	delivery	5	22
38593	2020-03-11 20:55:36	2020-03-11	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	15238	delivery	5	30
38594	2020-03-11 20:56:30	2020-03-11	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	14190	delivery	5	39
38595	2020-03-11 21:06:51	2020-03-11	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3507	pick-up	0	23
38596	2020-03-11 21:15:03	2020-03-11	21	[{"id_menu":1,"count":3},{"id_menu":6,"count":1}]	15258	delivery	5	26
38597	2020-03-11 21:16:46	2020-03-11	9	[{"id_menu":7,"count":1}]	5758	delivery	5	14
38598	2020-03-11 21:18:20	2020-03-11	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11891	delivery	5	39
38599	2020-03-11 21:19:27	2020-03-11	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	5857	pick-up	0	29
38600	2020-03-11 21:20:20	2020-03-11	12	[{"id_menu":1,"count":1}]	15207	pick-up	0	12
38601	2020-03-11 21:29:24	2020-03-11	8	[{"id_menu":5,"count":1}]	15239	delivery	5	13
38602	2020-03-11 21:30:08	2020-03-11	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	752	delivery	5	28
38603	2020-03-11 21:32:49	2020-03-11	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	15251	delivery	5	30
38604	2020-03-11 21:42:14	2020-03-11	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15294	delivery	5	43
38605	2020-03-11 21:42:41	2020-03-11	12	[{"id_menu":3,"count":1}]	11904	pick-up	0	12
38606	2020-03-11 21:48:00	2020-03-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":3}]	15236	delivery	5	22
38607	2020-03-11 21:53:12	2020-03-11	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	3341	delivery	5	26
38608	2020-03-11 22:05:48	2020-03-11	14	[{"id_menu":2,"count":1}]	1093	pick-up	0	14
38609	2020-03-11 22:06:17	2020-03-11	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15261	delivery	5	36
38610	2020-03-11 22:06:27	2020-03-11	14	[{"id_menu":2,"count":1}]	3062	delivery	5	19
38611	2020-03-11 22:08:45	2020-03-11	12	[{"id_menu":1,"count":2}]	7700	pick-up	0	12
38612	2020-03-11 22:11:38	2020-03-11	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	15274	delivery	5	26
38613	2020-03-11 22:15:45	2020-03-11	14	[{"id_menu":2,"count":1}]	15280	delivery	5	19
38614	2020-03-11 22:18:45	2020-03-11	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5074	delivery	5	36
38615	2020-03-11 22:21:31	2020-03-11	17	[{"id_menu":4,"count":1}]	15295	delivery	5	22
38616	2020-03-11 22:24:04	2020-03-11	14	[{"id_menu":2,"count":1}]	4585	pick-up	0	14
38617	2020-03-11 22:43:31	2020-03-11	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	15293	delivery	5	27
38618	2020-03-11 23:08:01	2020-03-11	9	[{"id_menu":6,"count":1}]	12455	delivery	5	14
38619	2020-03-11 23:17:54	2020-03-11	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	339	pick-up	0	34
38620	2020-03-11 23:26:26	2020-03-11	9	[{"id_menu":6,"count":1}]	15213	delivery	5	14
38621	2020-03-11 23:28:59	2020-03-11	9	[{"id_menu":7,"count":1}]	2041	delivery	5	14
38622	2020-03-11 23:42:31	2020-03-11	9	[{"id_menu":7,"count":1}]	5138	pick-up	0	9
38623	2020-03-11 23:53:45	2020-03-11	12	[{"id_menu":1,"count":1}]	7226	delivery	5	17
38624	2020-03-11 23:58:56	2020-03-11	12	[{"id_menu":3,"count":1}]	11553	pick-up	0	12
38625	2020-03-12 00:03:28	2020-03-12	8	[{"id_menu":5,"count":1}]	8282	delivery	5	13
38626	2020-03-12 00:05:23	2020-03-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1892	delivery	5	23
38627	2020-03-12 00:14:35	2020-03-12	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4204	delivery	5	34
38628	2020-03-12 00:32:32	2020-03-12	17	[{"id_menu":4,"count":1}]	15376	delivery	5	22
38629	2020-03-12 00:33:51	2020-03-12	12	[{"id_menu":3,"count":1}]	15331	pick-up	0	12
38630	2020-03-12 00:35:15	2020-03-12	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	5138	pick-up	0	22
38631	2020-03-12 00:39:44	2020-03-12	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15432	delivery	5	43
38632	2020-03-12 00:39:53	2020-03-12	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	688	pick-up	0	29
38633	2020-03-12 00:40:17	2020-03-12	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	15396	delivery	5	34
38634	2020-03-12 00:51:08	2020-03-12	12	[{"id_menu":3,"count":1}]	11493	delivery	5	17
38635	2020-03-12 00:53:59	2020-03-12	12	[{"id_menu":1,"count":2}]	5377	delivery	5	17
38636	2020-03-12 01:04:25	2020-03-12	8	[{"id_menu":5,"count":1}]	3731	delivery	5	13
38637	2020-03-12 01:10:35	2020-03-12	12	[{"id_menu":3,"count":1}]	10527	delivery	5	17
38638	2020-03-12 01:12:21	2020-03-12	9	[{"id_menu":7,"count":1}]	5572	delivery	5	14
38639	2020-03-12 01:18:55	2020-03-12	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	15374	delivery	5	22
38640	2020-03-12 01:27:37	2020-03-12	9	[{"id_menu":6,"count":1}]	4770	pick-up	0	9
38641	2020-03-12 01:32:34	2020-03-12	12	[{"id_menu":1,"count":1}]	15390	delivery	5	17
38642	2020-03-12 01:34:30	2020-03-12	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	15401	delivery	5	26
38643	2020-03-12 01:40:16	2020-03-12	8	[{"id_menu":5,"count":1}]	2980	pick-up	0	8
38644	2020-03-12 01:50:45	2020-03-12	12	[{"id_menu":3,"count":1}]	3130	delivery	5	17
38645	2020-03-12 01:51:43	2020-03-12	14	[{"id_menu":2,"count":1}]	13264	pick-up	0	14
38646	2020-03-12 01:52:34	2020-03-12	12	[{"id_menu":3,"count":1}]	11488	delivery	5	17
38647	2020-03-12 02:02:52	2020-03-12	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	8093	delivery	5	25
38648	2020-03-12 02:02:54	2020-03-12	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3393	delivery	5	40
38649	2020-03-12 02:04:44	2020-03-12	8	[{"id_menu":5,"count":1}]	15042	delivery	5	13
38650	2020-03-12 02:09:01	2020-03-12	9	[{"id_menu":7,"count":1}]	15411	delivery	5	14
38651	2020-03-12 02:11:22	2020-03-12	12	[{"id_menu":3,"count":1}]	7708	delivery	5	17
38652	2020-03-12 02:19:57	2020-03-12	9	[{"id_menu":6,"count":1}]	3540	delivery	5	14
38653	2020-03-12 02:29:50	2020-03-12	12	[{"id_menu":1,"count":1}]	10461	delivery	5	17
38654	2020-03-12 02:32:00	2020-03-12	8	[{"id_menu":5,"count":1}]	6621	pick-up	0	8
38655	2020-03-12 02:34:24	2020-03-12	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	389	pick-up	0	25
38656	2020-03-12 02:35:01	2020-03-12	17	[{"id_menu":4,"count":1}]	76	pick-up	0	17
38657	2020-03-12 02:36:58	2020-03-12	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	15314	delivery	5	40
38658	2020-03-12 02:37:51	2020-03-12	12	[{"id_menu":1,"count":1}]	8629	delivery	5	17
38659	2020-03-12 02:44:41	2020-03-12	9	[{"id_menu":7,"count":1}]	12467	delivery	5	14
38660	2020-03-12 02:46:36	2020-03-12	8	[{"id_menu":5,"count":3}]	287	pick-up	0	8
38661	2020-03-12 02:47:15	2020-03-12	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	4451	delivery	5	34
38662	2020-03-12 02:51:16	2020-03-12	9	[{"id_menu":7,"count":1}]	15427	delivery	5	14
38663	2020-03-12 02:51:35	2020-03-12	9	[{"id_menu":7,"count":1}]	10970	delivery	5	14
38664	2020-03-12 03:00:24	2020-03-12	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5236	delivery	5	22
38665	2020-03-12 03:00:48	2020-03-12	8	[{"id_menu":5,"count":1}]	15412	delivery	5	13
38666	2020-03-12 03:05:23	2020-03-12	9	[{"id_menu":7,"count":1}]	12179	delivery	5	14
38667	2020-03-12 03:09:04	2020-03-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7542	delivery	5	22
38668	2020-03-12 03:10:53	2020-03-12	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":3}]	13624	delivery	5	22
38669	2020-03-12 03:16:16	2020-03-12	8	[{"id_menu":5,"count":1}]	15405	delivery	5	13
38670	2020-03-12 03:18:39	2020-03-12	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15400	pick-up	0	17
38671	2020-03-12 03:35:47	2020-03-12	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	15351	delivery	5	27
38672	2020-03-12 03:38:18	2020-03-12	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15375	delivery	5	36
38673	2020-03-12 03:40:47	2020-03-12	12	[{"id_menu":3,"count":1}]	691	delivery	5	17
38674	2020-03-12 03:46:02	2020-03-12	8	[{"id_menu":5,"count":1}]	80	delivery	5	13
38675	2020-03-12 03:47:25	2020-03-12	9	[{"id_menu":7,"count":1}]	149	pick-up	0	9
38676	2020-03-12 03:49:09	2020-03-12	12	[{"id_menu":1,"count":1}]	5928	delivery	5	17
38677	2020-03-12 03:50:02	2020-03-12	9	[{"id_menu":7,"count":1}]	15355	delivery	5	14
38678	2020-03-12 03:51:40	2020-03-12	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15323	delivery	5	31
38679	2020-03-12 03:52:02	2020-03-12	12	[{"id_menu":3,"count":1}]	7815	pick-up	0	12
38680	2020-03-12 03:53:04	2020-03-12	17	[{"id_menu":4,"count":1}]	517	delivery	5	22
38681	2020-03-12 04:05:11	2020-03-12	8	[{"id_menu":5,"count":1}]	8081	delivery	5	13
38682	2020-03-12 04:06:22	2020-03-12	12	[{"id_menu":3,"count":1}]	4007	delivery	5	17
38683	2020-03-12 04:07:47	2020-03-12	8	[{"id_menu":5,"count":1}]	314	pick-up	0	8
38684	2020-03-12 04:11:01	2020-03-12	8	[{"id_menu":5,"count":1}]	12892	delivery	5	13
38685	2020-03-12 04:23:05	2020-03-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3571	delivery	5	31
38686	2020-03-12 04:23:18	2020-03-12	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	15368	delivery	5	22
38687	2020-03-12 04:23:52	2020-03-12	9	[{"id_menu":6,"count":1}]	15399	delivery	5	14
38688	2020-03-12 04:38:16	2020-03-12	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1259	pick-up	0	31
38689	2020-03-12 04:39:41	2020-03-12	17	[{"id_menu":4,"count":1}]	545	pick-up	0	17
38690	2020-03-12 04:40:42	2020-03-12	9	[{"id_menu":6,"count":1}]	15339	delivery	5	14
38691	2020-03-12 04:41:45	2020-03-12	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4788	delivery	5	43
38692	2020-03-12 04:48:37	2020-03-12	17	[{"id_menu":4,"count":1}]	2398	delivery	5	22
38693	2020-03-12 04:53:39	2020-03-12	12	[{"id_menu":3,"count":1}]	15371	delivery	5	17
38694	2020-03-12 04:58:35	2020-03-12	9	[{"id_menu":7,"count":1}]	8249	delivery	5	14
38695	2020-03-12 04:59:04	2020-03-12	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	2771	pick-up	0	20
38696	2020-03-12 05:03:53	2020-03-12	9	[{"id_menu":7,"count":1}]	9322	delivery	5	14
38697	2020-03-12 05:05:40	2020-03-12	8	[{"id_menu":5,"count":1}]	852	delivery	5	13
38698	2020-03-12 05:17:37	2020-03-12	9	[{"id_menu":6,"count":1}]	2538	pick-up	0	9
38699	2020-03-12 05:20:56	2020-03-12	9	[{"id_menu":7,"count":1}]	2924	delivery	5	14
38700	2020-03-12 05:23:06	2020-03-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9128	pick-up	0	26
38701	2020-03-12 05:26:47	2020-03-12	12	[{"id_menu":1,"count":1}]	12307	delivery	5	17
38702	2020-03-12 05:30:25	2020-03-12	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12605	delivery	5	45
38703	2020-03-12 05:34:02	2020-03-12	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	15433	delivery	5	28
38704	2020-03-12 05:36:23	2020-03-12	17	[{"id_menu":4,"count":1}]	15383	delivery	5	22
38705	2020-03-12 05:50:22	2020-03-12	14	[{"id_menu":2,"count":1}]	1030	delivery	5	19
38706	2020-03-12 05:55:37	2020-03-12	14	[{"id_menu":2,"count":1}]	11297	delivery	5	19
38707	2020-03-12 05:57:36	2020-03-12	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8012	delivery	5	22
38708	2020-03-12 06:00:34	2020-03-12	9	[{"id_menu":7,"count":1}]	1257	pick-up	0	9
38709	2020-03-12 06:04:13	2020-03-12	9	[{"id_menu":6,"count":3}]	1457	delivery	5	14
38710	2020-03-12 06:08:46	2020-03-12	17	[{"id_menu":4,"count":1}]	10387	pick-up	0	17
38711	2020-03-12 06:10:57	2020-03-12	9	[{"id_menu":6,"count":1}]	14157	delivery	5	14
38712	2020-03-12 06:21:01	2020-03-12	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	7790	delivery	5	28
38713	2020-03-12 06:21:43	2020-03-12	12	[{"id_menu":1,"count":1}]	15366	delivery	5	17
38714	2020-03-12 06:27:38	2020-03-12	14	[{"id_menu":2,"count":1}]	15257	delivery	5	19
38715	2020-03-12 06:31:13	2020-03-12	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5597	delivery	5	45
38716	2020-03-12 06:31:26	2020-03-12	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":2}]	9482	delivery	5	36
38717	2020-03-12 06:39:37	2020-03-12	8	[{"id_menu":5,"count":1}]	15325	delivery	5	13
38718	2020-03-12 06:52:23	2020-03-12	9	[{"id_menu":6,"count":1}]	8888	delivery	5	14
38719	2020-03-12 06:59:35	2020-03-12	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	15385	delivery	5	39
38720	2020-03-12 07:02:22	2020-03-12	12	[{"id_menu":1,"count":1}]	5235	delivery	5	17
38721	2020-03-12 07:16:37	2020-03-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	3542	delivery	5	28
38722	2020-03-12 07:17:04	2020-03-12	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	12760	delivery	5	30
38723	2020-03-12 07:18:22	2020-03-12	8	[{"id_menu":5,"count":1}]	15353	delivery	5	13
38724	2020-03-12 07:21:37	2020-03-12	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15145	delivery	5	34
38725	2020-03-12 07:31:07	2020-03-12	12	[{"id_menu":3,"count":1}]	15387	delivery	5	17
38726	2020-03-12 07:36:32	2020-03-12	12	[{"id_menu":1,"count":1}]	9167	delivery	5	17
38727	2020-03-12 07:37:44	2020-03-12	9	[{"id_menu":6,"count":1}]	13868	delivery	5	14
38728	2020-03-12 07:53:02	2020-03-12	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15422	delivery	5	31
38729	2020-03-12 07:54:49	2020-03-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9733	delivery	5	28
38730	2020-03-12 08:12:42	2020-03-12	14	[{"id_menu":2,"count":1}]	15382	delivery	5	19
38731	2020-03-12 08:19:44	2020-03-12	26	[{"id_menu":4,"count":3},{"id_menu":6,"count":1}]	11525	delivery	5	31
38732	2020-03-12 08:21:34	2020-03-12	12	[{"id_menu":3,"count":1}]	3048	pick-up	0	12
38733	2020-03-12 08:23:19	2020-03-12	9	[{"id_menu":6,"count":1}]	15406	delivery	5	14
38734	2020-03-12 08:28:24	2020-03-12	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4021	delivery	5	34
38735	2020-03-12 08:31:30	2020-03-12	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	15367	delivery	5	25
38736	2020-03-12 08:33:44	2020-03-12	9	[{"id_menu":7,"count":1}]	1812	pick-up	0	9
38737	2020-03-12 08:38:12	2020-03-12	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2440	delivery	5	25
38738	2020-03-12 08:38:12	2020-03-12	9	[{"id_menu":6,"count":1}]	15346	delivery	5	14
38739	2020-03-12 08:39:46	2020-03-12	8	[{"id_menu":5,"count":1}]	6582	delivery	5	13
38740	2020-03-12 08:40:06	2020-03-12	9	[{"id_menu":7,"count":1}]	13794	delivery	5	14
38741	2020-03-12 08:44:50	2020-03-12	9	[{"id_menu":7,"count":1}]	15425	delivery	5	14
38742	2020-03-12 08:45:18	2020-03-12	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	15398	delivery	5	39
38743	2020-03-12 08:53:47	2020-03-12	8	[{"id_menu":5,"count":1}]	6666	pick-up	0	8
38744	2020-03-12 08:59:14	2020-03-12	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	15035	delivery	5	40
38745	2020-03-12 09:01:12	2020-03-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2653	pick-up	0	18
38746	2020-03-12 09:04:24	2020-03-12	14	[{"id_menu":2,"count":1}]	15320	delivery	5	19
38747	2020-03-12 09:06:05	2020-03-12	14	[{"id_menu":2,"count":1}]	13951	pick-up	0	14
38748	2020-03-12 09:14:13	2020-03-12	9	[{"id_menu":6,"count":1}]	5378	delivery	5	14
38749	2020-03-12 09:15:10	2020-03-12	9	[{"id_menu":7,"count":1}]	4258	delivery	5	14
38750	2020-03-12 09:20:46	2020-03-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6965	pick-up	0	17
38751	2020-03-12 09:21:56	2020-03-12	8	[{"id_menu":5,"count":1}]	5048	pick-up	0	8
38752	2020-03-12 09:26:10	2020-03-12	14	[{"id_menu":2,"count":1}]	15348	delivery	5	19
38753	2020-03-12 09:29:31	2020-03-12	8	[{"id_menu":5,"count":1}]	15435	delivery	5	13
38754	2020-03-12 09:32:31	2020-03-12	9	[{"id_menu":7,"count":1}]	15391	delivery	5	14
38755	2020-03-12 09:37:48	2020-03-12	9	[{"id_menu":7,"count":1}]	5975	delivery	5	14
38756	2020-03-12 09:38:12	2020-03-12	9	[{"id_menu":7,"count":1}]	3314	pick-up	0	9
38757	2020-03-12 09:41:30	2020-03-12	9	[{"id_menu":7,"count":1}]	15370	delivery	5	14
38758	2020-03-12 09:44:40	2020-03-12	8	[{"id_menu":5,"count":1}]	15343	delivery	5	13
38759	2020-03-12 09:53:04	2020-03-12	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	15430	delivery	5	36
38760	2020-03-12 10:03:16	2020-03-12	12	[{"id_menu":3,"count":1}]	111	delivery	5	17
38761	2020-03-12 10:03:25	2020-03-12	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10582	delivery	5	35
38762	2020-03-12 10:05:32	2020-03-12	12	[{"id_menu":1,"count":1}]	11663	delivery	5	17
38763	2020-03-12 10:07:33	2020-03-12	9	[{"id_menu":7,"count":1}]	708	pick-up	0	9
38764	2020-03-12 10:09:02	2020-03-12	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15330	delivery	5	45
38765	2020-03-12 10:14:26	2020-03-12	14	[{"id_menu":2,"count":1}]	15322	delivery	5	19
38766	2020-03-12 10:15:38	2020-03-12	9	[{"id_menu":6,"count":1}]	15244	delivery	5	14
38767	2020-03-12 10:20:33	2020-03-12	12	[{"id_menu":3,"count":1}]	584	delivery	5	17
38768	2020-03-12 10:38:44	2020-03-12	8	[{"id_menu":5,"count":1}]	8399	delivery	5	13
38769	2020-03-12 10:41:19	2020-03-12	8	[{"id_menu":5,"count":1}]	10670	delivery	5	13
38770	2020-03-12 10:43:44	2020-03-12	9	[{"id_menu":6,"count":1}]	11634	delivery	5	14
38771	2020-03-12 10:47:40	2020-03-12	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	5099	pick-up	0	26
38772	2020-03-12 10:56:38	2020-03-12	12	[{"id_menu":1,"count":1}]	4563	delivery	5	17
38773	2020-03-12 11:00:18	2020-03-12	8	[{"id_menu":5,"count":1}]	11871	delivery	5	13
38774	2020-03-12 11:05:26	2020-03-12	8	[{"id_menu":5,"count":1}]	11735	delivery	5	13
38775	2020-03-12 11:05:29	2020-03-12	12	[{"id_menu":3,"count":1}]	1795	delivery	5	17
38776	2020-03-12 11:09:38	2020-03-12	14	[{"id_menu":2,"count":1}]	618	pick-up	0	14
38777	2020-03-12 11:15:26	2020-03-12	17	[{"id_menu":4,"count":1}]	2419	delivery	5	22
38778	2020-03-12 11:15:29	2020-03-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":3}]	15429	delivery	5	22
38779	2020-03-12 11:19:25	2020-03-12	9	[{"id_menu":7,"count":1}]	3858	pick-up	0	9
38780	2020-03-12 11:19:29	2020-03-12	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1549	pick-up	0	50
38781	2020-03-12 11:31:39	2020-03-12	9	[{"id_menu":7,"count":1}]	13502	pick-up	0	9
38782	2020-03-12 11:43:05	2020-03-12	12	[{"id_menu":3,"count":1}]	15332	delivery	5	17
38783	2020-03-12 12:01:11	2020-03-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15350	delivery	5	31
38784	2020-03-12 12:03:15	2020-03-12	9	[{"id_menu":7,"count":1}]	14477	delivery	5	14
38785	2020-03-12 12:10:45	2020-03-12	9	[{"id_menu":6,"count":1}]	15356	delivery	5	14
38786	2020-03-12 12:17:17	2020-03-12	8	[{"id_menu":5,"count":1}]	15386	delivery	5	13
38787	2020-03-12 12:21:09	2020-03-12	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	15328	pick-up	0	29
38788	2020-03-12 12:27:39	2020-03-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	27	pick-up	0	26
38789	2020-03-12 12:34:02	2020-03-12	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6885	pick-up	0	17
38790	2020-03-12 12:34:11	2020-03-12	12	[{"id_menu":3,"count":1}]	15358	delivery	5	17
38791	2020-03-12 12:37:15	2020-03-12	9	[{"id_menu":6,"count":1}]	15440	pick-up	0	9
38792	2020-03-12 12:39:05	2020-03-12	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	7733	delivery	5	29
38793	2020-03-12 12:42:15	2020-03-12	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	2921	pick-up	0	20
38794	2020-03-12 13:00:50	2020-03-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	15381	pick-up	0	23
38795	2020-03-12 13:01:20	2020-03-12	8	[{"id_menu":5,"count":1}]	993	pick-up	0	8
38796	2020-03-12 13:03:20	2020-03-12	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	15334	delivery	5	28
38797	2020-03-12 13:04:45	2020-03-12	17	[{"id_menu":4,"count":1}]	15360	delivery	5	22
38798	2020-03-12 13:06:40	2020-03-12	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	5641	delivery	5	22
38799	2020-03-12 13:16:11	2020-03-12	9	[{"id_menu":6,"count":2}]	429	pick-up	0	9
38800	2020-03-12 13:21:42	2020-03-12	9	[{"id_menu":6,"count":1}]	14033	pick-up	0	9
38801	2020-03-12 13:33:51	2020-03-12	14	[{"id_menu":2,"count":1}]	15434	pick-up	0	14
38802	2020-03-12 13:37:00	2020-03-12	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9906	delivery	5	37
38803	2020-03-12 13:43:42	2020-03-12	17	[{"id_menu":4,"count":1}]	2616	delivery	5	22
38804	2020-03-12 13:43:43	2020-03-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15402	delivery	5	31
38805	2020-03-12 13:44:30	2020-03-12	9	[{"id_menu":7,"count":1}]	15437	delivery	5	14
38806	2020-03-12 13:51:37	2020-03-12	17	[{"id_menu":4,"count":1}]	3111	pick-up	0	17
38807	2020-03-12 14:14:10	2020-03-12	17	[{"id_menu":4,"count":1}]	15345	delivery	5	22
38808	2020-03-12 14:15:22	2020-03-12	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	14602	delivery	5	38
38809	2020-03-12 14:17:40	2020-03-12	9	[{"id_menu":6,"count":1}]	15420	delivery	5	14
38810	2020-03-12 14:26:33	2020-03-12	12	[{"id_menu":3,"count":1}]	15347	delivery	5	17
38811	2020-03-12 14:28:16	2020-03-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13352	delivery	5	31
38812	2020-03-12 14:28:44	2020-03-12	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15324	delivery	5	36
38813	2020-03-12 14:30:06	2020-03-12	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	15388	pick-up	0	24
38814	2020-03-12 14:34:07	2020-03-12	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10653	delivery	5	44
38815	2020-03-12 14:37:02	2020-03-12	12	[{"id_menu":1,"count":1}]	14039	delivery	5	17
38816	2020-03-12 14:44:21	2020-03-12	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	15359	delivery	5	30
38817	2020-03-12 14:47:19	2020-03-12	14	[{"id_menu":2,"count":1}]	15378	delivery	5	19
38818	2020-03-12 14:50:43	2020-03-12	12	[{"id_menu":3,"count":1}]	15326	delivery	5	17
38819	2020-03-12 14:52:23	2020-03-12	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	11146	pick-up	0	31
38820	2020-03-12 14:59:42	2020-03-12	12	[{"id_menu":3,"count":1}]	11926	pick-up	0	12
38821	2020-03-12 15:04:00	2020-03-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15349	delivery	5	22
38822	2020-03-12 15:04:30	2020-03-12	12	[{"id_menu":1,"count":1}]	2990	pick-up	0	12
38823	2020-03-12 15:05:54	2020-03-12	14	[{"id_menu":2,"count":1}]	13639	delivery	5	19
38824	2020-03-12 15:09:51	2020-03-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	11679	delivery	5	28
38825	2020-03-12 15:11:01	2020-03-12	12	[{"id_menu":1,"count":1}]	8706	pick-up	0	12
38826	2020-03-12 15:14:30	2020-03-12	12	[{"id_menu":1,"count":1}]	5875	delivery	5	17
38827	2020-03-12 15:23:31	2020-03-12	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4414	delivery	5	34
38828	2020-03-12 15:31:57	2020-03-12	12	[{"id_menu":1,"count":1}]	8312	pick-up	0	12
38829	2020-03-12 15:36:29	2020-03-12	12	[{"id_menu":1,"count":1}]	4012	delivery	5	17
38830	2020-03-12 15:47:15	2020-03-12	14	[{"id_menu":2,"count":1}]	15338	delivery	5	19
38831	2020-03-12 16:02:35	2020-03-12	9	[{"id_menu":6,"count":1}]	15333	delivery	5	14
38832	2020-03-12 16:14:53	2020-03-12	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	8224	delivery	5	34
38833	2020-03-12 16:15:03	2020-03-12	12	[{"id_menu":3,"count":1}]	15277	delivery	5	17
38834	2020-03-12 16:16:28	2020-03-12	9	[{"id_menu":7,"count":1}]	12557	delivery	5	14
38835	2020-03-12 16:16:40	2020-03-12	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	13303	delivery	5	29
38836	2020-03-12 16:17:29	2020-03-12	9	[{"id_menu":6,"count":1}]	15372	delivery	5	14
38837	2020-03-12 16:18:07	2020-03-12	14	[{"id_menu":2,"count":1}]	15395	delivery	5	19
38838	2020-03-12 16:21:49	2020-03-12	9	[{"id_menu":6,"count":1}]	2367	pick-up	0	9
38839	2020-03-12 16:35:17	2020-03-12	9	[{"id_menu":6,"count":1}]	11239	delivery	5	14
38840	2020-03-12 16:36:36	2020-03-12	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2584	pick-up	0	17
38841	2020-03-12 16:37:43	2020-03-12	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	5483	pick-up	0	38
38842	2020-03-12 16:42:33	2020-03-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10755	delivery	5	31
38843	2020-03-12 16:43:06	2020-03-12	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	15365	delivery	5	26
38844	2020-03-12 16:52:03	2020-03-12	17	[{"id_menu":4,"count":1}]	15340	pick-up	0	17
38845	2020-03-12 16:52:28	2020-03-12	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15397	delivery	5	40
38846	2020-03-12 16:55:10	2020-03-12	9	[{"id_menu":6,"count":1}]	15410	delivery	5	14
38847	2020-03-12 17:00:01	2020-03-12	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7410	delivery	5	36
38848	2020-03-12 17:00:04	2020-03-12	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12248	pick-up	0	43
38849	2020-03-12 17:01:33	2020-03-12	9	[{"id_menu":6,"count":1}]	505	pick-up	0	9
38850	2020-03-12 17:10:44	2020-03-12	9	[{"id_menu":6,"count":1}]	15344	delivery	5	14
38851	2020-03-12 17:17:07	2020-03-12	9	[{"id_menu":7,"count":1}]	15421	delivery	5	14
38852	2020-03-12 17:17:50	2020-03-12	14	[{"id_menu":2,"count":1}]	330	pick-up	0	14
38853	2020-03-12 17:19:11	2020-03-12	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	10303	delivery	5	36
38854	2020-03-12 17:23:41	2020-03-12	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	4408	delivery	5	31
38855	2020-03-12 17:26:52	2020-03-12	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	10590	delivery	5	28
38856	2020-03-12 17:27:08	2020-03-12	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10023	delivery	5	57
38857	2020-03-12 17:31:44	2020-03-12	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	12705	delivery	5	22
38858	2020-03-12 17:33:21	2020-03-12	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	13987	delivery	5	28
38859	2020-03-12 17:44:54	2020-03-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15318	delivery	5	23
38860	2020-03-12 17:54:55	2020-03-12	9	[{"id_menu":7,"count":1}]	15423	delivery	5	14
38861	2020-03-12 17:57:23	2020-03-12	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15335	delivery	5	31
38862	2020-03-12 18:01:40	2020-03-12	14	[{"id_menu":2,"count":2}]	4466	delivery	5	19
38863	2020-03-12 18:05:03	2020-03-12	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	15363	delivery	5	40
38864	2020-03-12 18:10:02	2020-03-12	9	[{"id_menu":7,"count":1}]	351	pick-up	0	9
38865	2020-03-12 18:12:18	2020-03-12	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15415	delivery	5	48
38866	2020-03-12 18:13:11	2020-03-12	8	[{"id_menu":5,"count":1}]	15418	delivery	5	13
38867	2020-03-12 18:15:34	2020-03-12	17	[{"id_menu":4,"count":1}]	2168	pick-up	0	17
38868	2020-03-12 18:19:21	2020-03-12	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	609	pick-up	0	37
38869	2020-03-12 18:21:41	2020-03-12	17	[{"id_menu":4,"count":1}]	12210	pick-up	0	17
38870	2020-03-12 18:22:04	2020-03-12	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	12590	delivery	5	46
38871	2020-03-12 18:23:52	2020-03-12	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	15419	delivery	5	28
38872	2020-03-12 18:32:47	2020-03-12	9	[{"id_menu":7,"count":1}]	15389	delivery	5	14
38873	2020-03-12 18:33:35	2020-03-12	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10295	delivery	5	22
38874	2020-03-12 18:38:33	2020-03-12	17	[{"id_menu":4,"count":1}]	1542	delivery	5	22
38875	2020-03-12 18:49:39	2020-03-12	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	6224	pick-up	0	29
38876	2020-03-12 18:58:31	2020-03-12	9	[{"id_menu":6,"count":1}]	15319	pick-up	0	9
38877	2020-03-12 18:59:43	2020-03-12	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	2523	delivery	5	29
38878	2020-03-12 19:02:42	2020-03-12	9	[{"id_menu":7,"count":1}]	8306	delivery	5	14
38879	2020-03-12 19:04:25	2020-03-12	12	[{"id_menu":1,"count":1}]	4841	pick-up	0	12
38880	2020-03-12 19:10:36	2020-03-12	9	[{"id_menu":6,"count":1}]	15185	delivery	5	14
38881	2020-03-12 19:11:08	2020-03-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8548	delivery	5	31
38882	2020-03-12 19:30:25	2020-03-12	9	[{"id_menu":7,"count":1}]	15414	delivery	5	14
38883	2020-03-12 19:32:49	2020-03-12	9	[{"id_menu":6,"count":1}]	9304	pick-up	0	9
38884	2020-03-12 19:33:37	2020-03-12	17	[{"id_menu":4,"count":2}]	13864	delivery	5	22
38885	2020-03-12 19:37:39	2020-03-12	9	[{"id_menu":7,"count":1}]	1670	pick-up	0	9
38886	2020-03-12 19:38:46	2020-03-12	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	5699	delivery	5	34
38887	2020-03-12 19:39:32	2020-03-12	14	[{"id_menu":2,"count":1}]	3659	pick-up	0	14
38888	2020-03-12 19:40:04	2020-03-12	9	[{"id_menu":7,"count":1}]	15413	delivery	5	14
38889	2020-03-12 19:43:58	2020-03-12	14	[{"id_menu":2,"count":1}]	2376	pick-up	0	14
38890	2020-03-12 19:45:34	2020-03-12	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	13429	pick-up	0	29
38891	2020-03-12 19:56:00	2020-03-12	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	14610	delivery	5	34
38892	2020-03-12 20:10:22	2020-03-12	8	[{"id_menu":5,"count":1}]	3527	delivery	5	13
38893	2020-03-12 20:17:31	2020-03-12	14	[{"id_menu":2,"count":1}]	5643	pick-up	0	14
38894	2020-03-12 20:24:39	2020-03-12	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	9795	delivery	5	26
38895	2020-03-12 20:25:25	2020-03-12	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	15329	pick-up	0	26
38896	2020-03-12 20:31:16	2020-03-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11329	delivery	5	23
38897	2020-03-12 20:36:02	2020-03-12	9	[{"id_menu":6,"count":2}]	15407	delivery	5	14
38898	2020-03-12 20:49:26	2020-03-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13128	delivery	5	31
38899	2020-03-12 20:55:29	2020-03-12	9	[{"id_menu":6,"count":1}]	13056	delivery	5	14
38900	2020-03-12 21:00:54	2020-03-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	15373	delivery	5	28
38901	2020-03-12 21:20:02	2020-03-12	12	[{"id_menu":3,"count":1}]	7571	delivery	5	17
38902	2020-03-12 21:23:16	2020-03-12	9	[{"id_menu":6,"count":1}]	15409	delivery	5	14
38903	2020-03-12 21:26:15	2020-03-12	9	[{"id_menu":7,"count":1}]	7318	delivery	5	14
38904	2020-03-12 21:28:17	2020-03-12	9	[{"id_menu":6,"count":1}]	11844	delivery	5	14
38905	2020-03-12 21:31:42	2020-03-12	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	15341	delivery	5	39
38906	2020-03-12 21:35:10	2020-03-12	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9941	pick-up	0	25
38907	2020-03-12 21:48:30	2020-03-12	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15354	delivery	5	39
38908	2020-03-12 21:58:11	2020-03-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3385	pick-up	0	26
38909	2020-03-12 22:04:22	2020-03-12	12	[{"id_menu":1,"count":1}]	4356	delivery	5	17
38910	2020-03-12 22:04:22	2020-03-12	12	[{"id_menu":3,"count":1}]	2266	delivery	5	17
38911	2020-03-12 22:07:38	2020-03-12	8	[{"id_menu":5,"count":1}]	14027	delivery	5	13
38912	2020-03-12 22:07:59	2020-03-12	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3998	delivery	5	42
38913	2020-03-12 22:13:16	2020-03-12	17	[{"id_menu":4,"count":2}]	905	delivery	5	22
38914	2020-03-12 22:22:50	2020-03-12	9	[{"id_menu":7,"count":1}]	15321	delivery	5	14
38915	2020-03-12 22:25:55	2020-03-12	9	[{"id_menu":7,"count":1}]	8199	delivery	5	14
38916	2020-03-12 22:29:31	2020-03-12	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15436	delivery	5	31
38917	2020-03-12 22:32:59	2020-03-12	12	[{"id_menu":1,"count":2}]	4139	delivery	5	17
38918	2020-03-12 22:46:27	2020-03-12	9	[{"id_menu":6,"count":1}]	15438	delivery	5	14
38919	2020-03-12 22:47:11	2020-03-12	9	[{"id_menu":6,"count":1}]	5838	delivery	5	14
38920	2020-03-12 22:47:43	2020-03-12	8	[{"id_menu":5,"count":1}]	11040	pick-up	0	8
38921	2020-03-12 22:51:33	2020-03-12	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	15417	delivery	5	22
38922	2020-03-12 23:01:10	2020-03-12	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	15394	delivery	5	30
38923	2020-03-12 23:07:36	2020-03-12	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6877	delivery	5	28
38924	2020-03-12 23:14:08	2020-03-12	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	7041	delivery	5	26
38925	2020-03-12 23:21:53	2020-03-12	8	[{"id_menu":5,"count":1}]	15369	delivery	5	13
38926	2020-03-12 23:21:58	2020-03-12	12	[{"id_menu":1,"count":1}]	15392	delivery	5	17
38927	2020-03-12 23:46:38	2020-03-12	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	6811	delivery	5	26
38928	2020-03-12 23:53:12	2020-03-12	12	[{"id_menu":1,"count":1}]	13940	delivery	5	17
38929	2020-03-12 23:58:24	2020-03-12	14	[{"id_menu":2,"count":1}]	1637	delivery	5	19
38930	2020-03-13 00:00:24	2020-03-13	9	[{"id_menu":6,"count":1}]	15487	delivery	5	14
38931	2020-03-13 00:05:33	2020-03-13	9	[{"id_menu":6,"count":1}]	5534	pick-up	0	9
38932	2020-03-13 00:12:03	2020-03-13	9	[{"id_menu":7,"count":1}]	14314	delivery	5	14
38933	2020-03-13 00:18:08	2020-03-13	9	[{"id_menu":7,"count":1}]	14226	delivery	5	14
38934	2020-03-13 00:26:17	2020-03-13	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	7947	delivery	5	26
38935	2020-03-13 00:28:21	2020-03-13	17	[{"id_menu":4,"count":1}]	15465	pick-up	0	17
38936	2020-03-13 00:30:15	2020-03-13	12	[{"id_menu":3,"count":1}]	2321	pick-up	0	12
38937	2020-03-13 00:34:13	2020-03-13	9	[{"id_menu":6,"count":2}]	2085	pick-up	0	9
38938	2020-03-13 00:39:00	2020-03-13	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2919	delivery	5	45
38939	2020-03-13 00:39:49	2020-03-13	12	[{"id_menu":3,"count":1}]	6396	delivery	5	17
38940	2020-03-13 00:40:50	2020-03-13	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8760	delivery	5	22
38941	2020-03-13 00:44:07	2020-03-13	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15456	pick-up	0	17
38942	2020-03-13 00:51:23	2020-03-13	9	[{"id_menu":7,"count":1}]	15480	delivery	5	14
38943	2020-03-13 00:52:48	2020-03-13	14	[{"id_menu":2,"count":1}]	15497	delivery	5	19
38944	2020-03-13 00:57:17	2020-03-13	12	[{"id_menu":3,"count":1}]	14764	delivery	5	17
38945	2020-03-13 00:58:35	2020-03-13	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	15457	delivery	5	25
38946	2020-03-13 00:58:36	2020-03-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15493	delivery	5	23
38947	2020-03-13 01:16:29	2020-03-13	14	[{"id_menu":2,"count":1}]	15566	pick-up	0	14
38948	2020-03-13 01:23:07	2020-03-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	15505	delivery	5	36
38949	2020-03-13 01:31:22	2020-03-13	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	15509	delivery	5	30
38950	2020-03-13 01:38:16	2020-03-13	17	[{"id_menu":4,"count":1}]	15556	delivery	5	22
38951	2020-03-13 01:38:25	2020-03-13	14	[{"id_menu":2,"count":1}]	15535	pick-up	0	14
38952	2020-03-13 01:41:16	2020-03-13	14	[{"id_menu":2,"count":1}]	12369	delivery	5	19
38953	2020-03-13 01:41:25	2020-03-13	9	[{"id_menu":6,"count":1}]	15576	delivery	5	14
38954	2020-03-13 01:42:13	2020-03-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1681	delivery	5	36
38955	2020-03-13 01:51:29	2020-03-13	8	[{"id_menu":5,"count":1}]	11005	pick-up	0	8
38956	2020-03-13 01:52:18	2020-03-13	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12636	delivery	5	45
38957	2020-03-13 01:52:33	2020-03-13	14	[{"id_menu":2,"count":1}]	12995	delivery	5	19
38958	2020-03-13 02:00:21	2020-03-13	14	[{"id_menu":2,"count":1}]	15513	delivery	5	19
38959	2020-03-13 02:01:17	2020-03-13	9	[{"id_menu":6,"count":1}]	4868	delivery	5	14
38960	2020-03-13 02:20:23	2020-03-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	8128	delivery	5	28
38961	2020-03-13 02:22:37	2020-03-13	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15477	delivery	5	31
38962	2020-03-13 02:24:11	2020-03-13	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12217	delivery	5	43
38963	2020-03-13 02:34:05	2020-03-13	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	6101	pick-up	0	21
38964	2020-03-13 02:34:39	2020-03-13	12	[{"id_menu":1,"count":1}]	15550	pick-up	0	12
38965	2020-03-13 02:39:03	2020-03-13	17	[{"id_menu":4,"count":1}]	9737	delivery	5	22
38966	2020-03-13 02:42:37	2020-03-13	9	[{"id_menu":6,"count":1}]	7399	delivery	5	14
38967	2020-03-13 02:47:19	2020-03-13	14	[{"id_menu":2,"count":1}]	8640	delivery	5	19
38968	2020-03-13 02:55:49	2020-03-13	9	[{"id_menu":6,"count":1}]	15557	delivery	5	14
38969	2020-03-13 03:22:31	2020-03-13	14	[{"id_menu":2,"count":1}]	10436	pick-up	0	14
38970	2020-03-13 03:22:40	2020-03-13	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	15475	pick-up	0	21
38971	2020-03-13 03:30:26	2020-03-13	9	[{"id_menu":7,"count":1}]	6338	delivery	5	14
38972	2020-03-13 03:37:27	2020-03-13	17	[{"id_menu":4,"count":1}]	3961	delivery	5	22
38973	2020-03-13 03:44:16	2020-03-13	9	[{"id_menu":7,"count":1}]	13656	delivery	5	14
38974	2020-03-13 03:46:51	2020-03-13	9	[{"id_menu":7,"count":1}]	9308	delivery	5	14
38975	2020-03-13 03:56:14	2020-03-13	14	[{"id_menu":2,"count":1}]	15494	delivery	5	19
38976	2020-03-13 03:56:31	2020-03-13	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":3}]	15544	delivery	5	26
38977	2020-03-13 04:02:30	2020-03-13	14	[{"id_menu":2,"count":1}]	2477	pick-up	0	14
38978	2020-03-13 04:04:08	2020-03-13	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":2}]	13283	delivery	5	22
38979	2020-03-13 04:05:34	2020-03-13	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15539	delivery	5	31
38980	2020-03-13 04:08:10	2020-03-13	17	[{"id_menu":4,"count":1}]	11390	pick-up	0	17
38981	2020-03-13 04:13:01	2020-03-13	14	[{"id_menu":2,"count":1}]	10810	delivery	5	19
38982	2020-03-13 04:15:08	2020-03-13	12	[{"id_menu":1,"count":1}]	3780	pick-up	0	12
38983	2020-03-13 04:17:15	2020-03-13	14	[{"id_menu":2,"count":1}]	15527	pick-up	0	14
38984	2020-03-13 04:23:33	2020-03-13	9	[{"id_menu":7,"count":1}]	15492	delivery	5	14
38985	2020-03-13 04:28:18	2020-03-13	9	[{"id_menu":7,"count":1}]	3321	delivery	5	14
38986	2020-03-13 04:43:50	2020-03-13	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10646	delivery	5	35
38987	2020-03-13 04:46:12	2020-03-13	14	[{"id_menu":2,"count":1}]	12092	delivery	5	19
38988	2020-03-13 04:51:36	2020-03-13	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	3604	pick-up	0	31
38989	2020-03-13 04:52:35	2020-03-13	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	11254	delivery	5	45
38990	2020-03-13 04:53:23	2020-03-13	12	[{"id_menu":1,"count":1}]	174	delivery	5	17
38991	2020-03-13 04:54:35	2020-03-13	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4967	delivery	5	34
38992	2020-03-13 04:55:16	2020-03-13	12	[{"id_menu":3,"count":1}]	4453	pick-up	0	12
38993	2020-03-13 04:58:22	2020-03-13	9	[{"id_menu":6,"count":1}]	9462	delivery	5	14
38994	2020-03-13 04:59:14	2020-03-13	17	[{"id_menu":4,"count":1}]	15458	delivery	5	22
38995	2020-03-13 05:01:00	2020-03-13	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4008	delivery	5	40
38996	2020-03-13 05:03:33	2020-03-13	9	[{"id_menu":6,"count":1}]	15529	delivery	5	14
38997	2020-03-13 05:05:33	2020-03-13	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	15520	delivery	5	37
38998	2020-03-13 05:05:42	2020-03-13	14	[{"id_menu":2,"count":1}]	5571	delivery	5	19
38999	2020-03-13 05:05:57	2020-03-13	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4938	delivery	5	43
39000	2020-03-13 05:12:25	2020-03-13	8	[{"id_menu":5,"count":1}]	8183	delivery	5	13
39001	2020-03-13 05:13:41	2020-03-13	12	[{"id_menu":1,"count":1}]	9603	pick-up	0	12
39002	2020-03-13 05:24:53	2020-03-13	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	903	delivery	5	26
39003	2020-03-13 05:38:08	2020-03-13	12	[{"id_menu":1,"count":1}]	15461	delivery	5	17
39004	2020-03-13 05:47:26	2020-03-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7772	delivery	5	28
39005	2020-03-13 05:53:00	2020-03-13	9	[{"id_menu":7,"count":1}]	9633	delivery	5	14
39006	2020-03-13 05:53:14	2020-03-13	9	[{"id_menu":6,"count":1}]	15530	delivery	5	14
39007	2020-03-13 05:57:41	2020-03-13	17	[{"id_menu":4,"count":1}]	15449	pick-up	0	17
39008	2020-03-13 05:58:12	2020-03-13	8	[{"id_menu":5,"count":1}]	15490	delivery	5	13
39009	2020-03-13 05:59:20	2020-03-13	9	[{"id_menu":7,"count":1}]	11148	delivery	5	14
39010	2020-03-13 06:02:11	2020-03-13	14	[{"id_menu":2,"count":1}]	677	pick-up	0	14
39011	2020-03-13 06:06:23	2020-03-13	17	[{"id_menu":4,"count":1}]	11263	delivery	5	22
39012	2020-03-13 06:07:09	2020-03-13	12	[{"id_menu":1,"count":1}]	15503	delivery	5	17
39013	2020-03-13 06:07:49	2020-03-13	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	11563	delivery	5	26
39014	2020-03-13 06:20:49	2020-03-13	12	[{"id_menu":1,"count":1}]	12286	delivery	5	17
39015	2020-03-13 06:40:56	2020-03-13	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	15482	pick-up	0	21
39016	2020-03-13 06:55:54	2020-03-13	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	15488	delivery	5	26
39017	2020-03-13 06:57:52	2020-03-13	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11479	delivery	5	37
39018	2020-03-13 06:59:25	2020-03-13	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13911	delivery	5	55
39019	2020-03-13 07:04:12	2020-03-13	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15553	delivery	5	47
39020	2020-03-13 07:05:03	2020-03-13	12	[{"id_menu":1,"count":2}]	7882	delivery	5	17
39021	2020-03-13 07:07:37	2020-03-13	14	[{"id_menu":2,"count":1}]	6069	delivery	5	19
39022	2020-03-13 07:08:31	2020-03-13	17	[{"id_menu":4,"count":1}]	15442	delivery	5	22
39023	2020-03-13 07:13:33	2020-03-13	8	[{"id_menu":5,"count":1}]	15537	pick-up	0	8
39024	2020-03-13 07:20:18	2020-03-13	37	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1834	pick-up	0	37
39025	2020-03-13 07:24:49	2020-03-13	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	12345	delivery	5	39
39026	2020-03-13 07:29:31	2020-03-13	12	[{"id_menu":3,"count":1}]	15517	delivery	5	17
39027	2020-03-13 07:41:04	2020-03-13	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	5278	delivery	5	34
39028	2020-03-13 07:49:35	2020-03-13	14	[{"id_menu":2,"count":1}]	12506	pick-up	0	14
39029	2020-03-13 07:54:51	2020-03-13	12	[{"id_menu":1,"count":1}]	15473	pick-up	0	12
39030	2020-03-13 08:00:47	2020-03-13	9	[{"id_menu":6,"count":1}]	15451	delivery	5	14
39031	2020-03-13 08:01:02	2020-03-13	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	9738	delivery	5	25
39032	2020-03-13 08:02:43	2020-03-13	9	[{"id_menu":6,"count":1}]	5155	delivery	5	14
39033	2020-03-13 08:09:11	2020-03-13	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15533	delivery	5	22
39034	2020-03-13 08:10:15	2020-03-13	12	[{"id_menu":3,"count":1}]	3971	pick-up	0	12
39035	2020-03-13 08:15:50	2020-03-13	12	[{"id_menu":1,"count":1}]	11056	pick-up	0	12
39036	2020-03-13 08:20:03	2020-03-13	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15201	delivery	5	45
39037	2020-03-13 08:24:23	2020-03-13	14	[{"id_menu":2,"count":1}]	15495	delivery	5	19
39038	2020-03-13 08:27:17	2020-03-13	9	[{"id_menu":6,"count":1}]	6174	delivery	5	14
39039	2020-03-13 08:37:24	2020-03-13	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5888	delivery	5	36
39040	2020-03-13 08:38:41	2020-03-13	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	15470	delivery	5	26
39041	2020-03-13 08:39:20	2020-03-13	14	[{"id_menu":2,"count":1}]	9043	pick-up	0	14
39042	2020-03-13 08:40:48	2020-03-13	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8963	delivery	5	48
39043	2020-03-13 08:44:53	2020-03-13	8	[{"id_menu":5,"count":1}]	9996	delivery	5	13
39044	2020-03-13 08:50:48	2020-03-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4825	delivery	5	36
39045	2020-03-13 08:55:15	2020-03-13	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	590	delivery	5	31
39046	2020-03-13 08:56:20	2020-03-13	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	15565	pick-up	0	41
39047	2020-03-13 09:00:03	2020-03-13	12	[{"id_menu":3,"count":1}]	11652	delivery	5	17
39048	2020-03-13 09:15:26	2020-03-13	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	11101	delivery	5	27
39049	2020-03-13 09:19:44	2020-03-13	9	[{"id_menu":7,"count":1}]	15525	delivery	5	14
39050	2020-03-13 09:22:55	2020-03-13	8	[{"id_menu":5,"count":1}]	2517	delivery	5	13
39051	2020-03-13 09:28:39	2020-03-13	12	[{"id_menu":1,"count":1}]	14488	delivery	5	17
39052	2020-03-13 09:31:54	2020-03-13	17	[{"id_menu":4,"count":1}]	15454	delivery	5	22
39053	2020-03-13 09:34:11	2020-03-13	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	5160	pick-up	0	20
39054	2020-03-13 09:51:30	2020-03-13	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	10828	pick-up	0	21
39055	2020-03-13 09:51:49	2020-03-13	9	[{"id_menu":7,"count":2}]	7125	delivery	5	14
39056	2020-03-13 09:54:02	2020-03-13	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	15478	delivery	5	26
39057	2020-03-13 09:55:36	2020-03-13	9	[{"id_menu":6,"count":1}]	15523	delivery	5	14
39058	2020-03-13 10:02:01	2020-03-13	9	[{"id_menu":6,"count":1}]	10499	delivery	5	14
39059	2020-03-13 10:05:59	2020-03-13	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	3296	pick-up	0	26
39060	2020-03-13 10:08:05	2020-03-13	17	[{"id_menu":4,"count":2}]	15447	delivery	5	22
39061	2020-03-13 10:09:40	2020-03-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5419	pick-up	0	18
39062	2020-03-13 10:14:33	2020-03-13	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	4732	delivery	5	31
39063	2020-03-13 10:16:14	2020-03-13	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13038	delivery	5	22
39064	2020-03-13 10:27:39	2020-03-13	9	[{"id_menu":6,"count":1}]	15538	delivery	5	14
39065	2020-03-13 10:41:06	2020-03-13	9	[{"id_menu":7,"count":1}]	2510	delivery	5	14
39066	2020-03-13 10:50:25	2020-03-13	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	15489	delivery	5	22
39067	2020-03-13 10:54:02	2020-03-13	9	[{"id_menu":7,"count":1}]	1461	delivery	5	14
39068	2020-03-13 11:12:58	2020-03-13	9	[{"id_menu":7,"count":1}]	15547	pick-up	0	9
39069	2020-03-13 11:16:29	2020-03-13	9	[{"id_menu":7,"count":1}]	15500	delivery	5	14
39070	2020-03-13 11:17:23	2020-03-13	12	[{"id_menu":1,"count":1}]	11744	delivery	5	17
39071	2020-03-13 11:19:01	2020-03-13	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	15541	delivery	5	26
39072	2020-03-13 11:21:18	2020-03-13	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11383	pick-up	0	26
39073	2020-03-13 11:24:00	2020-03-13	9	[{"id_menu":7,"count":1}]	15572	pick-up	0	9
39074	2020-03-13 11:28:18	2020-03-13	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	13559	delivery	5	40
39075	2020-03-13 11:31:21	2020-03-13	17	[{"id_menu":4,"count":1}]	15564	delivery	5	22
39076	2020-03-13 11:34:55	2020-03-13	17	[{"id_menu":4,"count":1}]	2737	pick-up	0	17
39077	2020-03-13 11:35:46	2020-03-13	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	15445	delivery	5	38
39078	2020-03-13 11:37:56	2020-03-13	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	15464	delivery	5	26
39079	2020-03-13 12:04:17	2020-03-13	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1790	delivery	5	31
39080	2020-03-13 12:06:08	2020-03-13	17	[{"id_menu":4,"count":1}]	2497	pick-up	0	17
39081	2020-03-13 12:08:03	2020-03-13	12	[{"id_menu":1,"count":1}]	2367	delivery	5	17
39082	2020-03-13 12:16:54	2020-03-13	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	4215	delivery	5	26
39083	2020-03-13 12:21:46	2020-03-13	8	[{"id_menu":5,"count":1}]	3688	delivery	5	13
39084	2020-03-13 12:21:51	2020-03-13	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	197	pick-up	0	21
39085	2020-03-13 12:24:12	2020-03-13	17	[{"id_menu":4,"count":1}]	10480	pick-up	0	17
39086	2020-03-13 12:26:03	2020-03-13	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	5109	delivery	5	40
39087	2020-03-13 12:29:16	2020-03-13	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	7083	pick-up	0	25
39088	2020-03-13 12:35:03	2020-03-13	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	9145	delivery	5	31
39089	2020-03-13 12:50:01	2020-03-13	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	6851	delivery	5	26
39090	2020-03-13 12:54:22	2020-03-13	14	[{"id_menu":2,"count":2}]	292	delivery	5	19
39091	2020-03-13 13:00:43	2020-03-13	9	[{"id_menu":7,"count":1}]	13522	pick-up	0	9
39092	2020-03-13 13:02:56	2020-03-13	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	10763	delivery	5	26
39093	2020-03-13 13:11:19	2020-03-13	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15452	delivery	5	31
39094	2020-03-13 13:43:54	2020-03-13	9	[{"id_menu":7,"count":1}]	6853	delivery	5	14
39095	2020-03-13 13:48:33	2020-03-13	17	[{"id_menu":4,"count":1}]	4973	delivery	5	22
39096	2020-03-13 14:03:30	2020-03-13	17	[{"id_menu":4,"count":1}]	2779	delivery	5	22
39097	2020-03-13 14:07:12	2020-03-13	17	[{"id_menu":4,"count":1}]	9420	pick-up	0	17
39098	2020-03-13 14:10:20	2020-03-13	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15554	delivery	5	43
39099	2020-03-13 14:14:41	2020-03-13	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	15546	delivery	5	26
39100	2020-03-13 14:19:13	2020-03-13	9	[{"id_menu":6,"count":2}]	4122	pick-up	0	9
39101	2020-03-13 14:19:17	2020-03-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3770	pick-up	0	31
39102	2020-03-13 14:20:49	2020-03-13	14	[{"id_menu":2,"count":1}]	8669	delivery	5	19
39103	2020-03-13 14:32:24	2020-03-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10908	delivery	5	23
39104	2020-03-13 14:41:29	2020-03-13	12	[{"id_menu":1,"count":1}]	12527	pick-up	0	12
39105	2020-03-13 14:47:31	2020-03-13	12	[{"id_menu":1,"count":1}]	8313	delivery	5	17
39106	2020-03-13 14:53:29	2020-03-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	15486	pick-up	0	31
39107	2020-03-13 14:53:45	2020-03-13	14	[{"id_menu":2,"count":1}]	4536	pick-up	0	14
39108	2020-03-13 14:56:58	2020-03-13	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	15549	delivery	5	39
39109	2020-03-13 14:59:42	2020-03-13	12	[{"id_menu":3,"count":1}]	15575	delivery	5	17
39110	2020-03-13 15:00:04	2020-03-13	9	[{"id_menu":6,"count":1}]	2392	pick-up	0	9
39111	2020-03-13 15:11:00	2020-03-13	12	[{"id_menu":1,"count":1}]	6282	pick-up	0	12
39112	2020-03-13 15:12:27	2020-03-13	12	[{"id_menu":1,"count":1}]	161	pick-up	0	12
39113	2020-03-13 15:13:24	2020-03-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	507	delivery	5	36
39114	2020-03-13 15:20:46	2020-03-13	8	[{"id_menu":5,"count":1}]	15455	delivery	5	13
39115	2020-03-13 15:21:14	2020-03-13	9	[{"id_menu":6,"count":1}]	7283	delivery	5	14
39116	2020-03-13 15:33:43	2020-03-13	17	[{"id_menu":4,"count":1}]	13218	delivery	5	22
39117	2020-03-13 15:39:11	2020-03-13	8	[{"id_menu":5,"count":1}]	15448	delivery	5	13
39118	2020-03-13 15:43:40	2020-03-13	9	[{"id_menu":7,"count":1}]	15362	delivery	5	14
39119	2020-03-13 15:47:11	2020-03-13	12	[{"id_menu":1,"count":1}]	2654	delivery	5	17
39120	2020-03-13 15:49:00	2020-03-13	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	13790	delivery	5	22
39121	2020-03-13 16:02:18	2020-03-13	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3931	pick-up	0	26
39122	2020-03-13 16:04:28	2020-03-13	12	[{"id_menu":3,"count":1}]	7744	delivery	5	17
39123	2020-03-13 16:28:39	2020-03-13	14	[{"id_menu":2,"count":1}]	11891	delivery	5	19
39124	2020-03-13 16:29:27	2020-03-13	17	[{"id_menu":4,"count":1}]	14239	pick-up	0	17
39125	2020-03-13 16:31:21	2020-03-13	9	[{"id_menu":6,"count":1}]	15462	delivery	5	14
39126	2020-03-13 16:33:33	2020-03-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	15496	delivery	5	36
39127	2020-03-13 16:39:31	2020-03-13	9	[{"id_menu":6,"count":1}]	15474	delivery	5	14
39128	2020-03-13 16:49:46	2020-03-13	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15484	delivery	5	52
39129	2020-03-13 16:57:09	2020-03-13	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15563	delivery	5	34
39130	2020-03-13 17:02:05	2020-03-13	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15531	delivery	5	57
39131	2020-03-13 17:02:43	2020-03-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	14316	delivery	5	36
39132	2020-03-13 17:03:38	2020-03-13	14	[{"id_menu":2,"count":1}]	4238	pick-up	0	14
39133	2020-03-13 17:04:59	2020-03-13	8	[{"id_menu":5,"count":1}]	2051	pick-up	0	8
39134	2020-03-13 17:10:22	2020-03-13	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1656	delivery	5	31
39135	2020-03-13 17:39:29	2020-03-13	9	[{"id_menu":7,"count":1}]	6384	delivery	5	14
39136	2020-03-13 17:56:47	2020-03-13	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15472	delivery	5	43
39137	2020-03-13 18:07:28	2020-03-13	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	508	delivery	5	22
39138	2020-03-13 18:15:11	2020-03-13	9	[{"id_menu":7,"count":1}]	3562	delivery	5	14
39139	2020-03-13 18:48:01	2020-03-13	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	6886	delivery	5	40
39140	2020-03-13 18:54:19	2020-03-13	17	[{"id_menu":4,"count":1}]	10479	pick-up	0	17
39141	2020-03-13 18:54:27	2020-03-13	9	[{"id_menu":6,"count":1}]	7142	delivery	5	14
39142	2020-03-13 18:54:44	2020-03-13	14	[{"id_menu":2,"count":1}]	1493	pick-up	0	14
39143	2020-03-13 18:58:45	2020-03-13	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	15504	delivery	5	26
39144	2020-03-13 19:07:06	2020-03-13	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	15479	delivery	5	39
39145	2020-03-13 19:07:20	2020-03-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	15545	pick-up	0	31
39146	2020-03-13 19:11:05	2020-03-13	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15466	delivery	5	36
39147	2020-03-13 19:14:03	2020-03-13	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	5094	pick-up	0	29
39148	2020-03-13 19:15:07	2020-03-13	14	[{"id_menu":2,"count":1}]	3579	delivery	5	19
39149	2020-03-13 19:15:23	2020-03-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5329	delivery	5	23
39150	2020-03-13 19:16:41	2020-03-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	15441	delivery	5	28
39151	2020-03-13 19:26:00	2020-03-13	17	[{"id_menu":4,"count":1}]	15518	pick-up	0	17
39152	2020-03-13 19:28:04	2020-03-13	12	[{"id_menu":1,"count":1}]	2349	pick-up	0	12
39153	2020-03-13 19:33:57	2020-03-13	14	[{"id_menu":2,"count":1}]	2594	delivery	5	19
39154	2020-03-13 19:35:26	2020-03-13	9	[{"id_menu":7,"count":2}]	15536	delivery	5	14
39155	2020-03-13 19:35:29	2020-03-13	14	[{"id_menu":2,"count":1}]	4827	delivery	5	19
39156	2020-03-13 19:36:28	2020-03-13	9	[{"id_menu":6,"count":1}]	13276	delivery	5	14
39157	2020-03-13 19:39:42	2020-03-13	12	[{"id_menu":1,"count":1}]	2511	pick-up	0	12
39158	2020-03-13 19:48:53	2020-03-13	12	[{"id_menu":1,"count":1}]	1042	pick-up	0	12
39159	2020-03-13 20:07:53	2020-03-13	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	15498	delivery	5	26
39160	2020-03-13 20:30:26	2020-03-13	9	[{"id_menu":7,"count":1}]	11052	delivery	5	14
39161	2020-03-13 20:32:46	2020-03-13	9	[{"id_menu":6,"count":1}]	15532	delivery	5	14
39162	2020-03-13 20:37:05	2020-03-13	12	[{"id_menu":1,"count":1}]	6479	pick-up	0	12
39163	2020-03-13 20:38:24	2020-03-13	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	9450	delivery	5	25
39164	2020-03-13 20:56:28	2020-03-13	9	[{"id_menu":6,"count":3}]	15568	delivery	5	14
39165	2020-03-13 21:03:40	2020-03-13	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	15476	delivery	5	31
39166	2020-03-13 21:07:27	2020-03-13	9	[{"id_menu":6,"count":1}]	12344	delivery	5	14
39167	2020-03-13 21:22:01	2020-03-13	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	15453	delivery	5	26
39168	2020-03-13 21:27:00	2020-03-13	17	[{"id_menu":4,"count":1}]	7235	pick-up	0	17
39169	2020-03-13 21:45:48	2020-03-13	14	[{"id_menu":2,"count":1}]	4546	pick-up	0	14
39170	2020-03-13 21:46:14	2020-03-13	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	14281	delivery	5	34
39171	2020-03-13 21:49:30	2020-03-13	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	15569	delivery	5	30
39172	2020-03-13 21:50:20	2020-03-13	9	[{"id_menu":6,"count":1}]	10621	delivery	5	14
39173	2020-03-13 21:51:27	2020-03-13	12	[{"id_menu":1,"count":1}]	2138	delivery	5	17
39174	2020-03-13 21:59:25	2020-03-13	9	[{"id_menu":7,"count":1}]	3097	delivery	5	14
39175	2020-03-13 22:00:07	2020-03-13	17	[{"id_menu":4,"count":1}]	9728	pick-up	0	17
39176	2020-03-13 22:06:31	2020-03-13	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1375	pick-up	0	21
39177	2020-03-13 22:11:53	2020-03-13	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	15534	delivery	5	40
39178	2020-03-13 22:15:03	2020-03-13	12	[{"id_menu":3,"count":1}]	15528	pick-up	0	12
39179	2020-03-13 22:16:55	2020-03-13	14	[{"id_menu":2,"count":2}]	4685	pick-up	0	14
39180	2020-03-13 22:22:31	2020-03-13	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	15558	delivery	5	34
39181	2020-03-13 22:24:02	2020-03-13	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":3}]	15499	delivery	5	31
39182	2020-03-13 22:24:59	2020-03-13	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15491	delivery	5	34
39183	2020-03-13 22:26:51	2020-03-13	9	[{"id_menu":7,"count":1}]	6929	pick-up	0	9
39184	2020-03-13 22:38:50	2020-03-13	12	[{"id_menu":3,"count":1}]	7046	delivery	5	17
39185	2020-03-13 22:42:24	2020-03-13	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	13892	delivery	5	27
39186	2020-03-13 22:50:16	2020-03-13	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	135	delivery	5	43
39187	2020-03-13 22:50:47	2020-03-13	17	[{"id_menu":4,"count":1}]	48	pick-up	0	17
39188	2020-03-13 22:51:47	2020-03-13	14	[{"id_menu":2,"count":1}]	14497	delivery	5	19
39189	2020-03-13 22:54:39	2020-03-13	9	[{"id_menu":6,"count":1}]	15555	pick-up	0	9
39190	2020-03-13 23:00:03	2020-03-13	12	[{"id_menu":3,"count":1}]	15552	delivery	5	17
39191	2020-03-13 23:02:10	2020-03-13	9	[{"id_menu":6,"count":1}]	9688	delivery	5	14
39192	2020-03-13 23:05:40	2020-03-13	9	[{"id_menu":6,"count":1}]	15506	delivery	5	14
39193	2020-03-13 23:05:58	2020-03-13	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	15514	delivery	5	31
39194	2020-03-13 23:14:03	2020-03-13	9	[{"id_menu":6,"count":1}]	9991	delivery	5	14
39195	2020-03-13 23:16:17	2020-03-13	12	[{"id_menu":1,"count":1}]	1390	delivery	5	17
39196	2020-03-13 23:17:14	2020-03-13	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15562	delivery	5	22
39197	2020-03-13 23:23:47	2020-03-13	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15573	delivery	5	49
39198	2020-03-13 23:26:28	2020-03-13	8	[{"id_menu":5,"count":1}]	15018	delivery	5	13
39199	2020-03-13 23:33:59	2020-03-13	12	[{"id_menu":3,"count":1}]	15501	delivery	5	17
39200	2020-03-13 23:37:42	2020-03-13	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3135	delivery	5	34
39201	2020-03-13 23:46:43	2020-03-13	17	[{"id_menu":4,"count":1}]	12942	delivery	5	22
39202	2020-03-13 23:48:10	2020-03-13	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	13837	pick-up	0	23
39203	2020-03-13 23:52:33	2020-03-13	9	[{"id_menu":7,"count":1}]	1015	pick-up	0	9
39204	2020-03-13 23:52:37	2020-03-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	8448	pick-up	0	23
39205	2020-03-14 00:01:39	2020-03-14	8	[{"id_menu":5,"count":1}]	599	delivery	5	13
39206	2020-03-14 00:01:52	2020-03-14	9	[{"id_menu":7,"count":1}]	15580	delivery	5	14
39207	2020-03-14 00:06:13	2020-03-14	8	[{"id_menu":5,"count":1}]	15676	delivery	5	13
39208	2020-03-14 00:06:36	2020-03-14	12	[{"id_menu":1,"count":1}]	3780	pick-up	0	12
39209	2020-03-14 00:11:40	2020-03-14	9	[{"id_menu":6,"count":1}]	5318	pick-up	0	9
39210	2020-03-14 00:12:31	2020-03-14	14	[{"id_menu":2,"count":1}]	314	pick-up	0	14
39211	2020-03-14 00:20:36	2020-03-14	14	[{"id_menu":2,"count":1}]	15664	delivery	5	19
39212	2020-03-14 00:25:00	2020-03-14	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	4060	delivery	5	25
39213	2020-03-14 00:30:17	2020-03-14	17	[{"id_menu":4,"count":1}]	15615	delivery	5	22
39214	2020-03-14 00:33:06	2020-03-14	17	[{"id_menu":4,"count":1}]	15627	delivery	5	22
39215	2020-03-14 00:38:10	2020-03-14	9	[{"id_menu":6,"count":1}]	15685	delivery	5	14
39216	2020-03-14 00:38:54	2020-03-14	14	[{"id_menu":2,"count":2}]	784	pick-up	0	14
39217	2020-03-14 00:39:28	2020-03-14	9	[{"id_menu":6,"count":1}]	13528	pick-up	0	9
39218	2020-03-14 00:40:16	2020-03-14	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	12732	delivery	5	23
39219	2020-03-14 00:40:31	2020-03-14	12	[{"id_menu":3,"count":1}]	9253	pick-up	0	12
39220	2020-03-14 00:40:33	2020-03-14	9	[{"id_menu":6,"count":1}]	7672	delivery	5	14
39221	2020-03-14 00:44:11	2020-03-14	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15586	delivery	5	36
39222	2020-03-14 00:47:07	2020-03-14	12	[{"id_menu":3,"count":1}]	4252	delivery	5	17
39223	2020-03-14 01:00:32	2020-03-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	11955	delivery	5	28
39224	2020-03-14 01:01:11	2020-03-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9431	pick-up	0	23
39225	2020-03-14 01:03:03	2020-03-14	12	[{"id_menu":1,"count":1}]	15702	delivery	5	17
39226	2020-03-14 01:08:15	2020-03-14	9	[{"id_menu":7,"count":1}]	9103	delivery	5	14
39227	2020-03-14 01:09:06	2020-03-14	9	[{"id_menu":6,"count":1}]	14017	delivery	5	14
39228	2020-03-14 01:09:54	2020-03-14	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	15724	delivery	5	34
39229	2020-03-14 01:11:38	2020-03-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	15684	delivery	5	28
39230	2020-03-14 01:12:01	2020-03-14	9	[{"id_menu":6,"count":1}]	15683	pick-up	0	9
39231	2020-03-14 01:12:29	2020-03-14	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5550	delivery	5	48
39232	2020-03-14 01:16:45	2020-03-14	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	15648	delivery	5	30
39233	2020-03-14 01:17:31	2020-03-14	9	[{"id_menu":6,"count":1}]	2730	delivery	5	14
39234	2020-03-14 01:21:38	2020-03-14	9	[{"id_menu":6,"count":1}]	8012	delivery	5	14
39235	2020-03-14 01:22:29	2020-03-14	17	[{"id_menu":4,"count":1}]	10807	pick-up	0	17
39236	2020-03-14 01:23:47	2020-03-14	17	[{"id_menu":4,"count":1}]	15731	pick-up	0	17
39237	2020-03-14 01:24:48	2020-03-14	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9523	pick-up	0	39
39238	2020-03-14 01:27:46	2020-03-14	17	[{"id_menu":4,"count":1}]	4005	pick-up	0	17
39239	2020-03-14 01:28:16	2020-03-14	12	[{"id_menu":1,"count":1}]	15650	delivery	5	17
39240	2020-03-14 01:29:46	2020-03-14	9	[{"id_menu":6,"count":1}]	885	pick-up	0	9
39241	2020-03-14 01:32:17	2020-03-14	17	[{"id_menu":4,"count":1}]	9891	delivery	5	22
39242	2020-03-14 01:33:54	2020-03-14	9	[{"id_menu":6,"count":1}]	15612	delivery	5	14
39243	2020-03-14 01:35:26	2020-03-14	9	[{"id_menu":7,"count":1}]	15733	delivery	5	14
39244	2020-03-14 01:36:03	2020-03-14	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	3943	delivery	5	38
39245	2020-03-14 01:39:29	2020-03-14	9	[{"id_menu":7,"count":1}]	15713	delivery	5	14
39246	2020-03-14 01:41:08	2020-03-14	8	[{"id_menu":5,"count":1}]	3468	delivery	5	13
39247	2020-03-14 01:42:37	2020-03-14	9	[{"id_menu":7,"count":1}]	2475	delivery	5	14
39248	2020-03-14 01:44:15	2020-03-14	12	[{"id_menu":1,"count":1}]	15672	delivery	5	17
39249	2020-03-14 01:44:30	2020-03-14	9	[{"id_menu":6,"count":1}]	11238	delivery	5	14
39250	2020-03-14 01:46:41	2020-03-14	14	[{"id_menu":2,"count":1}]	8180	delivery	5	19
39251	2020-03-14 01:49:40	2020-03-14	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15656	delivery	5	35
39252	2020-03-14 01:52:45	2020-03-14	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	15585	delivery	5	40
39253	2020-03-14 01:54:03	2020-03-14	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15577	delivery	5	43
39254	2020-03-14 02:00:24	2020-03-14	9	[{"id_menu":6,"count":2}]	15647	delivery	5	14
39255	2020-03-14 02:03:12	2020-03-14	14	[{"id_menu":2,"count":1}]	9575	pick-up	0	14
39256	2020-03-14 02:05:49	2020-03-14	8	[{"id_menu":5,"count":1}]	6070	pick-up	0	8
39257	2020-03-14 02:11:16	2020-03-14	12	[{"id_menu":1,"count":1}]	3852	pick-up	0	12
39258	2020-03-14 02:16:18	2020-03-14	8	[{"id_menu":5,"count":1}]	3385	delivery	5	13
39259	2020-03-14 02:17:17	2020-03-14	8	[{"id_menu":5,"count":1}]	15607	delivery	5	13
39260	2020-03-14 02:21:30	2020-03-14	14	[{"id_menu":2,"count":1}]	767	delivery	5	19
39261	2020-03-14 02:21:30	2020-03-14	9	[{"id_menu":7,"count":1}]	9011	delivery	5	14
39262	2020-03-14 02:26:02	2020-03-14	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	11694	delivery	5	40
39263	2020-03-14 02:27:54	2020-03-14	8	[{"id_menu":5,"count":2}]	4413	delivery	5	13
39264	2020-03-14 02:29:28	2020-03-14	9	[{"id_menu":7,"count":1}]	11534	pick-up	0	9
39265	2020-03-14 02:31:10	2020-03-14	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7387	delivery	5	43
39266	2020-03-14 02:39:28	2020-03-14	14	[{"id_menu":2,"count":1}]	6798	delivery	5	19
39267	2020-03-14 02:42:17	2020-03-14	17	[{"id_menu":4,"count":1}]	11191	pick-up	0	17
39268	2020-03-14 02:42:23	2020-03-14	14	[{"id_menu":2,"count":1}]	2287	delivery	5	19
39269	2020-03-14 02:45:14	2020-03-14	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15670	delivery	5	45
39270	2020-03-14 02:51:44	2020-03-14	8	[{"id_menu":5,"count":1}]	9934	delivery	5	13
39271	2020-03-14 02:54:23	2020-03-14	9	[{"id_menu":6,"count":1}]	4677	delivery	5	14
39272	2020-03-14 02:55:48	2020-03-14	8	[{"id_menu":5,"count":1}]	15708	delivery	5	13
39273	2020-03-14 03:08:05	2020-03-14	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	4195	pick-up	0	21
39274	2020-03-14 03:08:13	2020-03-14	8	[{"id_menu":5,"count":1}]	10417	delivery	5	13
39275	2020-03-14 03:13:42	2020-03-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12169	delivery	5	22
39276	2020-03-14 03:17:50	2020-03-14	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2007	pick-up	0	18
39277	2020-03-14 03:18:58	2020-03-14	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	15604	delivery	5	26
39278	2020-03-14 03:21:41	2020-03-14	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15668	delivery	5	43
39279	2020-03-14 03:23:56	2020-03-14	9	[{"id_menu":7,"count":1}]	15679	delivery	5	14
39280	2020-03-14 03:28:06	2020-03-14	14	[{"id_menu":2,"count":1}]	3529	pick-up	0	14
39281	2020-03-14 03:28:34	2020-03-14	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	419	delivery	5	40
39282	2020-03-14 03:33:12	2020-03-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15589	delivery	5	22
39283	2020-03-14 03:33:14	2020-03-14	9	[{"id_menu":6,"count":1}]	15697	delivery	5	14
39284	2020-03-14 03:34:34	2020-03-14	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3634	pick-up	0	23
39285	2020-03-14 03:38:25	2020-03-14	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15691	delivery	5	35
39286	2020-03-14 03:39:32	2020-03-14	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	12285	pick-up	0	33
39287	2020-03-14 03:42:28	2020-03-14	17	[{"id_menu":4,"count":1}]	1149	delivery	5	22
39288	2020-03-14 03:46:41	2020-03-14	9	[{"id_menu":6,"count":1}]	15660	delivery	5	14
39289	2020-03-14 03:47:46	2020-03-14	17	[{"id_menu":4,"count":1}]	617	delivery	5	22
39290	2020-03-14 03:48:14	2020-03-14	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15591	delivery	5	40
39291	2020-03-14 03:49:45	2020-03-14	12	[{"id_menu":1,"count":1}]	3431	delivery	5	17
39292	2020-03-14 03:52:15	2020-03-14	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	15603	delivery	5	22
39293	2020-03-14 03:56:00	2020-03-14	14	[{"id_menu":2,"count":1}]	15598	delivery	5	19
39294	2020-03-14 03:59:56	2020-03-14	14	[{"id_menu":2,"count":1}]	10859	pick-up	0	14
39295	2020-03-14 04:10:34	2020-03-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11045	delivery	5	31
39296	2020-03-14 04:21:10	2020-03-14	14	[{"id_menu":2,"count":1}]	1289	pick-up	0	14
39297	2020-03-14 04:22:20	2020-03-14	12	[{"id_menu":1,"count":1}]	15688	pick-up	0	12
39298	2020-03-14 04:35:01	2020-03-14	14	[{"id_menu":2,"count":2}]	8899	pick-up	0	14
39299	2020-03-14 04:39:13	2020-03-14	14	[{"id_menu":2,"count":1}]	12182	delivery	5	19
39300	2020-03-14 04:41:39	2020-03-14	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	15690	delivery	5	23
39301	2020-03-14 04:48:32	2020-03-14	9	[{"id_menu":7,"count":1}]	15079	delivery	5	14
39302	2020-03-14 04:48:44	2020-03-14	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4951	delivery	5	43
39303	2020-03-14 04:50:09	2020-03-14	14	[{"id_menu":2,"count":1}]	7050	pick-up	0	14
39304	2020-03-14 04:52:19	2020-03-14	17	[{"id_menu":4,"count":2}]	14864	delivery	5	22
39305	2020-03-14 04:56:03	2020-03-14	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1044	pick-up	0	24
39306	2020-03-14 04:58:24	2020-03-14	9	[{"id_menu":7,"count":1}]	11840	delivery	5	14
39307	2020-03-14 04:59:32	2020-03-14	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9260	delivery	5	37
39308	2020-03-14 05:03:20	2020-03-14	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	10394	pick-up	0	43
39309	2020-03-14 05:03:43	2020-03-14	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	7019	pick-up	0	21
39310	2020-03-14 05:05:59	2020-03-14	12	[{"id_menu":1,"count":1}]	15695	pick-up	0	12
39311	2020-03-14 05:09:20	2020-03-14	8	[{"id_menu":5,"count":1}]	6643	pick-up	0	8
39312	2020-03-14 05:14:22	2020-03-14	12	[{"id_menu":3,"count":1}]	15265	delivery	5	17
39313	2020-03-14 05:27:52	2020-03-14	12	[{"id_menu":1,"count":1}]	5679	delivery	5	17
39314	2020-03-14 05:29:03	2020-03-14	9	[{"id_menu":7,"count":1}]	2237	pick-up	0	9
39315	2020-03-14 05:46:42	2020-03-14	12	[{"id_menu":3,"count":1}]	15594	pick-up	0	12
39316	2020-03-14 05:47:23	2020-03-14	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	207	pick-up	0	43
39317	2020-03-14 05:50:49	2020-03-14	9	[{"id_menu":7,"count":1}]	15616	delivery	5	14
39318	2020-03-14 05:53:05	2020-03-14	9	[{"id_menu":6,"count":1}]	15608	delivery	5	14
39319	2020-03-14 05:55:42	2020-03-14	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	15661	delivery	5	26
39320	2020-03-14 05:57:17	2020-03-14	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3257	delivery	5	39
39321	2020-03-14 06:02:36	2020-03-14	9	[{"id_menu":6,"count":1}]	10888	delivery	5	14
39322	2020-03-14 06:04:29	2020-03-14	9	[{"id_menu":7,"count":1}]	12275	delivery	5	14
39323	2020-03-14 06:08:44	2020-03-14	9	[{"id_menu":7,"count":1}]	15581	delivery	5	14
39324	2020-03-14 06:11:21	2020-03-14	21	[{"id_menu":1,"count":3},{"id_menu":6,"count":1}]	11788	delivery	5	26
39325	2020-03-14 06:14:56	2020-03-14	9	[{"id_menu":7,"count":1}]	15659	delivery	5	14
39326	2020-03-14 06:16:12	2020-03-14	9	[{"id_menu":6,"count":1}]	490	delivery	5	14
39327	2020-03-14 06:16:38	2020-03-14	9	[{"id_menu":6,"count":1}]	12236	delivery	5	14
39328	2020-03-14 06:26:28	2020-03-14	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15721	delivery	5	31
39329	2020-03-14 06:29:42	2020-03-14	8	[{"id_menu":5,"count":1}]	1569	pick-up	0	8
39330	2020-03-14 06:32:13	2020-03-14	14	[{"id_menu":2,"count":1}]	15662	pick-up	0	14
39331	2020-03-14 06:42:14	2020-03-14	17	[{"id_menu":4,"count":1}]	15593	delivery	5	22
39332	2020-03-14 06:43:51	2020-03-14	9	[{"id_menu":6,"count":1}]	15682	delivery	5	14
39333	2020-03-14 06:47:33	2020-03-14	9	[{"id_menu":7,"count":1}]	437	delivery	5	14
39334	2020-03-14 06:52:51	2020-03-14	14	[{"id_menu":2,"count":1}]	1781	delivery	5	19
39335	2020-03-14 06:59:17	2020-03-14	12	[{"id_menu":3,"count":1}]	15619	delivery	5	17
39336	2020-03-14 07:00:12	2020-03-14	9	[{"id_menu":6,"count":1}]	274	delivery	5	14
39337	2020-03-14 07:02:44	2020-03-14	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2050	pick-up	0	29
39338	2020-03-14 07:09:18	2020-03-14	14	[{"id_menu":2,"count":1}]	1713	delivery	5	19
39339	2020-03-14 07:12:26	2020-03-14	14	[{"id_menu":2,"count":1}]	15630	pick-up	0	14
39340	2020-03-14 07:13:05	2020-03-14	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	15592	delivery	5	27
39341	2020-03-14 07:14:13	2020-03-14	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9296	delivery	5	23
39342	2020-03-14 07:16:21	2020-03-14	9	[{"id_menu":7,"count":1}]	9790	delivery	5	14
39343	2020-03-14 07:18:41	2020-03-14	9	[{"id_menu":7,"count":1}]	9816	pick-up	0	9
39344	2020-03-14 07:18:57	2020-03-14	17	[{"id_menu":4,"count":1}]	15726	delivery	5	22
39345	2020-03-14 07:29:48	2020-03-14	9	[{"id_menu":7,"count":1}]	15663	delivery	5	14
39346	2020-03-14 07:33:12	2020-03-14	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4983	delivery	5	28
39347	2020-03-14 07:36:08	2020-03-14	17	[{"id_menu":4,"count":1}]	123	delivery	5	22
39348	2020-03-14 07:40:19	2020-03-14	12	[{"id_menu":1,"count":2}]	15715	delivery	5	17
39349	2020-03-14 07:45:59	2020-03-14	12	[{"id_menu":3,"count":1}]	7094	pick-up	0	12
39350	2020-03-14 07:48:42	2020-03-14	17	[{"id_menu":4,"count":1}]	15613	delivery	5	22
39351	2020-03-14 07:49:07	2020-03-14	17	[{"id_menu":4,"count":1}]	5758	pick-up	0	17
39352	2020-03-14 07:56:40	2020-03-14	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	12636	delivery	5	52
39353	2020-03-14 07:58:42	2020-03-14	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	8812	delivery	5	31
39354	2020-03-14 07:59:37	2020-03-14	9	[{"id_menu":7,"count":1}]	13923	delivery	5	14
39355	2020-03-14 08:00:05	2020-03-14	17	[{"id_menu":4,"count":1}]	7342	delivery	5	22
39356	2020-03-14 08:19:03	2020-03-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2431	pick-up	0	31
39357	2020-03-14 08:23:58	2020-03-14	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	15609	delivery	5	23
39358	2020-03-14 08:24:46	2020-03-14	17	[{"id_menu":4,"count":1}]	15667	delivery	5	22
39359	2020-03-14 08:28:26	2020-03-14	12	[{"id_menu":3,"count":1}]	14475	delivery	5	17
39360	2020-03-14 08:30:10	2020-03-14	9	[{"id_menu":6,"count":1}]	3022	delivery	5	14
39361	2020-03-14 08:31:24	2020-03-14	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	8019	delivery	5	39
39362	2020-03-14 08:33:57	2020-03-14	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2995	delivery	5	30
39363	2020-03-14 08:42:51	2020-03-14	14	[{"id_menu":2,"count":1}]	11464	delivery	5	19
39364	2020-03-14 08:51:32	2020-03-14	14	[{"id_menu":2,"count":1}]	15642	delivery	5	19
39365	2020-03-14 08:53:30	2020-03-14	9	[{"id_menu":6,"count":1}]	4447	delivery	5	14
39366	2020-03-14 08:56:04	2020-03-14	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15709	delivery	5	45
39367	2020-03-14 09:00:48	2020-03-14	8	[{"id_menu":5,"count":1}]	3053	delivery	5	13
39368	2020-03-14 09:01:24	2020-03-14	14	[{"id_menu":2,"count":1}]	15671	delivery	5	19
39369	2020-03-14 09:11:26	2020-03-14	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	15640	delivery	5	27
39370	2020-03-14 09:11:37	2020-03-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	11491	pick-up	0	31
39371	2020-03-14 09:14:35	2020-03-14	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1914	delivery	5	48
39372	2020-03-14 09:20:00	2020-03-14	8	[{"id_menu":5,"count":1}]	8115	pick-up	0	8
39373	2020-03-14 09:20:52	2020-03-14	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	15638	delivery	5	27
39374	2020-03-14 09:20:52	2020-03-14	9	[{"id_menu":6,"count":1}]	11379	delivery	5	14
39375	2020-03-14 09:21:10	2020-03-14	12	[{"id_menu":1,"count":1}]	15606	delivery	5	17
39376	2020-03-14 09:21:17	2020-03-14	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":3}]	6198	delivery	5	31
39377	2020-03-14 09:22:20	2020-03-14	9	[{"id_menu":6,"count":1}]	8586	delivery	5	14
39378	2020-03-14 09:23:00	2020-03-14	9	[{"id_menu":7,"count":3}]	8651	delivery	5	14
39379	2020-03-14 09:23:48	2020-03-14	17	[{"id_menu":4,"count":1}]	1177	pick-up	0	17
39380	2020-03-14 09:24:05	2020-03-14	9	[{"id_menu":7,"count":1}]	15727	delivery	5	14
39381	2020-03-14 09:30:36	2020-03-14	8	[{"id_menu":5,"count":1}]	11977	delivery	5	13
39382	2020-03-14 09:33:33	2020-03-14	9	[{"id_menu":7,"count":1}]	15652	delivery	5	14
39383	2020-03-14 09:34:04	2020-03-14	9	[{"id_menu":7,"count":1}]	8363	pick-up	0	9
39384	2020-03-14 09:37:12	2020-03-14	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15590	pick-up	0	38
39385	2020-03-14 09:41:18	2020-03-14	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	11806	delivery	5	46
39386	2020-03-14 09:42:42	2020-03-14	9	[{"id_menu":7,"count":1}]	15686	pick-up	0	9
39387	2020-03-14 10:03:00	2020-03-14	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15635	delivery	5	43
39388	2020-03-14 10:05:01	2020-03-14	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	15621	delivery	5	26
39389	2020-03-14 10:10:59	2020-03-14	17	[{"id_menu":4,"count":1}]	15700	delivery	5	22
39390	2020-03-14 10:11:00	2020-03-14	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	6666	pick-up	0	21
39391	2020-03-14 10:17:37	2020-03-14	17	[{"id_menu":4,"count":1}]	14081	delivery	5	22
39392	2020-03-14 10:21:11	2020-03-14	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5064	delivery	5	23
39393	2020-03-14 10:22:39	2020-03-14	9	[{"id_menu":6,"count":1}]	8670	pick-up	0	9
39394	2020-03-14 10:38:00	2020-03-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15649	delivery	5	22
39395	2020-03-14 10:38:02	2020-03-14	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	11095	delivery	5	25
39396	2020-03-14 10:40:01	2020-03-14	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	15654	delivery	5	40
39397	2020-03-14 10:40:44	2020-03-14	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6923	delivery	5	45
39398	2020-03-14 10:42:26	2020-03-14	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	15637	pick-up	0	24
39399	2020-03-14 10:46:54	2020-03-14	9	[{"id_menu":6,"count":1}]	15628	delivery	5	14
39400	2020-03-14 10:48:46	2020-03-14	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	15653	pick-up	0	29
39401	2020-03-14 10:51:57	2020-03-14	8	[{"id_menu":5,"count":1}]	632	delivery	5	13
39402	2020-03-14 10:54:02	2020-03-14	14	[{"id_menu":2,"count":1}]	8917	delivery	5	19
39403	2020-03-14 10:58:33	2020-03-14	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14775	delivery	5	51
39404	2020-03-14 10:58:43	2020-03-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1523	pick-up	0	26
39405	2020-03-14 11:09:14	2020-03-14	8	[{"id_menu":5,"count":1}]	5082	delivery	5	13
39406	2020-03-14 11:10:23	2020-03-14	12	[{"id_menu":1,"count":1}]	883	pick-up	0	12
39407	2020-03-14 11:17:31	2020-03-14	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	15687	delivery	5	26
39408	2020-03-14 11:17:52	2020-03-14	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	15117	delivery	5	34
39409	2020-03-14 11:19:25	2020-03-14	9	[{"id_menu":7,"count":1}]	14221	delivery	5	14
39410	2020-03-14 11:21:03	2020-03-14	14	[{"id_menu":2,"count":1}]	9295	pick-up	0	14
39411	2020-03-14 11:27:23	2020-03-14	14	[{"id_menu":2,"count":1}]	15699	delivery	5	19
39412	2020-03-14 11:33:08	2020-03-14	9	[{"id_menu":6,"count":1}]	15657	delivery	5	14
39413	2020-03-14 11:37:27	2020-03-14	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":3}]	15584	delivery	5	25
39414	2020-03-14 11:39:44	2020-03-14	8	[{"id_menu":5,"count":1}]	15617	delivery	5	13
39415	2020-03-14 11:42:52	2020-03-14	12	[{"id_menu":1,"count":2}]	135	pick-up	0	12
39416	2020-03-14 11:43:21	2020-03-14	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	12224	delivery	5	26
39417	2020-03-14 11:51:37	2020-03-14	17	[{"id_menu":4,"count":1}]	15655	delivery	5	22
39418	2020-03-14 11:53:22	2020-03-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	8235	delivery	5	36
39419	2020-03-14 11:53:56	2020-03-14	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	908	pick-up	0	29
39420	2020-03-14 11:56:15	2020-03-14	12	[{"id_menu":3,"count":1}]	15696	delivery	5	17
39421	2020-03-14 11:57:52	2020-03-14	14	[{"id_menu":2,"count":1}]	8748	delivery	5	19
39422	2020-03-14 12:03:05	2020-03-14	14	[{"id_menu":2,"count":1}]	15694	delivery	5	19
39423	2020-03-14 12:04:12	2020-03-14	17	[{"id_menu":4,"count":1}]	15705	delivery	5	22
39424	2020-03-14 12:04:37	2020-03-14	12	[{"id_menu":3,"count":1}]	11766	pick-up	0	12
39425	2020-03-14 12:05:24	2020-03-14	9	[{"id_menu":7,"count":1}]	15611	delivery	5	14
39426	2020-03-14 12:10:41	2020-03-14	17	[{"id_menu":4,"count":1}]	15673	delivery	5	22
39427	2020-03-14 12:12:21	2020-03-14	17	[{"id_menu":4,"count":1}]	15639	delivery	5	22
39428	2020-03-14 12:15:48	2020-03-14	12	[{"id_menu":1,"count":1}]	15719	delivery	5	17
39429	2020-03-14 12:15:55	2020-03-14	9	[{"id_menu":7,"count":1}]	15636	delivery	5	14
39430	2020-03-14 12:16:36	2020-03-14	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	788	delivery	5	34
39431	2020-03-14 12:22:07	2020-03-14	14	[{"id_menu":2,"count":1}]	14828	delivery	5	19
39432	2020-03-14 12:26:56	2020-03-14	9	[{"id_menu":7,"count":1}]	15704	delivery	5	14
39433	2020-03-14 12:27:33	2020-03-14	12	[{"id_menu":1,"count":1}]	570	pick-up	0	12
39434	2020-03-14 12:28:29	2020-03-14	8	[{"id_menu":5,"count":1}]	9482	pick-up	0	8
39435	2020-03-14 12:37:27	2020-03-14	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9039	delivery	5	36
39436	2020-03-14 12:40:24	2020-03-14	9	[{"id_menu":7,"count":1}]	37	pick-up	0	9
39437	2020-03-14 12:41:11	2020-03-14	8	[{"id_menu":5,"count":1}]	15703	delivery	5	13
39438	2020-03-14 12:42:36	2020-03-14	17	[{"id_menu":4,"count":1}]	1195	delivery	5	22
39439	2020-03-14 12:43:13	2020-03-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	6333	pick-up	0	23
39440	2020-03-14 12:45:33	2020-03-14	9	[{"id_menu":6,"count":1}]	13863	delivery	5	14
39441	2020-03-14 12:49:33	2020-03-14	9	[{"id_menu":7,"count":1}]	15730	delivery	5	14
39442	2020-03-14 12:52:04	2020-03-14	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15693	delivery	5	43
39443	2020-03-14 13:03:13	2020-03-14	9	[{"id_menu":6,"count":1}]	634	delivery	5	14
39444	2020-03-14 13:03:23	2020-03-14	9	[{"id_menu":6,"count":1}]	1912	pick-up	0	9
39445	2020-03-14 13:05:23	2020-03-14	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15646	delivery	5	34
39446	2020-03-14 13:16:20	2020-03-14	17	[{"id_menu":4,"count":1}]	10790	delivery	5	22
39447	2020-03-14 13:19:16	2020-03-14	9	[{"id_menu":6,"count":1}]	5886	delivery	5	14
39448	2020-03-14 13:23:38	2020-03-14	9	[{"id_menu":6,"count":1}]	11260	pick-up	0	9
39449	2020-03-14 13:23:59	2020-03-14	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	1457	delivery	5	34
39450	2020-03-14 13:24:10	2020-03-14	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8981	pick-up	0	37
39451	2020-03-14 13:33:29	2020-03-14	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5296	delivery	5	45
39452	2020-03-14 13:39:06	2020-03-14	12	[{"id_menu":3,"count":1}]	9695	delivery	5	17
39453	2020-03-14 13:40:58	2020-03-14	8	[{"id_menu":5,"count":1}]	2384	delivery	5	13
39454	2020-03-14 13:42:56	2020-03-14	41	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	11237	delivery	5	46
39455	2020-03-14 13:44:40	2020-03-14	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	15701	pick-up	0	24
39456	2020-03-14 13:45:55	2020-03-14	9	[{"id_menu":6,"count":1}]	15602	delivery	5	14
39457	2020-03-14 13:48:01	2020-03-14	14	[{"id_menu":2,"count":1}]	14998	delivery	5	19
39458	2020-03-14 13:50:45	2020-03-14	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8455	delivery	5	45
39459	2020-03-14 14:00:14	2020-03-14	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15729	delivery	5	34
39460	2020-03-14 14:05:54	2020-03-14	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	584	pick-up	0	35
39461	2020-03-14 14:12:36	2020-03-14	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15588	delivery	5	31
39462	2020-03-14 14:21:34	2020-03-14	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	9394	pick-up	0	26
39463	2020-03-14 14:21:34	2020-03-14	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5106	delivery	5	36
39464	2020-03-14 14:33:09	2020-03-14	9	[{"id_menu":7,"count":1}]	10395	delivery	5	14
39465	2020-03-14 14:33:52	2020-03-14	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8771	delivery	5	52
39466	2020-03-14 14:39:53	2020-03-14	9	[{"id_menu":7,"count":1}]	15644	delivery	5	14
39467	2020-03-14 14:52:07	2020-03-14	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15669	delivery	5	35
39468	2020-03-14 14:53:49	2020-03-14	9	[{"id_menu":7,"count":4}]	10014	delivery	5	14
39469	2020-03-14 14:54:24	2020-03-14	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9525	delivery	5	45
39470	2020-03-14 14:55:50	2020-03-14	8	[{"id_menu":5,"count":1}]	7667	delivery	5	13
39471	2020-03-14 15:02:41	2020-03-14	9	[{"id_menu":6,"count":1}]	621	pick-up	0	9
39472	2020-03-14 15:03:18	2020-03-14	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2021	delivery	5	31
39473	2020-03-14 15:07:44	2020-03-14	9	[{"id_menu":6,"count":1}]	3876	delivery	5	14
39474	2020-03-14 15:12:08	2020-03-14	9	[{"id_menu":6,"count":1}]	15720	pick-up	0	9
39475	2020-03-14 15:19:24	2020-03-14	14	[{"id_menu":2,"count":1}]	1934	pick-up	0	14
39476	2020-03-14 15:21:13	2020-03-14	17	[{"id_menu":4,"count":2}]	15689	delivery	5	22
39477	2020-03-14 15:21:55	2020-03-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9053	pick-up	0	23
39478	2020-03-14 15:25:11	2020-03-14	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	12102	delivery	5	28
39479	2020-03-14 15:33:57	2020-03-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7131	delivery	5	28
39480	2020-03-14 15:34:04	2020-03-14	12	[{"id_menu":1,"count":1}]	6628	pick-up	0	12
39481	2020-03-14 15:43:16	2020-03-14	14	[{"id_menu":2,"count":1}]	15665	pick-up	0	14
39482	2020-03-14 15:46:39	2020-03-14	9	[{"id_menu":6,"count":1}]	15624	pick-up	0	9
39483	2020-03-14 15:52:16	2020-03-14	12	[{"id_menu":3,"count":1}]	11530	delivery	5	17
39484	2020-03-14 15:58:28	2020-03-14	12	[{"id_menu":1,"count":1}]	15643	delivery	5	17
39485	2020-03-14 16:04:39	2020-03-14	14	[{"id_menu":2,"count":1}]	3854	delivery	5	19
39486	2020-03-14 16:06:14	2020-03-14	9	[{"id_menu":7,"count":1}]	15632	delivery	5	14
39487	2020-03-14 16:08:01	2020-03-14	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15629	delivery	5	34
39488	2020-03-14 16:10:30	2020-03-14	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	15579	delivery	5	30
39489	2020-03-14 16:16:34	2020-03-14	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1589	pick-up	0	23
39490	2020-03-14 16:22:30	2020-03-14	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	5950	delivery	5	25
39491	2020-03-14 16:30:33	2020-03-14	9	[{"id_menu":6,"count":1}]	15622	delivery	5	14
39492	2020-03-14 16:30:54	2020-03-14	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	15707	delivery	5	25
39493	2020-03-14 16:37:13	2020-03-14	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	11779	delivery	5	26
39494	2020-03-14 16:37:27	2020-03-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15623	delivery	5	22
39495	2020-03-14 16:55:51	2020-03-14	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	15605	delivery	5	37
39496	2020-03-14 16:58:58	2020-03-14	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	15595	delivery	5	26
39497	2020-03-14 16:59:18	2020-03-14	8	[{"id_menu":5,"count":1}]	15710	delivery	5	13
39498	2020-03-14 17:00:44	2020-03-14	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12579	delivery	5	43
39499	2020-03-14 17:01:30	2020-03-14	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	9924	delivery	5	25
39500	2020-03-14 17:05:24	2020-03-14	12	[{"id_menu":1,"count":1}]	15723	delivery	5	17
39501	2020-03-14 17:07:27	2020-03-14	9	[{"id_menu":6,"count":1}]	2264	delivery	5	14
39502	2020-03-14 17:08:33	2020-03-14	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	1373	delivery	5	28
39503	2020-03-14 17:09:14	2020-03-14	9	[{"id_menu":7,"count":1}]	15698	delivery	5	14
39504	2020-03-14 17:16:36	2020-03-14	12	[{"id_menu":1,"count":1}]	11946	pick-up	0	12
39505	2020-03-14 17:18:54	2020-03-14	21	[{"id_menu":3,"count":3},{"id_menu":6,"count":1}]	15596	delivery	5	26
39506	2020-03-14 17:19:01	2020-03-14	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	15666	delivery	5	23
39507	2020-03-14 17:24:32	2020-03-14	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	6644	pick-up	0	22
39508	2020-03-14 17:27:30	2020-03-14	12	[{"id_menu":1,"count":1}]	9032	delivery	5	17
39509	2020-03-14 17:31:02	2020-03-14	8	[{"id_menu":5,"count":1}]	15681	delivery	5	13
39510	2020-03-14 17:31:59	2020-03-14	9	[{"id_menu":6,"count":1}]	15717	delivery	5	14
39511	2020-03-14 17:36:54	2020-03-14	12	[{"id_menu":1,"count":1}]	10717	pick-up	0	12
39512	2020-03-14 17:43:23	2020-03-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6142	delivery	5	22
39513	2020-03-14 17:44:31	2020-03-14	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	15631	delivery	5	40
39514	2020-03-14 17:49:09	2020-03-14	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15725	delivery	5	35
39515	2020-03-14 17:55:47	2020-03-14	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15716	delivery	5	31
39516	2020-03-14 17:56:32	2020-03-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	15658	delivery	5	28
39517	2020-03-14 17:59:27	2020-03-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	12061	delivery	5	22
39518	2020-03-14 18:05:45	2020-03-14	9	[{"id_menu":7,"count":1}]	15732	pick-up	0	9
39519	2020-03-14 18:20:02	2020-03-14	12	[{"id_menu":1,"count":1}]	3417	delivery	5	17
39520	2020-03-14 18:23:07	2020-03-14	9	[{"id_menu":7,"count":1}]	12894	delivery	5	14
39521	2020-03-14 18:32:24	2020-03-14	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7192	delivery	5	57
39522	2020-03-14 18:34:58	2020-03-14	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15677	delivery	5	31
39523	2020-03-14 18:45:34	2020-03-14	9	[{"id_menu":7,"count":1}]	1900	delivery	5	14
39524	2020-03-14 18:48:15	2020-03-14	8	[{"id_menu":5,"count":1}]	4947	delivery	5	13
39525	2020-03-14 18:59:49	2020-03-14	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	15620	delivery	5	25
39526	2020-03-14 19:04:04	2020-03-14	14	[{"id_menu":2,"count":3}]	15674	delivery	5	19
39527	2020-03-14 19:05:17	2020-03-14	14	[{"id_menu":2,"count":2}]	1992	pick-up	0	14
39528	2020-03-14 19:06:07	2020-03-14	9	[{"id_menu":7,"count":1}]	15610	delivery	5	14
39529	2020-03-14 19:07:21	2020-03-14	12	[{"id_menu":1,"count":1}]	15711	delivery	5	17
39530	2020-03-14 19:15:15	2020-03-14	12	[{"id_menu":1,"count":1}]	15618	delivery	5	17
39531	2020-03-14 19:15:17	2020-03-14	14	[{"id_menu":2,"count":1}]	7365	delivery	5	19
39532	2020-03-14 19:26:11	2020-03-14	17	[{"id_menu":4,"count":1}]	8083	pick-up	0	17
39533	2020-03-14 19:27:15	2020-03-14	12	[{"id_menu":1,"count":2}]	7383	pick-up	0	12
39534	2020-03-14 19:32:21	2020-03-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	15626	delivery	5	28
39535	2020-03-14 19:35:50	2020-03-14	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3065	pick-up	0	29
39536	2020-03-14 20:00:19	2020-03-14	9	[{"id_menu":7,"count":2}]	11851	delivery	5	14
39537	2020-03-14 20:04:52	2020-03-14	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	12464	delivery	5	39
39538	2020-03-14 20:08:58	2020-03-14	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15614	delivery	5	34
39539	2020-03-14 20:16:40	2020-03-14	9	[{"id_menu":6,"count":2}]	15600	delivery	5	14
39540	2020-03-14 20:17:52	2020-03-14	30	[{"id_menu":3,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15371	delivery	5	35
39541	2020-03-14 20:20:13	2020-03-14	12	[{"id_menu":3,"count":1}]	4233	delivery	5	17
39542	2020-03-14 20:21:01	2020-03-14	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	10858	delivery	5	36
39543	2020-03-14 20:26:10	2020-03-14	12	[{"id_menu":1,"count":1}]	15706	delivery	5	17
39544	2020-03-14 20:34:58	2020-03-14	9	[{"id_menu":6,"count":1}]	11921	delivery	5	14
39545	2020-03-14 20:35:34	2020-03-14	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	9749	pick-up	0	21
39546	2020-03-14 20:47:23	2020-03-14	12	[{"id_menu":3,"count":1}]	2817	pick-up	0	12
39547	2020-03-14 20:49:43	2020-03-14	26	[{"id_menu":4,"count":3},{"id_menu":7,"count":1}]	15641	delivery	5	31
39548	2020-03-14 20:53:41	2020-03-14	12	[{"id_menu":3,"count":1}]	15680	delivery	5	17
39549	2020-03-14 20:55:51	2020-03-14	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	14073	delivery	5	28
39550	2020-03-14 20:57:08	2020-03-14	9	[{"id_menu":7,"count":1}]	8457	delivery	5	14
39551	2020-03-14 21:00:44	2020-03-14	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	7690	pick-up	0	29
39552	2020-03-14 21:04:44	2020-03-14	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14773	delivery	5	45
39553	2020-03-14 21:13:40	2020-03-14	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	11754	pick-up	0	26
39554	2020-03-14 21:15:39	2020-03-14	12	[{"id_menu":1,"count":1}]	15625	pick-up	0	12
39555	2020-03-14 21:19:14	2020-03-14	8	[{"id_menu":5,"count":1}]	6987	pick-up	0	8
39556	2020-03-14 21:30:00	2020-03-14	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	15651	delivery	5	42
39557	2020-03-14 21:36:37	2020-03-14	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	7957	pick-up	0	29
39558	2020-03-14 21:39:34	2020-03-14	9	[{"id_menu":6,"count":1}]	15718	delivery	5	14
39559	2020-03-14 21:39:52	2020-03-14	9	[{"id_menu":7,"count":1}]	11666	delivery	5	14
39560	2020-03-14 21:40:26	2020-03-14	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	12348	delivery	5	26
39561	2020-03-14 21:44:16	2020-03-14	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15728	delivery	5	43
39562	2020-03-14 21:48:58	2020-03-14	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15578	delivery	5	48
39563	2020-03-14 21:51:26	2020-03-14	14	[{"id_menu":2,"count":1}]	8846	delivery	5	19
39564	2020-03-14 21:51:32	2020-03-14	9	[{"id_menu":7,"count":1}]	2623	pick-up	0	9
39565	2020-03-14 21:55:59	2020-03-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	14369	delivery	5	22
39566	2020-03-14 22:01:42	2020-03-14	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	15634	delivery	5	26
39567	2020-03-14 22:06:17	2020-03-14	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	14389	delivery	5	22
39568	2020-03-14 22:14:25	2020-03-14	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15597	delivery	5	51
39569	2020-03-14 22:21:24	2020-03-14	14	[{"id_menu":2,"count":1}]	15645	pick-up	0	14
39570	2020-03-14 22:24:33	2020-03-14	9	[{"id_menu":7,"count":1}]	5155	delivery	5	14
39571	2020-03-14 22:24:58	2020-03-14	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12131	delivery	5	36
39572	2020-03-14 22:29:16	2020-03-14	9	[{"id_menu":6,"count":1}]	1970	delivery	5	14
39573	2020-03-14 22:33:10	2020-03-14	14	[{"id_menu":2,"count":1}]	15678	delivery	5	19
39574	2020-03-14 22:38:14	2020-03-14	8	[{"id_menu":5,"count":1}]	14256	delivery	5	13
39575	2020-03-14 22:40:24	2020-03-14	12	[{"id_menu":1,"count":1}]	6807	pick-up	0	12
39576	2020-03-14 22:40:40	2020-03-14	14	[{"id_menu":2,"count":1}]	12735	delivery	5	19
39577	2020-03-14 22:57:39	2020-03-14	9	[{"id_menu":7,"count":1}]	1280	pick-up	0	9
39578	2020-03-14 23:04:01	2020-03-14	8	[{"id_menu":5,"count":1}]	8518	delivery	5	13
39579	2020-03-14 23:05:16	2020-03-14	9	[{"id_menu":7,"count":1}]	4834	pick-up	0	9
39580	2020-03-14 23:13:24	2020-03-14	14	[{"id_menu":2,"count":3}]	15675	delivery	5	19
39581	2020-03-14 23:18:28	2020-03-14	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5020	delivery	5	31
39582	2020-03-14 23:19:07	2020-03-14	9	[{"id_menu":6,"count":1}]	15582	pick-up	0	9
39583	2020-03-14 23:19:36	2020-03-14	8	[{"id_menu":5,"count":1}]	15714	delivery	5	13
39584	2020-03-14 23:20:34	2020-03-14	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	13397	delivery	5	30
39585	2020-03-14 23:26:31	2020-03-14	12	[{"id_menu":1,"count":1}]	12129	pick-up	0	12
39586	2020-03-14 23:27:01	2020-03-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7919	pick-up	0	17
39587	2020-03-14 23:32:51	2020-03-14	9	[{"id_menu":7,"count":1}]	1344	pick-up	0	9
39588	2020-03-14 23:38:05	2020-03-14	8	[{"id_menu":5,"count":1}]	2658	delivery	5	13
39589	2020-03-14 23:39:23	2020-03-14	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15712	delivery	5	43
39590	2020-03-14 23:44:17	2020-03-14	8	[{"id_menu":5,"count":2}]	7525	delivery	5	13
39591	2020-03-14 23:47:18	2020-03-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":3}]	3935	delivery	5	22
39592	2020-03-14 23:52:56	2020-03-14	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	13108	delivery	5	27
39593	2020-03-14 23:53:27	2020-03-14	9	[{"id_menu":7,"count":1}]	10209	pick-up	0	9
39594	2020-03-14 23:53:50	2020-03-14	9	[{"id_menu":7,"count":1}]	15692	delivery	5	14
39595	2020-03-15 00:03:02	2020-03-15	14	[{"id_menu":2,"count":1}]	10389	pick-up	0	14
39596	2020-03-15 00:07:08	2020-03-15	14	[{"id_menu":2,"count":1}]	5824	delivery	5	19
39597	2020-03-15 00:10:22	2020-03-15	9	[{"id_menu":7,"count":1}]	15821	delivery	5	14
39598	2020-03-15 00:11:01	2020-03-15	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10425	pick-up	0	25
39599	2020-03-15 00:13:45	2020-03-15	9	[{"id_menu":7,"count":1}]	15809	delivery	5	14
39600	2020-03-15 00:18:41	2020-03-15	14	[{"id_menu":2,"count":1}]	13547	pick-up	0	14
39601	2020-03-15 00:23:38	2020-03-15	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	12473	pick-up	0	29
39602	2020-03-15 00:25:35	2020-03-15	14	[{"id_menu":2,"count":1}]	15751	pick-up	0	14
39603	2020-03-15 00:30:55	2020-03-15	14	[{"id_menu":2,"count":1}]	14088	delivery	5	19
39604	2020-03-15 00:50:10	2020-03-15	9	[{"id_menu":7,"count":1}]	5930	delivery	5	14
39605	2020-03-15 00:50:41	2020-03-15	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15760	delivery	5	31
39606	2020-03-15 00:54:56	2020-03-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1104	delivery	5	23
39607	2020-03-15 00:55:53	2020-03-15	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":2}]	10575	delivery	5	34
39608	2020-03-15 00:57:28	2020-03-15	17	[{"id_menu":4,"count":1}]	7488	delivery	5	22
39609	2020-03-15 01:12:39	2020-03-15	9	[{"id_menu":6,"count":1}]	15791	pick-up	0	9
39610	2020-03-15 01:14:13	2020-03-15	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	15819	delivery	5	30
39611	2020-03-15 01:16:41	2020-03-15	12	[{"id_menu":1,"count":1}]	14202	delivery	5	17
39612	2020-03-15 01:24:02	2020-03-15	14	[{"id_menu":2,"count":1}]	1865	pick-up	0	14
39613	2020-03-15 01:25:39	2020-03-15	9	[{"id_menu":6,"count":1}]	9419	delivery	5	14
39614	2020-03-15 01:27:42	2020-03-15	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	13172	delivery	5	26
39615	2020-03-15 01:29:17	2020-03-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	7440	delivery	5	28
39616	2020-03-15 01:30:13	2020-03-15	12	[{"id_menu":1,"count":1}]	14483	delivery	5	17
39617	2020-03-15 01:30:27	2020-03-15	9	[{"id_menu":7,"count":1}]	15812	delivery	5	14
39618	2020-03-15 01:32:55	2020-03-15	17	[{"id_menu":4,"count":1}]	15779	delivery	5	22
39619	2020-03-15 01:33:45	2020-03-15	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13023	delivery	5	45
39620	2020-03-15 01:38:55	2020-03-15	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14920	delivery	5	22
39621	2020-03-15 01:38:57	2020-03-15	9	[{"id_menu":7,"count":1}]	15756	delivery	5	14
39622	2020-03-15 01:41:42	2020-03-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	403	delivery	5	31
39623	2020-03-15 01:51:48	2020-03-15	14	[{"id_menu":2,"count":1}]	6101	delivery	5	19
39624	2020-03-15 01:53:25	2020-03-15	12	[{"id_menu":3,"count":1}]	1306	pick-up	0	12
39625	2020-03-15 01:54:06	2020-03-15	9	[{"id_menu":6,"count":1}]	9816	pick-up	0	9
39626	2020-03-15 01:58:44	2020-03-15	9	[{"id_menu":6,"count":1}]	3534	delivery	5	14
39627	2020-03-15 01:58:56	2020-03-15	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	8555	delivery	5	36
39628	2020-03-15 01:59:32	2020-03-15	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15459	delivery	5	43
39629	2020-03-15 02:08:30	2020-03-15	17	[{"id_menu":4,"count":1}]	1148	delivery	5	22
39630	2020-03-15 02:13:27	2020-03-15	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	7304	pick-up	0	21
39631	2020-03-15 02:16:55	2020-03-15	9	[{"id_menu":6,"count":1}]	15817	pick-up	0	9
39632	2020-03-15 02:17:00	2020-03-15	9	[{"id_menu":7,"count":1}]	4349	delivery	5	14
39633	2020-03-15 02:28:40	2020-03-15	8	[{"id_menu":5,"count":1}]	229	pick-up	0	8
39634	2020-03-15 02:28:47	2020-03-15	12	[{"id_menu":3,"count":1}]	2265	pick-up	0	12
39635	2020-03-15 02:33:40	2020-03-15	12	[{"id_menu":1,"count":2}]	13669	delivery	5	17
39636	2020-03-15 02:35:08	2020-03-15	9	[{"id_menu":6,"count":1}]	7497	delivery	5	14
39637	2020-03-15 02:36:36	2020-03-15	9	[{"id_menu":7,"count":2}]	14395	delivery	5	14
39638	2020-03-15 02:40:00	2020-03-15	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	8813	delivery	5	31
39639	2020-03-15 02:40:19	2020-03-15	14	[{"id_menu":2,"count":1}]	15449	pick-up	0	14
39640	2020-03-15 02:53:28	2020-03-15	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15833	delivery	5	31
39641	2020-03-15 02:55:49	2020-03-15	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	13185	delivery	5	35
39642	2020-03-15 02:56:42	2020-03-15	9	[{"id_menu":7,"count":1}]	7219	pick-up	0	9
39643	2020-03-15 02:58:42	2020-03-15	9	[{"id_menu":7,"count":1}]	337	pick-up	0	9
39644	2020-03-15 03:00:22	2020-03-15	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15813	delivery	5	22
39645	2020-03-15 03:05:43	2020-03-15	9	[{"id_menu":7,"count":1}]	3507	pick-up	0	9
39646	2020-03-15 03:08:14	2020-03-15	8	[{"id_menu":5,"count":1}]	2828	pick-up	0	8
39647	2020-03-15 03:11:51	2020-03-15	9	[{"id_menu":7,"count":1}]	13667	delivery	5	14
39648	2020-03-15 03:15:51	2020-03-15	17	[{"id_menu":4,"count":2}]	9327	delivery	5	22
39649	2020-03-15 03:15:56	2020-03-15	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4825	pick-up	0	31
39650	2020-03-15 03:18:36	2020-03-15	12	[{"id_menu":3,"count":1}]	11938	delivery	5	17
39651	2020-03-15 03:27:14	2020-03-15	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":2}]	15839	delivery	5	28
39652	2020-03-15 03:31:25	2020-03-15	12	[{"id_menu":3,"count":1}]	10273	pick-up	0	12
39653	2020-03-15 03:37:36	2020-03-15	12	[{"id_menu":3,"count":1}]	15734	pick-up	0	12
39654	2020-03-15 03:41:10	2020-03-15	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6301	pick-up	0	31
39655	2020-03-15 03:41:11	2020-03-15	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4420	delivery	5	22
39656	2020-03-15 03:44:26	2020-03-15	14	[{"id_menu":2,"count":1}]	7572	pick-up	0	14
39657	2020-03-15 03:51:10	2020-03-15	17	[{"id_menu":4,"count":1}]	464	pick-up	0	17
39658	2020-03-15 03:51:55	2020-03-15	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	11564	delivery	5	22
39659	2020-03-15 03:52:31	2020-03-15	14	[{"id_menu":2,"count":1}]	7135	pick-up	0	14
39660	2020-03-15 03:53:42	2020-03-15	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	13797	delivery	5	43
39661	2020-03-15 04:01:26	2020-03-15	14	[{"id_menu":2,"count":1}]	5094	pick-up	0	14
39662	2020-03-15 04:04:17	2020-03-15	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	7774	delivery	5	48
39663	2020-03-15 04:05:25	2020-03-15	8	[{"id_menu":5,"count":1}]	10395	delivery	5	13
39664	2020-03-15 04:05:29	2020-03-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	5000	delivery	5	28
39665	2020-03-15 04:08:13	2020-03-15	9	[{"id_menu":6,"count":1}]	15838	delivery	5	14
39666	2020-03-15 04:09:08	2020-03-15	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11595	delivery	5	45
39667	2020-03-15 04:09:55	2020-03-15	14	[{"id_menu":2,"count":2}]	15762	delivery	5	19
39668	2020-03-15 04:10:49	2020-03-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9014	delivery	5	23
39669	2020-03-15 04:14:40	2020-03-15	9	[{"id_menu":7,"count":1}]	5091	delivery	5	14
39670	2020-03-15 04:16:09	2020-03-15	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	10505	delivery	5	37
39671	2020-03-15 04:16:55	2020-03-15	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	14415	delivery	5	27
39672	2020-03-15 04:17:51	2020-03-15	14	[{"id_menu":2,"count":1}]	8050	delivery	5	19
39673	2020-03-15 04:19:30	2020-03-15	9	[{"id_menu":6,"count":1}]	3683	delivery	5	14
39674	2020-03-15 04:21:26	2020-03-15	12	[{"id_menu":3,"count":1}]	15748	delivery	5	17
39675	2020-03-15 04:30:02	2020-03-15	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	15829	pick-up	0	38
39676	2020-03-15 04:30:25	2020-03-15	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	8068	delivery	5	26
39677	2020-03-15 04:31:50	2020-03-15	14	[{"id_menu":2,"count":1}]	15790	delivery	5	19
39678	2020-03-15 04:36:28	2020-03-15	8	[{"id_menu":5,"count":1}]	15590	pick-up	0	8
39679	2020-03-15 04:38:38	2020-03-15	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15810	delivery	5	53
39680	2020-03-15 04:44:16	2020-03-15	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	15846	delivery	5	26
39681	2020-03-15 04:45:21	2020-03-15	14	[{"id_menu":2,"count":1}]	15835	delivery	5	19
39682	2020-03-15 04:50:32	2020-03-15	14	[{"id_menu":2,"count":2}]	15769	pick-up	0	14
39683	2020-03-15 04:56:15	2020-03-15	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	6496	delivery	5	26
39684	2020-03-15 05:01:08	2020-03-15	17	[{"id_menu":4,"count":1}]	12011	delivery	5	22
39685	2020-03-15 05:06:42	2020-03-15	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	12880	delivery	5	26
39686	2020-03-15 05:07:08	2020-03-15	8	[{"id_menu":5,"count":1}]	15776	delivery	5	13
39687	2020-03-15 05:07:23	2020-03-15	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	5507	pick-up	0	29
39688	2020-03-15 05:11:41	2020-03-15	14	[{"id_menu":2,"count":1}]	8866	delivery	5	19
39689	2020-03-15 05:13:19	2020-03-15	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	3398	delivery	5	30
39690	2020-03-15 05:16:42	2020-03-15	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	4191	pick-up	0	25
39691	2020-03-15 05:20:32	2020-03-15	14	[{"id_menu":2,"count":1}]	8065	delivery	5	19
39692	2020-03-15 05:21:55	2020-03-15	8	[{"id_menu":5,"count":1}]	8118	delivery	5	13
39693	2020-03-15 05:29:25	2020-03-15	14	[{"id_menu":2,"count":1}]	5857	delivery	5	19
39694	2020-03-15 05:45:17	2020-03-15	9	[{"id_menu":6,"count":1}]	801	delivery	5	14
39695	2020-03-15 05:46:51	2020-03-15	12	[{"id_menu":3,"count":1}]	15741	delivery	5	17
39696	2020-03-15 05:52:48	2020-03-15	12	[{"id_menu":3,"count":1}]	12474	delivery	5	17
39697	2020-03-15 05:56:20	2020-03-15	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	15808	delivery	5	36
39698	2020-03-15 05:59:17	2020-03-15	9	[{"id_menu":6,"count":2}]	14696	delivery	5	14
39699	2020-03-15 06:03:17	2020-03-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7532	delivery	5	28
39700	2020-03-15 06:07:57	2020-03-15	9	[{"id_menu":7,"count":2}]	10304	delivery	5	14
39701	2020-03-15 06:09:17	2020-03-15	14	[{"id_menu":2,"count":1}]	6090	pick-up	0	14
39702	2020-03-15 06:11:12	2020-03-15	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	9103	delivery	5	31
39703	2020-03-15 06:14:15	2020-03-15	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	15786	delivery	5	34
39704	2020-03-15 06:14:19	2020-03-15	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8397	delivery	5	35
39705	2020-03-15 06:15:40	2020-03-15	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	15850	delivery	5	25
39706	2020-03-15 06:23:01	2020-03-15	9	[{"id_menu":7,"count":1}]	10880	delivery	5	14
39707	2020-03-15 06:23:53	2020-03-15	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	15806	delivery	5	38
39708	2020-03-15 06:30:01	2020-03-15	9	[{"id_menu":7,"count":1}]	3767	delivery	5	14
39709	2020-03-15 06:30:11	2020-03-15	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11858	delivery	5	36
39710	2020-03-15 06:32:25	2020-03-15	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12034	delivery	5	31
39711	2020-03-15 06:36:13	2020-03-15	9	[{"id_menu":7,"count":1}]	11393	delivery	5	14
39712	2020-03-15 06:50:42	2020-03-15	8	[{"id_menu":5,"count":1}]	15746	delivery	5	13
39713	2020-03-15 06:50:49	2020-03-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6235	pick-up	0	18
39714	2020-03-15 06:52:18	2020-03-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	950	delivery	5	28
39715	2020-03-15 07:00:31	2020-03-15	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	12457	delivery	5	46
39716	2020-03-15 07:01:09	2020-03-15	14	[{"id_menu":2,"count":1}]	15799	delivery	5	19
39717	2020-03-15 07:27:16	2020-03-15	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	873	delivery	5	45
39718	2020-03-15 07:28:54	2020-03-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	15744	delivery	5	28
39719	2020-03-15 07:29:52	2020-03-15	17	[{"id_menu":4,"count":1}]	7423	pick-up	0	17
39720	2020-03-15 07:36:11	2020-03-15	9	[{"id_menu":6,"count":1}]	9603	pick-up	0	9
39721	2020-03-15 07:37:31	2020-03-15	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1666	delivery	5	25
39722	2020-03-15 07:46:59	2020-03-15	14	[{"id_menu":2,"count":1}]	10864	delivery	5	19
39723	2020-03-15 07:47:08	2020-03-15	43	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1924	pick-up	0	43
39724	2020-03-15 07:53:44	2020-03-15	9	[{"id_menu":6,"count":1}]	15815	pick-up	0	9
39725	2020-03-15 08:00:16	2020-03-15	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15782	delivery	5	43
39726	2020-03-15 08:07:00	2020-03-15	12	[{"id_menu":1,"count":1}]	9017	delivery	5	17
39727	2020-03-15 08:08:16	2020-03-15	9	[{"id_menu":7,"count":1}]	4658	pick-up	0	9
39728	2020-03-15 08:19:01	2020-03-15	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10180	delivery	5	39
39729	2020-03-15 08:20:32	2020-03-15	9	[{"id_menu":7,"count":1}]	13904	delivery	5	14
39730	2020-03-15 08:31:10	2020-03-15	9	[{"id_menu":6,"count":1}]	15826	pick-up	0	9
39731	2020-03-15 08:32:15	2020-03-15	8	[{"id_menu":5,"count":1}]	13840	delivery	5	13
39732	2020-03-15 08:33:50	2020-03-15	8	[{"id_menu":5,"count":1}]	2653	pick-up	0	8
39733	2020-03-15 08:37:09	2020-03-15	14	[{"id_menu":2,"count":1}]	235	pick-up	0	14
39734	2020-03-15 08:37:35	2020-03-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	951	delivery	5	28
39735	2020-03-15 08:39:38	2020-03-15	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	15787	delivery	5	44
39736	2020-03-15 08:40:14	2020-03-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	2657	delivery	5	23
39737	2020-03-15 08:40:45	2020-03-15	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15845	delivery	5	43
39738	2020-03-15 08:41:47	2020-03-15	9	[{"id_menu":6,"count":1}]	3393	delivery	5	14
39739	2020-03-15 08:48:26	2020-03-15	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1271	delivery	5	40
39740	2020-03-15 08:57:16	2020-03-15	9	[{"id_menu":7,"count":1}]	15818	pick-up	0	9
39741	2020-03-15 08:58:55	2020-03-15	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	15789	delivery	5	26
39742	2020-03-15 09:00:38	2020-03-15	9	[{"id_menu":6,"count":1}]	3863	delivery	5	14
39743	2020-03-15 09:02:48	2020-03-15	12	[{"id_menu":1,"count":1}]	7785	delivery	5	17
39744	2020-03-15 09:03:42	2020-03-15	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	15803	pick-up	0	43
39745	2020-03-15 09:03:44	2020-03-15	12	[{"id_menu":3,"count":1}]	6473	delivery	5	17
39746	2020-03-15 09:07:19	2020-03-15	8	[{"id_menu":5,"count":1}]	3999	delivery	5	13
39747	2020-03-15 09:09:29	2020-03-15	8	[{"id_menu":5,"count":1}]	12789	delivery	5	13
39748	2020-03-15 09:15:12	2020-03-15	12	[{"id_menu":3,"count":1}]	905	pick-up	0	12
39749	2020-03-15 09:19:09	2020-03-15	9	[{"id_menu":6,"count":1}]	15417	delivery	5	14
39750	2020-03-15 09:20:10	2020-03-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	2517	pick-up	0	26
39751	2020-03-15 09:23:58	2020-03-15	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	15761	delivery	5	42
39752	2020-03-15 09:27:21	2020-03-15	9	[{"id_menu":6,"count":1}]	1055	delivery	5	14
39753	2020-03-15 09:28:51	2020-03-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15831	delivery	5	23
39754	2020-03-15 09:29:07	2020-03-15	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	15834	delivery	5	40
39755	2020-03-15 09:36:46	2020-03-15	9	[{"id_menu":7,"count":1}]	2374	delivery	5	14
39756	2020-03-15 09:41:06	2020-03-15	9	[{"id_menu":6,"count":1}]	12161	pick-up	0	9
39757	2020-03-15 09:44:51	2020-03-15	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1176	pick-up	0	21
39758	2020-03-15 09:54:16	2020-03-15	17	[{"id_menu":4,"count":1}]	15828	delivery	5	22
39759	2020-03-15 09:57:41	2020-03-15	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8546	delivery	5	42
39760	2020-03-15 10:02:15	2020-03-15	12	[{"id_menu":1,"count":1}]	11495	pick-up	0	12
39761	2020-03-15 10:03:01	2020-03-15	8	[{"id_menu":5,"count":1}]	15788	delivery	5	13
39762	2020-03-15 10:03:15	2020-03-15	14	[{"id_menu":2,"count":1}]	3478	pick-up	0	14
39763	2020-03-15 10:04:28	2020-03-15	14	[{"id_menu":2,"count":1}]	8748	delivery	5	19
39764	2020-03-15 10:06:01	2020-03-15	9	[{"id_menu":6,"count":1}]	15848	delivery	5	14
39765	2020-03-15 10:07:03	2020-03-15	9	[{"id_menu":6,"count":1}]	6080	delivery	5	14
39766	2020-03-15 10:12:43	2020-03-15	9	[{"id_menu":6,"count":1}]	8742	delivery	5	14
39767	2020-03-15 10:12:51	2020-03-15	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1518	delivery	5	39
39768	2020-03-15 10:15:35	2020-03-15	17	[{"id_menu":4,"count":1}]	1956	pick-up	0	17
39769	2020-03-15 10:16:59	2020-03-15	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	11255	delivery	5	34
39770	2020-03-15 10:17:05	2020-03-15	9	[{"id_menu":6,"count":1}]	7755	pick-up	0	9
39771	2020-03-15 10:17:18	2020-03-15	9	[{"id_menu":7,"count":1}]	15159	delivery	5	14
39772	2020-03-15 10:26:41	2020-03-15	12	[{"id_menu":3,"count":1}]	11982	delivery	5	17
39773	2020-03-15 10:30:34	2020-03-15	9	[{"id_menu":6,"count":1}]	15772	delivery	5	14
39774	2020-03-15 10:31:27	2020-03-15	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	15743	delivery	5	22
39775	2020-03-15 10:34:10	2020-03-15	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1581	delivery	5	26
39776	2020-03-15 10:39:23	2020-03-15	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	15797	pick-up	0	31
39777	2020-03-15 10:42:43	2020-03-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12934	delivery	5	23
39778	2020-03-15 10:56:30	2020-03-15	9	[{"id_menu":7,"count":1}]	2570	pick-up	0	9
39779	2020-03-15 10:57:55	2020-03-15	9	[{"id_menu":6,"count":1}]	15844	delivery	5	14
39780	2020-03-15 11:05:05	2020-03-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	12760	delivery	5	28
39781	2020-03-15 11:05:16	2020-03-15	9	[{"id_menu":7,"count":1}]	752	delivery	5	14
39782	2020-03-15 11:05:55	2020-03-15	9	[{"id_menu":6,"count":1}]	576	pick-up	0	9
39783	2020-03-15 11:05:59	2020-03-15	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	15678	pick-up	0	21
39784	2020-03-15 11:05:59	2020-03-15	14	[{"id_menu":2,"count":1}]	11518	pick-up	0	14
39785	2020-03-15 11:08:11	2020-03-15	9	[{"id_menu":7,"count":1}]	12129	pick-up	0	9
39786	2020-03-15 11:14:12	2020-03-15	12	[{"id_menu":3,"count":1}]	1321	delivery	5	17
39787	2020-03-15 11:14:40	2020-03-15	14	[{"id_menu":2,"count":1}]	3730	delivery	5	19
39788	2020-03-15 11:18:12	2020-03-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6145	pick-up	0	23
39789	2020-03-15 11:19:10	2020-03-15	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	6202	pick-up	0	21
39790	2020-03-15 11:23:57	2020-03-15	17	[{"id_menu":4,"count":1}]	11581	delivery	5	22
39791	2020-03-15 11:29:57	2020-03-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4517	delivery	5	23
39792	2020-03-15 11:36:38	2020-03-15	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	6935	delivery	5	45
39793	2020-03-15 11:38:31	2020-03-15	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	204	delivery	5	47
39794	2020-03-15 11:42:09	2020-03-15	12	[{"id_menu":3,"count":1}]	4229	delivery	5	17
39795	2020-03-15 11:46:29	2020-03-15	12	[{"id_menu":1,"count":1}]	3770	delivery	5	17
39796	2020-03-15 11:49:57	2020-03-15	14	[{"id_menu":2,"count":2}]	1408	pick-up	0	14
39797	2020-03-15 11:51:52	2020-03-15	9	[{"id_menu":6,"count":1}]	9902	delivery	5	14
39798	2020-03-15 11:55:18	2020-03-15	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	15843	delivery	5	26
39799	2020-03-15 11:59:58	2020-03-15	9	[{"id_menu":6,"count":1}]	13060	delivery	5	14
39800	2020-03-15 12:00:09	2020-03-15	17	[{"id_menu":4,"count":1}]	2673	delivery	5	22
39801	2020-03-15 12:06:13	2020-03-15	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10568	delivery	5	22
39802	2020-03-15 12:17:07	2020-03-15	12	[{"id_menu":3,"count":1}]	1025	pick-up	0	12
39803	2020-03-15 12:20:22	2020-03-15	8	[{"id_menu":5,"count":2}]	13599	pick-up	0	8
39804	2020-03-15 12:26:27	2020-03-15	9	[{"id_menu":7,"count":1}]	15764	pick-up	0	9
39805	2020-03-15 12:27:27	2020-03-15	14	[{"id_menu":2,"count":1}]	12699	delivery	5	19
39806	2020-03-15 12:31:40	2020-03-15	9	[{"id_menu":6,"count":1}]	4411	delivery	5	14
39807	2020-03-15 12:33:25	2020-03-15	17	[{"id_menu":4,"count":1}]	226	pick-up	0	17
39808	2020-03-15 12:40:50	2020-03-15	17	[{"id_menu":4,"count":1}]	3119	delivery	5	22
39809	2020-03-15 12:45:29	2020-03-15	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1813	delivery	5	31
39810	2020-03-15 12:48:11	2020-03-15	14	[{"id_menu":2,"count":1}]	15749	delivery	5	19
39811	2020-03-15 12:49:54	2020-03-15	12	[{"id_menu":1,"count":1}]	12169	delivery	5	17
39812	2020-03-15 12:54:07	2020-03-15	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	11427	delivery	5	36
39813	2020-03-15 12:56:22	2020-03-15	9	[{"id_menu":7,"count":1}]	5530	delivery	5	14
39814	2020-03-15 12:56:29	2020-03-15	12	[{"id_menu":1,"count":1}]	13182	delivery	5	17
39815	2020-03-15 12:57:02	2020-03-15	14	[{"id_menu":2,"count":1}]	4192	delivery	5	19
39816	2020-03-15 12:58:41	2020-03-15	9	[{"id_menu":7,"count":1}]	5729	delivery	5	14
39817	2020-03-15 12:58:45	2020-03-15	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15765	delivery	5	48
39818	2020-03-15 13:01:52	2020-03-15	12	[{"id_menu":3,"count":1}]	8946	delivery	5	17
39819	2020-03-15 13:02:07	2020-03-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	15777	delivery	5	28
39820	2020-03-15 13:05:36	2020-03-15	12	[{"id_menu":1,"count":1}]	4380	delivery	5	17
39821	2020-03-15 13:08:07	2020-03-15	12	[{"id_menu":3,"count":1}]	13188	delivery	5	17
39822	2020-03-15 13:13:43	2020-03-15	17	[{"id_menu":4,"count":1}]	13256	pick-up	0	17
39823	2020-03-15 13:16:01	2020-03-15	12	[{"id_menu":1,"count":2}]	15827	pick-up	0	12
39824	2020-03-15 13:17:01	2020-03-15	9	[{"id_menu":6,"count":1}]	15794	delivery	5	14
39825	2020-03-15 13:17:33	2020-03-15	8	[{"id_menu":5,"count":1}]	14906	pick-up	0	8
39826	2020-03-15 13:19:12	2020-03-15	9	[{"id_menu":6,"count":1}]	15842	delivery	5	14
39827	2020-03-15 13:28:42	2020-03-15	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15836	delivery	5	45
39828	2020-03-15 13:39:00	2020-03-15	12	[{"id_menu":3,"count":1}]	15816	delivery	5	17
39829	2020-03-15 13:42:37	2020-03-15	12	[{"id_menu":1,"count":2}]	4960	delivery	5	17
39830	2020-03-15 13:48:55	2020-03-15	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	11560	delivery	5	26
39831	2020-03-15 13:53:53	2020-03-15	9	[{"id_menu":7,"count":1}]	8230	delivery	5	14
39832	2020-03-15 13:55:41	2020-03-15	14	[{"id_menu":2,"count":1}]	6953	delivery	5	19
39833	2020-03-15 14:00:14	2020-03-15	8	[{"id_menu":5,"count":1}]	15755	delivery	5	13
39834	2020-03-15 14:04:33	2020-03-15	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11535	delivery	5	35
39835	2020-03-15 14:08:45	2020-03-15	14	[{"id_menu":2,"count":1}]	9112	delivery	5	19
39836	2020-03-15 14:09:44	2020-03-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":3}]	7731	delivery	5	23
39837	2020-03-15 14:15:02	2020-03-15	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1258	delivery	5	43
39838	2020-03-15 14:19:02	2020-03-15	12	[{"id_menu":3,"count":1}]	12204	delivery	5	17
39839	2020-03-15 14:20:02	2020-03-15	9	[{"id_menu":7,"count":1}]	15785	delivery	5	14
39840	2020-03-15 14:25:23	2020-03-15	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	5654	delivery	5	27
39841	2020-03-15 14:26:29	2020-03-15	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	15243	delivery	5	31
39842	2020-03-15 14:31:01	2020-03-15	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	13713	delivery	5	28
39843	2020-03-15 14:36:35	2020-03-15	12	[{"id_menu":1,"count":1}]	15792	delivery	5	17
39844	2020-03-15 14:36:49	2020-03-15	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5917	delivery	5	22
39845	2020-03-15 14:39:04	2020-03-15	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	7204	delivery	5	31
39846	2020-03-15 14:39:10	2020-03-15	17	[{"id_menu":4,"count":1}]	13968	delivery	5	22
39847	2020-03-15 14:39:23	2020-03-15	12	[{"id_menu":1,"count":1}]	15767	delivery	5	17
39848	2020-03-15 14:40:03	2020-03-15	9	[{"id_menu":7,"count":2}]	15830	delivery	5	14
39849	2020-03-15 15:10:55	2020-03-15	9	[{"id_menu":6,"count":1}]	6883	delivery	5	14
39850	2020-03-15 15:14:58	2020-03-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15478	delivery	5	23
39851	2020-03-15 15:16:26	2020-03-15	17	[{"id_menu":4,"count":2}]	6369	pick-up	0	17
39852	2020-03-15 15:18:55	2020-03-15	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	15820	delivery	5	25
39853	2020-03-15 15:22:39	2020-03-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	15758	delivery	5	23
39854	2020-03-15 15:27:24	2020-03-15	17	[{"id_menu":4,"count":1}]	10970	delivery	5	22
39855	2020-03-15 15:53:02	2020-03-15	9	[{"id_menu":6,"count":1}]	6574	delivery	5	14
39856	2020-03-15 15:53:51	2020-03-15	8	[{"id_menu":5,"count":1}]	158	pick-up	0	8
39857	2020-03-15 15:54:01	2020-03-15	12	[{"id_menu":3,"count":1}]	7420	delivery	5	17
39858	2020-03-15 15:54:12	2020-03-15	9	[{"id_menu":6,"count":1}]	9453	delivery	5	14
39859	2020-03-15 16:05:24	2020-03-15	14	[{"id_menu":2,"count":1}]	5643	pick-up	0	14
39860	2020-03-15 16:25:05	2020-03-15	12	[{"id_menu":3,"count":1}]	15742	delivery	5	17
39861	2020-03-15 16:27:42	2020-03-15	17	[{"id_menu":4,"count":1}]	15757	delivery	5	22
39862	2020-03-15 16:28:33	2020-03-15	9	[{"id_menu":6,"count":1}]	7791	delivery	5	14
39863	2020-03-15 16:35:32	2020-03-15	14	[{"id_menu":2,"count":1}]	867	delivery	5	19
39864	2020-03-15 16:43:18	2020-03-15	9	[{"id_menu":6,"count":1}]	5850	delivery	5	14
39865	2020-03-15 16:44:04	2020-03-15	9	[{"id_menu":6,"count":1}]	41	pick-up	0	9
39866	2020-03-15 16:44:42	2020-03-15	14	[{"id_menu":2,"count":1}]	15739	delivery	5	19
39867	2020-03-15 16:44:44	2020-03-15	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6139	delivery	5	51
39868	2020-03-15 16:44:56	2020-03-15	9	[{"id_menu":7,"count":1}]	7678	delivery	5	14
39869	2020-03-15 16:52:40	2020-03-15	9	[{"id_menu":6,"count":1}]	15745	delivery	5	14
39870	2020-03-15 16:52:51	2020-03-15	9	[{"id_menu":6,"count":1}]	13021	delivery	5	14
39871	2020-03-15 16:53:20	2020-03-15	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15823	delivery	5	22
39872	2020-03-15 16:57:34	2020-03-15	12	[{"id_menu":1,"count":1}]	2252	delivery	5	17
39873	2020-03-15 16:59:51	2020-03-15	12	[{"id_menu":1,"count":1}]	117	pick-up	0	12
39874	2020-03-15 17:00:56	2020-03-15	12	[{"id_menu":1,"count":1}]	1791	pick-up	0	12
39875	2020-03-15 17:03:26	2020-03-15	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	13478	delivery	5	43
39876	2020-03-15 17:07:24	2020-03-15	8	[{"id_menu":5,"count":1}]	4815	delivery	5	13
39877	2020-03-15 17:10:36	2020-03-15	9	[{"id_menu":6,"count":1}]	14190	pick-up	0	9
39878	2020-03-15 17:13:06	2020-03-15	17	[{"id_menu":4,"count":1}]	15120	pick-up	0	17
39879	2020-03-15 17:15:51	2020-03-15	14	[{"id_menu":2,"count":1}]	9124	delivery	5	19
39880	2020-03-15 17:18:21	2020-03-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	15781	pick-up	0	23
39881	2020-03-15 17:18:29	2020-03-15	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	15837	delivery	5	38
39882	2020-03-15 17:19:25	2020-03-15	14	[{"id_menu":2,"count":1}]	15740	delivery	5	19
39883	2020-03-15 17:23:48	2020-03-15	12	[{"id_menu":1,"count":1}]	15841	delivery	5	17
39884	2020-03-15 17:25:08	2020-03-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15853	delivery	5	23
39885	2020-03-15 17:31:24	2020-03-15	9	[{"id_menu":6,"count":2}]	11183	pick-up	0	9
39886	2020-03-15 17:35:39	2020-03-15	8	[{"id_menu":5,"count":1}]	2442	delivery	5	13
39887	2020-03-15 17:36:10	2020-03-15	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	15800	delivery	5	27
39888	2020-03-15 17:36:21	2020-03-15	14	[{"id_menu":2,"count":1}]	9949	delivery	5	19
39889	2020-03-15 17:44:28	2020-03-15	9	[{"id_menu":6,"count":1}]	15737	delivery	5	14
39890	2020-03-15 17:46:41	2020-03-15	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	15747	delivery	5	22
39891	2020-03-15 17:49:06	2020-03-15	14	[{"id_menu":2,"count":1}]	15804	delivery	5	19
39892	2020-03-15 17:51:15	2020-03-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	707	delivery	5	28
39893	2020-03-15 17:59:05	2020-03-15	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	778	pick-up	0	31
39894	2020-03-15 17:59:17	2020-03-15	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	15110	pick-up	0	35
39895	2020-03-15 18:00:24	2020-03-15	17	[{"id_menu":4,"count":1}]	15763	delivery	5	22
39896	2020-03-15 18:04:09	2020-03-15	14	[{"id_menu":2,"count":1}]	349	pick-up	0	14
39897	2020-03-15 18:06:34	2020-03-15	12	[{"id_menu":1,"count":1}]	12174	delivery	5	17
39898	2020-03-15 18:16:08	2020-03-15	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15822	delivery	5	22
39899	2020-03-15 18:22:09	2020-03-15	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15770	delivery	5	34
39900	2020-03-15 18:26:18	2020-03-15	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5795	pick-up	0	25
39901	2020-03-15 18:27:22	2020-03-15	12	[{"id_menu":3,"count":2}]	13837	pick-up	0	12
39902	2020-03-15 18:27:50	2020-03-15	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7549	delivery	5	36
39903	2020-03-15 18:29:58	2020-03-15	9	[{"id_menu":7,"count":1}]	15766	delivery	5	14
39904	2020-03-15 18:30:24	2020-03-15	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	15793	pick-up	0	25
39905	2020-03-15 18:32:34	2020-03-15	14	[{"id_menu":2,"count":1}]	5222	delivery	5	19
39906	2020-03-15 18:35:55	2020-03-15	17	[{"id_menu":4,"count":1}]	9588	pick-up	0	17
39907	2020-03-15 18:37:16	2020-03-15	9	[{"id_menu":7,"count":1}]	10296	delivery	5	14
39908	2020-03-15 18:41:48	2020-03-15	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15752	delivery	5	31
39909	2020-03-15 18:47:54	2020-03-15	14	[{"id_menu":2,"count":1}]	2155	pick-up	0	14
39910	2020-03-15 18:48:37	2020-03-15	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	15824	delivery	5	25
39911	2020-03-15 18:51:57	2020-03-15	8	[{"id_menu":5,"count":1}]	15486	pick-up	0	8
39912	2020-03-15 18:54:45	2020-03-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	7042	delivery	5	31
39913	2020-03-15 18:56:07	2020-03-15	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15780	delivery	5	49
39914	2020-03-15 18:56:20	2020-03-15	9	[{"id_menu":6,"count":1}]	12469	delivery	5	14
39915	2020-03-15 19:01:34	2020-03-15	9	[{"id_menu":7,"count":1}]	12573	delivery	5	14
39916	2020-03-15 19:04:41	2020-03-15	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	12409	delivery	5	25
39917	2020-03-15 19:05:21	2020-03-15	9	[{"id_menu":6,"count":1}]	10922	delivery	5	14
39918	2020-03-15 19:06:03	2020-03-15	17	[{"id_menu":4,"count":1}]	6802	delivery	5	22
39919	2020-03-15 19:08:09	2020-03-15	8	[{"id_menu":5,"count":2}]	14782	pick-up	0	8
39920	2020-03-15 19:14:40	2020-03-15	9	[{"id_menu":7,"count":1}]	12558	pick-up	0	9
39921	2020-03-15 19:17:58	2020-03-15	14	[{"id_menu":2,"count":1}]	15750	delivery	5	19
39922	2020-03-15 19:23:14	2020-03-15	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	3315	delivery	5	26
39923	2020-03-15 19:26:25	2020-03-15	9	[{"id_menu":7,"count":1}]	6322	delivery	5	14
39924	2020-03-15 19:26:33	2020-03-15	17	[{"id_menu":4,"count":1}]	15738	delivery	5	22
39925	2020-03-15 19:27:31	2020-03-15	14	[{"id_menu":2,"count":1}]	11103	delivery	5	19
39926	2020-03-15 19:31:25	2020-03-15	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3388	delivery	5	37
39927	2020-03-15 19:37:28	2020-03-15	9	[{"id_menu":6,"count":1}]	10351	delivery	5	14
39928	2020-03-15 19:37:54	2020-03-15	9	[{"id_menu":7,"count":1}]	15849	delivery	5	14
39929	2020-03-15 19:40:50	2020-03-15	9	[{"id_menu":7,"count":1}]	8706	delivery	5	14
39930	2020-03-15 19:42:23	2020-03-15	9	[{"id_menu":7,"count":1}]	11760	delivery	5	14
39931	2020-03-15 19:46:46	2020-03-15	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	4622	delivery	5	29
39932	2020-03-15 20:00:27	2020-03-15	17	[{"id_menu":4,"count":1}]	5138	pick-up	0	17
39933	2020-03-15 20:02:21	2020-03-15	12	[{"id_menu":1,"count":1}]	1931	pick-up	0	12
39934	2020-03-15 20:04:17	2020-03-15	9	[{"id_menu":6,"count":1}]	5828	delivery	5	14
39935	2020-03-15 20:07:46	2020-03-15	12	[{"id_menu":3,"count":1}]	15795	pick-up	0	12
39936	2020-03-15 20:11:05	2020-03-15	12	[{"id_menu":3,"count":1}]	15854	pick-up	0	12
39937	2020-03-15 20:16:38	2020-03-15	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	12541	pick-up	0	33
39938	2020-03-15 20:17:15	2020-03-15	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	15805	delivery	5	27
39939	2020-03-15 20:18:18	2020-03-15	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	11020	delivery	5	44
39940	2020-03-15 20:19:56	2020-03-15	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	5437	delivery	5	40
39941	2020-03-15 20:34:55	2020-03-15	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	14819	delivery	5	26
39942	2020-03-15 20:35:51	2020-03-15	8	[{"id_menu":5,"count":1}]	15825	delivery	5	13
39943	2020-03-15 20:36:42	2020-03-15	9	[{"id_menu":7,"count":1}]	600	delivery	5	14
39944	2020-03-15 20:41:00	2020-03-15	12	[{"id_menu":3,"count":1}]	15773	delivery	5	17
39945	2020-03-15 20:43:15	2020-03-15	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	15733	delivery	5	40
39946	2020-03-15 20:43:26	2020-03-15	17	[{"id_menu":4,"count":1}]	8964	pick-up	0	17
39947	2020-03-15 20:57:23	2020-03-15	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	15807	delivery	5	26
39948	2020-03-15 20:57:54	2020-03-15	8	[{"id_menu":5,"count":1}]	14734	pick-up	0	8
39949	2020-03-15 20:59:41	2020-03-15	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	9891	delivery	5	48
39950	2020-03-15 21:04:53	2020-03-15	9	[{"id_menu":6,"count":3}]	15775	delivery	5	14
39951	2020-03-15 21:05:21	2020-03-15	9	[{"id_menu":6,"count":1}]	925	delivery	5	14
39952	2020-03-15 21:16:08	2020-03-15	8	[{"id_menu":5,"count":1}]	12800	delivery	5	13
39953	2020-03-15 21:19:43	2020-03-15	9	[{"id_menu":7,"count":1}]	15735	delivery	5	14
39954	2020-03-15 21:21:24	2020-03-15	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3031	delivery	5	31
39955	2020-03-15 21:25:51	2020-03-15	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	15085	delivery	5	22
39956	2020-03-15 21:33:28	2020-03-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15768	delivery	5	31
39957	2020-03-15 21:36:00	2020-03-15	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1970	pick-up	0	38
39958	2020-03-15 21:37:31	2020-03-15	12	[{"id_menu":1,"count":1}]	11156	pick-up	0	12
39959	2020-03-15 21:40:26	2020-03-15	8	[{"id_menu":5,"count":1}]	15309	pick-up	0	8
39960	2020-03-15 21:42:15	2020-03-15	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	2311	delivery	5	31
39961	2020-03-15 21:42:46	2020-03-15	12	[{"id_menu":1,"count":1}]	15832	delivery	5	17
39962	2020-03-15 21:45:27	2020-03-15	17	[{"id_menu":4,"count":2}]	2176	pick-up	0	17
39963	2020-03-15 21:45:31	2020-03-15	9	[{"id_menu":6,"count":1}]	15361	pick-up	0	9
39964	2020-03-15 21:46:07	2020-03-15	12	[{"id_menu":3,"count":1}]	15840	delivery	5	17
39965	2020-03-15 21:48:03	2020-03-15	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	13776	delivery	5	46
39966	2020-03-15 21:50:03	2020-03-15	8	[{"id_menu":5,"count":1}]	11822	delivery	5	13
39967	2020-03-15 21:50:32	2020-03-15	12	[{"id_menu":3,"count":1}]	8549	delivery	5	17
39968	2020-03-15 21:59:26	2020-03-15	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2771	delivery	5	34
39969	2020-03-15 22:00:28	2020-03-15	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15778	delivery	5	34
39970	2020-03-15 22:02:12	2020-03-15	9	[{"id_menu":6,"count":1}]	15801	delivery	5	14
39971	2020-03-15 22:02:54	2020-03-15	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	15814	delivery	5	30
39972	2020-03-15 22:05:45	2020-03-15	9	[{"id_menu":6,"count":1}]	9857	pick-up	0	9
39973	2020-03-15 22:07:26	2020-03-15	12	[{"id_menu":1,"count":1}]	2546	pick-up	0	12
39974	2020-03-15 22:08:59	2020-03-15	9	[{"id_menu":7,"count":1}]	14739	delivery	5	14
39975	2020-03-15 22:21:56	2020-03-15	14	[{"id_menu":2,"count":1}]	15784	delivery	5	19
39976	2020-03-15 22:23:08	2020-03-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4870	pick-up	0	23
39977	2020-03-15 22:24:53	2020-03-15	9	[{"id_menu":6,"count":1}]	14262	delivery	5	14
39978	2020-03-15 22:29:40	2020-03-15	12	[{"id_menu":3,"count":1}]	15783	delivery	5	17
39979	2020-03-15 22:33:32	2020-03-15	9	[{"id_menu":7,"count":1}]	15796	delivery	5	14
39980	2020-03-15 22:35:51	2020-03-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	15852	delivery	5	23
39981	2020-03-15 22:40:09	2020-03-15	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	15726	delivery	5	23
39982	2020-03-15 22:49:07	2020-03-15	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15759	pick-up	0	17
39983	2020-03-15 22:51:05	2020-03-15	9	[{"id_menu":7,"count":1}]	15811	delivery	5	14
39984	2020-03-15 22:57:05	2020-03-15	9	[{"id_menu":6,"count":1}]	15736	delivery	5	14
39985	2020-03-15 23:00:16	2020-03-15	17	[{"id_menu":4,"count":1}]	15771	delivery	5	22
39986	2020-03-15 23:01:08	2020-03-15	9	[{"id_menu":7,"count":1}]	13394	delivery	5	14
39987	2020-03-15 23:02:10	2020-03-15	9	[{"id_menu":6,"count":1}]	11109	delivery	5	14
39988	2020-03-15 23:08:24	2020-03-15	12	[{"id_menu":1,"count":1}]	3483	pick-up	0	12
39989	2020-03-15 23:10:38	2020-03-15	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	6609	pick-up	0	26
39990	2020-03-15 23:10:39	2020-03-15	8	[{"id_menu":5,"count":1}]	13636	delivery	5	13
39991	2020-03-15 23:10:40	2020-03-15	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7959	delivery	5	48
39992	2020-03-15 23:13:52	2020-03-15	17	[{"id_menu":4,"count":1}]	15802	pick-up	0	17
39993	2020-03-15 23:14:23	2020-03-15	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12823	delivery	5	40
39994	2020-03-15 23:14:43	2020-03-15	9	[{"id_menu":7,"count":1}]	8181	delivery	5	14
39995	2020-03-15 23:27:32	2020-03-15	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	4137	pick-up	0	21
39996	2020-03-15 23:27:44	2020-03-15	12	[{"id_menu":3,"count":1}]	14549	delivery	5	17
39997	2020-03-15 23:33:28	2020-03-15	14	[{"id_menu":2,"count":1}]	15798	pick-up	0	14
39998	2020-03-15 23:36:43	2020-03-15	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1609	pick-up	0	26
39999	2020-03-15 23:40:29	2020-03-15	8	[{"id_menu":5,"count":1}]	5604	delivery	5	13
40000	2020-03-15 23:40:43	2020-03-15	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1490	pick-up	0	29
40001	2020-03-15 23:41:47	2020-03-15	12	[{"id_menu":1,"count":1}]	11844	delivery	5	17
40002	2020-03-15 23:47:55	2020-03-15	12	[{"id_menu":3,"count":1}]	15753	delivery	5	17
40003	2020-03-15 23:50:36	2020-03-15	9	[{"id_menu":6,"count":1}]	6790	pick-up	0	9
40004	2020-03-15 23:50:55	2020-03-15	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	371	pick-up	0	20
40005	2020-03-15 23:59:16	2020-03-15	12	[{"id_menu":1,"count":1}]	4828	delivery	5	17
40006	2020-03-16 00:02:55	2020-03-16	17	[{"id_menu":4,"count":1}]	15866	pick-up	0	17
40007	2020-03-16 00:06:38	2020-03-16	14	[{"id_menu":2,"count":1}]	684	pick-up	0	14
40008	2020-03-16 00:24:21	2020-03-16	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1832	pick-up	0	26
40009	2020-03-16 00:29:32	2020-03-16	9	[{"id_menu":7,"count":1}]	2277	pick-up	0	9
40010	2020-03-16 00:33:48	2020-03-16	9	[{"id_menu":7,"count":1}]	15929	pick-up	0	9
40011	2020-03-16 00:39:09	2020-03-16	14	[{"id_menu":2,"count":1}]	15942	delivery	5	19
40012	2020-03-16 00:44:23	2020-03-16	12	[{"id_menu":1,"count":1}]	14519	pick-up	0	12
40013	2020-03-16 00:48:08	2020-03-16	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	3116	pick-up	0	29
40014	2020-03-16 01:02:35	2020-03-16	14	[{"id_menu":2,"count":1}]	15868	delivery	5	19
40015	2020-03-16 01:23:41	2020-03-16	17	[{"id_menu":4,"count":1}]	5811	delivery	5	22
40016	2020-03-16 01:29:54	2020-03-16	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	5112	pick-up	0	35
40017	2020-03-16 01:33:54	2020-03-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15922	delivery	5	22
40018	2020-03-16 01:39:57	2020-03-16	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15779	delivery	5	45
40019	2020-03-16 01:42:55	2020-03-16	8	[{"id_menu":5,"count":1}]	15896	delivery	5	13
40020	2020-03-16 02:02:57	2020-03-16	14	[{"id_menu":2,"count":1}]	1900	delivery	5	19
40021	2020-03-16 02:03:07	2020-03-16	9	[{"id_menu":7,"count":1}]	15933	delivery	5	14
40022	2020-03-16 02:03:14	2020-03-16	14	[{"id_menu":2,"count":1}]	15913	pick-up	0	14
40023	2020-03-16 02:05:00	2020-03-16	9	[{"id_menu":7,"count":1}]	1665	delivery	5	14
40024	2020-03-16 02:13:46	2020-03-16	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	1244	pick-up	0	29
40025	2020-03-16 02:30:43	2020-03-16	14	[{"id_menu":2,"count":1}]	1545	pick-up	0	14
40026	2020-03-16 02:37:26	2020-03-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2629	delivery	5	22
40027	2020-03-16 02:38:02	2020-03-16	8	[{"id_menu":5,"count":1}]	15863	delivery	5	13
40028	2020-03-16 02:45:41	2020-03-16	12	[{"id_menu":1,"count":1}]	2130	pick-up	0	12
40029	2020-03-16 02:49:32	2020-03-16	9	[{"id_menu":7,"count":1}]	15886	delivery	5	14
40030	2020-03-16 03:10:05	2020-03-16	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	15948	pick-up	0	26
40031	2020-03-16 03:11:49	2020-03-16	12	[{"id_menu":1,"count":1}]	1862	pick-up	0	12
40032	2020-03-16 03:22:51	2020-03-16	8	[{"id_menu":5,"count":1}]	11035	pick-up	0	8
40033	2020-03-16 03:30:33	2020-03-16	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15885	delivery	5	43
40034	2020-03-16 03:38:11	2020-03-16	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	5844	delivery	5	31
40035	2020-03-16 03:49:58	2020-03-16	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	9957	delivery	5	31
40036	2020-03-16 04:03:30	2020-03-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15911	delivery	5	23
40037	2020-03-16 04:11:08	2020-03-16	12	[{"id_menu":1,"count":1}]	11601	delivery	5	17
40038	2020-03-16 04:13:59	2020-03-16	8	[{"id_menu":5,"count":1}]	15897	delivery	5	13
40039	2020-03-16 04:17:47	2020-03-16	14	[{"id_menu":2,"count":1}]	12387	pick-up	0	14
40040	2020-03-16 04:27:38	2020-03-16	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6173	pick-up	0	31
40041	2020-03-16 04:29:38	2020-03-16	9	[{"id_menu":6,"count":1}]	15890	delivery	5	14
40042	2020-03-16 04:30:32	2020-03-16	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	12150	delivery	5	26
40043	2020-03-16 05:07:19	2020-03-16	8	[{"id_menu":5,"count":1}]	12650	delivery	5	13
40044	2020-03-16 05:08:23	2020-03-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4075	delivery	5	23
40045	2020-03-16 05:13:16	2020-03-16	14	[{"id_menu":2,"count":1}]	3785	pick-up	0	14
40046	2020-03-16 05:14:38	2020-03-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	456	pick-up	0	26
40047	2020-03-16 05:24:24	2020-03-16	12	[{"id_menu":1,"count":1}]	10258	pick-up	0	12
40048	2020-03-16 05:30:07	2020-03-16	9	[{"id_menu":6,"count":1}]	15853	delivery	5	14
40049	2020-03-16 05:50:36	2020-03-16	9	[{"id_menu":6,"count":1}]	15918	delivery	5	14
40050	2020-03-16 05:54:28	2020-03-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8583	delivery	5	23
40051	2020-03-16 05:56:59	2020-03-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15879	delivery	5	23
40052	2020-03-16 06:00:53	2020-03-16	12	[{"id_menu":1,"count":1}]	13488	delivery	5	17
40053	2020-03-16 06:03:51	2020-03-16	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	15953	delivery	5	26
40054	2020-03-16 06:11:30	2020-03-16	8	[{"id_menu":5,"count":1}]	12203	delivery	5	13
40055	2020-03-16 06:14:35	2020-03-16	8	[{"id_menu":5,"count":2}]	5785	delivery	5	13
40056	2020-03-16 06:14:58	2020-03-16	12	[{"id_menu":1,"count":1}]	13042	delivery	5	17
40057	2020-03-16 06:18:16	2020-03-16	9	[{"id_menu":7,"count":1}]	4835	delivery	5	14
40058	2020-03-16 06:21:26	2020-03-16	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15907	delivery	5	37
40059	2020-03-16 06:28:31	2020-03-16	12	[{"id_menu":1,"count":1}]	9423	pick-up	0	12
40060	2020-03-16 06:41:29	2020-03-16	9	[{"id_menu":6,"count":1}]	15947	delivery	5	14
40061	2020-03-16 06:49:59	2020-03-16	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15958	delivery	5	51
40062	2020-03-16 06:51:50	2020-03-16	9	[{"id_menu":6,"count":1}]	11756	delivery	5	14
40063	2020-03-16 07:09:14	2020-03-16	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15936	delivery	5	34
40064	2020-03-16 07:10:43	2020-03-16	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	15146	delivery	5	36
40065	2020-03-16 07:19:52	2020-03-16	8	[{"id_menu":5,"count":1}]	9107	pick-up	0	8
40066	2020-03-16 07:22:31	2020-03-16	9	[{"id_menu":6,"count":1}]	2134	pick-up	0	9
40067	2020-03-16 07:23:31	2020-03-16	17	[{"id_menu":4,"count":1}]	12231	delivery	5	22
40068	2020-03-16 07:33:26	2020-03-16	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	10058	delivery	5	26
40069	2020-03-16 07:35:46	2020-03-16	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2653	pick-up	0	38
40070	2020-03-16 07:37:09	2020-03-16	8	[{"id_menu":5,"count":1}]	3342	delivery	5	13
40071	2020-03-16 07:38:03	2020-03-16	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9727	delivery	5	48
40072	2020-03-16 07:54:07	2020-03-16	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12106	delivery	5	46
40073	2020-03-16 07:55:35	2020-03-16	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	15909	delivery	5	38
40074	2020-03-16 07:56:13	2020-03-16	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15874	delivery	5	34
40075	2020-03-16 07:59:30	2020-03-16	14	[{"id_menu":2,"count":1}]	5701	delivery	5	19
40076	2020-03-16 08:03:27	2020-03-16	17	[{"id_menu":4,"count":1}]	15895	delivery	5	22
40077	2020-03-16 08:05:50	2020-03-16	9	[{"id_menu":7,"count":1}]	4960	delivery	5	14
40078	2020-03-16 08:11:52	2020-03-16	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	7228	pick-up	0	29
40079	2020-03-16 08:12:02	2020-03-16	9	[{"id_menu":6,"count":1}]	15926	pick-up	0	9
40080	2020-03-16 08:12:39	2020-03-16	14	[{"id_menu":2,"count":1}]	3863	delivery	5	19
40081	2020-03-16 08:15:38	2020-03-16	17	[{"id_menu":4,"count":1}]	1432	pick-up	0	17
40082	2020-03-16 08:18:52	2020-03-16	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	15927	delivery	5	25
40083	2020-03-16 08:23:06	2020-03-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7527	delivery	5	23
40084	2020-03-16 08:38:34	2020-03-16	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	12643	delivery	5	46
40085	2020-03-16 08:45:06	2020-03-16	14	[{"id_menu":2,"count":1}]	15585	delivery	5	19
40086	2020-03-16 08:56:22	2020-03-16	12	[{"id_menu":1,"count":3}]	223	pick-up	0	12
40087	2020-03-16 09:00:27	2020-03-16	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15876	delivery	5	37
40088	2020-03-16 09:05:42	2020-03-16	12	[{"id_menu":3,"count":1}]	15881	delivery	5	17
40089	2020-03-16 09:17:04	2020-03-16	14	[{"id_menu":2,"count":2}]	3349	pick-up	0	14
40090	2020-03-16 09:17:26	2020-03-16	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	6780	pick-up	0	20
40091	2020-03-16 09:31:49	2020-03-16	12	[{"id_menu":3,"count":1}]	4436	pick-up	0	12
40092	2020-03-16 09:36:43	2020-03-16	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	15861	delivery	5	22
40093	2020-03-16 09:39:28	2020-03-16	9	[{"id_menu":6,"count":1}]	8146	delivery	5	14
40094	2020-03-16 09:39:39	2020-03-16	8	[{"id_menu":5,"count":1}]	14786	delivery	5	13
40095	2020-03-16 09:42:34	2020-03-16	12	[{"id_menu":3,"count":1}]	15960	delivery	5	17
40096	2020-03-16 09:46:27	2020-03-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15880	pick-up	0	26
40097	2020-03-16 09:47:21	2020-03-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11367	delivery	5	22
40098	2020-03-16 09:49:02	2020-03-16	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	15902	delivery	5	43
40099	2020-03-16 09:50:26	2020-03-16	9	[{"id_menu":7,"count":1}]	5668	pick-up	0	9
40100	2020-03-16 09:51:08	2020-03-16	9	[{"id_menu":6,"count":1}]	244	delivery	5	14
40101	2020-03-16 09:57:52	2020-03-16	9	[{"id_menu":6,"count":1}]	3857	delivery	5	14
40102	2020-03-16 10:09:59	2020-03-16	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14470	delivery	5	36
40103	2020-03-16 10:11:47	2020-03-16	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":2}]	15939	delivery	5	22
40104	2020-03-16 10:14:25	2020-03-16	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11908	delivery	5	34
40105	2020-03-16 10:19:35	2020-03-16	9	[{"id_menu":6,"count":1}]	2068	pick-up	0	9
40106	2020-03-16 10:20:16	2020-03-16	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	10976	delivery	5	29
40107	2020-03-16 10:33:27	2020-03-16	9	[{"id_menu":7,"count":1}]	1166	pick-up	0	9
40108	2020-03-16 10:41:06	2020-03-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8437	delivery	5	31
40109	2020-03-16 10:46:28	2020-03-16	12	[{"id_menu":3,"count":1}]	11476	pick-up	0	12
40110	2020-03-16 10:57:18	2020-03-16	12	[{"id_menu":3,"count":1}]	7186	delivery	5	17
40111	2020-03-16 10:58:47	2020-03-16	17	[{"id_menu":4,"count":1}]	15961	delivery	5	22
40112	2020-03-16 11:02:57	2020-03-16	12	[{"id_menu":1,"count":1}]	1627	pick-up	0	12
40113	2020-03-16 11:06:22	2020-03-16	12	[{"id_menu":3,"count":2}]	4622	delivery	5	17
40114	2020-03-16 11:06:47	2020-03-16	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	11010	pick-up	0	20
40115	2020-03-16 11:18:17	2020-03-16	12	[{"id_menu":3,"count":1}]	5397	delivery	5	17
40116	2020-03-16 11:21:40	2020-03-16	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	15857	delivery	5	39
40117	2020-03-16 11:22:08	2020-03-16	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	14503	delivery	5	36
40118	2020-03-16 11:22:27	2020-03-16	14	[{"id_menu":2,"count":1}]	2227	pick-up	0	14
40119	2020-03-16 11:30:15	2020-03-16	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	13583	pick-up	0	26
40120	2020-03-16 11:37:54	2020-03-16	14	[{"id_menu":2,"count":1}]	6074	pick-up	0	14
40121	2020-03-16 11:39:04	2020-03-16	14	[{"id_menu":2,"count":1}]	1944	delivery	5	19
40122	2020-03-16 11:41:57	2020-03-16	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	15938	delivery	5	48
40123	2020-03-16 11:43:11	2020-03-16	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	15858	delivery	5	31
40124	2020-03-16 11:50:05	2020-03-16	9	[{"id_menu":7,"count":1}]	757	pick-up	0	9
40125	2020-03-16 11:53:31	2020-03-16	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9081	delivery	5	43
40126	2020-03-16 11:55:28	2020-03-16	9	[{"id_menu":7,"count":1}]	15949	delivery	5	14
40127	2020-03-16 12:01:40	2020-03-16	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	9771	delivery	5	22
40128	2020-03-16 12:05:33	2020-03-16	17	[{"id_menu":4,"count":1}]	15871	delivery	5	22
40129	2020-03-16 12:13:20	2020-03-16	12	[{"id_menu":3,"count":1}]	15950	pick-up	0	12
40130	2020-03-16 12:20:19	2020-03-16	9	[{"id_menu":6,"count":1}]	7836	delivery	5	14
40131	2020-03-16 12:35:13	2020-03-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	10813	delivery	5	23
40132	2020-03-16 12:36:52	2020-03-16	8	[{"id_menu":5,"count":1}]	5103	pick-up	0	8
40133	2020-03-16 12:39:42	2020-03-16	8	[{"id_menu":5,"count":1}]	15930	delivery	5	13
40134	2020-03-16 12:56:05	2020-03-16	9	[{"id_menu":6,"count":1}]	8884	delivery	5	14
40135	2020-03-16 13:09:15	2020-03-16	14	[{"id_menu":2,"count":1}]	4646	delivery	5	19
40136	2020-03-16 13:17:37	2020-03-16	12	[{"id_menu":3,"count":1}]	13710	delivery	5	17
40137	2020-03-16 13:25:23	2020-03-16	17	[{"id_menu":4,"count":1}]	29	pick-up	0	17
40138	2020-03-16 13:28:51	2020-03-16	9	[{"id_menu":7,"count":1}]	6366	delivery	5	14
40139	2020-03-16 13:29:55	2020-03-16	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	15905	pick-up	0	35
40140	2020-03-16 13:31:32	2020-03-16	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	10391	delivery	5	34
40141	2020-03-16 13:37:19	2020-03-16	9	[{"id_menu":6,"count":1}]	15873	delivery	5	14
40142	2020-03-16 13:47:43	2020-03-16	8	[{"id_menu":5,"count":1}]	10007	pick-up	0	8
40143	2020-03-16 13:49:26	2020-03-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	15964	delivery	5	28
40144	2020-03-16 14:03:46	2020-03-16	9	[{"id_menu":7,"count":1}]	15855	delivery	5	14
40145	2020-03-16 14:23:58	2020-03-16	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15934	delivery	5	45
40146	2020-03-16 14:24:17	2020-03-16	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	7543	delivery	5	39
40147	2020-03-16 14:30:15	2020-03-16	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	507	delivery	5	54
40148	2020-03-16 14:44:30	2020-03-16	12	[{"id_menu":1,"count":1}]	5780	pick-up	0	12
40149	2020-03-16 14:52:56	2020-03-16	14	[{"id_menu":2,"count":1}]	15862	pick-up	0	14
40150	2020-03-16 14:57:12	2020-03-16	9	[{"id_menu":7,"count":1}]	10450	delivery	5	14
40151	2020-03-16 15:00:22	2020-03-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15954	delivery	5	31
40152	2020-03-16 15:03:11	2020-03-16	9	[{"id_menu":7,"count":1}]	15262	delivery	5	14
40153	2020-03-16 15:12:27	2020-03-16	8	[{"id_menu":5,"count":1}]	6873	delivery	5	13
40154	2020-03-16 15:15:08	2020-03-16	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	14679	delivery	5	48
40155	2020-03-16 15:17:45	2020-03-16	9	[{"id_menu":6,"count":1}]	15894	delivery	5	14
40156	2020-03-16 15:29:11	2020-03-16	17	[{"id_menu":4,"count":1}]	15011	delivery	5	22
40157	2020-03-16 15:31:22	2020-03-16	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	15882	delivery	5	26
40158	2020-03-16 15:41:27	2020-03-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	14935	delivery	5	26
40159	2020-03-16 15:46:34	2020-03-16	8	[{"id_menu":5,"count":1}]	15884	delivery	5	13
40160	2020-03-16 15:48:52	2020-03-16	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	15870	delivery	5	36
40161	2020-03-16 15:49:37	2020-03-16	17	[{"id_menu":4,"count":1}]	4172	delivery	5	22
40162	2020-03-16 15:52:15	2020-03-16	9	[{"id_menu":7,"count":1}]	12293	delivery	5	14
40163	2020-03-16 16:00:21	2020-03-16	14	[{"id_menu":2,"count":1}]	2065	pick-up	0	14
40164	2020-03-16 16:00:52	2020-03-16	17	[{"id_menu":4,"count":1}]	7566	pick-up	0	17
40165	2020-03-16 16:06:19	2020-03-16	9	[{"id_menu":6,"count":1}]	10800	pick-up	0	9
40166	2020-03-16 16:11:57	2020-03-16	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15919	delivery	5	39
40167	2020-03-16 16:13:45	2020-03-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15898	delivery	5	23
40168	2020-03-16 16:22:46	2020-03-16	9	[{"id_menu":6,"count":1}]	15869	pick-up	0	9
40169	2020-03-16 16:58:31	2020-03-16	8	[{"id_menu":5,"count":1}]	11553	pick-up	0	8
40170	2020-03-16 17:07:09	2020-03-16	9	[{"id_menu":6,"count":1}]	15935	delivery	5	14
40171	2020-03-16 17:09:55	2020-03-16	12	[{"id_menu":1,"count":1}]	15910	delivery	5	17
40172	2020-03-16 17:11:52	2020-03-16	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	292	delivery	5	36
40173	2020-03-16 17:13:59	2020-03-16	9	[{"id_menu":6,"count":1}]	7254	delivery	5	14
40174	2020-03-16 17:30:13	2020-03-16	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1723	pick-up	0	35
40175	2020-03-16 17:36:47	2020-03-16	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	15878	delivery	5	38
40176	2020-03-16 17:51:00	2020-03-16	8	[{"id_menu":5,"count":1}]	10518	delivery	5	13
40177	2020-03-16 17:55:30	2020-03-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15925	delivery	5	31
40178	2020-03-16 17:56:33	2020-03-16	8	[{"id_menu":5,"count":1}]	3996	delivery	5	13
40179	2020-03-16 18:05:10	2020-03-16	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	7282	delivery	5	34
40180	2020-03-16 18:05:34	2020-03-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3929	delivery	5	23
40181	2020-03-16 18:22:04	2020-03-16	8	[{"id_menu":5,"count":1}]	15917	delivery	5	13
40182	2020-03-16 18:23:35	2020-03-16	9	[{"id_menu":7,"count":1}]	14606	delivery	5	14
40183	2020-03-16 18:26:43	2020-03-16	12	[{"id_menu":3,"count":1}]	15899	delivery	5	17
40184	2020-03-16 18:39:54	2020-03-16	12	[{"id_menu":1,"count":1}]	14710	pick-up	0	12
40185	2020-03-16 18:44:53	2020-03-16	9	[{"id_menu":6,"count":1}]	14661	delivery	5	14
40186	2020-03-16 18:49:25	2020-03-16	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5699	delivery	5	40
40187	2020-03-16 18:54:37	2020-03-16	12	[{"id_menu":3,"count":1}]	7400	delivery	5	17
40188	2020-03-16 18:55:43	2020-03-16	8	[{"id_menu":5,"count":1}]	15970	delivery	5	13
40189	2020-03-16 19:06:17	2020-03-16	12	[{"id_menu":1,"count":1}]	15887	delivery	5	17
40190	2020-03-16 19:36:22	2020-03-16	9	[{"id_menu":7,"count":1}]	581	delivery	5	14
40191	2020-03-16 19:37:48	2020-03-16	17	[{"id_menu":4,"count":1}]	4973	pick-up	0	17
40192	2020-03-16 19:45:13	2020-03-16	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	15914	delivery	5	26
40193	2020-03-16 19:50:48	2020-03-16	9	[{"id_menu":7,"count":1}]	11932	delivery	5	14
40194	2020-03-16 20:00:15	2020-03-16	8	[{"id_menu":5,"count":2}]	15937	delivery	5	13
40195	2020-03-16 20:00:32	2020-03-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15859	delivery	5	31
40196	2020-03-16 20:05:56	2020-03-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	12823	delivery	5	28
40197	2020-03-16 20:21:53	2020-03-16	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15916	delivery	5	43
40198	2020-03-16 20:22:28	2020-03-16	8	[{"id_menu":5,"count":1}]	6147	delivery	5	13
40199	2020-03-16 20:24:35	2020-03-16	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	12148	delivery	5	30
40200	2020-03-16 20:41:53	2020-03-16	9	[{"id_menu":6,"count":1}]	14638	delivery	5	14
40201	2020-03-16 20:48:03	2020-03-16	9	[{"id_menu":7,"count":1}]	10209	pick-up	0	9
40202	2020-03-16 20:56:09	2020-03-16	9	[{"id_menu":6,"count":2}]	10932	delivery	5	14
40203	2020-03-16 20:56:30	2020-03-16	12	[{"id_menu":1,"count":1}]	1860	pick-up	0	12
40204	2020-03-16 20:57:43	2020-03-16	9	[{"id_menu":7,"count":1}]	15441	delivery	5	14
40205	2020-03-16 21:14:55	2020-03-16	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	15952	delivery	5	31
40206	2020-03-16 21:16:13	2020-03-16	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	13649	delivery	5	36
40207	2020-03-16 21:29:09	2020-03-16	9	[{"id_menu":7,"count":1}]	5649	delivery	5	14
40208	2020-03-16 21:40:03	2020-03-16	8	[{"id_menu":5,"count":1}]	13904	delivery	5	13
40209	2020-03-16 21:51:07	2020-03-16	12	[{"id_menu":3,"count":1}]	8998	pick-up	0	12
40210	2020-03-16 22:09:14	2020-03-16	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5768	delivery	5	34
40211	2020-03-16 22:10:55	2020-03-16	14	[{"id_menu":2,"count":1}]	15891	delivery	5	19
40212	2020-03-16 22:12:41	2020-03-16	9	[{"id_menu":7,"count":1}]	11227	pick-up	0	9
40213	2020-03-16 22:16:34	2020-03-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	15944	delivery	5	26
40214	2020-03-16 22:17:03	2020-03-16	9	[{"id_menu":6,"count":1}]	9562	delivery	5	14
40215	2020-03-16 22:37:37	2020-03-16	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":2}]	15908	delivery	5	26
40216	2020-03-16 22:38:14	2020-03-16	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	15872	delivery	5	27
40217	2020-03-16 22:39:33	2020-03-16	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	11723	delivery	5	27
40218	2020-03-16 22:51:33	2020-03-16	12	[{"id_menu":1,"count":1}]	15946	delivery	5	17
40219	2020-03-16 23:05:07	2020-03-16	9	[{"id_menu":6,"count":1}]	9847	pick-up	0	9
40220	2020-03-16 23:47:53	2020-03-16	9	[{"id_menu":7,"count":1}]	15860	delivery	5	14
40221	2020-03-16 23:51:03	2020-03-16	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14431	delivery	5	36
40222	2020-03-16 23:53:51	2020-03-16	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	15943	delivery	5	48
40223	2020-03-17 00:07:12	2020-03-17	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3421	pick-up	0	22
40224	2020-03-17 00:11:12	2020-03-17	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16066	delivery	5	22
40225	2020-03-17 00:13:34	2020-03-17	9	[{"id_menu":7,"count":1}]	4104	delivery	5	14
40226	2020-03-17 00:17:38	2020-03-17	17	[{"id_menu":4,"count":1}]	840	pick-up	0	17
40227	2020-03-17 00:21:11	2020-03-17	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	10717	pick-up	0	31
40228	2020-03-17 00:25:33	2020-03-17	14	[{"id_menu":2,"count":1}]	8213	delivery	5	19
40229	2020-03-17 00:47:09	2020-03-17	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	15427	delivery	5	25
40230	2020-03-17 00:50:08	2020-03-17	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	16038	delivery	5	34
40231	2020-03-17 00:54:31	2020-03-17	12	[{"id_menu":3,"count":1}]	955	pick-up	0	12
40232	2020-03-17 01:18:13	2020-03-17	12	[{"id_menu":1,"count":1}]	4798	delivery	5	17
40233	2020-03-17 01:20:44	2020-03-17	9	[{"id_menu":6,"count":1}]	1145	pick-up	0	9
40234	2020-03-17 01:24:07	2020-03-17	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	3558	delivery	5	35
40235	2020-03-17 01:29:30	2020-03-17	8	[{"id_menu":5,"count":1}]	2980	pick-up	0	8
40236	2020-03-17 01:36:19	2020-03-17	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8380	delivery	5	22
40237	2020-03-17 01:39:12	2020-03-17	17	[{"id_menu":4,"count":2}]	16086	delivery	5	22
40238	2020-03-17 01:39:36	2020-03-17	9	[{"id_menu":6,"count":1}]	813	delivery	5	14
40239	2020-03-17 01:41:24	2020-03-17	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	9701	delivery	5	22
40240	2020-03-17 01:42:12	2020-03-17	17	[{"id_menu":4,"count":1}]	13507	delivery	5	22
40241	2020-03-17 01:49:20	2020-03-17	9	[{"id_menu":6,"count":1}]	1687	delivery	5	14
40242	2020-03-17 01:56:37	2020-03-17	12	[{"id_menu":1,"count":1}]	2619	pick-up	0	12
40243	2020-03-17 02:01:09	2020-03-17	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	16093	delivery	5	36
40244	2020-03-17 02:02:50	2020-03-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16040	delivery	5	31
40245	2020-03-17 02:05:29	2020-03-17	17	[{"id_menu":4,"count":1}]	15971	delivery	5	22
40246	2020-03-17 02:07:01	2020-03-17	33	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	16027	delivery	5	38
40247	2020-03-17 02:08:45	2020-03-17	12	[{"id_menu":1,"count":1}]	14264	delivery	5	17
40248	2020-03-17 02:33:18	2020-03-17	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11388	delivery	5	36
40249	2020-03-17 02:43:43	2020-03-17	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	16039	delivery	5	26
40250	2020-03-17 02:53:59	2020-03-17	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2958	delivery	5	22
40251	2020-03-17 03:07:16	2020-03-17	12	[{"id_menu":3,"count":1}]	2366	delivery	5	17
40252	2020-03-17 03:15:48	2020-03-17	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	15990	delivery	5	37
40253	2020-03-17 03:20:43	2020-03-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	16056	delivery	5	28
40254	2020-03-17 03:22:10	2020-03-17	9	[{"id_menu":7,"count":1}]	1574	pick-up	0	9
40255	2020-03-17 03:32:03	2020-03-17	9	[{"id_menu":6,"count":1}]	4732	delivery	5	14
40256	2020-03-17 03:37:44	2020-03-17	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	3945	delivery	5	26
40257	2020-03-17 03:39:22	2020-03-17	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	9082	delivery	5	36
40258	2020-03-17 03:56:16	2020-03-17	9	[{"id_menu":7,"count":1}]	9303	pick-up	0	9
40259	2020-03-17 03:57:51	2020-03-17	9	[{"id_menu":6,"count":1}]	16026	delivery	5	14
40260	2020-03-17 03:59:04	2020-03-17	14	[{"id_menu":2,"count":1}]	13522	delivery	5	19
40261	2020-03-17 04:10:17	2020-03-17	8	[{"id_menu":5,"count":1}]	5823	delivery	5	13
40262	2020-03-17 04:14:49	2020-03-17	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	4562	delivery	5	25
40263	2020-03-17 04:24:32	2020-03-17	14	[{"id_menu":2,"count":1}]	16025	pick-up	0	14
40264	2020-03-17 04:25:51	2020-03-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	16043	pick-up	0	23
40265	2020-03-17 04:44:09	2020-03-17	14	[{"id_menu":2,"count":1}]	16011	delivery	5	19
40266	2020-03-17 04:55:46	2020-03-17	17	[{"id_menu":4,"count":1}]	3711	pick-up	0	17
40267	2020-03-17 04:56:23	2020-03-17	8	[{"id_menu":5,"count":1}]	11812	delivery	5	13
40268	2020-03-17 05:05:10	2020-03-17	17	[{"id_menu":4,"count":1}]	3782	pick-up	0	17
40269	2020-03-17 05:25:11	2020-03-17	17	[{"id_menu":4,"count":1}]	6492	pick-up	0	17
40270	2020-03-17 05:39:13	2020-03-17	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10354	delivery	5	48
40271	2020-03-17 05:43:26	2020-03-17	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16019	delivery	5	45
40272	2020-03-17 05:51:35	2020-03-17	17	[{"id_menu":4,"count":1}]	1097	delivery	5	22
40273	2020-03-17 06:03:15	2020-03-17	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	16098	pick-up	0	20
40274	2020-03-17 06:03:38	2020-03-17	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13481	delivery	5	22
40275	2020-03-17 06:06:05	2020-03-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8242	delivery	5	23
40276	2020-03-17 06:26:09	2020-03-17	8	[{"id_menu":5,"count":1}]	6200	delivery	5	13
40277	2020-03-17 06:28:39	2020-03-17	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	16096	delivery	5	26
40278	2020-03-17 06:33:30	2020-03-17	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16057	delivery	5	43
40279	2020-03-17 06:37:12	2020-03-17	9	[{"id_menu":6,"count":1}]	12161	delivery	5	14
40280	2020-03-17 06:38:58	2020-03-17	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3065	pick-up	0	40
40281	2020-03-17 06:50:27	2020-03-17	9	[{"id_menu":6,"count":1}]	16063	delivery	5	14
40282	2020-03-17 06:57:46	2020-03-17	17	[{"id_menu":4,"count":1}]	9273	delivery	5	22
40283	2020-03-17 06:59:29	2020-03-17	9	[{"id_menu":7,"count":1}]	16041	delivery	5	14
40284	2020-03-17 06:59:46	2020-03-17	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	16017	delivery	5	26
40285	2020-03-17 07:06:04	2020-03-17	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	16006	delivery	5	40
40286	2020-03-17 07:07:04	2020-03-17	17	[{"id_menu":4,"count":1}]	15216	pick-up	0	17
40287	2020-03-17 07:10:14	2020-03-17	8	[{"id_menu":5,"count":1}]	16009	delivery	5	13
40288	2020-03-17 07:26:53	2020-03-17	9	[{"id_menu":6,"count":1}]	12833	delivery	5	14
40289	2020-03-17 07:32:54	2020-03-17	17	[{"id_menu":4,"count":1}]	639	pick-up	0	17
40290	2020-03-17 07:35:01	2020-03-17	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13871	delivery	5	43
40291	2020-03-17 07:40:08	2020-03-17	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	16071	delivery	5	23
40292	2020-03-17 07:51:46	2020-03-17	17	[{"id_menu":4,"count":1}]	6704	pick-up	0	17
40293	2020-03-17 07:52:05	2020-03-17	12	[{"id_menu":1,"count":1}]	15995	delivery	5	17
40294	2020-03-17 07:57:11	2020-03-17	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	6600	delivery	5	34
40295	2020-03-17 07:57:18	2020-03-17	9	[{"id_menu":6,"count":1}]	8109	delivery	5	14
40296	2020-03-17 07:59:15	2020-03-17	8	[{"id_menu":5,"count":1}]	1965	pick-up	0	8
40297	2020-03-17 08:12:26	2020-03-17	17	[{"id_menu":4,"count":1}]	6511	pick-up	0	17
40298	2020-03-17 08:25:49	2020-03-17	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	7782	pick-up	0	29
40299	2020-03-17 08:31:27	2020-03-17	9	[{"id_menu":6,"count":1}]	1185	delivery	5	14
40300	2020-03-17 08:36:02	2020-03-17	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4913	delivery	5	48
40301	2020-03-17 08:45:18	2020-03-17	12	[{"id_menu":3,"count":1}]	16081	pick-up	0	12
40302	2020-03-17 08:46:10	2020-03-17	8	[{"id_menu":5,"count":1}]	11985	delivery	5	13
40303	2020-03-17 08:58:00	2020-03-17	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	3187	delivery	5	34
40304	2020-03-17 09:00:39	2020-03-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16052	delivery	5	23
40305	2020-03-17 09:04:37	2020-03-17	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	16059	delivery	5	30
40306	2020-03-17 09:07:41	2020-03-17	12	[{"id_menu":1,"count":1}]	2021	pick-up	0	12
40307	2020-03-17 09:09:23	2020-03-17	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	11350	delivery	5	31
40308	2020-03-17 09:09:51	2020-03-17	17	[{"id_menu":4,"count":1}]	15992	delivery	5	22
40309	2020-03-17 09:15:51	2020-03-17	17	[{"id_menu":4,"count":1}]	14656	delivery	5	22
40310	2020-03-17 09:16:56	2020-03-17	17	[{"id_menu":4,"count":1}]	13193	pick-up	0	17
40311	2020-03-17 09:20:27	2020-03-17	14	[{"id_menu":2,"count":1}]	2195	delivery	5	19
40312	2020-03-17 09:21:04	2020-03-17	14	[{"id_menu":2,"count":1}]	883	pick-up	0	14
40313	2020-03-17 09:32:06	2020-03-17	8	[{"id_menu":5,"count":1}]	8657	pick-up	0	8
40314	2020-03-17 09:51:24	2020-03-17	17	[{"id_menu":4,"count":1}]	16082	delivery	5	22
40315	2020-03-17 09:53:25	2020-03-17	12	[{"id_menu":3,"count":1}]	11028	pick-up	0	12
40316	2020-03-17 09:55:59	2020-03-17	14	[{"id_menu":2,"count":1}]	16060	delivery	5	19
40317	2020-03-17 09:58:21	2020-03-17	9	[{"id_menu":6,"count":1}]	738	delivery	5	14
40318	2020-03-17 09:59:52	2020-03-17	12	[{"id_menu":3,"count":1}]	235	pick-up	0	12
40319	2020-03-17 10:02:06	2020-03-17	12	[{"id_menu":1,"count":1}]	802	delivery	5	17
40320	2020-03-17 10:25:24	2020-03-17	14	[{"id_menu":2,"count":1}]	16012	delivery	5	19
40321	2020-03-17 10:25:35	2020-03-17	8	[{"id_menu":5,"count":1}]	8696	delivery	5	13
40322	2020-03-17 10:40:28	2020-03-17	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1921	pick-up	0	31
40323	2020-03-17 10:49:51	2020-03-17	17	[{"id_menu":4,"count":1}]	16091	delivery	5	22
40324	2020-03-17 10:51:19	2020-03-17	17	[{"id_menu":4,"count":1}]	15244	delivery	5	22
40325	2020-03-17 10:56:00	2020-03-17	17	[{"id_menu":4,"count":1}]	4607	pick-up	0	17
40326	2020-03-17 10:56:22	2020-03-17	9	[{"id_menu":7,"count":1}]	16036	delivery	5	14
40327	2020-03-17 10:57:20	2020-03-17	12	[{"id_menu":3,"count":1}]	15577	delivery	5	17
40328	2020-03-17 11:02:09	2020-03-17	8	[{"id_menu":5,"count":1}]	4455	delivery	5	13
40329	2020-03-17 11:05:53	2020-03-17	14	[{"id_menu":2,"count":2}]	4445	pick-up	0	14
40330	2020-03-17 11:11:28	2020-03-17	14	[{"id_menu":2,"count":1}]	14194	delivery	5	19
40331	2020-03-17 11:18:58	2020-03-17	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	8561	pick-up	0	26
40332	2020-03-17 11:27:51	2020-03-17	12	[{"id_menu":3,"count":1}]	15999	delivery	5	17
40333	2020-03-17 11:33:23	2020-03-17	9	[{"id_menu":6,"count":1}]	1193	pick-up	0	9
40334	2020-03-17 11:35:25	2020-03-17	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15144	delivery	5	22
40335	2020-03-17 11:49:06	2020-03-17	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	13578	delivery	5	22
40336	2020-03-17 11:51:18	2020-03-17	9	[{"id_menu":6,"count":1}]	16064	delivery	5	14
40337	2020-03-17 11:52:15	2020-03-17	12	[{"id_menu":1,"count":1}]	16053	delivery	5	17
40338	2020-03-17 11:53:05	2020-03-17	9	[{"id_menu":6,"count":1}]	16032	delivery	5	14
40339	2020-03-17 12:11:17	2020-03-17	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16092	delivery	5	22
40340	2020-03-17 12:13:41	2020-03-17	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4628	pick-up	0	25
40341	2020-03-17 12:26:21	2020-03-17	9	[{"id_menu":6,"count":1}]	16087	delivery	5	14
40342	2020-03-17 12:31:33	2020-03-17	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16002	delivery	5	48
40343	2020-03-17 12:36:25	2020-03-17	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	16077	delivery	5	30
40344	2020-03-17 12:47:15	2020-03-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	44	pick-up	0	23
40345	2020-03-17 12:54:02	2020-03-17	14	[{"id_menu":2,"count":1}]	1896	pick-up	0	14
40346	2020-03-17 12:54:21	2020-03-17	9	[{"id_menu":7,"count":1}]	2850	pick-up	0	9
40347	2020-03-17 13:00:18	2020-03-17	17	[{"id_menu":4,"count":1}]	708	pick-up	0	17
40348	2020-03-17 13:07:46	2020-03-17	14	[{"id_menu":2,"count":1}]	6250	pick-up	0	14
40349	2020-03-17 13:19:51	2020-03-17	9	[{"id_menu":6,"count":1}]	16033	delivery	5	14
40350	2020-03-17 13:23:17	2020-03-17	12	[{"id_menu":1,"count":1}]	5990	delivery	5	17
40351	2020-03-17 13:40:38	2020-03-17	14	[{"id_menu":2,"count":2}]	4120	pick-up	0	14
40352	2020-03-17 13:44:29	2020-03-17	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	16042	delivery	5	26
40353	2020-03-17 13:54:07	2020-03-17	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	15978	pick-up	0	34
40354	2020-03-17 13:56:54	2020-03-17	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	15972	delivery	5	31
40355	2020-03-17 14:11:55	2020-03-17	9	[{"id_menu":6,"count":1}]	3121	delivery	5	14
40356	2020-03-17 14:24:32	2020-03-17	8	[{"id_menu":5,"count":1}]	371	pick-up	0	8
40357	2020-03-17 14:26:51	2020-03-17	12	[{"id_menu":3,"count":1}]	16073	delivery	5	17
40358	2020-03-17 14:40:34	2020-03-17	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16015	delivery	5	22
40359	2020-03-17 14:42:33	2020-03-17	17	[{"id_menu":4,"count":1}]	16028	pick-up	0	17
40360	2020-03-17 14:45:23	2020-03-17	12	[{"id_menu":3,"count":1}]	4415	delivery	5	17
40361	2020-03-17 14:49:41	2020-03-17	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	1581	pick-up	0	29
40362	2020-03-17 15:17:19	2020-03-17	8	[{"id_menu":5,"count":1}]	12062	delivery	5	13
40363	2020-03-17 15:31:51	2020-03-17	9	[{"id_menu":7,"count":1}]	3732	delivery	5	14
40364	2020-03-17 15:43:18	2020-03-17	9	[{"id_menu":7,"count":1}]	16090	delivery	5	14
40365	2020-03-17 16:01:09	2020-03-17	9	[{"id_menu":7,"count":1}]	135	delivery	5	14
40366	2020-03-17 16:06:36	2020-03-17	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	8521	pick-up	0	23
40367	2020-03-17 16:11:49	2020-03-17	17	[{"id_menu":4,"count":1}]	7139	pick-up	0	17
40368	2020-03-17 16:22:01	2020-03-17	9	[{"id_menu":6,"count":1}]	15996	delivery	5	14
40369	2020-03-17 16:25:12	2020-03-17	14	[{"id_menu":2,"count":1}]	7150	delivery	5	19
40370	2020-03-17 16:40:10	2020-03-17	14	[{"id_menu":2,"count":1}]	15294	delivery	5	19
40371	2020-03-17 16:45:24	2020-03-17	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	16076	delivery	5	35
40372	2020-03-17 16:52:35	2020-03-17	9	[{"id_menu":7,"count":1}]	15976	delivery	5	14
40373	2020-03-17 17:00:14	2020-03-17	12	[{"id_menu":1,"count":1}]	588	pick-up	0	12
40374	2020-03-17 17:05:05	2020-03-17	12	[{"id_menu":3,"count":1}]	15980	delivery	5	17
40375	2020-03-17 17:11:14	2020-03-17	12	[{"id_menu":3,"count":1}]	1148	delivery	5	17
40376	2020-03-17 17:11:17	2020-03-17	9	[{"id_menu":6,"count":1}]	16051	delivery	5	14
40377	2020-03-17 17:29:53	2020-03-17	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	16007	delivery	5	25
40378	2020-03-17 17:31:29	2020-03-17	14	[{"id_menu":2,"count":1}]	15994	delivery	5	19
40379	2020-03-17 17:36:03	2020-03-17	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	7956	delivery	5	38
40380	2020-03-17 17:36:40	2020-03-17	9	[{"id_menu":6,"count":1}]	16058	delivery	5	14
40381	2020-03-17 17:38:37	2020-03-17	9	[{"id_menu":7,"count":1}]	6346	delivery	5	14
40382	2020-03-17 17:39:01	2020-03-17	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16088	delivery	5	35
40383	2020-03-17 17:47:46	2020-03-17	9	[{"id_menu":7,"count":1}]	15772	delivery	5	14
40384	2020-03-17 17:48:35	2020-03-17	8	[{"id_menu":5,"count":2}]	14360	delivery	5	13
40385	2020-03-17 17:51:48	2020-03-17	14	[{"id_menu":2,"count":1}]	16001	delivery	5	19
40386	2020-03-17 17:55:33	2020-03-17	9	[{"id_menu":6,"count":1}]	13127	delivery	5	14
40387	2020-03-17 17:56:02	2020-03-17	9	[{"id_menu":7,"count":1}]	16089	delivery	5	14
40388	2020-03-17 17:59:45	2020-03-17	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16048	delivery	5	57
40389	2020-03-17 18:01:48	2020-03-17	9	[{"id_menu":6,"count":1}]	9133	delivery	5	14
40390	2020-03-17 18:10:59	2020-03-17	12	[{"id_menu":3,"count":2}]	1044	pick-up	0	12
40391	2020-03-17 18:12:15	2020-03-17	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	15998	delivery	5	34
40392	2020-03-17 18:20:27	2020-03-17	8	[{"id_menu":5,"count":1}]	7762	pick-up	0	8
40393	2020-03-17 18:21:15	2020-03-17	9	[{"id_menu":6,"count":1}]	16055	pick-up	0	9
40394	2020-03-17 18:25:58	2020-03-17	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	15977	delivery	5	28
40395	2020-03-17 18:35:28	2020-03-17	17	[{"id_menu":4,"count":1}]	1523	pick-up	0	17
40396	2020-03-17 18:40:16	2020-03-17	9	[{"id_menu":6,"count":1}]	9061	pick-up	0	9
40397	2020-03-17 18:54:25	2020-03-17	8	[{"id_menu":5,"count":1}]	15975	delivery	5	13
40398	2020-03-17 19:18:20	2020-03-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11005	pick-up	0	18
40399	2020-03-17 19:42:37	2020-03-17	9	[{"id_menu":6,"count":1}]	16072	delivery	5	14
40400	2020-03-17 19:48:28	2020-03-17	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3439	delivery	5	31
40401	2020-03-17 19:52:10	2020-03-17	8	[{"id_menu":5,"count":1}]	251	pick-up	0	8
40402	2020-03-17 19:55:13	2020-03-17	17	[{"id_menu":4,"count":1}]	9820	pick-up	0	17
40403	2020-03-17 19:55:53	2020-03-17	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7306	pick-up	0	31
40404	2020-03-17 20:07:53	2020-03-17	9	[{"id_menu":6,"count":1}]	12987	delivery	5	14
40405	2020-03-17 20:10:30	2020-03-17	12	[{"id_menu":3,"count":1}]	16068	delivery	5	17
40406	2020-03-17 20:11:44	2020-03-17	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	13482	delivery	5	40
40407	2020-03-17 20:14:10	2020-03-17	17	[{"id_menu":4,"count":1}]	2303	pick-up	0	17
40408	2020-03-17 20:18:34	2020-03-17	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1676	pick-up	0	34
40409	2020-03-17 20:19:41	2020-03-17	17	[{"id_menu":4,"count":1}]	1021	pick-up	0	17
40410	2020-03-17 20:24:14	2020-03-17	9	[{"id_menu":6,"count":1}]	6617	pick-up	0	9
40411	2020-03-17 20:30:44	2020-03-17	9	[{"id_menu":7,"count":1}]	16069	delivery	5	14
40412	2020-03-17 20:33:46	2020-03-17	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16046	delivery	5	31
40413	2020-03-17 20:38:27	2020-03-17	14	[{"id_menu":2,"count":1}]	1529	delivery	5	19
40414	2020-03-17 20:43:00	2020-03-17	9	[{"id_menu":6,"count":1}]	7802	delivery	5	14
40415	2020-03-17 20:50:51	2020-03-17	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14336	delivery	5	45
40416	2020-03-17 20:51:00	2020-03-17	8	[{"id_menu":5,"count":1}]	11964	delivery	5	13
40417	2020-03-17 20:51:06	2020-03-17	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	153	pick-up	0	41
40418	2020-03-17 20:52:25	2020-03-17	12	[{"id_menu":3,"count":2}]	15987	pick-up	0	12
40419	2020-03-17 20:58:11	2020-03-17	14	[{"id_menu":2,"count":1}]	1626	delivery	5	19
40420	2020-03-17 21:54:37	2020-03-17	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8043	delivery	5	48
40421	2020-03-17 21:59:59	2020-03-17	12	[{"id_menu":3,"count":1}]	2089	pick-up	0	12
40422	2020-03-17 22:10:35	2020-03-17	12	[{"id_menu":3,"count":1}]	16016	delivery	5	17
40423	2020-03-17 22:16:52	2020-03-17	8	[{"id_menu":5,"count":1}]	16047	delivery	5	13
40424	2020-03-17 22:17:17	2020-03-17	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	399	pick-up	0	21
40425	2020-03-17 22:21:49	2020-03-17	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3477	pick-up	0	31
40426	2020-03-17 22:24:32	2020-03-17	14	[{"id_menu":2,"count":1}]	3883	delivery	5	19
40427	2020-03-17 22:34:48	2020-03-17	14	[{"id_menu":2,"count":2}]	2352	pick-up	0	14
40428	2020-03-17 22:43:36	2020-03-17	17	[{"id_menu":4,"count":1}]	2120	pick-up	0	17
40429	2020-03-17 22:50:02	2020-03-17	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	16061	delivery	5	25
40430	2020-03-17 22:50:52	2020-03-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	8019	pick-up	0	23
40431	2020-03-17 22:51:48	2020-03-17	14	[{"id_menu":2,"count":1}]	15993	pick-up	0	14
40432	2020-03-17 23:02:34	2020-03-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	15988	delivery	5	28
40433	2020-03-17 23:16:46	2020-03-17	17	[{"id_menu":4,"count":1}]	2426	delivery	5	22
40434	2020-03-17 23:20:49	2020-03-17	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2611	delivery	5	34
40435	2020-03-17 23:24:43	2020-03-17	9	[{"id_menu":7,"count":1}]	5668	pick-up	0	9
40436	2020-03-17 23:25:50	2020-03-17	17	[{"id_menu":4,"count":1}]	5639	pick-up	0	17
40437	2020-03-17 23:28:52	2020-03-17	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	16044	delivery	5	28
40438	2020-03-17 23:35:21	2020-03-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4560	delivery	5	31
40439	2020-03-17 23:39:16	2020-03-17	12	[{"id_menu":1,"count":1}]	8549	delivery	5	17
40440	2020-03-17 23:39:56	2020-03-17	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":2}]	11006	delivery	5	30
40441	2020-03-17 23:42:58	2020-03-17	17	[{"id_menu":4,"count":2}]	322	delivery	5	22
40442	2020-03-18 00:06:19	2020-03-18	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	16227	delivery	5	27
40443	2020-03-18 00:11:17	2020-03-18	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	4794	delivery	5	25
40444	2020-03-18 00:13:25	2020-03-18	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2228	pick-up	0	21
40445	2020-03-18 00:26:47	2020-03-18	9	[{"id_menu":6,"count":1}]	1025	pick-up	0	9
40446	2020-03-18 00:28:26	2020-03-18	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16187	delivery	5	22
40447	2020-03-18 00:35:10	2020-03-18	8	[{"id_menu":5,"count":1}]	7688	pick-up	0	8
40448	2020-03-18 00:48:28	2020-03-18	9	[{"id_menu":6,"count":1}]	13097	delivery	5	14
40449	2020-03-18 00:49:07	2020-03-18	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16152	delivery	5	48
40450	2020-03-18 00:53:09	2020-03-18	9	[{"id_menu":6,"count":1}]	14696	delivery	5	14
40451	2020-03-18 00:59:44	2020-03-18	9	[{"id_menu":6,"count":1}]	11244	delivery	5	14
40452	2020-03-18 01:00:30	2020-03-18	8	[{"id_menu":5,"count":1}]	5886	delivery	5	13
40453	2020-03-18 01:01:12	2020-03-18	8	[{"id_menu":5,"count":1}]	12699	pick-up	0	8
40454	2020-03-18 01:15:02	2020-03-18	9	[{"id_menu":6,"count":1}]	12686	pick-up	0	9
40455	2020-03-18 01:22:44	2020-03-18	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11921	delivery	5	48
40456	2020-03-18 01:24:46	2020-03-18	12	[{"id_menu":1,"count":1}]	5722	pick-up	0	12
40457	2020-03-18 01:29:00	2020-03-18	9	[{"id_menu":7,"count":1}]	9223	delivery	5	14
40458	2020-03-18 01:34:32	2020-03-18	9	[{"id_menu":6,"count":2}]	1832	pick-up	0	9
40459	2020-03-18 01:37:06	2020-03-18	9	[{"id_menu":6,"count":1}]	3380	pick-up	0	9
40460	2020-03-18 01:38:12	2020-03-18	8	[{"id_menu":5,"count":1}]	16174	delivery	5	13
40461	2020-03-18 01:38:17	2020-03-18	9	[{"id_menu":6,"count":1}]	7502	delivery	5	14
40462	2020-03-18 01:47:24	2020-03-18	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10841	delivery	5	34
40463	2020-03-18 01:55:50	2020-03-18	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	13002	delivery	5	25
40464	2020-03-18 02:04:34	2020-03-18	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	16190	delivery	5	26
40465	2020-03-18 02:04:55	2020-03-18	9	[{"id_menu":6,"count":1}]	16165	delivery	5	14
40466	2020-03-18 02:05:51	2020-03-18	12	[{"id_menu":1,"count":1}]	16112	delivery	5	17
40467	2020-03-18 02:06:52	2020-03-18	9	[{"id_menu":6,"count":1}]	12022	delivery	5	14
40468	2020-03-18 02:12:39	2020-03-18	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	7542	delivery	5	45
40469	2020-03-18 02:25:39	2020-03-18	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	11642	delivery	5	36
40470	2020-03-18 02:25:52	2020-03-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	14532	delivery	5	28
40471	2020-03-18 02:38:12	2020-03-18	14	[{"id_menu":2,"count":1}]	2613	pick-up	0	14
40472	2020-03-18 02:40:45	2020-03-18	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	2	delivery	5	25
40473	2020-03-18 02:41:19	2020-03-18	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	16150	delivery	5	44
40474	2020-03-18 02:41:24	2020-03-18	12	[{"id_menu":3,"count":1}]	2551	delivery	5	17
40475	2020-03-18 02:47:29	2020-03-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	14444	delivery	5	22
40476	2020-03-18 02:48:53	2020-03-18	12	[{"id_menu":3,"count":1}]	609	pick-up	0	12
40477	2020-03-18 02:51:17	2020-03-18	8	[{"id_menu":5,"count":1}]	16177	delivery	5	13
40478	2020-03-18 03:10:10	2020-03-18	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3784	delivery	5	42
40479	2020-03-18 03:11:40	2020-03-18	9	[{"id_menu":7,"count":1}]	511	delivery	5	14
40480	2020-03-18 03:16:36	2020-03-18	12	[{"id_menu":3,"count":2}]	7191	delivery	5	17
40481	2020-03-18 03:19:47	2020-03-18	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	5359	delivery	5	35
40482	2020-03-18 03:32:16	2020-03-18	9	[{"id_menu":6,"count":1}]	16172	delivery	5	14
40483	2020-03-18 03:36:04	2020-03-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11735	delivery	5	22
40484	2020-03-18 03:41:00	2020-03-18	8	[{"id_menu":5,"count":1}]	9394	pick-up	0	8
40485	2020-03-18 03:45:31	2020-03-18	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16153	delivery	5	31
40486	2020-03-18 03:48:08	2020-03-18	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	5939	delivery	5	40
40487	2020-03-18 03:52:29	2020-03-18	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16145	delivery	5	57
40488	2020-03-18 03:55:42	2020-03-18	9	[{"id_menu":7,"count":1}]	13103	delivery	5	14
40489	2020-03-18 03:56:27	2020-03-18	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	16226	delivery	5	39
40490	2020-03-18 03:56:51	2020-03-18	9	[{"id_menu":7,"count":1}]	6235	pick-up	0	9
40491	2020-03-18 04:09:25	2020-03-18	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	15171	delivery	5	26
40492	2020-03-18 04:13:07	2020-03-18	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16124	delivery	5	40
40493	2020-03-18 04:17:01	2020-03-18	9	[{"id_menu":6,"count":1}]	13410	delivery	5	14
40494	2020-03-18 04:19:07	2020-03-18	9	[{"id_menu":6,"count":1}]	10915	delivery	5	14
40495	2020-03-18 04:22:28	2020-03-18	14	[{"id_menu":2,"count":1}]	16128	delivery	5	19
40496	2020-03-18 04:27:58	2020-03-18	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	78	pick-up	0	26
40497	2020-03-18 04:31:02	2020-03-18	9	[{"id_menu":6,"count":1}]	1862	pick-up	0	9
40498	2020-03-18 04:40:31	2020-03-18	17	[{"id_menu":4,"count":1}]	584	pick-up	0	17
40499	2020-03-18 04:40:38	2020-03-18	9	[{"id_menu":7,"count":1}]	16107	delivery	5	14
40500	2020-03-18 04:41:42	2020-03-18	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	4701	delivery	5	36
40501	2020-03-18 04:43:25	2020-03-18	8	[{"id_menu":5,"count":1}]	1721	pick-up	0	8
40502	2020-03-18 04:50:53	2020-03-18	12	[{"id_menu":3,"count":1}]	500	pick-up	0	12
40503	2020-03-18 04:54:05	2020-03-18	17	[{"id_menu":4,"count":1}]	13930	delivery	5	22
40504	2020-03-18 05:02:54	2020-03-18	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	16175	delivery	5	34
40505	2020-03-18 05:15:31	2020-03-18	9	[{"id_menu":6,"count":1}]	4271	delivery	5	14
40506	2020-03-18 05:23:20	2020-03-18	12	[{"id_menu":1,"count":1}]	16178	delivery	5	17
40507	2020-03-18 05:25:59	2020-03-18	12	[{"id_menu":1,"count":2}]	3382	delivery	5	17
40508	2020-03-18 05:27:30	2020-03-18	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16205	delivery	5	22
40509	2020-03-18 05:30:38	2020-03-18	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	7530	delivery	5	25
40510	2020-03-18 05:33:24	2020-03-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9965	delivery	5	23
40511	2020-03-18 05:37:29	2020-03-18	12	[{"id_menu":3,"count":1}]	16127	delivery	5	17
40512	2020-03-18 05:38:59	2020-03-18	8	[{"id_menu":5,"count":1}]	8149	delivery	5	13
40513	2020-03-18 05:40:44	2020-03-18	12	[{"id_menu":3,"count":1}]	10007	pick-up	0	12
40514	2020-03-18 05:40:57	2020-03-18	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5003	delivery	5	51
40515	2020-03-18 05:44:17	2020-03-18	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2384	pick-up	0	26
40516	2020-03-18 05:55:24	2020-03-18	12	[{"id_menu":1,"count":1}]	16111	pick-up	0	12
40517	2020-03-18 05:55:46	2020-03-18	17	[{"id_menu":4,"count":1}]	16103	delivery	5	22
40518	2020-03-18 06:06:32	2020-03-18	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4694	delivery	5	55
40519	2020-03-18 06:10:03	2020-03-18	9	[{"id_menu":7,"count":1}]	16216	delivery	5	14
40520	2020-03-18 06:18:58	2020-03-18	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	3631	delivery	5	26
40521	2020-03-18 06:19:46	2020-03-18	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	14691	delivery	5	26
40522	2020-03-18 06:20:03	2020-03-18	12	[{"id_menu":3,"count":1}]	16183	delivery	5	17
40523	2020-03-18 06:21:33	2020-03-18	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	16106	delivery	5	25
40524	2020-03-18 06:23:15	2020-03-18	9	[{"id_menu":6,"count":1}]	1776	delivery	5	14
40525	2020-03-18 06:26:56	2020-03-18	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3168	pick-up	0	31
40526	2020-03-18 06:29:39	2020-03-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	8625	delivery	5	23
40527	2020-03-18 06:30:51	2020-03-18	12	[{"id_menu":1,"count":1}]	821	pick-up	0	12
40528	2020-03-18 06:34:34	2020-03-18	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7293	delivery	5	48
40529	2020-03-18 06:36:17	2020-03-18	8	[{"id_menu":5,"count":1}]	16229	delivery	5	13
40530	2020-03-18 06:41:46	2020-03-18	8	[{"id_menu":5,"count":2}]	2134	pick-up	0	8
40531	2020-03-18 06:58:57	2020-03-18	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	16212	delivery	5	34
40532	2020-03-18 07:12:05	2020-03-18	14	[{"id_menu":2,"count":1}]	5649	delivery	5	19
40533	2020-03-18 07:13:04	2020-03-18	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4085	delivery	5	22
40534	2020-03-18 07:13:57	2020-03-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16148	delivery	5	22
40601	2020-03-18 12:22:43	2020-03-18	9	[{"id_menu":6,"count":1}]	16194	delivery	5	14
40535	2020-03-18 07:14:30	2020-03-18	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	11506	delivery	5	36
40536	2020-03-18 07:17:12	2020-03-18	9	[{"id_menu":6,"count":1}]	8380	delivery	5	14
40537	2020-03-18 07:36:34	2020-03-18	9	[{"id_menu":7,"count":1}]	3640	delivery	5	14
40538	2020-03-18 07:41:22	2020-03-18	14	[{"id_menu":2,"count":1}]	1044	delivery	5	19
40539	2020-03-18 07:51:26	2020-03-18	14	[{"id_menu":2,"count":1}]	16115	delivery	5	19
40540	2020-03-18 07:52:49	2020-03-18	12	[{"id_menu":3,"count":1}]	2434	delivery	5	17
40541	2020-03-18 07:59:05	2020-03-18	17	[{"id_menu":4,"count":1}]	3825	pick-up	0	17
40542	2020-03-18 08:03:43	2020-03-18	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16182	delivery	5	36
40543	2020-03-18 08:05:46	2020-03-18	17	[{"id_menu":4,"count":1}]	12850	delivery	5	22
40544	2020-03-18 08:10:39	2020-03-18	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	16169	delivery	5	22
40545	2020-03-18 08:10:57	2020-03-18	9	[{"id_menu":7,"count":1}]	16209	delivery	5	14
40546	2020-03-18 08:12:43	2020-03-18	17	[{"id_menu":4,"count":1}]	16225	delivery	5	22
40547	2020-03-18 08:16:35	2020-03-18	8	[{"id_menu":5,"count":1}]	13199	pick-up	0	8
40548	2020-03-18 08:26:44	2020-03-18	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	11140	delivery	5	31
40549	2020-03-18 08:27:28	2020-03-18	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7899	delivery	5	53
40550	2020-03-18 08:30:11	2020-03-18	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	16147	delivery	5	26
40551	2020-03-18 08:35:26	2020-03-18	9	[{"id_menu":7,"count":1}]	16191	delivery	5	14
40552	2020-03-18 08:37:11	2020-03-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	16133	delivery	5	28
40553	2020-03-18 08:39:31	2020-03-18	9	[{"id_menu":7,"count":1}]	16132	pick-up	0	9
40554	2020-03-18 08:46:03	2020-03-18	9	[{"id_menu":7,"count":1}]	16120	delivery	5	14
40555	2020-03-18 08:46:25	2020-03-18	9	[{"id_menu":6,"count":1}]	16102	delivery	5	14
40556	2020-03-18 08:47:44	2020-03-18	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	12843	delivery	5	44
40557	2020-03-18 08:51:55	2020-03-18	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16220	delivery	5	45
40558	2020-03-18 08:57:41	2020-03-18	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	16116	pick-up	0	47
40559	2020-03-18 08:59:42	2020-03-18	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	16137	delivery	5	31
40560	2020-03-18 09:02:52	2020-03-18	14	[{"id_menu":2,"count":1}]	5138	pick-up	0	14
40561	2020-03-18 09:09:36	2020-03-18	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	16122	delivery	5	46
40562	2020-03-18 09:12:51	2020-03-18	12	[{"id_menu":3,"count":1}]	6346	delivery	5	17
40563	2020-03-18 09:18:25	2020-03-18	17	[{"id_menu":4,"count":1}]	16208	delivery	5	22
40564	2020-03-18 09:26:14	2020-03-18	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7572	pick-up	0	26
40565	2020-03-18 09:27:23	2020-03-18	9	[{"id_menu":7,"count":1}]	8234	delivery	5	14
40566	2020-03-18 09:28:40	2020-03-18	9	[{"id_menu":7,"count":1}]	5792	delivery	5	14
40567	2020-03-18 09:32:43	2020-03-18	17	[{"id_menu":4,"count":1}]	16157	delivery	5	22
40568	2020-03-18 09:34:24	2020-03-18	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	16219	delivery	5	37
40569	2020-03-18 09:38:02	2020-03-18	9	[{"id_menu":6,"count":2}]	16192	delivery	5	14
40570	2020-03-18 09:38:13	2020-03-18	14	[{"id_menu":2,"count":1}]	10152	pick-up	0	14
40571	2020-03-18 09:41:04	2020-03-18	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	6153	delivery	5	22
40572	2020-03-18 09:41:35	2020-03-18	12	[{"id_menu":1,"count":1}]	14025	pick-up	0	12
40573	2020-03-18 09:42:21	2020-03-18	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1293	delivery	5	25
40574	2020-03-18 09:43:16	2020-03-18	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12765	delivery	5	43
40575	2020-03-18 09:54:07	2020-03-18	12	[{"id_menu":1,"count":1}]	16105	delivery	5	17
40576	2020-03-18 10:07:40	2020-03-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12287	delivery	5	22
40577	2020-03-18 10:09:27	2020-03-18	8	[{"id_menu":5,"count":1}]	16211	delivery	5	13
40578	2020-03-18 10:14:40	2020-03-18	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	11303	delivery	5	43
40579	2020-03-18 10:18:48	2020-03-18	12	[{"id_menu":1,"count":1}]	389	pick-up	0	12
40580	2020-03-18 10:25:01	2020-03-18	9	[{"id_menu":6,"count":1}]	14038	pick-up	0	9
40581	2020-03-18 10:25:38	2020-03-18	9	[{"id_menu":7,"count":1}]	3456	delivery	5	14
40582	2020-03-18 10:31:04	2020-03-18	14	[{"id_menu":2,"count":1}]	9198	pick-up	0	14
40583	2020-03-18 10:33:56	2020-03-18	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	9044	delivery	5	25
40584	2020-03-18 10:38:41	2020-03-18	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	62	pick-up	0	38
40585	2020-03-18 10:38:45	2020-03-18	14	[{"id_menu":2,"count":1}]	8496	delivery	5	19
40586	2020-03-18 10:49:40	2020-03-18	14	[{"id_menu":2,"count":1}]	13050	pick-up	0	14
40587	2020-03-18 10:59:03	2020-03-18	12	[{"id_menu":3,"count":2}]	5489	delivery	5	17
40588	2020-03-18 11:08:06	2020-03-18	9	[{"id_menu":7,"count":1}]	6007	delivery	5	14
40589	2020-03-18 11:13:37	2020-03-18	12	[{"id_menu":3,"count":1}]	16156	delivery	5	17
40590	2020-03-18 11:23:40	2020-03-18	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	4678	pick-up	0	20
40591	2020-03-18 11:33:31	2020-03-18	12	[{"id_menu":1,"count":1}]	5058	delivery	5	17
40592	2020-03-18 11:33:51	2020-03-18	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10729	delivery	5	48
40593	2020-03-18 11:44:51	2020-03-18	14	[{"id_menu":2,"count":1}]	9322	delivery	5	19
40594	2020-03-18 12:03:16	2020-03-18	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	16171	delivery	5	31
40595	2020-03-18 12:07:51	2020-03-18	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	5337	delivery	5	26
40596	2020-03-18 12:11:59	2020-03-18	14	[{"id_menu":2,"count":1}]	13365	delivery	5	19
40597	2020-03-18 12:13:48	2020-03-18	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":3}]	10249	delivery	5	31
40598	2020-03-18 12:15:59	2020-03-18	8	[{"id_menu":5,"count":1}]	263	delivery	5	13
40599	2020-03-18 12:17:15	2020-03-18	12	[{"id_menu":3,"count":1}]	5043	delivery	5	17
40600	2020-03-18 12:17:16	2020-03-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16146	delivery	5	22
40602	2020-03-18 12:23:08	2020-03-18	9	[{"id_menu":6,"count":1}]	10381	pick-up	0	9
40603	2020-03-18 12:26:00	2020-03-18	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1424	pick-up	0	31
40604	2020-03-18 12:28:58	2020-03-18	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7796	delivery	5	31
40605	2020-03-18 12:30:39	2020-03-18	17	[{"id_menu":4,"count":1}]	14951	delivery	5	22
40606	2020-03-18 12:35:56	2020-03-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16221	delivery	5	22
40607	2020-03-18 12:42:25	2020-03-18	12	[{"id_menu":3,"count":2}]	14699	delivery	5	17
40608	2020-03-18 12:49:04	2020-03-18	12	[{"id_menu":1,"count":1}]	4060	delivery	5	17
40609	2020-03-18 12:49:55	2020-03-18	12	[{"id_menu":3,"count":1}]	16110	pick-up	0	12
40610	2020-03-18 12:56:24	2020-03-18	46	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	12323	delivery	5	51
40611	2020-03-18 12:57:30	2020-03-18	12	[{"id_menu":1,"count":1}]	16201	delivery	5	17
40612	2020-03-18 13:01:06	2020-03-18	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16181	delivery	5	43
40613	2020-03-18 13:04:26	2020-03-18	12	[{"id_menu":3,"count":1}]	16123	pick-up	0	12
40614	2020-03-18 13:04:36	2020-03-18	12	[{"id_menu":1,"count":1}]	2154	pick-up	0	12
40615	2020-03-18 13:11:18	2020-03-18	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4125	delivery	5	22
40616	2020-03-18 13:25:17	2020-03-18	17	[{"id_menu":4,"count":1}]	13994	delivery	5	22
40617	2020-03-18 13:29:03	2020-03-18	9	[{"id_menu":6,"count":1}]	16121	delivery	5	14
40618	2020-03-18 13:44:27	2020-03-18	12	[{"id_menu":1,"count":1}]	7253	delivery	5	17
40619	2020-03-18 13:47:00	2020-03-18	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7001	delivery	5	31
40620	2020-03-18 13:51:33	2020-03-18	9	[{"id_menu":7,"count":1}]	3135	pick-up	0	9
40621	2020-03-18 14:01:12	2020-03-18	14	[{"id_menu":2,"count":1}]	2604	delivery	5	19
40622	2020-03-18 14:01:53	2020-03-18	8	[{"id_menu":5,"count":1}]	11106	delivery	5	13
40623	2020-03-18 14:04:16	2020-03-18	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3621	pick-up	0	38
40624	2020-03-18 14:04:54	2020-03-18	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15720	pick-up	0	43
40625	2020-03-18 14:09:45	2020-03-18	12	[{"id_menu":3,"count":1}]	16185	delivery	5	17
40626	2020-03-18 14:13:52	2020-03-18	12	[{"id_menu":3,"count":1}]	6152	pick-up	0	12
40627	2020-03-18 14:14:15	2020-03-18	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	15286	delivery	5	23
40628	2020-03-18 14:18:41	2020-03-18	12	[{"id_menu":1,"count":1}]	2070	pick-up	0	12
40629	2020-03-18 14:20:37	2020-03-18	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5975	delivery	5	36
40630	2020-03-18 14:21:08	2020-03-18	14	[{"id_menu":2,"count":1}]	5268	delivery	5	19
40631	2020-03-18 14:33:36	2020-03-18	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9610	pick-up	0	26
40632	2020-03-18 14:47:16	2020-03-18	17	[{"id_menu":4,"count":1}]	11010	delivery	5	22
40633	2020-03-18 14:50:25	2020-03-18	8	[{"id_menu":5,"count":1}]	10539	pick-up	0	8
40634	2020-03-18 14:53:37	2020-03-18	9	[{"id_menu":6,"count":1}]	7574	pick-up	0	9
40635	2020-03-18 14:54:49	2020-03-18	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3077	pick-up	0	33
40636	2020-03-18 14:55:03	2020-03-18	14	[{"id_menu":2,"count":1}]	537	pick-up	0	14
40637	2020-03-18 14:55:11	2020-03-18	14	[{"id_menu":2,"count":1}]	16173	delivery	5	19
40638	2020-03-18 14:57:44	2020-03-18	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	2630	delivery	5	34
40639	2020-03-18 14:59:15	2020-03-18	9	[{"id_menu":7,"count":1}]	6901	delivery	5	14
40640	2020-03-18 15:06:17	2020-03-18	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1379	pick-up	0	31
40641	2020-03-18 15:07:54	2020-03-18	17	[{"id_menu":4,"count":1}]	1343	pick-up	0	17
40642	2020-03-18 15:16:34	2020-03-18	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	16130	delivery	5	46
40643	2020-03-18 15:21:02	2020-03-18	9	[{"id_menu":7,"count":1}]	7740	delivery	5	14
40644	2020-03-18 15:22:56	2020-03-18	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4375	delivery	5	46
40645	2020-03-18 15:23:06	2020-03-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	41	pick-up	0	23
40646	2020-03-18 15:23:27	2020-03-18	17	[{"id_menu":4,"count":1}]	4688	delivery	5	22
40647	2020-03-18 15:29:39	2020-03-18	8	[{"id_menu":5,"count":1}]	16203	delivery	5	13
40648	2020-03-18 15:29:56	2020-03-18	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	337	pick-up	0	43
40649	2020-03-18 15:38:12	2020-03-18	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	16136	delivery	5	39
40650	2020-03-18 15:41:11	2020-03-18	14	[{"id_menu":2,"count":1}]	2894	pick-up	0	14
40651	2020-03-18 15:47:40	2020-03-18	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16119	delivery	5	22
40652	2020-03-18 15:49:14	2020-03-18	14	[{"id_menu":2,"count":1}]	13780	delivery	5	19
40653	2020-03-18 15:55:55	2020-03-18	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	11760	delivery	5	26
40654	2020-03-18 15:56:15	2020-03-18	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	16186	pick-up	0	24
40655	2020-03-18 15:59:24	2020-03-18	9	[{"id_menu":6,"count":1}]	11200	delivery	5	14
40656	2020-03-18 16:00:36	2020-03-18	9	[{"id_menu":7,"count":1}]	7806	pick-up	0	9
40657	2020-03-18 16:05:21	2020-03-18	9	[{"id_menu":6,"count":1}]	11779	pick-up	0	9
40658	2020-03-18 16:13:49	2020-03-18	9	[{"id_menu":6,"count":3}]	9021	delivery	5	14
40659	2020-03-18 16:17:07	2020-03-18	12	[{"id_menu":1,"count":1}]	16151	delivery	5	17
40660	2020-03-18 16:17:36	2020-03-18	12	[{"id_menu":1,"count":1}]	13825	delivery	5	17
40661	2020-03-18 16:19:37	2020-03-18	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	2965	delivery	5	25
40662	2020-03-18 16:22:46	2020-03-18	9	[{"id_menu":6,"count":1}]	16232	delivery	5	14
40663	2020-03-18 16:25:39	2020-03-18	8	[{"id_menu":5,"count":1}]	1457	delivery	5	13
40664	2020-03-18 16:25:45	2020-03-18	12	[{"id_menu":1,"count":1}]	3651	pick-up	0	12
40665	2020-03-18 16:30:16	2020-03-18	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8408	delivery	5	52
40666	2020-03-18 16:39:50	2020-03-18	9	[{"id_menu":6,"count":1}]	416	delivery	5	14
40667	2020-03-18 16:42:55	2020-03-18	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8068	delivery	5	22
40668	2020-03-18 16:44:44	2020-03-18	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	10870	delivery	5	40
40669	2020-03-18 16:47:14	2020-03-18	9	[{"id_menu":6,"count":1}]	10212	delivery	5	14
40670	2020-03-18 16:49:10	2020-03-18	12	[{"id_menu":3,"count":1}]	13587	pick-up	0	12
40671	2020-03-18 16:49:45	2020-03-18	12	[{"id_menu":1,"count":1}]	209	delivery	5	17
40672	2020-03-18 16:55:58	2020-03-18	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	16154	delivery	5	34
40673	2020-03-18 16:57:22	2020-03-18	14	[{"id_menu":2,"count":1}]	5430	pick-up	0	14
40674	2020-03-18 16:59:49	2020-03-18	12	[{"id_menu":3,"count":1}]	16217	pick-up	0	12
40675	2020-03-18 17:04:28	2020-03-18	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16184	delivery	5	57
40676	2020-03-18 17:04:50	2020-03-18	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	13864	delivery	5	36
40677	2020-03-18 17:05:43	2020-03-18	9	[{"id_menu":7,"count":1}]	16109	delivery	5	14
40678	2020-03-18 17:09:59	2020-03-18	14	[{"id_menu":2,"count":1}]	9941	pick-up	0	14
40679	2020-03-18 17:11:03	2020-03-18	9	[{"id_menu":7,"count":1}]	16223	pick-up	0	9
40680	2020-03-18 17:18:10	2020-03-18	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	16114	pick-up	0	47
40681	2020-03-18 17:20:52	2020-03-18	17	[{"id_menu":4,"count":1}]	6978	delivery	5	22
40682	2020-03-18 17:23:10	2020-03-18	8	[{"id_menu":5,"count":1}]	16213	delivery	5	13
40683	2020-03-18 17:30:33	2020-03-18	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16159	delivery	5	34
40684	2020-03-18 17:34:21	2020-03-18	8	[{"id_menu":5,"count":1}]	2081	delivery	5	13
40685	2020-03-18 17:37:02	2020-03-18	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	7782	pick-up	0	35
40686	2020-03-18 17:37:34	2020-03-18	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16163	delivery	5	31
40687	2020-03-18 17:43:20	2020-03-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4367	pick-up	0	18
40688	2020-03-18 17:50:56	2020-03-18	9	[{"id_menu":6,"count":1}]	16108	delivery	5	14
40689	2020-03-18 18:01:59	2020-03-18	17	[{"id_menu":4,"count":1}]	1959	delivery	5	22
40690	2020-03-18 18:02:34	2020-03-18	17	[{"id_menu":4,"count":1}]	16140	delivery	5	22
40691	2020-03-18 18:07:07	2020-03-18	14	[{"id_menu":2,"count":1}]	14036	delivery	5	19
40692	2020-03-18 18:07:12	2020-03-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	12552	pick-up	0	23
40693	2020-03-18 18:07:39	2020-03-18	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3856	delivery	5	31
40694	2020-03-18 18:14:08	2020-03-18	14	[{"id_menu":2,"count":1}]	2980	delivery	5	19
40695	2020-03-18 18:18:46	2020-03-18	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	16125	pick-up	0	21
40696	2020-03-18 18:23:54	2020-03-18	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	11630	delivery	5	31
40697	2020-03-18 18:29:51	2020-03-18	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	798	pick-up	0	25
40698	2020-03-18 18:30:09	2020-03-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8145	pick-up	0	17
40699	2020-03-18 18:43:25	2020-03-18	9	[{"id_menu":6,"count":1}]	16168	delivery	5	14
40700	2020-03-18 18:44:30	2020-03-18	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16200	delivery	5	37
40701	2020-03-18 18:51:16	2020-03-18	12	[{"id_menu":1,"count":1}]	6957	delivery	5	17
40702	2020-03-18 18:56:21	2020-03-18	14	[{"id_menu":2,"count":1}]	16117	delivery	5	19
40703	2020-03-18 19:00:02	2020-03-18	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	14354	delivery	5	43
40704	2020-03-18 19:03:23	2020-03-18	9	[{"id_menu":6,"count":1}]	10264	pick-up	0	9
40705	2020-03-18 19:11:29	2020-03-18	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	16104	delivery	5	22
40706	2020-03-18 19:19:55	2020-03-18	14	[{"id_menu":2,"count":1}]	2382	delivery	5	19
40707	2020-03-18 19:24:01	2020-03-18	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	7852	delivery	5	36
40708	2020-03-18 19:25:16	2020-03-18	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	14566	delivery	5	42
40709	2020-03-18 19:31:37	2020-03-18	9	[{"id_menu":6,"count":1}]	16193	delivery	5	14
40710	2020-03-18 19:32:06	2020-03-18	9	[{"id_menu":6,"count":1}]	3767	delivery	5	14
40711	2020-03-18 19:35:14	2020-03-18	9	[{"id_menu":6,"count":1}]	1404	pick-up	0	9
40712	2020-03-18 19:36:07	2020-03-18	9	[{"id_menu":7,"count":2}]	1526	delivery	5	14
40713	2020-03-18 19:37:21	2020-03-18	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	16160	delivery	5	36
40714	2020-03-18 19:38:31	2020-03-18	9	[{"id_menu":7,"count":1}]	16204	delivery	5	14
40715	2020-03-18 19:38:45	2020-03-18	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12760	delivery	5	34
40716	2020-03-18 19:42:56	2020-03-18	12	[{"id_menu":1,"count":1}]	539	pick-up	0	12
40717	2020-03-18 20:01:44	2020-03-18	9	[{"id_menu":7,"count":1}]	10651	delivery	5	14
40718	2020-03-18 20:06:03	2020-03-18	17	[{"id_menu":4,"count":1}]	16218	delivery	5	22
40719	2020-03-18 20:07:44	2020-03-18	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	14174	delivery	5	30
40720	2020-03-18 20:08:54	2020-03-18	12	[{"id_menu":3,"count":1}]	2499	delivery	5	17
40721	2020-03-18 20:12:33	2020-03-18	12	[{"id_menu":3,"count":1}]	13650	delivery	5	17
40722	2020-03-18 20:13:27	2020-03-18	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5110	delivery	5	36
40723	2020-03-18 20:17:10	2020-03-18	12	[{"id_menu":1,"count":1}]	1480	pick-up	0	12
40724	2020-03-18 20:18:34	2020-03-18	17	[{"id_menu":4,"count":1}]	9053	delivery	5	22
40725	2020-03-18 20:20:58	2020-03-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7304	pick-up	0	23
40726	2020-03-18 20:21:52	2020-03-18	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	3761	delivery	5	31
40727	2020-03-18 20:23:59	2020-03-18	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16202	delivery	5	37
40728	2020-03-18 20:28:18	2020-03-18	12	[{"id_menu":3,"count":1}]	16198	delivery	5	17
40729	2020-03-18 20:33:34	2020-03-18	9	[{"id_menu":6,"count":1}]	10940	pick-up	0	9
40730	2020-03-18 20:40:24	2020-03-18	12	[{"id_menu":3,"count":1}]	2708	pick-up	0	12
40731	2020-03-18 20:41:00	2020-03-18	12	[{"id_menu":3,"count":1}]	6485	delivery	5	17
40732	2020-03-18 20:43:13	2020-03-18	17	[{"id_menu":4,"count":1}]	12516	delivery	5	22
40733	2020-03-18 20:43:21	2020-03-18	17	[{"id_menu":4,"count":1}]	7960	delivery	5	22
40734	2020-03-18 20:44:07	2020-03-18	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	8607	delivery	5	36
40735	2020-03-18 20:47:53	2020-03-18	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	293	pick-up	0	31
40736	2020-03-18 20:53:41	2020-03-18	12	[{"id_menu":1,"count":2}]	8284	pick-up	0	12
40737	2020-03-18 20:59:05	2020-03-18	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	16224	delivery	5	27
40738	2020-03-18 21:16:58	2020-03-18	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	16179	delivery	5	31
40739	2020-03-18 21:22:40	2020-03-18	8	[{"id_menu":5,"count":1}]	16131	delivery	5	13
40740	2020-03-18 21:23:30	2020-03-18	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	9695	delivery	5	26
40741	2020-03-18 21:42:31	2020-03-18	12	[{"id_menu":1,"count":1}]	12268	pick-up	0	12
40742	2020-03-18 21:44:31	2020-03-18	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	16180	delivery	5	40
40743	2020-03-18 21:48:26	2020-03-18	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	12095	pick-up	0	23
40744	2020-03-18 21:52:33	2020-03-18	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	11014	delivery	5	26
40745	2020-03-18 22:00:47	2020-03-18	17	[{"id_menu":4,"count":1}]	16188	delivery	5	22
40746	2020-03-18 22:05:45	2020-03-18	9	[{"id_menu":7,"count":1}]	16113	pick-up	0	9
40747	2020-03-18 22:08:06	2020-03-18	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	2579	pick-up	0	35
40748	2020-03-18 22:10:15	2020-03-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	15153	delivery	5	28
40749	2020-03-18 22:13:03	2020-03-18	14	[{"id_menu":2,"count":1}]	16196	delivery	5	19
40750	2020-03-18 22:16:16	2020-03-18	9	[{"id_menu":6,"count":1}]	16170	delivery	5	14
40751	2020-03-18 22:17:21	2020-03-18	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10331	delivery	5	45
40752	2020-03-18 22:22:21	2020-03-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	15230	delivery	5	28
40753	2020-03-18 22:28:40	2020-03-18	14	[{"id_menu":2,"count":1}]	7566	pick-up	0	14
40754	2020-03-18 22:34:05	2020-03-18	9	[{"id_menu":7,"count":1}]	16129	delivery	5	14
40755	2020-03-18 22:34:40	2020-03-18	17	[{"id_menu":4,"count":1}]	16231	delivery	5	22
40756	2020-03-18 22:39:30	2020-03-18	9	[{"id_menu":7,"count":1}]	13155	pick-up	0	9
40757	2020-03-18 22:48:19	2020-03-18	8	[{"id_menu":5,"count":1}]	16135	delivery	5	13
40758	2020-03-18 23:01:20	2020-03-18	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16195	delivery	5	22
40759	2020-03-18 23:03:50	2020-03-18	9	[{"id_menu":6,"count":2}]	8249	delivery	5	14
40760	2020-03-18 23:12:27	2020-03-18	9	[{"id_menu":7,"count":1}]	16167	delivery	5	14
40761	2020-03-18 23:19:35	2020-03-18	9	[{"id_menu":6,"count":1}]	12964	delivery	5	14
40762	2020-03-18 23:24:50	2020-03-18	17	[{"id_menu":4,"count":1}]	244	delivery	5	22
40763	2020-03-18 23:25:42	2020-03-18	9	[{"id_menu":7,"count":2}]	16143	delivery	5	14
40764	2020-03-18 23:29:46	2020-03-18	17	[{"id_menu":4,"count":1}]	13837	pick-up	0	17
40765	2020-03-18 23:39:24	2020-03-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4380	delivery	5	28
40766	2020-03-18 23:41:38	2020-03-18	9	[{"id_menu":7,"count":1}]	5478	pick-up	0	9
40767	2020-03-18 23:54:33	2020-03-18	9	[{"id_menu":6,"count":1}]	16228	pick-up	0	9
40768	2020-03-18 23:55:31	2020-03-18	34	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	8181	delivery	5	39
40769	2020-03-18 23:57:33	2020-03-18	14	[{"id_menu":2,"count":1}]	6253	delivery	5	19
40770	2020-03-19 00:00:07	2020-03-19	9	[{"id_menu":7,"count":1}]	12978	delivery	5	14
40771	2020-03-19 00:04:58	2020-03-19	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	16254	delivery	5	44
40772	2020-03-19 00:08:48	2020-03-19	9	[{"id_menu":7,"count":2}]	1724	delivery	5	14
40773	2020-03-19 00:15:25	2020-03-19	9	[{"id_menu":6,"count":1}]	7205	pick-up	0	9
40774	2020-03-19 00:18:52	2020-03-19	17	[{"id_menu":4,"count":1}]	8234	delivery	5	22
40775	2020-03-19 00:23:01	2020-03-19	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11822	delivery	5	35
40776	2020-03-19 00:24:31	2020-03-19	14	[{"id_menu":2,"count":1}]	13028	pick-up	0	14
40777	2020-03-19 00:24:52	2020-03-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16277	delivery	5	22
40778	2020-03-19 00:25:51	2020-03-19	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	14984	delivery	5	26
40779	2020-03-19 00:28:07	2020-03-19	12	[{"id_menu":1,"count":1}]	14841	delivery	5	17
40780	2020-03-19 00:32:58	2020-03-19	8	[{"id_menu":5,"count":1}]	16359	delivery	5	13
40781	2020-03-19 00:39:22	2020-03-19	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	8763	delivery	5	26
40782	2020-03-19 00:44:32	2020-03-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7339	pick-up	0	17
40783	2020-03-19 00:45:36	2020-03-19	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13948	delivery	5	36
40784	2020-03-19 00:45:50	2020-03-19	8	[{"id_menu":5,"count":1}]	2604	pick-up	0	8
40785	2020-03-19 00:49:08	2020-03-19	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	8370	delivery	5	39
40786	2020-03-19 00:51:39	2020-03-19	9	[{"id_menu":6,"count":1}]	16303	delivery	5	14
40787	2020-03-19 01:00:36	2020-03-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	16286	delivery	5	31
40788	2020-03-19 01:00:41	2020-03-19	14	[{"id_menu":2,"count":1}]	16362	pick-up	0	14
40789	2020-03-19 01:06:34	2020-03-19	37	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10580	pick-up	0	37
40790	2020-03-19 01:08:06	2020-03-19	9	[{"id_menu":6,"count":1}]	4946	delivery	5	14
40791	2020-03-19 01:09:34	2020-03-19	9	[{"id_menu":6,"count":1}]	16331	delivery	5	14
40792	2020-03-19 01:15:18	2020-03-19	14	[{"id_menu":2,"count":1}]	3710	pick-up	0	14
40793	2020-03-19 01:21:18	2020-03-19	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	13942	delivery	5	26
40794	2020-03-19 01:23:43	2020-03-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	1407	pick-up	0	18
40795	2020-03-19 01:25:35	2020-03-19	9	[{"id_menu":7,"count":1}]	16279	delivery	5	14
40796	2020-03-19 01:27:16	2020-03-19	17	[{"id_menu":4,"count":2}]	4846	delivery	5	22
40797	2020-03-19 01:28:41	2020-03-19	14	[{"id_menu":2,"count":2}]	2873	delivery	5	19
40798	2020-03-19 01:28:52	2020-03-19	12	[{"id_menu":3,"count":1}]	92	delivery	5	17
40799	2020-03-19 01:32:49	2020-03-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16354	delivery	5	31
40800	2020-03-19 01:40:43	2020-03-19	14	[{"id_menu":2,"count":1}]	12856	pick-up	0	14
40801	2020-03-19 01:47:33	2020-03-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9317	delivery	5	22
40802	2020-03-19 01:53:54	2020-03-19	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16236	delivery	5	34
40803	2020-03-19 02:04:51	2020-03-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16298	delivery	5	23
40804	2020-03-19 02:09:10	2020-03-19	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	1489	pick-up	0	21
40805	2020-03-19 02:12:52	2020-03-19	9	[{"id_menu":6,"count":1}]	11625	pick-up	0	9
40806	2020-03-19 02:14:51	2020-03-19	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	5325	delivery	5	28
40807	2020-03-19 02:16:26	2020-03-19	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	12334	pick-up	0	20
40808	2020-03-19 02:17:13	2020-03-19	9	[{"id_menu":6,"count":1}]	5930	delivery	5	14
40809	2020-03-19 02:17:20	2020-03-19	17	[{"id_menu":4,"count":1}]	2421	pick-up	0	17
40810	2020-03-19 02:17:55	2020-03-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1765	pick-up	0	17
40811	2020-03-19 02:24:32	2020-03-19	17	[{"id_menu":4,"count":1}]	16280	pick-up	0	17
40812	2020-03-19 02:28:26	2020-03-19	12	[{"id_menu":3,"count":1}]	1720	pick-up	0	12
40813	2020-03-19 02:32:06	2020-03-19	17	[{"id_menu":4,"count":1}]	16288	delivery	5	22
40814	2020-03-19 02:35:03	2020-03-19	9	[{"id_menu":6,"count":1}]	12263	pick-up	0	9
40815	2020-03-19 02:39:29	2020-03-19	17	[{"id_menu":4,"count":1}]	16332	delivery	5	22
40816	2020-03-19 02:41:23	2020-03-19	17	[{"id_menu":4,"count":1}]	15826	pick-up	0	17
40817	2020-03-19 02:45:44	2020-03-19	17	[{"id_menu":4,"count":1}]	4451	pick-up	0	17
40818	2020-03-19 02:57:18	2020-03-19	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	16276	delivery	5	34
40819	2020-03-19 03:05:17	2020-03-19	14	[{"id_menu":2,"count":1}]	3870	pick-up	0	14
40820	2020-03-19 03:06:14	2020-03-19	8	[{"id_menu":5,"count":1}]	16353	pick-up	0	8
40821	2020-03-19 03:08:38	2020-03-19	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16347	delivery	5	36
40822	2020-03-19 03:14:03	2020-03-19	9	[{"id_menu":7,"count":1}]	2199	delivery	5	14
40823	2020-03-19 03:18:04	2020-03-19	9	[{"id_menu":7,"count":1}]	16261	delivery	5	14
40824	2020-03-19 03:25:45	2020-03-19	14	[{"id_menu":2,"count":2}]	16300	delivery	5	19
40825	2020-03-19 03:25:57	2020-03-19	12	[{"id_menu":1,"count":1}]	16246	pick-up	0	12
40826	2020-03-19 03:34:35	2020-03-19	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16269	delivery	5	48
40827	2020-03-19 03:37:06	2020-03-19	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	16295	pick-up	0	21
40828	2020-03-19 03:47:25	2020-03-19	12	[{"id_menu":1,"count":1}]	1578	pick-up	0	12
40829	2020-03-19 03:51:58	2020-03-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6869	delivery	5	36
40830	2020-03-19 03:52:39	2020-03-19	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2187	pick-up	0	52
40831	2020-03-19 03:52:44	2020-03-19	12	[{"id_menu":3,"count":1}]	9402	pick-up	0	12
40832	2020-03-19 03:56:47	2020-03-19	14	[{"id_menu":2,"count":1}]	11946	delivery	5	19
40833	2020-03-19 03:56:58	2020-03-19	17	[{"id_menu":4,"count":1}]	4487	delivery	5	22
40834	2020-03-19 04:10:04	2020-03-19	9	[{"id_menu":7,"count":1}]	16285	delivery	5	14
40835	2020-03-19 04:11:58	2020-03-19	17	[{"id_menu":4,"count":1}]	2004	pick-up	0	17
40836	2020-03-19 04:18:13	2020-03-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12911	delivery	5	22
40837	2020-03-19 04:18:49	2020-03-19	9	[{"id_menu":6,"count":1}]	15423	delivery	5	14
40838	2020-03-19 04:19:23	2020-03-19	9	[{"id_menu":6,"count":1}]	13431	delivery	5	14
40839	2020-03-19 04:19:37	2020-03-19	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	553	delivery	5	25
40840	2020-03-19 04:21:19	2020-03-19	9	[{"id_menu":6,"count":1}]	10830	delivery	5	14
40841	2020-03-19 04:26:24	2020-03-19	9	[{"id_menu":7,"count":1}]	16238	delivery	5	14
40842	2020-03-19 04:35:28	2020-03-19	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	6106	delivery	5	25
40843	2020-03-19 04:40:05	2020-03-19	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	15037	delivery	5	22
40844	2020-03-19 04:49:06	2020-03-19	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	14411	delivery	5	31
40845	2020-03-19 04:57:31	2020-03-19	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12522	delivery	5	39
40846	2020-03-19 04:57:51	2020-03-19	9	[{"id_menu":7,"count":1}]	11825	delivery	5	14
40847	2020-03-19 05:02:20	2020-03-19	12	[{"id_menu":3,"count":1}]	5404	delivery	5	17
40848	2020-03-19 05:03:45	2020-03-19	14	[{"id_menu":2,"count":1}]	11973	delivery	5	19
40849	2020-03-19 05:07:58	2020-03-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16352	delivery	5	23
40850	2020-03-19 05:22:32	2020-03-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3382	delivery	5	28
40851	2020-03-19 05:22:47	2020-03-19	8	[{"id_menu":5,"count":1}]	7150	pick-up	0	8
40852	2020-03-19 05:25:43	2020-03-19	12	[{"id_menu":1,"count":1}]	8584	delivery	5	17
40853	2020-03-19 05:26:12	2020-03-19	9	[{"id_menu":7,"count":1}]	16313	delivery	5	14
40854	2020-03-19 05:31:58	2020-03-19	8	[{"id_menu":5,"count":1}]	2692	delivery	5	13
40855	2020-03-19 05:32:10	2020-03-19	9	[{"id_menu":6,"count":1}]	16278	delivery	5	14
40856	2020-03-19 05:35:01	2020-03-19	8	[{"id_menu":5,"count":1}]	3863	pick-up	0	8
40857	2020-03-19 05:52:19	2020-03-19	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	15955	delivery	5	26
40858	2020-03-19 06:01:11	2020-03-19	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	12999	delivery	5	27
40859	2020-03-19 06:10:39	2020-03-19	17	[{"id_menu":4,"count":1}]	5473	delivery	5	22
40860	2020-03-19 06:11:02	2020-03-19	9	[{"id_menu":6,"count":1}]	16358	delivery	5	14
40861	2020-03-19 06:12:21	2020-03-19	8	[{"id_menu":5,"count":1}]	16264	delivery	5	13
40862	2020-03-19 06:16:20	2020-03-19	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	507	delivery	5	39
40863	2020-03-19 06:27:45	2020-03-19	12	[{"id_menu":1,"count":1}]	16321	pick-up	0	12
40864	2020-03-19 06:27:57	2020-03-19	8	[{"id_menu":5,"count":1}]	12675	pick-up	0	8
40865	2020-03-19 06:35:58	2020-03-19	9	[{"id_menu":6,"count":1}]	16259	delivery	5	14
40866	2020-03-19 06:39:46	2020-03-19	9	[{"id_menu":6,"count":1}]	12848	delivery	5	14
40867	2020-03-19 06:45:06	2020-03-19	17	[{"id_menu":4,"count":1}]	16363	delivery	5	22
40868	2020-03-19 07:03:45	2020-03-19	9	[{"id_menu":7,"count":1}]	5246	pick-up	0	9
40869	2020-03-19 07:04:13	2020-03-19	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16307	delivery	5	34
40870	2020-03-19 07:05:53	2020-03-19	9	[{"id_menu":6,"count":1}]	16306	delivery	5	14
40871	2020-03-19 07:05:53	2020-03-19	17	[{"id_menu":4,"count":1}]	16318	delivery	5	22
40872	2020-03-19 07:08:07	2020-03-19	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5824	pick-up	0	30
40873	2020-03-19 07:09:13	2020-03-19	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	11519	delivery	5	25
40874	2020-03-19 07:12:45	2020-03-19	12	[{"id_menu":1,"count":1}]	5138	delivery	5	17
40875	2020-03-19 07:16:58	2020-03-19	17	[{"id_menu":4,"count":1}]	2139	pick-up	0	17
40876	2020-03-19 07:23:15	2020-03-19	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	9457	delivery	5	26
40877	2020-03-19 07:30:01	2020-03-19	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	6666	delivery	5	31
40878	2020-03-19 07:30:02	2020-03-19	14	[{"id_menu":2,"count":1}]	803	pick-up	0	14
40879	2020-03-19 07:31:14	2020-03-19	12	[{"id_menu":1,"count":1}]	612	pick-up	0	12
40880	2020-03-19 07:31:18	2020-03-19	14	[{"id_menu":2,"count":1}]	16368	delivery	5	19
40881	2020-03-19 07:31:31	2020-03-19	9	[{"id_menu":7,"count":1}]	16310	delivery	5	14
40882	2020-03-19 07:31:54	2020-03-19	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	11287	pick-up	0	43
40883	2020-03-19 07:35:14	2020-03-19	14	[{"id_menu":2,"count":1}]	6960	delivery	5	19
40884	2020-03-19 07:41:24	2020-03-19	14	[{"id_menu":2,"count":1}]	16301	pick-up	0	14
40885	2020-03-19 07:50:38	2020-03-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16365	delivery	5	23
40886	2020-03-19 07:54:53	2020-03-19	17	[{"id_menu":4,"count":1}]	1252	pick-up	0	17
40887	2020-03-19 08:00:27	2020-03-19	17	[{"id_menu":5,"count":3},{"id_menu":6,"count":1}]	6542	delivery	5	22
40888	2020-03-19 08:01:19	2020-03-19	14	[{"id_menu":2,"count":2}]	106	pick-up	0	14
40889	2020-03-19 08:03:18	2020-03-19	8	[{"id_menu":5,"count":2}]	1582	delivery	5	13
40890	2020-03-19 08:04:35	2020-03-19	17	[{"id_menu":4,"count":1}]	16275	delivery	5	22
40891	2020-03-19 08:04:35	2020-03-19	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	16309	pick-up	0	29
40892	2020-03-19 08:06:45	2020-03-19	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	15829	delivery	5	29
40893	2020-03-19 08:09:29	2020-03-19	12	[{"id_menu":1,"count":1}]	3972	delivery	5	17
40894	2020-03-19 08:09:44	2020-03-19	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	3064	delivery	5	36
40895	2020-03-19 08:10:47	2020-03-19	17	[{"id_menu":4,"count":1}]	16308	pick-up	0	17
40896	2020-03-19 08:14:07	2020-03-19	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13944	delivery	5	36
40897	2020-03-19 08:22:09	2020-03-19	14	[{"id_menu":2,"count":1}]	12281	delivery	5	19
40898	2020-03-19 08:24:51	2020-03-19	12	[{"id_menu":3,"count":1}]	14427	pick-up	0	12
40899	2020-03-19 08:29:06	2020-03-19	12	[{"id_menu":1,"count":1}]	16265	delivery	5	17
40900	2020-03-19 08:36:49	2020-03-19	17	[{"id_menu":4,"count":1}]	11983	delivery	5	22
40901	2020-03-19 08:43:20	2020-03-19	9	[{"id_menu":6,"count":1}]	16314	delivery	5	14
40902	2020-03-19 08:44:54	2020-03-19	12	[{"id_menu":1,"count":1}]	1813	delivery	5	17
40903	2020-03-19 08:45:08	2020-03-19	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	11867	delivery	5	26
40904	2020-03-19 08:47:16	2020-03-19	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	8684	delivery	5	34
40905	2020-03-19 08:55:42	2020-03-19	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11122	delivery	5	31
40906	2020-03-19 08:59:24	2020-03-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	4766	delivery	5	36
40907	2020-03-19 09:00:01	2020-03-19	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	16312	delivery	5	29
40908	2020-03-19 09:07:14	2020-03-19	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13000	delivery	5	53
40909	2020-03-19 09:12:22	2020-03-19	8	[{"id_menu":5,"count":1}]	643	pick-up	0	8
40910	2020-03-19 09:13:29	2020-03-19	12	[{"id_menu":1,"count":1}]	16344	delivery	5	17
40911	2020-03-19 09:15:25	2020-03-19	12	[{"id_menu":3,"count":1}]	8999	delivery	5	17
40912	2020-03-19 09:18:39	2020-03-19	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4787	pick-up	0	26
40913	2020-03-19 09:22:12	2020-03-19	9	[{"id_menu":6,"count":1}]	11760	delivery	5	14
40914	2020-03-19 09:36:25	2020-03-19	12	[{"id_menu":1,"count":1}]	16330	pick-up	0	12
40915	2020-03-19 09:36:48	2020-03-19	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	16274	delivery	5	43
40916	2020-03-19 09:36:54	2020-03-19	9	[{"id_menu":7,"count":1}]	980	pick-up	0	9
40917	2020-03-19 09:37:21	2020-03-19	8	[{"id_menu":5,"count":1}]	16289	delivery	5	13
40918	2020-03-19 09:39:41	2020-03-19	14	[{"id_menu":2,"count":1}]	16302	delivery	5	19
40919	2020-03-19 09:40:09	2020-03-19	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	16346	delivery	5	26
40920	2020-03-19 09:40:56	2020-03-19	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	16250	delivery	5	42
40921	2020-03-19 09:57:27	2020-03-19	17	[{"id_menu":4,"count":1}]	7933	delivery	5	22
40922	2020-03-19 10:09:40	2020-03-19	8	[{"id_menu":5,"count":1}]	8089	pick-up	0	8
40923	2020-03-19 10:11:35	2020-03-19	8	[{"id_menu":5,"count":1}]	14680	delivery	5	13
40924	2020-03-19 10:12:15	2020-03-19	14	[{"id_menu":2,"count":1}]	10613	delivery	5	19
40925	2020-03-19 10:14:49	2020-03-19	12	[{"id_menu":1,"count":1}]	9723	delivery	5	17
40926	2020-03-19 10:26:40	2020-03-19	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14963	delivery	5	31
40927	2020-03-19 10:31:48	2020-03-19	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	4435	pick-up	0	26
40928	2020-03-19 10:42:53	2020-03-19	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12236	delivery	5	54
40929	2020-03-19 10:47:48	2020-03-19	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	16342	delivery	5	26
40930	2020-03-19 10:55:09	2020-03-19	12	[{"id_menu":3,"count":1}]	4870	pick-up	0	12
40931	2020-03-19 11:00:04	2020-03-19	17	[{"id_menu":4,"count":1}]	15656	delivery	5	22
40932	2020-03-19 11:13:31	2020-03-19	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	2241	delivery	5	26
40933	2020-03-19 11:13:41	2020-03-19	9	[{"id_menu":6,"count":1}]	16256	delivery	5	14
40934	2020-03-19 11:25:21	2020-03-19	9	[{"id_menu":6,"count":2}]	5394	delivery	5	14
40935	2020-03-19 11:29:50	2020-03-19	9	[{"id_menu":7,"count":1}]	14881	delivery	5	14
40936	2020-03-19 11:30:07	2020-03-19	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1674	pick-up	0	26
40937	2020-03-19 11:37:39	2020-03-19	14	[{"id_menu":2,"count":1}]	14903	pick-up	0	14
40938	2020-03-19 11:42:05	2020-03-19	17	[{"id_menu":4,"count":1}]	8748	pick-up	0	17
40939	2020-03-19 11:58:17	2020-03-19	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11478	delivery	5	48
40940	2020-03-19 12:05:38	2020-03-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4506	delivery	5	31
40941	2020-03-19 12:12:13	2020-03-19	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	7615	pick-up	0	26
40942	2020-03-19 12:19:12	2020-03-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8212	delivery	5	22
40943	2020-03-19 12:34:09	2020-03-19	17	[{"id_menu":4,"count":1}]	16271	delivery	5	22
40944	2020-03-19 12:37:58	2020-03-19	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	16324	delivery	5	27
40945	2020-03-19 12:40:19	2020-03-19	14	[{"id_menu":2,"count":1}]	13464	pick-up	0	14
40946	2020-03-19 12:40:35	2020-03-19	14	[{"id_menu":2,"count":1}]	5118	pick-up	0	14
40947	2020-03-19 12:48:47	2020-03-19	8	[{"id_menu":5,"count":1}]	16284	delivery	5	13
40948	2020-03-19 12:49:52	2020-03-19	14	[{"id_menu":2,"count":1}]	8392	pick-up	0	14
40949	2020-03-19 12:58:24	2020-03-19	9	[{"id_menu":6,"count":1}]	9260	delivery	5	14
40950	2020-03-19 12:59:15	2020-03-19	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	16361	delivery	5	26
40951	2020-03-19 13:05:47	2020-03-19	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	16323	delivery	5	26
40952	2020-03-19 13:07:38	2020-03-19	9	[{"id_menu":7,"count":1}]	16351	delivery	5	14
40953	2020-03-19 13:15:55	2020-03-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	6778	delivery	5	22
40954	2020-03-19 13:17:51	2020-03-19	14	[{"id_menu":2,"count":1}]	11454	pick-up	0	14
40955	2020-03-19 13:20:30	2020-03-19	17	[{"id_menu":4,"count":1}]	16268	delivery	5	22
40956	2020-03-19 13:21:04	2020-03-19	17	[{"id_menu":4,"count":2}]	16367	delivery	5	22
40957	2020-03-19 13:29:09	2020-03-19	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16247	delivery	5	34
40958	2020-03-19 13:31:14	2020-03-19	8	[{"id_menu":5,"count":1}]	4655	delivery	5	13
40959	2020-03-19 13:31:17	2020-03-19	8	[{"id_menu":5,"count":1}]	677	delivery	5	13
40960	2020-03-19 13:37:55	2020-03-19	14	[{"id_menu":2,"count":1}]	16249	delivery	5	19
40961	2020-03-19 13:38:27	2020-03-19	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	87	delivery	5	31
40962	2020-03-19 13:40:06	2020-03-19	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	7053	pick-up	0	26
40963	2020-03-19 13:40:12	2020-03-19	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	10892	delivery	5	23
40964	2020-03-19 13:50:56	2020-03-19	17	[{"id_menu":4,"count":1}]	8656	delivery	5	22
40965	2020-03-19 13:51:37	2020-03-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7312	delivery	5	28
40966	2020-03-19 14:00:41	2020-03-19	12	[{"id_menu":3,"count":1}]	16244	pick-up	0	12
40967	2020-03-19 14:02:52	2020-03-19	8	[{"id_menu":5,"count":1}]	16293	delivery	5	13
40968	2020-03-19 14:04:33	2020-03-19	9	[{"id_menu":6,"count":1}]	16360	delivery	5	14
40969	2020-03-19 14:29:42	2020-03-19	14	[{"id_menu":2,"count":1}]	14173	delivery	5	19
40970	2020-03-19 14:32:41	2020-03-19	9	[{"id_menu":7,"count":1}]	9156	delivery	5	14
40971	2020-03-19 14:56:29	2020-03-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2875	delivery	5	36
40972	2020-03-19 15:00:03	2020-03-19	9	[{"id_menu":7,"count":1}]	6609	delivery	5	14
40973	2020-03-19 15:07:04	2020-03-19	8	[{"id_menu":5,"count":1}]	2425	pick-up	0	8
40974	2020-03-19 15:15:10	2020-03-19	9	[{"id_menu":6,"count":1}]	998	pick-up	0	9
40975	2020-03-19 15:18:21	2020-03-19	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6668	delivery	5	34
40976	2020-03-19 15:21:35	2020-03-19	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16237	delivery	5	45
40977	2020-03-19 15:22:20	2020-03-19	17	[{"id_menu":4,"count":1}]	1044	pick-up	0	17
40978	2020-03-19 15:23:51	2020-03-19	9	[{"id_menu":6,"count":1}]	743	delivery	5	14
40979	2020-03-19 15:23:53	2020-03-19	9	[{"id_menu":7,"count":1}]	16245	delivery	5	14
40980	2020-03-19 15:31:48	2020-03-19	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	4263	delivery	5	26
40981	2020-03-19 15:32:48	2020-03-19	9	[{"id_menu":7,"count":1}]	7377	pick-up	0	9
40982	2020-03-19 15:33:19	2020-03-19	9	[{"id_menu":7,"count":1}]	16335	pick-up	0	9
40983	2020-03-19 15:38:30	2020-03-19	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	16283	delivery	5	31
40984	2020-03-19 15:43:33	2020-03-19	8	[{"id_menu":5,"count":1}]	15387	delivery	5	13
40985	2020-03-19 15:46:48	2020-03-19	9	[{"id_menu":6,"count":1}]	7595	pick-up	0	9
40986	2020-03-19 15:49:47	2020-03-19	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	16304	delivery	5	40
40987	2020-03-19 15:53:30	2020-03-19	12	[{"id_menu":1,"count":1}]	8114	delivery	5	17
40988	2020-03-19 15:56:09	2020-03-19	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1461	pick-up	0	24
40989	2020-03-19 16:00:25	2020-03-19	9	[{"id_menu":7,"count":1}]	1095	pick-up	0	9
40990	2020-03-19 16:01:28	2020-03-19	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	10090	delivery	5	40
40991	2020-03-19 16:10:50	2020-03-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16255	delivery	5	22
40992	2020-03-19 16:12:15	2020-03-19	17	[{"id_menu":4,"count":1}]	4510	delivery	5	22
40993	2020-03-19 16:18:59	2020-03-19	12	[{"id_menu":3,"count":1}]	5917	delivery	5	17
40994	2020-03-19 16:20:45	2020-03-19	9	[{"id_menu":6,"count":1}]	16334	delivery	5	14
40995	2020-03-19 16:22:58	2020-03-19	8	[{"id_menu":5,"count":1}]	16356	delivery	5	13
40996	2020-03-19 16:23:16	2020-03-19	9	[{"id_menu":6,"count":1}]	11011	delivery	5	14
40997	2020-03-19 16:23:22	2020-03-19	14	[{"id_menu":2,"count":2}]	16258	delivery	5	19
40998	2020-03-19 16:23:42	2020-03-19	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1810	delivery	5	39
40999	2020-03-19 16:23:56	2020-03-19	12	[{"id_menu":1,"count":1}]	10542	delivery	5	17
41000	2020-03-19 16:25:29	2020-03-19	12	[{"id_menu":1,"count":1}]	14722	pick-up	0	12
41001	2020-03-19 16:40:09	2020-03-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16305	delivery	5	22
41002	2020-03-19 16:54:41	2020-03-19	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15679	delivery	5	45
41003	2020-03-19 16:56:09	2020-03-19	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	7441	delivery	5	42
41004	2020-03-19 16:58:25	2020-03-19	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16243	delivery	5	57
41005	2020-03-19 17:02:55	2020-03-19	12	[{"id_menu":3,"count":1}]	10525	delivery	5	17
41006	2020-03-19 17:04:42	2020-03-19	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":2}]	3615	delivery	5	28
41007	2020-03-19 17:07:53	2020-03-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16291	delivery	5	23
41008	2020-03-19 17:20:09	2020-03-19	9	[{"id_menu":7,"count":1}]	552	delivery	5	14
41009	2020-03-19 17:25:23	2020-03-19	12	[{"id_menu":1,"count":1}]	16355	pick-up	0	12
41010	2020-03-19 17:26:22	2020-03-19	9	[{"id_menu":6,"count":1}]	6762	delivery	5	14
41011	2020-03-19 17:28:49	2020-03-19	8	[{"id_menu":5,"count":1}]	16239	delivery	5	13
41012	2020-03-19 17:32:11	2020-03-19	12	[{"id_menu":3,"count":1}]	9728	delivery	5	17
41013	2020-03-19 17:36:21	2020-03-19	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	16316	delivery	5	31
41014	2020-03-19 17:42:20	2020-03-19	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1592	pick-up	0	22
41015	2020-03-19 17:43:12	2020-03-19	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	11789	delivery	5	46
41016	2020-03-19 17:47:07	2020-03-19	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12687	delivery	5	57
41017	2020-03-19 17:49:37	2020-03-19	12	[{"id_menu":1,"count":1}]	4130	delivery	5	17
41018	2020-03-19 17:51:07	2020-03-19	12	[{"id_menu":1,"count":1}]	2373	delivery	5	17
41019	2020-03-19 17:57:19	2020-03-19	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16345	delivery	5	31
41020	2020-03-19 18:01:37	2020-03-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9291	delivery	5	22
41021	2020-03-19 18:03:28	2020-03-19	8	[{"id_menu":5,"count":1}]	6678	delivery	5	13
41022	2020-03-19 18:04:17	2020-03-19	14	[{"id_menu":2,"count":1}]	10747	delivery	5	19
41023	2020-03-19 18:04:36	2020-03-19	17	[{"id_menu":4,"count":1}]	16328	pick-up	0	17
41024	2020-03-19 18:07:20	2020-03-19	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	12852	delivery	5	44
41025	2020-03-19 18:08:56	2020-03-19	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	3830	pick-up	0	29
41026	2020-03-19 18:10:45	2020-03-19	9	[{"id_menu":6,"count":1}]	13245	pick-up	0	9
41027	2020-03-19 18:18:20	2020-03-19	9	[{"id_menu":7,"count":1}]	6433	delivery	5	14
41028	2020-03-19 18:22:32	2020-03-19	12	[{"id_menu":1,"count":1}]	189	delivery	5	17
41029	2020-03-19 18:22:54	2020-03-19	9	[{"id_menu":6,"count":1}]	14103	delivery	5	14
41030	2020-03-19 18:24:05	2020-03-19	9	[{"id_menu":6,"count":1}]	6773	delivery	5	14
41031	2020-03-19 18:25:21	2020-03-19	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8057	delivery	5	43
41032	2020-03-19 18:33:16	2020-03-19	9	[{"id_menu":7,"count":1}]	16297	delivery	5	14
41033	2020-03-19 18:36:50	2020-03-19	12	[{"id_menu":1,"count":1}]	3364	delivery	5	17
41034	2020-03-19 18:37:17	2020-03-19	12	[{"id_menu":1,"count":1}]	13916	delivery	5	17
41035	2020-03-19 18:41:15	2020-03-19	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14622	pick-up	0	30
41036	2020-03-19 18:57:05	2020-03-19	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1676	delivery	5	43
41037	2020-03-19 18:58:47	2020-03-19	12	[{"id_menu":1,"count":1}]	16248	delivery	5	17
41038	2020-03-19 19:01:33	2020-03-19	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	14726	delivery	5	40
41039	2020-03-19 19:04:36	2020-03-19	8	[{"id_menu":5,"count":1}]	928	pick-up	0	8
41040	2020-03-19 19:12:41	2020-03-19	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	16287	delivery	5	26
41041	2020-03-19 19:13:22	2020-03-19	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16026	delivery	5	48
41042	2020-03-19 19:19:52	2020-03-19	9	[{"id_menu":7,"count":1}]	5120	delivery	5	14
41043	2020-03-19 19:31:11	2020-03-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	154	delivery	5	36
41044	2020-03-19 19:32:08	2020-03-19	9	[{"id_menu":6,"count":1}]	11386	delivery	5	14
41045	2020-03-19 19:34:10	2020-03-19	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	688	delivery	5	31
41046	2020-03-19 19:34:39	2020-03-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	128	pick-up	0	31
41047	2020-03-19 19:35:10	2020-03-19	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16329	delivery	5	51
41048	2020-03-19 19:36:32	2020-03-19	17	[{"id_menu":4,"count":1}]	16251	delivery	5	22
41049	2020-03-19 19:44:30	2020-03-19	9	[{"id_menu":6,"count":1}]	16336	delivery	5	14
41050	2020-03-19 19:44:34	2020-03-19	46	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	12546	delivery	5	51
41051	2020-03-19 19:46:39	2020-03-19	14	[{"id_menu":2,"count":1}]	8316	delivery	5	19
41052	2020-03-19 19:58:07	2020-03-19	12	[{"id_menu":1,"count":1}]	204	pick-up	0	12
41053	2020-03-19 20:04:08	2020-03-19	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	12928	delivery	5	34
41054	2020-03-19 20:17:32	2020-03-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3864	pick-up	0	17
41055	2020-03-19 20:23:32	2020-03-19	12	[{"id_menu":1,"count":1}]	15250	delivery	5	17
41056	2020-03-19 20:28:18	2020-03-19	12	[{"id_menu":3,"count":1}]	14334	pick-up	0	12
41057	2020-03-19 20:35:52	2020-03-19	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3077	pick-up	0	29
41058	2020-03-19 20:38:17	2020-03-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	11181	delivery	5	22
41059	2020-03-19 20:38:23	2020-03-19	12	[{"id_menu":3,"count":1}]	4223	pick-up	0	12
41060	2020-03-19 20:39:12	2020-03-19	9	[{"id_menu":6,"count":1}]	16326	delivery	5	14
41061	2020-03-19 20:50:17	2020-03-19	37	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	14558	pick-up	0	37
41062	2020-03-19 21:05:51	2020-03-19	8	[{"id_menu":5,"count":1}]	5373	pick-up	0	8
41063	2020-03-19 21:07:36	2020-03-19	9	[{"id_menu":6,"count":2}]	13094	delivery	5	14
41064	2020-03-19 21:13:52	2020-03-19	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	930	pick-up	0	29
41065	2020-03-19 21:14:19	2020-03-19	14	[{"id_menu":2,"count":1}]	15944	delivery	5	19
41066	2020-03-19 21:23:02	2020-03-19	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9906	delivery	5	40
41067	2020-03-19 21:23:30	2020-03-19	17	[{"id_menu":4,"count":1}]	13572	delivery	5	22
41068	2020-03-19 21:24:04	2020-03-19	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	16252	delivery	5	39
41069	2020-03-19 21:30:40	2020-03-19	9	[{"id_menu":6,"count":2}]	16296	delivery	5	14
41070	2020-03-19 21:34:47	2020-03-19	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	16339	delivery	5	27
41071	2020-03-19 21:45:53	2020-03-19	12	[{"id_menu":3,"count":1}]	16240	delivery	5	17
41072	2020-03-19 21:47:23	2020-03-19	17	[{"id_menu":4,"count":1}]	7638	delivery	5	22
41073	2020-03-19 21:48:53	2020-03-19	17	[{"id_menu":4,"count":1}]	16350	delivery	5	22
41074	2020-03-19 21:49:57	2020-03-19	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	16263	delivery	5	22
41075	2020-03-19 21:52:12	2020-03-19	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	996	pick-up	0	31
41076	2020-03-19 21:52:48	2020-03-19	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16364	delivery	5	34
41077	2020-03-19 21:54:03	2020-03-19	14	[{"id_menu":2,"count":1}]	5381	delivery	5	19
41078	2020-03-19 21:55:35	2020-03-19	12	[{"id_menu":1,"count":1}]	6658	pick-up	0	12
41079	2020-03-19 21:57:01	2020-03-19	9	[{"id_menu":7,"count":1}]	16320	delivery	5	14
41080	2020-03-19 22:03:30	2020-03-19	14	[{"id_menu":2,"count":1}]	16262	delivery	5	19
41081	2020-03-19 22:05:03	2020-03-19	9	[{"id_menu":7,"count":1}]	6168	delivery	5	14
41082	2020-03-19 22:07:29	2020-03-19	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10277	delivery	5	45
41083	2020-03-19 22:11:00	2020-03-19	14	[{"id_menu":2,"count":1}]	16311	delivery	5	19
41084	2020-03-19 22:12:32	2020-03-19	12	[{"id_menu":3,"count":1}]	16338	delivery	5	17
41085	2020-03-19 22:15:37	2020-03-19	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	16349	delivery	5	44
41086	2020-03-19 22:16:17	2020-03-19	8	[{"id_menu":5,"count":1}]	280	pick-up	0	8
41087	2020-03-19 22:21:34	2020-03-19	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	5201	pick-up	0	26
41088	2020-03-19 22:25:17	2020-03-19	14	[{"id_menu":2,"count":1}]	1900	pick-up	0	14
41089	2020-03-19 22:26:30	2020-03-19	9	[{"id_menu":6,"count":1}]	9819	delivery	5	14
41090	2020-03-19 22:30:59	2020-03-19	8	[{"id_menu":5,"count":1}]	6987	delivery	5	13
41091	2020-03-19 22:37:53	2020-03-19	9	[{"id_menu":6,"count":2}]	9894	delivery	5	14
41092	2020-03-19 22:41:37	2020-03-19	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3557	pick-up	0	29
41093	2020-03-19 22:43:55	2020-03-19	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	16266	delivery	5	34
41094	2020-03-19 22:44:34	2020-03-19	9	[{"id_menu":7,"count":1}]	16260	delivery	5	14
41095	2020-03-19 22:45:08	2020-03-19	14	[{"id_menu":2,"count":1}]	16270	delivery	5	19
41096	2020-03-19 22:46:21	2020-03-19	12	[{"id_menu":3,"count":1}]	14569	delivery	5	17
41097	2020-03-19 22:47:04	2020-03-19	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16325	delivery	5	43
41098	2020-03-19 22:57:24	2020-03-19	12	[{"id_menu":3,"count":1}]	16257	delivery	5	17
41099	2020-03-19 23:01:53	2020-03-19	9	[{"id_menu":6,"count":1}]	9833	delivery	5	14
41100	2020-03-19 23:04:49	2020-03-19	12	[{"id_menu":1,"count":1}]	14519	pick-up	0	12
41101	2020-03-19 23:07:51	2020-03-19	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1656	pick-up	0	26
41102	2020-03-19 23:10:13	2020-03-19	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8538	delivery	5	40
41103	2020-03-19 23:10:29	2020-03-19	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	12649	delivery	5	27
41104	2020-03-19 23:12:41	2020-03-19	17	[{"id_menu":4,"count":1}]	16294	pick-up	0	17
41105	2020-03-19 23:15:08	2020-03-19	9	[{"id_menu":7,"count":1}]	7810	pick-up	0	9
41106	2020-03-19 23:18:25	2020-03-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9974	delivery	5	23
41107	2020-03-19 23:21:55	2020-03-19	17	[{"id_menu":4,"count":1}]	11615	pick-up	0	17
41108	2020-03-19 23:28:40	2020-03-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4983	delivery	5	31
41109	2020-03-19 23:30:57	2020-03-19	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	16340	delivery	5	26
41110	2020-03-19 23:32:00	2020-03-19	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11373	delivery	5	55
41111	2020-03-19 23:39:19	2020-03-19	17	[{"id_menu":4,"count":1}]	14168	delivery	5	22
41112	2020-03-19 23:42:00	2020-03-19	17	[{"id_menu":4,"count":1}]	16357	delivery	5	22
41113	2020-03-19 23:43:06	2020-03-19	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	16234	delivery	5	39
41114	2020-03-19 23:45:46	2020-03-19	12	[{"id_menu":1,"count":1}]	16267	delivery	5	17
41115	2020-03-19 23:49:12	2020-03-19	9	[{"id_menu":7,"count":1}]	467	delivery	5	14
41116	2020-03-19 23:50:25	2020-03-19	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	7622	delivery	5	22
41117	2020-03-19 23:51:00	2020-03-19	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16299	delivery	5	35
41118	2020-03-19 23:51:18	2020-03-19	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14668	delivery	5	43
41119	2020-03-19 23:51:59	2020-03-19	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1185	delivery	5	39
41120	2020-03-19 23:55:58	2020-03-19	21	[{"id_menu":1,"count":3},{"id_menu":6,"count":1}]	7813	delivery	5	26
41121	2020-03-19 23:58:20	2020-03-19	14	[{"id_menu":2,"count":2}]	4607	delivery	5	19
41122	2020-03-19 23:59:39	2020-03-19	14	[{"id_menu":2,"count":1}]	16337	pick-up	0	14
41123	2020-03-20 00:05:57	2020-03-20	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	16450	delivery	5	34
41124	2020-03-20 00:06:53	2020-03-20	12	[{"id_menu":1,"count":1}]	8730	pick-up	0	12
41125	2020-03-20 00:07:50	2020-03-20	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	12823	delivery	5	26
41126	2020-03-20 00:08:26	2020-03-20	9	[{"id_menu":6,"count":1}]	16440	delivery	5	14
41127	2020-03-20 00:21:02	2020-03-20	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	5427	delivery	5	26
41128	2020-03-20 00:24:25	2020-03-20	8	[{"id_menu":5,"count":1}]	13397	delivery	5	13
41129	2020-03-20 00:25:52	2020-03-20	9	[{"id_menu":6,"count":1}]	845	delivery	5	14
41130	2020-03-20 00:28:12	2020-03-20	9	[{"id_menu":6,"count":1}]	13120	pick-up	0	9
41131	2020-03-20 00:32:52	2020-03-20	14	[{"id_menu":2,"count":1}]	2217	pick-up	0	14
41132	2020-03-20 00:40:02	2020-03-20	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	14202	delivery	5	31
41133	2020-03-20 00:54:18	2020-03-20	9	[{"id_menu":6,"count":1}]	1563	pick-up	0	9
41134	2020-03-20 00:54:22	2020-03-20	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16473	delivery	5	43
41135	2020-03-20 00:57:52	2020-03-20	14	[{"id_menu":2,"count":1}]	389	delivery	5	19
41136	2020-03-20 00:59:08	2020-03-20	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16471	delivery	5	43
41137	2020-03-20 01:06:41	2020-03-20	9	[{"id_menu":6,"count":1}]	10373	delivery	5	14
41138	2020-03-20 01:08:50	2020-03-20	9	[{"id_menu":6,"count":1}]	16400	delivery	5	14
41139	2020-03-20 01:09:33	2020-03-20	9	[{"id_menu":7,"count":1}]	10024	delivery	5	14
41140	2020-03-20 01:22:09	2020-03-20	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3576	delivery	5	37
41141	2020-03-20 01:22:25	2020-03-20	8	[{"id_menu":5,"count":1}]	16456	delivery	5	13
41142	2020-03-20 01:22:44	2020-03-20	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":2}]	6817	pick-up	0	31
41143	2020-03-20 01:32:41	2020-03-20	14	[{"id_menu":2,"count":1}]	111	pick-up	0	14
41144	2020-03-20 01:33:53	2020-03-20	8	[{"id_menu":5,"count":1}]	299	delivery	5	13
41145	2020-03-20 01:35:30	2020-03-20	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	12078	delivery	5	26
41146	2020-03-20 01:48:19	2020-03-20	14	[{"id_menu":2,"count":1}]	16434	pick-up	0	14
41147	2020-03-20 01:50:25	2020-03-20	12	[{"id_menu":3,"count":1}]	5649	delivery	5	17
41148	2020-03-20 01:50:58	2020-03-20	14	[{"id_menu":2,"count":1}]	3296	pick-up	0	14
41149	2020-03-20 02:03:36	2020-03-20	12	[{"id_menu":1,"count":1}]	12740	delivery	5	17
41150	2020-03-20 02:16:40	2020-03-20	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	16439	delivery	5	31
41151	2020-03-20 02:17:12	2020-03-20	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2897	pick-up	0	25
41152	2020-03-20 02:33:15	2020-03-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	13828	delivery	5	23
41153	2020-03-20 02:38:47	2020-03-20	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	7530	delivery	5	27
41154	2020-03-20 02:39:53	2020-03-20	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2200	pick-up	0	26
41155	2020-03-20 02:41:35	2020-03-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":3}]	6276	delivery	5	28
41156	2020-03-20 02:43:03	2020-03-20	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	16344	delivery	5	34
41157	2020-03-20 02:56:32	2020-03-20	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	16426	delivery	5	43
41158	2020-03-20 02:58:18	2020-03-20	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16449	delivery	5	37
41159	2020-03-20 03:01:36	2020-03-20	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	16481	pick-up	0	31
41160	2020-03-20 03:14:39	2020-03-20	14	[{"id_menu":2,"count":3}]	16374	delivery	5	19
41161	2020-03-20 03:23:22	2020-03-20	12	[{"id_menu":1,"count":1}]	14969	pick-up	0	12
41162	2020-03-20 03:23:38	2020-03-20	17	[{"id_menu":4,"count":1}]	2608	delivery	5	22
41163	2020-03-20 03:26:09	2020-03-20	14	[{"id_menu":2,"count":1}]	16451	delivery	5	19
41164	2020-03-20 03:29:16	2020-03-20	12	[{"id_menu":1,"count":1}]	3399	pick-up	0	12
41165	2020-03-20 03:32:27	2020-03-20	12	[{"id_menu":3,"count":1}]	13593	pick-up	0	12
41166	2020-03-20 03:36:00	2020-03-20	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5110	delivery	5	52
41167	2020-03-20 03:43:51	2020-03-20	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2575	pick-up	0	41
41168	2020-03-20 03:55:34	2020-03-20	9	[{"id_menu":6,"count":1}]	2440	delivery	5	14
41169	2020-03-20 04:01:41	2020-03-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16388	delivery	5	22
41170	2020-03-20 04:06:25	2020-03-20	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	16482	pick-up	0	21
41171	2020-03-20 04:07:22	2020-03-20	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	10815	delivery	5	39
41172	2020-03-20 04:10:54	2020-03-20	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1715	delivery	5	31
41173	2020-03-20 04:10:56	2020-03-20	8	[{"id_menu":5,"count":1}]	16328	pick-up	0	8
41174	2020-03-20 04:22:40	2020-03-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7279	delivery	5	23
41175	2020-03-20 04:23:51	2020-03-20	9	[{"id_menu":7,"count":1}]	11367	delivery	5	14
41176	2020-03-20 04:27:17	2020-03-20	17	[{"id_menu":4,"count":1}]	7796	delivery	5	22
41177	2020-03-20 04:41:30	2020-03-20	14	[{"id_menu":2,"count":1}]	1296	pick-up	0	14
41178	2020-03-20 04:43:40	2020-03-20	9	[{"id_menu":6,"count":1}]	9657	delivery	5	14
41179	2020-03-20 04:50:32	2020-03-20	9	[{"id_menu":6,"count":1}]	4609	pick-up	0	9
41180	2020-03-20 05:01:10	2020-03-20	12	[{"id_menu":3,"count":1}]	3812	pick-up	0	12
41181	2020-03-20 05:04:29	2020-03-20	17	[{"id_menu":4,"count":2}]	16380	pick-up	0	17
41182	2020-03-20 05:06:32	2020-03-20	12	[{"id_menu":3,"count":1}]	16446	delivery	5	17
41183	2020-03-20 05:27:29	2020-03-20	17	[{"id_menu":4,"count":1}]	203	pick-up	0	17
41184	2020-03-20 05:33:11	2020-03-20	9	[{"id_menu":7,"count":1}]	2536	delivery	5	14
41185	2020-03-20 05:41:39	2020-03-20	12	[{"id_menu":3,"count":1}]	10173	delivery	5	17
41186	2020-03-20 05:43:40	2020-03-20	14	[{"id_menu":2,"count":1}]	4929	pick-up	0	14
41187	2020-03-20 05:45:00	2020-03-20	9	[{"id_menu":6,"count":3}]	10336	delivery	5	14
41188	2020-03-20 05:45:12	2020-03-20	8	[{"id_menu":5,"count":1}]	12036	delivery	5	13
41189	2020-03-20 05:55:19	2020-03-20	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2062	pick-up	0	26
41190	2020-03-20 05:56:32	2020-03-20	12	[{"id_menu":1,"count":1}]	16422	pick-up	0	12
41191	2020-03-20 06:03:00	2020-03-20	8	[{"id_menu":5,"count":1}]	1166	pick-up	0	8
41192	2020-03-20 06:13:01	2020-03-20	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	9057	pick-up	0	26
41193	2020-03-20 06:13:48	2020-03-20	8	[{"id_menu":5,"count":1}]	13968	delivery	5	13
41194	2020-03-20 06:18:56	2020-03-20	14	[{"id_menu":2,"count":1}]	7461	delivery	5	19
41195	2020-03-20 06:23:05	2020-03-20	9	[{"id_menu":6,"count":1}]	1785	pick-up	0	9
41196	2020-03-20 06:28:02	2020-03-20	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6901	pick-up	0	32
41197	2020-03-20 06:36:06	2020-03-20	8	[{"id_menu":5,"count":1}]	14165	delivery	5	13
41198	2020-03-20 06:42:57	2020-03-20	17	[{"id_menu":4,"count":1}]	16472	pick-up	0	17
41199	2020-03-20 06:43:45	2020-03-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	16458	delivery	5	28
41200	2020-03-20 06:55:16	2020-03-20	9	[{"id_menu":7,"count":1}]	15614	delivery	5	14
41201	2020-03-20 06:56:57	2020-03-20	9	[{"id_menu":6,"count":1}]	16430	delivery	5	14
41202	2020-03-20 06:59:34	2020-03-20	12	[{"id_menu":3,"count":1}]	16461	pick-up	0	12
41203	2020-03-20 07:01:09	2020-03-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	9303	pick-up	0	23
41204	2020-03-20 07:05:23	2020-03-20	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6733	pick-up	0	52
41205	2020-03-20 07:16:48	2020-03-20	9	[{"id_menu":7,"count":1}]	15998	delivery	5	14
41206	2020-03-20 07:21:00	2020-03-20	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3099	delivery	5	57
41207	2020-03-20 07:23:20	2020-03-20	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	5771	delivery	5	40
41208	2020-03-20 07:38:12	2020-03-20	9	[{"id_menu":6,"count":1}]	16377	delivery	5	14
41209	2020-03-20 07:40:43	2020-03-20	9	[{"id_menu":7,"count":1}]	16401	delivery	5	14
41210	2020-03-20 07:44:00	2020-03-20	12	[{"id_menu":3,"count":1}]	16467	delivery	5	17
41211	2020-03-20 07:46:24	2020-03-20	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	3493	delivery	5	37
41212	2020-03-20 07:55:25	2020-03-20	8	[{"id_menu":5,"count":1}]	5648	pick-up	0	8
41213	2020-03-20 08:15:29	2020-03-20	14	[{"id_menu":2,"count":1}]	16396	delivery	5	19
41214	2020-03-20 08:23:42	2020-03-20	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16468	delivery	5	36
41215	2020-03-20 08:36:30	2020-03-20	8	[{"id_menu":5,"count":2}]	8234	delivery	5	13
41216	2020-03-20 08:47:00	2020-03-20	12	[{"id_menu":3,"count":1}]	2071	pick-up	0	12
41217	2020-03-20 08:54:30	2020-03-20	9	[{"id_menu":7,"count":1}]	1795	delivery	5	14
41218	2020-03-20 09:00:57	2020-03-20	12	[{"id_menu":3,"count":1}]	8426	pick-up	0	12
41219	2020-03-20 09:09:48	2020-03-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	16387	delivery	5	28
41220	2020-03-20 09:11:34	2020-03-20	17	[{"id_menu":4,"count":1}]	16454	delivery	5	22
41221	2020-03-20 09:13:30	2020-03-20	12	[{"id_menu":1,"count":1}]	16421	delivery	5	17
41222	2020-03-20 09:17:41	2020-03-20	17	[{"id_menu":4,"count":1}]	4961	delivery	5	22
41223	2020-03-20 09:19:14	2020-03-20	9	[{"id_menu":7,"count":1}]	16398	delivery	5	14
41224	2020-03-20 09:28:36	2020-03-20	8	[{"id_menu":5,"count":1}]	4622	delivery	5	13
41225	2020-03-20 09:29:03	2020-03-20	14	[{"id_menu":2,"count":1}]	15049	delivery	5	19
41226	2020-03-20 09:34:30	2020-03-20	9	[{"id_menu":7,"count":1}]	16404	delivery	5	14
41227	2020-03-20 09:35:37	2020-03-20	14	[{"id_menu":2,"count":1}]	3467	delivery	5	19
41228	2020-03-20 09:38:59	2020-03-20	17	[{"id_menu":4,"count":1}]	3458	pick-up	0	17
41229	2020-03-20 09:47:35	2020-03-20	9	[{"id_menu":7,"count":1}]	16420	delivery	5	14
41230	2020-03-20 09:48:25	2020-03-20	34	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	16418	pick-up	0	34
41231	2020-03-20 09:49:46	2020-03-20	17	[{"id_menu":4,"count":1}]	16391	delivery	5	22
41232	2020-03-20 09:54:57	2020-03-20	9	[{"id_menu":7,"count":1}]	16435	delivery	5	14
41233	2020-03-20 10:11:43	2020-03-20	14	[{"id_menu":2,"count":1}]	2980	pick-up	0	14
41234	2020-03-20 10:14:27	2020-03-20	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":3}]	2997	delivery	5	27
41235	2020-03-20 10:15:14	2020-03-20	17	[{"id_menu":4,"count":1}]	13429	pick-up	0	17
41236	2020-03-20 10:34:23	2020-03-20	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16372	delivery	5	22
41237	2020-03-20 10:35:07	2020-03-20	9	[{"id_menu":7,"count":1}]	10500	delivery	5	14
41238	2020-03-20 10:38:04	2020-03-20	9	[{"id_menu":6,"count":1}]	5524	delivery	5	14
41239	2020-03-20 10:40:02	2020-03-20	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	271	pick-up	0	26
41240	2020-03-20 10:42:55	2020-03-20	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	11152	delivery	5	26
41241	2020-03-20 10:45:27	2020-03-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	16480	delivery	5	22
41242	2020-03-20 10:47:05	2020-03-20	8	[{"id_menu":5,"count":1}]	4529	pick-up	0	8
41243	2020-03-20 10:47:41	2020-03-20	9	[{"id_menu":6,"count":1}]	3444	pick-up	0	9
41244	2020-03-20 10:53:03	2020-03-20	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6097	pick-up	0	26
41245	2020-03-20 11:01:19	2020-03-20	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	14073	delivery	5	22
41246	2020-03-20 11:17:43	2020-03-20	9	[{"id_menu":7,"count":1}]	7669	delivery	5	14
41247	2020-03-20 11:18:35	2020-03-20	9	[{"id_menu":7,"count":1}]	16448	delivery	5	14
41248	2020-03-20 11:25:02	2020-03-20	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	16464	delivery	5	38
41249	2020-03-20 11:28:03	2020-03-20	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	16427	delivery	5	26
41250	2020-03-20 11:29:46	2020-03-20	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	16443	delivery	5	25
41251	2020-03-20 11:30:23	2020-03-20	17	[{"id_menu":4,"count":1}]	3668	delivery	5	22
41252	2020-03-20 11:30:38	2020-03-20	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	16466	pick-up	0	21
41253	2020-03-20 11:39:47	2020-03-20	9	[{"id_menu":6,"count":3}]	14311	delivery	5	14
41254	2020-03-20 11:55:48	2020-03-20	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	11418	delivery	5	34
41255	2020-03-20 12:00:18	2020-03-20	8	[{"id_menu":5,"count":1}]	15319	pick-up	0	8
41256	2020-03-20 12:02:20	2020-03-20	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13829	delivery	5	45
41257	2020-03-20 12:15:43	2020-03-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	12229	delivery	5	28
41258	2020-03-20 12:16:29	2020-03-20	17	[{"id_menu":4,"count":1}]	8229	delivery	5	22
41259	2020-03-20 12:16:32	2020-03-20	9	[{"id_menu":7,"count":2}]	730	pick-up	0	9
41260	2020-03-20 12:16:33	2020-03-20	9	[{"id_menu":6,"count":1}]	136	delivery	5	14
41261	2020-03-20 12:22:49	2020-03-20	8	[{"id_menu":5,"count":1}]	16465	delivery	5	13
41262	2020-03-20 12:25:55	2020-03-20	14	[{"id_menu":2,"count":1}]	6213	delivery	5	19
41263	2020-03-20 12:35:12	2020-03-20	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6666	pick-up	0	49
41264	2020-03-20 12:35:30	2020-03-20	9	[{"id_menu":6,"count":2}]	16431	delivery	5	14
41265	2020-03-20 12:36:19	2020-03-20	8	[{"id_menu":5,"count":1}]	16417	delivery	5	13
41266	2020-03-20 12:46:20	2020-03-20	8	[{"id_menu":5,"count":1}]	3476	delivery	5	13
41267	2020-03-20 12:49:22	2020-03-20	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	351	delivery	5	25
41268	2020-03-20 12:50:58	2020-03-20	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16423	delivery	5	22
41269	2020-03-20 13:14:35	2020-03-20	9	[{"id_menu":7,"count":1}]	10228	delivery	5	14
41270	2020-03-20 13:16:26	2020-03-20	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16148	delivery	5	37
41271	2020-03-20 13:18:15	2020-03-20	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2818	delivery	5	48
41272	2020-03-20 13:18:41	2020-03-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9096	delivery	5	23
41273	2020-03-20 13:29:57	2020-03-20	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2631	pick-up	0	31
41274	2020-03-20 13:41:13	2020-03-20	12	[{"id_menu":3,"count":1}]	16382	delivery	5	17
41275	2020-03-20 13:46:44	2020-03-20	9	[{"id_menu":7,"count":1}]	11684	delivery	5	14
41276	2020-03-20 13:51:47	2020-03-20	17	[{"id_menu":4,"count":1}]	16406	pick-up	0	17
41277	2020-03-20 13:57:52	2020-03-20	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3659	delivery	5	31
41278	2020-03-20 14:08:26	2020-03-20	8	[{"id_menu":5,"count":1}]	16412	delivery	5	13
41279	2020-03-20 14:10:19	2020-03-20	12	[{"id_menu":3,"count":1}]	16403	delivery	5	17
41280	2020-03-20 14:13:08	2020-03-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3480	delivery	5	23
41281	2020-03-20 14:21:50	2020-03-20	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	8982	delivery	5	26
41282	2020-03-20 14:24:28	2020-03-20	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	7295	delivery	5	26
41283	2020-03-20 14:27:05	2020-03-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	16111	pick-up	0	23
41284	2020-03-20 14:28:40	2020-03-20	9	[{"id_menu":7,"count":1}]	1215	delivery	5	14
41285	2020-03-20 14:34:44	2020-03-20	12	[{"id_menu":3,"count":1}]	11228	delivery	5	17
41286	2020-03-20 14:41:24	2020-03-20	12	[{"id_menu":1,"count":1}]	16477	delivery	5	17
41287	2020-03-20 14:42:19	2020-03-20	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	1773	delivery	5	43
41288	2020-03-20 14:45:05	2020-03-20	9	[{"id_menu":7,"count":1}]	15243	pick-up	0	9
41289	2020-03-20 14:45:10	2020-03-20	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2706	pick-up	0	21
41290	2020-03-20 14:55:07	2020-03-20	12	[{"id_menu":3,"count":1}]	4965	delivery	5	17
41291	2020-03-20 14:59:23	2020-03-20	14	[{"id_menu":2,"count":1}]	848	pick-up	0	14
41292	2020-03-20 15:06:18	2020-03-20	9	[{"id_menu":7,"count":1}]	7946	delivery	5	14
41293	2020-03-20 15:11:42	2020-03-20	14	[{"id_menu":2,"count":1}]	16395	delivery	5	19
41294	2020-03-20 15:25:44	2020-03-20	12	[{"id_menu":1,"count":1}]	15941	delivery	5	17
41295	2020-03-20 15:27:19	2020-03-20	8	[{"id_menu":5,"count":1}]	5506	delivery	5	13
41296	2020-03-20 15:30:40	2020-03-20	14	[{"id_menu":2,"count":1}]	13611	delivery	5	19
41297	2020-03-20 15:37:51	2020-03-20	12	[{"id_menu":3,"count":1}]	3185	pick-up	0	12
41298	2020-03-20 15:43:35	2020-03-20	8	[{"id_menu":5,"count":1}]	16459	delivery	5	13
41299	2020-03-20 15:45:32	2020-03-20	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16415	delivery	5	43
41300	2020-03-20 16:03:33	2020-03-20	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14826	delivery	5	34
41301	2020-03-20 16:28:38	2020-03-20	17	[{"id_menu":4,"count":1}]	15765	delivery	5	22
41302	2020-03-20 16:29:03	2020-03-20	12	[{"id_menu":1,"count":1}]	6532	delivery	5	17
41303	2020-03-20 16:29:18	2020-03-20	9	[{"id_menu":7,"count":1}]	16441	delivery	5	14
41304	2020-03-20 16:31:00	2020-03-20	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4210	delivery	5	31
41305	2020-03-20 16:43:27	2020-03-20	9	[{"id_menu":6,"count":1}]	13909	delivery	5	14
41306	2020-03-20 16:57:41	2020-03-20	8	[{"id_menu":5,"count":2}]	8840	delivery	5	13
41307	2020-03-20 17:06:19	2020-03-20	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	13048	delivery	5	34
41308	2020-03-20 17:07:57	2020-03-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	836	delivery	5	28
41309	2020-03-20 17:09:24	2020-03-20	12	[{"id_menu":1,"count":1}]	1255	pick-up	0	12
41310	2020-03-20 17:13:45	2020-03-20	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	12546	delivery	5	26
41311	2020-03-20 17:17:52	2020-03-20	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5075	pick-up	0	52
41312	2020-03-20 17:34:51	2020-03-20	14	[{"id_menu":2,"count":1}]	12374	delivery	5	19
41313	2020-03-20 17:39:30	2020-03-20	12	[{"id_menu":3,"count":1}]	16463	delivery	5	17
41314	2020-03-20 17:45:06	2020-03-20	12	[{"id_menu":1,"count":1}]	16433	delivery	5	17
41315	2020-03-20 17:55:48	2020-03-20	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16457	delivery	5	40
41316	2020-03-20 17:56:24	2020-03-20	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12827	delivery	5	31
41317	2020-03-20 18:00:00	2020-03-20	12	[{"id_menu":1,"count":1}]	2928	pick-up	0	12
41318	2020-03-20 18:01:24	2020-03-20	12	[{"id_menu":3,"count":1}]	2176	pick-up	0	12
41319	2020-03-20 18:03:22	2020-03-20	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	16416	delivery	5	26
41320	2020-03-20 18:13:01	2020-03-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	12942	delivery	5	28
41321	2020-03-20 18:23:07	2020-03-20	8	[{"id_menu":5,"count":1}]	7106	delivery	5	13
41322	2020-03-20 18:26:20	2020-03-20	9	[{"id_menu":6,"count":1}]	16445	delivery	5	14
41323	2020-03-20 18:29:30	2020-03-20	8	[{"id_menu":5,"count":1}]	3572	delivery	5	13
41324	2020-03-20 18:31:17	2020-03-20	9	[{"id_menu":7,"count":1}]	5839	pick-up	0	9
41325	2020-03-20 18:35:36	2020-03-20	17	[{"id_menu":4,"count":1}]	8940	pick-up	0	17
41326	2020-03-20 18:36:15	2020-03-20	14	[{"id_menu":2,"count":1}]	16462	delivery	5	19
41327	2020-03-20 18:36:40	2020-03-20	17	[{"id_menu":4,"count":1}]	14812	delivery	5	22
41328	2020-03-20 18:41:25	2020-03-20	14	[{"id_menu":2,"count":1}]	3711	delivery	5	19
41329	2020-03-20 18:41:32	2020-03-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	16437	pick-up	0	23
41330	2020-03-20 18:54:51	2020-03-20	9	[{"id_menu":7,"count":1}]	14937	delivery	5	14
41331	2020-03-20 18:56:12	2020-03-20	12	[{"id_menu":1,"count":1}]	6074	delivery	5	17
41332	2020-03-20 19:07:29	2020-03-20	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	16389	delivery	5	26
41333	2020-03-20 19:14:27	2020-03-20	17	[{"id_menu":4,"count":1}]	15111	delivery	5	22
41334	2020-03-20 19:20:36	2020-03-20	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	12952	delivery	5	23
41335	2020-03-20 19:25:36	2020-03-20	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1231	pick-up	0	35
41336	2020-03-20 19:26:36	2020-03-20	12	[{"id_menu":3,"count":1}]	10879	delivery	5	17
41337	2020-03-20 19:39:26	2020-03-20	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	14475	delivery	5	38
41338	2020-03-20 19:46:33	2020-03-20	12	[{"id_menu":3,"count":1}]	2641	delivery	5	17
41339	2020-03-20 19:46:54	2020-03-20	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	14227	delivery	5	42
41340	2020-03-20 20:01:12	2020-03-20	12	[{"id_menu":3,"count":1}]	2474	pick-up	0	12
41341	2020-03-20 20:08:35	2020-03-20	9	[{"id_menu":7,"count":1}]	2068	pick-up	0	9
41342	2020-03-20 20:14:17	2020-03-20	8	[{"id_menu":5,"count":1}]	16438	delivery	5	13
41343	2020-03-20 20:24:28	2020-03-20	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	12905	pick-up	0	24
41344	2020-03-20 20:37:16	2020-03-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4556	delivery	5	22
41345	2020-03-20 20:39:13	2020-03-20	17	[{"id_menu":4,"count":1}]	8595	pick-up	0	17
41346	2020-03-20 20:41:23	2020-03-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4843	pick-up	0	23
41347	2020-03-20 20:46:14	2020-03-20	17	[{"id_menu":4,"count":1}]	11681	pick-up	0	17
41348	2020-03-20 20:50:54	2020-03-20	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	16397	delivery	5	39
41349	2020-03-20 20:54:33	2020-03-20	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	4100	delivery	5	28
41350	2020-03-20 20:56:17	2020-03-20	9	[{"id_menu":7,"count":1}]	12312	delivery	5	14
41351	2020-03-20 20:57:39	2020-03-20	14	[{"id_menu":2,"count":1}]	9420	delivery	5	19
41352	2020-03-20 21:00:12	2020-03-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16379	delivery	5	23
41353	2020-03-20 21:04:28	2020-03-20	9	[{"id_menu":7,"count":1}]	12680	delivery	5	14
41354	2020-03-20 21:06:25	2020-03-20	12	[{"id_menu":1,"count":1}]	15332	delivery	5	17
41355	2020-03-20 21:07:38	2020-03-20	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	16424	delivery	5	39
41356	2020-03-20 21:10:57	2020-03-20	9	[{"id_menu":6,"count":2}]	5639	pick-up	0	9
41357	2020-03-20 21:16:41	2020-03-20	9	[{"id_menu":6,"count":1}]	6577	delivery	5	14
41358	2020-03-20 21:23:30	2020-03-20	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14125	delivery	5	31
41359	2020-03-20 21:31:38	2020-03-20	17	[{"id_menu":4,"count":1}]	11484	delivery	5	22
41360	2020-03-20 21:32:25	2020-03-20	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	7793	pick-up	0	29
41361	2020-03-20 21:35:37	2020-03-20	8	[{"id_menu":5,"count":1}]	16484	delivery	5	13
41362	2020-03-20 21:36:24	2020-03-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	15041	delivery	5	28
41363	2020-03-20 21:43:48	2020-03-20	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	458	pick-up	0	26
41364	2020-03-20 21:46:09	2020-03-20	8	[{"id_menu":5,"count":1}]	16469	pick-up	0	8
41365	2020-03-20 21:47:00	2020-03-20	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4646	delivery	5	42
41366	2020-03-20 21:49:57	2020-03-20	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2278	pick-up	0	29
41367	2020-03-20 21:55:49	2020-03-20	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	975	delivery	5	31
41368	2020-03-20 21:59:10	2020-03-20	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	16068	delivery	5	29
41369	2020-03-20 21:59:43	2020-03-20	12	[{"id_menu":3,"count":1}]	11416	delivery	5	17
41370	2020-03-20 22:04:08	2020-03-20	9	[{"id_menu":7,"count":1}]	12338	delivery	5	14
41371	2020-03-20 22:12:04	2020-03-20	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	16410	pick-up	0	26
41372	2020-03-20 22:13:49	2020-03-20	14	[{"id_menu":2,"count":1}]	16442	pick-up	0	14
41373	2020-03-20 22:33:06	2020-03-20	9	[{"id_menu":7,"count":2}]	12941	delivery	5	14
41374	2020-03-20 22:34:25	2020-03-20	12	[{"id_menu":1,"count":1}]	16408	pick-up	0	12
41375	2020-03-20 22:37:19	2020-03-20	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	2054	pick-up	0	38
41376	2020-03-20 22:43:20	2020-03-20	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16455	delivery	5	48
41377	2020-03-20 22:57:43	2020-03-20	9	[{"id_menu":6,"count":1}]	2672	pick-up	0	9
41378	2020-03-20 23:04:45	2020-03-20	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3256	delivery	5	45
41379	2020-03-20 23:10:25	2020-03-20	14	[{"id_menu":2,"count":1}]	5331	delivery	5	19
41380	2020-03-20 23:11:16	2020-03-20	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	16384	delivery	5	36
41381	2020-03-20 23:11:30	2020-03-20	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1228	delivery	5	30
41382	2020-03-20 23:12:56	2020-03-20	9	[{"id_menu":6,"count":1}]	16419	delivery	5	14
41383	2020-03-20 23:13:47	2020-03-20	9	[{"id_menu":7,"count":2}]	16370	delivery	5	14
41384	2020-03-20 23:18:24	2020-03-20	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	14263	delivery	5	31
41385	2020-03-20 23:27:09	2020-03-20	12	[{"id_menu":3,"count":1}]	11415	delivery	5	17
41386	2020-03-20 23:29:20	2020-03-20	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	16386	delivery	5	40
41387	2020-03-20 23:30:25	2020-03-20	8	[{"id_menu":5,"count":1}]	16476	pick-up	0	8
41388	2020-03-20 23:32:55	2020-03-20	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16371	delivery	5	31
41389	2020-03-20 23:34:20	2020-03-20	9	[{"id_menu":6,"count":1}]	16447	delivery	5	14
41390	2020-03-20 23:50:20	2020-03-20	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	11739	delivery	5	30
41391	2020-03-21 00:02:08	2020-03-21	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":2}]	16578	delivery	5	22
41392	2020-03-21 00:02:57	2020-03-21	17	[{"id_menu":4,"count":1}]	9303	pick-up	0	17
41393	2020-03-21 00:07:38	2020-03-21	9	[{"id_menu":7,"count":1}]	10288	delivery	5	14
41394	2020-03-21 00:08:03	2020-03-21	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16532	delivery	5	48
41395	2020-03-21 00:08:26	2020-03-21	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	16627	pick-up	0	26
41396	2020-03-21 00:11:03	2020-03-21	8	[{"id_menu":5,"count":1}]	16637	delivery	5	13
41397	2020-03-21 00:11:15	2020-03-21	14	[{"id_menu":2,"count":1}]	7383	delivery	5	19
41398	2020-03-21 00:13:18	2020-03-21	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	5094	pick-up	0	35
41399	2020-03-21 00:13:19	2020-03-21	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	3155	pick-up	0	26
41400	2020-03-21 00:15:07	2020-03-21	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	10766	delivery	5	22
41401	2020-03-21 00:18:51	2020-03-21	17	[{"id_menu":4,"count":1}]	8383	pick-up	0	17
41402	2020-03-21 00:19:48	2020-03-21	8	[{"id_menu":5,"count":1}]	346	delivery	5	13
41403	2020-03-21 00:20:40	2020-03-21	9	[{"id_menu":7,"count":1}]	16512	delivery	5	14
41404	2020-03-21 00:36:34	2020-03-21	17	[{"id_menu":4,"count":1}]	16500	delivery	5	22
41405	2020-03-21 00:42:46	2020-03-21	12	[{"id_menu":3,"count":1}]	16630	delivery	5	17
41406	2020-03-21 00:42:51	2020-03-21	17	[{"id_menu":4,"count":1}]	16549	pick-up	0	17
41407	2020-03-21 00:48:02	2020-03-21	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	13885	delivery	5	26
41408	2020-03-21 00:53:44	2020-03-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4655	delivery	5	22
41409	2020-03-21 01:12:45	2020-03-21	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16620	delivery	5	37
41410	2020-03-21 01:16:48	2020-03-21	14	[{"id_menu":2,"count":1}]	6932	delivery	5	19
41411	2020-03-21 01:17:20	2020-03-21	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	16631	delivery	5	27
41412	2020-03-21 01:18:41	2020-03-21	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	16619	delivery	5	26
41413	2020-03-21 01:20:04	2020-03-21	12	[{"id_menu":3,"count":1}]	16321	delivery	5	17
41414	2020-03-21 01:25:56	2020-03-21	9	[{"id_menu":7,"count":1}]	16505	delivery	5	14
41415	2020-03-21 01:29:49	2020-03-21	14	[{"id_menu":2,"count":1}]	338	pick-up	0	14
41416	2020-03-21 01:32:21	2020-03-21	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	16524	delivery	5	36
41417	2020-03-21 01:36:42	2020-03-21	9	[{"id_menu":6,"count":1}]	1119	delivery	5	14
41418	2020-03-21 01:47:44	2020-03-21	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16506	pick-up	0	52
41419	2020-03-21 01:49:26	2020-03-21	12	[{"id_menu":3,"count":1}]	16623	pick-up	0	12
41420	2020-03-21 01:53:37	2020-03-21	33	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	16529	delivery	5	38
41421	2020-03-21 01:53:54	2020-03-21	14	[{"id_menu":2,"count":1}]	8800	pick-up	0	14
41422	2020-03-21 02:01:53	2020-03-21	9	[{"id_menu":7,"count":1}]	8078	delivery	5	14
41423	2020-03-21 02:03:20	2020-03-21	9	[{"id_menu":6,"count":3}]	16595	delivery	5	14
41424	2020-03-21 02:03:25	2020-03-21	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	5894	delivery	5	31
41425	2020-03-21 02:11:01	2020-03-21	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	8506	delivery	5	40
41426	2020-03-21 02:15:43	2020-03-21	9	[{"id_menu":6,"count":1}]	4469	delivery	5	14
41427	2020-03-21 02:21:17	2020-03-21	17	[{"id_menu":4,"count":1}]	15700	delivery	5	22
41428	2020-03-21 02:23:04	2020-03-21	12	[{"id_menu":3,"count":1}]	16493	delivery	5	17
41429	2020-03-21 02:24:08	2020-03-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	16622	delivery	5	28
41430	2020-03-21 02:26:04	2020-03-21	12	[{"id_menu":3,"count":1}]	5873	delivery	5	17
41431	2020-03-21 02:29:04	2020-03-21	8	[{"id_menu":5,"count":1}]	2776	delivery	5	13
41432	2020-03-21 02:33:47	2020-03-21	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	16530	delivery	5	44
41433	2020-03-21 02:35:06	2020-03-21	12	[{"id_menu":3,"count":1}]	1468	pick-up	0	12
41434	2020-03-21 02:35:11	2020-03-21	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	15995	delivery	5	44
41435	2020-03-21 02:43:26	2020-03-21	9	[{"id_menu":7,"count":1}]	16612	delivery	5	14
41436	2020-03-21 02:44:48	2020-03-21	8	[{"id_menu":5,"count":2}]	1067	delivery	5	13
41437	2020-03-21 02:46:06	2020-03-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6104	delivery	5	23
41438	2020-03-21 02:48:34	2020-03-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16614	delivery	5	31
41439	2020-03-21 02:55:32	2020-03-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12224	delivery	5	22
41440	2020-03-21 03:11:25	2020-03-21	12	[{"id_menu":3,"count":1}]	439	pick-up	0	12
41441	2020-03-21 03:12:33	2020-03-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8531	delivery	5	31
41442	2020-03-21 03:12:50	2020-03-21	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14847	delivery	5	35
41443	2020-03-21 03:17:25	2020-03-21	12	[{"id_menu":1,"count":1}]	10393	delivery	5	17
41444	2020-03-21 03:18:15	2020-03-21	14	[{"id_menu":2,"count":1}]	389	pick-up	0	14
41445	2020-03-21 03:25:35	2020-03-21	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	9503	delivery	5	31
41446	2020-03-21 03:30:42	2020-03-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16501	pick-up	0	18
41447	2020-03-21 03:33:44	2020-03-21	12	[{"id_menu":3,"count":1}]	16511	delivery	5	17
41448	2020-03-21 03:35:54	2020-03-21	17	[{"id_menu":4,"count":1}]	16487	delivery	5	22
41449	2020-03-21 03:36:49	2020-03-21	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	7460	delivery	5	22
41450	2020-03-21 03:43:28	2020-03-21	14	[{"id_menu":2,"count":1}]	16644	delivery	5	19
41451	2020-03-21 03:50:04	2020-03-21	12	[{"id_menu":3,"count":1}]	2796	pick-up	0	12
41452	2020-03-21 03:52:16	2020-03-21	12	[{"id_menu":3,"count":1}]	1564	pick-up	0	12
41453	2020-03-21 03:53:12	2020-03-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12519	delivery	5	31
41454	2020-03-21 03:55:50	2020-03-21	14	[{"id_menu":2,"count":1}]	10209	pick-up	0	14
41455	2020-03-21 03:59:15	2020-03-21	12	[{"id_menu":3,"count":1}]	10954	pick-up	0	12
41456	2020-03-21 04:02:06	2020-03-21	9	[{"id_menu":6,"count":1}]	15768	delivery	5	14
41457	2020-03-21 04:04:47	2020-03-21	9	[{"id_menu":7,"count":1}]	16535	delivery	5	14
41458	2020-03-21 04:09:40	2020-03-21	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	203	delivery	5	31
41459	2020-03-21 04:10:17	2020-03-21	9	[{"id_menu":6,"count":2}]	16569	delivery	5	14
41460	2020-03-21 04:14:22	2020-03-21	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	16598	delivery	5	35
41461	2020-03-21 04:16:05	2020-03-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	16642	delivery	5	28
41462	2020-03-21 04:17:23	2020-03-21	8	[{"id_menu":5,"count":1}]	16585	delivery	5	13
41463	2020-03-21 04:23:23	2020-03-21	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16494	delivery	5	45
41464	2020-03-21 04:29:04	2020-03-21	9	[{"id_menu":7,"count":1}]	806	delivery	5	14
41465	2020-03-21 04:29:13	2020-03-21	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	16580	delivery	5	39
41466	2020-03-21 04:36:09	2020-03-21	14	[{"id_menu":2,"count":1}]	10308	delivery	5	19
41467	2020-03-21 04:41:55	2020-03-21	8	[{"id_menu":5,"count":1}]	11547	delivery	5	13
41468	2020-03-21 04:42:44	2020-03-21	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8645	delivery	5	45
41469	2020-03-21 04:43:30	2020-03-21	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	878	pick-up	0	34
41470	2020-03-21 04:45:48	2020-03-21	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":2}]	16485	pick-up	0	17
41471	2020-03-21 04:47:23	2020-03-21	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	6487	pick-up	0	24
41472	2020-03-21 04:49:52	2020-03-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1876	delivery	5	31
41473	2020-03-21 04:49:56	2020-03-21	8	[{"id_menu":5,"count":1}]	13579	delivery	5	13
41474	2020-03-21 04:53:02	2020-03-21	9	[{"id_menu":6,"count":1}]	1475	delivery	5	14
41475	2020-03-21 04:54:25	2020-03-21	17	[{"id_menu":4,"count":2}]	547	pick-up	0	17
41476	2020-03-21 04:59:19	2020-03-21	12	[{"id_menu":3,"count":1}]	7983	pick-up	0	12
41477	2020-03-21 04:59:26	2020-03-21	14	[{"id_menu":2,"count":1}]	16503	delivery	5	19
41478	2020-03-21 05:04:12	2020-03-21	14	[{"id_menu":2,"count":1}]	16525	delivery	5	19
41479	2020-03-21 05:17:30	2020-03-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4447	delivery	5	28
41480	2020-03-21 05:23:34	2020-03-21	17	[{"id_menu":4,"count":2}]	9469	pick-up	0	17
41481	2020-03-21 05:29:58	2020-03-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	16544	delivery	5	28
41482	2020-03-21 05:33:00	2020-03-21	9	[{"id_menu":6,"count":1}]	44	pick-up	0	9
41483	2020-03-21 05:35:51	2020-03-21	12	[{"id_menu":3,"count":1}]	10264	delivery	5	17
41484	2020-03-21 05:45:49	2020-03-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	820	pick-up	0	18
41485	2020-03-21 05:55:14	2020-03-21	9	[{"id_menu":6,"count":1}]	1548	pick-up	0	9
41486	2020-03-21 06:00:16	2020-03-21	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	12001	pick-up	0	21
41487	2020-03-21 06:04:23	2020-03-21	9	[{"id_menu":7,"count":1}]	7330	pick-up	0	9
41488	2020-03-21 06:05:03	2020-03-21	17	[{"id_menu":4,"count":1}]	2227	pick-up	0	17
41489	2020-03-21 06:06:20	2020-03-21	12	[{"id_menu":3,"count":1}]	16557	delivery	5	17
41490	2020-03-21 06:14:39	2020-03-21	12	[{"id_menu":1,"count":1}]	5958	delivery	5	17
41491	2020-03-21 06:17:06	2020-03-21	17	[{"id_menu":4,"count":1}]	6037	pick-up	0	17
41492	2020-03-21 06:22:00	2020-03-21	17	[{"id_menu":4,"count":2}]	1633	pick-up	0	17
41493	2020-03-21 06:22:08	2020-03-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2513	pick-up	0	18
41494	2020-03-21 06:24:52	2020-03-21	12	[{"id_menu":1,"count":2}]	9852	delivery	5	17
41495	2020-03-21 06:25:10	2020-03-21	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	16183	delivery	5	25
41496	2020-03-21 06:26:09	2020-03-21	9	[{"id_menu":6,"count":1}]	3936	delivery	5	14
41497	2020-03-21 06:30:04	2020-03-21	9	[{"id_menu":6,"count":1}]	12509	delivery	5	14
41498	2020-03-21 06:32:56	2020-03-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	993	pick-up	0	23
41499	2020-03-21 06:34:37	2020-03-21	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	16556	delivery	5	26
41500	2020-03-21 06:36:08	2020-03-21	17	[{"id_menu":4,"count":1}]	16546	delivery	5	22
41501	2020-03-21 06:38:19	2020-03-21	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	4133	delivery	5	39
41502	2020-03-21 06:45:00	2020-03-21	9	[{"id_menu":6,"count":1}]	16552	delivery	5	14
41503	2020-03-21 06:46:45	2020-03-21	12	[{"id_menu":3,"count":1}]	2124	pick-up	0	12
41504	2020-03-21 06:51:03	2020-03-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6848	pick-up	0	23
41505	2020-03-21 06:59:15	2020-03-21	9	[{"id_menu":6,"count":1}]	7337	delivery	5	14
41506	2020-03-21 07:05:04	2020-03-21	14	[{"id_menu":2,"count":1}]	16593	delivery	5	19
41507	2020-03-21 07:09:39	2020-03-21	9	[{"id_menu":6,"count":1}]	9418	delivery	5	14
41508	2020-03-21 07:13:43	2020-03-21	17	[{"id_menu":4,"count":1}]	3752	delivery	5	22
41509	2020-03-21 07:14:47	2020-03-21	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	5064	delivery	5	31
41510	2020-03-21 07:15:41	2020-03-21	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16607	delivery	5	34
41511	2020-03-21 07:18:09	2020-03-21	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	6443	delivery	5	29
41512	2020-03-21 07:19:05	2020-03-21	14	[{"id_menu":2,"count":1}]	6579	delivery	5	19
41513	2020-03-21 07:21:26	2020-03-21	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3096	delivery	5	26
41514	2020-03-21 07:23:34	2020-03-21	9	[{"id_menu":6,"count":1}]	2736	delivery	5	14
41515	2020-03-21 07:24:31	2020-03-21	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	14742	delivery	5	43
41516	2020-03-21 07:26:41	2020-03-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16603	delivery	5	22
41517	2020-03-21 07:28:31	2020-03-21	8	[{"id_menu":5,"count":1}]	5855	delivery	5	13
41518	2020-03-21 07:29:00	2020-03-21	17	[{"id_menu":4,"count":1}]	9920	pick-up	0	17
41519	2020-03-21 07:39:59	2020-03-21	17	[{"id_menu":4,"count":1}]	16568	pick-up	0	17
41520	2020-03-21 07:55:51	2020-03-21	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3360	delivery	5	45
41521	2020-03-21 07:56:18	2020-03-21	12	[{"id_menu":3,"count":1}]	5829	delivery	5	17
41522	2020-03-21 07:57:59	2020-03-21	8	[{"id_menu":5,"count":1}]	16602	pick-up	0	8
41523	2020-03-21 07:59:04	2020-03-21	17	[{"id_menu":4,"count":1}]	196	delivery	5	22
41524	2020-03-21 08:05:16	2020-03-21	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	16562	delivery	5	26
41525	2020-03-21 08:13:00	2020-03-21	14	[{"id_menu":2,"count":1}]	9560	delivery	5	19
41526	2020-03-21 08:16:05	2020-03-21	9	[{"id_menu":6,"count":1}]	16601	delivery	5	14
41527	2020-03-21 08:22:10	2020-03-21	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1862	pick-up	0	38
41528	2020-03-21 08:22:48	2020-03-21	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16617	pick-up	0	52
41529	2020-03-21 08:25:47	2020-03-21	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	16495	delivery	5	29
41530	2020-03-21 08:28:08	2020-03-21	8	[{"id_menu":5,"count":1}]	16555	delivery	5	13
41531	2020-03-21 08:30:35	2020-03-21	9	[{"id_menu":6,"count":1}]	16559	delivery	5	14
41532	2020-03-21 08:38:00	2020-03-21	17	[{"id_menu":4,"count":1}]	16582	pick-up	0	17
41533	2020-03-21 08:41:58	2020-03-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6163	pick-up	0	17
41534	2020-03-21 08:42:15	2020-03-21	14	[{"id_menu":2,"count":2}]	10628	delivery	5	19
41535	2020-03-21 08:42:52	2020-03-21	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	16579	delivery	5	30
41536	2020-03-21 08:49:41	2020-03-21	8	[{"id_menu":5,"count":1}]	1606	pick-up	0	8
41537	2020-03-21 08:50:29	2020-03-21	9	[{"id_menu":6,"count":1}]	1269	pick-up	0	9
41538	2020-03-21 08:55:40	2020-03-21	12	[{"id_menu":3,"count":1}]	16510	delivery	5	17
41539	2020-03-21 08:56:23	2020-03-21	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6498	delivery	5	40
41540	2020-03-21 09:02:54	2020-03-21	17	[{"id_menu":4,"count":1}]	11322	delivery	5	22
41541	2020-03-21 09:10:34	2020-03-21	14	[{"id_menu":2,"count":2}]	16550	delivery	5	19
41542	2020-03-21 09:15:37	2020-03-21	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	16629	pick-up	0	21
41543	2020-03-21 09:22:12	2020-03-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16626	delivery	5	31
41544	2020-03-21 09:30:02	2020-03-21	12	[{"id_menu":1,"count":1}]	16592	pick-up	0	12
41545	2020-03-21 09:30:31	2020-03-21	9	[{"id_menu":6,"count":1}]	16491	delivery	5	14
41546	2020-03-21 09:34:02	2020-03-21	9	[{"id_menu":7,"count":1}]	3318	pick-up	0	9
41547	2020-03-21 09:34:45	2020-03-21	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5964	delivery	5	36
41548	2020-03-21 09:36:01	2020-03-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	16647	delivery	5	28
41549	2020-03-21 09:44:53	2020-03-21	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16531	delivery	5	37
41550	2020-03-21 09:46:49	2020-03-21	12	[{"id_menu":1,"count":1}]	1732	pick-up	0	12
41551	2020-03-21 09:48:57	2020-03-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	13477	pick-up	0	26
41552	2020-03-21 09:49:24	2020-03-21	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16534	delivery	5	43
41553	2020-03-21 10:00:33	2020-03-21	17	[{"id_menu":4,"count":1}]	11465	pick-up	0	17
41554	2020-03-21 10:15:48	2020-03-21	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5923	delivery	5	39
41555	2020-03-21 10:17:11	2020-03-21	17	[{"id_menu":4,"count":1}]	197	delivery	5	22
41556	2020-03-21 10:18:02	2020-03-21	14	[{"id_menu":2,"count":1}]	16590	delivery	5	19
41557	2020-03-21 10:28:06	2020-03-21	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	16621	delivery	5	45
41558	2020-03-21 10:33:21	2020-03-21	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	5811	pick-up	0	26
41559	2020-03-21 10:35:35	2020-03-21	41	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	16561	delivery	5	46
41560	2020-03-21 10:35:54	2020-03-21	12	[{"id_menu":3,"count":1}]	16044	delivery	5	17
41561	2020-03-21 10:38:43	2020-03-21	8	[{"id_menu":5,"count":1}]	15955	delivery	5	13
41562	2020-03-21 10:50:06	2020-03-21	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3709	pick-up	0	21
41563	2020-03-21 11:00:14	2020-03-21	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	9073	pick-up	0	29
41564	2020-03-21 11:01:12	2020-03-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	12449	delivery	5	22
41565	2020-03-21 11:02:24	2020-03-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16613	pick-up	0	17
41566	2020-03-21 11:03:33	2020-03-21	12	[{"id_menu":1,"count":1}]	173	pick-up	0	12
41567	2020-03-21 11:03:59	2020-03-21	17	[{"id_menu":4,"count":1}]	15812	delivery	5	22
41568	2020-03-21 11:05:02	2020-03-21	17	[{"id_menu":4,"count":1}]	16572	delivery	5	22
41569	2020-03-21 11:09:05	2020-03-21	9	[{"id_menu":7,"count":1}]	9554	delivery	5	14
41570	2020-03-21 11:15:28	2020-03-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	16600	delivery	5	28
41571	2020-03-21 11:17:55	2020-03-21	12	[{"id_menu":1,"count":2}]	5947	pick-up	0	12
41572	2020-03-21 11:18:52	2020-03-21	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	14941	delivery	5	30
41573	2020-03-21 11:19:58	2020-03-21	8	[{"id_menu":5,"count":1}]	16486	delivery	5	13
41574	2020-03-21 11:21:46	2020-03-21	17	[{"id_menu":4,"count":1}]	9846	pick-up	0	17
41575	2020-03-21 11:24:57	2020-03-21	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	16526	delivery	5	42
41576	2020-03-21 11:25:22	2020-03-21	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	16596	delivery	5	28
41577	2020-03-21 11:25:24	2020-03-21	9	[{"id_menu":6,"count":1}]	6621	pick-up	0	9
41578	2020-03-21 11:28:37	2020-03-21	12	[{"id_menu":1,"count":1}]	141	pick-up	0	12
41579	2020-03-21 11:33:42	2020-03-21	30	[{"id_menu":3,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5520	pick-up	0	30
41580	2020-03-21 11:37:34	2020-03-21	17	[{"id_menu":4,"count":1}]	1715	pick-up	0	17
41581	2020-03-21 11:38:44	2020-03-21	17	[{"id_menu":4,"count":3}]	3146	delivery	5	22
41582	2020-03-21 11:39:34	2020-03-21	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	15852	delivery	5	40
41583	2020-03-21 11:41:42	2020-03-21	9	[{"id_menu":7,"count":1}]	16502	delivery	5	14
41584	2020-03-21 11:50:46	2020-03-21	9	[{"id_menu":7,"count":1}]	1015	pick-up	0	9
41585	2020-03-21 11:51:20	2020-03-21	9	[{"id_menu":7,"count":1}]	16628	delivery	5	14
41586	2020-03-21 11:52:50	2020-03-21	9	[{"id_menu":7,"count":1}]	16509	delivery	5	14
41587	2020-03-21 11:53:11	2020-03-21	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	16504	delivery	5	31
41588	2020-03-21 11:55:50	2020-03-21	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	16625	delivery	5	42
41589	2020-03-21 11:58:37	2020-03-21	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	16641	delivery	5	26
41590	2020-03-21 12:01:11	2020-03-21	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16515	delivery	5	45
41591	2020-03-21 12:01:25	2020-03-21	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15294	delivery	5	36
41592	2020-03-21 12:05:44	2020-03-21	8	[{"id_menu":5,"count":1}]	6773	delivery	5	13
41593	2020-03-21 12:07:58	2020-03-21	9	[{"id_menu":6,"count":1}]	16513	delivery	5	14
41594	2020-03-21 12:22:24	2020-03-21	14	[{"id_menu":2,"count":1}]	1545	pick-up	0	14
41595	2020-03-21 12:24:29	2020-03-21	14	[{"id_menu":2,"count":1}]	14920	delivery	5	19
41596	2020-03-21 12:36:30	2020-03-21	12	[{"id_menu":1,"count":2}]	6236	pick-up	0	12
41597	2020-03-21 12:48:17	2020-03-21	17	[{"id_menu":4,"count":1}]	4843	pick-up	0	17
41598	2020-03-21 12:55:27	2020-03-21	12	[{"id_menu":1,"count":1}]	16533	delivery	5	17
41599	2020-03-21 13:03:10	2020-03-21	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	16584	delivery	5	39
41600	2020-03-21 13:05:10	2020-03-21	12	[{"id_menu":1,"count":1}]	4981	delivery	5	17
41601	2020-03-21 13:10:43	2020-03-21	12	[{"id_menu":1,"count":1}]	2065	pick-up	0	12
41602	2020-03-21 13:13:12	2020-03-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	16583	delivery	5	23
41603	2020-03-21 13:19:39	2020-03-21	12	[{"id_menu":1,"count":1}]	3153	pick-up	0	12
41604	2020-03-21 13:20:38	2020-03-21	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	16587	delivery	5	30
41605	2020-03-21 13:21:07	2020-03-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13584	delivery	5	22
41606	2020-03-21 13:23:15	2020-03-21	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4287	delivery	5	34
41607	2020-03-21 13:24:34	2020-03-21	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16581	delivery	5	31
41608	2020-03-21 13:30:30	2020-03-21	12	[{"id_menu":3,"count":1}]	9021	delivery	5	17
41609	2020-03-21 13:37:42	2020-03-21	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16541	delivery	5	34
41610	2020-03-21 13:42:25	2020-03-21	12	[{"id_menu":1,"count":1}]	16640	delivery	5	17
41611	2020-03-21 13:48:59	2020-03-21	14	[{"id_menu":2,"count":1}]	8240	pick-up	0	14
41612	2020-03-21 13:49:33	2020-03-21	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	10394	delivery	5	31
41613	2020-03-21 13:55:32	2020-03-21	12	[{"id_menu":1,"count":1}]	16547	pick-up	0	12
41614	2020-03-21 13:57:12	2020-03-21	17	[{"id_menu":4,"count":1}]	12355	delivery	5	22
41615	2020-03-21 13:58:47	2020-03-21	12	[{"id_menu":1,"count":1}]	16597	delivery	5	17
41616	2020-03-21 13:59:44	2020-03-21	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	4339	delivery	5	40
41617	2020-03-21 14:00:03	2020-03-21	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8342	delivery	5	40
41618	2020-03-21 14:01:55	2020-03-21	17	[{"id_menu":4,"count":1}]	16488	delivery	5	22
41619	2020-03-21 14:05:03	2020-03-21	17	[{"id_menu":4,"count":1}]	3161	delivery	5	22
41620	2020-03-21 14:05:26	2020-03-21	8	[{"id_menu":5,"count":1}]	16489	delivery	5	13
41621	2020-03-21 14:09:37	2020-03-21	14	[{"id_menu":2,"count":1}]	16611	delivery	5	19
41622	2020-03-21 14:13:42	2020-03-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6251	delivery	5	23
41623	2020-03-21 14:21:58	2020-03-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	16553	delivery	5	28
41624	2020-03-21 14:23:40	2020-03-21	9	[{"id_menu":6,"count":2}]	11756	delivery	5	14
41625	2020-03-21 14:27:47	2020-03-21	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	16548	delivery	5	48
41626	2020-03-21 14:38:13	2020-03-21	14	[{"id_menu":2,"count":1}]	5067	delivery	5	19
41627	2020-03-21 14:41:28	2020-03-21	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1760	pick-up	0	31
41628	2020-03-21 14:43:34	2020-03-21	17	[{"id_menu":4,"count":1}]	13639	delivery	5	22
41629	2020-03-21 14:44:14	2020-03-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16606	delivery	5	22
41630	2020-03-21 14:47:53	2020-03-21	17	[{"id_menu":4,"count":1}]	16474	delivery	5	22
41631	2020-03-21 14:51:10	2020-03-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1415	pick-up	0	23
41632	2020-03-21 14:52:50	2020-03-21	9	[{"id_menu":6,"count":1}]	7957	delivery	5	14
41633	2020-03-21 14:54:05	2020-03-21	12	[{"id_menu":1,"count":1}]	11766	pick-up	0	12
41634	2020-03-21 14:54:15	2020-03-21	8	[{"id_menu":5,"count":1}]	2367	delivery	5	13
41635	2020-03-21 14:57:40	2020-03-21	9	[{"id_menu":6,"count":1}]	2311	pick-up	0	9
41636	2020-03-21 14:57:55	2020-03-21	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	8640	delivery	5	36
41637	2020-03-21 15:01:11	2020-03-21	12	[{"id_menu":1,"count":1}]	2634	pick-up	0	12
41638	2020-03-21 15:04:56	2020-03-21	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16604	delivery	5	40
41639	2020-03-21 15:07:23	2020-03-21	17	[{"id_menu":4,"count":1}]	16558	delivery	5	22
41640	2020-03-21 15:11:02	2020-03-21	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	9115	pick-up	0	26
41641	2020-03-21 15:13:50	2020-03-21	9	[{"id_menu":6,"count":1}]	16608	delivery	5	14
41642	2020-03-21 15:18:59	2020-03-21	12	[{"id_menu":1,"count":1}]	16492	pick-up	0	12
41643	2020-03-21 15:19:02	2020-03-21	9	[{"id_menu":6,"count":1}]	14747	delivery	5	14
41644	2020-03-21 15:27:10	2020-03-21	12	[{"id_menu":3,"count":2}]	15188	delivery	5	17
41645	2020-03-21 15:29:29	2020-03-21	9	[{"id_menu":6,"count":1}]	16496	pick-up	0	9
41646	2020-03-21 15:30:30	2020-03-21	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16566	delivery	5	34
41647	2020-03-21 15:30:40	2020-03-21	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16609	delivery	5	45
41648	2020-03-21 15:32:03	2020-03-21	9	[{"id_menu":7,"count":1}]	3534	delivery	5	14
41649	2020-03-21 15:34:14	2020-03-21	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":2}]	2647	delivery	5	28
41650	2020-03-21 15:38:30	2020-03-21	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	7204	delivery	5	48
41651	2020-03-21 15:39:37	2020-03-21	12	[{"id_menu":1,"count":1}]	1752	pick-up	0	12
41652	2020-03-21 15:41:04	2020-03-21	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16517	delivery	5	39
41653	2020-03-21 15:49:36	2020-03-21	8	[{"id_menu":5,"count":1}]	2421	pick-up	0	8
41654	2020-03-21 15:50:17	2020-03-21	9	[{"id_menu":7,"count":1}]	1830	delivery	5	14
41655	2020-03-21 15:54:59	2020-03-21	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	3099	delivery	5	34
41656	2020-03-21 15:55:16	2020-03-21	8	[{"id_menu":5,"count":1}]	9733	delivery	5	13
41657	2020-03-21 15:59:10	2020-03-21	9	[{"id_menu":7,"count":1}]	15065	delivery	5	14
41658	2020-03-21 16:01:37	2020-03-21	9	[{"id_menu":6,"count":1}]	6246	pick-up	0	9
41659	2020-03-21 16:01:49	2020-03-21	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	12361	delivery	5	22
41660	2020-03-21 16:07:58	2020-03-21	8	[{"id_menu":5,"count":1}]	16539	pick-up	0	8
41661	2020-03-21 16:09:19	2020-03-21	8	[{"id_menu":5,"count":1}]	12089	delivery	5	13
41662	2020-03-21 16:09:36	2020-03-21	8	[{"id_menu":5,"count":1}]	11718	delivery	5	13
41663	2020-03-21 16:11:02	2020-03-21	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	16588	delivery	5	36
41664	2020-03-21 16:12:16	2020-03-21	12	[{"id_menu":1,"count":1}]	16563	pick-up	0	12
41665	2020-03-21 16:15:13	2020-03-21	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	16508	delivery	5	36
41666	2020-03-21 16:19:07	2020-03-21	17	[{"id_menu":4,"count":1}]	16633	delivery	5	22
41667	2020-03-21 16:20:46	2020-03-21	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16540	delivery	5	52
41668	2020-03-21 16:22:06	2020-03-21	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	16499	delivery	5	39
41669	2020-03-21 16:23:32	2020-03-21	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	13089	delivery	5	44
41670	2020-03-21 16:26:00	2020-03-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	15576	delivery	5	31
41671	2020-03-21 16:26:58	2020-03-21	14	[{"id_menu":2,"count":1}]	16618	delivery	5	19
41672	2020-03-21 16:30:23	2020-03-21	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	16591	delivery	5	30
41673	2020-03-21 16:32:36	2020-03-21	12	[{"id_menu":1,"count":1}]	3730	pick-up	0	12
41674	2020-03-21 16:33:58	2020-03-21	9	[{"id_menu":6,"count":1}]	2083	pick-up	0	9
41675	2020-03-21 16:35:44	2020-03-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5311	pick-up	0	23
41676	2020-03-21 16:37:10	2020-03-21	8	[{"id_menu":5,"count":1}]	7748	delivery	5	13
41677	2020-03-21 16:40:07	2020-03-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	15514	delivery	5	28
41678	2020-03-21 16:42:42	2020-03-21	14	[{"id_menu":2,"count":1}]	9584	delivery	5	19
41679	2020-03-21 16:42:45	2020-03-21	9	[{"id_menu":7,"count":1}]	16645	delivery	5	14
41680	2020-03-21 16:53:20	2020-03-21	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	16594	delivery	5	26
41681	2020-03-21 16:56:28	2020-03-21	9	[{"id_menu":6,"count":1}]	16545	delivery	5	14
41682	2020-03-21 17:05:00	2020-03-21	12	[{"id_menu":1,"count":1}]	7491	delivery	5	17
41683	2020-03-21 17:10:31	2020-03-21	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	16610	delivery	5	25
41684	2020-03-21 17:11:57	2020-03-21	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	16648	delivery	5	36
41685	2020-03-21 17:12:49	2020-03-21	12	[{"id_menu":3,"count":1}]	3000	pick-up	0	12
41686	2020-03-21 17:17:22	2020-03-21	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	5452	pick-up	0	31
41687	2020-03-21 17:20:43	2020-03-21	9	[{"id_menu":7,"count":1}]	16523	delivery	5	14
41688	2020-03-21 17:23:21	2020-03-21	14	[{"id_menu":2,"count":1}]	11554	pick-up	0	14
41689	2020-03-21 17:23:50	2020-03-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11104	delivery	5	23
41690	2020-03-21 17:25:45	2020-03-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16615	delivery	5	31
41691	2020-03-21 17:29:26	2020-03-21	9	[{"id_menu":6,"count":1}]	16565	delivery	5	14
41692	2020-03-21 17:36:20	2020-03-21	9	[{"id_menu":6,"count":1}]	16646	delivery	5	14
41693	2020-03-21 17:38:47	2020-03-21	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5117	delivery	5	37
41694	2020-03-21 17:38:57	2020-03-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16570	delivery	5	23
41695	2020-03-21 17:42:21	2020-03-21	9	[{"id_menu":7,"count":1}]	16490	delivery	5	14
41696	2020-03-21 17:47:10	2020-03-21	14	[{"id_menu":2,"count":1}]	169	pick-up	0	14
41697	2020-03-21 17:48:34	2020-03-21	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16634	delivery	5	51
41698	2020-03-21 17:58:37	2020-03-21	12	[{"id_menu":1,"count":2}]	16542	delivery	5	17
41699	2020-03-21 18:07:23	2020-03-21	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	12984	delivery	5	26
41700	2020-03-21 18:08:08	2020-03-21	17	[{"id_menu":4,"count":1}]	177	pick-up	0	17
41701	2020-03-21 18:08:20	2020-03-21	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3867	delivery	5	43
41702	2020-03-21 18:12:29	2020-03-21	8	[{"id_menu":5,"count":1}]	7006	delivery	5	13
41703	2020-03-21 18:15:18	2020-03-21	9	[{"id_menu":6,"count":1}]	16528	delivery	5	14
41704	2020-03-21 18:22:37	2020-03-21	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16538	delivery	5	49
41705	2020-03-21 18:23:21	2020-03-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":3}]	6190	delivery	5	28
41706	2020-03-21 18:25:23	2020-03-21	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5035	pick-up	0	40
41707	2020-03-21 18:27:38	2020-03-21	8	[{"id_menu":5,"count":1}]	16516	delivery	5	13
41708	2020-03-21 18:27:58	2020-03-21	9	[{"id_menu":7,"count":3}]	16536	delivery	5	14
41709	2020-03-21 18:29:41	2020-03-21	9	[{"id_menu":7,"count":1}]	6820	delivery	5	14
41710	2020-03-21 18:30:32	2020-03-21	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16577	delivery	5	45
41711	2020-03-21 18:33:58	2020-03-21	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	13275	pick-up	0	43
41712	2020-03-21 18:35:58	2020-03-21	12	[{"id_menu":1,"count":1}]	11615	pick-up	0	12
41713	2020-03-21 18:35:58	2020-03-21	12	[{"id_menu":1,"count":1}]	4983	delivery	5	17
41714	2020-03-21 18:37:44	2020-03-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15019	delivery	5	31
41715	2020-03-21 18:46:13	2020-03-21	12	[{"id_menu":3,"count":1}]	16498	delivery	5	17
41716	2020-03-21 18:51:05	2020-03-21	8	[{"id_menu":5,"count":1}]	11840	delivery	5	13
41717	2020-03-21 19:03:03	2020-03-21	9	[{"id_menu":7,"count":1}]	16519	pick-up	0	9
41718	2020-03-21 19:06:23	2020-03-21	17	[{"id_menu":4,"count":1}]	6536	delivery	5	22
41719	2020-03-21 19:15:43	2020-03-21	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16638	delivery	5	36
41720	2020-03-21 19:29:23	2020-03-21	9	[{"id_menu":7,"count":1}]	15449	pick-up	0	9
41721	2020-03-21 19:34:37	2020-03-21	12	[{"id_menu":3,"count":1}]	14133	pick-up	0	12
41722	2020-03-21 19:34:57	2020-03-21	8	[{"id_menu":5,"count":1}]	2320	delivery	5	13
41723	2020-03-21 19:35:31	2020-03-21	9	[{"id_menu":6,"count":1}]	16527	delivery	5	14
41724	2020-03-21 19:40:48	2020-03-21	12	[{"id_menu":1,"count":1}]	16554	delivery	5	17
41725	2020-03-21 19:40:53	2020-03-21	9	[{"id_menu":7,"count":1}]	16518	delivery	5	14
41726	2020-03-21 19:40:59	2020-03-21	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16573	delivery	5	36
41727	2020-03-21 19:44:43	2020-03-21	12	[{"id_menu":1,"count":1}]	16575	delivery	5	17
41728	2020-03-21 19:51:57	2020-03-21	14	[{"id_menu":2,"count":1}]	8090	delivery	5	19
41729	2020-03-21 19:53:05	2020-03-21	9	[{"id_menu":7,"count":1}]	9011	delivery	5	14
41730	2020-03-21 19:53:45	2020-03-21	9	[{"id_menu":6,"count":1}]	16514	delivery	5	14
41731	2020-03-21 20:02:40	2020-03-21	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6075	delivery	5	56
41732	2020-03-21 20:05:06	2020-03-21	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	10066	delivery	5	26
41733	2020-03-21 20:09:34	2020-03-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1819	pick-up	0	23
41734	2020-03-21 20:13:13	2020-03-21	12	[{"id_menu":1,"count":1}]	16560	delivery	5	17
41735	2020-03-21 20:18:57	2020-03-21	17	[{"id_menu":4,"count":1}]	3054	pick-up	0	17
41736	2020-03-21 20:23:11	2020-03-21	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2876	delivery	5	30
41737	2020-03-21 20:27:42	2020-03-21	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	332	pick-up	0	29
41738	2020-03-21 20:27:56	2020-03-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6506	delivery	5	28
41739	2020-03-21 20:33:59	2020-03-21	12	[{"id_menu":3,"count":1}]	8609	pick-up	0	12
41740	2020-03-21 20:38:13	2020-03-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2780	pick-up	0	17
41741	2020-03-21 20:38:31	2020-03-21	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	16543	delivery	5	26
41742	2020-03-21 20:40:29	2020-03-21	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	11534	pick-up	0	23
41743	2020-03-21 20:49:19	2020-03-21	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12290	delivery	5	43
41744	2020-03-21 20:51:46	2020-03-21	17	[{"id_menu":4,"count":1}]	4395	pick-up	0	17
41745	2020-03-21 20:55:37	2020-03-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16507	delivery	5	31
41746	2020-03-21 20:58:29	2020-03-21	9	[{"id_menu":6,"count":1}]	7189	delivery	5	14
41747	2020-03-21 21:01:10	2020-03-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4943	pick-up	0	26
41748	2020-03-21 21:01:33	2020-03-21	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	8098	pick-up	0	31
41749	2020-03-21 21:02:36	2020-03-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10616	delivery	5	23
41750	2020-03-21 21:07:02	2020-03-21	9	[{"id_menu":6,"count":1}]	6962	pick-up	0	9
41751	2020-03-21 21:09:32	2020-03-21	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	16635	delivery	5	40
41752	2020-03-21 21:09:39	2020-03-21	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	691	pick-up	0	20
41753	2020-03-21 21:12:06	2020-03-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	163	delivery	5	28
41754	2020-03-21 21:17:58	2020-03-21	12	[{"id_menu":1,"count":1}]	543	delivery	5	17
41755	2020-03-21 21:27:32	2020-03-21	17	[{"id_menu":4,"count":1}]	6109	pick-up	0	17
41756	2020-03-21 21:28:32	2020-03-21	14	[{"id_menu":2,"count":1}]	15569	delivery	5	19
41757	2020-03-21 21:32:48	2020-03-21	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16520	delivery	5	47
41758	2020-03-21 21:43:09	2020-03-21	14	[{"id_menu":2,"count":1}]	8466	delivery	5	19
41759	2020-03-21 21:51:14	2020-03-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	5044	delivery	5	28
41760	2020-03-21 21:51:36	2020-03-21	9	[{"id_menu":6,"count":1}]	16632	pick-up	0	9
41761	2020-03-21 21:52:53	2020-03-21	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8828	delivery	5	36
41762	2020-03-21 21:56:57	2020-03-21	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	5120	delivery	5	48
41763	2020-03-21 22:00:43	2020-03-21	8	[{"id_menu":5,"count":1}]	13507	delivery	5	13
41764	2020-03-21 22:09:30	2020-03-21	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16567	delivery	5	35
41765	2020-03-21 22:10:47	2020-03-21	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	13651	delivery	5	26
41766	2020-03-21 22:23:47	2020-03-21	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	16574	delivery	5	36
41767	2020-03-21 22:25:04	2020-03-21	9	[{"id_menu":7,"count":1}]	6496	delivery	5	14
41768	2020-03-21 22:27:08	2020-03-21	12	[{"id_menu":1,"count":1}]	16624	delivery	5	17
41769	2020-03-21 22:30:25	2020-03-21	12	[{"id_menu":1,"count":1}]	3701	pick-up	0	12
41770	2020-03-21 22:36:58	2020-03-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6958	delivery	5	22
41771	2020-03-21 22:37:50	2020-03-21	9	[{"id_menu":6,"count":1}]	16586	delivery	5	14
41772	2020-03-21 22:37:52	2020-03-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	12758	delivery	5	22
41773	2020-03-21 22:42:44	2020-03-21	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	16497	delivery	5	26
41774	2020-03-21 22:42:57	2020-03-21	14	[{"id_menu":2,"count":1}]	16522	delivery	5	19
41775	2020-03-21 22:45:55	2020-03-21	8	[{"id_menu":5,"count":1}]	546	delivery	5	13
41776	2020-03-21 22:46:46	2020-03-21	14	[{"id_menu":2,"count":1}]	16589	delivery	5	19
41777	2020-03-21 22:49:12	2020-03-21	9	[{"id_menu":6,"count":1}]	2110	delivery	5	14
41778	2020-03-21 22:51:00	2020-03-21	14	[{"id_menu":2,"count":1}]	13681	delivery	5	19
41779	2020-03-21 22:51:55	2020-03-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12846	pick-up	0	26
41780	2020-03-21 23:02:47	2020-03-21	12	[{"id_menu":3,"count":1}]	1313	delivery	5	17
41781	2020-03-21 23:06:08	2020-03-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	16576	delivery	5	31
41782	2020-03-21 23:09:12	2020-03-21	14	[{"id_menu":2,"count":2}]	3493	delivery	5	19
41783	2020-03-21 23:09:14	2020-03-21	9	[{"id_menu":7,"count":1}]	13987	delivery	5	14
41784	2020-03-21 23:12:28	2020-03-21	12	[{"id_menu":1,"count":1}]	10870	pick-up	0	12
41785	2020-03-21 23:13:13	2020-03-21	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	9197	delivery	5	26
41786	2020-03-21 23:18:21	2020-03-21	17	[{"id_menu":4,"count":1}]	486	delivery	5	22
41787	2020-03-21 23:24:24	2020-03-21	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	7091	delivery	5	40
41788	2020-03-21 23:28:31	2020-03-21	12	[{"id_menu":1,"count":1}]	11933	delivery	5	17
41789	2020-03-21 23:29:26	2020-03-21	9	[{"id_menu":6,"count":1}]	16571	delivery	5	14
41790	2020-03-21 23:30:21	2020-03-21	8	[{"id_menu":5,"count":1}]	16639	delivery	5	13
41791	2020-03-21 23:30:55	2020-03-21	8	[{"id_menu":5,"count":1}]	5430	pick-up	0	8
41792	2020-03-21 23:39:31	2020-03-21	14	[{"id_menu":2,"count":1}]	16564	delivery	5	19
41793	2020-03-21 23:41:33	2020-03-21	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2041	pick-up	0	21
41794	2020-03-21 23:42:06	2020-03-21	12	[{"id_menu":3,"count":1}]	9490	delivery	5	17
41795	2020-03-21 23:45:48	2020-03-21	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	16643	delivery	5	26
41796	2020-03-21 23:46:38	2020-03-21	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":2}]	14792	delivery	5	28
41797	2020-03-21 23:50:06	2020-03-21	12	[{"id_menu":3,"count":1}]	14093	delivery	5	17
41798	2020-03-21 23:52:53	2020-03-21	9	[{"id_menu":6,"count":1}]	4714	pick-up	0	9
41799	2020-03-21 23:58:43	2020-03-21	9	[{"id_menu":7,"count":3}]	16537	delivery	5	14
41800	2020-03-22 00:06:53	2020-03-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	314	pick-up	0	17
41801	2020-03-22 00:07:21	2020-03-22	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	11063	delivery	5	31
41802	2020-03-22 00:09:12	2020-03-22	8	[{"id_menu":5,"count":1}]	1015	pick-up	0	8
41803	2020-03-22 00:13:41	2020-03-22	9	[{"id_menu":6,"count":1}]	16734	delivery	5	14
41804	2020-03-22 00:16:15	2020-03-22	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	16741	delivery	5	25
41805	2020-03-22 00:26:32	2020-03-22	17	[{"id_menu":4,"count":1}]	16747	delivery	5	22
41806	2020-03-22 00:29:53	2020-03-22	14	[{"id_menu":2,"count":1}]	599	pick-up	0	14
41807	2020-03-22 00:34:07	2020-03-22	9	[{"id_menu":6,"count":1}]	16673	delivery	5	14
41808	2020-03-22 00:41:52	2020-03-22	9	[{"id_menu":6,"count":1}]	16770	delivery	5	14
41809	2020-03-22 00:44:06	2020-03-22	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16731	delivery	5	45
41810	2020-03-22 00:44:38	2020-03-22	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	621	pick-up	0	20
41811	2020-03-22 00:45:42	2020-03-22	17	[{"id_menu":4,"count":1}]	16748	delivery	5	22
41812	2020-03-22 00:45:45	2020-03-22	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13844	delivery	5	22
41813	2020-03-22 00:45:48	2020-03-22	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	3489	delivery	5	26
41814	2020-03-22 00:49:42	2020-03-22	9	[{"id_menu":6,"count":1}]	15162	delivery	5	14
41815	2020-03-22 00:51:02	2020-03-22	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1424	pick-up	0	30
41816	2020-03-22 00:51:17	2020-03-22	9	[{"id_menu":7,"count":1}]	11730	delivery	5	14
41817	2020-03-22 00:51:46	2020-03-22	14	[{"id_menu":2,"count":1}]	2116	delivery	5	19
41818	2020-03-22 00:53:13	2020-03-22	12	[{"id_menu":3,"count":1}]	1138	pick-up	0	12
41819	2020-03-22 00:59:23	2020-03-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	16733	delivery	5	36
41820	2020-03-22 01:04:50	2020-03-22	14	[{"id_menu":2,"count":1}]	3600	pick-up	0	14
41821	2020-03-22 01:08:54	2020-03-22	14	[{"id_menu":2,"count":1}]	12858	pick-up	0	14
41822	2020-03-22 01:09:54	2020-03-22	9	[{"id_menu":7,"count":1}]	16705	delivery	5	14
41823	2020-03-22 01:17:39	2020-03-22	14	[{"id_menu":2,"count":1}]	3268	delivery	5	19
41824	2020-03-22 01:18:20	2020-03-22	9	[{"id_menu":6,"count":1}]	16782	delivery	5	14
41825	2020-03-22 01:19:25	2020-03-22	12	[{"id_menu":1,"count":1}]	2729	delivery	5	17
41826	2020-03-22 01:27:34	2020-03-22	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16746	delivery	5	37
41827	2020-03-22 01:29:07	2020-03-22	9	[{"id_menu":6,"count":2}]	14969	pick-up	0	9
41828	2020-03-22 01:30:26	2020-03-22	9	[{"id_menu":7,"count":2}]	16703	delivery	5	14
41829	2020-03-22 01:33:43	2020-03-22	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	15829	pick-up	0	22
41830	2020-03-22 01:37:30	2020-03-22	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	16628	delivery	5	31
41831	2020-03-22 01:37:37	2020-03-22	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	5555	pick-up	0	20
41832	2020-03-22 01:40:26	2020-03-22	9	[{"id_menu":7,"count":1}]	10939	pick-up	0	9
41833	2020-03-22 01:41:51	2020-03-22	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16627	pick-up	0	40
41834	2020-03-22 01:47:55	2020-03-22	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16695	delivery	5	35
41835	2020-03-22 01:48:50	2020-03-22	9	[{"id_menu":6,"count":1}]	16725	delivery	5	14
41836	2020-03-22 01:53:05	2020-03-22	14	[{"id_menu":2,"count":1}]	5171	delivery	5	19
41837	2020-03-22 01:54:29	2020-03-22	9	[{"id_menu":7,"count":1}]	16717	delivery	5	14
41838	2020-03-22 01:54:35	2020-03-22	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6022	delivery	5	51
41839	2020-03-22 01:59:16	2020-03-22	9	[{"id_menu":7,"count":2}]	16672	delivery	5	14
41840	2020-03-22 02:09:24	2020-03-22	9	[{"id_menu":7,"count":1}]	11572	delivery	5	14
41841	2020-03-22 02:16:44	2020-03-22	9	[{"id_menu":7,"count":1}]	1562	pick-up	0	9
41842	2020-03-22 02:17:48	2020-03-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	13097	delivery	5	28
41843	2020-03-22 02:22:11	2020-03-22	14	[{"id_menu":2,"count":1}]	16018	pick-up	0	14
41844	2020-03-22 02:23:55	2020-03-22	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9172	delivery	5	31
41845	2020-03-22 02:25:20	2020-03-22	14	[{"id_menu":2,"count":1}]	16499	delivery	5	19
41846	2020-03-22 02:28:19	2020-03-22	17	[{"id_menu":4,"count":1}]	5301	delivery	5	22
41847	2020-03-22 02:29:50	2020-03-22	12	[{"id_menu":1,"count":1}]	1450	pick-up	0	12
41848	2020-03-22 02:32:42	2020-03-22	9	[{"id_menu":6,"count":1}]	16783	delivery	5	14
41849	2020-03-22 02:34:17	2020-03-22	17	[{"id_menu":4,"count":1}]	4841	pick-up	0	17
41850	2020-03-22 02:36:36	2020-03-22	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	5830	delivery	5	37
41851	2020-03-22 02:38:08	2020-03-22	12	[{"id_menu":3,"count":1}]	11287	delivery	5	17
41852	2020-03-22 02:42:24	2020-03-22	9	[{"id_menu":6,"count":1}]	11239	pick-up	0	9
41853	2020-03-22 02:44:49	2020-03-22	9	[{"id_menu":7,"count":2}]	2401	pick-up	0	9
41854	2020-03-22 02:47:55	2020-03-22	9	[{"id_menu":7,"count":1}]	16726	delivery	5	14
41855	2020-03-22 02:48:51	2020-03-22	14	[{"id_menu":2,"count":2}]	16727	delivery	5	19
41856	2020-03-22 02:49:51	2020-03-22	14	[{"id_menu":2,"count":1}]	16678	pick-up	0	14
41857	2020-03-22 02:53:04	2020-03-22	17	[{"id_menu":4,"count":1}]	10242	delivery	5	22
41858	2020-03-22 02:55:28	2020-03-22	8	[{"id_menu":5,"count":1}]	11673	delivery	5	13
41859	2020-03-22 02:56:10	2020-03-22	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	7765	delivery	5	25
41860	2020-03-22 02:58:20	2020-03-22	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12129	pick-up	0	17
41861	2020-03-22 03:00:20	2020-03-22	12	[{"id_menu":1,"count":1}]	16651	delivery	5	17
41862	2020-03-22 03:02:45	2020-03-22	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16775	delivery	5	36
41863	2020-03-22 03:04:00	2020-03-22	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1174	pick-up	0	24
41864	2020-03-22 03:05:07	2020-03-22	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15437	delivery	5	39
41865	2020-03-22 03:07:16	2020-03-22	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	4593	delivery	5	22
41866	2020-03-22 03:09:30	2020-03-22	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	13673	delivery	5	25
41867	2020-03-22 03:12:33	2020-03-22	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	11859	delivery	5	26
41868	2020-03-22 03:15:37	2020-03-22	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8146	pick-up	0	29
41869	2020-03-22 03:16:37	2020-03-22	9	[{"id_menu":6,"count":1}]	1742	delivery	5	14
41870	2020-03-22 03:21:07	2020-03-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	16442	pick-up	0	23
41871	2020-03-22 03:26:06	2020-03-22	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	15057	delivery	5	34
41872	2020-03-22 03:28:02	2020-03-22	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	16342	pick-up	0	23
41873	2020-03-22 03:29:38	2020-03-22	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	9048	delivery	5	26
41874	2020-03-22 03:30:35	2020-03-22	9	[{"id_menu":7,"count":1}]	16765	pick-up	0	9
41875	2020-03-22 03:32:38	2020-03-22	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4313	delivery	5	31
41876	2020-03-22 03:33:33	2020-03-22	12	[{"id_menu":1,"count":2}]	2311	pick-up	0	12
41877	2020-03-22 03:33:44	2020-03-22	8	[{"id_menu":5,"count":1}]	11672	delivery	5	13
41878	2020-03-22 03:33:56	2020-03-22	9	[{"id_menu":6,"count":1}]	16768	delivery	5	14
41879	2020-03-22 03:35:30	2020-03-22	14	[{"id_menu":2,"count":1}]	12089	delivery	5	19
41880	2020-03-22 03:44:33	2020-03-22	8	[{"id_menu":5,"count":1}]	2023	delivery	5	13
41881	2020-03-22 03:49:57	2020-03-22	14	[{"id_menu":2,"count":1}]	13850	delivery	5	19
41882	2020-03-22 03:57:11	2020-03-22	33	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	5812	pick-up	0	33
41883	2020-03-22 03:58:35	2020-03-22	14	[{"id_menu":2,"count":1}]	1832	pick-up	0	14
41884	2020-03-22 04:03:08	2020-03-22	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	16429	delivery	5	40
41885	2020-03-22 04:03:54	2020-03-22	17	[{"id_menu":4,"count":1}]	11533	delivery	5	22
41886	2020-03-22 04:05:03	2020-03-22	12	[{"id_menu":3,"count":1}]	16670	delivery	5	17
41887	2020-03-22 04:06:38	2020-03-22	12	[{"id_menu":1,"count":1}]	154	delivery	5	17
41888	2020-03-22 04:07:16	2020-03-22	9	[{"id_menu":7,"count":1}]	15768	delivery	5	14
41889	2020-03-22 04:09:20	2020-03-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6326	delivery	5	22
41890	2020-03-22 04:11:46	2020-03-22	12	[{"id_menu":1,"count":1}]	6205	delivery	5	17
41891	2020-03-22 04:11:57	2020-03-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	1968	delivery	5	36
41892	2020-03-22 04:13:54	2020-03-22	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3251	delivery	5	55
41893	2020-03-22 04:17:43	2020-03-22	9	[{"id_menu":6,"count":1}]	15902	delivery	5	14
41894	2020-03-22 04:17:51	2020-03-22	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15018	delivery	5	45
41895	2020-03-22 04:19:02	2020-03-22	9	[{"id_menu":7,"count":1}]	2513	pick-up	0	9
41896	2020-03-22 04:25:04	2020-03-22	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	16771	delivery	5	22
41897	2020-03-22 04:25:33	2020-03-22	8	[{"id_menu":5,"count":1}]	11815	delivery	5	13
41898	2020-03-22 04:26:23	2020-03-22	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	11	pick-up	0	20
41899	2020-03-22 04:33:00	2020-03-22	14	[{"id_menu":2,"count":1}]	2520	delivery	5	19
41900	2020-03-22 04:33:01	2020-03-22	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	14519	pick-up	0	26
41901	2020-03-22 04:34:58	2020-03-22	8	[{"id_menu":5,"count":1}]	12664	delivery	5	13
41902	2020-03-22 04:36:35	2020-03-22	12	[{"id_menu":3,"count":1}]	11253	delivery	5	17
41903	2020-03-22 04:39:59	2020-03-22	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	16777	delivery	5	40
41904	2020-03-22 04:43:40	2020-03-22	14	[{"id_menu":2,"count":1}]	8583	delivery	5	19
41905	2020-03-22 04:44:02	2020-03-22	12	[{"id_menu":1,"count":1}]	856	pick-up	0	12
41906	2020-03-22 04:44:40	2020-03-22	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16764	delivery	5	22
41907	2020-03-22 04:44:55	2020-03-22	17	[{"id_menu":4,"count":1}]	8955	delivery	5	22
41908	2020-03-22 04:48:47	2020-03-22	8	[{"id_menu":5,"count":1}]	12577	pick-up	0	8
41909	2020-03-22 04:52:37	2020-03-22	12	[{"id_menu":1,"count":1}]	12683	delivery	5	17
41910	2020-03-22 04:53:38	2020-03-22	8	[{"id_menu":5,"count":1}]	9268	delivery	5	13
41911	2020-03-22 04:56:32	2020-03-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4007	delivery	5	23
41912	2020-03-22 05:00:24	2020-03-22	12	[{"id_menu":3,"count":1}]	4987	delivery	5	17
41913	2020-03-22 05:01:10	2020-03-22	12	[{"id_menu":3,"count":1}]	4190	delivery	5	17
41914	2020-03-22 05:03:30	2020-03-22	14	[{"id_menu":2,"count":1}]	13702	delivery	5	19
41915	2020-03-22 05:11:52	2020-03-22	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16753	pick-up	0	30
41916	2020-03-22 05:20:44	2020-03-22	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	8629	pick-up	0	21
41917	2020-03-22 05:21:19	2020-03-22	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	16246	pick-up	0	20
41918	2020-03-22 05:21:26	2020-03-22	14	[{"id_menu":2,"count":1}]	9621	delivery	5	19
41919	2020-03-22 05:21:50	2020-03-22	14	[{"id_menu":2,"count":1}]	748	delivery	5	19
41920	2020-03-22 05:21:58	2020-03-22	12	[{"id_menu":1,"count":1}]	16658	delivery	5	17
41921	2020-03-22 05:22:30	2020-03-22	9	[{"id_menu":7,"count":1}]	16655	delivery	5	14
41922	2020-03-22 05:24:11	2020-03-22	17	[{"id_menu":4,"count":1}]	4943	pick-up	0	17
41923	2020-03-22 05:27:41	2020-03-22	17	[{"id_menu":4,"count":1}]	16687	delivery	5	22
41924	2020-03-22 05:32:49	2020-03-22	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	10883	delivery	5	38
41925	2020-03-22 05:41:36	2020-03-22	12	[{"id_menu":3,"count":1}]	3469	delivery	5	17
41926	2020-03-22 05:42:28	2020-03-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16700	delivery	5	23
41927	2020-03-22 05:47:57	2020-03-22	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6941	pick-up	0	26
41928	2020-03-22 05:48:18	2020-03-22	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16650	delivery	5	31
41929	2020-03-22 05:51:52	2020-03-22	12	[{"id_menu":1,"count":1}]	1649	pick-up	0	12
41930	2020-03-22 05:54:35	2020-03-22	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	197	pick-up	0	26
41931	2020-03-22 05:57:06	2020-03-22	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16254	delivery	5	31
41932	2020-03-22 05:58:31	2020-03-22	17	[{"id_menu":4,"count":1}]	15188	delivery	5	22
41933	2020-03-22 06:07:55	2020-03-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	8088	pick-up	0	31
41934	2020-03-22 06:11:18	2020-03-22	12	[{"id_menu":3,"count":2}]	16769	pick-up	0	12
41935	2020-03-22 06:23:45	2020-03-22	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	16744	delivery	5	27
41936	2020-03-22 06:24:29	2020-03-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16780	delivery	5	23
41937	2020-03-22 06:25:38	2020-03-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11518	delivery	5	22
41938	2020-03-22 06:25:43	2020-03-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2142	pick-up	0	18
41939	2020-03-22 06:28:46	2020-03-22	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	5960	delivery	5	36
41940	2020-03-22 06:30:30	2020-03-22	8	[{"id_menu":5,"count":1}]	256	pick-up	0	8
41941	2020-03-22 06:34:39	2020-03-22	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2032	pick-up	0	17
41942	2020-03-22 06:34:48	2020-03-22	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	16694	delivery	5	36
41943	2020-03-22 06:34:48	2020-03-22	8	[{"id_menu":5,"count":1}]	14284	pick-up	0	8
41944	2020-03-22 06:36:13	2020-03-22	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	16668	delivery	5	26
41945	2020-03-22 06:39:40	2020-03-22	12	[{"id_menu":3,"count":1}]	16742	delivery	5	17
41946	2020-03-22 06:39:58	2020-03-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	15096	delivery	5	22
41947	2020-03-22 06:42:50	2020-03-22	14	[{"id_menu":2,"count":1}]	1963	delivery	5	19
41948	2020-03-22 06:42:52	2020-03-22	12	[{"id_menu":3,"count":1}]	7815	pick-up	0	12
41949	2020-03-22 06:47:22	2020-03-22	9	[{"id_menu":7,"count":1}]	8813	delivery	5	14
41950	2020-03-22 06:49:44	2020-03-22	9	[{"id_menu":7,"count":1}]	16718	delivery	5	14
41951	2020-03-22 06:53:44	2020-03-22	12	[{"id_menu":1,"count":1}]	2134	pick-up	0	12
41952	2020-03-22 06:58:18	2020-03-22	8	[{"id_menu":5,"count":2}]	12711	delivery	5	13
41953	2020-03-22 07:01:20	2020-03-22	12	[{"id_menu":1,"count":2}]	6733	pick-up	0	12
41954	2020-03-22 07:09:39	2020-03-22	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	8962	delivery	5	39
41955	2020-03-22 07:11:48	2020-03-22	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16671	delivery	5	34
41956	2020-03-22 07:21:49	2020-03-22	17	[{"id_menu":4,"count":1}]	3544	pick-up	0	17
41957	2020-03-22 07:30:45	2020-03-22	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	16690	delivery	5	34
41958	2020-03-22 07:33:08	2020-03-22	17	[{"id_menu":4,"count":1}]	16729	delivery	5	22
41959	2020-03-22 07:33:48	2020-03-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6869	pick-up	0	23
41960	2020-03-22 07:34:35	2020-03-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7427	delivery	5	22
41961	2020-03-22 07:36:12	2020-03-22	12	[{"id_menu":1,"count":1}]	3809	delivery	5	17
41962	2020-03-22 07:47:19	2020-03-22	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2477	pick-up	0	22
41963	2020-03-22 07:47:32	2020-03-22	17	[{"id_menu":4,"count":1}]	3157	delivery	5	22
41964	2020-03-22 07:51:14	2020-03-22	9	[{"id_menu":7,"count":1}]	14940	delivery	5	14
41965	2020-03-22 07:52:02	2020-03-22	12	[{"id_menu":3,"count":1}]	16704	pick-up	0	12
41966	2020-03-22 07:54:47	2020-03-22	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	786	pick-up	0	29
41967	2020-03-22 08:00:09	2020-03-22	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	466	delivery	5	31
41968	2020-03-22 08:03:54	2020-03-22	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16786	delivery	5	35
41969	2020-03-22 08:06:54	2020-03-22	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6509	delivery	5	40
41970	2020-03-22 08:12:56	2020-03-22	14	[{"id_menu":2,"count":1}]	10067	pick-up	0	14
41971	2020-03-22 08:13:33	2020-03-22	9	[{"id_menu":6,"count":1}]	543	delivery	5	14
41972	2020-03-22 08:21:13	2020-03-22	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15079	delivery	5	36
41973	2020-03-22 08:23:43	2020-03-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	5159	delivery	5	28
41974	2020-03-22 08:25:05	2020-03-22	9	[{"id_menu":7,"count":1}]	16762	pick-up	0	9
41975	2020-03-22 08:29:15	2020-03-22	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16693	delivery	5	57
41976	2020-03-22 08:36:19	2020-03-22	9	[{"id_menu":6,"count":1}]	16745	pick-up	0	9
41977	2020-03-22 08:37:40	2020-03-22	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	16669	delivery	5	56
41978	2020-03-22 08:38:28	2020-03-22	14	[{"id_menu":2,"count":1}]	8183	delivery	5	19
41979	2020-03-22 08:46:58	2020-03-22	12	[{"id_menu":1,"count":1}]	10447	delivery	5	17
41980	2020-03-22 08:47:39	2020-03-22	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	10584	delivery	5	34
41981	2020-03-22 08:48:18	2020-03-22	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	16709	delivery	5	22
41982	2020-03-22 08:50:24	2020-03-22	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16752	delivery	5	31
41983	2020-03-22 08:52:36	2020-03-22	14	[{"id_menu":2,"count":1}]	1878	pick-up	0	14
41984	2020-03-22 08:56:58	2020-03-22	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	13087	delivery	5	23
41985	2020-03-22 08:58:05	2020-03-22	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16784	delivery	5	31
41986	2020-03-22 09:00:41	2020-03-22	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16706	delivery	5	55
41987	2020-03-22 09:00:58	2020-03-22	8	[{"id_menu":5,"count":1}]	585	delivery	5	13
41988	2020-03-22 09:05:31	2020-03-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	14256	delivery	5	28
41989	2020-03-22 09:08:25	2020-03-22	8	[{"id_menu":5,"count":1}]	16774	delivery	5	13
41990	2020-03-22 09:11:27	2020-03-22	12	[{"id_menu":1,"count":1}]	16739	delivery	5	17
41991	2020-03-22 09:12:23	2020-03-22	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16785	delivery	5	35
41992	2020-03-22 09:14:33	2020-03-22	12	[{"id_menu":3,"count":1}]	16656	delivery	5	17
41993	2020-03-22 09:15:49	2020-03-22	12	[{"id_menu":1,"count":1}]	13923	pick-up	0	12
41994	2020-03-22 09:26:57	2020-03-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	16736	delivery	5	36
41995	2020-03-22 09:29:17	2020-03-22	12	[{"id_menu":3,"count":1}]	12738	pick-up	0	12
41996	2020-03-22 09:37:19	2020-03-22	9	[{"id_menu":7,"count":1}]	16091	delivery	5	14
41997	2020-03-22 09:39:41	2020-03-22	12	[{"id_menu":3,"count":1}]	9278	delivery	5	17
41998	2020-03-22 09:40:03	2020-03-22	8	[{"id_menu":5,"count":1}]	16264	pick-up	0	8
41999	2020-03-22 09:40:18	2020-03-22	8	[{"id_menu":5,"count":1}]	15563	delivery	5	13
42000	2020-03-22 09:41:37	2020-03-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6299	pick-up	0	31
42001	2020-03-22 09:54:28	2020-03-22	14	[{"id_menu":2,"count":1}]	13535	delivery	5	19
42002	2020-03-22 09:55:14	2020-03-22	12	[{"id_menu":1,"count":1}]	16740	delivery	5	17
42003	2020-03-22 09:55:29	2020-03-22	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2055	delivery	5	26
42004	2020-03-22 09:56:27	2020-03-22	8	[{"id_menu":5,"count":1}]	16750	delivery	5	13
42005	2020-03-22 10:03:11	2020-03-22	12	[{"id_menu":1,"count":1}]	78	pick-up	0	12
42006	2020-03-22 10:09:24	2020-03-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	7688	pick-up	0	31
42007	2020-03-22 10:10:20	2020-03-22	8	[{"id_menu":5,"count":2}]	16722	delivery	5	13
42008	2020-03-22 10:10:35	2020-03-22	17	[{"id_menu":4,"count":1}]	3609	pick-up	0	17
42009	2020-03-22 10:15:05	2020-03-22	14	[{"id_menu":2,"count":1}]	3000	pick-up	0	14
42010	2020-03-22 10:15:59	2020-03-22	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2081	delivery	5	26
42011	2020-03-22 10:24:47	2020-03-22	8	[{"id_menu":5,"count":1}]	14879	delivery	5	13
42012	2020-03-22 10:28:26	2020-03-22	9	[{"id_menu":7,"count":1}]	9003	delivery	5	14
42013	2020-03-22 10:30:11	2020-03-22	9	[{"id_menu":7,"count":1}]	16054	delivery	5	14
42014	2020-03-22 10:30:32	2020-03-22	9	[{"id_menu":6,"count":2}]	1824	delivery	5	14
42015	2020-03-22 10:36:47	2020-03-22	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	4075	delivery	5	25
42016	2020-03-22 10:41:34	2020-03-22	9	[{"id_menu":7,"count":3}]	12180	delivery	5	14
42017	2020-03-22 10:43:06	2020-03-22	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9194	delivery	5	34
42018	2020-03-22 10:49:49	2020-03-22	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	439	pick-up	0	26
42019	2020-03-22 10:50:02	2020-03-22	9	[{"id_menu":7,"count":1}]	716	delivery	5	14
42020	2020-03-22 10:51:15	2020-03-22	12	[{"id_menu":3,"count":1}]	931	delivery	5	17
42021	2020-03-22 10:56:57	2020-03-22	14	[{"id_menu":2,"count":1}]	2244	pick-up	0	14
42022	2020-03-22 10:59:12	2020-03-22	14	[{"id_menu":2,"count":1}]	14084	delivery	5	19
42023	2020-03-22 11:00:59	2020-03-22	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	15120	delivery	5	27
42024	2020-03-22 11:03:04	2020-03-22	14	[{"id_menu":2,"count":1}]	16675	delivery	5	19
42025	2020-03-22 11:06:26	2020-03-22	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	16721	delivery	5	25
42026	2020-03-22 11:09:24	2020-03-22	9	[{"id_menu":6,"count":1}]	10518	delivery	5	14
42027	2020-03-22 11:09:46	2020-03-22	14	[{"id_menu":2,"count":2}]	8653	delivery	5	19
42028	2020-03-22 11:14:25	2020-03-22	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	5048	delivery	5	31
42029	2020-03-22 11:16:22	2020-03-22	9	[{"id_menu":6,"count":1}]	16772	delivery	5	14
42030	2020-03-22 11:17:20	2020-03-22	12	[{"id_menu":1,"count":1}]	16676	delivery	5	17
42031	2020-03-22 11:19:16	2020-03-22	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	16686	delivery	5	22
42032	2020-03-22 11:20:10	2020-03-22	9	[{"id_menu":6,"count":2}]	16682	pick-up	0	9
42033	2020-03-22 11:21:36	2020-03-22	9	[{"id_menu":7,"count":1}]	4324	delivery	5	14
42034	2020-03-22 11:28:27	2020-03-22	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	16231	delivery	5	25
42035	2020-03-22 11:30:43	2020-03-22	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15110	pick-up	0	26
42036	2020-03-22 11:30:46	2020-03-22	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16665	delivery	5	34
42037	2020-03-22 11:32:38	2020-03-22	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16680	delivery	5	36
42038	2020-03-22 11:43:12	2020-03-22	17	[{"id_menu":4,"count":1}]	7510	pick-up	0	17
42039	2020-03-22 11:44:01	2020-03-22	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	14198	delivery	5	23
42040	2020-03-22 11:44:55	2020-03-22	9	[{"id_menu":7,"count":1}]	16549	pick-up	0	9
42041	2020-03-22 11:47:07	2020-03-22	9	[{"id_menu":6,"count":1}]	14746	delivery	5	14
42042	2020-03-22 11:48:37	2020-03-22	9	[{"id_menu":7,"count":1}]	14099	delivery	5	14
42043	2020-03-22 11:50:54	2020-03-22	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1731	pick-up	0	24
42044	2020-03-22 11:52:07	2020-03-22	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	6895	delivery	5	31
42045	2020-03-22 11:53:26	2020-03-22	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1924	delivery	5	48
42046	2020-03-22 11:54:44	2020-03-22	9	[{"id_menu":6,"count":2}]	11454	pick-up	0	9
42047	2020-03-22 11:55:03	2020-03-22	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	14067	delivery	5	31
42048	2020-03-22 11:59:37	2020-03-22	12	[{"id_menu":3,"count":1}]	6797	delivery	5	17
42049	2020-03-22 12:02:08	2020-03-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1905	pick-up	0	31
42050	2020-03-22 12:02:22	2020-03-22	14	[{"id_menu":2,"count":1}]	9216	pick-up	0	14
42051	2020-03-22 12:06:28	2020-03-22	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	4595	delivery	5	39
42052	2020-03-22 12:10:52	2020-03-22	12	[{"id_menu":3,"count":1}]	16763	delivery	5	17
42053	2020-03-22 12:11:40	2020-03-22	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	10434	delivery	5	38
42054	2020-03-22 12:14:37	2020-03-22	14	[{"id_menu":2,"count":1}]	11539	pick-up	0	14
42055	2020-03-22 12:15:40	2020-03-22	8	[{"id_menu":5,"count":1}]	16214	delivery	5	13
42056	2020-03-22 12:23:45	2020-03-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5310	pick-up	0	17
42057	2020-03-22 12:28:58	2020-03-22	12	[{"id_menu":1,"count":1}]	14593	pick-up	0	12
42058	2020-03-22 12:38:21	2020-03-22	14	[{"id_menu":2,"count":1}]	3388	delivery	5	19
42059	2020-03-22 12:39:49	2020-03-22	9	[{"id_menu":7,"count":1}]	2287	pick-up	0	9
42060	2020-03-22 12:41:42	2020-03-22	14	[{"id_menu":2,"count":1}]	4720	delivery	5	19
42061	2020-03-22 12:45:49	2020-03-22	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	8448	delivery	5	26
42062	2020-03-22 12:46:31	2020-03-22	8	[{"id_menu":5,"count":1}]	16735	delivery	5	13
42063	2020-03-22 12:53:14	2020-03-22	14	[{"id_menu":2,"count":1}]	4882	delivery	5	19
42064	2020-03-22 12:54:11	2020-03-22	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14701	pick-up	0	50
42065	2020-03-22 12:55:12	2020-03-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	16630	delivery	5	28
42066	2020-03-22 13:00:56	2020-03-22	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	6705	delivery	5	25
42067	2020-03-22 13:07:12	2020-03-22	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	16712	delivery	5	26
42068	2020-03-22 13:08:37	2020-03-22	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	3595	delivery	5	25
42069	2020-03-22 13:08:55	2020-03-22	17	[{"id_menu":4,"count":1}]	3965	delivery	5	22
42070	2020-03-22 13:14:01	2020-03-22	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	16666	delivery	5	25
42071	2020-03-22 13:28:25	2020-03-22	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16649	delivery	5	39
42072	2020-03-22 13:29:26	2020-03-22	9	[{"id_menu":6,"count":1}]	16664	delivery	5	14
42073	2020-03-22 13:29:40	2020-03-22	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	9728	pick-up	0	26
42074	2020-03-22 13:32:49	2020-03-22	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	7986	delivery	5	31
42075	2020-03-22 13:36:44	2020-03-22	9	[{"id_menu":7,"count":1}]	709	pick-up	0	9
42076	2020-03-22 13:37:19	2020-03-22	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	1996	pick-up	0	32
42077	2020-03-22 13:37:52	2020-03-22	9	[{"id_menu":6,"count":1}]	13502	pick-up	0	9
42078	2020-03-22 13:38:05	2020-03-22	9	[{"id_menu":6,"count":1}]	12204	delivery	5	14
42079	2020-03-22 13:38:44	2020-03-22	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1499	pick-up	0	26
42080	2020-03-22 13:39:49	2020-03-22	8	[{"id_menu":5,"count":1}]	5514	pick-up	0	8
42081	2020-03-22 13:41:19	2020-03-22	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3624	pick-up	0	25
42082	2020-03-22 13:42:09	2020-03-22	9	[{"id_menu":6,"count":1}]	5979	delivery	5	14
42083	2020-03-22 13:44:25	2020-03-22	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	16696	delivery	5	38
42084	2020-03-22 13:53:16	2020-03-22	9	[{"id_menu":6,"count":1}]	482	delivery	5	14
42085	2020-03-22 13:53:47	2020-03-22	17	[{"id_menu":4,"count":2}]	689	pick-up	0	17
42086	2020-03-22 13:54:00	2020-03-22	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14068	delivery	5	35
42087	2020-03-22 14:00:06	2020-03-22	9	[{"id_menu":6,"count":1}]	14190	delivery	5	14
42088	2020-03-22 14:07:41	2020-03-22	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	12392	delivery	5	26
42089	2020-03-22 14:08:48	2020-03-22	17	[{"id_menu":4,"count":2}]	16737	pick-up	0	17
42090	2020-03-22 14:11:02	2020-03-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	10106	pick-up	0	31
42091	2020-03-22 14:13:16	2020-03-22	12	[{"id_menu":3,"count":1}]	3015	delivery	5	17
42092	2020-03-22 14:13:56	2020-03-22	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	16787	delivery	5	30
42093	2020-03-22 14:24:41	2020-03-22	9	[{"id_menu":7,"count":1}]	4444	pick-up	0	9
42094	2020-03-22 14:26:35	2020-03-22	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	16657	delivery	5	26
42095	2020-03-22 14:39:31	2020-03-22	9	[{"id_menu":6,"count":1}]	10525	pick-up	0	9
42096	2020-03-22 14:43:30	2020-03-22	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	16759	pick-up	0	22
42097	2020-03-22 14:47:37	2020-03-22	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	16778	delivery	5	56
42098	2020-03-22 14:48:40	2020-03-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	9737	delivery	5	36
42099	2020-03-22 14:49:50	2020-03-22	12	[{"id_menu":1,"count":1}]	13592	delivery	5	17
42100	2020-03-22 14:53:21	2020-03-22	17	[{"id_menu":4,"count":1}]	3335	pick-up	0	17
42101	2020-03-22 14:54:57	2020-03-22	17	[{"id_menu":4,"count":1}]	12142	delivery	5	22
42102	2020-03-22 15:02:53	2020-03-22	12	[{"id_menu":1,"count":1}]	16677	delivery	5	17
42103	2020-03-22 15:11:42	2020-03-22	9	[{"id_menu":7,"count":2}]	10354	delivery	5	14
42104	2020-03-22 15:15:40	2020-03-22	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	16724	delivery	5	35
42105	2020-03-22 15:19:45	2020-03-22	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	16659	pick-up	0	38
42106	2020-03-22 15:21:56	2020-03-22	9	[{"id_menu":6,"count":1}]	14984	delivery	5	14
42107	2020-03-22 15:23:55	2020-03-22	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	16723	delivery	5	34
42108	2020-03-22 15:24:58	2020-03-22	14	[{"id_menu":2,"count":1}]	12098	delivery	5	19
42109	2020-03-22 15:27:47	2020-03-22	9	[{"id_menu":6,"count":1}]	9460	delivery	5	14
42110	2020-03-22 15:31:14	2020-03-22	9	[{"id_menu":6,"count":1}]	2929	delivery	5	14
42111	2020-03-22 15:33:18	2020-03-22	12	[{"id_menu":3,"count":1}]	401	delivery	5	17
42112	2020-03-22 15:45:22	2020-03-22	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2686	delivery	5	26
42113	2020-03-22 15:55:14	2020-03-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	10394	pick-up	0	31
42114	2020-03-22 15:56:14	2020-03-22	12	[{"id_menu":1,"count":1}]	14089	pick-up	0	12
42115	2020-03-22 16:02:26	2020-03-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	11156	delivery	5	36
42116	2020-03-22 16:04:59	2020-03-22	9	[{"id_menu":7,"count":3}]	16711	delivery	5	14
42117	2020-03-22 16:06:11	2020-03-22	9	[{"id_menu":6,"count":1}]	16779	delivery	5	14
42118	2020-03-22 16:16:51	2020-03-22	12	[{"id_menu":1,"count":1}]	12778	delivery	5	17
42119	2020-03-22 16:16:54	2020-03-22	9	[{"id_menu":6,"count":1}]	7401	delivery	5	14
42120	2020-03-22 16:20:11	2020-03-22	12	[{"id_menu":3,"count":1}]	16707	pick-up	0	12
42121	2020-03-22 16:20:58	2020-03-22	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	16663	delivery	5	37
42122	2020-03-22 16:24:53	2020-03-22	12	[{"id_menu":3,"count":1}]	806	pick-up	0	12
42123	2020-03-22 16:26:54	2020-03-22	12	[{"id_menu":1,"count":1}]	135	delivery	5	17
42124	2020-03-22 16:32:35	2020-03-22	17	[{"id_menu":4,"count":1}]	1085	pick-up	0	17
42125	2020-03-22 16:34:52	2020-03-22	12	[{"id_menu":3,"count":1}]	832	delivery	5	17
42126	2020-03-22 16:34:59	2020-03-22	12	[{"id_menu":1,"count":1}]	3569	delivery	5	17
42127	2020-03-22 16:40:12	2020-03-22	12	[{"id_menu":3,"count":1}]	7159	delivery	5	17
42128	2020-03-22 16:42:34	2020-03-22	12	[{"id_menu":1,"count":1}]	7330	delivery	5	17
42129	2020-03-22 16:44:10	2020-03-22	12	[{"id_menu":3,"count":1}]	10396	delivery	5	17
42130	2020-03-22 16:53:31	2020-03-22	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	16730	delivery	5	27
42131	2020-03-22 16:57:09	2020-03-22	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	15663	delivery	5	31
42132	2020-03-22 17:00:55	2020-03-22	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16661	pick-up	0	26
42133	2020-03-22 17:03:18	2020-03-22	9	[{"id_menu":7,"count":1}]	16719	delivery	5	14
42134	2020-03-22 17:03:18	2020-03-22	9	[{"id_menu":7,"count":1}]	6920	delivery	5	14
42135	2020-03-22 17:05:37	2020-03-22	9	[{"id_menu":6,"count":1}]	2478	delivery	5	14
42136	2020-03-22 17:07:42	2020-03-22	14	[{"id_menu":2,"count":1}]	5478	pick-up	0	14
42137	2020-03-22 17:08:16	2020-03-22	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6150	delivery	5	43
42138	2020-03-22 17:16:41	2020-03-22	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	16781	delivery	5	26
42139	2020-03-22 17:19:55	2020-03-22	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	12184	pick-up	0	26
42140	2020-03-22 17:21:44	2020-03-22	12	[{"id_menu":1,"count":1}]	14281	delivery	5	17
42141	2020-03-22 17:27:37	2020-03-22	9	[{"id_menu":6,"count":1}]	16692	delivery	5	14
42142	2020-03-22 17:28:05	2020-03-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16228	pick-up	0	18
42143	2020-03-22 17:30:33	2020-03-22	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	16683	delivery	5	40
42144	2020-03-22 17:34:47	2020-03-22	9	[{"id_menu":6,"count":1}]	16691	delivery	5	14
42145	2020-03-22 17:37:27	2020-03-22	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1213	delivery	5	26
42146	2020-03-22 17:38:04	2020-03-22	9	[{"id_menu":7,"count":1}]	16743	delivery	5	14
42147	2020-03-22 17:39:28	2020-03-22	14	[{"id_menu":2,"count":1}]	7122	delivery	5	19
42148	2020-03-22 17:42:15	2020-03-22	8	[{"id_menu":5,"count":2}]	16714	delivery	5	13
42149	2020-03-22 17:54:43	2020-03-22	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	13773	delivery	5	23
42150	2020-03-22 17:56:41	2020-03-22	9	[{"id_menu":6,"count":1}]	8349	delivery	5	14
42151	2020-03-22 18:06:39	2020-03-22	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	16689	pick-up	0	21
42152	2020-03-22 18:06:56	2020-03-22	8	[{"id_menu":5,"count":1}]	16653	delivery	5	13
42153	2020-03-22 18:15:41	2020-03-22	12	[{"id_menu":3,"count":1}]	13607	delivery	5	17
42154	2020-03-22 18:25:37	2020-03-22	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	16340	delivery	5	23
42155	2020-03-22 18:30:29	2020-03-22	9	[{"id_menu":6,"count":1}]	15153	delivery	5	14
42156	2020-03-22 18:33:01	2020-03-22	14	[{"id_menu":2,"count":1}]	16701	pick-up	0	14
42157	2020-03-22 18:40:28	2020-03-22	9	[{"id_menu":6,"count":1}]	16472	delivery	5	14
42158	2020-03-22 18:46:29	2020-03-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2265	pick-up	0	23
42159	2020-03-22 18:49:55	2020-03-22	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12236	delivery	5	35
42160	2020-03-22 18:58:26	2020-03-22	8	[{"id_menu":5,"count":1}]	6369	pick-up	0	8
42161	2020-03-22 19:03:15	2020-03-22	12	[{"id_menu":3,"count":1}]	16716	delivery	5	17
42162	2020-03-22 19:06:59	2020-03-22	9	[{"id_menu":6,"count":1}]	16760	pick-up	0	9
42163	2020-03-22 19:09:44	2020-03-22	9	[{"id_menu":6,"count":1}]	16698	delivery	5	14
42164	2020-03-22 19:09:44	2020-03-22	9	[{"id_menu":6,"count":1}]	15263	delivery	5	14
42165	2020-03-22 19:11:20	2020-03-22	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	654	pick-up	0	26
42166	2020-03-22 19:14:17	2020-03-22	14	[{"id_menu":2,"count":1}]	7250	delivery	5	19
42167	2020-03-22 19:17:58	2020-03-22	14	[{"id_menu":2,"count":1}]	5430	pick-up	0	14
42168	2020-03-22 19:19:38	2020-03-22	12	[{"id_menu":3,"count":1}]	3244	delivery	5	17
42169	2020-03-22 19:22:14	2020-03-22	9	[{"id_menu":6,"count":1}]	4462	pick-up	0	9
42170	2020-03-22 19:23:40	2020-03-22	17	[{"id_menu":4,"count":1}]	338	pick-up	0	17
42171	2020-03-22 19:27:41	2020-03-22	17	[{"id_menu":4,"count":1}]	5253	pick-up	0	17
42172	2020-03-22 19:30:23	2020-03-22	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	16720	delivery	5	27
42173	2020-03-22 19:30:59	2020-03-22	9	[{"id_menu":7,"count":1}]	16697	delivery	5	14
42174	2020-03-22 19:32:22	2020-03-22	12	[{"id_menu":3,"count":1}]	236	pick-up	0	12
42175	2020-03-22 19:33:48	2020-03-22	9	[{"id_menu":6,"count":1}]	6690	delivery	5	14
42176	2020-03-22 19:34:06	2020-03-22	12	[{"id_menu":3,"count":1}]	16280	pick-up	0	12
42177	2020-03-22 19:34:55	2020-03-22	14	[{"id_menu":2,"count":1}]	351	pick-up	0	14
42178	2020-03-22 19:37:13	2020-03-22	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	7327	delivery	5	25
42179	2020-03-22 19:42:39	2020-03-22	9	[{"id_menu":6,"count":1}]	822	delivery	5	14
42180	2020-03-22 19:51:02	2020-03-22	14	[{"id_menu":2,"count":1}]	14446	delivery	5	19
42181	2020-03-22 19:53:16	2020-03-22	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8054	pick-up	0	26
42182	2020-03-22 19:55:06	2020-03-22	9	[{"id_menu":6,"count":1}]	16756	delivery	5	14
42183	2020-03-22 19:58:30	2020-03-22	9	[{"id_menu":7,"count":1}]	16667	delivery	5	14
42184	2020-03-22 19:58:31	2020-03-22	17	[{"id_menu":4,"count":1}]	16662	delivery	5	22
42185	2020-03-22 19:59:48	2020-03-22	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15614	delivery	5	31
42186	2020-03-22 20:03:05	2020-03-22	17	[{"id_menu":4,"count":1}]	16699	pick-up	0	17
42187	2020-03-22 20:10:54	2020-03-22	8	[{"id_menu":5,"count":1}]	6119	delivery	5	13
42188	2020-03-22 20:12:58	2020-03-22	8	[{"id_menu":5,"count":1}]	81	pick-up	0	8
42189	2020-03-22 20:13:44	2020-03-22	17	[{"id_menu":4,"count":1}]	16367	delivery	5	22
42190	2020-03-22 20:17:52	2020-03-22	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	5451	delivery	5	36
42191	2020-03-22 20:19:24	2020-03-22	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16738	delivery	5	34
42192	2020-03-22 20:20:00	2020-03-22	9	[{"id_menu":6,"count":1}]	3168	pick-up	0	9
42193	2020-03-22 20:23:51	2020-03-22	12	[{"id_menu":3,"count":1}]	2017	delivery	5	17
42194	2020-03-22 20:26:24	2020-03-22	9	[{"id_menu":7,"count":1}]	5192	delivery	5	14
42195	2020-03-22 20:27:04	2020-03-22	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16751	delivery	5	31
42196	2020-03-22 20:33:18	2020-03-22	9	[{"id_menu":7,"count":1}]	1896	pick-up	0	9
42197	2020-03-22 20:38:48	2020-03-22	17	[{"id_menu":4,"count":1}]	16708	delivery	5	22
42198	2020-03-22 20:39:01	2020-03-22	9	[{"id_menu":7,"count":1}]	16757	delivery	5	14
42199	2020-03-22 20:41:27	2020-03-22	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3579	delivery	5	48
42200	2020-03-22 20:44:25	2020-03-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	14943	delivery	5	23
42201	2020-03-22 20:49:13	2020-03-22	14	[{"id_menu":2,"count":1}]	16713	delivery	5	19
42202	2020-03-22 20:51:00	2020-03-22	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16688	delivery	5	40
42203	2020-03-22 20:52:59	2020-03-22	12	[{"id_menu":1,"count":1}]	13375	delivery	5	17
42204	2020-03-22 20:56:19	2020-03-22	8	[{"id_menu":5,"count":1}]	16660	delivery	5	13
42205	2020-03-22 20:57:34	2020-03-22	12	[{"id_menu":3,"count":1}]	3971	delivery	5	17
42206	2020-03-22 20:57:50	2020-03-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	16773	delivery	5	22
42207	2020-03-22 20:58:03	2020-03-22	12	[{"id_menu":3,"count":1}]	16674	pick-up	0	12
42208	2020-03-22 20:58:21	2020-03-22	9	[{"id_menu":6,"count":1}]	16710	pick-up	0	9
42209	2020-03-22 20:58:53	2020-03-22	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16654	delivery	5	48
42210	2020-03-22 21:02:12	2020-03-22	9	[{"id_menu":6,"count":1}]	16702	delivery	5	14
42211	2020-03-22 21:02:32	2020-03-22	14	[{"id_menu":2,"count":1}]	4973	delivery	5	19
42212	2020-03-22 21:02:40	2020-03-22	12	[{"id_menu":1,"count":1}]	9716	delivery	5	17
42213	2020-03-22 21:04:18	2020-03-22	9	[{"id_menu":6,"count":1}]	11296	delivery	5	14
42214	2020-03-22 21:07:33	2020-03-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	16749	delivery	5	28
42215	2020-03-22 21:12:22	2020-03-22	12	[{"id_menu":3,"count":1}]	10565	delivery	5	17
42216	2020-03-22 21:15:04	2020-03-22	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	16715	delivery	5	25
42217	2020-03-22 21:15:13	2020-03-22	9	[{"id_menu":7,"count":1}]	16281	delivery	5	14
42218	2020-03-22 21:19:15	2020-03-22	8	[{"id_menu":5,"count":1}]	16767	delivery	5	13
42219	2020-03-22 21:20:44	2020-03-22	9	[{"id_menu":6,"count":1}]	5155	delivery	5	14
42220	2020-03-22 21:20:47	2020-03-22	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	10003	delivery	5	26
42221	2020-03-22 21:21:24	2020-03-22	8	[{"id_menu":5,"count":1}]	16758	delivery	5	13
42222	2020-03-22 21:21:29	2020-03-22	9	[{"id_menu":6,"count":1}]	16728	delivery	5	14
42223	2020-03-22 21:25:13	2020-03-22	17	[{"id_menu":4,"count":1}]	5875	pick-up	0	17
42224	2020-03-22 21:25:23	2020-03-22	9	[{"id_menu":7,"count":1}]	89	pick-up	0	9
42225	2020-03-22 21:25:49	2020-03-22	14	[{"id_menu":2,"count":1}]	2498	pick-up	0	14
42226	2020-03-22 21:28:03	2020-03-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	16761	pick-up	0	23
42227	2020-03-22 21:30:23	2020-03-22	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	11495	pick-up	0	29
42228	2020-03-22 21:33:51	2020-03-22	17	[{"id_menu":4,"count":1}]	143	pick-up	0	17
42229	2020-03-22 21:34:10	2020-03-22	9	[{"id_menu":6,"count":1}]	13371	delivery	5	14
42230	2020-03-22 21:42:12	2020-03-22	12	[{"id_menu":1,"count":1}]	3523	delivery	5	17
42231	2020-03-22 21:45:41	2020-03-22	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	16652	delivery	5	26
42232	2020-03-22 21:46:38	2020-03-22	9	[{"id_menu":6,"count":1}]	2768	pick-up	0	9
42233	2020-03-22 21:46:56	2020-03-22	9	[{"id_menu":6,"count":1}]	15385	pick-up	0	9
42234	2020-03-22 21:48:11	2020-03-22	12	[{"id_menu":1,"count":1}]	584	delivery	5	17
42235	2020-03-22 21:49:29	2020-03-22	12	[{"id_menu":1,"count":1}]	6533	delivery	5	17
42236	2020-03-22 21:51:32	2020-03-22	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3961	pick-up	0	26
42237	2020-03-22 21:55:45	2020-03-22	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3647	pick-up	0	29
42238	2020-03-22 22:00:03	2020-03-22	12	[{"id_menu":1,"count":1}]	16776	delivery	5	17
42239	2020-03-22 22:05:48	2020-03-22	9	[{"id_menu":7,"count":1}]	16755	delivery	5	14
42240	2020-03-22 22:06:04	2020-03-22	12	[{"id_menu":1,"count":1}]	304	delivery	5	17
42241	2020-03-22 22:09:44	2020-03-22	17	[{"id_menu":4,"count":1}]	12791	pick-up	0	17
42242	2020-03-22 22:11:37	2020-03-22	14	[{"id_menu":2,"count":1}]	5338	pick-up	0	14
42243	2020-03-22 22:13:50	2020-03-22	39	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	16685	pick-up	0	39
42244	2020-03-22 22:14:05	2020-03-22	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7156	pick-up	0	39
42245	2020-03-22 22:14:19	2020-03-22	9	[{"id_menu":6,"count":2}]	16679	delivery	5	14
42246	2020-03-22 22:14:45	2020-03-22	12	[{"id_menu":1,"count":1}]	1568	delivery	5	17
42247	2020-03-22 22:21:25	2020-03-22	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16754	delivery	5	45
42248	2020-03-22 22:21:54	2020-03-22	8	[{"id_menu":5,"count":1}]	8600	delivery	5	13
42249	2020-03-22 22:26:00	2020-03-22	14	[{"id_menu":2,"count":1}]	16732	delivery	5	19
42250	2020-03-22 22:26:57	2020-03-22	17	[{"id_menu":4,"count":1}]	9483	pick-up	0	17
42251	2020-03-22 22:52:10	2020-03-22	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5624	delivery	5	35
42252	2020-03-22 23:05:28	2020-03-22	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	15594	pick-up	0	29
42253	2020-03-22 23:06:12	2020-03-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1681	pick-up	0	31
42254	2020-03-22 23:14:25	2020-03-22	8	[{"id_menu":5,"count":1}]	1347	pick-up	0	8
42255	2020-03-22 23:19:06	2020-03-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2556	delivery	5	28
42256	2020-03-22 23:22:59	2020-03-22	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2552	delivery	5	34
42257	2020-03-22 23:30:52	2020-03-22	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	16766	delivery	5	40
42258	2020-03-22 23:31:07	2020-03-22	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2195	pick-up	0	21
42259	2020-03-22 23:35:34	2020-03-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5324	delivery	5	23
42260	2020-03-22 23:35:52	2020-03-22	9	[{"id_menu":7,"count":1}]	4045	delivery	5	14
42261	2020-03-22 23:36:41	2020-03-22	9	[{"id_menu":6,"count":1}]	10203	pick-up	0	9
42262	2020-03-22 23:37:00	2020-03-22	8	[{"id_menu":5,"count":1}]	16681	delivery	5	13
42263	2020-03-22 23:50:48	2020-03-22	9	[{"id_menu":6,"count":1}]	11380	pick-up	0	9
42264	2020-03-22 23:51:04	2020-03-22	17	[{"id_menu":4,"count":2}]	1581	pick-up	0	17
42265	2020-03-22 23:58:43	2020-03-22	12	[{"id_menu":1,"count":1}]	16684	delivery	5	17
42266	2020-03-23 00:06:23	2020-03-23	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3364	delivery	5	34
42267	2020-03-23 00:07:17	2020-03-23	17	[{"id_menu":4,"count":1}]	2205	delivery	5	22
42268	2020-03-23 00:08:30	2020-03-23	9	[{"id_menu":6,"count":1}]	16860	delivery	5	14
42269	2020-03-23 00:15:14	2020-03-23	17	[{"id_menu":4,"count":1}]	15776	delivery	5	22
42270	2020-03-23 00:17:52	2020-03-23	8	[{"id_menu":5,"count":1}]	14962	delivery	5	13
42271	2020-03-23 00:23:23	2020-03-23	12	[{"id_menu":1,"count":1}]	16865	delivery	5	17
42272	2020-03-23 00:26:00	2020-03-23	9	[{"id_menu":6,"count":1}]	12661	delivery	5	14
42273	2020-03-23 00:26:54	2020-03-23	9	[{"id_menu":6,"count":1}]	16866	delivery	5	14
42274	2020-03-23 00:30:39	2020-03-23	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	16867	delivery	5	25
42275	2020-03-23 00:41:05	2020-03-23	14	[{"id_menu":2,"count":1}]	16806	delivery	5	19
42276	2020-03-23 00:50:03	2020-03-23	12	[{"id_menu":3,"count":1}]	16847	delivery	5	17
42277	2020-03-23 01:00:33	2020-03-23	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	16791	delivery	5	26
42278	2020-03-23 01:07:57	2020-03-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	16870	delivery	5	36
42279	2020-03-23 01:09:32	2020-03-23	17	[{"id_menu":4,"count":1}]	16810	pick-up	0	17
42280	2020-03-23 01:11:03	2020-03-23	9	[{"id_menu":7,"count":1}]	9295	delivery	5	14
42281	2020-03-23 01:11:55	2020-03-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	698	delivery	5	31
42282	2020-03-23 01:26:35	2020-03-23	17	[{"id_menu":4,"count":1}]	2333	delivery	5	22
42283	2020-03-23 01:28:57	2020-03-23	9	[{"id_menu":7,"count":1}]	8045	delivery	5	14
42284	2020-03-23 01:32:03	2020-03-23	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16798	delivery	5	34
42285	2020-03-23 01:33:44	2020-03-23	17	[{"id_menu":4,"count":1}]	6235	pick-up	0	17
42286	2020-03-23 01:36:59	2020-03-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	16803	delivery	5	31
42287	2020-03-23 01:59:58	2020-03-23	17	[{"id_menu":4,"count":1}]	16874	delivery	5	22
42288	2020-03-23 02:10:03	2020-03-23	17	[{"id_menu":4,"count":1}]	6083	delivery	5	22
42289	2020-03-23 02:13:16	2020-03-23	12	[{"id_menu":3,"count":1}]	16815	pick-up	0	12
42290	2020-03-23 02:37:00	2020-03-23	12	[{"id_menu":1,"count":1}]	110	pick-up	0	12
42291	2020-03-23 02:37:44	2020-03-23	14	[{"id_menu":2,"count":1}]	4924	delivery	5	19
42292	2020-03-23 03:05:22	2020-03-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	3918	pick-up	0	26
42293	2020-03-23 03:17:10	2020-03-23	12	[{"id_menu":1,"count":1}]	8971	delivery	5	17
42294	2020-03-23 03:17:46	2020-03-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	16834	delivery	5	26
42295	2020-03-23 03:24:52	2020-03-23	9	[{"id_menu":7,"count":2}]	16891	pick-up	0	9
42296	2020-03-23 03:41:18	2020-03-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16804	delivery	5	31
42297	2020-03-23 03:53:10	2020-03-23	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	10235	delivery	5	40
42298	2020-03-23 03:53:15	2020-03-23	9	[{"id_menu":6,"count":1}]	4737	delivery	5	14
42299	2020-03-23 03:53:50	2020-03-23	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	16871	delivery	5	31
42300	2020-03-23 03:54:48	2020-03-23	9	[{"id_menu":6,"count":1}]	13380	delivery	5	14
42301	2020-03-23 04:41:16	2020-03-23	9	[{"id_menu":6,"count":1}]	6869	pick-up	0	9
42302	2020-03-23 04:48:30	2020-03-23	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1837	delivery	5	40
42303	2020-03-23 04:51:21	2020-03-23	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	6510	delivery	5	34
42304	2020-03-23 04:52:56	2020-03-23	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	16127	pick-up	0	29
42305	2020-03-23 04:56:02	2020-03-23	17	[{"id_menu":4,"count":1}]	16820	pick-up	0	17
42306	2020-03-23 04:57:18	2020-03-23	9	[{"id_menu":6,"count":1}]	16838	delivery	5	14
42307	2020-03-23 05:01:52	2020-03-23	9	[{"id_menu":6,"count":1}]	16061	delivery	5	14
42308	2020-03-23 05:11:51	2020-03-23	9	[{"id_menu":6,"count":1}]	293	pick-up	0	9
42309	2020-03-23 05:13:39	2020-03-23	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	10930	pick-up	0	26
42310	2020-03-23 05:13:49	2020-03-23	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	16831	delivery	5	40
42311	2020-03-23 05:31:47	2020-03-23	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	950	pick-up	0	21
42312	2020-03-23 05:57:05	2020-03-23	14	[{"id_menu":2,"count":1}]	9530	delivery	5	19
42313	2020-03-23 06:01:17	2020-03-23	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	16886	delivery	5	48
42314	2020-03-23 06:02:05	2020-03-23	17	[{"id_menu":4,"count":1}]	5019	pick-up	0	17
42315	2020-03-23 06:05:27	2020-03-23	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	6701	delivery	5	26
42316	2020-03-23 06:11:38	2020-03-23	9	[{"id_menu":6,"count":2}]	16854	delivery	5	14
42317	2020-03-23 06:28:18	2020-03-23	12	[{"id_menu":1,"count":1}]	16855	delivery	5	17
42318	2020-03-23 06:35:53	2020-03-23	9	[{"id_menu":7,"count":1}]	1876	pick-up	0	9
42319	2020-03-23 06:44:00	2020-03-23	12	[{"id_menu":1,"count":1}]	2488	pick-up	0	12
42320	2020-03-23 06:48:35	2020-03-23	14	[{"id_menu":2,"count":1}]	1820	pick-up	0	14
42321	2020-03-23 06:48:55	2020-03-23	12	[{"id_menu":3,"count":1}]	7737	delivery	5	17
42322	2020-03-23 06:52:25	2020-03-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	2506	delivery	5	36
42323	2020-03-23 06:53:25	2020-03-23	14	[{"id_menu":2,"count":1}]	7217	delivery	5	19
42324	2020-03-23 06:56:05	2020-03-23	9	[{"id_menu":7,"count":1}]	9072	delivery	5	14
42325	2020-03-23 07:04:17	2020-03-23	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	5742	delivery	5	48
42326	2020-03-23 07:14:53	2020-03-23	9	[{"id_menu":6,"count":1}]	12776	delivery	5	14
42327	2020-03-23 08:06:30	2020-03-23	9	[{"id_menu":7,"count":1}]	1376	pick-up	0	9
42328	2020-03-23 08:14:25	2020-03-23	17	[{"id_menu":4,"count":1}]	3567	pick-up	0	17
42329	2020-03-23 08:22:18	2020-03-23	9	[{"id_menu":7,"count":1}]	13429	pick-up	0	9
42330	2020-03-23 08:31:33	2020-03-23	9	[{"id_menu":7,"count":1}]	3216	delivery	5	14
42331	2020-03-23 08:43:26	2020-03-23	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6155	delivery	5	40
42332	2020-03-23 08:54:42	2020-03-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2440	delivery	5	26
42333	2020-03-23 08:54:42	2020-03-23	9	[{"id_menu":6,"count":1}]	4081	pick-up	0	9
42334	2020-03-23 08:56:48	2020-03-23	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13439	delivery	5	39
42335	2020-03-23 08:58:33	2020-03-23	8	[{"id_menu":5,"count":1}]	16814	delivery	5	13
42336	2020-03-23 09:01:27	2020-03-23	9	[{"id_menu":7,"count":1}]	13180	delivery	5	14
42337	2020-03-23 09:15:54	2020-03-23	17	[{"id_menu":4,"count":1}]	16041	delivery	5	22
42338	2020-03-23 09:27:04	2020-03-23	14	[{"id_menu":2,"count":1}]	8566	pick-up	0	14
42339	2020-03-23 09:36:00	2020-03-23	9	[{"id_menu":6,"count":1}]	16850	delivery	5	14
42340	2020-03-23 09:38:15	2020-03-23	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	16802	delivery	5	26
42341	2020-03-23 09:42:56	2020-03-23	12	[{"id_menu":3,"count":1}]	8561	delivery	5	17
42342	2020-03-23 09:44:50	2020-03-23	17	[{"id_menu":4,"count":1}]	15395	pick-up	0	17
42343	2020-03-23 09:54:19	2020-03-23	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6950	pick-up	0	40
42344	2020-03-23 09:57:11	2020-03-23	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5325	delivery	5	22
42345	2020-03-23 10:05:39	2020-03-23	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16869	delivery	5	31
42346	2020-03-23 10:30:45	2020-03-23	17	[{"id_menu":5,"count":3},{"id_menu":7,"count":1}]	14216	delivery	5	22
42347	2020-03-23 10:32:59	2020-03-23	12	[{"id_menu":1,"count":1}]	6952	delivery	5	17
42348	2020-03-23 10:34:49	2020-03-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6075	delivery	5	28
42349	2020-03-23 10:38:10	2020-03-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	9859	pick-up	0	26
42350	2020-03-23 10:47:59	2020-03-23	12	[{"id_menu":3,"count":1}]	3271	delivery	5	17
42351	2020-03-23 11:02:56	2020-03-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	14559	pick-up	0	23
42352	2020-03-23 11:04:39	2020-03-23	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16863	delivery	5	43
42353	2020-03-23 11:04:51	2020-03-23	17	[{"id_menu":4,"count":1}]	11262	pick-up	0	17
42354	2020-03-23 11:12:23	2020-03-23	9	[{"id_menu":7,"count":1}]	10819	delivery	5	14
42355	2020-03-23 11:16:27	2020-03-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	379	delivery	5	22
42356	2020-03-23 11:25:20	2020-03-23	12	[{"id_menu":1,"count":1}]	3703	delivery	5	17
42357	2020-03-23 11:26:55	2020-03-23	12	[{"id_menu":3,"count":1}]	4629	pick-up	0	12
42358	2020-03-23 11:35:57	2020-03-23	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11964	delivery	5	34
42359	2020-03-23 11:42:25	2020-03-23	9	[{"id_menu":6,"count":1}]	15284	delivery	5	14
42360	2020-03-23 11:54:44	2020-03-23	43	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	5930	delivery	5	48
42361	2020-03-23 12:08:07	2020-03-23	17	[{"id_menu":4,"count":1}]	12205	pick-up	0	17
42362	2020-03-23 12:08:55	2020-03-23	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16528	delivery	5	22
42363	2020-03-23 12:15:47	2020-03-23	8	[{"id_menu":5,"count":1}]	15470	delivery	5	13
42364	2020-03-23 12:27:21	2020-03-23	14	[{"id_menu":2,"count":1}]	6090	delivery	5	19
42365	2020-03-23 12:31:10	2020-03-23	9	[{"id_menu":7,"count":1}]	16890	delivery	5	14
42366	2020-03-23 12:31:51	2020-03-23	8	[{"id_menu":5,"count":1}]	5648	pick-up	0	8
42367	2020-03-23 12:32:43	2020-03-23	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11864	delivery	5	22
42368	2020-03-23 12:35:35	2020-03-23	8	[{"id_menu":5,"count":2}]	12912	pick-up	0	8
42369	2020-03-23 12:39:32	2020-03-23	8	[{"id_menu":5,"count":1}]	6678	delivery	5	13
42370	2020-03-23 12:39:47	2020-03-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	11000	delivery	5	28
42371	2020-03-23 12:40:34	2020-03-23	9	[{"id_menu":6,"count":1}]	12316	delivery	5	14
42372	2020-03-23 12:41:11	2020-03-23	14	[{"id_menu":2,"count":1}]	766	pick-up	0	14
42373	2020-03-23 13:08:31	2020-03-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	11395	pick-up	0	23
42374	2020-03-23 13:15:54	2020-03-23	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	16665	delivery	5	35
42375	2020-03-23 13:17:33	2020-03-23	14	[{"id_menu":2,"count":1}]	6113	delivery	5	19
42376	2020-03-23 13:30:24	2020-03-23	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	480	delivery	5	23
42377	2020-03-23 13:31:37	2020-03-23	14	[{"id_menu":2,"count":1}]	3961	pick-up	0	14
42378	2020-03-23 13:34:27	2020-03-23	17	[{"id_menu":4,"count":1}]	16792	delivery	5	22
42379	2020-03-23 13:54:29	2020-03-23	12	[{"id_menu":1,"count":1}]	15501	delivery	5	17
42380	2020-03-23 14:11:57	2020-03-23	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16832	delivery	5	22
42381	2020-03-23 14:13:40	2020-03-23	17	[{"id_menu":4,"count":1}]	7280	delivery	5	22
42382	2020-03-23 14:25:58	2020-03-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	16898	delivery	5	28
42383	2020-03-23 14:30:42	2020-03-23	12	[{"id_menu":3,"count":1}]	5050	pick-up	0	12
42384	2020-03-23 14:33:45	2020-03-23	14	[{"id_menu":2,"count":1}]	12290	delivery	5	19
42385	2020-03-23 14:51:16	2020-03-23	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	271	delivery	5	26
42386	2020-03-23 14:54:59	2020-03-23	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	10011	delivery	5	23
42387	2020-03-23 15:02:01	2020-03-23	9	[{"id_menu":7,"count":1}]	16839	delivery	5	14
42388	2020-03-23 15:02:09	2020-03-23	9	[{"id_menu":7,"count":1}]	16795	delivery	5	14
42389	2020-03-23 15:05:53	2020-03-23	8	[{"id_menu":5,"count":1}]	2731	delivery	5	13
42390	2020-03-23 15:09:37	2020-03-23	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	16877	delivery	5	31
42391	2020-03-23 15:13:33	2020-03-23	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16805	delivery	5	22
42392	2020-03-23 15:21:12	2020-03-23	12	[{"id_menu":3,"count":1}]	5303	pick-up	0	12
42393	2020-03-23 15:25:05	2020-03-23	17	[{"id_menu":4,"count":1}]	3529	pick-up	0	17
42394	2020-03-23 15:31:17	2020-03-23	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	496	delivery	5	25
42395	2020-03-23 15:33:03	2020-03-23	14	[{"id_menu":2,"count":1}]	16853	pick-up	0	14
42396	2020-03-23 15:33:48	2020-03-23	17	[{"id_menu":4,"count":1}]	2498	delivery	5	22
42397	2020-03-23 15:34:50	2020-03-23	9	[{"id_menu":6,"count":1}]	6565	pick-up	0	9
42398	2020-03-23 15:42:03	2020-03-23	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	16873	delivery	5	39
42399	2020-03-23 15:48:25	2020-03-23	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	11887	pick-up	0	32
42400	2020-03-23 15:49:09	2020-03-23	9	[{"id_menu":7,"count":1}]	16800	delivery	5	14
42401	2020-03-23 15:57:06	2020-03-23	17	[{"id_menu":4,"count":1}]	16809	delivery	5	22
42402	2020-03-23 16:05:41	2020-03-23	12	[{"id_menu":3,"count":1}]	5035	pick-up	0	12
42403	2020-03-23 16:09:46	2020-03-23	9	[{"id_menu":7,"count":1}]	16878	delivery	5	14
42404	2020-03-23 16:17:36	2020-03-23	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	15159	delivery	5	40
42405	2020-03-23 16:28:42	2020-03-23	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2227	pick-up	0	32
42406	2020-03-23 16:51:31	2020-03-23	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":2}]	4150	delivery	5	22
42407	2020-03-23 16:54:58	2020-03-23	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	9170	delivery	5	31
42408	2020-03-23 16:56:30	2020-03-23	12	[{"id_menu":3,"count":1}]	16753	pick-up	0	12
42409	2020-03-23 17:06:50	2020-03-23	12	[{"id_menu":1,"count":1}]	16833	delivery	5	17
42410	2020-03-23 17:09:06	2020-03-23	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	3125	delivery	5	39
42411	2020-03-23 17:09:25	2020-03-23	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1895	pick-up	0	21
42412	2020-03-23 17:19:32	2020-03-23	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	14775	delivery	5	23
42413	2020-03-23 17:21:10	2020-03-23	8	[{"id_menu":5,"count":1}]	1241	pick-up	0	8
42414	2020-03-23 17:22:05	2020-03-23	14	[{"id_menu":2,"count":1}]	16859	delivery	5	19
42415	2020-03-23 17:23:31	2020-03-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8340	delivery	5	31
42416	2020-03-23 17:29:09	2020-03-23	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	9251	delivery	5	37
42417	2020-03-23 17:36:49	2020-03-23	17	[{"id_menu":4,"count":1}]	14997	delivery	5	22
42418	2020-03-23 17:43:21	2020-03-23	12	[{"id_menu":1,"count":1}]	16875	delivery	5	17
42419	2020-03-23 17:44:18	2020-03-23	12	[{"id_menu":1,"count":2}]	13548	pick-up	0	12
42420	2020-03-23 17:45:43	2020-03-23	8	[{"id_menu":5,"count":1}]	16856	delivery	5	13
42421	2020-03-23 17:49:40	2020-03-23	8	[{"id_menu":5,"count":1}]	7604	delivery	5	13
42422	2020-03-23 17:53:48	2020-03-23	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	16818	delivery	5	28
42423	2020-03-23 18:09:42	2020-03-23	17	[{"id_menu":4,"count":1}]	2951	delivery	5	22
42424	2020-03-23 18:36:16	2020-03-23	12	[{"id_menu":3,"count":1}]	15140	delivery	5	17
42425	2020-03-23 19:02:21	2020-03-23	8	[{"id_menu":5,"count":1}]	16862	delivery	5	13
42426	2020-03-23 19:07:53	2020-03-23	9	[{"id_menu":6,"count":1}]	16885	delivery	5	14
42427	2020-03-23 19:09:13	2020-03-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1614	delivery	5	31
42428	2020-03-23 19:09:27	2020-03-23	9	[{"id_menu":7,"count":1}]	9256	pick-up	0	9
42429	2020-03-23 19:18:38	2020-03-23	8	[{"id_menu":5,"count":1}]	16897	delivery	5	13
42430	2020-03-23 19:19:55	2020-03-23	14	[{"id_menu":2,"count":1}]	16844	pick-up	0	14
42431	2020-03-23 19:27:30	2020-03-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	12204	delivery	5	26
42432	2020-03-23 19:41:44	2020-03-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	16811	delivery	5	36
42433	2020-03-23 19:43:57	2020-03-23	9	[{"id_menu":6,"count":1}]	9769	delivery	5	14
42434	2020-03-23 19:45:45	2020-03-23	8	[{"id_menu":5,"count":1}]	2662	pick-up	0	8
42435	2020-03-23 19:52:23	2020-03-23	14	[{"id_menu":2,"count":1}]	3044	delivery	5	19
42436	2020-03-23 20:00:29	2020-03-23	8	[{"id_menu":5,"count":1}]	2933	pick-up	0	8
42437	2020-03-23 20:07:08	2020-03-23	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	8123	delivery	5	26
42438	2020-03-23 20:08:58	2020-03-23	9	[{"id_menu":7,"count":1}]	12490	delivery	5	14
42439	2020-03-23 20:09:51	2020-03-23	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	16887	delivery	5	29
42440	2020-03-23 20:28:34	2020-03-23	8	[{"id_menu":5,"count":1}]	8782	delivery	5	13
42441	2020-03-23 20:33:49	2020-03-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	3304	pick-up	0	21
42442	2020-03-23 20:42:24	2020-03-23	9	[{"id_menu":7,"count":1}]	3915	pick-up	0	9
42443	2020-03-23 20:51:06	2020-03-23	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8852	delivery	5	40
42444	2020-03-23 20:51:33	2020-03-23	14	[{"id_menu":2,"count":1}]	16797	delivery	5	19
42445	2020-03-23 20:59:30	2020-03-23	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	10033	delivery	5	39
42446	2020-03-23 21:00:25	2020-03-23	12	[{"id_menu":3,"count":1}]	143	delivery	5	17
42447	2020-03-23 21:21:50	2020-03-23	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2339	pick-up	0	31
42448	2020-03-23 21:37:17	2020-03-23	9	[{"id_menu":7,"count":1}]	7341	delivery	5	14
42449	2020-03-23 21:39:37	2020-03-23	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	16823	delivery	5	22
42450	2020-03-23 22:08:41	2020-03-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13723	delivery	5	23
42451	2020-03-23 22:16:57	2020-03-23	9	[{"id_menu":7,"count":2}]	16846	delivery	5	14
42452	2020-03-23 22:18:41	2020-03-23	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16876	delivery	5	45
42453	2020-03-23 22:19:57	2020-03-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	11591	delivery	5	28
42454	2020-03-23 22:24:14	2020-03-23	12	[{"id_menu":1,"count":1}]	1273	delivery	5	17
42455	2020-03-23 22:30:53	2020-03-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16842	delivery	5	22
42456	2020-03-23 22:37:12	2020-03-23	9	[{"id_menu":6,"count":1}]	16880	delivery	5	14
42457	2020-03-23 22:42:03	2020-03-23	8	[{"id_menu":5,"count":1}]	16868	delivery	5	13
42458	2020-03-23 22:53:02	2020-03-23	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4710	pick-up	0	30
42459	2020-03-23 22:53:09	2020-03-23	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	16794	pick-up	0	40
42460	2020-03-23 22:55:56	2020-03-23	17	[{"id_menu":4,"count":1}]	16857	delivery	5	22
42461	2020-03-23 23:03:06	2020-03-23	12	[{"id_menu":3,"count":1}]	3155	pick-up	0	12
42462	2020-03-23 23:11:49	2020-03-23	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	3558	delivery	5	22
42463	2020-03-23 23:17:03	2020-03-23	12	[{"id_menu":1,"count":1}]	1460	pick-up	0	12
42464	2020-03-23 23:19:32	2020-03-23	9	[{"id_menu":6,"count":1}]	15337	delivery	5	14
42465	2020-03-23 23:20:31	2020-03-23	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	8656	pick-up	0	21
42466	2020-03-23 23:20:38	2020-03-23	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3618	delivery	5	22
42467	2020-03-23 23:21:30	2020-03-23	8	[{"id_menu":5,"count":1}]	6516	pick-up	0	8
42468	2020-03-23 23:26:31	2020-03-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	16799	delivery	5	31
42469	2020-03-23 23:31:29	2020-03-23	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	16894	delivery	5	38
42470	2020-03-23 23:32:55	2020-03-23	14	[{"id_menu":2,"count":2}]	16849	delivery	5	19
42471	2020-03-23 23:49:04	2020-03-23	12	[{"id_menu":3,"count":1}]	12183	pick-up	0	12
42472	2020-03-23 23:51:18	2020-03-23	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8291	delivery	5	51
42473	2020-03-23 23:53:03	2020-03-23	9	[{"id_menu":7,"count":1}]	12547	delivery	5	14
42474	2020-03-23 23:53:50	2020-03-23	8	[{"id_menu":5,"count":1}]	13502	delivery	5	13
42475	2020-03-23 23:56:06	2020-03-23	9	[{"id_menu":6,"count":1}]	381	pick-up	0	9
42476	2020-03-23 23:56:33	2020-03-23	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	8043	delivery	5	26
42477	2020-03-23 23:59:08	2020-03-23	9	[{"id_menu":6,"count":1}]	439	pick-up	0	9
42478	2020-03-24 00:03:02	2020-03-24	9	[{"id_menu":6,"count":1}]	16950	delivery	5	14
42479	2020-03-24 00:14:15	2020-03-24	12	[{"id_menu":3,"count":1}]	2116	pick-up	0	12
42480	2020-03-24 00:16:03	2020-03-24	14	[{"id_menu":2,"count":1}]	16910	pick-up	0	14
42481	2020-03-24 00:23:42	2020-03-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	14134	delivery	5	28
42482	2020-03-24 00:24:18	2020-03-24	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16965	delivery	5	35
42483	2020-03-24 00:26:20	2020-03-24	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8081	delivery	5	22
42484	2020-03-24 00:28:00	2020-03-24	12	[{"id_menu":1,"count":1}]	16986	delivery	5	17
42485	2020-03-24 00:28:34	2020-03-24	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	16944	pick-up	0	23
42486	2020-03-24 00:28:36	2020-03-24	12	[{"id_menu":3,"count":1}]	16908	delivery	5	17
42487	2020-03-24 00:31:28	2020-03-24	8	[{"id_menu":5,"count":1}]	5189	pick-up	0	8
42488	2020-03-24 00:35:39	2020-03-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16929	delivery	5	31
42489	2020-03-24 00:37:54	2020-03-24	14	[{"id_menu":2,"count":1}]	16919	delivery	5	19
42490	2020-03-24 00:38:03	2020-03-24	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4629	pick-up	0	26
42491	2020-03-24 00:38:43	2020-03-24	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16928	delivery	5	39
42492	2020-03-24 00:42:35	2020-03-24	14	[{"id_menu":2,"count":1}]	5783	pick-up	0	14
42493	2020-03-24 00:47:43	2020-03-24	9	[{"id_menu":7,"count":1}]	16979	pick-up	0	9
42494	2020-03-24 00:59:42	2020-03-24	12	[{"id_menu":3,"count":1}]	11634	pick-up	0	12
42495	2020-03-24 01:00:50	2020-03-24	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	16938	pick-up	0	26
42496	2020-03-24 01:02:50	2020-03-24	9	[{"id_menu":7,"count":1}]	17013	delivery	5	14
42497	2020-03-24 01:05:38	2020-03-24	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	599	delivery	5	22
42498	2020-03-24 01:07:50	2020-03-24	9	[{"id_menu":7,"count":1}]	8642	delivery	5	14
42499	2020-03-24 01:08:14	2020-03-24	17	[{"id_menu":4,"count":1}]	16985	delivery	5	22
42500	2020-03-24 01:15:54	2020-03-24	9	[{"id_menu":7,"count":1}]	14488	delivery	5	14
42501	2020-03-24 01:30:32	2020-03-24	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	17026	delivery	5	31
42502	2020-03-24 01:32:44	2020-03-24	9	[{"id_menu":7,"count":1}]	9535	delivery	5	14
42503	2020-03-24 01:37:35	2020-03-24	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16913	delivery	5	52
42504	2020-03-24 01:37:56	2020-03-24	14	[{"id_menu":2,"count":1}]	7156	pick-up	0	14
42505	2020-03-24 01:40:25	2020-03-24	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	7668	delivery	5	26
42506	2020-03-24 01:47:02	2020-03-24	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13746	delivery	5	49
42507	2020-03-24 01:49:54	2020-03-24	9	[{"id_menu":7,"count":1}]	13568	delivery	5	14
42508	2020-03-24 01:53:28	2020-03-24	17	[{"id_menu":4,"count":1}]	6399	pick-up	0	17
42509	2020-03-24 01:55:46	2020-03-24	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	15143	delivery	5	26
42510	2020-03-24 02:04:33	2020-03-24	17	[{"id_menu":4,"count":1}]	10551	pick-up	0	17
42511	2020-03-24 02:15:23	2020-03-24	14	[{"id_menu":2,"count":1}]	16963	delivery	5	19
42512	2020-03-24 02:36:56	2020-03-24	17	[{"id_menu":4,"count":1}]	16973	delivery	5	22
42513	2020-03-24 02:38:24	2020-03-24	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16976	delivery	5	31
42514	2020-03-24 02:45:04	2020-03-24	17	[{"id_menu":4,"count":1}]	1568	pick-up	0	17
42515	2020-03-24 02:45:57	2020-03-24	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	749	pick-up	0	26
42516	2020-03-24 02:50:39	2020-03-24	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	17017	delivery	5	40
42517	2020-03-24 02:52:48	2020-03-24	9	[{"id_menu":7,"count":1}]	16958	delivery	5	14
42518	2020-03-24 03:08:27	2020-03-24	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	3820	delivery	5	43
42519	2020-03-24 03:09:59	2020-03-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16968	delivery	5	22
42520	2020-03-24 03:14:36	2020-03-24	14	[{"id_menu":2,"count":1}]	7931	pick-up	0	14
42521	2020-03-24 03:30:11	2020-03-24	12	[{"id_menu":3,"count":1}]	16990	delivery	5	17
42522	2020-03-24 03:33:39	2020-03-24	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15026	delivery	5	39
42523	2020-03-24 03:44:18	2020-03-24	12	[{"id_menu":1,"count":2}]	13841	pick-up	0	12
42524	2020-03-24 03:49:04	2020-03-24	8	[{"id_menu":5,"count":1}]	8656	pick-up	0	8
42525	2020-03-24 03:50:17	2020-03-24	9	[{"id_menu":6,"count":2}]	10300	delivery	5	14
42526	2020-03-24 03:50:19	2020-03-24	9	[{"id_menu":6,"count":1}]	14380	delivery	5	14
42527	2020-03-24 04:00:34	2020-03-24	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	1470	delivery	5	36
42528	2020-03-24 04:03:16	2020-03-24	9	[{"id_menu":6,"count":1}]	16926	pick-up	0	9
42529	2020-03-24 04:09:49	2020-03-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9151	delivery	5	22
42530	2020-03-24 04:11:37	2020-03-24	12	[{"id_menu":3,"count":1}]	531	delivery	5	17
42531	2020-03-24 04:12:36	2020-03-24	17	[{"id_menu":4,"count":1}]	3349	delivery	5	22
42532	2020-03-24 04:29:33	2020-03-24	9	[{"id_menu":7,"count":1}]	9621	delivery	5	14
42533	2020-03-24 04:32:09	2020-03-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	17025	delivery	5	28
42534	2020-03-24 04:37:02	2020-03-24	14	[{"id_menu":2,"count":1}]	16902	delivery	5	19
42535	2020-03-24 04:49:18	2020-03-24	9	[{"id_menu":7,"count":1}]	11952	delivery	5	14
42536	2020-03-24 04:49:59	2020-03-24	17	[{"id_menu":4,"count":1}]	9001	delivery	5	22
42537	2020-03-24 04:50:35	2020-03-24	9	[{"id_menu":6,"count":1}]	9014	delivery	5	14
42538	2020-03-24 05:03:58	2020-03-24	17	[{"id_menu":4,"count":1}]	15400	pick-up	0	17
42539	2020-03-24 05:04:23	2020-03-24	12	[{"id_menu":3,"count":1}]	6589	pick-up	0	12
42540	2020-03-24 05:05:12	2020-03-24	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1293	delivery	5	35
42541	2020-03-24 05:05:51	2020-03-24	12	[{"id_menu":3,"count":1}]	2384	pick-up	0	12
42542	2020-03-24 05:07:52	2020-03-24	9	[{"id_menu":7,"count":1}]	16937	delivery	5	14
42543	2020-03-24 05:09:58	2020-03-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12183	pick-up	0	17
42544	2020-03-24 05:10:08	2020-03-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9531	pick-up	0	23
42545	2020-03-24 05:19:38	2020-03-24	12	[{"id_menu":3,"count":1}]	11614	delivery	5	17
42546	2020-03-24 05:20:06	2020-03-24	8	[{"id_menu":5,"count":1}]	14829	delivery	5	13
42547	2020-03-24 05:21:02	2020-03-24	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	11208	delivery	5	26
42548	2020-03-24 05:23:25	2020-03-24	9	[{"id_menu":7,"count":1}]	16768	delivery	5	14
42549	2020-03-24 05:24:02	2020-03-24	9	[{"id_menu":7,"count":1}]	16931	delivery	5	14
42550	2020-03-24 05:24:03	2020-03-24	17	[{"id_menu":4,"count":1}]	1322	pick-up	0	17
42551	2020-03-24 05:27:38	2020-03-24	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	12827	delivery	5	26
42552	2020-03-24 05:29:32	2020-03-24	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	10464	delivery	5	38
42553	2020-03-24 05:36:59	2020-03-24	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16974	delivery	5	40
42554	2020-03-24 05:37:03	2020-03-24	12	[{"id_menu":1,"count":1}]	10187	pick-up	0	12
42555	2020-03-24 05:44:10	2020-03-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1453	delivery	5	22
42556	2020-03-24 05:50:02	2020-03-24	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4342	pick-up	0	31
42557	2020-03-24 05:55:42	2020-03-24	9	[{"id_menu":7,"count":1}]	17014	delivery	5	14
42558	2020-03-24 05:57:05	2020-03-24	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	11878	delivery	5	30
42559	2020-03-24 05:58:49	2020-03-24	9	[{"id_menu":7,"count":1}]	6182	pick-up	0	9
42560	2020-03-24 06:08:58	2020-03-24	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	4677	delivery	5	22
42561	2020-03-24 06:13:26	2020-03-24	8	[{"id_menu":5,"count":1}]	4290	delivery	5	13
42562	2020-03-24 06:22:37	2020-03-24	17	[{"id_menu":4,"count":1}]	14897	delivery	5	22
42563	2020-03-24 06:40:01	2020-03-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	10244	delivery	5	28
42564	2020-03-24 06:44:11	2020-03-24	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17012	delivery	5	35
42565	2020-03-24 06:51:15	2020-03-24	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17018	delivery	5	39
42566	2020-03-24 06:51:50	2020-03-24	9	[{"id_menu":6,"count":1}]	6742	delivery	5	14
42567	2020-03-24 07:04:54	2020-03-24	17	[{"id_menu":4,"count":2}]	1729	pick-up	0	17
42568	2020-03-24 07:06:38	2020-03-24	17	[{"id_menu":4,"count":1}]	5354	delivery	5	22
42569	2020-03-24 07:21:47	2020-03-24	9	[{"id_menu":7,"count":1}]	12541	pick-up	0	9
42570	2020-03-24 07:37:13	2020-03-24	9	[{"id_menu":7,"count":1}]	16997	delivery	5	14
42571	2020-03-24 07:37:42	2020-03-24	12	[{"id_menu":1,"count":1}]	16934	delivery	5	17
42572	2020-03-24 07:40:37	2020-03-24	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16271	delivery	5	31
42573	2020-03-24 07:41:16	2020-03-24	17	[{"id_menu":4,"count":1}]	16813	pick-up	0	17
42574	2020-03-24 07:41:29	2020-03-24	9	[{"id_menu":7,"count":1}]	5904	delivery	5	14
42575	2020-03-24 07:46:22	2020-03-24	9	[{"id_menu":6,"count":1}]	16953	delivery	5	14
42576	2020-03-24 07:55:39	2020-03-24	8	[{"id_menu":5,"count":2}]	16841	pick-up	0	8
42577	2020-03-24 08:09:41	2020-03-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	16945	delivery	5	31
42578	2020-03-24 08:13:49	2020-03-24	14	[{"id_menu":2,"count":1}]	16978	delivery	5	19
42579	2020-03-24 08:14:18	2020-03-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	16903	delivery	5	28
42580	2020-03-24 08:17:12	2020-03-24	14	[{"id_menu":2,"count":1}]	2062	pick-up	0	14
42581	2020-03-24 08:22:42	2020-03-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	16993	delivery	5	28
42582	2020-03-24 08:23:50	2020-03-24	12	[{"id_menu":3,"count":1}]	15385	pick-up	0	12
42583	2020-03-24 08:49:55	2020-03-24	9	[{"id_menu":7,"count":1}]	17022	delivery	5	14
42584	2020-03-24 08:50:25	2020-03-24	17	[{"id_menu":4,"count":2}]	6877	delivery	5	22
42585	2020-03-24 08:55:19	2020-03-24	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16962	delivery	5	40
42586	2020-03-24 08:55:50	2020-03-24	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	28	pick-up	0	21
42587	2020-03-24 08:58:27	2020-03-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	675	delivery	5	31
42588	2020-03-24 09:00:01	2020-03-24	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":3}]	10091	delivery	5	22
42589	2020-03-24 09:00:18	2020-03-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	992	delivery	5	23
42590	2020-03-24 09:03:14	2020-03-24	17	[{"id_menu":4,"count":1}]	16925	delivery	5	22
42591	2020-03-24 09:07:21	2020-03-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6738	delivery	5	28
42592	2020-03-24 09:14:18	2020-03-24	9	[{"id_menu":7,"count":1}]	17016	delivery	5	14
42593	2020-03-24 09:20:12	2020-03-24	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	8194	delivery	5	22
42594	2020-03-24 09:21:49	2020-03-24	17	[{"id_menu":4,"count":1}]	2477	pick-up	0	17
42595	2020-03-24 09:24:24	2020-03-24	17	[{"id_menu":4,"count":1}]	13426	delivery	5	22
42596	2020-03-24 09:26:02	2020-03-24	9	[{"id_menu":6,"count":1}]	16948	delivery	5	14
42597	2020-03-24 09:26:29	2020-03-24	14	[{"id_menu":2,"count":1}]	5951	delivery	5	19
42598	2020-03-24 09:27:24	2020-03-24	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	12274	pick-up	0	26
42599	2020-03-24 09:46:11	2020-03-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	16921	delivery	5	28
42600	2020-03-24 09:46:52	2020-03-24	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":2}]	16922	delivery	5	26
42601	2020-03-24 09:49:03	2020-03-24	9	[{"id_menu":6,"count":1}]	16941	delivery	5	14
42602	2020-03-24 09:53:59	2020-03-24	9	[{"id_menu":7,"count":1}]	3212	delivery	5	14
42603	2020-03-24 09:59:26	2020-03-24	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	3656	delivery	5	26
42604	2020-03-24 10:01:45	2020-03-24	9	[{"id_menu":7,"count":1}]	2932	pick-up	0	9
42605	2020-03-24 10:08:23	2020-03-24	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2339	pick-up	0	21
42606	2020-03-24 10:27:20	2020-03-24	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	270	pick-up	0	20
42607	2020-03-24 10:29:46	2020-03-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1924	pick-up	0	18
42608	2020-03-24 10:31:59	2020-03-24	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":2}]	8880	delivery	5	26
42609	2020-03-24 10:36:23	2020-03-24	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	424	pick-up	0	21
42610	2020-03-24 10:36:30	2020-03-24	17	[{"id_menu":4,"count":1}]	15635	delivery	5	22
42611	2020-03-24 10:38:51	2020-03-24	8	[{"id_menu":5,"count":1}]	12184	pick-up	0	8
42612	2020-03-24 10:41:25	2020-03-24	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	11028	pick-up	0	21
42613	2020-03-24 10:41:32	2020-03-24	9	[{"id_menu":7,"count":1}]	14485	pick-up	0	9
42614	2020-03-24 10:42:52	2020-03-24	14	[{"id_menu":2,"count":1}]	5303	delivery	5	19
42615	2020-03-24 10:44:44	2020-03-24	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	524	pick-up	0	35
42616	2020-03-24 10:45:43	2020-03-24	14	[{"id_menu":2,"count":1}]	10257	delivery	5	19
42617	2020-03-24 10:48:53	2020-03-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	10867	delivery	5	28
42618	2020-03-24 10:55:31	2020-03-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13743	delivery	5	31
42619	2020-03-24 11:01:03	2020-03-24	9	[{"id_menu":6,"count":1}]	15281	delivery	5	14
42620	2020-03-24 11:03:30	2020-03-24	9	[{"id_menu":6,"count":1}]	11901	delivery	5	14
42621	2020-03-24 11:03:39	2020-03-24	12	[{"id_menu":1,"count":1}]	2415	pick-up	0	12
42622	2020-03-24 11:27:41	2020-03-24	12	[{"id_menu":3,"count":1}]	6173	pick-up	0	12
42623	2020-03-24 11:31:44	2020-03-24	9	[{"id_menu":6,"count":1}]	16957	pick-up	0	9
42624	2020-03-24 11:32:36	2020-03-24	9	[{"id_menu":6,"count":1}]	15990	delivery	5	14
42625	2020-03-24 11:32:42	2020-03-24	9	[{"id_menu":7,"count":1}]	13758	delivery	5	14
42626	2020-03-24 11:34:07	2020-03-24	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15725	delivery	5	31
42627	2020-03-24 11:35:00	2020-03-24	8	[{"id_menu":5,"count":1}]	9675	delivery	5	13
42628	2020-03-24 11:40:44	2020-03-24	12	[{"id_menu":3,"count":1}]	16966	delivery	5	17
42629	2020-03-24 11:58:53	2020-03-24	9	[{"id_menu":6,"count":1}]	5958	pick-up	0	9
42630	2020-03-24 12:00:39	2020-03-24	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	16936	delivery	5	25
42631	2020-03-24 12:02:30	2020-03-24	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	13042	delivery	5	31
42632	2020-03-24 12:04:42	2020-03-24	17	[{"id_menu":4,"count":1}]	3995	pick-up	0	17
42633	2020-03-24 12:07:46	2020-03-24	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	16994	delivery	5	31
42634	2020-03-24 12:13:53	2020-03-24	12	[{"id_menu":1,"count":1}]	16988	delivery	5	17
42635	2020-03-24 12:22:53	2020-03-24	17	[{"id_menu":4,"count":1}]	16980	delivery	5	22
42636	2020-03-24 12:35:19	2020-03-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1045	pick-up	0	23
42637	2020-03-24 12:38:04	2020-03-24	9	[{"id_menu":6,"count":1}]	17000	delivery	5	14
42638	2020-03-24 12:43:36	2020-03-24	9	[{"id_menu":7,"count":1}]	2197	pick-up	0	9
42639	2020-03-24 12:44:34	2020-03-24	14	[{"id_menu":2,"count":1}]	10802	delivery	5	19
42640	2020-03-24 12:45:44	2020-03-24	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	14205	delivery	5	38
42641	2020-03-24 12:47:49	2020-03-24	9	[{"id_menu":7,"count":1}]	13105	delivery	5	14
42642	2020-03-24 12:48:46	2020-03-24	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	17028	delivery	5	35
42643	2020-03-24 12:49:35	2020-03-24	12	[{"id_menu":3,"count":1}]	29	delivery	5	17
42644	2020-03-24 12:57:06	2020-03-24	12	[{"id_menu":1,"count":1}]	4062	pick-up	0	12
42645	2020-03-24 12:59:41	2020-03-24	14	[{"id_menu":2,"count":1}]	3230	delivery	5	19
42646	2020-03-24 13:04:13	2020-03-24	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	7565	pick-up	0	26
42647	2020-03-24 13:05:04	2020-03-24	8	[{"id_menu":5,"count":1}]	16943	delivery	5	13
42648	2020-03-24 13:26:17	2020-03-24	9	[{"id_menu":7,"count":2}]	3794	delivery	5	14
42649	2020-03-24 13:33:18	2020-03-24	17	[{"id_menu":4,"count":1}]	5311	delivery	5	22
42650	2020-03-24 13:36:25	2020-03-24	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	3858	pick-up	0	29
42651	2020-03-24 13:45:57	2020-03-24	9	[{"id_menu":7,"count":1}]	12231	delivery	5	14
42652	2020-03-24 13:46:44	2020-03-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12725	delivery	5	31
42653	2020-03-24 13:49:25	2020-03-24	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	17009	delivery	5	25
42654	2020-03-24 14:00:20	2020-03-24	9	[{"id_menu":6,"count":1}]	16930	delivery	5	14
42655	2020-03-24 14:00:36	2020-03-24	9	[{"id_menu":6,"count":1}]	12517	delivery	5	14
42656	2020-03-24 14:04:31	2020-03-24	14	[{"id_menu":2,"count":1}]	17010	pick-up	0	14
42657	2020-03-24 14:04:52	2020-03-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16911	delivery	5	23
42658	2020-03-24 14:05:14	2020-03-24	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3709	pick-up	0	26
42659	2020-03-24 14:08:45	2020-03-24	8	[{"id_menu":5,"count":1}]	78	pick-up	0	8
42660	2020-03-24 14:13:53	2020-03-24	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17001	delivery	5	52
42661	2020-03-24 14:21:47	2020-03-24	14	[{"id_menu":2,"count":1}]	15757	delivery	5	19
42662	2020-03-24 14:23:15	2020-03-24	14	[{"id_menu":2,"count":1}]	9112	pick-up	0	14
42663	2020-03-24 14:29:03	2020-03-24	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12841	delivery	5	35
42664	2020-03-24 14:31:25	2020-03-24	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16989	delivery	5	43
42665	2020-03-24 14:33:49	2020-03-24	17	[{"id_menu":4,"count":1}]	9358	pick-up	0	17
42666	2020-03-24 14:45:55	2020-03-24	17	[{"id_menu":4,"count":1}]	643	pick-up	0	17
42667	2020-03-24 14:46:16	2020-03-24	9	[{"id_menu":6,"count":1}]	1273	pick-up	0	9
42668	2020-03-24 14:51:41	2020-03-24	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	14823	pick-up	0	39
42669	2020-03-24 14:58:09	2020-03-24	12	[{"id_menu":1,"count":1}]	6609	pick-up	0	12
42670	2020-03-24 15:08:14	2020-03-24	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9870	delivery	5	45
42671	2020-03-24 15:18:58	2020-03-24	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5158	delivery	5	39
42672	2020-03-24 15:20:35	2020-03-24	12	[{"id_menu":3,"count":1}]	16952	delivery	5	17
42673	2020-03-24 15:32:53	2020-03-24	8	[{"id_menu":5,"count":1}]	12678	delivery	5	13
42674	2020-03-24 15:40:58	2020-03-24	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	13197	pick-up	0	31
42675	2020-03-24 15:46:50	2020-03-24	9	[{"id_menu":6,"count":1}]	9277	delivery	5	14
42676	2020-03-24 15:51:16	2020-03-24	17	[{"id_menu":4,"count":1}]	7710	delivery	5	22
42677	2020-03-24 15:57:21	2020-03-24	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1633	delivery	5	43
42678	2020-03-24 15:59:45	2020-03-24	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1588	delivery	5	22
42679	2020-03-24 16:15:27	2020-03-24	12	[{"id_menu":3,"count":1}]	17005	delivery	5	17
42680	2020-03-24 16:16:34	2020-03-24	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	16996	pick-up	0	22
42681	2020-03-24 16:26:00	2020-03-24	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16942	delivery	5	35
42682	2020-03-24 16:29:07	2020-03-24	17	[{"id_menu":4,"count":1}]	17021	delivery	5	22
42683	2020-03-24 16:30:39	2020-03-24	12	[{"id_menu":1,"count":1}]	4526	pick-up	0	12
42684	2020-03-24 16:32:31	2020-03-24	8	[{"id_menu":5,"count":2}]	10589	pick-up	0	8
42685	2020-03-24 16:34:10	2020-03-24	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	13528	pick-up	0	22
42686	2020-03-24 16:39:59	2020-03-24	12	[{"id_menu":1,"count":1}]	5338	pick-up	0	12
42687	2020-03-24 16:47:48	2020-03-24	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7014	delivery	5	36
42688	2020-03-24 16:54:26	2020-03-24	9	[{"id_menu":6,"count":1}]	16977	delivery	5	14
42689	2020-03-24 16:58:06	2020-03-24	14	[{"id_menu":2,"count":1}]	16964	pick-up	0	14
42690	2020-03-24 16:58:47	2020-03-24	17	[{"id_menu":4,"count":1}]	3529	pick-up	0	17
42691	2020-03-24 17:01:56	2020-03-24	9	[{"id_menu":6,"count":1}]	14796	delivery	5	14
42692	2020-03-24 17:11:31	2020-03-24	14	[{"id_menu":2,"count":2}]	16905	delivery	5	19
42693	2020-03-24 17:14:27	2020-03-24	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	3640	delivery	5	25
42694	2020-03-24 17:46:15	2020-03-24	14	[{"id_menu":2,"count":1}]	15380	delivery	5	19
42695	2020-03-24 17:50:50	2020-03-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9838	delivery	5	28
42696	2020-03-24 17:56:20	2020-03-24	8	[{"id_menu":5,"count":1}]	1918	pick-up	0	8
42697	2020-03-24 18:04:53	2020-03-24	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	12316	delivery	5	39
42698	2020-03-24 18:06:44	2020-03-24	14	[{"id_menu":2,"count":1}]	17002	pick-up	0	14
42699	2020-03-24 18:21:14	2020-03-24	9	[{"id_menu":7,"count":1}]	16951	delivery	5	14
42700	2020-03-24 18:38:09	2020-03-24	14	[{"id_menu":2,"count":1}]	2575	pick-up	0	14
42701	2020-03-24 18:49:14	2020-03-24	17	[{"id_menu":4,"count":2}]	16972	pick-up	0	17
42702	2020-03-24 18:54:19	2020-03-24	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	10796	delivery	5	27
42703	2020-03-24 18:54:20	2020-03-24	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12808	pick-up	0	26
42704	2020-03-24 19:07:14	2020-03-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5802	pick-up	0	23
42705	2020-03-24 19:08:38	2020-03-24	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	8363	pick-up	0	32
42706	2020-03-24 19:14:50	2020-03-24	8	[{"id_menu":5,"count":1}]	5236	delivery	5	13
42707	2020-03-24 19:17:23	2020-03-24	9	[{"id_menu":6,"count":1}]	11765	delivery	5	14
42708	2020-03-24 19:21:35	2020-03-24	8	[{"id_menu":5,"count":1}]	4261	pick-up	0	8
42709	2020-03-24 19:22:22	2020-03-24	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	938	pick-up	0	26
42710	2020-03-24 19:24:53	2020-03-24	12	[{"id_menu":3,"count":1}]	1742	delivery	5	17
42711	2020-03-24 19:32:15	2020-03-24	17	[{"id_menu":4,"count":1}]	1630	pick-up	0	17
42712	2020-03-24 19:44:15	2020-03-24	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	16982	delivery	5	22
42713	2020-03-24 19:48:08	2020-03-24	14	[{"id_menu":2,"count":1}]	16999	delivery	5	19
42714	2020-03-24 19:54:16	2020-03-24	12	[{"id_menu":1,"count":1}]	3403	pick-up	0	12
42715	2020-03-24 20:06:26	2020-03-24	9	[{"id_menu":7,"count":1}]	527	pick-up	0	9
42716	2020-03-24 20:08:13	2020-03-24	9	[{"id_menu":6,"count":1}]	2223	pick-up	0	9
42717	2020-03-24 20:09:50	2020-03-24	12	[{"id_menu":3,"count":1}]	13996	pick-up	0	12
42718	2020-03-24 20:14:25	2020-03-24	12	[{"id_menu":1,"count":1}]	16975	delivery	5	17
42719	2020-03-24 20:24:38	2020-03-24	12	[{"id_menu":1,"count":1}]	2245	pick-up	0	12
42720	2020-03-24 20:28:25	2020-03-24	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	15288	delivery	5	38
42721	2020-03-24 20:39:57	2020-03-24	8	[{"id_menu":5,"count":1}]	17034	delivery	5	13
42722	2020-03-24 20:40:07	2020-03-24	9	[{"id_menu":6,"count":1}]	213	pick-up	0	9
42723	2020-03-24 20:49:57	2020-03-24	14	[{"id_menu":2,"count":2}]	13427	pick-up	0	14
42724	2020-03-24 20:51:38	2020-03-24	8	[{"id_menu":5,"count":1}]	950	pick-up	0	8
42725	2020-03-24 21:00:28	2020-03-24	9	[{"id_menu":7,"count":1}]	16971	delivery	5	14
42726	2020-03-24 21:01:03	2020-03-24	9	[{"id_menu":7,"count":1}]	6224	delivery	5	14
42727	2020-03-24 21:09:03	2020-03-24	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	4872	pick-up	0	20
42728	2020-03-24 21:20:09	2020-03-24	12	[{"id_menu":3,"count":1}]	16949	delivery	5	17
42729	2020-03-24 21:28:16	2020-03-24	9	[{"id_menu":6,"count":1}]	16969	delivery	5	14
42730	2020-03-24 21:28:42	2020-03-24	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7766	pick-up	0	40
42731	2020-03-24 21:31:09	2020-03-24	12	[{"id_menu":3,"count":1}]	8732	pick-up	0	12
42732	2020-03-24 21:45:46	2020-03-24	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10246	delivery	5	30
42733	2020-03-24 21:48:34	2020-03-24	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9525	delivery	5	34
42734	2020-03-24 22:01:42	2020-03-24	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	9491	pick-up	0	21
42735	2020-03-24 22:06:18	2020-03-24	9	[{"id_menu":6,"count":2}]	8346	delivery	5	14
42736	2020-03-24 22:12:17	2020-03-24	8	[{"id_menu":5,"count":1}]	13966	delivery	5	13
42737	2020-03-24 22:16:25	2020-03-24	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7860	delivery	5	35
42738	2020-03-24 22:16:37	2020-03-24	14	[{"id_menu":2,"count":1}]	16906	delivery	5	19
42739	2020-03-24 22:34:15	2020-03-24	9	[{"id_menu":7,"count":1}]	11618	delivery	5	14
42740	2020-03-24 22:42:28	2020-03-24	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	7106	delivery	5	22
42741	2020-03-24 22:42:50	2020-03-24	12	[{"id_menu":1,"count":1}]	16939	delivery	5	17
42742	2020-03-24 22:48:14	2020-03-24	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	17020	delivery	5	22
42743	2020-03-24 22:51:25	2020-03-24	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	16907	delivery	5	25
42744	2020-03-24 23:05:09	2020-03-24	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5191	delivery	5	34
42745	2020-03-24 23:07:35	2020-03-24	14	[{"id_menu":2,"count":1}]	17023	delivery	5	19
42746	2020-03-24 23:09:21	2020-03-24	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	6987	delivery	5	31
42747	2020-03-24 23:10:08	2020-03-24	14	[{"id_menu":2,"count":1}]	14973	delivery	5	19
42748	2020-03-24 23:16:01	2020-03-24	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5091	delivery	5	37
42749	2020-03-24 23:17:31	2020-03-24	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6241	delivery	5	31
42750	2020-03-24 23:21:27	2020-03-24	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2420	pick-up	0	29
42751	2020-03-24 23:22:42	2020-03-24	9	[{"id_menu":7,"count":1}]	1993	pick-up	0	9
42752	2020-03-24 23:24:39	2020-03-24	9	[{"id_menu":6,"count":1}]	16970	delivery	5	14
42753	2020-03-24 23:30:22	2020-03-24	8	[{"id_menu":5,"count":1}]	16992	delivery	5	13
42754	2020-03-24 23:33:03	2020-03-24	14	[{"id_menu":2,"count":1}]	14866	delivery	5	19
42755	2020-03-24 23:50:58	2020-03-24	14	[{"id_menu":2,"count":1}]	1460	pick-up	0	14
42756	2020-03-25 00:00:36	2020-03-25	14	[{"id_menu":2,"count":1}]	9081	delivery	5	19
42757	2020-03-25 00:01:52	2020-03-25	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1497	pick-up	0	20
42758	2020-03-25 00:02:46	2020-03-25	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	12949	delivery	5	26
42759	2020-03-25 00:04:02	2020-03-25	14	[{"id_menu":2,"count":1}]	2510	pick-up	0	14
42760	2020-03-25 00:07:27	2020-03-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9101	delivery	5	31
42761	2020-03-25 00:16:53	2020-03-25	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	17085	delivery	5	29
42762	2020-03-25 00:17:06	2020-03-25	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	17096	delivery	5	22
42763	2020-03-25 00:20:30	2020-03-25	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	13130	delivery	5	28
42764	2020-03-25 00:22:19	2020-03-25	12	[{"id_menu":1,"count":1}]	17087	delivery	5	17
42765	2020-03-25 00:29:31	2020-03-25	12	[{"id_menu":1,"count":1}]	12601	delivery	5	17
42766	2020-03-25 00:30:56	2020-03-25	9	[{"id_menu":6,"count":1}]	13210	delivery	5	14
42767	2020-03-25 00:33:43	2020-03-25	8	[{"id_menu":5,"count":1}]	17056	pick-up	0	8
42768	2020-03-25 00:35:40	2020-03-25	9	[{"id_menu":6,"count":1}]	13180	delivery	5	14
42769	2020-03-25 00:36:47	2020-03-25	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	2123	pick-up	0	23
42770	2020-03-25 00:39:10	2020-03-25	9	[{"id_menu":6,"count":1}]	4060	delivery	5	14
42771	2020-03-25 00:41:15	2020-03-25	12	[{"id_menu":3,"count":1}]	2085	pick-up	0	12
42772	2020-03-25 00:43:24	2020-03-25	12	[{"id_menu":3,"count":1}]	2545	pick-up	0	12
42773	2020-03-25 00:52:39	2020-03-25	9	[{"id_menu":6,"count":1}]	17077	delivery	5	14
42774	2020-03-25 00:53:05	2020-03-25	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	14232	pick-up	0	23
42775	2020-03-25 00:57:57	2020-03-25	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	17094	delivery	5	26
42776	2020-03-25 00:59:09	2020-03-25	12	[{"id_menu":1,"count":1}]	17076	delivery	5	17
42777	2020-03-25 00:59:37	2020-03-25	9	[{"id_menu":6,"count":1}]	9721	delivery	5	14
42778	2020-03-25 01:03:56	2020-03-25	9	[{"id_menu":6,"count":1}]	340	pick-up	0	9
42779	2020-03-25 01:05:22	2020-03-25	12	[{"id_menu":3,"count":1}]	3069	pick-up	0	12
42780	2020-03-25 01:09:30	2020-03-25	8	[{"id_menu":5,"count":1}]	13837	pick-up	0	8
42781	2020-03-25 01:11:00	2020-03-25	8	[{"id_menu":5,"count":1}]	13570	pick-up	0	8
42782	2020-03-25 01:14:11	2020-03-25	9	[{"id_menu":6,"count":1}]	17050	pick-up	0	9
42783	2020-03-25 01:20:05	2020-03-25	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7863	delivery	5	42
42784	2020-03-25 01:20:07	2020-03-25	9	[{"id_menu":7,"count":1}]	17122	delivery	5	14
42785	2020-03-25 01:28:47	2020-03-25	14	[{"id_menu":2,"count":2}]	17121	delivery	5	19
42786	2020-03-25 01:33:17	2020-03-25	14	[{"id_menu":2,"count":1}]	17075	delivery	5	19
42787	2020-03-25 01:34:00	2020-03-25	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15639	delivery	5	37
42788	2020-03-25 01:34:08	2020-03-25	14	[{"id_menu":2,"count":1}]	16239	delivery	5	19
42789	2020-03-25 01:35:07	2020-03-25	9	[{"id_menu":7,"count":1}]	5758	pick-up	0	9
42790	2020-03-25 01:43:36	2020-03-25	14	[{"id_menu":2,"count":1}]	599	pick-up	0	14
42791	2020-03-25 01:49:30	2020-03-25	17	[{"id_menu":4,"count":1}]	8628	delivery	5	22
42792	2020-03-25 01:51:12	2020-03-25	12	[{"id_menu":1,"count":1}]	17038	delivery	5	17
42793	2020-03-25 01:59:06	2020-03-25	8	[{"id_menu":5,"count":1}]	11377	delivery	5	13
42794	2020-03-25 02:04:06	2020-03-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16914	delivery	5	23
42795	2020-03-25 02:06:30	2020-03-25	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14630	delivery	5	39
42796	2020-03-25 02:07:07	2020-03-25	9	[{"id_menu":6,"count":1}]	5506	delivery	5	14
42797	2020-03-25 02:08:06	2020-03-25	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	11785	delivery	5	34
42798	2020-03-25 02:11:16	2020-03-25	9	[{"id_menu":6,"count":1}]	227	pick-up	0	9
42799	2020-03-25 02:22:10	2020-03-25	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13308	delivery	5	36
42800	2020-03-25 02:30:40	2020-03-25	14	[{"id_menu":2,"count":1}]	10880	pick-up	0	14
42801	2020-03-25 02:35:27	2020-03-25	14	[{"id_menu":2,"count":2}]	9160	pick-up	0	14
42802	2020-03-25 02:44:53	2020-03-25	8	[{"id_menu":5,"count":1}]	2087	delivery	5	13
42803	2020-03-25 02:51:24	2020-03-25	43	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	17089	pick-up	0	43
42804	2020-03-25 02:59:52	2020-03-25	12	[{"id_menu":1,"count":1}]	4326	pick-up	0	12
42805	2020-03-25 03:00:32	2020-03-25	12	[{"id_menu":3,"count":2}]	9320	pick-up	0	12
42806	2020-03-25 03:07:29	2020-03-25	9	[{"id_menu":7,"count":1}]	10819	pick-up	0	9
42807	2020-03-25 03:11:07	2020-03-25	12	[{"id_menu":1,"count":1}]	14491	delivery	5	17
42808	2020-03-25 03:15:57	2020-03-25	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	17095	delivery	5	46
42809	2020-03-25 03:18:02	2020-03-25	9	[{"id_menu":6,"count":1}]	17110	delivery	5	14
42810	2020-03-25 03:26:45	2020-03-25	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	15094	delivery	5	40
42811	2020-03-25 03:42:58	2020-03-25	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1968	delivery	5	26
42812	2020-03-25 03:47:52	2020-03-25	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":2}]	17103	delivery	5	28
42813	2020-03-25 03:51:56	2020-03-25	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	14210	delivery	5	31
42814	2020-03-25 03:57:38	2020-03-25	9	[{"id_menu":7,"count":1}]	6511	delivery	5	14
42815	2020-03-25 03:59:14	2020-03-25	9	[{"id_menu":6,"count":1}]	1212	delivery	5	14
42816	2020-03-25 03:59:15	2020-03-25	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3420	pick-up	0	29
42817	2020-03-25 04:07:54	2020-03-25	9	[{"id_menu":6,"count":2}]	6875	delivery	5	14
42818	2020-03-25 04:08:59	2020-03-25	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	6470	pick-up	0	33
42819	2020-03-25 04:09:04	2020-03-25	12	[{"id_menu":1,"count":1}]	17035	pick-up	0	12
42820	2020-03-25 04:13:43	2020-03-25	8	[{"id_menu":5,"count":1}]	5175	pick-up	0	8
42821	2020-03-25 04:29:12	2020-03-25	14	[{"id_menu":2,"count":1}]	13240	delivery	5	19
42822	2020-03-25 04:42:17	2020-03-25	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4302	delivery	5	36
42823	2020-03-25 04:46:53	2020-03-25	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	6102	delivery	5	31
42824	2020-03-25 04:53:23	2020-03-25	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14677	delivery	5	22
42825	2020-03-25 04:56:07	2020-03-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11534	pick-up	0	17
42826	2020-03-25 05:03:18	2020-03-25	14	[{"id_menu":2,"count":1}]	5877	delivery	5	19
42827	2020-03-25 05:04:34	2020-03-25	8	[{"id_menu":5,"count":1}]	9306	delivery	5	13
42828	2020-03-25 05:05:23	2020-03-25	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	13497	delivery	5	42
42829	2020-03-25 05:14:18	2020-03-25	17	[{"id_menu":4,"count":1}]	12001	delivery	5	22
42830	2020-03-25 05:18:23	2020-03-25	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	7357	delivery	5	34
42831	2020-03-25 05:30:03	2020-03-25	9	[{"id_menu":7,"count":3}]	10409	delivery	5	14
42832	2020-03-25 05:33:13	2020-03-25	9	[{"id_menu":6,"count":1}]	7766	pick-up	0	9
42833	2020-03-25 05:36:34	2020-03-25	9	[{"id_menu":7,"count":1}]	11898	delivery	5	14
42834	2020-03-25 05:44:18	2020-03-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9766	pick-up	0	26
42835	2020-03-25 05:49:17	2020-03-25	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2546	delivery	5	27
42836	2020-03-25 05:58:55	2020-03-25	14	[{"id_menu":2,"count":1}]	1369	pick-up	0	14
42837	2020-03-25 05:59:27	2020-03-25	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7095	delivery	5	52
42838	2020-03-25 06:02:53	2020-03-25	12	[{"id_menu":3,"count":1}]	5635	delivery	5	17
42839	2020-03-25 06:03:55	2020-03-25	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	12588	delivery	5	34
42840	2020-03-25 06:12:51	2020-03-25	8	[{"id_menu":5,"count":1}]	13540	delivery	5	13
42841	2020-03-25 06:17:59	2020-03-25	12	[{"id_menu":1,"count":1}]	7861	delivery	5	17
42842	2020-03-25 06:19:35	2020-03-25	17	[{"id_menu":4,"count":1}]	14309	delivery	5	22
42843	2020-03-25 06:20:38	2020-03-25	14	[{"id_menu":2,"count":1}]	17117	delivery	5	19
42844	2020-03-25 06:25:37	2020-03-25	9	[{"id_menu":6,"count":1}]	15292	pick-up	0	9
42845	2020-03-25 06:27:04	2020-03-25	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	4994	delivery	5	26
42846	2020-03-25 06:28:07	2020-03-25	9	[{"id_menu":7,"count":1}]	17130	delivery	5	14
42847	2020-03-25 06:42:16	2020-03-25	9	[{"id_menu":7,"count":1}]	14984	delivery	5	14
42848	2020-03-25 06:45:47	2020-03-25	9	[{"id_menu":6,"count":1}]	2373	pick-up	0	9
42849	2020-03-25 06:50:07	2020-03-25	12	[{"id_menu":3,"count":1}]	17138	pick-up	0	12
42850	2020-03-25 06:55:18	2020-03-25	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	17036	pick-up	0	25
42851	2020-03-25 06:55:31	2020-03-25	17	[{"id_menu":4,"count":1}]	2717	pick-up	0	17
42852	2020-03-25 06:58:11	2020-03-25	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17071	delivery	5	31
42853	2020-03-25 07:00:38	2020-03-25	9	[{"id_menu":6,"count":1}]	12132	delivery	5	14
42854	2020-03-25 07:16:50	2020-03-25	9	[{"id_menu":7,"count":1}]	3319	pick-up	0	9
42855	2020-03-25 07:22:30	2020-03-25	9	[{"id_menu":6,"count":1}]	2615	pick-up	0	9
42856	2020-03-25 07:26:10	2020-03-25	14	[{"id_menu":2,"count":1}]	13028	pick-up	0	14
42857	2020-03-25 07:31:16	2020-03-25	17	[{"id_menu":4,"count":1}]	15361	delivery	5	22
42858	2020-03-25 07:41:30	2020-03-25	9	[{"id_menu":7,"count":1}]	1431	delivery	5	14
42859	2020-03-25 07:44:56	2020-03-25	14	[{"id_menu":2,"count":2}]	17045	delivery	5	19
42860	2020-03-25 07:52:46	2020-03-25	12	[{"id_menu":1,"count":1}]	7447	delivery	5	17
42861	2020-03-25 07:58:38	2020-03-25	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13934	delivery	5	43
42862	2020-03-25 08:14:13	2020-03-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17043	delivery	5	23
42863	2020-03-25 08:16:36	2020-03-25	17	[{"id_menu":4,"count":1}]	2283	delivery	5	22
42864	2020-03-25 08:28:52	2020-03-25	17	[{"id_menu":4,"count":1}]	1259	pick-up	0	17
42865	2020-03-25 08:32:00	2020-03-25	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	17098	pick-up	0	47
42866	2020-03-25 08:46:21	2020-03-25	9	[{"id_menu":7,"count":1}]	15271	delivery	5	14
42867	2020-03-25 08:51:35	2020-03-25	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	17062	pick-up	0	23
42868	2020-03-25 08:54:57	2020-03-25	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	17086	delivery	5	40
42869	2020-03-25 08:59:07	2020-03-25	12	[{"id_menu":1,"count":1}]	10468	pick-up	0	12
42870	2020-03-25 08:59:45	2020-03-25	9	[{"id_menu":6,"count":1}]	17128	delivery	5	14
42871	2020-03-25 09:01:25	2020-03-25	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14534	delivery	5	51
42872	2020-03-25 09:01:40	2020-03-25	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	14765	delivery	5	26
42873	2020-03-25 09:03:11	2020-03-25	9	[{"id_menu":6,"count":2}]	17120	delivery	5	14
42874	2020-03-25 09:04:36	2020-03-25	14	[{"id_menu":2,"count":1}]	17123	delivery	5	19
42875	2020-03-25 09:06:36	2020-03-25	17	[{"id_menu":4,"count":1}]	1322	pick-up	0	17
42876	2020-03-25 09:09:30	2020-03-25	8	[{"id_menu":5,"count":1}]	3180	delivery	5	13
42877	2020-03-25 09:12:08	2020-03-25	9	[{"id_menu":7,"count":1}]	16434	pick-up	0	9
42878	2020-03-25 09:18:47	2020-03-25	14	[{"id_menu":2,"count":1}]	1528	delivery	5	19
42879	2020-03-25 09:33:53	2020-03-25	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17093	delivery	5	37
42880	2020-03-25 09:36:56	2020-03-25	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16998	delivery	5	53
42881	2020-03-25 09:38:47	2020-03-25	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1373	pick-up	0	21
42882	2020-03-25 09:40:09	2020-03-25	9	[{"id_menu":7,"count":1}]	17039	delivery	5	14
42883	2020-03-25 09:48:47	2020-03-25	9	[{"id_menu":6,"count":2}]	8172	delivery	5	14
42884	2020-03-25 09:59:40	2020-03-25	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	17100	delivery	5	28
42885	2020-03-25 10:02:24	2020-03-25	12	[{"id_menu":1,"count":1}]	2304	pick-up	0	12
42886	2020-03-25 10:13:25	2020-03-25	12	[{"id_menu":1,"count":1}]	5722	delivery	5	17
42887	2020-03-25 10:23:44	2020-03-25	12	[{"id_menu":1,"count":1}]	12235	pick-up	0	12
42888	2020-03-25 10:28:09	2020-03-25	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	8066	delivery	5	43
42889	2020-03-25 10:30:25	2020-03-25	9	[{"id_menu":7,"count":1}]	17109	delivery	5	14
42890	2020-03-25 10:32:37	2020-03-25	9	[{"id_menu":6,"count":1}]	2562	pick-up	0	9
42891	2020-03-25 10:35:40	2020-03-25	9	[{"id_menu":6,"count":2}]	11867	delivery	5	14
42892	2020-03-25 10:37:29	2020-03-25	9	[{"id_menu":6,"count":1}]	9093	pick-up	0	9
42893	2020-03-25 10:47:20	2020-03-25	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	12905	pick-up	0	21
42894	2020-03-25 10:53:16	2020-03-25	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4161	pick-up	0	22
42895	2020-03-25 10:54:03	2020-03-25	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	11806	delivery	5	40
42896	2020-03-25 10:57:46	2020-03-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2989	pick-up	0	26
42897	2020-03-25 11:01:27	2020-03-25	9	[{"id_menu":7,"count":1}]	17114	delivery	5	14
42898	2020-03-25 11:06:52	2020-03-25	14	[{"id_menu":2,"count":1}]	3766	pick-up	0	14
42899	2020-03-25 11:07:19	2020-03-25	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	11183	pick-up	0	21
42900	2020-03-25 11:12:04	2020-03-25	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	17111	delivery	5	26
42901	2020-03-25 11:15:02	2020-03-25	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3238	delivery	5	34
42902	2020-03-25 11:24:48	2020-03-25	17	[{"id_menu":4,"count":1}]	1513	delivery	5	22
42903	2020-03-25 11:26:07	2020-03-25	17	[{"id_menu":4,"count":2}]	16342	pick-up	0	17
42904	2020-03-25 11:33:35	2020-03-25	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	11369	delivery	5	34
42905	2020-03-25 11:41:15	2020-03-25	12	[{"id_menu":3,"count":1}]	5729	pick-up	0	12
42906	2020-03-25 11:45:00	2020-03-25	17	[{"id_menu":4,"count":1}]	4882	delivery	5	22
42907	2020-03-25 11:45:24	2020-03-25	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17119	pick-up	0	38
42908	2020-03-25 11:52:32	2020-03-25	8	[{"id_menu":5,"count":1}]	8652	pick-up	0	8
42909	2020-03-25 11:52:51	2020-03-25	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5531	delivery	5	43
42910	2020-03-25 11:54:56	2020-03-25	12	[{"id_menu":3,"count":2}]	2228	pick-up	0	12
42911	2020-03-25 11:56:56	2020-03-25	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	8609	pick-up	0	41
42912	2020-03-25 12:06:30	2020-03-25	14	[{"id_menu":2,"count":1}]	7017	delivery	5	19
42913	2020-03-25 12:16:35	2020-03-25	9	[{"id_menu":7,"count":1}]	7244	delivery	5	14
42914	2020-03-25 12:24:50	2020-03-25	17	[{"id_menu":4,"count":1}]	11495	pick-up	0	17
42915	2020-03-25 12:26:45	2020-03-25	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1245	pick-up	0	35
42916	2020-03-25 12:28:43	2020-03-25	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6364	pick-up	0	38
42917	2020-03-25 12:29:59	2020-03-25	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	14134	delivery	5	23
42918	2020-03-25 12:30:24	2020-03-25	12	[{"id_menu":3,"count":1}]	17079	pick-up	0	12
42919	2020-03-25 12:32:43	2020-03-25	8	[{"id_menu":5,"count":1}]	3837	delivery	5	13
42920	2020-03-25 12:32:54	2020-03-25	14	[{"id_menu":2,"count":1}]	6229	delivery	5	19
42921	2020-03-25 12:33:39	2020-03-25	17	[{"id_menu":4,"count":1}]	8461	delivery	5	22
42922	2020-03-25 12:38:20	2020-03-25	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13158	delivery	5	22
42923	2020-03-25 12:48:38	2020-03-25	12	[{"id_menu":1,"count":1}]	12393	pick-up	0	12
42924	2020-03-25 12:48:55	2020-03-25	9	[{"id_menu":6,"count":1}]	17047	delivery	5	14
42925	2020-03-25 12:50:05	2020-03-25	12	[{"id_menu":1,"count":1}]	9440	delivery	5	17
42926	2020-03-25 13:07:39	2020-03-25	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16361	delivery	5	34
42927	2020-03-25 13:11:25	2020-03-25	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2739	delivery	5	22
42928	2020-03-25 13:22:37	2020-03-25	8	[{"id_menu":5,"count":1}]	14705	delivery	5	13
42929	2020-03-25 13:40:39	2020-03-25	12	[{"id_menu":3,"count":1}]	17084	delivery	5	17
42930	2020-03-25 13:42:30	2020-03-25	17	[{"id_menu":4,"count":1}]	10574	delivery	5	22
42931	2020-03-25 13:49:33	2020-03-25	9	[{"id_menu":6,"count":1}]	17067	delivery	5	14
42932	2020-03-25 13:51:28	2020-03-25	9	[{"id_menu":7,"count":1}]	14434	delivery	5	14
42933	2020-03-25 13:54:14	2020-03-25	12	[{"id_menu":1,"count":1}]	7250	pick-up	0	12
42934	2020-03-25 13:56:11	2020-03-25	9	[{"id_menu":6,"count":1}]	5015	pick-up	0	9
42935	2020-03-25 14:05:08	2020-03-25	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	12755	delivery	5	36
42936	2020-03-25 14:10:09	2020-03-25	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2076	pick-up	0	22
42937	2020-03-25 14:10:21	2020-03-25	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":2}]	16052	delivery	5	22
42938	2020-03-25 14:12:32	2020-03-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11723	delivery	5	22
42939	2020-03-25 14:13:15	2020-03-25	9	[{"id_menu":7,"count":1}]	15146	delivery	5	14
42940	2020-03-25 14:18:57	2020-03-25	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	13324	delivery	5	26
42941	2020-03-25 14:19:00	2020-03-25	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	9957	delivery	5	39
42942	2020-03-25 14:22:37	2020-03-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	13507	delivery	5	28
42943	2020-03-25 14:23:18	2020-03-25	9	[{"id_menu":7,"count":1}]	17041	delivery	5	14
42944	2020-03-25 14:25:52	2020-03-25	17	[{"id_menu":4,"count":1}]	1093	pick-up	0	17
42945	2020-03-25 14:26:52	2020-03-25	12	[{"id_menu":1,"count":1}]	17083	pick-up	0	12
42946	2020-03-25 14:30:44	2020-03-25	9	[{"id_menu":7,"count":1}]	15969	delivery	5	14
42947	2020-03-25 14:38:16	2020-03-25	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17106	delivery	5	31
42948	2020-03-25 14:41:01	2020-03-25	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2783	delivery	5	26
42949	2020-03-25 14:41:11	2020-03-25	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	17059	delivery	5	35
42950	2020-03-25 14:46:00	2020-03-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1017	delivery	5	28
42951	2020-03-25 14:52:46	2020-03-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17091	delivery	5	22
42952	2020-03-25 14:57:37	2020-03-25	17	[{"id_menu":4,"count":1}]	2401	pick-up	0	17
42953	2020-03-25 15:04:57	2020-03-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	10442	delivery	5	23
42954	2020-03-25 15:06:28	2020-03-25	17	[{"id_menu":4,"count":1}]	11223	pick-up	0	17
42955	2020-03-25 15:06:43	2020-03-25	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8554	delivery	5	39
42956	2020-03-25 15:15:36	2020-03-25	30	[{"id_menu":1,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8050	delivery	5	35
42957	2020-03-25 15:17:48	2020-03-25	12	[{"id_menu":1,"count":1}]	4658	delivery	5	17
42958	2020-03-25 15:22:15	2020-03-25	14	[{"id_menu":2,"count":1}]	2294	delivery	5	19
42959	2020-03-25 15:29:55	2020-03-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	424	delivery	5	31
42960	2020-03-25 15:37:27	2020-03-25	14	[{"id_menu":2,"count":1}]	17125	delivery	5	19
42961	2020-03-25 15:38:44	2020-03-25	17	[{"id_menu":4,"count":1}]	2863	pick-up	0	17
42962	2020-03-25 16:00:15	2020-03-25	17	[{"id_menu":4,"count":1}]	17074	delivery	5	22
42963	2020-03-25 16:00:37	2020-03-25	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1922	pick-up	0	22
42964	2020-03-25 16:00:43	2020-03-25	9	[{"id_menu":7,"count":2}]	15774	delivery	5	14
42965	2020-03-25 16:04:03	2020-03-25	14	[{"id_menu":2,"count":1}]	7260	pick-up	0	14
42966	2020-03-25 16:05:28	2020-03-25	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17058	delivery	5	43
42967	2020-03-25 16:11:22	2020-03-25	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	11266	delivery	5	25
42968	2020-03-25 16:15:32	2020-03-25	14	[{"id_menu":2,"count":1}]	8177	delivery	5	19
42969	2020-03-25 16:23:10	2020-03-25	12	[{"id_menu":3,"count":1}]	1446	pick-up	0	12
42970	2020-03-25 16:28:23	2020-03-25	9	[{"id_menu":7,"count":1}]	17068	delivery	5	14
42971	2020-03-25 16:31:40	2020-03-25	9	[{"id_menu":6,"count":1}]	12616	delivery	5	14
42972	2020-03-25 16:31:50	2020-03-25	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	17069	delivery	5	37
42973	2020-03-25 16:55:04	2020-03-25	12	[{"id_menu":1,"count":1}]	17066	delivery	5	17
42974	2020-03-25 17:04:16	2020-03-25	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	17052	delivery	5	26
42975	2020-03-25 17:05:23	2020-03-25	14	[{"id_menu":2,"count":2}]	1068	delivery	5	19
42976	2020-03-25 17:08:12	2020-03-25	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	17141	delivery	5	31
42977	2020-03-25 17:14:22	2020-03-25	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	17057	pick-up	0	21
42978	2020-03-25 17:16:45	2020-03-25	9	[{"id_menu":6,"count":1}]	8249	delivery	5	14
42979	2020-03-25 17:17:52	2020-03-25	12	[{"id_menu":3,"count":1}]	12321	delivery	5	17
42980	2020-03-25 17:20:18	2020-03-25	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	17060	pick-up	0	31
42981	2020-03-25 17:20:44	2020-03-25	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	347	delivery	5	44
42982	2020-03-25 17:21:22	2020-03-25	14	[{"id_menu":2,"count":1}]	377	delivery	5	19
42983	2020-03-25 17:31:09	2020-03-25	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17133	delivery	5	31
42984	2020-03-25 17:37:00	2020-03-25	17	[{"id_menu":4,"count":1}]	12384	delivery	5	22
42985	2020-03-25 17:47:02	2020-03-25	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	5741	delivery	5	27
42986	2020-03-25 17:49:35	2020-03-25	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6455	delivery	5	48
42987	2020-03-25 17:58:53	2020-03-25	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1395	delivery	5	40
42988	2020-03-25 18:01:35	2020-03-25	9	[{"id_menu":6,"count":1}]	1800	delivery	5	14
42989	2020-03-25 18:14:18	2020-03-25	9	[{"id_menu":7,"count":1}]	8887	pick-up	0	9
42990	2020-03-25 18:14:55	2020-03-25	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	6755	pick-up	0	21
42991	2020-03-25 18:17:31	2020-03-25	17	[{"id_menu":4,"count":1}]	12685	delivery	5	22
42992	2020-03-25 18:21:13	2020-03-25	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	13237	delivery	5	26
42993	2020-03-25 18:21:45	2020-03-25	12	[{"id_menu":3,"count":1}]	15394	delivery	5	17
42994	2020-03-25 18:22:52	2020-03-25	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	17129	delivery	5	26
42995	2020-03-25 18:30:38	2020-03-25	12	[{"id_menu":1,"count":1}]	17139	delivery	5	17
42996	2020-03-25 18:31:16	2020-03-25	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4267	pick-up	0	21
42997	2020-03-25 18:34:55	2020-03-25	8	[{"id_menu":5,"count":1}]	4702	delivery	5	13
42998	2020-03-25 18:37:46	2020-03-25	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	1854	delivery	5	34
42999	2020-03-25 18:47:12	2020-03-25	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	17137	delivery	5	36
43000	2020-03-25 18:52:38	2020-03-25	12	[{"id_menu":1,"count":1}]	17061	pick-up	0	12
43001	2020-03-25 18:53:38	2020-03-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5120	delivery	5	22
43002	2020-03-25 18:56:18	2020-03-25	9	[{"id_menu":6,"count":1}]	17131	delivery	5	14
43003	2020-03-25 19:02:46	2020-03-25	12	[{"id_menu":1,"count":1}]	13288	pick-up	0	12
43004	2020-03-25 19:02:52	2020-03-25	14	[{"id_menu":2,"count":1}]	17049	delivery	5	19
43005	2020-03-25 19:13:15	2020-03-25	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	8730	pick-up	0	21
43006	2020-03-25 19:21:28	2020-03-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5306	delivery	5	23
43007	2020-03-25 19:21:47	2020-03-25	9	[{"id_menu":6,"count":1}]	17081	delivery	5	14
43008	2020-03-25 19:24:33	2020-03-25	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	4100	delivery	5	22
43009	2020-03-25 19:28:08	2020-03-25	17	[{"id_menu":4,"count":1}]	8071	pick-up	0	17
43010	2020-03-25 19:54:59	2020-03-25	14	[{"id_menu":2,"count":1}]	1676	pick-up	0	14
43011	2020-03-25 20:00:48	2020-03-25	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	17053	delivery	5	36
43012	2020-03-25 20:05:27	2020-03-25	8	[{"id_menu":5,"count":1}]	1924	pick-up	0	8
43013	2020-03-25 20:07:37	2020-03-25	9	[{"id_menu":6,"count":1}]	12375	delivery	5	14
43014	2020-03-25 20:17:08	2020-03-25	17	[{"id_menu":4,"count":1}]	17112	delivery	5	22
43015	2020-03-25 20:19:17	2020-03-25	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8382	delivery	5	45
43016	2020-03-25 20:29:56	2020-03-25	9	[{"id_menu":7,"count":1}]	5674	delivery	5	14
43017	2020-03-25 20:31:01	2020-03-25	12	[{"id_menu":3,"count":1}]	2256	pick-up	0	12
43018	2020-03-25 20:38:23	2020-03-25	12	[{"id_menu":1,"count":1}]	17080	pick-up	0	12
43019	2020-03-25 20:40:39	2020-03-25	9	[{"id_menu":7,"count":1}]	16181	delivery	5	14
43020	2020-03-25 20:42:18	2020-03-25	9	[{"id_menu":6,"count":1}]	11666	delivery	5	14
43021	2020-03-25 20:49:09	2020-03-25	9	[{"id_menu":6,"count":1}]	4946	delivery	5	14
43022	2020-03-25 20:52:55	2020-03-25	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	17054	delivery	5	45
43023	2020-03-25 20:58:02	2020-03-25	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	17092	delivery	5	34
43024	2020-03-25 20:59:19	2020-03-25	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17048	delivery	5	45
43025	2020-03-25 21:03:40	2020-03-25	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17140	delivery	5	51
43026	2020-03-25 21:10:36	2020-03-25	9	[{"id_menu":7,"count":1}]	17064	delivery	5	14
43027	2020-03-25 21:14:06	2020-03-25	8	[{"id_menu":5,"count":1}]	360	pick-up	0	8
43028	2020-03-25 21:15:05	2020-03-25	9	[{"id_menu":7,"count":1}]	17097	delivery	5	14
43029	2020-03-25 21:22:49	2020-03-25	14	[{"id_menu":2,"count":1}]	10369	delivery	5	19
43030	2020-03-25 21:28:31	2020-03-25	17	[{"id_menu":4,"count":1}]	293	pick-up	0	17
43031	2020-03-25 21:33:29	2020-03-25	12	[{"id_menu":1,"count":1}]	13821	pick-up	0	12
43032	2020-03-25 21:46:40	2020-03-25	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	11509	pick-up	0	35
43033	2020-03-25 21:47:18	2020-03-25	9	[{"id_menu":7,"count":1}]	7279	delivery	5	14
43034	2020-03-25 21:49:32	2020-03-25	12	[{"id_menu":3,"count":1}]	17126	delivery	5	17
43035	2020-03-25 21:52:33	2020-03-25	9	[{"id_menu":7,"count":1}]	3600	pick-up	0	9
43036	2020-03-25 21:57:20	2020-03-25	8	[{"id_menu":5,"count":2}]	3934	delivery	5	13
43037	2020-03-25 22:02:45	2020-03-25	9	[{"id_menu":7,"count":1}]	16512	delivery	5	14
43038	2020-03-25 22:09:12	2020-03-25	14	[{"id_menu":2,"count":1}]	7960	delivery	5	19
43039	2020-03-25 22:14:16	2020-03-25	14	[{"id_menu":2,"count":1}]	807	pick-up	0	14
43040	2020-03-25 22:23:55	2020-03-25	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	6348	delivery	5	31
43041	2020-03-25 22:24:10	2020-03-25	8	[{"id_menu":5,"count":1}]	11624	delivery	5	13
43042	2020-03-25 22:25:51	2020-03-25	9	[{"id_menu":7,"count":1}]	4089	pick-up	0	9
43043	2020-03-25 22:29:16	2020-03-25	9	[{"id_menu":7,"count":1}]	17102	delivery	5	14
43044	2020-03-25 22:32:58	2020-03-25	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	13787	delivery	5	38
43045	2020-03-25 22:42:56	2020-03-25	14	[{"id_menu":2,"count":1}]	16127	pick-up	0	14
43046	2020-03-25 22:44:25	2020-03-25	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3913	delivery	5	26
43047	2020-03-25 22:45:05	2020-03-25	9	[{"id_menu":7,"count":1}]	17107	delivery	5	14
43048	2020-03-25 22:48:04	2020-03-25	14	[{"id_menu":2,"count":1}]	16627	pick-up	0	14
43049	2020-03-25 22:56:23	2020-03-25	9	[{"id_menu":6,"count":1}]	1202	pick-up	0	9
43050	2020-03-25 23:10:09	2020-03-25	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	389	pick-up	0	21
43051	2020-03-25 23:14:00	2020-03-25	9	[{"id_menu":6,"count":1}]	8990	delivery	5	14
43052	2020-03-25 23:29:44	2020-03-25	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	9623	delivery	5	45
43053	2020-03-25 23:38:48	2020-03-25	14	[{"id_menu":2,"count":1}]	6573	delivery	5	19
43054	2020-03-25 23:39:40	2020-03-25	14	[{"id_menu":2,"count":1}]	8363	pick-up	0	14
43055	2020-03-25 23:49:39	2020-03-25	17	[{"id_menu":4,"count":1}]	2887	delivery	5	22
43056	2020-03-25 23:50:12	2020-03-25	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	17046	pick-up	0	20
43057	2020-03-25 23:50:40	2020-03-25	17	[{"id_menu":4,"count":1}]	14133	delivery	5	22
43058	2020-03-25 23:58:52	2020-03-25	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17099	delivery	5	36
43059	2020-03-26 00:02:25	2020-03-26	8	[{"id_menu":5,"count":1}]	17205	delivery	5	13
43060	2020-03-26 00:05:49	2020-03-26	14	[{"id_menu":2,"count":1}]	17155	delivery	5	19
43130	2020-03-26 05:00:30	2020-03-26	12	[{"id_menu":1,"count":1}]	17263	delivery	5	17
43061	2020-03-26 00:06:39	2020-03-26	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17187	delivery	5	39
43062	2020-03-26 00:16:58	2020-03-26	8	[{"id_menu":5,"count":1}]	13881	delivery	5	13
43063	2020-03-26 00:26:00	2020-03-26	9	[{"id_menu":6,"count":4}]	12752	delivery	5	14
43064	2020-03-26 00:38:07	2020-03-26	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	17239	pick-up	0	26
43065	2020-03-26 00:44:43	2020-03-26	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3848	pick-up	0	26
43066	2020-03-26 00:54:03	2020-03-26	9	[{"id_menu":6,"count":1}]	1687	pick-up	0	9
43067	2020-03-26 01:00:29	2020-03-26	8	[{"id_menu":5,"count":1}]	497	pick-up	0	8
43068	2020-03-26 01:02:01	2020-03-26	9	[{"id_menu":7,"count":1}]	5064	pick-up	0	9
43069	2020-03-26 01:02:15	2020-03-26	12	[{"id_menu":1,"count":1}]	17167	delivery	5	17
43070	2020-03-26 01:08:53	2020-03-26	9	[{"id_menu":7,"count":1}]	3299	delivery	5	14
43071	2020-03-26 01:10:22	2020-03-26	17	[{"id_menu":4,"count":1}]	13410	pick-up	0	17
43072	2020-03-26 01:13:51	2020-03-26	9	[{"id_menu":6,"count":1}]	17149	delivery	5	14
43073	2020-03-26 01:21:14	2020-03-26	8	[{"id_menu":5,"count":1}]	17148	delivery	5	13
43074	2020-03-26 01:30:48	2020-03-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	401	pick-up	0	21
43075	2020-03-26 01:33:34	2020-03-26	9	[{"id_menu":7,"count":1}]	16739	delivery	5	14
43076	2020-03-26 01:34:34	2020-03-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	914	pick-up	0	21
43077	2020-03-26 01:37:37	2020-03-26	12	[{"id_menu":1,"count":1}]	14442	delivery	5	17
43078	2020-03-26 01:40:21	2020-03-26	8	[{"id_menu":5,"count":1}]	14661	pick-up	0	8
43079	2020-03-26 01:42:09	2020-03-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	9175	delivery	5	26
43080	2020-03-26 01:43:19	2020-03-26	12	[{"id_menu":3,"count":1}]	13050	pick-up	0	12
43081	2020-03-26 01:49:46	2020-03-26	9	[{"id_menu":6,"count":1}]	8081	pick-up	0	9
43082	2020-03-26 01:53:16	2020-03-26	12	[{"id_menu":3,"count":1}]	17150	delivery	5	17
43083	2020-03-26 01:53:16	2020-03-26	9	[{"id_menu":6,"count":1}]	17195	delivery	5	14
43084	2020-03-26 01:57:07	2020-03-26	8	[{"id_menu":5,"count":1}]	12550	delivery	5	13
43085	2020-03-26 01:57:13	2020-03-26	9	[{"id_menu":7,"count":4}]	10666	delivery	5	14
43086	2020-03-26 01:59:28	2020-03-26	9	[{"id_menu":7,"count":1}]	5256	pick-up	0	9
43087	2020-03-26 02:04:11	2020-03-26	12	[{"id_menu":3,"count":1}]	255	pick-up	0	12
43088	2020-03-26 02:07:07	2020-03-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3459	delivery	5	26
43089	2020-03-26 02:07:58	2020-03-26	9	[{"id_menu":6,"count":1}]	3038	pick-up	0	9
43090	2020-03-26 02:16:11	2020-03-26	14	[{"id_menu":2,"count":1}]	62	pick-up	0	14
43091	2020-03-26 02:18:38	2020-03-26	9	[{"id_menu":7,"count":1}]	17254	delivery	5	14
43092	2020-03-26 02:22:58	2020-03-26	12	[{"id_menu":3,"count":1}]	2041	pick-up	0	12
43093	2020-03-26 02:23:02	2020-03-26	14	[{"id_menu":2,"count":1}]	17245	delivery	5	19
43094	2020-03-26 02:25:48	2020-03-26	17	[{"id_menu":4,"count":1}]	15548	delivery	5	22
43095	2020-03-26 02:26:56	2020-03-26	8	[{"id_menu":5,"count":1}]	10501	delivery	5	13
43096	2020-03-26 02:27:35	2020-03-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2320	pick-up	0	26
43097	2020-03-26 02:28:06	2020-03-26	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1079	delivery	5	26
43098	2020-03-26 02:30:00	2020-03-26	9	[{"id_menu":7,"count":1}]	3375	pick-up	0	9
43099	2020-03-26 02:31:17	2020-03-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":3}]	17201	delivery	5	22
43100	2020-03-26 02:33:21	2020-03-26	9	[{"id_menu":7,"count":1}]	17268	delivery	5	14
43101	2020-03-26 02:33:59	2020-03-26	17	[{"id_menu":4,"count":1}]	17190	delivery	5	22
43102	2020-03-26 02:34:42	2020-03-26	12	[{"id_menu":1,"count":1}]	7097	pick-up	0	12
43103	2020-03-26 02:37:59	2020-03-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	10423	delivery	5	22
43104	2020-03-26 02:43:45	2020-03-26	17	[{"id_menu":4,"count":1}]	17232	delivery	5	22
43105	2020-03-26 02:49:57	2020-03-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	203	pick-up	0	18
43106	2020-03-26 02:54:00	2020-03-26	9	[{"id_menu":7,"count":1}]	17218	delivery	5	14
43107	2020-03-26 02:57:01	2020-03-26	9	[{"id_menu":7,"count":1}]	17275	delivery	5	14
43108	2020-03-26 02:58:54	2020-03-26	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5775	delivery	5	40
43109	2020-03-26 03:01:14	2020-03-26	9	[{"id_menu":7,"count":1}]	15961	pick-up	0	9
43110	2020-03-26 03:09:34	2020-03-26	12	[{"id_menu":3,"count":1}]	17249	delivery	5	17
43111	2020-03-26 03:10:38	2020-03-26	8	[{"id_menu":5,"count":1}]	7500	delivery	5	13
43112	2020-03-26 03:14:42	2020-03-26	12	[{"id_menu":3,"count":1}]	2227	pick-up	0	12
43113	2020-03-26 03:18:56	2020-03-26	9	[{"id_menu":7,"count":1}]	17214	delivery	5	14
43114	2020-03-26 03:26:34	2020-03-26	17	[{"id_menu":4,"count":1}]	9749	pick-up	0	17
43115	2020-03-26 03:30:10	2020-03-26	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2409	pick-up	0	29
43116	2020-03-26 03:35:27	2020-03-26	14	[{"id_menu":2,"count":1}]	16964	pick-up	0	14
43117	2020-03-26 03:41:12	2020-03-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8646	delivery	5	22
43118	2020-03-26 03:49:38	2020-03-26	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9559	delivery	5	36
43119	2020-03-26 03:59:26	2020-03-26	9	[{"id_menu":6,"count":1}]	17270	delivery	5	14
43120	2020-03-26 04:01:12	2020-03-26	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	7899	delivery	5	39
43121	2020-03-26 04:05:37	2020-03-26	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	15933	delivery	5	36
43122	2020-03-26 04:05:52	2020-03-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17256	delivery	5	22
43123	2020-03-26 04:11:30	2020-03-26	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4748	delivery	5	40
43124	2020-03-26 04:12:13	2020-03-26	8	[{"id_menu":5,"count":1}]	4939	delivery	5	13
43125	2020-03-26 04:17:09	2020-03-26	17	[{"id_menu":4,"count":1}]	2070	delivery	5	22
43126	2020-03-26 04:26:49	2020-03-26	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	13195	delivery	5	31
43127	2020-03-26 04:43:28	2020-03-26	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	3578	delivery	5	31
43128	2020-03-26 04:45:13	2020-03-26	26	[{"id_menu":4,"count":3},{"id_menu":6,"count":1}]	10729	delivery	5	31
43129	2020-03-26 04:55:27	2020-03-26	12	[{"id_menu":1,"count":1}]	12486	pick-up	0	12
43131	2020-03-26 05:02:43	2020-03-26	8	[{"id_menu":5,"count":1}]	5768	delivery	5	13
43132	2020-03-26 05:04:43	2020-03-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	17189	delivery	5	22
43133	2020-03-26 05:07:11	2020-03-26	12	[{"id_menu":1,"count":1}]	17161	delivery	5	17
43134	2020-03-26 05:11:10	2020-03-26	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1273	delivery	5	27
43135	2020-03-26 05:13:46	2020-03-26	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	17265	delivery	5	34
43136	2020-03-26 05:17:03	2020-03-26	17	[{"id_menu":4,"count":1}]	16150	delivery	5	22
43137	2020-03-26 05:21:00	2020-03-26	8	[{"id_menu":5,"count":1}]	10785	pick-up	0	8
43138	2020-03-26 05:21:51	2020-03-26	9	[{"id_menu":6,"count":1}]	6941	delivery	5	14
43139	2020-03-26 05:25:27	2020-03-26	14	[{"id_menu":2,"count":1}]	14088	delivery	5	19
43140	2020-03-26 05:26:10	2020-03-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	17271	delivery	5	26
43141	2020-03-26 05:29:46	2020-03-26	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	9990	pick-up	0	18
43142	2020-03-26 05:33:42	2020-03-26	9	[{"id_menu":7,"count":1}]	16117	delivery	5	14
43143	2020-03-26 05:35:19	2020-03-26	8	[{"id_menu":5,"count":1}]	17215	delivery	5	13
43144	2020-03-26 05:36:32	2020-03-26	9	[{"id_menu":7,"count":1}]	16305	delivery	5	14
43145	2020-03-26 05:42:56	2020-03-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17157	delivery	5	31
43146	2020-03-26 05:45:19	2020-03-26	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4021	pick-up	0	31
43147	2020-03-26 05:46:54	2020-03-26	17	[{"id_menu":4,"count":1}]	17158	delivery	5	22
43148	2020-03-26 05:47:46	2020-03-26	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	17178	delivery	5	26
43149	2020-03-26 05:50:00	2020-03-26	9	[{"id_menu":7,"count":1}]	11669	delivery	5	14
43150	2020-03-26 05:50:53	2020-03-26	9	[{"id_menu":7,"count":1}]	17210	delivery	5	14
43151	2020-03-26 05:51:46	2020-03-26	14	[{"id_menu":2,"count":1}]	3816	delivery	5	19
43152	2020-03-26 05:53:20	2020-03-26	9	[{"id_menu":7,"count":1}]	6455	delivery	5	14
43153	2020-03-26 05:55:15	2020-03-26	12	[{"id_menu":1,"count":1}]	17274	pick-up	0	12
43154	2020-03-26 06:00:00	2020-03-26	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	8884	delivery	5	25
43155	2020-03-26 06:06:29	2020-03-26	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1707	delivery	5	30
43156	2020-03-26 06:09:14	2020-03-26	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	17169	delivery	5	34
43157	2020-03-26 06:09:29	2020-03-26	12	[{"id_menu":3,"count":1}]	17222	delivery	5	17
43158	2020-03-26 06:29:20	2020-03-26	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	17278	delivery	5	40
43159	2020-03-26 06:29:28	2020-03-26	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17153	delivery	5	36
43160	2020-03-26 06:40:18	2020-03-26	9	[{"id_menu":6,"count":2}]	17266	delivery	5	14
43161	2020-03-26 06:43:55	2020-03-26	8	[{"id_menu":5,"count":1}]	17170	delivery	5	13
43162	2020-03-26 06:46:30	2020-03-26	9	[{"id_menu":7,"count":1}]	17197	pick-up	0	9
43163	2020-03-26 06:52:38	2020-03-26	14	[{"id_menu":2,"count":1}]	11444	delivery	5	19
43164	2020-03-26 06:57:39	2020-03-26	12	[{"id_menu":1,"count":1}]	2690	delivery	5	17
43165	2020-03-26 07:02:20	2020-03-26	9	[{"id_menu":6,"count":1}]	5935	delivery	5	14
43166	2020-03-26 07:13:51	2020-03-26	9	[{"id_menu":6,"count":1}]	11549	delivery	5	14
43167	2020-03-26 07:14:52	2020-03-26	9	[{"id_menu":7,"count":3}]	3137	delivery	5	14
43168	2020-03-26 07:15:02	2020-03-26	9	[{"id_menu":7,"count":1}]	17188	delivery	5	14
43169	2020-03-26 07:20:10	2020-03-26	14	[{"id_menu":2,"count":1}]	2474	pick-up	0	14
43170	2020-03-26 07:29:05	2020-03-26	17	[{"id_menu":4,"count":1}]	17192	delivery	5	22
43171	2020-03-26 07:41:18	2020-03-26	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	17208	delivery	5	35
43172	2020-03-26 07:48:14	2020-03-26	9	[{"id_menu":6,"count":1}]	1804	pick-up	0	9
43173	2020-03-26 07:52:58	2020-03-26	8	[{"id_menu":5,"count":1}]	2081	delivery	5	13
43174	2020-03-26 07:56:11	2020-03-26	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	15368	delivery	5	26
43175	2020-03-26 08:02:15	2020-03-26	8	[{"id_menu":5,"count":1}]	11308	delivery	5	13
43176	2020-03-26 08:03:19	2020-03-26	9	[{"id_menu":6,"count":1}]	8522	delivery	5	14
43177	2020-03-26 08:05:58	2020-03-26	9	[{"id_menu":6,"count":2}]	3983	delivery	5	14
43178	2020-03-26 08:10:20	2020-03-26	14	[{"id_menu":2,"count":1}]	2989	pick-up	0	14
43179	2020-03-26 08:12:28	2020-03-26	12	[{"id_menu":1,"count":1}]	16901	delivery	5	17
43180	2020-03-26 08:15:16	2020-03-26	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	17171	delivery	5	48
43181	2020-03-26 08:18:06	2020-03-26	17	[{"id_menu":4,"count":1}]	5180	pick-up	0	17
43182	2020-03-26 08:18:27	2020-03-26	8	[{"id_menu":5,"count":2}]	8757	pick-up	0	8
43183	2020-03-26 08:19:13	2020-03-26	9	[{"id_menu":7,"count":1}]	10746	delivery	5	14
43184	2020-03-26 08:25:13	2020-03-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17250	delivery	5	22
43185	2020-03-26 08:26:18	2020-03-26	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	17246	delivery	5	25
43186	2020-03-26 08:28:26	2020-03-26	9	[{"id_menu":6,"count":1}]	8495	delivery	5	14
43187	2020-03-26 08:38:19	2020-03-26	9	[{"id_menu":7,"count":1}]	15973	delivery	5	14
43188	2020-03-26 08:40:27	2020-03-26	14	[{"id_menu":2,"count":2}]	15198	delivery	5	19
43189	2020-03-26 08:41:32	2020-03-26	17	[{"id_menu":4,"count":1}]	17225	pick-up	0	17
43190	2020-03-26 08:46:07	2020-03-26	17	[{"id_menu":4,"count":1}]	2902	pick-up	0	17
43191	2020-03-26 08:49:14	2020-03-26	14	[{"id_menu":2,"count":1}]	5236	delivery	5	19
43192	2020-03-26 08:53:02	2020-03-26	8	[{"id_menu":5,"count":2}]	5654	delivery	5	13
43193	2020-03-26 08:54:01	2020-03-26	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	743	delivery	5	29
43194	2020-03-26 08:54:18	2020-03-26	8	[{"id_menu":5,"count":2}]	17160	delivery	5	13
43195	2020-03-26 08:56:33	2020-03-26	9	[{"id_menu":7,"count":1}]	14585	pick-up	0	9
43196	2020-03-26 08:57:29	2020-03-26	9	[{"id_menu":7,"count":1}]	17177	delivery	5	14
43197	2020-03-26 09:00:56	2020-03-26	8	[{"id_menu":5,"count":1}]	17219	delivery	5	13
43198	2020-03-26 09:12:01	2020-03-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	17207	delivery	5	28
43199	2020-03-26 09:15:06	2020-03-26	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	11615	pick-up	0	26
43200	2020-03-26 09:20:37	2020-03-26	14	[{"id_menu":2,"count":1}]	14193	delivery	5	19
43201	2020-03-26 09:21:06	2020-03-26	12	[{"id_menu":1,"count":1}]	17198	delivery	5	17
43202	2020-03-26 09:21:10	2020-03-26	14	[{"id_menu":2,"count":1}]	17193	delivery	5	19
43203	2020-03-26 09:22:41	2020-03-26	9	[{"id_menu":6,"count":1}]	17217	delivery	5	14
43204	2020-03-26 09:34:26	2020-03-26	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17176	delivery	5	39
43205	2020-03-26 09:34:57	2020-03-26	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	17231	delivery	5	31
43206	2020-03-26 09:43:21	2020-03-26	8	[{"id_menu":5,"count":1}]	1225	delivery	5	13
43207	2020-03-26 09:45:54	2020-03-26	17	[{"id_menu":4,"count":1}]	1239	pick-up	0	17
43208	2020-03-26 09:53:43	2020-03-26	9	[{"id_menu":6,"count":1}]	17180	pick-up	0	9
43209	2020-03-26 09:54:34	2020-03-26	8	[{"id_menu":5,"count":1}]	4465	delivery	5	13
43210	2020-03-26 09:55:47	2020-03-26	9	[{"id_menu":6,"count":2}]	17212	delivery	5	14
43211	2020-03-26 10:02:19	2020-03-26	12	[{"id_menu":3,"count":1}]	12076	delivery	5	17
43212	2020-03-26 10:02:44	2020-03-26	14	[{"id_menu":2,"count":1}]	14223	delivery	5	19
43213	2020-03-26 10:05:03	2020-03-26	12	[{"id_menu":1,"count":1}]	6851	delivery	5	17
43214	2020-03-26 10:10:38	2020-03-26	9	[{"id_menu":6,"count":1}]	4592	delivery	5	14
43215	2020-03-26 10:13:01	2020-03-26	14	[{"id_menu":2,"count":1}]	17277	pick-up	0	14
43216	2020-03-26 10:14:07	2020-03-26	17	[{"id_menu":4,"count":1}]	356	pick-up	0	17
43217	2020-03-26 10:17:07	2020-03-26	8	[{"id_menu":5,"count":1}]	1282	delivery	5	13
43218	2020-03-26 10:21:17	2020-03-26	8	[{"id_menu":5,"count":1}]	17216	delivery	5	13
43219	2020-03-26 10:23:02	2020-03-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9014	delivery	5	23
43220	2020-03-26 10:31:03	2020-03-26	9	[{"id_menu":7,"count":1}]	17238	delivery	5	14
43221	2020-03-26 10:32:16	2020-03-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":3}]	17244	delivery	5	28
43222	2020-03-26 10:32:44	2020-03-26	8	[{"id_menu":5,"count":1}]	17147	delivery	5	13
43223	2020-03-26 10:35:31	2020-03-26	9	[{"id_menu":7,"count":1}]	17251	delivery	5	14
43224	2020-03-26 10:40:49	2020-03-26	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10758	delivery	5	40
43225	2020-03-26 10:41:03	2020-03-26	9	[{"id_menu":6,"count":1}]	3647	pick-up	0	9
43226	2020-03-26 10:46:11	2020-03-26	9	[{"id_menu":6,"count":1}]	17194	pick-up	0	9
43227	2020-03-26 10:52:44	2020-03-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	17241	delivery	5	26
43228	2020-03-26 10:59:11	2020-03-26	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	2975	delivery	5	28
43229	2020-03-26 11:03:10	2020-03-26	12	[{"id_menu":3,"count":1}]	1176	pick-up	0	12
43230	2020-03-26 11:07:12	2020-03-26	9	[{"id_menu":7,"count":1}]	6174	delivery	5	14
43231	2020-03-26 11:12:23	2020-03-26	9	[{"id_menu":6,"count":1}]	17227	delivery	5	14
43232	2020-03-26 11:15:24	2020-03-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	4354	delivery	5	23
43233	2020-03-26 11:16:57	2020-03-26	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	1228	delivery	5	45
43234	2020-03-26 11:26:00	2020-03-26	14	[{"id_menu":2,"count":1}]	8574	delivery	5	19
43235	2020-03-26 11:27:25	2020-03-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	17213	delivery	5	26
43236	2020-03-26 11:28:28	2020-03-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1070	delivery	5	28
43237	2020-03-26 11:31:21	2020-03-26	12	[{"id_menu":3,"count":1}]	2480	pick-up	0	12
43238	2020-03-26 11:31:22	2020-03-26	8	[{"id_menu":5,"count":1}]	15385	pick-up	0	8
43239	2020-03-26 11:34:27	2020-03-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6511	delivery	5	22
43240	2020-03-26 11:39:50	2020-03-26	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17191	delivery	5	45
43241	2020-03-26 11:40:48	2020-03-26	12	[{"id_menu":3,"count":1}]	9103	delivery	5	17
43242	2020-03-26 11:42:12	2020-03-26	17	[{"id_menu":4,"count":1}]	452	pick-up	0	17
43243	2020-03-26 11:45:21	2020-03-26	12	[{"id_menu":1,"count":1}]	7619	delivery	5	17
43244	2020-03-26 11:45:57	2020-03-26	8	[{"id_menu":5,"count":2}]	17151	delivery	5	13
43245	2020-03-26 11:52:28	2020-03-26	9	[{"id_menu":7,"count":1}]	5830	delivery	5	14
43246	2020-03-26 12:01:45	2020-03-26	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11756	delivery	5	34
43247	2020-03-26 12:09:25	2020-03-26	9	[{"id_menu":6,"count":1}]	6004	pick-up	0	9
43248	2020-03-26 12:11:43	2020-03-26	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5675	delivery	5	43
43249	2020-03-26 12:15:20	2020-03-26	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17159	delivery	5	31
43250	2020-03-26 12:19:46	2020-03-26	9	[{"id_menu":7,"count":1}]	13856	delivery	5	14
43251	2020-03-26 12:20:50	2020-03-26	17	[{"id_menu":4,"count":1}]	14501	pick-up	0	17
43252	2020-03-26 12:21:33	2020-03-26	14	[{"id_menu":2,"count":1}]	2722	pick-up	0	14
43253	2020-03-26 12:22:56	2020-03-26	14	[{"id_menu":2,"count":1}]	17168	delivery	5	19
43254	2020-03-26 12:32:42	2020-03-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12420	pick-up	0	17
43255	2020-03-26 12:35:10	2020-03-26	12	[{"id_menu":1,"count":1}]	17234	delivery	5	17
43256	2020-03-26 12:51:08	2020-03-26	9	[{"id_menu":7,"count":1}]	17142	delivery	5	14
43257	2020-03-26 12:56:42	2020-03-26	8	[{"id_menu":5,"count":1}]	947	delivery	5	13
43258	2020-03-26 12:57:31	2020-03-26	8	[{"id_menu":5,"count":1}]	17143	delivery	5	13
43259	2020-03-26 12:58:40	2020-03-26	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	13906	delivery	5	28
43260	2020-03-26 13:06:45	2020-03-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	17253	delivery	5	28
43261	2020-03-26 13:08:23	2020-03-26	9	[{"id_menu":7,"count":1}]	9241	pick-up	0	9
43262	2020-03-26 13:11:47	2020-03-26	12	[{"id_menu":3,"count":1}]	12527	pick-up	0	12
43263	2020-03-26 13:15:09	2020-03-26	9	[{"id_menu":6,"count":1}]	6782	delivery	5	14
43264	2020-03-26 13:16:21	2020-03-26	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4231	delivery	5	43
43265	2020-03-26 13:19:56	2020-03-26	14	[{"id_menu":2,"count":1}]	17172	pick-up	0	14
43266	2020-03-26 13:20:09	2020-03-26	12	[{"id_menu":3,"count":1}]	17211	delivery	5	17
43267	2020-03-26 13:20:27	2020-03-26	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2275	pick-up	0	29
43268	2020-03-26 13:28:54	2020-03-26	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4072	delivery	5	26
43269	2020-03-26 13:43:56	2020-03-26	9	[{"id_menu":7,"count":1}]	17199	pick-up	0	9
43270	2020-03-26 13:46:01	2020-03-26	12	[{"id_menu":3,"count":1}]	13285	delivery	5	17
43271	2020-03-26 13:46:12	2020-03-26	9	[{"id_menu":6,"count":1}]	9991	delivery	5	14
43272	2020-03-26 13:46:25	2020-03-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15867	delivery	5	23
43273	2020-03-26 13:48:50	2020-03-26	12	[{"id_menu":3,"count":1}]	7879	pick-up	0	12
43274	2020-03-26 13:49:49	2020-03-26	9	[{"id_menu":6,"count":2}]	80	pick-up	0	9
43275	2020-03-26 13:50:00	2020-03-26	12	[{"id_menu":1,"count":1}]	15585	delivery	5	17
43276	2020-03-26 13:53:18	2020-03-26	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17156	delivery	5	51
43277	2020-03-26 13:56:55	2020-03-26	12	[{"id_menu":3,"count":1}]	3024	delivery	5	17
43278	2020-03-26 13:57:37	2020-03-26	9	[{"id_menu":7,"count":1}]	7559	delivery	5	14
43279	2020-03-26 14:00:37	2020-03-26	14	[{"id_menu":2,"count":1}]	17229	delivery	5	19
43280	2020-03-26 14:03:58	2020-03-26	12	[{"id_menu":1,"count":1}]	17269	delivery	5	17
43281	2020-03-26 14:04:25	2020-03-26	9	[{"id_menu":7,"count":1}]	17186	delivery	5	14
43282	2020-03-26 14:08:18	2020-03-26	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	17230	delivery	5	26
43283	2020-03-26 14:20:00	2020-03-26	14	[{"id_menu":2,"count":2}]	8520	delivery	5	19
43284	2020-03-26 14:23:32	2020-03-26	8	[{"id_menu":5,"count":1}]	7028	delivery	5	13
43285	2020-03-26 14:24:28	2020-03-26	14	[{"id_menu":2,"count":1}]	5820	delivery	5	19
43286	2020-03-26 14:25:56	2020-03-26	17	[{"id_menu":4,"count":1}]	6666	pick-up	0	17
43287	2020-03-26 14:26:53	2020-03-26	9	[{"id_menu":7,"count":1}]	287	delivery	5	14
43288	2020-03-26 14:31:16	2020-03-26	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	13662	pick-up	0	24
43289	2020-03-26 14:36:56	2020-03-26	12	[{"id_menu":3,"count":1}]	3116	pick-up	0	12
43290	2020-03-26 14:37:41	2020-03-26	17	[{"id_menu":4,"count":1}]	1884	pick-up	0	17
43291	2020-03-26 14:37:58	2020-03-26	12	[{"id_menu":3,"count":1}]	13127	delivery	5	17
43292	2020-03-26 14:38:03	2020-03-26	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1540	pick-up	0	29
43293	2020-03-26 14:40:08	2020-03-26	9	[{"id_menu":7,"count":1}]	17163	delivery	5	14
43294	2020-03-26 14:42:33	2020-03-26	17	[{"id_menu":5,"count":3},{"id_menu":7,"count":1}]	17272	delivery	5	22
43295	2020-03-26 14:51:01	2020-03-26	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13437	delivery	5	53
43296	2020-03-26 14:52:44	2020-03-26	14	[{"id_menu":2,"count":1}]	1140	pick-up	0	14
43297	2020-03-26 15:00:17	2020-03-26	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	17248	delivery	5	22
43298	2020-03-26 15:05:25	2020-03-26	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16883	pick-up	0	38
43299	2020-03-26 15:05:49	2020-03-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2875	pick-up	0	21
43300	2020-03-26 15:06:43	2020-03-26	17	[{"id_menu":4,"count":1}]	4605	delivery	5	22
43301	2020-03-26 15:11:05	2020-03-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17267	delivery	5	31
43302	2020-03-26 15:25:30	2020-03-26	17	[{"id_menu":4,"count":1}]	10097	pick-up	0	17
43303	2020-03-26 15:26:03	2020-03-26	9	[{"id_menu":7,"count":1}]	4996	delivery	5	14
43304	2020-03-26 15:29:13	2020-03-26	17	[{"id_menu":4,"count":1}]	2447	pick-up	0	17
43305	2020-03-26 15:29:22	2020-03-26	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10375	delivery	5	31
43306	2020-03-26 15:38:26	2020-03-26	14	[{"id_menu":2,"count":1}]	924	pick-up	0	14
43307	2020-03-26 15:42:27	2020-03-26	12	[{"id_menu":3,"count":1}]	2252	pick-up	0	12
43308	2020-03-26 15:56:32	2020-03-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	8240	delivery	5	26
43309	2020-03-26 16:03:45	2020-03-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	8305	delivery	5	26
43310	2020-03-26 16:11:50	2020-03-26	9	[{"id_menu":6,"count":1}]	17179	delivery	5	14
43311	2020-03-26 16:13:20	2020-03-26	9	[{"id_menu":7,"count":1}]	8281	delivery	5	14
43312	2020-03-26 16:14:59	2020-03-26	8	[{"id_menu":5,"count":1}]	17242	delivery	5	13
43313	2020-03-26 16:16:58	2020-03-26	8	[{"id_menu":5,"count":1}]	17252	delivery	5	13
43314	2020-03-26 16:20:08	2020-03-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	15114	delivery	5	22
43315	2020-03-26 16:22:47	2020-03-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1991	delivery	5	28
43316	2020-03-26 16:23:04	2020-03-26	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	9295	pick-up	0	21
43317	2020-03-26 16:23:47	2020-03-26	9	[{"id_menu":6,"count":1}]	5227	delivery	5	14
43318	2020-03-26 16:38:51	2020-03-26	9	[{"id_menu":6,"count":1}]	17162	delivery	5	14
43319	2020-03-26 16:50:55	2020-03-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15213	delivery	5	22
43320	2020-03-26 16:54:46	2020-03-26	14	[{"id_menu":2,"count":1}]	13154	delivery	5	19
43321	2020-03-26 16:58:52	2020-03-26	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	13775	delivery	5	34
43322	2020-03-26 17:00:09	2020-03-26	9	[{"id_menu":6,"count":1}]	17045	delivery	5	14
43323	2020-03-26 17:09:47	2020-03-26	9	[{"id_menu":6,"count":1}]	4845	delivery	5	14
43324	2020-03-26 17:11:43	2020-03-26	9	[{"id_menu":6,"count":1}]	17145	pick-up	0	9
43325	2020-03-26 17:12:06	2020-03-26	14	[{"id_menu":2,"count":1}]	905	pick-up	0	14
43326	2020-03-26 17:15:32	2020-03-26	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	9144	delivery	5	26
43327	2020-03-26 17:15:39	2020-03-26	9	[{"id_menu":6,"count":1}]	16217	pick-up	0	9
43328	2020-03-26 17:19:59	2020-03-26	17	[{"id_menu":4,"count":1}]	16422	delivery	5	22
43329	2020-03-26 17:21:33	2020-03-26	17	[{"id_menu":4,"count":2}]	5928	delivery	5	22
43330	2020-03-26 17:23:12	2020-03-26	14	[{"id_menu":2,"count":1}]	2907	pick-up	0	14
43331	2020-03-26 17:28:06	2020-03-26	8	[{"id_menu":5,"count":1}]	17273	delivery	5	13
43332	2020-03-26 17:28:42	2020-03-26	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	17258	delivery	5	34
43333	2020-03-26 17:29:39	2020-03-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	10180	delivery	5	28
43334	2020-03-26 17:29:49	2020-03-26	9	[{"id_menu":6,"count":1}]	17146	delivery	5	14
43335	2020-03-26 17:46:09	2020-03-26	17	[{"id_menu":4,"count":1}]	17182	delivery	5	22
43336	2020-03-26 17:47:46	2020-03-26	12	[{"id_menu":3,"count":1}]	16710	pick-up	0	12
43337	2020-03-26 17:53:32	2020-03-26	12	[{"id_menu":3,"count":1}]	1406	pick-up	0	12
43338	2020-03-26 17:57:52	2020-03-26	12	[{"id_menu":1,"count":1}]	17247	pick-up	0	12
43339	2020-03-26 18:01:15	2020-03-26	12	[{"id_menu":3,"count":2}]	11334	pick-up	0	12
43340	2020-03-26 18:06:16	2020-03-26	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	7702	delivery	5	28
43341	2020-03-26 18:12:25	2020-03-26	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12242	delivery	5	37
43342	2020-03-26 18:18:51	2020-03-26	9	[{"id_menu":7,"count":1}]	17262	delivery	5	14
43343	2020-03-26 18:30:55	2020-03-26	9	[{"id_menu":7,"count":1}]	14480	pick-up	0	9
43344	2020-03-26 18:32:07	2020-03-26	17	[{"id_menu":4,"count":1}]	3268	pick-up	0	17
43345	2020-03-26 18:34:03	2020-03-26	9	[{"id_menu":7,"count":1}]	189	delivery	5	14
43346	2020-03-26 18:39:06	2020-03-26	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	17196	delivery	5	38
43347	2020-03-26 18:41:04	2020-03-26	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":2}]	11101	delivery	5	22
43348	2020-03-26 18:43:19	2020-03-26	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	17235	pick-up	0	38
43349	2020-03-26 18:49:15	2020-03-26	8	[{"id_menu":5,"count":1}]	390	pick-up	0	8
43350	2020-03-26 18:49:21	2020-03-26	9	[{"id_menu":6,"count":1}]	3372	pick-up	0	9
43351	2020-03-26 18:55:15	2020-03-26	9	[{"id_menu":6,"count":1}]	16737	pick-up	0	9
43352	2020-03-26 19:02:54	2020-03-26	9	[{"id_menu":7,"count":1}]	1497	pick-up	0	9
43353	2020-03-26 19:06:36	2020-03-26	9	[{"id_menu":7,"count":1}]	3614	pick-up	0	9
43354	2020-03-26 19:06:56	2020-03-26	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11519	pick-up	0	29
43355	2020-03-26 19:20:44	2020-03-26	17	[{"id_menu":4,"count":1}]	17260	delivery	5	22
43356	2020-03-26 19:21:19	2020-03-26	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	11183	delivery	5	31
43357	2020-03-26 19:34:45	2020-03-26	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	17203	delivery	5	34
43358	2020-03-26 19:39:27	2020-03-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3010	pick-up	0	23
43359	2020-03-26 19:45:20	2020-03-26	14	[{"id_menu":2,"count":1}]	16810	pick-up	0	14
43360	2020-03-26 19:53:33	2020-03-26	8	[{"id_menu":5,"count":1}]	3213	delivery	5	13
43361	2020-03-26 19:58:49	2020-03-26	12	[{"id_menu":1,"count":1}]	14735	pick-up	0	12
43362	2020-03-26 20:06:00	2020-03-26	9	[{"id_menu":6,"count":1}]	17276	delivery	5	14
43363	2020-03-26 20:11:34	2020-03-26	8	[{"id_menu":5,"count":1}]	17257	delivery	5	13
43364	2020-03-26 20:19:01	2020-03-26	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	11543	delivery	5	40
43365	2020-03-26 20:19:59	2020-03-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	14926	delivery	5	26
43366	2020-03-26 20:31:30	2020-03-26	9	[{"id_menu":7,"count":1}]	6452	delivery	5	14
43367	2020-03-26 20:34:56	2020-03-26	12	[{"id_menu":3,"count":1}]	17226	delivery	5	17
43368	2020-03-26 20:35:56	2020-03-26	9	[{"id_menu":6,"count":1}]	17068	delivery	5	14
43369	2020-03-26 20:38:16	2020-03-26	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	14475	delivery	5	46
43370	2020-03-26 20:38:33	2020-03-26	9	[{"id_menu":7,"count":1}]	17224	delivery	5	14
43371	2020-03-26 20:50:23	2020-03-26	8	[{"id_menu":5,"count":1}]	17204	delivery	5	13
43372	2020-03-26 20:56:10	2020-03-26	8	[{"id_menu":5,"count":1}]	7837	delivery	5	13
43373	2020-03-26 21:00:30	2020-03-26	8	[{"id_menu":5,"count":1}]	17181	delivery	5	13
43374	2020-03-26 21:05:58	2020-03-26	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	8065	delivery	5	36
43375	2020-03-26 21:09:30	2020-03-26	9	[{"id_menu":7,"count":1}]	5073	delivery	5	14
43376	2020-03-26 21:11:46	2020-03-26	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	17154	delivery	5	34
43377	2020-03-26 21:16:27	2020-03-26	12	[{"id_menu":1,"count":1}]	6729	delivery	5	17
43378	2020-03-26 21:17:28	2020-03-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	1582	pick-up	0	21
43379	2020-03-26 21:19:36	2020-03-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5094	pick-up	0	23
43380	2020-03-26 21:22:36	2020-03-26	8	[{"id_menu":5,"count":2}]	17220	delivery	5	13
43381	2020-03-26 21:23:20	2020-03-26	9	[{"id_menu":7,"count":1}]	8034	delivery	5	14
43382	2020-03-26 21:24:23	2020-03-26	9	[{"id_menu":7,"count":1}]	11135	delivery	5	14
43383	2020-03-26 21:29:22	2020-03-26	14	[{"id_menu":2,"count":1}]	2004	pick-up	0	14
43384	2020-03-26 21:31:16	2020-03-26	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	17237	delivery	5	25
43385	2020-03-26 21:32:02	2020-03-26	8	[{"id_menu":5,"count":1}]	6638	delivery	5	13
43386	2020-03-26 21:43:26	2020-03-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13370	pick-up	0	18
43387	2020-03-26 21:43:28	2020-03-26	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	898	pick-up	0	26
43388	2020-03-26 21:49:18	2020-03-26	9	[{"id_menu":6,"count":1}]	1746	pick-up	0	9
43389	2020-03-26 21:52:54	2020-03-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	15449	pick-up	0	23
43390	2020-03-26 21:59:51	2020-03-26	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16789	delivery	5	43
43391	2020-03-26 22:01:14	2020-03-26	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	3530	delivery	5	25
43392	2020-03-26 22:06:54	2020-03-26	12	[{"id_menu":1,"count":1}]	15482	pick-up	0	12
43393	2020-03-26 22:11:11	2020-03-26	8	[{"id_menu":5,"count":1}]	11012	delivery	5	13
43394	2020-03-26 22:19:47	2020-03-26	12	[{"id_menu":3,"count":1}]	17209	pick-up	0	12
43395	2020-03-26 22:20:45	2020-03-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9020	pick-up	0	23
43396	2020-03-26 22:21:05	2020-03-26	12	[{"id_menu":3,"count":1}]	9104	pick-up	0	12
43397	2020-03-26 22:31:09	2020-03-26	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10145	delivery	5	43
43398	2020-03-26 22:42:06	2020-03-26	9	[{"id_menu":6,"count":1}]	4445	pick-up	0	9
43399	2020-03-26 22:42:41	2020-03-26	14	[{"id_menu":2,"count":2}]	10988	pick-up	0	14
43400	2020-03-26 22:47:15	2020-03-26	12	[{"id_menu":1,"count":1}]	9065	delivery	5	17
43401	2020-03-26 22:49:28	2020-03-26	14	[{"id_menu":2,"count":1}]	16571	delivery	5	19
43402	2020-03-26 22:49:47	2020-03-26	12	[{"id_menu":1,"count":1}]	17233	delivery	5	17
43403	2020-03-26 22:57:36	2020-03-26	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	15864	pick-up	0	21
43404	2020-03-26 22:59:42	2020-03-26	14	[{"id_menu":2,"count":2}]	17184	delivery	5	19
43405	2020-03-26 23:13:09	2020-03-26	12	[{"id_menu":1,"count":2}]	11640	delivery	5	17
43406	2020-03-26 23:16:45	2020-03-26	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	2706	delivery	5	28
43407	2020-03-26 23:24:03	2020-03-26	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	17185	delivery	5	25
43408	2020-03-26 23:26:16	2020-03-26	12	[{"id_menu":3,"count":1}]	11863	delivery	5	17
43409	2020-03-26 23:32:43	2020-03-26	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17174	pick-up	0	49
43410	2020-03-26 23:32:56	2020-03-26	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3638	delivery	5	26
43411	2020-03-26 23:41:01	2020-03-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	17240	delivery	5	22
43412	2020-03-26 23:45:11	2020-03-26	8	[{"id_menu":5,"count":1}]	17259	delivery	5	13
43413	2020-03-26 23:52:27	2020-03-26	41	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	12231	delivery	5	46
43414	2020-03-26 23:53:38	2020-03-26	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2599	pick-up	0	26
43415	2020-03-26 23:54:09	2020-03-26	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12999	delivery	5	39
43416	2020-03-27 00:00:23	2020-03-27	14	[{"id_menu":2,"count":1}]	17288	delivery	5	19
43417	2020-03-27 00:03:46	2020-03-27	9	[{"id_menu":6,"count":1}]	5930	delivery	5	14
43418	2020-03-27 00:06:51	2020-03-27	17	[{"id_menu":4,"count":1}]	15777	delivery	5	22
43419	2020-03-27 00:07:48	2020-03-27	12	[{"id_menu":3,"count":1}]	12053	delivery	5	17
43420	2020-03-27 00:10:42	2020-03-27	8	[{"id_menu":5,"count":1}]	10022	delivery	5	13
43421	2020-03-27 00:14:45	2020-03-27	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2850	pick-up	0	21
43422	2020-03-27 00:31:37	2020-03-27	14	[{"id_menu":2,"count":1}]	1208	pick-up	0	14
43423	2020-03-27 00:38:12	2020-03-27	9	[{"id_menu":6,"count":1}]	10618	delivery	5	14
43424	2020-03-27 00:39:39	2020-03-27	17	[{"id_menu":4,"count":1}]	7880	pick-up	0	17
43425	2020-03-27 00:40:53	2020-03-27	9	[{"id_menu":7,"count":1}]	17412	delivery	5	14
43426	2020-03-27 00:53:39	2020-03-27	8	[{"id_menu":5,"count":1}]	16569	delivery	5	13
43427	2020-03-27 00:59:15	2020-03-27	14	[{"id_menu":2,"count":1}]	6916	pick-up	0	14
43428	2020-03-27 01:00:14	2020-03-27	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	17329	delivery	5	26
43429	2020-03-27 01:08:49	2020-03-27	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17411	delivery	5	36
43430	2020-03-27 01:14:33	2020-03-27	9	[{"id_menu":7,"count":1}]	17337	delivery	5	14
43431	2020-03-27 01:24:22	2020-03-27	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16407	delivery	5	48
43432	2020-03-27 01:26:22	2020-03-27	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17353	delivery	5	31
43433	2020-03-27 01:27:26	2020-03-27	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	640	pick-up	0	29
43434	2020-03-27 01:29:48	2020-03-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17327	delivery	5	22
43435	2020-03-27 01:33:26	2020-03-27	12	[{"id_menu":3,"count":1}]	17317	pick-up	0	12
43436	2020-03-27 01:37:32	2020-03-27	9	[{"id_menu":6,"count":1}]	12191	delivery	5	14
43437	2020-03-27 01:41:08	2020-03-27	9	[{"id_menu":6,"count":1}]	17378	delivery	5	14
43438	2020-03-27 01:41:48	2020-03-27	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17368	pick-up	0	26
43439	2020-03-27 01:48:45	2020-03-27	14	[{"id_menu":2,"count":1}]	2381	delivery	5	19
43440	2020-03-27 01:55:05	2020-03-27	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11346	delivery	5	37
43441	2020-03-27 01:59:17	2020-03-27	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	15449	delivery	5	40
43442	2020-03-27 02:01:12	2020-03-27	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	9106	pick-up	0	29
43443	2020-03-27 02:06:30	2020-03-27	14	[{"id_menu":2,"count":2}]	4992	pick-up	0	14
43444	2020-03-27 02:08:05	2020-03-27	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4949	delivery	5	54
43445	2020-03-27 02:20:30	2020-03-27	14	[{"id_menu":2,"count":1}]	3168	pick-up	0	14
43446	2020-03-27 02:21:42	2020-03-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6987	pick-up	0	18
43447	2020-03-27 02:22:45	2020-03-27	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	17385	delivery	5	23
43448	2020-03-27 02:23:39	2020-03-27	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4307	delivery	5	45
43449	2020-03-27 02:25:01	2020-03-27	17	[{"id_menu":4,"count":1}]	1222	pick-up	0	17
43450	2020-03-27 02:44:54	2020-03-27	8	[{"id_menu":5,"count":1}]	2633	delivery	5	13
43451	2020-03-27 02:46:14	2020-03-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9964	delivery	5	22
43452	2020-03-27 02:53:02	2020-03-27	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	17404	delivery	5	26
43453	2020-03-27 02:55:40	2020-03-27	9	[{"id_menu":7,"count":1}]	17356	delivery	5	14
43454	2020-03-27 02:59:46	2020-03-27	14	[{"id_menu":2,"count":1}]	12338	pick-up	0	14
43455	2020-03-27 02:59:52	2020-03-27	9	[{"id_menu":6,"count":1}]	7849	delivery	5	14
43456	2020-03-27 03:00:20	2020-03-27	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17413	delivery	5	31
43457	2020-03-27 03:05:18	2020-03-27	14	[{"id_menu":2,"count":1}]	12355	delivery	5	19
43458	2020-03-27 03:06:32	2020-03-27	9	[{"id_menu":6,"count":1}]	17399	pick-up	0	9
43459	2020-03-27 03:10:50	2020-03-27	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	17379	delivery	5	42
43460	2020-03-27 03:15:52	2020-03-27	9	[{"id_menu":7,"count":1}]	13050	pick-up	0	9
43461	2020-03-27 03:17:06	2020-03-27	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	14897	delivery	5	40
43462	2020-03-27 03:18:52	2020-03-27	9	[{"id_menu":7,"count":1}]	8866	delivery	5	14
43463	2020-03-27 03:22:14	2020-03-27	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	17428	delivery	5	38
43464	2020-03-27 03:22:26	2020-03-27	9	[{"id_menu":7,"count":1}]	14132	delivery	5	14
43465	2020-03-27 03:25:16	2020-03-27	12	[{"id_menu":3,"count":1}]	17393	delivery	5	17
43466	2020-03-27 03:28:01	2020-03-27	12	[{"id_menu":3,"count":1}]	4194	pick-up	0	12
43467	2020-03-27 03:31:26	2020-03-27	12	[{"id_menu":1,"count":1}]	5642	delivery	5	17
43468	2020-03-27 03:46:28	2020-03-27	9	[{"id_menu":6,"count":1}]	17313	delivery	5	14
43469	2020-03-27 03:47:52	2020-03-27	9	[{"id_menu":7,"count":1}]	17287	delivery	5	14
43470	2020-03-27 03:48:54	2020-03-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	17420	delivery	5	23
43471	2020-03-27 04:00:37	2020-03-27	8	[{"id_menu":5,"count":1}]	13015	delivery	5	13
43472	2020-03-27 04:05:24	2020-03-27	17	[{"id_menu":4,"count":1}]	17309	delivery	5	22
43473	2020-03-27 04:11:02	2020-03-27	12	[{"id_menu":3,"count":1}]	1970	delivery	5	17
43474	2020-03-27 04:13:53	2020-03-27	14	[{"id_menu":2,"count":1}]	17365	pick-up	0	14
43475	2020-03-27 04:15:38	2020-03-27	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11480	delivery	5	54
43476	2020-03-27 04:18:15	2020-03-27	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	16363	delivery	5	26
43477	2020-03-27 04:18:20	2020-03-27	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	17394	delivery	5	40
43478	2020-03-27 04:24:05	2020-03-27	17	[{"id_menu":4,"count":1}]	17358	delivery	5	22
43479	2020-03-27 04:25:19	2020-03-27	12	[{"id_menu":3,"count":1}]	2889	pick-up	0	12
43480	2020-03-27 04:29:26	2020-03-27	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	17396	delivery	5	22
43481	2020-03-27 04:33:06	2020-03-27	9	[{"id_menu":6,"count":1}]	3349	pick-up	0	9
43482	2020-03-27 04:33:13	2020-03-27	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17314	delivery	5	40
43483	2020-03-27 04:34:59	2020-03-27	17	[{"id_menu":4,"count":1}]	12027	delivery	5	22
43484	2020-03-27 04:44:34	2020-03-27	14	[{"id_menu":2,"count":1}]	17389	delivery	5	19
43485	2020-03-27 04:48:19	2020-03-27	12	[{"id_menu":3,"count":1}]	1354	delivery	5	17
43486	2020-03-27 04:50:05	2020-03-27	9	[{"id_menu":6,"count":1}]	17295	pick-up	0	9
43487	2020-03-27 04:53:30	2020-03-27	9	[{"id_menu":7,"count":1}]	5674	delivery	5	14
43488	2020-03-27 05:12:28	2020-03-27	9	[{"id_menu":6,"count":1}]	17376	delivery	5	14
43489	2020-03-27 05:14:47	2020-03-27	12	[{"id_menu":3,"count":1}]	17298	pick-up	0	12
43490	2020-03-27 05:15:14	2020-03-27	9	[{"id_menu":6,"count":1}]	17417	delivery	5	14
43491	2020-03-27 05:20:35	2020-03-27	12	[{"id_menu":3,"count":1}]	10264	pick-up	0	12
43492	2020-03-27 05:20:50	2020-03-27	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17296	delivery	5	22
43493	2020-03-27 05:21:44	2020-03-27	17	[{"id_menu":4,"count":1}]	10075	delivery	5	22
43494	2020-03-27 05:30:13	2020-03-27	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5035	pick-up	0	35
43495	2020-03-27 05:31:28	2020-03-27	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5229	delivery	5	31
43496	2020-03-27 05:32:39	2020-03-27	9	[{"id_menu":6,"count":1}]	17422	delivery	5	14
43497	2020-03-27 05:37:48	2020-03-27	14	[{"id_menu":2,"count":1}]	7566	pick-up	0	14
43498	2020-03-27 05:38:20	2020-03-27	9	[{"id_menu":7,"count":1}]	17324	delivery	5	14
43499	2020-03-27 05:39:35	2020-03-27	14	[{"id_menu":2,"count":1}]	15949	delivery	5	19
43500	2020-03-27 05:48:30	2020-03-27	9	[{"id_menu":6,"count":1}]	2583	delivery	5	14
43501	2020-03-27 06:00:31	2020-03-27	12	[{"id_menu":1,"count":1}]	7010	pick-up	0	12
43502	2020-03-27 06:03:12	2020-03-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4735	pick-up	0	17
43503	2020-03-27 06:06:20	2020-03-27	9	[{"id_menu":6,"count":1}]	10258	pick-up	0	9
43504	2020-03-27 06:06:25	2020-03-27	8	[{"id_menu":5,"count":1}]	4170	pick-up	0	8
43505	2020-03-27 06:10:08	2020-03-27	8	[{"id_menu":5,"count":2}]	10176	delivery	5	13
43506	2020-03-27 06:11:13	2020-03-27	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	17328	pick-up	0	29
43507	2020-03-27 06:13:14	2020-03-27	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17357	delivery	5	43
43508	2020-03-27 06:13:52	2020-03-27	8	[{"id_menu":5,"count":1}]	16128	delivery	5	13
43509	2020-03-27 06:18:57	2020-03-27	14	[{"id_menu":2,"count":1}]	768	delivery	5	19
43510	2020-03-27 06:28:41	2020-03-27	17	[{"id_menu":4,"count":2}]	14127	delivery	5	22
43511	2020-03-27 06:31:55	2020-03-27	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	8211	delivery	5	31
43512	2020-03-27 06:42:06	2020-03-27	17	[{"id_menu":4,"count":1}]	781	pick-up	0	17
43513	2020-03-27 06:47:53	2020-03-27	14	[{"id_menu":2,"count":1}]	17383	delivery	5	19
43514	2020-03-27 06:48:45	2020-03-27	8	[{"id_menu":5,"count":1}]	5213	delivery	5	13
43515	2020-03-27 06:51:19	2020-03-27	9	[{"id_menu":6,"count":2}]	15079	delivery	5	14
43516	2020-03-27 06:54:03	2020-03-27	14	[{"id_menu":2,"count":1}]	2520	pick-up	0	14
43517	2020-03-27 07:03:02	2020-03-27	9	[{"id_menu":7,"count":1}]	21	pick-up	0	9
43518	2020-03-27 07:07:49	2020-03-27	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	9541	pick-up	0	21
43519	2020-03-27 07:12:47	2020-03-27	9	[{"id_menu":6,"count":1}]	11215	delivery	5	14
43520	2020-03-27 07:14:46	2020-03-27	9	[{"id_menu":7,"count":1}]	17424	pick-up	0	9
43521	2020-03-27 07:15:44	2020-03-27	17	[{"id_menu":4,"count":1}]	17402	pick-up	0	17
43522	2020-03-27 07:16:31	2020-03-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	17390	delivery	5	28
43523	2020-03-27 07:18:46	2020-03-27	9	[{"id_menu":6,"count":1}]	12378	delivery	5	14
43524	2020-03-27 07:35:51	2020-03-27	9	[{"id_menu":6,"count":1}]	9153	delivery	5	14
43525	2020-03-27 07:38:09	2020-03-27	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13240	delivery	5	51
43526	2020-03-27 07:38:17	2020-03-27	12	[{"id_menu":1,"count":1}]	17316	delivery	5	17
43527	2020-03-27 07:42:00	2020-03-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	17312	delivery	5	28
43528	2020-03-27 07:44:02	2020-03-27	17	[{"id_menu":4,"count":1}]	17348	delivery	5	22
43529	2020-03-27 07:45:08	2020-03-27	9	[{"id_menu":7,"count":1}]	1239	pick-up	0	9
43530	2020-03-27 07:46:41	2020-03-27	17	[{"id_menu":4,"count":1}]	2623	pick-up	0	17
43531	2020-03-27 07:49:17	2020-03-27	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	17366	delivery	5	28
43532	2020-03-27 07:53:18	2020-03-27	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":3}]	776	delivery	5	26
43533	2020-03-27 07:55:38	2020-03-27	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14680	delivery	5	39
43534	2020-03-27 07:56:41	2020-03-27	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	17307	delivery	5	30
43535	2020-03-27 08:00:02	2020-03-27	9	[{"id_menu":6,"count":1}]	9141	delivery	5	14
43536	2020-03-27 08:01:06	2020-03-27	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	3054	pick-up	0	21
43537	2020-03-27 08:02:45	2020-03-27	14	[{"id_menu":2,"count":1}]	16442	pick-up	0	14
43538	2020-03-27 08:03:24	2020-03-27	8	[{"id_menu":5,"count":1}]	17374	delivery	5	13
43539	2020-03-27 08:21:47	2020-03-27	17	[{"id_menu":4,"count":1}]	17352	pick-up	0	17
43540	2020-03-27 08:22:18	2020-03-27	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	17304	delivery	5	40
43541	2020-03-27 08:26:17	2020-03-27	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8448	pick-up	0	26
43542	2020-03-27 08:29:50	2020-03-27	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17355	delivery	5	31
43543	2020-03-27 08:37:47	2020-03-27	9	[{"id_menu":7,"count":2}]	7293	delivery	5	14
43544	2020-03-27 08:40:50	2020-03-27	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	13432	delivery	5	28
43545	2020-03-27 08:42:23	2020-03-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	17323	delivery	5	28
43546	2020-03-27 08:45:59	2020-03-27	8	[{"id_menu":5,"count":1}]	17363	delivery	5	13
43547	2020-03-27 08:53:33	2020-03-27	12	[{"id_menu":3,"count":1}]	17340	delivery	5	17
43548	2020-03-27 09:01:13	2020-03-27	8	[{"id_menu":5,"count":1}]	540	delivery	5	13
43549	2020-03-27 09:11:40	2020-03-27	12	[{"id_menu":3,"count":1}]	17294	delivery	5	17
43550	2020-03-27 09:16:53	2020-03-27	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	17330	delivery	5	29
43551	2020-03-27 09:20:09	2020-03-27	9	[{"id_menu":6,"count":1}]	7856	delivery	5	14
43552	2020-03-27 09:30:23	2020-03-27	9	[{"id_menu":6,"count":2}]	17297	delivery	5	14
43553	2020-03-27 09:40:22	2020-03-27	14	[{"id_menu":2,"count":2}]	2619	delivery	5	19
43554	2020-03-27 09:40:25	2020-03-27	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	17414	delivery	5	40
43555	2020-03-27 09:47:59	2020-03-27	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12367	pick-up	0	26
43556	2020-03-27 09:53:19	2020-03-27	9	[{"id_menu":7,"count":1}]	15418	delivery	5	14
43557	2020-03-27 10:07:28	2020-03-27	9	[{"id_menu":7,"count":1}]	17286	delivery	5	14
43558	2020-03-27 10:19:44	2020-03-27	9	[{"id_menu":6,"count":2}]	16536	delivery	5	14
43559	2020-03-27 10:29:33	2020-03-27	8	[{"id_menu":5,"count":2}]	4235	delivery	5	13
43560	2020-03-27 10:38:06	2020-03-27	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	6894	delivery	5	29
43561	2020-03-27 10:43:18	2020-03-27	12	[{"id_menu":3,"count":1}]	15902	delivery	5	17
43562	2020-03-27 10:45:42	2020-03-27	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	6914	delivery	5	40
43563	2020-03-27 10:45:49	2020-03-27	17	[{"id_menu":4,"count":1}]	16469	pick-up	0	17
43564	2020-03-27 10:46:14	2020-03-27	8	[{"id_menu":5,"count":1}]	9092	delivery	5	13
43565	2020-03-27 10:46:48	2020-03-27	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	3811	delivery	5	22
43566	2020-03-27 11:06:32	2020-03-27	17	[{"id_menu":4,"count":1}]	10793	pick-up	0	17
43567	2020-03-27 11:25:44	2020-03-27	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	17388	delivery	5	29
43568	2020-03-27 11:27:19	2020-03-27	43	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7542	delivery	5	48
43569	2020-03-27 11:29:44	2020-03-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17409	delivery	5	22
43570	2020-03-27 11:35:06	2020-03-27	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6202	pick-up	0	25
43571	2020-03-27 11:41:02	2020-03-27	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17282	delivery	5	34
43572	2020-03-27 11:46:01	2020-03-27	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	17387	delivery	5	36
43573	2020-03-27 11:51:56	2020-03-27	9	[{"id_menu":7,"count":1}]	17310	delivery	5	14
43574	2020-03-27 12:04:45	2020-03-27	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	13413	delivery	5	26
43575	2020-03-27 12:19:54	2020-03-27	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17326	delivery	5	36
43576	2020-03-27 12:20:23	2020-03-27	9	[{"id_menu":6,"count":1}]	13547	pick-up	0	9
43577	2020-03-27 12:22:17	2020-03-27	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	7428	delivery	5	34
43578	2020-03-27 12:46:30	2020-03-27	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10651	delivery	5	22
43579	2020-03-27 12:57:22	2020-03-27	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17382	delivery	5	39
43580	2020-03-27 12:58:18	2020-03-27	8	[{"id_menu":5,"count":1}]	8812	delivery	5	13
43581	2020-03-27 13:05:36	2020-03-27	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	413	pick-up	0	24
43582	2020-03-27 13:07:09	2020-03-27	8	[{"id_menu":5,"count":1}]	17322	delivery	5	13
43583	2020-03-27 13:07:44	2020-03-27	14	[{"id_menu":2,"count":1}]	13735	delivery	5	19
43584	2020-03-27 13:08:23	2020-03-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	433	pick-up	0	17
43585	2020-03-27 13:12:58	2020-03-27	12	[{"id_menu":1,"count":1}]	5531	delivery	5	17
43586	2020-03-27 13:16:28	2020-03-27	14	[{"id_menu":2,"count":1}]	10828	pick-up	0	14
43587	2020-03-27 13:19:49	2020-03-27	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	17400	delivery	5	31
43588	2020-03-27 13:25:53	2020-03-27	12	[{"id_menu":3,"count":1}]	709	pick-up	0	12
43589	2020-03-27 13:26:17	2020-03-27	12	[{"id_menu":1,"count":1}]	17315	pick-up	0	12
43590	2020-03-27 13:34:57	2020-03-27	9	[{"id_menu":6,"count":1}]	16295	delivery	5	14
43591	2020-03-27 13:36:50	2020-03-27	12	[{"id_menu":1,"count":1}]	17349	delivery	5	17
43592	2020-03-27 13:38:08	2020-03-27	8	[{"id_menu":5,"count":1}]	2860	delivery	5	13
43593	2020-03-27 13:41:47	2020-03-27	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	17360	delivery	5	34
43594	2020-03-27 13:51:15	2020-03-27	17	[{"id_menu":4,"count":1}]	17319	delivery	5	22
43595	2020-03-27 13:56:53	2020-03-27	14	[{"id_menu":2,"count":1}]	9103	delivery	5	19
43596	2020-03-27 13:57:04	2020-03-27	14	[{"id_menu":2,"count":1}]	6413	delivery	5	19
43597	2020-03-27 14:05:57	2020-03-27	12	[{"id_menu":1,"count":1}]	352	delivery	5	17
43598	2020-03-27 14:21:34	2020-03-27	9	[{"id_menu":7,"count":1}]	6990	pick-up	0	9
43599	2020-03-27 14:23:35	2020-03-27	14	[{"id_menu":2,"count":1}]	17392	pick-up	0	14
43600	2020-03-27 14:32:55	2020-03-27	9	[{"id_menu":7,"count":1}]	4411	pick-up	0	9
43601	2020-03-27 14:43:57	2020-03-27	12	[{"id_menu":3,"count":1}]	17384	delivery	5	17
43602	2020-03-27 14:51:54	2020-03-27	9	[{"id_menu":7,"count":1}]	17377	pick-up	0	9
43603	2020-03-27 14:52:53	2020-03-27	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1656	delivery	5	39
43604	2020-03-27 14:55:30	2020-03-27	17	[{"id_menu":4,"count":1}]	12532	delivery	5	22
43605	2020-03-27 14:57:16	2020-03-27	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	17333	delivery	5	30
43606	2020-03-27 15:08:38	2020-03-27	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4029	delivery	5	37
43607	2020-03-27 15:13:10	2020-03-27	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	17283	delivery	5	39
43608	2020-03-27 15:14:19	2020-03-27	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	17375	pick-up	0	26
43609	2020-03-27 15:19:55	2020-03-27	9	[{"id_menu":6,"count":3}]	17350	delivery	5	14
43610	2020-03-27 15:33:05	2020-03-27	17	[{"id_menu":4,"count":1}]	4846	pick-up	0	17
43611	2020-03-27 15:34:49	2020-03-27	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17285	delivery	5	40
43612	2020-03-27 15:40:21	2020-03-27	17	[{"id_menu":4,"count":1}]	12920	delivery	5	22
43613	2020-03-27 15:41:50	2020-03-27	9	[{"id_menu":6,"count":1}]	17416	delivery	5	14
43614	2020-03-27 15:42:07	2020-03-27	26	[{"id_menu":4,"count":3},{"id_menu":6,"count":1}]	3835	delivery	5	31
43615	2020-03-27 15:42:44	2020-03-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17346	delivery	5	23
43616	2020-03-27 15:43:18	2020-03-27	17	[{"id_menu":4,"count":1}]	17423	pick-up	0	17
43617	2020-03-27 15:46:19	2020-03-27	9	[{"id_menu":6,"count":1}]	17395	delivery	5	14
43618	2020-03-27 15:49:19	2020-03-27	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	518	delivery	5	23
43619	2020-03-27 15:59:56	2020-03-27	9	[{"id_menu":6,"count":1}]	4166	delivery	5	14
43620	2020-03-27 16:12:03	2020-03-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17336	delivery	5	22
43621	2020-03-27 16:15:48	2020-03-27	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11932	delivery	5	39
43622	2020-03-27 16:18:50	2020-03-27	9	[{"id_menu":6,"count":1}]	12690	pick-up	0	9
43623	2020-03-27 16:21:17	2020-03-27	9	[{"id_menu":7,"count":1}]	17343	delivery	5	14
43624	2020-03-27 16:21:50	2020-03-27	17	[{"id_menu":4,"count":1}]	3869	pick-up	0	17
43625	2020-03-27 16:26:43	2020-03-27	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	5298	delivery	5	43
43626	2020-03-27 16:30:03	2020-03-27	14	[{"id_menu":2,"count":1}]	13634	delivery	5	19
43627	2020-03-27 16:43:12	2020-03-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17370	delivery	5	22
43628	2020-03-27 16:50:24	2020-03-27	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11708	delivery	5	45
43629	2020-03-27 16:54:35	2020-03-27	17	[{"id_menu":4,"count":1}]	2264	pick-up	0	17
43630	2020-03-27 16:54:58	2020-03-27	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	4125	delivery	5	31
43631	2020-03-27 16:55:00	2020-03-27	9	[{"id_menu":6,"count":1}]	17361	delivery	5	14
43632	2020-03-27 16:57:33	2020-03-27	17	[{"id_menu":4,"count":1}]	4981	pick-up	0	17
43633	2020-03-27 16:59:39	2020-03-27	17	[{"id_menu":4,"count":1}]	4395	pick-up	0	17
43634	2020-03-27 17:01:28	2020-03-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2216	delivery	5	23
43635	2020-03-27 17:06:53	2020-03-27	8	[{"id_menu":5,"count":1}]	6617	pick-up	0	8
43636	2020-03-27 17:10:43	2020-03-27	9	[{"id_menu":6,"count":1}]	17426	delivery	5	14
43637	2020-03-27 17:24:07	2020-03-27	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	17334	delivery	5	22
43638	2020-03-27 17:28:44	2020-03-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17386	delivery	5	22
43639	2020-03-27 17:28:44	2020-03-27	14	[{"id_menu":2,"count":1}]	17391	delivery	5	19
43640	2020-03-27 17:41:44	2020-03-27	9	[{"id_menu":7,"count":1}]	17405	delivery	5	14
43641	2020-03-27 17:44:12	2020-03-27	12	[{"id_menu":1,"count":1}]	12059	delivery	5	17
43642	2020-03-27 17:54:04	2020-03-27	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	15773	delivery	5	26
43643	2020-03-27 17:58:46	2020-03-27	8	[{"id_menu":5,"count":1}]	17341	delivery	5	13
43644	2020-03-27 18:05:38	2020-03-27	17	[{"id_menu":4,"count":1}]	17364	delivery	5	22
43645	2020-03-27 18:07:26	2020-03-27	14	[{"id_menu":2,"count":1}]	10436	pick-up	0	14
43646	2020-03-27 18:10:45	2020-03-27	14	[{"id_menu":2,"count":1}]	17418	delivery	5	19
43647	2020-03-27 18:12:23	2020-03-27	17	[{"id_menu":4,"count":1}]	6247	pick-up	0	17
43648	2020-03-27 18:14:28	2020-03-27	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	12290	delivery	5	25
43649	2020-03-27 18:16:35	2020-03-27	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	8020	pick-up	0	21
43650	2020-03-27 18:18:50	2020-03-27	9	[{"id_menu":7,"count":1}]	8465	delivery	5	14
43651	2020-03-27 18:23:29	2020-03-27	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1118	pick-up	0	40
43652	2020-03-27 18:24:08	2020-03-27	8	[{"id_menu":5,"count":2}]	12098	delivery	5	13
43653	2020-03-27 18:30:38	2020-03-27	9	[{"id_menu":6,"count":2}]	17371	delivery	5	14
43654	2020-03-27 18:44:26	2020-03-27	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13518	delivery	5	43
43655	2020-03-27 18:53:54	2020-03-27	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	11172	delivery	5	31
43656	2020-03-27 18:58:53	2020-03-27	9	[{"id_menu":6,"count":1}]	7902	delivery	5	14
43657	2020-03-27 19:04:59	2020-03-27	9	[{"id_menu":6,"count":1}]	17306	pick-up	0	9
43658	2020-03-27 19:19:04	2020-03-27	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17293	delivery	5	51
43659	2020-03-27 19:23:09	2020-03-27	14	[{"id_menu":2,"count":2}]	14884	pick-up	0	14
43660	2020-03-27 19:25:14	2020-03-27	9	[{"id_menu":6,"count":1}]	17407	delivery	5	14
43661	2020-03-27 19:27:17	2020-03-27	9	[{"id_menu":6,"count":1}]	16717	delivery	5	14
43662	2020-03-27 19:29:21	2020-03-27	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11760	delivery	5	39
43663	2020-03-27 19:31:25	2020-03-27	9	[{"id_menu":7,"count":1}]	10423	delivery	5	14
43664	2020-03-27 19:34:52	2020-03-27	17	[{"id_menu":4,"count":1}]	17280	delivery	5	22
43665	2020-03-27 19:38:04	2020-03-27	9	[{"id_menu":6,"count":1}]	4130	pick-up	0	9
43666	2020-03-27 19:42:37	2020-03-27	12	[{"id_menu":3,"count":1}]	424	pick-up	0	12
43667	2020-03-27 19:45:03	2020-03-27	12	[{"id_menu":1,"count":1}]	17369	pick-up	0	12
43668	2020-03-27 19:55:29	2020-03-27	12	[{"id_menu":1,"count":1}]	14964	delivery	5	17
43669	2020-03-27 19:58:31	2020-03-27	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17318	delivery	5	43
43670	2020-03-27 20:03:17	2020-03-27	9	[{"id_menu":7,"count":1}]	1316	pick-up	0	9
43671	2020-03-27 20:08:14	2020-03-27	9	[{"id_menu":6,"count":1}]	242	pick-up	0	9
43672	2020-03-27 20:23:30	2020-03-27	8	[{"id_menu":5,"count":1}]	2484	pick-up	0	8
43673	2020-03-27 20:30:45	2020-03-27	14	[{"id_menu":2,"count":1}]	6591	delivery	5	19
43674	2020-03-27 20:31:13	2020-03-27	8	[{"id_menu":5,"count":1}]	5324	delivery	5	13
43675	2020-03-27 20:34:40	2020-03-27	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	688	delivery	5	34
43676	2020-03-27 20:42:13	2020-03-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12803	delivery	5	22
43677	2020-03-27 20:43:21	2020-03-27	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	5832	pick-up	0	21
43678	2020-03-27 20:44:29	2020-03-27	14	[{"id_menu":2,"count":1}]	15813	delivery	5	19
43679	2020-03-27 20:46:34	2020-03-27	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10306	delivery	5	31
43680	2020-03-27 20:56:25	2020-03-27	17	[{"id_menu":4,"count":1}]	4842	delivery	5	22
43681	2020-03-27 21:00:52	2020-03-27	9	[{"id_menu":6,"count":1}]	17011	delivery	5	14
43682	2020-03-27 21:12:49	2020-03-27	9	[{"id_menu":7,"count":1}]	17381	delivery	5	14
43683	2020-03-27 21:20:20	2020-03-27	14	[{"id_menu":2,"count":1}]	17415	pick-up	0	14
43684	2020-03-27 21:24:55	2020-03-27	12	[{"id_menu":1,"count":1}]	17291	delivery	5	17
43685	2020-03-27 21:27:20	2020-03-27	9	[{"id_menu":6,"count":1}]	12934	delivery	5	14
43686	2020-03-27 21:27:41	2020-03-27	9	[{"id_menu":6,"count":1}]	14011	delivery	5	14
43687	2020-03-27 21:28:53	2020-03-27	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17320	delivery	5	31
43688	2020-03-27 21:30:01	2020-03-27	8	[{"id_menu":5,"count":1}]	17351	pick-up	0	8
43689	2020-03-27 21:32:58	2020-03-27	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	7465	delivery	5	25
43690	2020-03-27 21:33:21	2020-03-27	14	[{"id_menu":2,"count":1}]	6074	pick-up	0	14
43691	2020-03-27 21:35:54	2020-03-27	9	[{"id_menu":7,"count":1}]	16643	delivery	5	14
43692	2020-03-27 21:37:19	2020-03-27	9	[{"id_menu":7,"count":1}]	17401	delivery	5	14
43693	2020-03-27 21:43:33	2020-03-27	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	8884	delivery	5	26
43694	2020-03-27 21:48:54	2020-03-27	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2477	delivery	5	53
43695	2020-03-27 21:50:36	2020-03-27	8	[{"id_menu":5,"count":1}]	7142	delivery	5	13
43696	2020-03-27 22:00:50	2020-03-27	14	[{"id_menu":2,"count":1}]	17373	delivery	5	19
43697	2020-03-27 22:12:24	2020-03-27	17	[{"id_menu":4,"count":1}]	15109	pick-up	0	17
43698	2020-03-27 22:13:09	2020-03-27	14	[{"id_menu":2,"count":1}]	1889	pick-up	0	14
43699	2020-03-27 22:13:13	2020-03-27	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	17325	delivery	5	48
43700	2020-03-27 22:24:09	2020-03-27	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	14523	delivery	5	28
43701	2020-03-27 22:24:40	2020-03-27	17	[{"id_menu":4,"count":1}]	9503	delivery	5	22
43702	2020-03-27 22:26:52	2020-03-27	9	[{"id_menu":7,"count":1}]	17359	delivery	5	14
43703	2020-03-27 22:29:05	2020-03-27	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":2}]	5165	delivery	5	28
43704	2020-03-27 22:30:59	2020-03-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2119	delivery	5	28
43705	2020-03-27 22:35:43	2020-03-27	9	[{"id_menu":7,"count":1}]	11348	delivery	5	14
43706	2020-03-27 22:37:27	2020-03-27	8	[{"id_menu":5,"count":1}]	17342	delivery	5	13
43707	2020-03-27 22:38:58	2020-03-27	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3788	pick-up	0	17
43708	2020-03-27 22:41:31	2020-03-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	17331	delivery	5	36
43709	2020-03-27 22:44:16	2020-03-27	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	17284	pick-up	0	21
43710	2020-03-27 22:44:25	2020-03-27	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1068	delivery	5	25
43711	2020-03-27 23:08:15	2020-03-27	14	[{"id_menu":2,"count":1}]	11131	pick-up	0	14
43712	2020-03-27 23:13:06	2020-03-27	12	[{"id_menu":1,"count":1}]	11407	pick-up	0	12
43713	2020-03-27 23:16:22	2020-03-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	15417	delivery	5	36
43714	2020-03-27 23:21:16	2020-03-27	12	[{"id_menu":1,"count":1}]	9053	pick-up	0	12
43715	2020-03-27 23:22:37	2020-03-27	17	[{"id_menu":4,"count":1}]	4600	delivery	5	22
43716	2020-03-27 23:36:41	2020-03-27	9	[{"id_menu":6,"count":1}]	17421	delivery	5	14
43717	2020-03-27 23:46:52	2020-03-27	14	[{"id_menu":2,"count":1}]	10209	delivery	5	19
43718	2020-03-27 23:52:19	2020-03-27	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	1689	delivery	5	26
43719	2020-03-27 23:55:13	2020-03-27	12	[{"id_menu":1,"count":1}]	13770	delivery	5	17
43720	2020-03-27 23:57:13	2020-03-27	14	[{"id_menu":2,"count":1}]	5120	delivery	5	19
43721	2020-03-28 00:05:03	2020-03-28	14	[{"id_menu":2,"count":1}]	9911	delivery	5	19
43722	2020-03-28 00:07:14	2020-03-28	9	[{"id_menu":6,"count":1}]	14244	delivery	5	14
43723	2020-03-28 00:09:29	2020-03-28	12	[{"id_menu":3,"count":1}]	2116	delivery	5	17
43724	2020-03-28 00:09:34	2020-03-28	17	[{"id_menu":4,"count":1}]	111	pick-up	0	17
43725	2020-03-28 00:12:11	2020-03-28	12	[{"id_menu":1,"count":1}]	17461	delivery	5	17
43726	2020-03-28 00:13:14	2020-03-28	9	[{"id_menu":7,"count":1}]	13209	delivery	5	14
43727	2020-03-28 00:17:50	2020-03-28	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	595	delivery	5	36
43728	2020-03-28 00:25:18	2020-03-28	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	17487	delivery	5	31
43729	2020-03-28 00:26:33	2020-03-28	12	[{"id_menu":3,"count":1}]	5293	pick-up	0	12
43730	2020-03-28 00:26:57	2020-03-28	8	[{"id_menu":5,"count":1}]	17220	delivery	5	13
43731	2020-03-28 00:28:10	2020-03-28	17	[{"id_menu":4,"count":1}]	6478	pick-up	0	17
43732	2020-03-28 00:30:07	2020-03-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17520	pick-up	0	17
43733	2020-03-28 00:31:00	2020-03-28	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17514	delivery	5	34
43734	2020-03-28 00:34:54	2020-03-28	9	[{"id_menu":6,"count":1}]	584	pick-up	0	9
43735	2020-03-28 00:38:55	2020-03-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7385	delivery	5	23
43736	2020-03-28 00:46:02	2020-03-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3227	pick-up	0	26
43737	2020-03-28 00:51:34	2020-03-28	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12313	delivery	5	31
43738	2020-03-28 00:53:52	2020-03-28	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2068	delivery	5	34
43739	2020-03-28 00:54:20	2020-03-28	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2780	pick-up	0	20
43740	2020-03-28 00:57:45	2020-03-28	8	[{"id_menu":5,"count":1}]	3010	pick-up	0	8
43741	2020-03-28 01:04:47	2020-03-28	12	[{"id_menu":3,"count":1}]	8397	delivery	5	17
43742	2020-03-28 01:06:33	2020-03-28	17	[{"id_menu":4,"count":1}]	7430	pick-up	0	17
43743	2020-03-28 01:10:57	2020-03-28	8	[{"id_menu":5,"count":1}]	17434	delivery	5	13
43744	2020-03-28 01:14:45	2020-03-28	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	7451	delivery	5	34
43745	2020-03-28 01:15:23	2020-03-28	9	[{"id_menu":6,"count":1}]	4871	delivery	5	14
43746	2020-03-28 01:17:29	2020-03-28	9	[{"id_menu":6,"count":1}]	16826	delivery	5	14
43747	2020-03-28 01:23:53	2020-03-28	9	[{"id_menu":7,"count":1}]	17532	delivery	5	14
43748	2020-03-28 01:24:50	2020-03-28	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	17528	delivery	5	43
43749	2020-03-28 01:26:17	2020-03-28	8	[{"id_menu":5,"count":1}]	3476	delivery	5	13
43750	2020-03-28 01:27:02	2020-03-28	9	[{"id_menu":6,"count":1}]	12676	delivery	5	14
43751	2020-03-28 01:30:11	2020-03-28	12	[{"id_menu":1,"count":1}]	5064	pick-up	0	12
43752	2020-03-28 01:31:56	2020-03-28	8	[{"id_menu":5,"count":1}]	15948	pick-up	0	8
43753	2020-03-28 01:32:33	2020-03-28	17	[{"id_menu":4,"count":1}]	17498	pick-up	0	17
43754	2020-03-28 01:33:27	2020-03-28	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	17499	delivery	5	36
43755	2020-03-28 01:43:22	2020-03-28	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	14954	delivery	5	52
43756	2020-03-28 01:45:09	2020-03-28	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6000	delivery	5	39
43757	2020-03-28 01:46:58	2020-03-28	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	17509	delivery	5	44
43758	2020-03-28 01:50:25	2020-03-28	9	[{"id_menu":6,"count":1}]	17563	delivery	5	14
43759	2020-03-28 01:51:28	2020-03-28	8	[{"id_menu":5,"count":1}]	17459	delivery	5	13
43760	2020-03-28 02:02:13	2020-03-28	12	[{"id_menu":3,"count":1}]	10151	pick-up	0	12
43761	2020-03-28 02:05:54	2020-03-28	17	[{"id_menu":4,"count":1}]	2420	pick-up	0	17
43762	2020-03-28 02:08:26	2020-03-28	9	[{"id_menu":6,"count":1}]	11550	delivery	5	14
43763	2020-03-28 02:13:02	2020-03-28	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	11360	delivery	5	42
43764	2020-03-28 02:15:52	2020-03-28	12	[{"id_menu":1,"count":1}]	10452	pick-up	0	12
43765	2020-03-28 02:19:13	2020-03-28	9	[{"id_menu":7,"count":1}]	562	delivery	5	14
43766	2020-03-28 02:22:06	2020-03-28	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	11756	delivery	5	34
43767	2020-03-28 02:28:03	2020-03-28	12	[{"id_menu":3,"count":1}]	17531	delivery	5	17
43768	2020-03-28 02:32:37	2020-03-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15609	delivery	5	31
43769	2020-03-28 02:38:12	2020-03-28	17	[{"id_menu":4,"count":1}]	4222	delivery	5	22
43770	2020-03-28 02:38:51	2020-03-28	12	[{"id_menu":3,"count":1}]	13568	delivery	5	17
43771	2020-03-28 02:43:34	2020-03-28	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16660	delivery	5	31
43772	2020-03-28 02:44:08	2020-03-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5950	delivery	5	23
43773	2020-03-28 02:50:13	2020-03-28	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14337	delivery	5	36
43774	2020-03-28 02:58:14	2020-03-28	12	[{"id_menu":1,"count":1}]	4094	pick-up	0	12
43775	2020-03-28 02:59:07	2020-03-28	14	[{"id_menu":2,"count":1}]	4411	pick-up	0	14
43776	2020-03-28 03:02:05	2020-03-28	17	[{"id_menu":4,"count":1}]	13930	pick-up	0	17
43777	2020-03-28 03:04:03	2020-03-28	9	[{"id_menu":7,"count":1}]	17440	delivery	5	14
43778	2020-03-28 03:05:30	2020-03-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7113	delivery	5	22
43779	2020-03-28 03:07:35	2020-03-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8139	delivery	5	31
43780	2020-03-28 03:10:23	2020-03-28	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17552	delivery	5	36
43781	2020-03-28 03:12:49	2020-03-28	9	[{"id_menu":6,"count":1}]	9995	delivery	5	14
43782	2020-03-28 03:13:51	2020-03-28	9	[{"id_menu":6,"count":1}]	6055	delivery	5	14
43783	2020-03-28 03:18:09	2020-03-28	12	[{"id_menu":3,"count":1}]	14593	pick-up	0	12
43784	2020-03-28 03:18:41	2020-03-28	12	[{"id_menu":3,"count":1}]	2789	delivery	5	17
43785	2020-03-28 03:23:37	2020-03-28	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	11973	delivery	5	36
43786	2020-03-28 03:24:44	2020-03-28	17	[{"id_menu":4,"count":1}]	17530	delivery	5	22
43787	2020-03-28 03:26:26	2020-03-28	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	10772	pick-up	0	29
43788	2020-03-28 03:29:33	2020-03-28	17	[{"id_menu":4,"count":1}]	3930	delivery	5	22
43789	2020-03-28 03:30:48	2020-03-28	9	[{"id_menu":6,"count":1}]	7957	pick-up	0	9
43790	2020-03-28 03:32:54	2020-03-28	14	[{"id_menu":2,"count":1}]	9475	pick-up	0	14
43791	2020-03-28 03:33:28	2020-03-28	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	15383	delivery	5	28
43792	2020-03-28 03:36:38	2020-03-28	8	[{"id_menu":5,"count":1}]	14207	delivery	5	13
43793	2020-03-28 03:41:00	2020-03-28	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	17500	pick-up	0	31
43794	2020-03-28 03:43:18	2020-03-28	17	[{"id_menu":4,"count":1}]	17486	delivery	5	22
43795	2020-03-28 03:49:31	2020-03-28	9	[{"id_menu":6,"count":3}]	17510	delivery	5	14
43796	2020-03-28 03:50:04	2020-03-28	12	[{"id_menu":1,"count":1}]	10828	pick-up	0	12
43797	2020-03-28 03:54:04	2020-03-28	9	[{"id_menu":7,"count":1}]	3711	delivery	5	14
43798	2020-03-28 03:58:51	2020-03-28	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	213	delivery	5	25
43799	2020-03-28 04:00:12	2020-03-28	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3093	delivery	5	34
43800	2020-03-28 04:02:36	2020-03-28	9	[{"id_menu":7,"count":1}]	5301	pick-up	0	9
43801	2020-03-28 04:03:41	2020-03-28	9	[{"id_menu":7,"count":1}]	12144	pick-up	0	9
43802	2020-03-28 04:04:48	2020-03-28	17	[{"id_menu":4,"count":1}]	2121	delivery	5	22
43803	2020-03-28 04:05:29	2020-03-28	8	[{"id_menu":5,"count":1}]	11053	delivery	5	13
43804	2020-03-28 04:06:35	2020-03-28	8	[{"id_menu":5,"count":1}]	12395	delivery	5	13
43805	2020-03-28 04:12:09	2020-03-28	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	9451	delivery	5	26
43806	2020-03-28 04:13:42	2020-03-28	14	[{"id_menu":2,"count":1}]	17458	delivery	5	19
43807	2020-03-28 04:20:26	2020-03-28	12	[{"id_menu":3,"count":1}]	11734	delivery	5	17
43808	2020-03-28 04:28:05	2020-03-28	12	[{"id_menu":1,"count":1}]	4193	pick-up	0	12
43809	2020-03-28 04:31:04	2020-03-28	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	9735	delivery	5	36
43810	2020-03-28 04:38:35	2020-03-28	12	[{"id_menu":1,"count":1}]	14252	delivery	5	17
43811	2020-03-28 04:40:20	2020-03-28	17	[{"id_menu":4,"count":1}]	14576	delivery	5	22
43812	2020-03-28 04:46:16	2020-03-28	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17545	delivery	5	34
43813	2020-03-28 04:46:31	2020-03-28	14	[{"id_menu":2,"count":1}]	15829	pick-up	0	14
43814	2020-03-28 04:47:20	2020-03-28	14	[{"id_menu":2,"count":1}]	10755	pick-up	0	14
43815	2020-03-28 04:47:43	2020-03-28	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	12327	delivery	5	27
43816	2020-03-28 05:00:25	2020-03-28	12	[{"id_menu":1,"count":1}]	17523	delivery	5	17
43817	2020-03-28 05:09:05	2020-03-28	17	[{"id_menu":4,"count":1}]	10447	delivery	5	22
43818	2020-03-28 05:10:12	2020-03-28	12	[{"id_menu":3,"count":1}]	17548	delivery	5	17
43819	2020-03-28 05:18:47	2020-03-28	9	[{"id_menu":6,"count":1}]	17452	delivery	5	14
43820	2020-03-28 05:21:16	2020-03-28	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	17553	delivery	5	44
43821	2020-03-28 05:21:36	2020-03-28	12	[{"id_menu":3,"count":1}]	1175	pick-up	0	12
43822	2020-03-28 05:23:40	2020-03-28	9	[{"id_menu":6,"count":1}]	8584	delivery	5	14
43823	2020-03-28 05:23:56	2020-03-28	12	[{"id_menu":3,"count":1}]	7383	delivery	5	17
43824	2020-03-28 05:25:39	2020-03-28	9	[{"id_menu":6,"count":1}]	6541	delivery	5	14
43825	2020-03-28 05:26:53	2020-03-28	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1820	delivery	5	26
43826	2020-03-28 05:31:27	2020-03-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3112	pick-up	0	23
43827	2020-03-28 05:37:23	2020-03-28	9	[{"id_menu":7,"count":1}]	17476	delivery	5	14
43828	2020-03-28 05:40:29	2020-03-28	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	14991	delivery	5	26
43829	2020-03-28 05:41:49	2020-03-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	16749	delivery	5	22
43830	2020-03-28 05:45:05	2020-03-28	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10462	delivery	5	31
43831	2020-03-28 05:46:46	2020-03-28	12	[{"id_menu":1,"count":1}]	17549	delivery	5	17
43832	2020-03-28 05:48:10	2020-03-28	14	[{"id_menu":2,"count":1}]	16236	delivery	5	19
43833	2020-03-28 05:58:51	2020-03-28	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	15159	delivery	5	26
43834	2020-03-28 06:00:17	2020-03-28	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17538	delivery	5	31
43835	2020-03-28 06:04:09	2020-03-28	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	17443	delivery	5	35
43836	2020-03-28 06:04:36	2020-03-28	9	[{"id_menu":6,"count":1}]	15563	delivery	5	14
43837	2020-03-28 06:07:14	2020-03-28	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11671	delivery	5	45
43838	2020-03-28 06:07:18	2020-03-28	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	15855	delivery	5	42
43839	2020-03-28 06:12:07	2020-03-28	9	[{"id_menu":6,"count":1}]	14013	pick-up	0	9
43840	2020-03-28 06:16:58	2020-03-28	17	[{"id_menu":4,"count":1}]	17454	delivery	5	22
43841	2020-03-28 06:26:44	2020-03-28	9	[{"id_menu":6,"count":1}]	2993	pick-up	0	9
43842	2020-03-28 06:33:24	2020-03-28	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	8319	delivery	5	35
43843	2020-03-28 06:38:14	2020-03-28	9	[{"id_menu":6,"count":1}]	8963	delivery	5	14
43844	2020-03-28 06:41:06	2020-03-28	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	9838	delivery	5	25
43845	2020-03-28 06:44:42	2020-03-28	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13478	delivery	5	48
43846	2020-03-28 06:55:20	2020-03-28	17	[{"id_menu":4,"count":1}]	17475	delivery	5	22
43847	2020-03-28 07:02:53	2020-03-28	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	7509	delivery	5	40
43848	2020-03-28 07:04:38	2020-03-28	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	12240	delivery	5	26
43849	2020-03-28 07:04:40	2020-03-28	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	17212	delivery	5	31
43850	2020-03-28 07:07:29	2020-03-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17546	delivery	5	22
43851	2020-03-28 07:09:25	2020-03-28	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2416	delivery	5	36
43852	2020-03-28 07:15:37	2020-03-28	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17483	delivery	5	45
43853	2020-03-28 07:17:41	2020-03-28	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1095	delivery	5	31
43854	2020-03-28 07:21:38	2020-03-28	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	15326	pick-up	0	22
43855	2020-03-28 07:23:10	2020-03-28	17	[{"id_menu":4,"count":1}]	3448	pick-up	0	17
43856	2020-03-28 07:25:18	2020-03-28	9	[{"id_menu":7,"count":1}]	17368	pick-up	0	9
43857	2020-03-28 07:25:25	2020-03-28	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14915	delivery	5	39
43858	2020-03-28 07:38:16	2020-03-28	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	2021	pick-up	0	40
43859	2020-03-28 07:39:13	2020-03-28	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	14710	pick-up	0	29
43860	2020-03-28 07:41:27	2020-03-28	17	[{"id_menu":4,"count":1}]	3774	pick-up	0	17
43861	2020-03-28 07:50:51	2020-03-28	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	17507	delivery	5	44
43862	2020-03-28 07:58:26	2020-03-28	9	[{"id_menu":7,"count":1}]	9119	delivery	5	14
43863	2020-03-28 07:59:06	2020-03-28	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3230	pick-up	0	31
43864	2020-03-28 08:07:06	2020-03-28	9	[{"id_menu":6,"count":1}]	4777	delivery	5	14
43865	2020-03-28 08:09:22	2020-03-28	9	[{"id_menu":7,"count":1}]	15800	pick-up	0	9
43866	2020-03-28 08:09:31	2020-03-28	12	[{"id_menu":1,"count":1}]	10356	delivery	5	17
43867	2020-03-28 08:10:06	2020-03-28	17	[{"id_menu":4,"count":1}]	2064	pick-up	0	17
43868	2020-03-28 08:12:11	2020-03-28	9	[{"id_menu":7,"count":1}]	17481	delivery	5	14
43869	2020-03-28 08:12:38	2020-03-28	12	[{"id_menu":3,"count":1}]	8090	delivery	5	17
43870	2020-03-28 08:15:17	2020-03-28	12	[{"id_menu":1,"count":1}]	14461	delivery	5	17
43871	2020-03-28 08:16:40	2020-03-28	17	[{"id_menu":4,"count":1}]	354	pick-up	0	17
43872	2020-03-28 08:19:24	2020-03-28	12	[{"id_menu":3,"count":1}]	6714	delivery	5	17
43873	2020-03-28 08:21:29	2020-03-28	9	[{"id_menu":6,"count":1}]	17496	delivery	5	14
43874	2020-03-28 08:27:41	2020-03-28	9	[{"id_menu":7,"count":2}]	13340	delivery	5	14
43875	2020-03-28 08:31:25	2020-03-28	14	[{"id_menu":2,"count":1}]	17470	delivery	5	19
43876	2020-03-28 08:33:13	2020-03-28	17	[{"id_menu":4,"count":1}]	5235	delivery	5	22
43877	2020-03-28 08:38:10	2020-03-28	17	[{"id_menu":4,"count":1}]	3452	delivery	5	22
43878	2020-03-28 08:38:39	2020-03-28	12	[{"id_menu":1,"count":1}]	17460	pick-up	0	12
43879	2020-03-28 08:42:52	2020-03-28	9	[{"id_menu":6,"count":2}]	17441	delivery	5	14
43880	2020-03-28 08:45:27	2020-03-28	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	6821	delivery	5	48
43881	2020-03-28 08:53:14	2020-03-28	9	[{"id_menu":6,"count":1}]	17432	delivery	5	14
43882	2020-03-28 08:58:08	2020-03-28	12	[{"id_menu":1,"count":1}]	11958	delivery	5	17
43883	2020-03-28 09:01:30	2020-03-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	17558	delivery	5	28
43884	2020-03-28 09:03:19	2020-03-28	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1885	pick-up	0	21
43885	2020-03-28 09:04:21	2020-03-28	8	[{"id_menu":5,"count":1}]	17435	delivery	5	13
43886	2020-03-28 09:05:03	2020-03-28	8	[{"id_menu":5,"count":1}]	15645	pick-up	0	8
43887	2020-03-28 09:06:30	2020-03-28	17	[{"id_menu":4,"count":1}]	17534	delivery	5	22
43888	2020-03-28 09:10:59	2020-03-28	9	[{"id_menu":6,"count":1}]	6313	delivery	5	14
43889	2020-03-28 09:11:21	2020-03-28	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	17543	delivery	5	28
43890	2020-03-28 09:13:23	2020-03-28	9	[{"id_menu":7,"count":1}]	8944	delivery	5	14
43891	2020-03-28 09:14:02	2020-03-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	13087	delivery	5	28
43892	2020-03-28 09:15:42	2020-03-28	12	[{"id_menu":3,"count":1}]	7190	pick-up	0	12
43893	2020-03-28 09:17:26	2020-03-28	17	[{"id_menu":4,"count":1}]	11357	pick-up	0	17
43894	2020-03-28 09:23:00	2020-03-28	14	[{"id_menu":2,"count":2}]	17491	pick-up	0	14
43895	2020-03-28 09:23:14	2020-03-28	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	17477	delivery	5	40
43896	2020-03-28 09:33:51	2020-03-28	9	[{"id_menu":6,"count":1}]	17448	delivery	5	14
43897	2020-03-28 09:34:48	2020-03-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3172	delivery	5	31
43898	2020-03-28 09:35:31	2020-03-28	8	[{"id_menu":5,"count":1}]	17542	delivery	5	13
43899	2020-03-28 09:35:45	2020-03-28	17	[{"id_menu":4,"count":1}]	11969	pick-up	0	17
43900	2020-03-28 09:43:30	2020-03-28	9	[{"id_menu":6,"count":1}]	16912	delivery	5	14
43901	2020-03-28 09:44:17	2020-03-28	9	[{"id_menu":6,"count":1}]	7573	delivery	5	14
43902	2020-03-28 09:45:14	2020-03-28	17	[{"id_menu":4,"count":1}]	17561	delivery	5	22
43903	2020-03-28 09:51:06	2020-03-28	17	[{"id_menu":4,"count":1}]	3271	delivery	5	22
43904	2020-03-28 09:56:26	2020-03-28	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	17560	delivery	5	37
43905	2020-03-28 10:01:02	2020-03-28	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7279	delivery	5	44
43906	2020-03-28 10:06:29	2020-03-28	14	[{"id_menu":2,"count":1}]	9843	delivery	5	19
43907	2020-03-28 10:11:30	2020-03-28	9	[{"id_menu":6,"count":1}]	4137	delivery	5	14
43908	2020-03-28 10:13:41	2020-03-28	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10180	delivery	5	47
43909	2020-03-28 10:13:46	2020-03-28	17	[{"id_menu":4,"count":1}]	14133	pick-up	0	17
43910	2020-03-28 10:19:50	2020-03-28	12	[{"id_menu":1,"count":1}]	17478	pick-up	0	12
43911	2020-03-28 10:21:25	2020-03-28	12	[{"id_menu":3,"count":1}]	17464	delivery	5	17
43912	2020-03-28 10:22:14	2020-03-28	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	8448	delivery	5	29
43913	2020-03-28 10:24:01	2020-03-28	9	[{"id_menu":7,"count":1}]	17550	delivery	5	14
43914	2020-03-28 10:28:16	2020-03-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3289	pick-up	0	23
43915	2020-03-28 10:29:01	2020-03-28	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	1491	pick-up	0	38
43916	2020-03-28 10:31:17	2020-03-28	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	6074	pick-up	0	38
43917	2020-03-28 10:35:32	2020-03-28	14	[{"id_menu":2,"count":1}]	13136	delivery	5	19
43918	2020-03-28 10:37:30	2020-03-28	17	[{"id_menu":4,"count":1}]	2902	pick-up	0	17
43919	2020-03-28 10:45:39	2020-03-28	9	[{"id_menu":7,"count":1}]	17540	pick-up	0	9
43920	2020-03-28 10:46:14	2020-03-28	9	[{"id_menu":7,"count":1}]	17541	delivery	5	14
43921	2020-03-28 10:47:26	2020-03-28	17	[{"id_menu":4,"count":1}]	841	pick-up	0	17
43922	2020-03-28 10:51:56	2020-03-28	9	[{"id_menu":6,"count":1}]	17367	delivery	5	14
43923	2020-03-28 10:54:48	2020-03-28	12	[{"id_menu":1,"count":1}]	127	pick-up	0	12
43924	2020-03-28 10:58:19	2020-03-28	12	[{"id_menu":3,"count":1}]	8256	delivery	5	17
43925	2020-03-28 11:00:27	2020-03-28	12	[{"id_menu":3,"count":1}]	17437	delivery	5	17
43926	2020-03-28 11:08:24	2020-03-28	17	[{"id_menu":4,"count":1}]	17490	delivery	5	22
43927	2020-03-28 11:09:41	2020-03-28	17	[{"id_menu":4,"count":1}]	17472	pick-up	0	17
43928	2020-03-28 11:10:19	2020-03-28	12	[{"id_menu":3,"count":1}]	5550	delivery	5	17
43929	2020-03-28 11:13:57	2020-03-28	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	17484	delivery	5	22
43930	2020-03-28 11:15:42	2020-03-28	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	12670	delivery	5	28
43931	2020-03-28 11:16:40	2020-03-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2277	pick-up	0	17
43932	2020-03-28 11:19:55	2020-03-28	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3621	delivery	5	44
43933	2020-03-28 11:22:44	2020-03-28	17	[{"id_menu":4,"count":1}]	17086	delivery	5	22
43934	2020-03-28 11:23:19	2020-03-28	12	[{"id_menu":1,"count":1}]	4710	pick-up	0	12
43935	2020-03-28 11:27:09	2020-03-28	17	[{"id_menu":4,"count":1}]	3684	delivery	5	22
43936	2020-03-28 11:28:26	2020-03-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17527	delivery	5	22
43937	2020-03-28 11:29:09	2020-03-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	431	pick-up	0	26
43938	2020-03-28 11:30:10	2020-03-28	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9222	delivery	5	43
43939	2020-03-28 11:32:36	2020-03-28	17	[{"id_menu":4,"count":1}]	150	pick-up	0	17
43940	2020-03-28 11:34:05	2020-03-28	8	[{"id_menu":5,"count":1}]	11233	delivery	5	13
43941	2020-03-28 11:36:17	2020-03-28	9	[{"id_menu":7,"count":1}]	16854	delivery	5	14
43942	2020-03-28 11:50:25	2020-03-28	12	[{"id_menu":3,"count":1}]	17512	pick-up	0	12
43943	2020-03-28 12:03:31	2020-03-28	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17451	delivery	5	37
43944	2020-03-28 12:04:03	2020-03-28	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17504	delivery	5	40
43945	2020-03-28 12:12:43	2020-03-28	9	[{"id_menu":6,"count":1}]	17517	delivery	5	14
43946	2020-03-28 12:25:51	2020-03-28	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17430	delivery	5	45
43947	2020-03-28 12:25:52	2020-03-28	9	[{"id_menu":6,"count":1}]	149	delivery	5	14
43948	2020-03-28 12:27:12	2020-03-28	9	[{"id_menu":6,"count":1}]	17502	delivery	5	14
43949	2020-03-28 12:27:28	2020-03-28	12	[{"id_menu":1,"count":1}]	17524	delivery	5	17
43950	2020-03-28 12:27:43	2020-03-28	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	10434	delivery	5	26
43951	2020-03-28 12:31:33	2020-03-28	12	[{"id_menu":3,"count":1}]	17518	delivery	5	17
43952	2020-03-28 12:33:44	2020-03-28	8	[{"id_menu":5,"count":1}]	17501	pick-up	0	8
43953	2020-03-28 12:40:04	2020-03-28	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8031	delivery	5	43
43954	2020-03-28 12:41:17	2020-03-28	9	[{"id_menu":6,"count":1}]	5200	delivery	5	14
43955	2020-03-28 12:41:35	2020-03-28	9	[{"id_menu":7,"count":1}]	5340	delivery	5	14
43956	2020-03-28 12:42:35	2020-03-28	9	[{"id_menu":6,"count":1}]	15407	delivery	5	14
43957	2020-03-28 12:45:50	2020-03-28	12	[{"id_menu":1,"count":1}]	13689	delivery	5	17
43958	2020-03-28 12:52:20	2020-03-28	46	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	6567	delivery	5	51
43959	2020-03-28 12:55:32	2020-03-28	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	6528	delivery	5	43
43960	2020-03-28 13:02:02	2020-03-28	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	17465	delivery	5	27
43961	2020-03-28 13:02:37	2020-03-28	8	[{"id_menu":5,"count":1}]	10799	delivery	5	13
43962	2020-03-28 13:04:24	2020-03-28	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	17521	pick-up	0	23
43963	2020-03-28 13:07:09	2020-03-28	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	17564	delivery	5	44
43964	2020-03-28 13:10:01	2020-03-28	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14316	delivery	5	36
43965	2020-03-28 13:10:14	2020-03-28	12	[{"id_menu":1,"count":1}]	650	delivery	5	17
43966	2020-03-28 13:11:13	2020-03-28	8	[{"id_menu":5,"count":1}]	5149	pick-up	0	8
43967	2020-03-28 13:12:02	2020-03-28	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	16754	delivery	5	34
43968	2020-03-28 13:15:46	2020-03-28	17	[{"id_menu":4,"count":1}]	1337	pick-up	0	17
43969	2020-03-28 13:16:46	2020-03-28	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	9503	delivery	5	25
43970	2020-03-28 13:24:32	2020-03-28	12	[{"id_menu":1,"count":1}]	17555	delivery	5	17
43971	2020-03-28 13:26:39	2020-03-28	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	8389	delivery	5	27
43972	2020-03-28 13:27:33	2020-03-28	14	[{"id_menu":2,"count":1}]	1529	pick-up	0	14
43973	2020-03-28 13:28:13	2020-03-28	8	[{"id_menu":5,"count":1}]	17444	delivery	5	13
43974	2020-03-28 13:42:38	2020-03-28	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	17551	delivery	5	34
43975	2020-03-28 13:44:16	2020-03-28	14	[{"id_menu":2,"count":1}]	17426	delivery	5	19
43976	2020-03-28 13:47:21	2020-03-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	93	pick-up	0	17
43977	2020-03-28 13:48:42	2020-03-28	14	[{"id_menu":2,"count":1}]	4363	pick-up	0	14
43978	2020-03-28 13:49:45	2020-03-28	9	[{"id_menu":6,"count":1}]	16717	delivery	5	14
43979	2020-03-28 13:52:42	2020-03-28	8	[{"id_menu":5,"count":1}]	17469	delivery	5	13
43980	2020-03-28 13:56:12	2020-03-28	9	[{"id_menu":7,"count":3}]	16426	delivery	5	14
43981	2020-03-28 13:58:37	2020-03-28	9	[{"id_menu":7,"count":1}]	10033	delivery	5	14
43982	2020-03-28 14:00:11	2020-03-28	17	[{"id_menu":4,"count":1}]	14488	delivery	5	22
43983	2020-03-28 14:01:10	2020-03-28	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	17473	delivery	5	28
43984	2020-03-28 14:05:38	2020-03-28	9	[{"id_menu":7,"count":1}]	4578	pick-up	0	9
43985	2020-03-28 14:12:05	2020-03-28	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	550	delivery	5	39
43986	2020-03-28 14:12:54	2020-03-28	14	[{"id_menu":2,"count":1}]	17468	delivery	5	19
43987	2020-03-28 14:14:45	2020-03-28	9	[{"id_menu":6,"count":1}]	2291	pick-up	0	9
43988	2020-03-28 14:16:21	2020-03-28	8	[{"id_menu":5,"count":1}]	17466	delivery	5	13
43989	2020-03-28 14:31:34	2020-03-28	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	17489	delivery	5	25
43990	2020-03-28 14:35:44	2020-03-28	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2383	pick-up	0	43
43991	2020-03-28 14:37:41	2020-03-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17497	delivery	5	22
43992	2020-03-28 14:42:51	2020-03-28	17	[{"id_menu":4,"count":1}]	3785	pick-up	0	17
43993	2020-03-28 14:51:06	2020-03-28	9	[{"id_menu":6,"count":1}]	17506	delivery	5	14
43994	2020-03-28 15:08:20	2020-03-28	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12396	delivery	5	31
43995	2020-03-28 15:15:15	2020-03-28	17	[{"id_menu":4,"count":1}]	10760	pick-up	0	17
43996	2020-03-28 15:17:11	2020-03-28	12	[{"id_menu":3,"count":1}]	1834	pick-up	0	12
43997	2020-03-28 15:18:02	2020-03-28	14	[{"id_menu":2,"count":1}]	5201	pick-up	0	14
43998	2020-03-28 15:27:53	2020-03-28	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17449	delivery	5	39
43999	2020-03-28 15:28:38	2020-03-28	8	[{"id_menu":5,"count":1}]	17463	delivery	5	13
44000	2020-03-28 15:28:55	2020-03-28	14	[{"id_menu":2,"count":1}]	11946	pick-up	0	14
44001	2020-03-28 15:32:32	2020-03-28	14	[{"id_menu":2,"count":1}]	8930	delivery	5	19
44002	2020-03-28 15:33:16	2020-03-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13162	delivery	5	23
44003	2020-03-28 15:35:16	2020-03-28	12	[{"id_menu":3,"count":1}]	1902	pick-up	0	12
44004	2020-03-28 15:45:16	2020-03-28	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	15332	delivery	5	28
44005	2020-03-28 15:48:48	2020-03-28	14	[{"id_menu":2,"count":1}]	17479	delivery	5	19
44006	2020-03-28 15:49:27	2020-03-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	16809	delivery	5	28
44007	2020-03-28 15:50:31	2020-03-28	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	3827	pick-up	0	21
44008	2020-03-28 15:50:45	2020-03-28	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	17445	delivery	5	30
44009	2020-03-28 15:54:13	2020-03-28	9	[{"id_menu":7,"count":1}]	17436	delivery	5	14
44010	2020-03-28 15:59:43	2020-03-28	8	[{"id_menu":5,"count":1}]	7551	delivery	5	13
44011	2020-03-28 16:00:51	2020-03-28	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	7467	pick-up	0	21
44012	2020-03-28 16:04:53	2020-03-28	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	17457	pick-up	0	25
44013	2020-03-28 16:05:35	2020-03-28	14	[{"id_menu":2,"count":1}]	8153	pick-up	0	14
44014	2020-03-28 16:10:12	2020-03-28	14	[{"id_menu":2,"count":1}]	6548	delivery	5	19
44015	2020-03-28 16:12:02	2020-03-28	9	[{"id_menu":6,"count":1}]	17480	pick-up	0	9
44016	2020-03-28 16:12:30	2020-03-28	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1760	pick-up	0	25
44017	2020-03-28 16:12:48	2020-03-28	12	[{"id_menu":1,"count":2}]	10330	delivery	5	17
44018	2020-03-28 16:20:10	2020-03-28	9	[{"id_menu":6,"count":1}]	16892	delivery	5	14
44019	2020-03-28 16:21:52	2020-03-28	12	[{"id_menu":1,"count":1}]	1079	delivery	5	17
44020	2020-03-28 16:22:20	2020-03-28	9	[{"id_menu":6,"count":1}]	14905	delivery	5	14
44021	2020-03-28 16:23:29	2020-03-28	9	[{"id_menu":6,"count":1}]	3162	delivery	5	14
44022	2020-03-28 16:39:13	2020-03-28	9	[{"id_menu":7,"count":1}]	17493	delivery	5	14
44023	2020-03-28 16:46:42	2020-03-28	14	[{"id_menu":2,"count":1}]	8799	pick-up	0	14
44024	2020-03-28 16:47:16	2020-03-28	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	17533	delivery	5	30
44025	2020-03-28 16:48:06	2020-03-28	9	[{"id_menu":6,"count":1}]	17513	delivery	5	14
44026	2020-03-28 16:54:00	2020-03-28	14	[{"id_menu":2,"count":1}]	15498	delivery	5	19
44027	2020-03-28 16:55:43	2020-03-28	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	7158	delivery	5	23
44028	2020-03-28 16:59:37	2020-03-28	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	6434	delivery	5	22
44029	2020-03-28 17:01:18	2020-03-28	12	[{"id_menu":3,"count":1}]	17492	delivery	5	17
44030	2020-03-28 17:01:59	2020-03-28	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	17488	delivery	5	27
44031	2020-03-28 17:02:33	2020-03-28	9	[{"id_menu":6,"count":1}]	15735	delivery	5	14
44032	2020-03-28 17:03:47	2020-03-28	12	[{"id_menu":1,"count":1}]	2193	pick-up	0	12
44033	2020-03-28 17:05:21	2020-03-28	9	[{"id_menu":6,"count":1}]	17482	delivery	5	14
44034	2020-03-28 17:06:24	2020-03-28	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	14777	delivery	5	43
44035	2020-03-28 17:13:01	2020-03-28	14	[{"id_menu":2,"count":1}]	17438	delivery	5	19
44036	2020-03-28 17:15:09	2020-03-28	9	[{"id_menu":7,"count":1}]	6321	pick-up	0	9
44037	2020-03-28 17:16:05	2020-03-28	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	15193	delivery	5	37
44038	2020-03-28 17:16:34	2020-03-28	9	[{"id_menu":6,"count":1}]	17536	pick-up	0	9
44039	2020-03-28 17:17:26	2020-03-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	17557	delivery	5	28
44040	2020-03-28 17:18:50	2020-03-28	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	10088	delivery	5	36
44041	2020-03-28 17:23:01	2020-03-28	8	[{"id_menu":5,"count":1}]	17495	pick-up	0	8
44042	2020-03-28 17:28:21	2020-03-28	14	[{"id_menu":2,"count":1}]	665	delivery	5	19
44043	2020-03-28 17:30:07	2020-03-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	17554	delivery	5	23
44044	2020-03-28 17:31:07	2020-03-28	8	[{"id_menu":5,"count":1}]	10871	delivery	5	13
44045	2020-03-28 17:33:56	2020-03-28	9	[{"id_menu":6,"count":1}]	17467	delivery	5	14
44046	2020-03-28 17:35:52	2020-03-28	8	[{"id_menu":5,"count":1}]	17431	delivery	5	13
44047	2020-03-28 17:42:17	2020-03-28	17	[{"id_menu":5,"count":3},{"id_menu":6,"count":1}]	14492	delivery	5	22
44048	2020-03-28 17:45:18	2020-03-28	12	[{"id_menu":3,"count":1}]	856	pick-up	0	12
44049	2020-03-28 17:45:22	2020-03-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2418	pick-up	0	17
44050	2020-03-28 17:51:08	2020-03-28	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9927	delivery	5	40
44051	2020-03-28 18:00:24	2020-03-28	8	[{"id_menu":5,"count":1}]	17511	delivery	5	13
44052	2020-03-28 18:05:55	2020-03-28	14	[{"id_menu":2,"count":1}]	9010	pick-up	0	14
44053	2020-03-28 18:16:42	2020-03-28	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	17522	delivery	5	26
44054	2020-03-28 18:17:47	2020-03-28	12	[{"id_menu":1,"count":1}]	5130	delivery	5	17
44055	2020-03-28 18:24:22	2020-03-28	17	[{"id_menu":4,"count":1}]	5743	delivery	5	22
44056	2020-03-28 18:27:31	2020-03-28	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	17516	delivery	5	26
44057	2020-03-28 18:27:40	2020-03-28	17	[{"id_menu":4,"count":1}]	9127	delivery	5	22
44058	2020-03-28 18:31:26	2020-03-28	9	[{"id_menu":6,"count":1}]	8632	pick-up	0	9
44059	2020-03-28 18:35:40	2020-03-28	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	6458	delivery	5	34
44060	2020-03-28 18:46:01	2020-03-28	8	[{"id_menu":5,"count":1}]	3268	delivery	5	13
44061	2020-03-28 18:46:30	2020-03-28	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5238	pick-up	0	37
44062	2020-03-28 18:50:54	2020-03-28	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7022	delivery	5	34
44063	2020-03-28 18:51:06	2020-03-28	9	[{"id_menu":6,"count":1}]	17562	delivery	5	14
44064	2020-03-28 18:53:28	2020-03-28	12	[{"id_menu":1,"count":1}]	17442	delivery	5	17
44065	2020-03-28 18:53:59	2020-03-28	9	[{"id_menu":6,"count":1}]	76	pick-up	0	9
44066	2020-03-28 18:56:23	2020-03-28	9	[{"id_menu":7,"count":1}]	17526	delivery	5	14
44067	2020-03-28 19:03:33	2020-03-28	12	[{"id_menu":3,"count":1}]	1153	delivery	5	17
44068	2020-03-28 19:03:37	2020-03-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":3}]	17446	delivery	5	22
44069	2020-03-28 19:04:42	2020-03-28	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	5578	delivery	5	23
44070	2020-03-28 19:09:54	2020-03-28	9	[{"id_menu":7,"count":1}]	17439	delivery	5	14
44071	2020-03-28 19:14:13	2020-03-28	9	[{"id_menu":7,"count":1}]	13257	delivery	5	14
44072	2020-03-28 19:21:27	2020-03-28	17	[{"id_menu":4,"count":1}]	17453	pick-up	0	17
44073	2020-03-28 19:21:35	2020-03-28	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	11091	delivery	5	48
44074	2020-03-28 19:27:19	2020-03-28	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	5048	delivery	5	52
44075	2020-03-28 19:30:06	2020-03-28	9	[{"id_menu":6,"count":1}]	1344	pick-up	0	9
44076	2020-03-28 19:31:23	2020-03-28	14	[{"id_menu":2,"count":1}]	17471	delivery	5	19
44077	2020-03-28 19:32:12	2020-03-28	12	[{"id_menu":3,"count":1}]	3222	delivery	5	17
44078	2020-03-28 19:34:25	2020-03-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	8067	delivery	5	28
44079	2020-03-28 19:36:36	2020-03-28	9	[{"id_menu":7,"count":1}]	20	delivery	5	14
44080	2020-03-28 19:38:52	2020-03-28	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2153	pick-up	0	29
44081	2020-03-28 19:47:54	2020-03-28	12	[{"id_menu":1,"count":1}]	17539	delivery	5	17
44082	2020-03-28 19:49:19	2020-03-28	17	[{"id_menu":4,"count":1}]	3918	pick-up	0	17
44083	2020-03-28 19:58:13	2020-03-28	14	[{"id_menu":2,"count":1}]	11394	pick-up	0	14
44084	2020-03-28 20:05:12	2020-03-28	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17519	delivery	5	40
44085	2020-03-28 20:06:14	2020-03-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17525	delivery	5	31
44086	2020-03-28 20:08:27	2020-03-28	17	[{"id_menu":4,"count":1}]	17494	delivery	5	22
44087	2020-03-28 20:17:17	2020-03-28	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	5509	delivery	5	31
44088	2020-03-28 20:28:16	2020-03-28	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	17485	delivery	5	31
44089	2020-03-28 20:29:34	2020-03-28	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":2}]	17547	delivery	5	26
44090	2020-03-28 20:31:11	2020-03-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1021	pick-up	0	18
44091	2020-03-28 20:31:14	2020-03-28	14	[{"id_menu":2,"count":1}]	2928	pick-up	0	14
44092	2020-03-28 20:31:27	2020-03-28	9	[{"id_menu":6,"count":1}]	17456	delivery	5	14
44093	2020-03-28 20:33:12	2020-03-28	8	[{"id_menu":5,"count":1}]	17433	delivery	5	13
44094	2020-03-28 20:34:19	2020-03-28	12	[{"id_menu":1,"count":1}]	17447	delivery	5	17
44095	2020-03-28 20:52:06	2020-03-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16004	delivery	5	23
44096	2020-03-28 20:56:04	2020-03-28	8	[{"id_menu":5,"count":1}]	3252	delivery	5	13
44097	2020-03-28 20:57:54	2020-03-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	16178	pick-up	0	23
44098	2020-03-28 21:00:16	2020-03-28	17	[{"id_menu":4,"count":1}]	15440	pick-up	0	17
44099	2020-03-28 21:03:24	2020-03-28	14	[{"id_menu":2,"count":1}]	17535	delivery	5	19
44100	2020-03-28 21:14:28	2020-03-28	14	[{"id_menu":2,"count":1}]	10433	delivery	5	19
44101	2020-03-28 21:28:30	2020-03-28	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2415	delivery	5	34
44102	2020-03-28 21:28:46	2020-03-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17515	pick-up	0	17
44103	2020-03-28 21:29:10	2020-03-28	9	[{"id_menu":7,"count":1}]	8372	pick-up	0	9
44104	2020-03-28 21:29:46	2020-03-28	14	[{"id_menu":2,"count":1}]	6153	delivery	5	19
44105	2020-03-28 21:31:24	2020-03-28	8	[{"id_menu":5,"count":1}]	3619	pick-up	0	8
44106	2020-03-28 21:32:10	2020-03-28	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	2879	delivery	5	23
44107	2020-03-28 21:35:17	2020-03-28	9	[{"id_menu":6,"count":1}]	15763	delivery	5	14
44108	2020-03-28 21:36:16	2020-03-28	9	[{"id_menu":6,"count":1}]	12882	delivery	5	14
44109	2020-03-28 21:37:09	2020-03-28	9	[{"id_menu":7,"count":1}]	1832	pick-up	0	9
44110	2020-03-28 21:39:42	2020-03-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	207	delivery	5	31
44111	2020-03-28 21:40:19	2020-03-28	12	[{"id_menu":1,"count":1}]	4754	delivery	5	17
44112	2020-03-28 21:42:51	2020-03-28	12	[{"id_menu":3,"count":1}]	13273	delivery	5	17
44113	2020-03-28 21:45:29	2020-03-28	14	[{"id_menu":2,"count":1}]	14852	delivery	5	19
44114	2020-03-28 21:52:36	2020-03-28	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	11802	delivery	5	40
44115	2020-03-28 21:54:19	2020-03-28	17	[{"id_menu":4,"count":1}]	13807	delivery	5	22
44116	2020-03-28 21:56:39	2020-03-28	17	[{"id_menu":4,"count":1}]	17474	delivery	5	22
44117	2020-03-28 22:00:29	2020-03-28	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	4081	pick-up	0	20
44118	2020-03-28 22:00:38	2020-03-28	14	[{"id_menu":2,"count":1}]	16355	pick-up	0	14
44119	2020-03-28 22:01:47	2020-03-28	9	[{"id_menu":7,"count":1}]	2314	pick-up	0	9
44120	2020-03-28 22:11:01	2020-03-28	17	[{"id_menu":4,"count":1}]	4967	pick-up	0	17
44121	2020-03-28 22:13:40	2020-03-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	9281	delivery	5	22
44122	2020-03-28 22:19:50	2020-03-28	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	9761	delivery	5	28
44123	2020-03-28 22:22:58	2020-03-28	9	[{"id_menu":7,"count":1}]	17455	delivery	5	14
44124	2020-03-28 22:25:11	2020-03-28	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	7388	delivery	5	28
44125	2020-03-28 22:30:41	2020-03-28	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	15348	delivery	5	30
44126	2020-03-28 22:31:43	2020-03-28	9	[{"id_menu":7,"count":1}]	17503	delivery	5	14
44127	2020-03-28 22:32:54	2020-03-28	9	[{"id_menu":7,"count":1}]	361	pick-up	0	9
44128	2020-03-28 22:41:50	2020-03-28	17	[{"id_menu":4,"count":1}]	2189	pick-up	0	17
44129	2020-03-28 22:44:01	2020-03-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17429	delivery	5	31
44130	2020-03-28 22:46:41	2020-03-28	14	[{"id_menu":2,"count":1}]	17462	delivery	5	19
44131	2020-03-28 22:47:56	2020-03-28	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	17537	delivery	5	26
44132	2020-03-28 22:48:34	2020-03-28	9	[{"id_menu":6,"count":1}]	1113	pick-up	0	9
44133	2020-03-28 22:55:19	2020-03-28	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	6996	pick-up	0	21
44134	2020-03-28 22:58:28	2020-03-28	9	[{"id_menu":6,"count":1}]	7156	delivery	5	14
44135	2020-03-28 23:05:20	2020-03-28	9	[{"id_menu":6,"count":1}]	3111	pick-up	0	9
44136	2020-03-28 23:07:21	2020-03-28	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	626	pick-up	0	21
44137	2020-03-28 23:09:43	2020-03-28	12	[{"id_menu":3,"count":1}]	15791	pick-up	0	12
44138	2020-03-28 23:18:52	2020-03-28	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17505	delivery	5	35
44139	2020-03-28 23:22:48	2020-03-28	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	14804	delivery	5	36
44140	2020-03-28 23:23:21	2020-03-28	14	[{"id_menu":2,"count":1}]	9315	delivery	5	19
44141	2020-03-28 23:31:34	2020-03-28	12	[{"id_menu":3,"count":1}]	17556	delivery	5	17
44142	2020-03-28 23:33:10	2020-03-28	9	[{"id_menu":6,"count":1}]	6799	delivery	5	14
44143	2020-03-28 23:41:07	2020-03-28	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	995	delivery	5	56
44144	2020-03-28 23:43:46	2020-03-28	9	[{"id_menu":6,"count":1}]	4998	delivery	5	14
44145	2020-03-28 23:49:10	2020-03-28	8	[{"id_menu":5,"count":1}]	17508	delivery	5	13
44146	2020-03-28 23:50:34	2020-03-28	17	[{"id_menu":4,"count":1}]	15827	pick-up	0	17
44147	2020-03-28 23:51:52	2020-03-28	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1582	delivery	5	39
44148	2020-03-28 23:55:10	2020-03-28	12	[{"id_menu":1,"count":1}]	17559	delivery	5	17
44149	2020-03-29 00:02:09	2020-03-29	12	[{"id_menu":3,"count":1}]	5407	delivery	5	17
44150	2020-03-29 00:02:35	2020-03-29	9	[{"id_menu":7,"count":1}]	17615	delivery	5	14
44151	2020-03-29 00:13:13	2020-03-29	8	[{"id_menu":5,"count":1}]	11311	delivery	5	13
44152	2020-03-29 00:14:46	2020-03-29	8	[{"id_menu":5,"count":1}]	17634	delivery	5	13
44153	2020-03-29 00:14:48	2020-03-29	14	[{"id_menu":2,"count":1}]	17662	delivery	5	19
44154	2020-03-29 00:15:59	2020-03-29	8	[{"id_menu":5,"count":1}]	14251	delivery	5	13
44155	2020-03-29 00:20:53	2020-03-29	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11956	delivery	5	43
44156	2020-03-29 00:21:50	2020-03-29	12	[{"id_menu":3,"count":1}]	3898	delivery	5	17
44157	2020-03-29 00:25:11	2020-03-29	9	[{"id_menu":7,"count":1}]	17609	pick-up	0	9
44158	2020-03-29 00:26:31	2020-03-29	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	12011	delivery	5	31
44159	2020-03-29 00:27:34	2020-03-29	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	17695	delivery	5	36
44160	2020-03-29 00:30:43	2020-03-29	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17703	delivery	5	40
44161	2020-03-29 00:32:23	2020-03-29	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	3054	pick-up	0	21
44162	2020-03-29 00:35:47	2020-03-29	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	1907	delivery	5	34
44163	2020-03-29 00:36:44	2020-03-29	12	[{"id_menu":1,"count":1}]	11239	pick-up	0	12
44164	2020-03-29 00:38:17	2020-03-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2894	pick-up	0	23
44165	2020-03-29 00:43:20	2020-03-29	12	[{"id_menu":1,"count":1}]	16179	delivery	5	17
44166	2020-03-29 00:44:41	2020-03-29	8	[{"id_menu":5,"count":1}]	14414	delivery	5	13
44167	2020-03-29 00:44:56	2020-03-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	16171	delivery	5	26
44168	2020-03-29 00:46:13	2020-03-29	12	[{"id_menu":3,"count":1}]	6120	pick-up	0	12
44169	2020-03-29 00:46:27	2020-03-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	15594	delivery	5	28
44170	2020-03-29 00:50:46	2020-03-29	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3574	delivery	5	43
44171	2020-03-29 00:51:18	2020-03-29	17	[{"id_menu":4,"count":1}]	7801	pick-up	0	17
44172	2020-03-29 00:51:28	2020-03-29	12	[{"id_menu":3,"count":1}]	229	pick-up	0	12
44173	2020-03-29 00:52:24	2020-03-29	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13058	delivery	5	31
44174	2020-03-29 00:56:24	2020-03-29	8	[{"id_menu":5,"count":1}]	17630	delivery	5	13
44175	2020-03-29 00:57:09	2020-03-29	12	[{"id_menu":3,"count":1}]	6151	pick-up	0	12
44176	2020-03-29 01:00:47	2020-03-29	17	[{"id_menu":4,"count":2}]	5548	pick-up	0	17
44177	2020-03-29 01:03:23	2020-03-29	8	[{"id_menu":5,"count":1}]	15181	delivery	5	13
44178	2020-03-29 01:06:52	2020-03-29	12	[{"id_menu":1,"count":1}]	7341	pick-up	0	12
44179	2020-03-29 01:11:23	2020-03-29	17	[{"id_menu":4,"count":1}]	2761	delivery	5	22
44180	2020-03-29 01:13:37	2020-03-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	17579	delivery	5	27
44181	2020-03-29 01:14:14	2020-03-29	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	17580	delivery	5	31
44182	2020-03-29 01:14:35	2020-03-29	17	[{"id_menu":4,"count":1}]	5786	delivery	5	22
44183	2020-03-29 01:17:38	2020-03-29	8	[{"id_menu":5,"count":1}]	8229	pick-up	0	8
44184	2020-03-29 01:18:36	2020-03-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	17622	delivery	5	28
44185	2020-03-29 01:20:36	2020-03-29	17	[{"id_menu":4,"count":1}]	7690	pick-up	0	17
44186	2020-03-29 01:21:18	2020-03-29	8	[{"id_menu":5,"count":1}]	3066	pick-up	0	8
44187	2020-03-29 01:23:01	2020-03-29	9	[{"id_menu":6,"count":1}]	17527	delivery	5	14
44188	2020-03-29 01:25:29	2020-03-29	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12951	pick-up	0	32
44189	2020-03-29 01:26:10	2020-03-29	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	14972	pick-up	0	38
44190	2020-03-29 01:28:38	2020-03-29	9	[{"id_menu":6,"count":1}]	506	pick-up	0	9
44191	2020-03-29 01:29:24	2020-03-29	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	17635	delivery	5	23
44192	2020-03-29 01:33:26	2020-03-29	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17594	delivery	5	57
44193	2020-03-29 01:35:00	2020-03-29	12	[{"id_menu":1,"count":1}]	11183	delivery	5	17
44194	2020-03-29 01:38:15	2020-03-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17691	pick-up	0	26
44195	2020-03-29 01:41:56	2020-03-29	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	17607	delivery	5	25
44196	2020-03-29 01:44:18	2020-03-29	12	[{"id_menu":1,"count":1}]	9319	delivery	5	17
44197	2020-03-29 01:46:08	2020-03-29	9	[{"id_menu":6,"count":1}]	2552	delivery	5	14
44198	2020-03-29 01:49:55	2020-03-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	10575	delivery	5	26
44199	2020-03-29 01:50:03	2020-03-29	9	[{"id_menu":7,"count":1}]	5975	delivery	5	14
44200	2020-03-29 02:00:39	2020-03-29	17	[{"id_menu":4,"count":1}]	9175	delivery	5	22
44201	2020-03-29 02:08:25	2020-03-29	12	[{"id_menu":1,"count":1}]	9440	delivery	5	17
44202	2020-03-29 02:11:00	2020-03-29	17	[{"id_menu":4,"count":1}]	17620	delivery	5	22
44203	2020-03-29 02:13:10	2020-03-29	17	[{"id_menu":4,"count":2}]	15187	delivery	5	22
44204	2020-03-29 02:14:18	2020-03-29	14	[{"id_menu":2,"count":1}]	9296	delivery	5	19
44205	2020-03-29 02:14:50	2020-03-29	17	[{"id_menu":4,"count":1}]	394	delivery	5	22
44206	2020-03-29 02:26:02	2020-03-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2691	delivery	5	26
44207	2020-03-29 02:35:13	2020-03-29	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	9356	pick-up	0	41
44208	2020-03-29 02:39:31	2020-03-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	17613	delivery	5	28
44209	2020-03-29 02:44:41	2020-03-29	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1638	delivery	5	40
44210	2020-03-29 02:50:20	2020-03-29	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	719	pick-up	0	26
44211	2020-03-29 02:53:40	2020-03-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	13859	pick-up	0	21
44212	2020-03-29 02:56:04	2020-03-29	12	[{"id_menu":3,"count":1}]	2428	delivery	5	17
44213	2020-03-29 02:58:57	2020-03-29	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	17610	delivery	5	29
44214	2020-03-29 03:03:43	2020-03-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	8065	delivery	5	26
44215	2020-03-29 03:04:51	2020-03-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	15350	delivery	5	31
44216	2020-03-29 03:07:12	2020-03-29	9	[{"id_menu":6,"count":2}]	980	pick-up	0	9
44217	2020-03-29 03:11:00	2020-03-29	14	[{"id_menu":2,"count":1}]	12651	delivery	5	19
44218	2020-03-29 03:15:18	2020-03-29	12	[{"id_menu":1,"count":1}]	17570	delivery	5	17
44219	2020-03-29 03:15:29	2020-03-29	12	[{"id_menu":1,"count":1}]	8890	delivery	5	17
44220	2020-03-29 03:15:56	2020-03-29	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6233	delivery	5	34
44221	2020-03-29 03:18:49	2020-03-29	12	[{"id_menu":1,"count":1}]	7451	delivery	5	17
44222	2020-03-29 03:20:46	2020-03-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	17588	delivery	5	26
44223	2020-03-29 03:27:02	2020-03-29	9	[{"id_menu":6,"count":3}]	17670	delivery	5	14
44224	2020-03-29 03:31:26	2020-03-29	8	[{"id_menu":5,"count":1}]	7095	delivery	5	13
44225	2020-03-29 03:39:15	2020-03-29	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	17628	delivery	5	22
44226	2020-03-29 03:41:25	2020-03-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	7083	pick-up	0	26
44227	2020-03-29 03:42:53	2020-03-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	627	pick-up	0	17
44228	2020-03-29 03:42:59	2020-03-29	8	[{"id_menu":5,"count":1}]	17648	delivery	5	13
44229	2020-03-29 03:42:59	2020-03-29	12	[{"id_menu":1,"count":1}]	5004	delivery	5	17
44230	2020-03-29 03:57:17	2020-03-29	8	[{"id_menu":5,"count":1}]	17705	delivery	5	13
44231	2020-03-29 03:58:59	2020-03-29	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	7247	pick-up	0	35
44232	2020-03-29 04:11:51	2020-03-29	8	[{"id_menu":5,"count":1}]	10950	delivery	5	13
44233	2020-03-29 04:14:15	2020-03-29	12	[{"id_menu":1,"count":1}]	4007	delivery	5	17
44234	2020-03-29 04:21:46	2020-03-29	12	[{"id_menu":3,"count":1}]	1797	pick-up	0	12
44235	2020-03-29 04:26:06	2020-03-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	6221	pick-up	0	21
44236	2020-03-29 04:30:28	2020-03-29	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	344	pick-up	0	39
44237	2020-03-29 04:31:21	2020-03-29	9	[{"id_menu":6,"count":1}]	15600	delivery	5	14
44238	2020-03-29 04:31:24	2020-03-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11520	delivery	5	36
44239	2020-03-29 04:33:52	2020-03-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15563	delivery	5	36
44240	2020-03-29 04:33:57	2020-03-29	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	12623	pick-up	0	29
44241	2020-03-29 04:37:44	2020-03-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10151	pick-up	0	26
44242	2020-03-29 04:40:16	2020-03-29	14	[{"id_menu":2,"count":1}]	3012	pick-up	0	14
44243	2020-03-29 04:42:43	2020-03-29	9	[{"id_menu":6,"count":1}]	11735	delivery	5	14
44244	2020-03-29 04:47:01	2020-03-29	9	[{"id_menu":6,"count":1}]	17649	pick-up	0	9
44245	2020-03-29 04:47:07	2020-03-29	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17596	delivery	5	51
44246	2020-03-29 04:48:20	2020-03-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	14585	pick-up	0	22
44247	2020-03-29 04:49:17	2020-03-29	8	[{"id_menu":5,"count":1}]	3754	pick-up	0	8
44248	2020-03-29 04:49:32	2020-03-29	9	[{"id_menu":6,"count":1}]	7815	delivery	5	14
44249	2020-03-29 04:51:20	2020-03-29	14	[{"id_menu":2,"count":1}]	3116	pick-up	0	14
44250	2020-03-29 04:56:30	2020-03-29	14	[{"id_menu":2,"count":1}]	17513	delivery	5	19
44251	2020-03-29 04:56:41	2020-03-29	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17258	delivery	5	34
44252	2020-03-29 04:59:56	2020-03-29	17	[{"id_menu":4,"count":1}]	17689	delivery	5	22
44253	2020-03-29 05:02:14	2020-03-29	14	[{"id_menu":2,"count":1}]	7545	delivery	5	19
44254	2020-03-29 05:02:24	2020-03-29	9	[{"id_menu":6,"count":1}]	10761	delivery	5	14
44255	2020-03-29 05:04:15	2020-03-29	9	[{"id_menu":7,"count":1}]	17591	delivery	5	14
44256	2020-03-29 05:09:22	2020-03-29	9	[{"id_menu":7,"count":1}]	15896	delivery	5	14
44257	2020-03-29 05:14:00	2020-03-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17684	delivery	5	31
44258	2020-03-29 05:20:50	2020-03-29	12	[{"id_menu":1,"count":1}]	4403	delivery	5	17
44259	2020-03-29 05:24:54	2020-03-29	14	[{"id_menu":2,"count":1}]	16724	delivery	5	19
44260	2020-03-29 05:30:08	2020-03-29	17	[{"id_menu":4,"count":1}]	17688	pick-up	0	17
44261	2020-03-29 05:32:23	2020-03-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17612	delivery	5	22
44262	2020-03-29 05:38:33	2020-03-29	12	[{"id_menu":1,"count":1}]	286	delivery	5	17
44263	2020-03-29 05:40:06	2020-03-29	17	[{"id_menu":4,"count":1}]	16647	delivery	5	22
44264	2020-03-29 05:41:18	2020-03-29	8	[{"id_menu":5,"count":1}]	4186	delivery	5	13
44265	2020-03-29 05:49:54	2020-03-29	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	6367	delivery	5	40
44266	2020-03-29 05:54:06	2020-03-29	12	[{"id_menu":1,"count":1}]	1992	delivery	5	17
44267	2020-03-29 05:54:23	2020-03-29	9	[{"id_menu":6,"count":1}]	15323	delivery	5	14
44268	2020-03-29 05:54:38	2020-03-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3485	delivery	5	28
44269	2020-03-29 06:07:52	2020-03-29	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	12574	delivery	5	31
44270	2020-03-29 06:13:31	2020-03-29	9	[{"id_menu":7,"count":1}]	14497	delivery	5	14
44271	2020-03-29 06:14:02	2020-03-29	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16160	delivery	5	43
44272	2020-03-29 06:15:54	2020-03-29	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	3158	delivery	5	26
44273	2020-03-29 06:16:31	2020-03-29	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	10538	delivery	5	31
44274	2020-03-29 06:20:32	2020-03-29	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10444	delivery	5	34
44275	2020-03-29 06:21:27	2020-03-29	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	17660	delivery	5	34
44276	2020-03-29 06:23:33	2020-03-29	9	[{"id_menu":6,"count":1}]	17598	delivery	5	14
44277	2020-03-29 06:24:01	2020-03-29	9	[{"id_menu":6,"count":1}]	3328	delivery	5	14
44278	2020-03-29 06:25:32	2020-03-29	8	[{"id_menu":5,"count":1}]	17507	delivery	5	13
44279	2020-03-29 06:27:39	2020-03-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1536	delivery	5	23
44280	2020-03-29 06:30:27	2020-03-29	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17690	delivery	5	45
44281	2020-03-29 06:43:25	2020-03-29	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	17679	pick-up	0	31
44282	2020-03-29 06:43:48	2020-03-29	17	[{"id_menu":4,"count":1}]	17674	delivery	5	22
44283	2020-03-29 06:47:30	2020-03-29	9	[{"id_menu":6,"count":1}]	17577	delivery	5	14
44284	2020-03-29 06:50:42	2020-03-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	15752	delivery	5	26
44285	2020-03-29 06:53:01	2020-03-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7585	delivery	5	22
44286	2020-03-29 06:57:02	2020-03-29	17	[{"id_menu":4,"count":2}]	17565	delivery	5	22
44287	2020-03-29 06:58:28	2020-03-29	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17575	delivery	5	45
44288	2020-03-29 07:02:59	2020-03-29	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	11225	pick-up	0	26
44289	2020-03-29 07:03:11	2020-03-29	8	[{"id_menu":5,"count":1}]	17603	delivery	5	13
44290	2020-03-29 07:09:10	2020-03-29	12	[{"id_menu":3,"count":1}]	2282	pick-up	0	12
44291	2020-03-29 07:14:03	2020-03-29	17	[{"id_menu":4,"count":1}]	1526	delivery	5	22
44292	2020-03-29 07:17:40	2020-03-29	14	[{"id_menu":2,"count":1}]	17661	pick-up	0	14
44293	2020-03-29 07:19:44	2020-03-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	17678	delivery	5	26
44294	2020-03-29 07:20:30	2020-03-29	9	[{"id_menu":6,"count":1}]	5141	pick-up	0	9
44295	2020-03-29 07:21:24	2020-03-29	17	[{"id_menu":4,"count":1}]	17582	pick-up	0	17
44296	2020-03-29 07:25:11	2020-03-29	9	[{"id_menu":6,"count":2}]	17616	delivery	5	14
44297	2020-03-29 07:25:24	2020-03-29	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	3870	pick-up	0	23
44298	2020-03-29 07:33:42	2020-03-29	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15417	delivery	5	51
44299	2020-03-29 07:49:47	2020-03-29	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2891	delivery	5	48
44300	2020-03-29 07:52:59	2020-03-29	9	[{"id_menu":6,"count":1}]	1393	delivery	5	14
44301	2020-03-29 08:00:16	2020-03-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6480	delivery	5	22
44302	2020-03-29 08:08:13	2020-03-29	12	[{"id_menu":1,"count":1}]	2608	delivery	5	17
44303	2020-03-29 08:12:57	2020-03-29	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	17677	delivery	5	25
44304	2020-03-29 08:16:51	2020-03-29	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	17584	delivery	5	39
44305	2020-03-29 08:17:24	2020-03-29	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	76	pick-up	0	21
44306	2020-03-29 08:28:29	2020-03-29	9	[{"id_menu":7,"count":1}]	295	pick-up	0	9
44307	2020-03-29 08:29:58	2020-03-29	9	[{"id_menu":6,"count":1}]	5019	pick-up	0	9
44308	2020-03-29 08:30:11	2020-03-29	14	[{"id_menu":2,"count":1}]	5979	delivery	5	19
44309	2020-03-29 08:31:48	2020-03-29	9	[{"id_menu":7,"count":1}]	4834	pick-up	0	9
44310	2020-03-29 08:32:54	2020-03-29	55	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	9509	pick-up	0	55
44311	2020-03-29 08:34:10	2020-03-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	17589	delivery	5	28
44312	2020-03-29 08:37:08	2020-03-29	22	[{"id_menu":2,"count":3},{"id_menu":5,"count":1}]	17698	delivery	5	27
44313	2020-03-29 08:42:48	2020-03-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1049	delivery	5	28
44314	2020-03-29 08:43:57	2020-03-29	9	[{"id_menu":6,"count":1}]	15726	delivery	5	14
44315	2020-03-29 08:45:47	2020-03-29	17	[{"id_menu":4,"count":1}]	4351	pick-up	0	17
44316	2020-03-29 08:48:06	2020-03-29	8	[{"id_menu":5,"count":1}]	17366	delivery	5	13
44317	2020-03-29 08:50:19	2020-03-29	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13621	delivery	5	36
44318	2020-03-29 08:50:56	2020-03-29	14	[{"id_menu":2,"count":1}]	8512	delivery	5	19
44319	2020-03-29 08:51:44	2020-03-29	14	[{"id_menu":2,"count":1}]	12591	delivery	5	19
44320	2020-03-29 08:58:04	2020-03-29	8	[{"id_menu":5,"count":1}]	17676	delivery	5	13
44321	2020-03-29 09:07:23	2020-03-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4871	delivery	5	23
44322	2020-03-29 09:09:48	2020-03-29	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17694	delivery	5	40
44323	2020-03-29 09:13:00	2020-03-29	12	[{"id_menu":3,"count":1}]	14454	delivery	5	17
44324	2020-03-29 09:20:19	2020-03-29	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	9514	delivery	5	25
44325	2020-03-29 09:21:26	2020-03-29	9	[{"id_menu":7,"count":1}]	1024	pick-up	0	9
44326	2020-03-29 09:22:11	2020-03-29	14	[{"id_menu":2,"count":2}]	1776	delivery	5	19
44327	2020-03-29 09:30:15	2020-03-29	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1380	delivery	5	40
44328	2020-03-29 09:31:54	2020-03-29	17	[{"id_menu":4,"count":1}]	1053	pick-up	0	17
44329	2020-03-29 09:34:13	2020-03-29	9	[{"id_menu":7,"count":1}]	3563	delivery	5	14
44330	2020-03-29 09:36:09	2020-03-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	17597	pick-up	0	22
44331	2020-03-29 09:42:51	2020-03-29	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17581	delivery	5	43
44332	2020-03-29 09:43:40	2020-03-29	9	[{"id_menu":6,"count":1}]	6869	delivery	5	14
44333	2020-03-29 09:44:03	2020-03-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	9743	delivery	5	26
44334	2020-03-29 09:47:18	2020-03-29	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	6276	delivery	5	39
44335	2020-03-29 09:48:21	2020-03-29	9	[{"id_menu":7,"count":1}]	6342	delivery	5	14
44336	2020-03-29 09:50:11	2020-03-29	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2845	delivery	5	35
44337	2020-03-29 09:50:56	2020-03-29	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2632	delivery	5	47
44338	2020-03-29 09:51:36	2020-03-29	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17633	delivery	5	48
44339	2020-03-29 09:56:22	2020-03-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2005	pick-up	0	18
44340	2020-03-29 09:57:09	2020-03-29	8	[{"id_menu":5,"count":1}]	7940	delivery	5	13
44341	2020-03-29 09:57:45	2020-03-29	12	[{"id_menu":1,"count":1}]	17685	delivery	5	17
44342	2020-03-29 10:03:34	2020-03-29	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12378	delivery	5	34
44343	2020-03-29 10:05:09	2020-03-29	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2551	pick-up	0	26
44344	2020-03-29 10:07:42	2020-03-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12831	delivery	5	22
44345	2020-03-29 10:08:44	2020-03-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	17647	delivery	5	28
44346	2020-03-29 10:12:59	2020-03-29	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17682	pick-up	0	43
44347	2020-03-29 10:14:33	2020-03-29	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	17629	delivery	5	56
44348	2020-03-29 10:15:04	2020-03-29	8	[{"id_menu":5,"count":1}]	17569	pick-up	0	8
44349	2020-03-29 10:18:45	2020-03-29	8	[{"id_menu":5,"count":1}]	11914	pick-up	0	8
44350	2020-03-29 10:19:50	2020-03-29	9	[{"id_menu":7,"count":1}]	14054	delivery	5	14
44351	2020-03-29 10:26:12	2020-03-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4644	pick-up	0	23
44352	2020-03-29 10:26:35	2020-03-29	17	[{"id_menu":4,"count":1}]	17500	delivery	5	22
44353	2020-03-29 10:28:21	2020-03-29	9	[{"id_menu":6,"count":1}]	17586	delivery	5	14
44354	2020-03-29 10:38:22	2020-03-29	9	[{"id_menu":6,"count":1}]	6421	delivery	5	14
44355	2020-03-29 10:44:39	2020-03-29	14	[{"id_menu":2,"count":1}]	12905	pick-up	0	14
44356	2020-03-29 10:49:17	2020-03-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	13049	delivery	5	27
44357	2020-03-29 10:53:47	2020-03-29	8	[{"id_menu":5,"count":1}]	13494	delivery	5	13
44358	2020-03-29 10:57:12	2020-03-29	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	17623	delivery	5	37
44359	2020-03-29 10:58:40	2020-03-29	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	17583	delivery	5	34
44360	2020-03-29 10:59:00	2020-03-29	12	[{"id_menu":3,"count":1}]	791	delivery	5	17
44361	2020-03-29 10:59:15	2020-03-29	12	[{"id_menu":1,"count":1}]	3052	pick-up	0	12
44362	2020-03-29 11:03:31	2020-03-29	9	[{"id_menu":7,"count":1}]	17650	delivery	5	14
44363	2020-03-29 11:08:41	2020-03-29	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6980	delivery	5	40
44364	2020-03-29 11:09:01	2020-03-29	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":2}]	11932	delivery	5	22
44365	2020-03-29 11:13:06	2020-03-29	14	[{"id_menu":2,"count":1}]	684	pick-up	0	14
44366	2020-03-29 11:14:42	2020-03-29	9	[{"id_menu":6,"count":1}]	7997	delivery	5	14
44367	2020-03-29 11:17:03	2020-03-29	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17645	delivery	5	34
44368	2020-03-29 11:18:53	2020-03-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17617	delivery	5	22
44369	2020-03-29 11:20:49	2020-03-29	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	17571	delivery	5	31
44370	2020-03-29 11:29:05	2020-03-29	9	[{"id_menu":6,"count":1}]	17671	delivery	5	14
44371	2020-03-29 11:29:23	2020-03-29	9	[{"id_menu":6,"count":1}]	17567	delivery	5	14
44372	2020-03-29 11:34:59	2020-03-29	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10159	delivery	5	55
44373	2020-03-29 11:38:34	2020-03-29	12	[{"id_menu":3,"count":1}]	4445	pick-up	0	12
44374	2020-03-29 11:39:56	2020-03-29	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17576	delivery	5	43
44375	2020-03-29 11:42:07	2020-03-29	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	17627	delivery	5	31
44376	2020-03-29 11:45:49	2020-03-29	9	[{"id_menu":6,"count":1}]	2623	pick-up	0	9
44377	2020-03-29 11:46:47	2020-03-29	12	[{"id_menu":3,"count":1}]	3451	pick-up	0	12
44378	2020-03-29 11:50:48	2020-03-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	11846	delivery	5	28
44379	2020-03-29 11:52:33	2020-03-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	17666	delivery	5	26
44380	2020-03-29 11:55:40	2020-03-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	14496	delivery	5	26
44381	2020-03-29 11:59:31	2020-03-29	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	13466	delivery	5	40
44382	2020-03-29 12:05:01	2020-03-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	9904	pick-up	0	23
44383	2020-03-29 12:07:19	2020-03-29	12	[{"id_menu":1,"count":2}]	5972	pick-up	0	12
44384	2020-03-29 12:12:51	2020-03-29	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	17574	delivery	5	25
44385	2020-03-29 12:14:10	2020-03-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	17665	delivery	5	31
44386	2020-03-29 12:15:30	2020-03-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13164	delivery	5	22
44387	2020-03-29 12:29:37	2020-03-29	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	17652	delivery	5	30
44388	2020-03-29 12:32:03	2020-03-29	9	[{"id_menu":7,"count":1}]	7362	delivery	5	14
44389	2020-03-29 12:37:33	2020-03-29	14	[{"id_menu":2,"count":1}]	9171	pick-up	0	14
44390	2020-03-29 12:37:40	2020-03-29	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17687	delivery	5	54
44391	2020-03-29 12:37:59	2020-03-29	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	17681	delivery	5	30
44392	2020-03-29 12:46:56	2020-03-29	17	[{"id_menu":4,"count":1}]	5094	pick-up	0	17
44393	2020-03-29 12:48:40	2020-03-29	17	[{"id_menu":4,"count":1}]	841	pick-up	0	17
44394	2020-03-29 12:48:42	2020-03-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1747	delivery	5	28
44395	2020-03-29 12:52:42	2020-03-29	8	[{"id_menu":5,"count":1}]	2886	pick-up	0	8
44396	2020-03-29 12:55:30	2020-03-29	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17638	delivery	5	34
44397	2020-03-29 12:55:48	2020-03-29	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	10429	delivery	5	25
44398	2020-03-29 12:59:41	2020-03-29	17	[{"id_menu":4,"count":1}]	2932	pick-up	0	17
44399	2020-03-29 13:06:01	2020-03-29	9	[{"id_menu":6,"count":1}]	17668	pick-up	0	9
44400	2020-03-29 13:11:36	2020-03-29	12	[{"id_menu":3,"count":1}]	2007	pick-up	0	12
44401	2020-03-29 13:14:13	2020-03-29	9	[{"id_menu":6,"count":1}]	3108	delivery	5	14
44402	2020-03-29 13:16:11	2020-03-29	17	[{"id_menu":4,"count":1}]	12937	delivery	5	22
44403	2020-03-29 13:17:59	2020-03-29	9	[{"id_menu":7,"count":1}]	17592	delivery	5	14
44404	2020-03-29 13:19:33	2020-03-29	9	[{"id_menu":6,"count":1}]	10101	delivery	5	14
44405	2020-03-29 13:22:59	2020-03-29	12	[{"id_menu":3,"count":1}]	722	pick-up	0	12
44406	2020-03-29 13:27:33	2020-03-29	17	[{"id_menu":4,"count":1}]	5180	pick-up	0	17
44407	2020-03-29 13:30:17	2020-03-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	8767	delivery	5	26
44408	2020-03-29 13:32:25	2020-03-29	8	[{"id_menu":5,"count":1}]	8884	delivery	5	13
44409	2020-03-29 13:37:58	2020-03-29	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	17664	delivery	5	26
44410	2020-03-29 13:38:47	2020-03-29	12	[{"id_menu":1,"count":1}]	4428	pick-up	0	12
44411	2020-03-29 13:40:53	2020-03-29	12	[{"id_menu":3,"count":1}]	5154	delivery	5	17
44412	2020-03-29 13:52:55	2020-03-29	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	11764	pick-up	0	24
44413	2020-03-29 13:53:04	2020-03-29	17	[{"id_menu":4,"count":1}]	2546	pick-up	0	17
44414	2020-03-29 13:54:48	2020-03-29	17	[{"id_menu":4,"count":1}]	17593	delivery	5	22
44415	2020-03-29 14:00:47	2020-03-29	9	[{"id_menu":6,"count":1}]	7505	pick-up	0	9
44416	2020-03-29 14:03:11	2020-03-29	8	[{"id_menu":5,"count":1}]	17599	delivery	5	13
44417	2020-03-29 14:07:59	2020-03-29	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1677	delivery	5	45
44418	2020-03-29 14:10:31	2020-03-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	17701	delivery	5	22
44419	2020-03-29 14:12:48	2020-03-29	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	17657	delivery	5	42
44420	2020-03-29 14:13:06	2020-03-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	14341	delivery	5	28
44421	2020-03-29 14:18:55	2020-03-29	12	[{"id_menu":3,"count":1}]	17600	delivery	5	17
44422	2020-03-29 14:24:44	2020-03-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12990	pick-up	0	26
44423	2020-03-29 14:29:25	2020-03-29	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7626	pick-up	0	43
44424	2020-03-29 14:32:43	2020-03-29	14	[{"id_menu":2,"count":1}]	15205	delivery	5	19
44425	2020-03-29 14:43:07	2020-03-29	8	[{"id_menu":5,"count":1}]	14086	pick-up	0	8
44426	2020-03-29 15:00:42	2020-03-29	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	12178	delivery	5	40
44427	2020-03-29 15:03:51	2020-03-29	9	[{"id_menu":7,"count":1}]	5367	delivery	5	14
44428	2020-03-29 15:10:07	2020-03-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	16952	delivery	5	26
44429	2020-03-29 15:13:34	2020-03-29	12	[{"id_menu":3,"count":1}]	17700	pick-up	0	12
44430	2020-03-29 15:18:51	2020-03-29	8	[{"id_menu":5,"count":1}]	17699	delivery	5	13
44431	2020-03-29 15:21:57	2020-03-29	9	[{"id_menu":7,"count":1}]	15395	pick-up	0	9
44432	2020-03-29 15:27:16	2020-03-29	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1387	pick-up	0	35
44433	2020-03-29 15:29:58	2020-03-29	12	[{"id_menu":1,"count":1}]	389	delivery	5	17
44434	2020-03-29 15:30:14	2020-03-29	14	[{"id_menu":2,"count":1}]	16375	pick-up	0	14
44435	2020-03-29 15:31:42	2020-03-29	14	[{"id_menu":2,"count":1}]	6729	delivery	5	19
44436	2020-03-29 15:35:41	2020-03-29	14	[{"id_menu":2,"count":1}]	13881	delivery	5	19
44437	2020-03-29 15:35:54	2020-03-29	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17573	delivery	5	37
44438	2020-03-29 15:37:52	2020-03-29	9	[{"id_menu":7,"count":1}]	13032	delivery	5	14
44439	2020-03-29 15:39:39	2020-03-29	8	[{"id_menu":5,"count":1}]	612	pick-up	0	8
44440	2020-03-29 15:42:04	2020-03-29	8	[{"id_menu":5,"count":1}]	17644	delivery	5	13
44441	2020-03-29 15:42:31	2020-03-29	9	[{"id_menu":7,"count":1}]	17640	delivery	5	14
44442	2020-03-29 15:49:00	2020-03-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2493	pick-up	0	31
44443	2020-03-29 15:53:11	2020-03-29	12	[{"id_menu":3,"count":1}]	3538	delivery	5	17
44444	2020-03-29 15:57:54	2020-03-29	9	[{"id_menu":6,"count":1}]	5437	delivery	5	14
44445	2020-03-29 16:00:54	2020-03-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	17646	delivery	5	26
44446	2020-03-29 16:03:51	2020-03-29	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	9264	delivery	5	22
44447	2020-03-29 16:06:07	2020-03-29	9	[{"id_menu":7,"count":2}]	12988	delivery	5	14
44448	2020-03-29 16:09:01	2020-03-29	9	[{"id_menu":6,"count":1}]	2129	delivery	5	14
44449	2020-03-29 16:11:46	2020-03-29	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	10026	delivery	5	27
44450	2020-03-29 16:12:20	2020-03-29	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	17585	delivery	5	39
44451	2020-03-29 16:14:11	2020-03-29	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	17566	delivery	5	34
44452	2020-03-29 16:15:23	2020-03-29	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	17659	delivery	5	29
44453	2020-03-29 16:16:47	2020-03-29	8	[{"id_menu":5,"count":1}]	17602	delivery	5	13
44454	2020-03-29 16:23:48	2020-03-29	9	[{"id_menu":6,"count":1}]	17672	delivery	5	14
44455	2020-03-29 16:27:23	2020-03-29	9	[{"id_menu":6,"count":1}]	17621	delivery	5	14
44456	2020-03-29 16:28:17	2020-03-29	8	[{"id_menu":5,"count":1}]	17618	delivery	5	13
44457	2020-03-29 16:29:42	2020-03-29	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3741	pick-up	0	35
44458	2020-03-29 16:34:03	2020-03-29	17	[{"id_menu":4,"count":1}]	17663	delivery	5	22
44459	2020-03-29 16:34:03	2020-03-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	6001	delivery	5	31
44460	2020-03-29 16:37:29	2020-03-29	12	[{"id_menu":1,"count":1}]	1323	pick-up	0	12
44461	2020-03-29 16:39:23	2020-03-29	14	[{"id_menu":2,"count":1}]	17626	delivery	5	19
44462	2020-03-29 16:40:32	2020-03-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	17611	delivery	5	27
44463	2020-03-29 16:43:14	2020-03-29	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17667	delivery	5	48
44464	2020-03-29 16:47:16	2020-03-29	9	[{"id_menu":7,"count":1}]	11812	delivery	5	14
44465	2020-03-29 17:02:41	2020-03-29	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	10356	delivery	5	30
44466	2020-03-29 17:06:47	2020-03-29	8	[{"id_menu":5,"count":1}]	17686	delivery	5	13
44467	2020-03-29 17:06:52	2020-03-29	14	[{"id_menu":2,"count":1}]	2353	pick-up	0	14
44468	2020-03-29 17:17:13	2020-03-29	9	[{"id_menu":6,"count":1}]	623	pick-up	0	9
44469	2020-03-29 17:23:05	2020-03-29	17	[{"id_menu":4,"count":1}]	15328	delivery	5	22
44470	2020-03-29 17:26:06	2020-03-29	8	[{"id_menu":5,"count":1}]	7419	delivery	5	13
44471	2020-03-29 17:30:55	2020-03-29	9	[{"id_menu":7,"count":1}]	13100	delivery	5	14
44472	2020-03-29 17:34:55	2020-03-29	12	[{"id_menu":1,"count":1}]	17673	delivery	5	17
44473	2020-03-29 17:37:06	2020-03-29	9	[{"id_menu":6,"count":1}]	17578	pick-up	0	9
44474	2020-03-29 17:39:18	2020-03-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	13187	delivery	5	28
44475	2020-03-29 17:39:42	2020-03-29	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	17619	delivery	5	23
44476	2020-03-29 17:40:19	2020-03-29	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15793	pick-up	0	40
44477	2020-03-29 17:41:26	2020-03-29	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	17675	delivery	5	31
44478	2020-03-29 17:41:43	2020-03-29	8	[{"id_menu":5,"count":1}]	609	pick-up	0	8
44479	2020-03-29 17:44:54	2020-03-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7632	delivery	5	36
44480	2020-03-29 17:45:24	2020-03-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7798	delivery	5	36
44481	2020-03-29 17:46:09	2020-03-29	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	466	delivery	5	45
44482	2020-03-29 17:46:21	2020-03-29	12	[{"id_menu":3,"count":1}]	757	delivery	5	17
44483	2020-03-29 17:46:23	2020-03-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	17614	delivery	5	26
44484	2020-03-29 17:50:08	2020-03-29	17	[{"id_menu":4,"count":1}]	8879	pick-up	0	17
44485	2020-03-29 17:56:26	2020-03-29	12	[{"id_menu":3,"count":1}]	6469	delivery	5	17
44486	2020-03-29 17:57:54	2020-03-29	9	[{"id_menu":7,"count":1}]	13666	delivery	5	14
44487	2020-03-29 18:00:08	2020-03-29	9	[{"id_menu":7,"count":1}]	13762	pick-up	0	9
44488	2020-03-29 18:01:37	2020-03-29	12	[{"id_menu":1,"count":1}]	11485	delivery	5	17
44489	2020-03-29 18:01:47	2020-03-29	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	10792	delivery	5	40
44490	2020-03-29 18:02:31	2020-03-29	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1741	pick-up	0	31
44491	2020-03-29 18:05:47	2020-03-29	9	[{"id_menu":7,"count":1}]	15242	delivery	5	14
44492	2020-03-29 18:07:58	2020-03-29	14	[{"id_menu":2,"count":1}]	17636	delivery	5	19
44493	2020-03-29 18:10:21	2020-03-29	9	[{"id_menu":6,"count":1}]	5035	pick-up	0	9
44494	2020-03-29 18:10:22	2020-03-29	14	[{"id_menu":2,"count":1}]	6238	pick-up	0	14
44495	2020-03-29 18:14:35	2020-03-29	9	[{"id_menu":6,"count":1}]	14139	pick-up	0	9
44496	2020-03-29 18:24:10	2020-03-29	9	[{"id_menu":6,"count":1}]	9420	pick-up	0	9
44497	2020-03-29 18:37:17	2020-03-29	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	14663	delivery	5	38
44498	2020-03-29 18:38:18	2020-03-29	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	17697	delivery	5	45
44499	2020-03-29 18:38:50	2020-03-29	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1659	pick-up	0	43
44500	2020-03-29 18:39:00	2020-03-29	17	[{"id_menu":4,"count":1}]	11495	pick-up	0	17
44501	2020-03-29 18:40:12	2020-03-29	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17658	delivery	5	45
44502	2020-03-29 18:40:18	2020-03-29	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	17625	delivery	5	39
44503	2020-03-29 18:45:18	2020-03-29	8	[{"id_menu":5,"count":1}]	15639	delivery	5	13
44504	2020-03-29 18:47:50	2020-03-29	9	[{"id_menu":7,"count":1}]	2523	pick-up	0	9
44505	2020-03-29 18:55:00	2020-03-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3659	pick-up	0	17
44506	2020-03-29 18:55:19	2020-03-29	17	[{"id_menu":4,"count":1}]	5081	delivery	5	22
44507	2020-03-29 19:01:33	2020-03-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	6787	delivery	5	23
44508	2020-03-29 19:04:55	2020-03-29	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17656	delivery	5	43
44509	2020-03-29 19:08:35	2020-03-29	17	[{"id_menu":4,"count":1}]	13504	pick-up	0	17
44510	2020-03-29 19:11:46	2020-03-29	8	[{"id_menu":5,"count":1}]	9352	delivery	5	13
44511	2020-03-29 19:13:42	2020-03-29	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	141	pick-up	0	37
44512	2020-03-29 19:14:54	2020-03-29	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3006	delivery	5	37
44513	2020-03-29 19:15:11	2020-03-29	9	[{"id_menu":7,"count":2}]	4991	delivery	5	14
44514	2020-03-29 19:17:54	2020-03-29	12	[{"id_menu":1,"count":1}]	17643	delivery	5	17
44515	2020-03-29 19:18:37	2020-03-29	8	[{"id_menu":5,"count":1}]	12976	delivery	5	13
44516	2020-03-29 19:18:42	2020-03-29	14	[{"id_menu":2,"count":1}]	8145	pick-up	0	14
44517	2020-03-29 19:20:01	2020-03-29	14	[{"id_menu":2,"count":1}]	17680	delivery	5	19
44518	2020-03-29 19:23:29	2020-03-29	9	[{"id_menu":6,"count":1}]	17604	pick-up	0	9
44519	2020-03-29 19:25:28	2020-03-29	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4127	delivery	5	55
44520	2020-03-29 19:35:41	2020-03-29	9	[{"id_menu":7,"count":2}]	10650	delivery	5	14
44521	2020-03-29 19:36:23	2020-03-29	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	17632	pick-up	0	25
44522	2020-03-29 19:40:03	2020-03-29	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	17606	delivery	5	40
44523	2020-03-29 19:42:34	2020-03-29	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	17706	delivery	5	25
44524	2020-03-29 19:45:11	2020-03-29	17	[{"id_menu":4,"count":1}]	17654	delivery	5	22
44525	2020-03-29 19:47:17	2020-03-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	17595	delivery	5	36
44526	2020-03-29 19:51:12	2020-03-29	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	66	pick-up	0	21
44527	2020-03-29 19:53:06	2020-03-29	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6445	delivery	5	45
44528	2020-03-29 19:56:01	2020-03-29	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	13951	pick-up	0	29
44529	2020-03-29 19:56:44	2020-03-29	8	[{"id_menu":5,"count":1}]	14752	delivery	5	13
44530	2020-03-29 20:00:03	2020-03-29	12	[{"id_menu":1,"count":1}]	1264	pick-up	0	12
44531	2020-03-29 20:01:13	2020-03-29	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":2}]	17653	delivery	5	28
44532	2020-03-29 20:01:54	2020-03-29	9	[{"id_menu":6,"count":1}]	17655	delivery	5	14
44533	2020-03-29 20:02:09	2020-03-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	7277	delivery	5	26
44534	2020-03-29 20:04:45	2020-03-29	9	[{"id_menu":6,"count":1}]	5013	delivery	5	14
44535	2020-03-29 20:05:04	2020-03-29	9	[{"id_menu":7,"count":1}]	12180	delivery	5	14
44536	2020-03-29 20:05:37	2020-03-29	17	[{"id_menu":4,"count":1}]	2055	pick-up	0	17
44537	2020-03-29 20:09:17	2020-03-29	9	[{"id_menu":7,"count":1}]	17683	delivery	5	14
44538	2020-03-29 20:13:51	2020-03-29	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":2}]	17704	delivery	5	29
44539	2020-03-29 20:14:32	2020-03-29	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	17608	delivery	5	30
44540	2020-03-29 20:20:54	2020-03-29	12	[{"id_menu":1,"count":2}]	9097	pick-up	0	12
44541	2020-03-29 20:24:40	2020-03-29	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	9750	pick-up	0	38
44542	2020-03-29 20:31:48	2020-03-29	9	[{"id_menu":6,"count":1}]	11181	delivery	5	14
44543	2020-03-29 20:37:00	2020-03-29	9	[{"id_menu":6,"count":1}]	6097	delivery	5	14
44544	2020-03-29 20:37:39	2020-03-29	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	17081	delivery	5	34
44545	2020-03-29 20:48:08	2020-03-29	14	[{"id_menu":2,"count":1}]	13689	delivery	5	19
44546	2020-03-29 20:50:23	2020-03-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	105	delivery	5	31
44547	2020-03-29 21:01:54	2020-03-29	17	[{"id_menu":4,"count":1}]	15722	delivery	5	22
44548	2020-03-29 21:05:23	2020-03-29	12	[{"id_menu":1,"count":1}]	17587	delivery	5	17
44549	2020-03-29 21:14:00	2020-03-29	9	[{"id_menu":7,"count":1}]	9531	delivery	5	14
44550	2020-03-29 21:17:12	2020-03-29	14	[{"id_menu":2,"count":1}]	1104	delivery	5	19
44551	2020-03-29 21:22:20	2020-03-29	12	[{"id_menu":1,"count":1}]	17642	delivery	5	17
44552	2020-03-29 21:24:02	2020-03-29	9	[{"id_menu":7,"count":1}]	16081	pick-up	0	9
44553	2020-03-29 21:24:03	2020-03-29	12	[{"id_menu":3,"count":1}]	17605	delivery	5	17
44554	2020-03-29 21:24:56	2020-03-29	12	[{"id_menu":1,"count":2}]	17568	delivery	5	17
44555	2020-03-29 21:28:12	2020-03-29	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	3494	pick-up	0	20
44556	2020-03-29 21:33:29	2020-03-29	8	[{"id_menu":5,"count":1}]	5281	pick-up	0	8
44557	2020-03-29 21:40:11	2020-03-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	17651	delivery	5	28
44558	2020-03-29 21:46:58	2020-03-29	12	[{"id_menu":3,"count":1}]	8109	delivery	5	17
44559	2020-03-29 21:49:06	2020-03-29	17	[{"id_menu":4,"count":1}]	4498	delivery	5	22
44560	2020-03-29 21:52:24	2020-03-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	3181	delivery	5	31
44561	2020-03-29 21:55:26	2020-03-29	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	12965	pick-up	0	20
44562	2020-03-29 22:04:34	2020-03-29	17	[{"id_menu":4,"count":1}]	11789	delivery	5	22
44563	2020-03-29 22:13:39	2020-03-29	9	[{"id_menu":7,"count":1}]	17624	delivery	5	14
44564	2020-03-29 22:14:41	2020-03-29	9	[{"id_menu":6,"count":1}]	12983	delivery	5	14
44565	2020-03-29 22:18:25	2020-03-29	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	8903	delivery	5	43
44566	2020-03-29 22:19:18	2020-03-29	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":2}]	4210	delivery	5	31
44567	2020-03-29 22:20:31	2020-03-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7252	pick-up	0	26
44568	2020-03-29 22:21:44	2020-03-29	8	[{"id_menu":5,"count":1}]	12078	delivery	5	13
44569	2020-03-29 22:21:57	2020-03-29	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	6470	pick-up	0	26
44570	2020-03-29 22:24:04	2020-03-29	12	[{"id_menu":1,"count":1}]	17702	pick-up	0	12
44571	2020-03-29 22:24:47	2020-03-29	17	[{"id_menu":4,"count":1}]	12287	delivery	5	22
44572	2020-03-29 22:25:46	2020-03-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	17641	delivery	5	26
44573	2020-03-29 22:43:16	2020-03-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1025	pick-up	0	21
44574	2020-03-29 22:44:43	2020-03-29	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17639	delivery	5	40
44575	2020-03-29 22:49:59	2020-03-29	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	17069	delivery	5	31
44576	2020-03-29 22:50:28	2020-03-29	8	[{"id_menu":5,"count":1}]	17572	delivery	5	13
44577	2020-03-29 22:52:41	2020-03-29	9	[{"id_menu":7,"count":1}]	17692	delivery	5	14
44578	2020-03-29 22:58:09	2020-03-29	12	[{"id_menu":3,"count":1}]	12285	pick-up	0	12
44579	2020-03-29 23:06:50	2020-03-29	17	[{"id_menu":4,"count":1}]	17669	delivery	5	22
44580	2020-03-29 23:17:45	2020-03-29	9	[{"id_menu":7,"count":1}]	10209	pick-up	0	9
44581	2020-03-29 23:19:59	2020-03-29	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	11881	delivery	5	40
44582	2020-03-29 23:23:35	2020-03-29	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	17601	delivery	5	31
44583	2020-03-29 23:26:22	2020-03-29	12	[{"id_menu":3,"count":1}]	17696	delivery	5	17
44584	2020-03-29 23:27:13	2020-03-29	9	[{"id_menu":6,"count":1}]	13688	delivery	5	14
44585	2020-03-29 23:28:19	2020-03-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":3}]	17637	delivery	5	22
44586	2020-03-29 23:30:02	2020-03-29	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	14647	delivery	5	34
44587	2020-03-29 23:31:18	2020-03-29	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8495	delivery	5	31
44588	2020-03-29 23:31:44	2020-03-29	8	[{"id_menu":5,"count":1}]	9966	delivery	5	13
44589	2020-03-29 23:32:24	2020-03-29	14	[{"id_menu":2,"count":1}]	7591	pick-up	0	14
44590	2020-03-29 23:34:22	2020-03-29	12	[{"id_menu":3,"count":1}]	6825	delivery	5	17
44591	2020-03-29 23:37:20	2020-03-29	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	17590	delivery	5	34
44592	2020-03-29 23:37:35	2020-03-29	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2706	delivery	5	42
44593	2020-03-29 23:43:06	2020-03-29	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	15353	delivery	5	31
44594	2020-03-29 23:46:22	2020-03-29	8	[{"id_menu":5,"count":1}]	17693	delivery	5	13
44595	2020-03-29 23:47:52	2020-03-29	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2089	delivery	5	40
44596	2020-03-29 23:48:18	2020-03-29	9	[{"id_menu":7,"count":2}]	15676	delivery	5	14
44597	2020-03-29 23:51:43	2020-03-29	8	[{"id_menu":5,"count":1}]	13905	delivery	5	13
44598	2020-03-29 23:53:38	2020-03-29	14	[{"id_menu":2,"count":1}]	4161	pick-up	0	14
44599	2020-03-29 23:53:57	2020-03-29	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11822	delivery	5	39
44600	2020-03-29 23:54:11	2020-03-29	8	[{"id_menu":5,"count":3}]	8410	delivery	5	13
44601	2020-03-30 00:01:48	2020-03-30	12	[{"id_menu":3,"count":1}]	13923	pick-up	0	12
44602	2020-03-30 00:07:00	2020-03-30	9	[{"id_menu":7,"count":1}]	6480	delivery	5	14
44603	2020-03-30 00:10:18	2020-03-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17796	delivery	5	23
44604	2020-03-30 00:28:11	2020-03-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	16450	delivery	5	28
44605	2020-03-30 00:28:57	2020-03-30	9	[{"id_menu":6,"count":1}]	9299	delivery	5	14
44606	2020-03-30 00:30:32	2020-03-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	11298	delivery	5	27
44607	2020-03-30 00:44:06	2020-03-30	8	[{"id_menu":5,"count":1}]	17814	delivery	5	13
44608	2020-03-30 00:51:06	2020-03-30	9	[{"id_menu":7,"count":1}]	14352	delivery	5	14
44609	2020-03-30 00:58:31	2020-03-30	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17318	delivery	5	39
44610	2020-03-30 01:08:48	2020-03-30	12	[{"id_menu":1,"count":1}]	561	pick-up	0	12
44611	2020-03-30 01:10:28	2020-03-30	14	[{"id_menu":2,"count":1}]	1334	delivery	5	19
44612	2020-03-30 01:13:41	2020-03-30	14	[{"id_menu":2,"count":1}]	17824	delivery	5	19
44613	2020-03-30 01:14:02	2020-03-30	12	[{"id_menu":3,"count":1}]	8228	delivery	5	17
44614	2020-03-30 01:14:06	2020-03-30	9	[{"id_menu":7,"count":1}]	11756	delivery	5	14
44615	2020-03-30 01:14:43	2020-03-30	12	[{"id_menu":1,"count":1}]	9752	delivery	5	17
44616	2020-03-30 01:17:27	2020-03-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	17716	pick-up	0	22
44617	2020-03-30 01:28:31	2020-03-30	17	[{"id_menu":4,"count":1}]	5329	delivery	5	22
44618	2020-03-30 01:34:10	2020-03-30	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	15120	pick-up	0	20
44619	2020-03-30 01:41:03	2020-03-30	12	[{"id_menu":1,"count":1}]	9	pick-up	0	12
44620	2020-03-30 01:43:59	2020-03-30	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17757	delivery	5	39
44621	2020-03-30 01:55:02	2020-03-30	12	[{"id_menu":1,"count":1}]	14562	pick-up	0	12
44622	2020-03-30 01:56:00	2020-03-30	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5031	delivery	5	48
44623	2020-03-30 01:59:15	2020-03-30	17	[{"id_menu":4,"count":1}]	10461	delivery	5	22
44624	2020-03-30 02:02:49	2020-03-30	9	[{"id_menu":7,"count":1}]	11896	pick-up	0	9
44625	2020-03-30 02:05:10	2020-03-30	9	[{"id_menu":6,"count":1}]	17760	delivery	5	14
44626	2020-03-30 02:20:22	2020-03-30	9	[{"id_menu":7,"count":1}]	4824	delivery	5	14
44627	2020-03-30 02:20:50	2020-03-30	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8398	delivery	5	35
44628	2020-03-30 02:22:02	2020-03-30	14	[{"id_menu":2,"count":1}]	17779	delivery	5	19
44629	2020-03-30 02:22:04	2020-03-30	12	[{"id_menu":3,"count":1}]	16797	delivery	5	17
44630	2020-03-30 02:25:05	2020-03-30	14	[{"id_menu":2,"count":1}]	16571	delivery	5	19
44631	2020-03-30 02:29:52	2020-03-30	9	[{"id_menu":7,"count":1}]	1409	pick-up	0	9
44632	2020-03-30 02:35:45	2020-03-30	12	[{"id_menu":3,"count":1}]	14338	delivery	5	17
44633	2020-03-30 02:43:50	2020-03-30	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17711	delivery	5	40
44634	2020-03-30 02:53:52	2020-03-30	9	[{"id_menu":7,"count":1}]	12390	delivery	5	14
44635	2020-03-30 02:54:13	2020-03-30	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	17791	delivery	5	36
44636	2020-03-30 02:54:56	2020-03-30	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	5872	delivery	5	36
44637	2020-03-30 02:54:57	2020-03-30	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	17719	delivery	5	23
44638	2020-03-30 02:56:07	2020-03-30	9	[{"id_menu":7,"count":1}]	2379	delivery	5	14
44639	2020-03-30 03:05:54	2020-03-30	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14218	delivery	5	22
44640	2020-03-30 03:08:56	2020-03-30	9	[{"id_menu":7,"count":1}]	17717	delivery	5	14
44641	2020-03-30 03:10:42	2020-03-30	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	9308	pick-up	0	31
44642	2020-03-30 03:13:05	2020-03-30	17	[{"id_menu":4,"count":1}]	6439	pick-up	0	17
44643	2020-03-30 03:20:34	2020-03-30	8	[{"id_menu":5,"count":1}]	17708	pick-up	0	8
44644	2020-03-30 03:23:51	2020-03-30	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	14533	delivery	5	36
44645	2020-03-30 03:25:10	2020-03-30	14	[{"id_menu":2,"count":1}]	4652	pick-up	0	14
44646	2020-03-30 03:28:00	2020-03-30	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	17764	pick-up	0	31
44647	2020-03-30 03:30:22	2020-03-30	8	[{"id_menu":5,"count":1}]	9695	delivery	5	13
44648	2020-03-30 03:42:58	2020-03-30	17	[{"id_menu":4,"count":1}]	11248	delivery	5	22
44649	2020-03-30 03:43:41	2020-03-30	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	14144	delivery	5	26
44650	2020-03-30 03:54:35	2020-03-30	9	[{"id_menu":6,"count":1}]	6562	pick-up	0	9
44651	2020-03-30 03:59:18	2020-03-30	17	[{"id_menu":4,"count":1}]	8767	delivery	5	22
44652	2020-03-30 04:01:47	2020-03-30	14	[{"id_menu":2,"count":1}]	17145	delivery	5	19
44653	2020-03-30 04:03:10	2020-03-30	12	[{"id_menu":1,"count":1}]	13537	pick-up	0	12
44654	2020-03-30 04:07:29	2020-03-30	12	[{"id_menu":1,"count":1}]	2333	pick-up	0	12
44655	2020-03-30 04:19:20	2020-03-30	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	17758	delivery	5	25
44656	2020-03-30 04:25:20	2020-03-30	8	[{"id_menu":5,"count":1}]	8744	delivery	5	13
44657	2020-03-30 04:32:50	2020-03-30	9	[{"id_menu":6,"count":2}]	17813	delivery	5	14
44658	2020-03-30 04:42:14	2020-03-30	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17769	delivery	5	22
44659	2020-03-30 04:43:55	2020-03-30	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	12577	pick-up	0	21
44660	2020-03-30 04:49:39	2020-03-30	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12793	delivery	5	57
44661	2020-03-30 04:51:20	2020-03-30	9	[{"id_menu":6,"count":1}]	17731	delivery	5	14
44662	2020-03-30 04:54:49	2020-03-30	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	17258	delivery	5	34
44663	2020-03-30 05:02:46	2020-03-30	12	[{"id_menu":1,"count":1}]	13754	delivery	5	17
44664	2020-03-30 05:05:02	2020-03-30	9	[{"id_menu":7,"count":1}]	2602	pick-up	0	9
44665	2020-03-30 05:05:56	2020-03-30	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	10810	delivery	5	29
44666	2020-03-30 05:15:38	2020-03-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	17773	delivery	5	22
44667	2020-03-30 05:21:35	2020-03-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4170	pick-up	0	22
44668	2020-03-30 05:26:46	2020-03-30	12	[{"id_menu":3,"count":1}]	17782	delivery	5	17
44669	2020-03-30 05:32:21	2020-03-30	12	[{"id_menu":3,"count":1}]	563	pick-up	0	12
44670	2020-03-30 05:39:16	2020-03-30	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	17805	pick-up	0	24
44671	2020-03-30 05:45:39	2020-03-30	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	17811	delivery	5	36
44672	2020-03-30 05:56:43	2020-03-30	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2504	delivery	5	46
44673	2020-03-30 06:03:46	2020-03-30	17	[{"id_menu":4,"count":2}]	17797	delivery	5	22
44674	2020-03-30 06:06:52	2020-03-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	17053	delivery	5	28
44675	2020-03-30 06:10:57	2020-03-30	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15491	delivery	5	43
44676	2020-03-30 06:20:53	2020-03-30	14	[{"id_menu":2,"count":1}]	1988	pick-up	0	14
44677	2020-03-30 06:23:15	2020-03-30	9	[{"id_menu":7,"count":1}]	13743	delivery	5	14
44678	2020-03-30 06:24:04	2020-03-30	9	[{"id_menu":7,"count":1}]	7840	delivery	5	14
44679	2020-03-30 06:29:08	2020-03-30	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	7494	delivery	5	38
44680	2020-03-30 06:29:09	2020-03-30	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17756	delivery	5	35
44681	2020-03-30 06:29:12	2020-03-30	17	[{"id_menu":4,"count":1}]	1900	pick-up	0	17
44682	2020-03-30 06:32:47	2020-03-30	8	[{"id_menu":5,"count":1}]	10729	delivery	5	13
44683	2020-03-30 06:38:17	2020-03-30	12	[{"id_menu":1,"count":1}]	17786	pick-up	0	12
44684	2020-03-30 06:48:01	2020-03-30	9	[{"id_menu":7,"count":1}]	13341	delivery	5	14
44685	2020-03-30 06:50:32	2020-03-30	14	[{"id_menu":2,"count":1}]	11969	pick-up	0	14
44686	2020-03-30 06:54:48	2020-03-30	17	[{"id_menu":4,"count":1}]	4190	delivery	5	22
44687	2020-03-30 07:00:12	2020-03-30	9	[{"id_menu":7,"count":1}]	17822	delivery	5	14
44688	2020-03-30 07:05:33	2020-03-30	8	[{"id_menu":5,"count":1}]	9923	delivery	5	13
44689	2020-03-30 07:22:45	2020-03-30	9	[{"id_menu":6,"count":1}]	8101	delivery	5	14
44690	2020-03-30 07:34:19	2020-03-30	9	[{"id_menu":7,"count":1}]	3129	delivery	5	14
44691	2020-03-30 07:34:28	2020-03-30	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	9562	pick-up	0	31
44692	2020-03-30 07:35:30	2020-03-30	8	[{"id_menu":5,"count":1}]	17046	pick-up	0	8
44693	2020-03-30 07:38:08	2020-03-30	9	[{"id_menu":6,"count":1}]	2982	delivery	5	14
44694	2020-03-30 07:38:35	2020-03-30	12	[{"id_menu":1,"count":1}]	16426	delivery	5	17
44695	2020-03-30 07:56:30	2020-03-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	9287	delivery	5	27
44696	2020-03-30 07:57:15	2020-03-30	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	4793	pick-up	0	24
44697	2020-03-30 07:58:14	2020-03-30	14	[{"id_menu":2,"count":1}]	17763	delivery	5	19
44698	2020-03-30 08:00:02	2020-03-30	9	[{"id_menu":6,"count":1}]	11449	pick-up	0	9
44699	2020-03-30 08:02:34	2020-03-30	9	[{"id_menu":7,"count":1}]	8300	pick-up	0	9
44700	2020-03-30 08:10:09	2020-03-30	17	[{"id_menu":4,"count":1}]	4370	pick-up	0	17
44701	2020-03-30 08:12:09	2020-03-30	17	[{"id_menu":4,"count":1}]	17755	delivery	5	22
44702	2020-03-30 08:12:52	2020-03-30	14	[{"id_menu":2,"count":1}]	10372	delivery	5	19
44703	2020-03-30 08:12:56	2020-03-30	8	[{"id_menu":5,"count":1}]	12933	delivery	5	13
44704	2020-03-30 08:21:41	2020-03-30	17	[{"id_menu":4,"count":1}]	3600	delivery	5	22
44705	2020-03-30 08:24:50	2020-03-30	14	[{"id_menu":2,"count":1}]	17802	delivery	5	19
44706	2020-03-30 08:26:44	2020-03-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	17800	delivery	5	26
44707	2020-03-30 08:43:27	2020-03-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	17821	delivery	5	28
44708	2020-03-30 08:46:29	2020-03-30	14	[{"id_menu":2,"count":1}]	17766	delivery	5	19
44709	2020-03-30 08:52:36	2020-03-30	14	[{"id_menu":2,"count":1}]	5238	pick-up	0	14
44710	2020-03-30 08:55:47	2020-03-30	9	[{"id_menu":6,"count":1}]	17803	delivery	5	14
44711	2020-03-30 09:15:17	2020-03-30	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	16897	delivery	5	36
44712	2020-03-30 09:21:17	2020-03-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	13415	delivery	5	27
44713	2020-03-30 09:37:03	2020-03-30	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":2}]	15444	delivery	5	28
44714	2020-03-30 09:42:06	2020-03-30	14	[{"id_menu":2,"count":1}]	17753	delivery	5	19
44715	2020-03-30 09:46:36	2020-03-30	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14175	delivery	5	43
44716	2020-03-30 09:52:32	2020-03-30	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10210	delivery	5	34
44717	2020-03-30 09:55:19	2020-03-30	12	[{"id_menu":3,"count":1}]	16494	delivery	5	17
44718	2020-03-30 10:03:27	2020-03-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5977	delivery	5	31
44719	2020-03-30 10:06:56	2020-03-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	9825	delivery	5	22
44720	2020-03-30 10:09:50	2020-03-30	9	[{"id_menu":7,"count":4}]	6664	delivery	5	14
44721	2020-03-30 10:16:11	2020-03-30	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15052	pick-up	0	17
44722	2020-03-30 10:23:14	2020-03-30	9	[{"id_menu":7,"count":1}]	1026	pick-up	0	9
44723	2020-03-30 10:33:24	2020-03-30	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1736	delivery	5	26
44724	2020-03-30 10:34:24	2020-03-30	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	17787	delivery	5	46
44725	2020-03-30 10:51:19	2020-03-30	9	[{"id_menu":6,"count":1}]	15078	delivery	5	14
44726	2020-03-30 10:56:56	2020-03-30	14	[{"id_menu":2,"count":1}]	5143	pick-up	0	14
44727	2020-03-30 11:03:26	2020-03-30	12	[{"id_menu":3,"count":1}]	17759	delivery	5	17
44728	2020-03-30 11:04:33	2020-03-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	10866	delivery	5	31
44729	2020-03-30 11:13:52	2020-03-30	12	[{"id_menu":1,"count":1}]	9716	pick-up	0	12
44730	2020-03-30 11:20:16	2020-03-30	9	[{"id_menu":6,"count":1}]	13582	delivery	5	14
44731	2020-03-30 11:33:02	2020-03-30	12	[{"id_menu":3,"count":1}]	8397	delivery	5	17
44732	2020-03-30 11:42:15	2020-03-30	14	[{"id_menu":2,"count":2}]	6339	delivery	5	19
44733	2020-03-30 11:44:21	2020-03-30	9	[{"id_menu":7,"count":1}]	6811	delivery	5	14
44734	2020-03-30 11:46:12	2020-03-30	9	[{"id_menu":6,"count":1}]	11628	delivery	5	14
44735	2020-03-30 11:50:27	2020-03-30	17	[{"id_menu":4,"count":1}]	2947	pick-up	0	17
44736	2020-03-30 12:19:09	2020-03-30	8	[{"id_menu":5,"count":1}]	13901	delivery	5	13
44737	2020-03-30 12:22:28	2020-03-30	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	3463	pick-up	0	29
44738	2020-03-30 12:27:38	2020-03-30	12	[{"id_menu":1,"count":1}]	10827	delivery	5	17
44739	2020-03-30 12:28:32	2020-03-30	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5663	delivery	5	36
44740	2020-03-30 12:31:20	2020-03-30	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11170	delivery	5	55
44741	2020-03-30 12:31:43	2020-03-30	12	[{"id_menu":1,"count":1}]	17794	delivery	5	17
44742	2020-03-30 12:38:42	2020-03-30	9	[{"id_menu":7,"count":1}]	12435	delivery	5	14
44743	2020-03-30 12:40:51	2020-03-30	8	[{"id_menu":5,"count":1}]	8146	pick-up	0	8
44744	2020-03-30 12:45:04	2020-03-30	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	4398	delivery	5	43
44745	2020-03-30 12:46:59	2020-03-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	17734	delivery	5	26
44746	2020-03-30 12:52:28	2020-03-30	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	75	delivery	5	34
44747	2020-03-30 12:59:25	2020-03-30	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	749	delivery	5	43
44748	2020-03-30 13:03:18	2020-03-30	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	15880	pick-up	0	25
44749	2020-03-30 13:05:27	2020-03-30	14	[{"id_menu":2,"count":1}]	2426	delivery	5	19
44750	2020-03-30 13:27:15	2020-03-30	9	[{"id_menu":7,"count":1}]	4601	delivery	5	14
44751	2020-03-30 13:32:02	2020-03-30	12	[{"id_menu":3,"count":1}]	4810	pick-up	0	12
44752	2020-03-30 13:36:43	2020-03-30	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	13082	delivery	5	27
44753	2020-03-30 13:37:08	2020-03-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	17751	delivery	5	27
44754	2020-03-30 13:52:20	2020-03-30	8	[{"id_menu":5,"count":1}]	17784	pick-up	0	8
44755	2020-03-30 13:56:22	2020-03-30	14	[{"id_menu":2,"count":1}]	17810	delivery	5	19
44756	2020-03-30 13:59:22	2020-03-30	12	[{"id_menu":1,"count":1}]	1676	pick-up	0	12
44757	2020-03-30 14:04:26	2020-03-30	8	[{"id_menu":5,"count":1}]	10246	delivery	5	13
44758	2020-03-30 14:15:23	2020-03-30	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	3726	delivery	5	43
44759	2020-03-30 14:20:47	2020-03-30	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	17816	pick-up	0	35
44760	2020-03-30 14:21:13	2020-03-30	12	[{"id_menu":1,"count":1}]	4079	delivery	5	17
44761	2020-03-30 14:27:24	2020-03-30	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15709	delivery	5	40
44762	2020-03-30 14:34:29	2020-03-30	9	[{"id_menu":6,"count":1}]	17707	delivery	5	14
44763	2020-03-30 14:40:09	2020-03-30	12	[{"id_menu":3,"count":1}]	17709	delivery	5	17
44764	2020-03-30 15:04:28	2020-03-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17737	delivery	5	31
44765	2020-03-30 15:12:47	2020-03-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17762	delivery	5	31
44766	2020-03-30 15:13:01	2020-03-30	9	[{"id_menu":6,"count":1}]	15368	delivery	5	14
44767	2020-03-30 15:19:34	2020-03-30	9	[{"id_menu":6,"count":2}]	17798	pick-up	0	9
44768	2020-03-30 15:27:53	2020-03-30	9	[{"id_menu":6,"count":2}]	2833	delivery	5	14
44769	2020-03-30 15:28:10	2020-03-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8477	pick-up	0	23
44770	2020-03-30 15:38:01	2020-03-30	12	[{"id_menu":1,"count":2}]	3494	pick-up	0	12
44771	2020-03-30 15:49:34	2020-03-30	17	[{"id_menu":4,"count":1}]	7741	delivery	5	22
44772	2020-03-30 15:54:03	2020-03-30	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1993	delivery	5	52
44773	2020-03-30 15:55:07	2020-03-30	9	[{"id_menu":6,"count":1}]	17732	delivery	5	14
44774	2020-03-30 15:57:33	2020-03-30	17	[{"id_menu":4,"count":1}]	2561	pick-up	0	17
44775	2020-03-30 16:00:33	2020-03-30	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	9315	delivery	5	34
44776	2020-03-30 16:07:23	2020-03-30	9	[{"id_menu":7,"count":1}]	17723	pick-up	0	9
44777	2020-03-30 16:08:49	2020-03-30	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	17715	delivery	5	31
44778	2020-03-30 16:09:12	2020-03-30	8	[{"id_menu":5,"count":1}]	11183	pick-up	0	8
44779	2020-03-30 16:12:01	2020-03-30	8	[{"id_menu":5,"count":1}]	17720	delivery	5	13
44780	2020-03-30 16:33:48	2020-03-30	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11037	delivery	5	55
44781	2020-03-30 16:34:08	2020-03-30	9	[{"id_menu":6,"count":1}]	17744	delivery	5	14
44782	2020-03-30 16:36:34	2020-03-30	9	[{"id_menu":7,"count":1}]	12772	delivery	5	14
44783	2020-03-30 16:41:41	2020-03-30	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	7235	delivery	5	46
44784	2020-03-30 16:43:15	2020-03-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":3}]	5822	delivery	5	26
44785	2020-03-30 16:47:10	2020-03-30	8	[{"id_menu":5,"count":1}]	3997	delivery	5	13
44786	2020-03-30 16:51:27	2020-03-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11467	delivery	5	23
44787	2020-03-30 16:52:11	2020-03-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13735	delivery	5	23
44788	2020-03-30 16:53:02	2020-03-30	9	[{"id_menu":6,"count":1}]	13615	delivery	5	14
44789	2020-03-30 16:55:52	2020-03-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	17795	delivery	5	26
44790	2020-03-30 17:01:51	2020-03-30	14	[{"id_menu":2,"count":1}]	14221	delivery	5	19
44791	2020-03-30 17:10:32	2020-03-30	9	[{"id_menu":7,"count":1}]	13351	delivery	5	14
44792	2020-03-30 17:28:27	2020-03-30	9	[{"id_menu":6,"count":1}]	15679	delivery	5	14
44793	2020-03-30 17:39:29	2020-03-30	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	126	delivery	5	39
44794	2020-03-30 17:49:51	2020-03-30	17	[{"id_menu":4,"count":1}]	875	delivery	5	22
44795	2020-03-30 17:57:30	2020-03-30	9	[{"id_menu":7,"count":1}]	17721	delivery	5	14
44796	2020-03-30 17:58:55	2020-03-30	14	[{"id_menu":2,"count":1}]	7772	delivery	5	19
44797	2020-03-30 17:59:57	2020-03-30	8	[{"id_menu":5,"count":1}]	17742	delivery	5	13
44798	2020-03-30 18:01:37	2020-03-30	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	17741	delivery	5	26
44799	2020-03-30 18:02:44	2020-03-30	17	[{"id_menu":4,"count":1}]	1485	pick-up	0	17
44800	2020-03-30 18:21:06	2020-03-30	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	9975	pick-up	0	26
44801	2020-03-30 18:48:53	2020-03-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	15313	delivery	5	27
44802	2020-03-30 19:09:18	2020-03-30	17	[{"id_menu":4,"count":1}]	10283	pick-up	0	17
44803	2020-03-30 19:12:55	2020-03-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17789	delivery	5	22
44804	2020-03-30 19:14:22	2020-03-30	17	[{"id_menu":4,"count":1}]	83	pick-up	0	17
44805	2020-03-30 19:14:22	2020-03-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	7217	delivery	5	26
44806	2020-03-30 19:16:40	2020-03-30	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	11760	delivery	5	22
44807	2020-03-30 19:17:41	2020-03-30	9	[{"id_menu":6,"count":1}]	17754	pick-up	0	9
44808	2020-03-30 19:24:17	2020-03-30	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	15022	delivery	5	34
44809	2020-03-30 19:40:28	2020-03-30	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	396	pick-up	0	40
44810	2020-03-30 19:41:33	2020-03-30	14	[{"id_menu":2,"count":1}]	17809	delivery	5	19
44811	2020-03-30 19:43:26	2020-03-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11104	delivery	5	22
44812	2020-03-30 19:58:15	2020-03-30	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	17722	delivery	5	26
44813	2020-03-30 20:06:33	2020-03-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	14840	pick-up	0	23
44814	2020-03-30 20:08:53	2020-03-30	14	[{"id_menu":2,"count":1}]	2082	pick-up	0	14
44815	2020-03-30 20:11:57	2020-03-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	17740	pick-up	0	22
44816	2020-03-30 20:15:07	2020-03-30	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3452	delivery	5	42
44817	2020-03-30 20:27:05	2020-03-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	10883	delivery	5	28
44818	2020-03-30 20:36:39	2020-03-30	8	[{"id_menu":5,"count":1}]	3705	delivery	5	13
44819	2020-03-30 20:43:41	2020-03-30	14	[{"id_menu":2,"count":1}]	3287	pick-up	0	14
44820	2020-03-30 20:53:37	2020-03-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	8418	pick-up	0	23
44821	2020-03-30 21:00:29	2020-03-30	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	17812	pick-up	0	26
44822	2020-03-30 21:06:41	2020-03-30	14	[{"id_menu":2,"count":1}]	3853	delivery	5	19
44823	2020-03-30 21:23:32	2020-03-30	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17792	delivery	5	31
44824	2020-03-30 21:24:57	2020-03-30	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	2928	pick-up	0	29
44825	2020-03-30 21:25:12	2020-03-30	12	[{"id_menu":3,"count":1}]	7489	delivery	5	17
44826	2020-03-30 21:27:26	2020-03-30	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	8632	pick-up	0	26
44827	2020-03-30 21:33:48	2020-03-30	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12474	pick-up	0	34
44828	2020-03-30 21:35:17	2020-03-30	17	[{"id_menu":4,"count":1}]	17770	delivery	5	22
44829	2020-03-30 21:39:00	2020-03-30	9	[{"id_menu":7,"count":1}]	17790	delivery	5	14
44830	2020-03-30 21:40:14	2020-03-30	9	[{"id_menu":6,"count":1}]	17799	delivery	5	14
44831	2020-03-30 21:45:20	2020-03-30	12	[{"id_menu":1,"count":1}]	17785	delivery	5	17
44832	2020-03-30 21:50:16	2020-03-30	9	[{"id_menu":7,"count":1}]	13918	delivery	5	14
44833	2020-03-30 22:05:07	2020-03-30	14	[{"id_menu":2,"count":1}]	17819	delivery	5	19
44834	2020-03-30 22:06:31	2020-03-30	9	[{"id_menu":6,"count":1}]	17783	delivery	5	14
44835	2020-03-30 22:06:57	2020-03-30	14	[{"id_menu":2,"count":1}]	3024	pick-up	0	14
44836	2020-03-30 22:22:58	2020-03-30	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	4710	pick-up	0	22
44837	2020-03-30 22:33:15	2020-03-30	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	15795	pick-up	0	20
44838	2020-03-30 22:34:49	2020-03-30	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	16404	delivery	5	42
44839	2020-03-30 22:39:41	2020-03-30	9	[{"id_menu":6,"count":1}]	12078	delivery	5	14
44840	2020-03-30 22:50:14	2020-03-30	12	[{"id_menu":3,"count":1}]	8098	delivery	5	17
44841	2020-03-30 22:57:25	2020-03-30	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13101	delivery	5	35
44842	2020-03-30 22:59:14	2020-03-30	14	[{"id_menu":2,"count":1}]	17767	delivery	5	19
44843	2020-03-30 23:00:57	2020-03-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	17788	pick-up	0	22
44844	2020-03-30 23:09:56	2020-03-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8792	delivery	5	28
44845	2020-03-30 23:16:03	2020-03-30	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	17771	delivery	5	40
44846	2020-03-30 23:16:03	2020-03-30	9	[{"id_menu":7,"count":1}]	6470	pick-up	0	9
44847	2020-03-30 23:20:02	2020-03-30	14	[{"id_menu":2,"count":1}]	80	pick-up	0	14
44848	2020-03-30 23:32:14	2020-03-30	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17728	delivery	5	22
44849	2020-03-30 23:33:00	2020-03-30	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	1896	pick-up	0	40
44850	2020-03-30 23:35:52	2020-03-30	17	[{"id_menu":4,"count":1}]	14897	delivery	5	22
44851	2020-03-30 23:46:47	2020-03-30	9	[{"id_menu":7,"count":1}]	15129	delivery	5	14
44852	2020-03-30 23:47:32	2020-03-30	9	[{"id_menu":7,"count":1}]	722	delivery	5	14
44853	2020-03-30 23:48:13	2020-03-30	9	[{"id_menu":6,"count":1}]	17733	delivery	5	14
44854	2020-03-30 23:51:21	2020-03-30	17	[{"id_menu":4,"count":1}]	12290	delivery	5	22
44855	2020-03-30 23:55:21	2020-03-30	8	[{"id_menu":5,"count":1}]	6801	delivery	5	13
44856	2020-03-30 23:59:38	2020-03-30	9	[{"id_menu":6,"count":1}]	11277	delivery	5	14
44857	2020-03-31 00:10:07	2020-03-31	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	17864	delivery	5	38
44858	2020-03-31 00:15:41	2020-03-31	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16874	delivery	5	31
44859	2020-03-31 00:28:10	2020-03-31	9	[{"id_menu":6,"count":3}]	7190	delivery	5	14
44860	2020-03-31 00:29:49	2020-03-31	9	[{"id_menu":6,"count":1}]	17879	delivery	5	14
44861	2020-03-31 00:31:48	2020-03-31	12	[{"id_menu":3,"count":1}]	17847	delivery	5	17
44862	2020-03-31 00:32:26	2020-03-31	17	[{"id_menu":4,"count":1}]	7234	delivery	5	22
44863	2020-03-31 00:44:58	2020-03-31	12	[{"id_menu":1,"count":1}]	12076	delivery	5	17
44864	2020-03-31 00:45:19	2020-03-31	8	[{"id_menu":5,"count":1}]	3976	delivery	5	13
44865	2020-03-31 00:56:10	2020-03-31	9	[{"id_menu":7,"count":1}]	17911	delivery	5	14
44866	2020-03-31 01:03:34	2020-03-31	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17923	delivery	5	36
44867	2020-03-31 01:04:07	2020-03-31	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	17878	delivery	5	26
44868	2020-03-31 01:06:08	2020-03-31	14	[{"id_menu":2,"count":2}]	17909	delivery	5	19
44869	2020-03-31 01:07:14	2020-03-31	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12733	delivery	5	36
44870	2020-03-31 01:11:36	2020-03-31	8	[{"id_menu":5,"count":1}]	15205	delivery	5	13
44871	2020-03-31 01:22:45	2020-03-31	9	[{"id_menu":6,"count":1}]	15028	delivery	5	14
44872	2020-03-31 01:24:46	2020-03-31	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	17949	delivery	5	26
44873	2020-03-31 01:29:48	2020-03-31	12	[{"id_menu":3,"count":1}]	14146	delivery	5	17
44874	2020-03-31 01:32:32	2020-03-31	17	[{"id_menu":4,"count":1}]	17829	pick-up	0	17
44875	2020-03-31 01:46:39	2020-03-31	9	[{"id_menu":6,"count":2}]	17862	delivery	5	14
44876	2020-03-31 01:47:21	2020-03-31	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	17922	delivery	5	38
44877	2020-03-31 01:50:26	2020-03-31	12	[{"id_menu":3,"count":1}]	5361	delivery	5	17
44878	2020-03-31 01:50:34	2020-03-31	9	[{"id_menu":7,"count":1}]	15611	delivery	5	14
44879	2020-03-31 01:52:51	2020-03-31	9	[{"id_menu":7,"count":1}]	13615	delivery	5	14
44880	2020-03-31 01:59:24	2020-03-31	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	13662	pick-up	0	21
44881	2020-03-31 01:59:39	2020-03-31	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	21	pick-up	0	24
44882	2020-03-31 02:03:59	2020-03-31	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15749	delivery	5	37
44883	2020-03-31 02:05:03	2020-03-31	8	[{"id_menu":5,"count":1}]	16942	delivery	5	13
44884	2020-03-31 02:05:26	2020-03-31	9	[{"id_menu":7,"count":1}]	17915	delivery	5	14
44885	2020-03-31 02:07:00	2020-03-31	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	13183	delivery	5	26
44886	2020-03-31 02:09:27	2020-03-31	9	[{"id_menu":7,"count":1}]	17848	delivery	5	14
44887	2020-03-31 02:11:05	2020-03-31	9	[{"id_menu":6,"count":1}]	17896	delivery	5	14
44888	2020-03-31 02:17:01	2020-03-31	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	11591	delivery	5	28
44889	2020-03-31 02:17:34	2020-03-31	9	[{"id_menu":7,"count":1}]	11773	delivery	5	14
44890	2020-03-31 02:17:38	2020-03-31	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	17919	delivery	5	34
44891	2020-03-31 02:22:07	2020-03-31	14	[{"id_menu":2,"count":3}]	2827	pick-up	0	14
44892	2020-03-31 02:25:40	2020-03-31	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12564	delivery	5	22
44893	2020-03-31 02:27:09	2020-03-31	9	[{"id_menu":7,"count":1}]	10785	delivery	5	14
44894	2020-03-31 02:28:24	2020-03-31	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17936	delivery	5	45
44895	2020-03-31 02:33:56	2020-03-31	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4802	delivery	5	22
44896	2020-03-31 02:35:07	2020-03-31	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	15263	delivery	5	22
44897	2020-03-31 02:39:29	2020-03-31	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1792	pick-up	0	23
44898	2020-03-31 02:39:54	2020-03-31	9	[{"id_menu":7,"count":1}]	6039	pick-up	0	9
44899	2020-03-31 02:45:31	2020-03-31	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	283	delivery	5	37
44900	2020-03-31 02:47:49	2020-03-31	8	[{"id_menu":5,"count":1}]	17893	delivery	5	13
44901	2020-03-31 02:57:41	2020-03-31	9	[{"id_menu":7,"count":1}]	4281	delivery	5	14
44902	2020-03-31 03:10:21	2020-03-31	12	[{"id_menu":3,"count":1}]	17844	delivery	5	17
44903	2020-03-31 03:17:47	2020-03-31	9	[{"id_menu":7,"count":1}]	11711	pick-up	0	9
44904	2020-03-31 03:18:04	2020-03-31	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3115	pick-up	0	23
44905	2020-03-31 03:25:27	2020-03-31	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	11197	delivery	5	28
44906	2020-03-31 03:25:53	2020-03-31	9	[{"id_menu":6,"count":1}]	13319	pick-up	0	9
44907	2020-03-31 03:28:26	2020-03-31	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	1373	pick-up	0	29
44908	2020-03-31 03:30:35	2020-03-31	9	[{"id_menu":7,"count":1}]	3935	delivery	5	14
44909	2020-03-31 03:41:59	2020-03-31	9	[{"id_menu":6,"count":1}]	6385	pick-up	0	9
44910	2020-03-31 03:47:34	2020-03-31	8	[{"id_menu":5,"count":1}]	17952	delivery	5	13
44911	2020-03-31 03:53:42	2020-03-31	14	[{"id_menu":2,"count":1}]	2897	pick-up	0	14
44912	2020-03-31 03:54:02	2020-03-31	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	12894	delivery	5	22
44913	2020-03-31 04:02:53	2020-03-31	9	[{"id_menu":7,"count":1}]	8346	delivery	5	14
44914	2020-03-31 04:05:17	2020-03-31	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	7298	delivery	5	26
44915	2020-03-31 04:08:45	2020-03-31	9	[{"id_menu":7,"count":1}]	1110	pick-up	0	9
44916	2020-03-31 04:12:44	2020-03-31	9	[{"id_menu":6,"count":1}]	17858	delivery	5	14
44917	2020-03-31 04:14:13	2020-03-31	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2343	pick-up	0	43
44918	2020-03-31 04:15:36	2020-03-31	12	[{"id_menu":1,"count":1}]	17918	delivery	5	17
44919	2020-03-31 04:23:14	2020-03-31	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9188	delivery	5	31
44920	2020-03-31 04:31:34	2020-03-31	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	17861	pick-up	0	23
44921	2020-03-31 04:35:24	2020-03-31	17	[{"id_menu":4,"count":1}]	17176	delivery	5	22
44922	2020-03-31 04:46:49	2020-03-31	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	8726	delivery	5	26
44923	2020-03-31 04:49:38	2020-03-31	17	[{"id_menu":4,"count":1}]	7328	pick-up	0	17
44924	2020-03-31 04:52:28	2020-03-31	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17830	delivery	5	23
44925	2020-03-31 04:59:41	2020-03-31	9	[{"id_menu":6,"count":1}]	15815	delivery	5	14
44926	2020-03-31 05:00:06	2020-03-31	9	[{"id_menu":7,"count":1}]	15394	delivery	5	14
44927	2020-03-31 05:06:25	2020-03-31	12	[{"id_menu":3,"count":1}]	9318	delivery	5	17
44928	2020-03-31 05:13:02	2020-03-31	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	17840	delivery	5	37
44929	2020-03-31 05:13:05	2020-03-31	9	[{"id_menu":6,"count":2}]	786	delivery	5	14
44930	2020-03-31 05:44:55	2020-03-31	17	[{"id_menu":4,"count":1}]	7032	pick-up	0	17
44931	2020-03-31 05:44:56	2020-03-31	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6234	delivery	5	22
44932	2020-03-31 06:11:44	2020-03-31	9	[{"id_menu":7,"count":1}]	14202	delivery	5	14
44933	2020-03-31 06:17:24	2020-03-31	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	15009	delivery	5	28
44934	2020-03-31 06:21:48	2020-03-31	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10748	delivery	5	42
44935	2020-03-31 06:25:10	2020-03-31	9	[{"id_menu":7,"count":1}]	934	pick-up	0	9
44936	2020-03-31 06:26:58	2020-03-31	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17835	delivery	5	45
44937	2020-03-31 06:30:49	2020-03-31	8	[{"id_menu":5,"count":2}]	17461	delivery	5	13
44938	2020-03-31 06:37:23	2020-03-31	9	[{"id_menu":7,"count":1}]	7468	delivery	5	14
44939	2020-03-31 06:39:33	2020-03-31	12	[{"id_menu":1,"count":1}]	8870	delivery	5	17
44940	2020-03-31 06:41:27	2020-03-31	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5453	delivery	5	31
44941	2020-03-31 06:53:49	2020-03-31	14	[{"id_menu":2,"count":1}]	12378	delivery	5	19
44942	2020-03-31 06:55:01	2020-03-31	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	9226	delivery	5	43
44943	2020-03-31 06:57:16	2020-03-31	8	[{"id_menu":5,"count":2}]	14679	pick-up	0	8
44944	2020-03-31 06:57:16	2020-03-31	8	[{"id_menu":5,"count":1}]	17828	delivery	5	13
44945	2020-03-31 06:57:24	2020-03-31	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	17938	pick-up	0	31
44946	2020-03-31 07:09:38	2020-03-31	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	17913	delivery	5	26
44947	2020-03-31 07:09:51	2020-03-31	9	[{"id_menu":6,"count":1}]	17841	delivery	5	14
44948	2020-03-31 07:16:58	2020-03-31	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":2}]	9937	delivery	5	25
44949	2020-03-31 07:25:32	2020-03-31	12	[{"id_menu":1,"count":1}]	6635	delivery	5	17
44950	2020-03-31 07:37:32	2020-03-31	12	[{"id_menu":1,"count":1}]	16613	delivery	5	17
44951	2020-03-31 07:45:15	2020-03-31	14	[{"id_menu":2,"count":1}]	531	pick-up	0	14
44952	2020-03-31 07:47:05	2020-03-31	14	[{"id_menu":2,"count":1}]	3850	delivery	5	19
44953	2020-03-31 08:19:12	2020-03-31	9	[{"id_menu":6,"count":1}]	13568	delivery	5	14
44954	2020-03-31 08:19:30	2020-03-31	14	[{"id_menu":2,"count":1}]	11897	pick-up	0	14
44955	2020-03-31 08:22:26	2020-03-31	8	[{"id_menu":5,"count":1}]	10764	delivery	5	13
44956	2020-03-31 08:25:59	2020-03-31	14	[{"id_menu":2,"count":1}]	17914	delivery	5	19
44957	2020-03-31 08:26:58	2020-03-31	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2780	pick-up	0	43
44958	2020-03-31 08:34:17	2020-03-31	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17866	delivery	5	31
44959	2020-03-31 08:39:45	2020-03-31	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1393	delivery	5	31
44960	2020-03-31 08:40:41	2020-03-31	8	[{"id_menu":5,"count":1}]	14013	delivery	5	13
44961	2020-03-31 08:42:38	2020-03-31	9	[{"id_menu":6,"count":1}]	7265	delivery	5	14
44962	2020-03-31 08:43:13	2020-03-31	8	[{"id_menu":5,"count":1}]	8119	delivery	5	13
44963	2020-03-31 08:48:04	2020-03-31	12	[{"id_menu":3,"count":1}]	10548	pick-up	0	12
44964	2020-03-31 09:17:51	2020-03-31	8	[{"id_menu":5,"count":1}]	17885	delivery	5	13
44965	2020-03-31 09:18:56	2020-03-31	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	13685	delivery	5	28
44966	2020-03-31 09:25:09	2020-03-31	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17910	delivery	5	34
44967	2020-03-31 09:29:01	2020-03-31	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	8269	delivery	5	26
44968	2020-03-31 09:35:14	2020-03-31	9	[{"id_menu":7,"count":1}]	123	delivery	5	14
44969	2020-03-31 09:37:27	2020-03-31	17	[{"id_menu":4,"count":1}]	3635	delivery	5	22
44970	2020-03-31 09:39:39	2020-03-31	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17943	pick-up	0	43
44971	2020-03-31 09:40:37	2020-03-31	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17912	delivery	5	39
44972	2020-03-31 09:41:05	2020-03-31	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	5016	delivery	5	27
44973	2020-03-31 09:46:58	2020-03-31	8	[{"id_menu":5,"count":1}]	8747	pick-up	0	8
44974	2020-03-31 09:48:49	2020-03-31	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	777	pick-up	0	22
44975	2020-03-31 09:57:17	2020-03-31	14	[{"id_menu":2,"count":1}]	1685	delivery	5	19
44976	2020-03-31 09:58:09	2020-03-31	9	[{"id_menu":6,"count":1}]	10655	delivery	5	14
44977	2020-03-31 10:15:29	2020-03-31	12	[{"id_menu":3,"count":1}]	14492	delivery	5	17
44978	2020-03-31 10:16:35	2020-03-31	14	[{"id_menu":2,"count":1}]	1198	pick-up	0	14
44979	2020-03-31 10:17:27	2020-03-31	9	[{"id_menu":7,"count":1}]	17892	delivery	5	14
44980	2020-03-31 10:17:33	2020-03-31	12	[{"id_menu":3,"count":2}]	721	delivery	5	17
44981	2020-03-31 10:31:03	2020-03-31	9	[{"id_menu":7,"count":1}]	5869	pick-up	0	9
44982	2020-03-31 10:33:29	2020-03-31	9	[{"id_menu":6,"count":1}]	15957	delivery	5	14
44983	2020-03-31 10:42:38	2020-03-31	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14558	delivery	5	39
44984	2020-03-31 10:44:37	2020-03-31	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17833	delivery	5	31
44985	2020-03-31 10:47:46	2020-03-31	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1523	pick-up	0	29
44986	2020-03-31 10:49:34	2020-03-31	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17859	delivery	5	22
44987	2020-03-31 10:51:58	2020-03-31	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	17916	delivery	5	28
44988	2020-03-31 10:52:32	2020-03-31	12	[{"id_menu":3,"count":1}]	5491	pick-up	0	12
44989	2020-03-31 10:53:50	2020-03-31	17	[{"id_menu":4,"count":1}]	11004	delivery	5	22
44990	2020-03-31 10:59:25	2020-03-31	9	[{"id_menu":7,"count":1}]	17867	delivery	5	14
44991	2020-03-31 11:00:16	2020-03-31	8	[{"id_menu":5,"count":1}]	17888	delivery	5	13
44992	2020-03-31 11:06:37	2020-03-31	12	[{"id_menu":1,"count":1}]	17941	delivery	5	17
44993	2020-03-31 11:12:09	2020-03-31	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	16342	delivery	5	26
44994	2020-03-31 11:17:38	2020-03-31	9	[{"id_menu":6,"count":1}]	17869	delivery	5	14
44995	2020-03-31 11:18:43	2020-03-31	9	[{"id_menu":7,"count":1}]	11204	delivery	5	14
44996	2020-03-31 11:23:28	2020-03-31	12	[{"id_menu":3,"count":1}]	8724	delivery	5	17
44997	2020-03-31 11:27:58	2020-03-31	12	[{"id_menu":1,"count":1}]	9828	delivery	5	17
44998	2020-03-31 11:40:02	2020-03-31	9	[{"id_menu":7,"count":1}]	7232	delivery	5	14
44999	2020-03-31 11:40:08	2020-03-31	17	[{"id_menu":4,"count":1}]	10139	pick-up	0	17
45000	2020-03-31 11:42:51	2020-03-31	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	17902	delivery	5	37
45001	2020-03-31 11:49:25	2020-03-31	14	[{"id_menu":2,"count":1}]	2237	pick-up	0	14
45002	2020-03-31 11:53:37	2020-03-31	12	[{"id_menu":3,"count":1}]	17086	delivery	5	17
45003	2020-03-31 11:58:13	2020-03-31	14	[{"id_menu":2,"count":1}]	5114	delivery	5	19
45004	2020-03-31 12:03:21	2020-03-31	12	[{"id_menu":1,"count":1}]	16018	pick-up	0	12
45005	2020-03-31 12:07:13	2020-03-31	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	732	pick-up	0	22
45006	2020-03-31 12:07:20	2020-03-31	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	17945	delivery	5	30
45007	2020-03-31 12:08:01	2020-03-31	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	7383	pick-up	0	24
45008	2020-03-31 12:14:23	2020-03-31	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	17868	delivery	5	28
45009	2020-03-31 12:22:22	2020-03-31	9	[{"id_menu":7,"count":1}]	15036	delivery	5	14
45010	2020-03-31 12:29:23	2020-03-31	9	[{"id_menu":7,"count":1}]	17951	delivery	5	14
45011	2020-03-31 12:35:27	2020-03-31	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17328	pick-up	0	52
45012	2020-03-31 12:36:25	2020-03-31	14	[{"id_menu":2,"count":1}]	2310	pick-up	0	14
45013	2020-03-31 12:36:29	2020-03-31	12	[{"id_menu":3,"count":1}]	9695	delivery	5	17
45014	2020-03-31 12:40:39	2020-03-31	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	7352	delivery	5	22
45015	2020-03-31 12:40:51	2020-03-31	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15603	delivery	5	45
45016	2020-03-31 12:53:44	2020-03-31	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17944	delivery	5	34
45017	2020-03-31 13:07:09	2020-03-31	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11999	delivery	5	34
45018	2020-03-31 13:09:15	2020-03-31	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3781	delivery	5	40
45019	2020-03-31 13:10:02	2020-03-31	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	17917	delivery	5	23
45020	2020-03-31 13:13:36	2020-03-31	14	[{"id_menu":2,"count":1}]	1917	pick-up	0	14
45021	2020-03-31 13:34:12	2020-03-31	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	17863	delivery	5	28
45022	2020-03-31 13:37:39	2020-03-31	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15578	delivery	5	54
45023	2020-03-31 13:53:16	2020-03-31	8	[{"id_menu":5,"count":1}]	17881	delivery	5	13
45024	2020-03-31 13:53:23	2020-03-31	12	[{"id_menu":3,"count":1}]	1956	pick-up	0	12
45025	2020-03-31 13:56:58	2020-03-31	12	[{"id_menu":3,"count":1}]	676	pick-up	0	12
45026	2020-03-31 13:58:32	2020-03-31	9	[{"id_menu":6,"count":1}]	17928	delivery	5	14
45027	2020-03-31 13:59:54	2020-03-31	9	[{"id_menu":6,"count":1}]	17854	delivery	5	14
45028	2020-03-31 14:00:20	2020-03-31	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	17903	delivery	5	31
45029	2020-03-31 14:04:02	2020-03-31	17	[{"id_menu":4,"count":1}]	2231	delivery	5	22
45030	2020-03-31 14:10:43	2020-03-31	17	[{"id_menu":4,"count":1}]	17935	delivery	5	22
45031	2020-03-31 14:20:16	2020-03-31	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	13676	delivery	5	31
45032	2020-03-31 14:22:46	2020-03-31	8	[{"id_menu":5,"count":1}]	17905	delivery	5	13
45033	2020-03-31 14:27:02	2020-03-31	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":3}]	17856	delivery	5	26
45034	2020-03-31 14:34:32	2020-03-31	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17932	pick-up	0	30
45035	2020-03-31 14:37:36	2020-03-31	8	[{"id_menu":5,"count":1}]	13010	delivery	5	13
45036	2020-03-31 14:42:23	2020-03-31	17	[{"id_menu":4,"count":2}]	17876	delivery	5	22
45037	2020-03-31 14:51:08	2020-03-31	9	[{"id_menu":7,"count":1}]	17931	delivery	5	14
45038	2020-03-31 14:51:57	2020-03-31	8	[{"id_menu":5,"count":1}]	12011	delivery	5	13
45039	2020-03-31 14:54:14	2020-03-31	8	[{"id_menu":5,"count":1}]	8224	pick-up	0	8
45040	2020-03-31 15:01:25	2020-03-31	12	[{"id_menu":3,"count":1}]	6391	delivery	5	17
45041	2020-03-31 15:01:45	2020-03-31	12	[{"id_menu":1,"count":1}]	7927	pick-up	0	12
45042	2020-03-31 15:04:34	2020-03-31	12	[{"id_menu":3,"count":1}]	17890	delivery	5	17
45043	2020-03-31 15:22:32	2020-03-31	9	[{"id_menu":7,"count":1}]	14505	delivery	5	14
45044	2020-03-31 15:26:01	2020-03-31	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2036	pick-up	0	21
45045	2020-03-31 15:31:02	2020-03-31	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17921	delivery	5	34
45046	2020-03-31 15:51:52	2020-03-31	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10089	delivery	5	22
45047	2020-03-31 15:53:19	2020-03-31	8	[{"id_menu":5,"count":1}]	3878	delivery	5	13
45048	2020-03-31 15:59:50	2020-03-31	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2311	delivery	5	31
45049	2020-03-31 16:03:23	2020-03-31	17	[{"id_menu":4,"count":1}]	9001	delivery	5	22
45050	2020-03-31 16:04:56	2020-03-31	14	[{"id_menu":2,"count":1}]	15654	delivery	5	19
45051	2020-03-31 16:29:22	2020-03-31	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	16778	delivery	5	40
45052	2020-03-31 16:34:39	2020-03-31	9	[{"id_menu":6,"count":1}]	12247	delivery	5	14
45053	2020-03-31 16:37:52	2020-03-31	17	[{"id_menu":4,"count":1}]	2473	delivery	5	22
45054	2020-03-31 16:44:44	2020-03-31	17	[{"id_menu":4,"count":1}]	12028	pick-up	0	17
45055	2020-03-31 16:47:56	2020-03-31	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13209	delivery	5	39
45056	2020-03-31 16:49:10	2020-03-31	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	17842	delivery	5	43
45057	2020-03-31 16:49:46	2020-03-31	17	[{"id_menu":4,"count":1}]	17939	delivery	5	22
45058	2020-03-31 16:51:23	2020-03-31	9	[{"id_menu":7,"count":1}]	7709	delivery	5	14
45059	2020-03-31 16:52:49	2020-03-31	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1382	pick-up	0	23
45060	2020-03-31 17:07:35	2020-03-31	8	[{"id_menu":5,"count":1}]	17845	delivery	5	13
45061	2020-03-31 17:11:08	2020-03-31	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	15929	pick-up	0	31
45062	2020-03-31 17:11:08	2020-03-31	8	[{"id_menu":5,"count":1}]	14039	delivery	5	13
45063	2020-03-31 17:16:43	2020-03-31	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	3446	delivery	5	26
45064	2020-03-31 17:20:47	2020-03-31	30	[{"id_menu":3,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8379	delivery	5	35
45065	2020-03-31 17:27:45	2020-03-31	12	[{"id_menu":3,"count":1}]	17940	delivery	5	17
45066	2020-03-31 17:29:09	2020-03-31	9	[{"id_menu":6,"count":1}]	1992	pick-up	0	9
45067	2020-03-31 17:31:49	2020-03-31	8	[{"id_menu":5,"count":1}]	1498	delivery	5	13
45068	2020-03-31 17:35:06	2020-03-31	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17908	delivery	5	37
45069	2020-03-31 17:39:32	2020-03-31	17	[{"id_menu":4,"count":1}]	68	pick-up	0	17
45070	2020-03-31 17:43:24	2020-03-31	9	[{"id_menu":6,"count":1}]	6062	pick-up	0	9
45071	2020-03-31 17:53:37	2020-03-31	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	314	delivery	5	34
45072	2020-03-31 17:54:00	2020-03-31	17	[{"id_menu":4,"count":1}]	15798	delivery	5	22
45073	2020-03-31 18:03:15	2020-03-31	9	[{"id_menu":6,"count":1}]	13082	delivery	5	14
45074	2020-03-31 18:11:07	2020-03-31	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	17843	delivery	5	29
45075	2020-03-31 18:13:40	2020-03-31	17	[{"id_menu":4,"count":1}]	17883	pick-up	0	17
45076	2020-03-31 18:20:07	2020-03-31	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13044	delivery	5	40
45077	2020-03-31 18:21:09	2020-03-31	9	[{"id_menu":6,"count":1}]	14915	delivery	5	14
45078	2020-03-31 18:23:14	2020-03-31	12	[{"id_menu":3,"count":1}]	37	pick-up	0	12
45079	2020-03-31 18:23:20	2020-03-31	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1533	pick-up	0	26
45080	2020-03-31 18:23:22	2020-03-31	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15512	delivery	5	40
45081	2020-03-31 18:24:47	2020-03-31	17	[{"id_menu":4,"count":1}]	17926	delivery	5	22
45082	2020-03-31 18:29:26	2020-03-31	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	13731	delivery	5	31
45083	2020-03-31 18:32:17	2020-03-31	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	8054	pick-up	0	22
45084	2020-03-31 18:45:45	2020-03-31	12	[{"id_menu":3,"count":1}]	2604	pick-up	0	12
45085	2020-03-31 19:06:53	2020-03-31	9	[{"id_menu":6,"count":1}]	12983	delivery	5	14
45086	2020-03-31 19:08:17	2020-03-31	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2483	delivery	5	23
45087	2020-03-31 19:10:31	2020-03-31	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2806	delivery	5	37
45088	2020-03-31 19:10:42	2020-03-31	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11401	delivery	5	31
45089	2020-03-31 19:13:45	2020-03-31	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	10354	delivery	5	22
45090	2020-03-31 19:17:51	2020-03-31	9	[{"id_menu":7,"count":1}]	14957	delivery	5	14
45091	2020-03-31 19:24:11	2020-03-31	14	[{"id_menu":2,"count":1}]	623	delivery	5	19
45092	2020-03-31 19:25:01	2020-03-31	17	[{"id_menu":4,"count":1}]	17937	delivery	5	22
45093	2020-03-31 19:25:15	2020-03-31	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	7260	pick-up	0	21
45094	2020-03-31 19:25:25	2020-03-31	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17836	delivery	5	53
45095	2020-03-31 19:34:24	2020-03-31	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	13734	delivery	5	31
45096	2020-03-31 19:40:45	2020-03-31	8	[{"id_menu":5,"count":1}]	9053	pick-up	0	8
45097	2020-03-31 19:40:47	2020-03-31	17	[{"id_menu":4,"count":1}]	16135	delivery	5	22
45098	2020-03-31 19:43:10	2020-03-31	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3917	delivery	5	56
45099	2020-03-31 19:46:37	2020-03-31	9	[{"id_menu":6,"count":1}]	5966	pick-up	0	9
45100	2020-03-31 19:48:23	2020-03-31	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3086	delivery	5	34
45101	2020-03-31 19:51:34	2020-03-31	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11254	delivery	5	23
45102	2020-03-31 19:53:31	2020-03-31	9	[{"id_menu":6,"count":1}]	12797	delivery	5	14
45103	2020-03-31 19:53:37	2020-03-31	17	[{"id_menu":4,"count":1}]	7069	pick-up	0	17
45104	2020-03-31 19:55:16	2020-03-31	9	[{"id_menu":6,"count":1}]	1168	pick-up	0	9
45105	2020-03-31 19:55:25	2020-03-31	9	[{"id_menu":6,"count":1}]	5286	pick-up	0	9
45106	2020-03-31 20:00:37	2020-03-31	12	[{"id_menu":3,"count":1}]	1875	delivery	5	17
45107	2020-03-31 20:01:56	2020-03-31	12	[{"id_menu":1,"count":1}]	14703	delivery	5	17
45108	2020-03-31 20:03:31	2020-03-31	14	[{"id_menu":2,"count":1}]	8819	delivery	5	19
45109	2020-03-31 20:12:48	2020-03-31	12	[{"id_menu":1,"count":1}]	16978	delivery	5	17
45110	2020-03-31 20:14:06	2020-03-31	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17929	pick-up	0	26
45111	2020-03-31 20:17:30	2020-03-31	9	[{"id_menu":6,"count":1}]	16835	delivery	5	14
45112	2020-03-31 20:19:25	2020-03-31	9	[{"id_menu":6,"count":1}]	17920	delivery	5	14
45113	2020-03-31 20:27:39	2020-03-31	8	[{"id_menu":5,"count":1}]	342	delivery	5	13
45114	2020-03-31 20:29:13	2020-03-31	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	17818	delivery	5	30
45115	2020-03-31 20:30:14	2020-03-31	12	[{"id_menu":1,"count":1}]	16450	delivery	5	17
45116	2020-03-31 20:40:10	2020-03-31	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17925	delivery	5	37
45117	2020-03-31 20:43:20	2020-03-31	8	[{"id_menu":5,"count":1}]	2083	pick-up	0	8
45118	2020-03-31 20:46:00	2020-03-31	14	[{"id_menu":2,"count":1}]	8716	pick-up	0	14
45119	2020-03-31 21:21:54	2020-03-31	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	2040	pick-up	0	17
45120	2020-03-31 21:29:03	2020-03-31	17	[{"id_menu":4,"count":1}]	14754	delivery	5	22
45121	2020-03-31 21:45:00	2020-03-31	12	[{"id_menu":1,"count":1}]	1537	delivery	5	17
45122	2020-03-31 21:46:07	2020-03-31	9	[{"id_menu":6,"count":1}]	10046	delivery	5	14
45123	2020-03-31 21:46:42	2020-03-31	17	[{"id_menu":4,"count":1}]	4498	delivery	5	22
45124	2020-03-31 21:46:45	2020-03-31	8	[{"id_menu":5,"count":1}]	4280	delivery	5	13
45125	2020-03-31 21:50:13	2020-03-31	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	16947	delivery	5	31
45126	2020-03-31 21:52:18	2020-03-31	9	[{"id_menu":6,"count":1}]	13945	pick-up	0	9
45127	2020-03-31 21:53:38	2020-03-31	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	12377	delivery	5	34
45128	2020-03-31 21:58:06	2020-03-31	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17832	delivery	5	37
45129	2020-03-31 22:01:12	2020-03-31	17	[{"id_menu":4,"count":1}]	14290	pick-up	0	17
45130	2020-03-31 22:01:27	2020-03-31	9	[{"id_menu":7,"count":2}]	15903	delivery	5	14
45131	2020-03-31 22:10:19	2020-03-31	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	17442	delivery	5	36
45132	2020-03-31 22:12:43	2020-03-31	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3981	delivery	5	57
45133	2020-03-31 22:22:04	2020-03-31	17	[{"id_menu":4,"count":1}]	2564	pick-up	0	17
45134	2020-03-31 22:22:08	2020-03-31	8	[{"id_menu":5,"count":1}]	3048	pick-up	0	8
45135	2020-03-31 22:26:52	2020-03-31	12	[{"id_menu":1,"count":1}]	17901	delivery	5	17
45136	2020-03-31 22:29:09	2020-03-31	8	[{"id_menu":5,"count":1}]	17852	delivery	5	13
45137	2020-03-31 22:43:30	2020-03-31	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5575	delivery	5	28
45138	2020-03-31 22:45:56	2020-03-31	9	[{"id_menu":7,"count":1}]	7150	pick-up	0	9
45139	2020-03-31 22:48:00	2020-03-31	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	17899	pick-up	0	33
45140	2020-03-31 22:59:54	2020-03-31	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10282	delivery	5	31
45141	2020-03-31 23:02:23	2020-03-31	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4016	delivery	5	31
45142	2020-03-31 23:05:50	2020-03-31	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17906	pick-up	0	17
45143	2020-03-31 23:07:37	2020-03-31	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17421	delivery	5	22
45144	2020-03-31 23:14:57	2020-03-31	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	5574	delivery	5	34
45145	2020-03-31 23:16:43	2020-03-31	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	4924	delivery	5	26
45146	2020-03-31 23:20:03	2020-03-31	9	[{"id_menu":6,"count":1}]	4757	delivery	5	14
45147	2020-03-31 23:25:03	2020-03-31	17	[{"id_menu":4,"count":1}]	12272	delivery	5	22
45148	2020-03-31 23:38:01	2020-03-31	9	[{"id_menu":6,"count":1}]	8109	delivery	5	14
45149	2020-03-31 23:47:59	2020-03-31	14	[{"id_menu":2,"count":1}]	1325	delivery	5	19
45150	2020-03-31 23:48:03	2020-03-31	14	[{"id_menu":2,"count":1}]	17083	pick-up	0	14
45151	2020-03-31 23:48:54	2020-03-31	8	[{"id_menu":5,"count":1}]	17826	delivery	5	13
45152	2020-04-01 00:09:36	2020-04-01	12	[{"id_menu":1,"count":1}]	12278	pick-up	0	12
45153	2020-04-01 00:11:21	2020-04-01	14	[{"id_menu":2,"count":1}]	3863	pick-up	0	14
45154	2020-04-01 00:13:04	2020-04-01	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	9107	pick-up	0	21
45155	2020-04-01 00:17:02	2020-04-01	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2714	pick-up	0	22
45156	2020-04-01 00:17:02	2020-04-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	17984	delivery	5	26
45157	2020-04-01 00:18:41	2020-04-01	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2450	pick-up	0	21
45158	2020-04-01 00:23:58	2020-04-01	9	[{"id_menu":6,"count":1}]	18068	delivery	5	14
45159	2020-04-01 00:29:01	2020-04-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	18012	delivery	5	31
45160	2020-04-01 00:33:00	2020-04-01	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17955	delivery	5	31
45161	2020-04-01 00:41:51	2020-04-01	12	[{"id_menu":1,"count":1}]	18009	delivery	5	17
45162	2020-04-01 00:47:54	2020-04-01	9	[{"id_menu":6,"count":1}]	13758	delivery	5	14
45163	2020-04-01 00:51:44	2020-04-01	17	[{"id_menu":4,"count":2}]	14559	pick-up	0	17
45164	2020-04-01 00:52:34	2020-04-01	12	[{"id_menu":1,"count":1}]	1369	delivery	5	17
45165	2020-04-01 00:53:04	2020-04-01	17	[{"id_menu":4,"count":2}]	3335	pick-up	0	17
45166	2020-04-01 00:53:27	2020-04-01	8	[{"id_menu":5,"count":1}]	18048	delivery	5	13
45167	2020-04-01 01:02:46	2020-04-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13136	delivery	5	22
45168	2020-04-01 01:08:11	2020-04-01	8	[{"id_menu":5,"count":1}]	18028	delivery	5	13
45169	2020-04-01 01:08:35	2020-04-01	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	108	delivery	5	43
45170	2020-04-01 01:08:42	2020-04-01	9	[{"id_menu":7,"count":2}]	14739	delivery	5	14
45171	2020-04-01 01:16:22	2020-04-01	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":3}]	15565	delivery	5	31
45172	2020-04-01 01:17:09	2020-04-01	17	[{"id_menu":4,"count":1}]	2659	pick-up	0	17
45173	2020-04-01 01:24:41	2020-04-01	38	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	13479	delivery	5	43
45174	2020-04-01 01:30:39	2020-04-01	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	16293	delivery	5	25
45175	2020-04-01 01:37:45	2020-04-01	9	[{"id_menu":6,"count":1}]	2780	delivery	5	14
45176	2020-04-01 01:41:58	2020-04-01	9	[{"id_menu":6,"count":1}]	4152	delivery	5	14
45177	2020-04-01 01:43:39	2020-04-01	14	[{"id_menu":2,"count":1}]	17999	delivery	5	19
45178	2020-04-01 01:52:53	2020-04-01	8	[{"id_menu":5,"count":1}]	3755	pick-up	0	8
45179	2020-04-01 01:57:02	2020-04-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5279	delivery	5	22
45180	2020-04-01 02:05:41	2020-04-01	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	4587	delivery	5	23
45181	2020-04-01 02:15:51	2020-04-01	9	[{"id_menu":6,"count":1}]	7435	delivery	5	14
45182	2020-04-01 02:19:52	2020-04-01	8	[{"id_menu":5,"count":1}]	17992	delivery	5	13
45183	2020-04-01 02:20:57	2020-04-01	9	[{"id_menu":6,"count":1}]	17980	delivery	5	14
45184	2020-04-01 02:23:59	2020-04-01	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	9833	delivery	5	39
45185	2020-04-01 02:28:42	2020-04-01	9	[{"id_menu":7,"count":1}]	17988	delivery	5	14
45186	2020-04-01 02:34:11	2020-04-01	9	[{"id_menu":7,"count":1}]	13111	delivery	5	14
45187	2020-04-01 02:36:46	2020-04-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	18031	delivery	5	28
45188	2020-04-01 02:36:57	2020-04-01	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	18070	delivery	5	26
45189	2020-04-01 02:38:44	2020-04-01	14	[{"id_menu":2,"count":1}]	7814	pick-up	0	14
45190	2020-04-01 02:43:44	2020-04-01	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	12699	pick-up	0	35
45191	2020-04-01 02:52:43	2020-04-01	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	17969	delivery	5	22
45192	2020-04-01 02:53:28	2020-04-01	9	[{"id_menu":6,"count":1}]	17972	delivery	5	14
45193	2020-04-01 02:54:24	2020-04-01	9	[{"id_menu":6,"count":1}]	4782	delivery	5	14
45194	2020-04-01 03:09:06	2020-04-01	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	12555	delivery	5	26
45195	2020-04-01 03:11:06	2020-04-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18043	delivery	5	22
45196	2020-04-01 03:12:44	2020-04-01	9	[{"id_menu":6,"count":1}]	3895	delivery	5	14
45197	2020-04-01 03:39:36	2020-04-01	9	[{"id_menu":6,"count":1}]	18059	delivery	5	14
45198	2020-04-01 03:41:28	2020-04-01	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7779	delivery	5	34
45199	2020-04-01 03:44:38	2020-04-01	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7451	delivery	5	45
45200	2020-04-01 03:45:36	2020-04-01	14	[{"id_menu":2,"count":1}]	18081	delivery	5	19
45201	2020-04-01 03:54:35	2020-04-01	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	10876	delivery	5	31
45202	2020-04-01 03:56:16	2020-04-01	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	18035	delivery	5	45
45203	2020-04-01 03:58:05	2020-04-01	8	[{"id_menu":5,"count":1}]	2507	delivery	5	13
45204	2020-04-01 03:59:58	2020-04-01	9	[{"id_menu":7,"count":1}]	17957	delivery	5	14
45205	2020-04-01 04:00:12	2020-04-01	14	[{"id_menu":2,"count":1}]	9706	pick-up	0	14
45206	2020-04-01 04:00:31	2020-04-01	9	[{"id_menu":6,"count":1}]	6068	delivery	5	14
45207	2020-04-01 04:02:12	2020-04-01	8	[{"id_menu":5,"count":1}]	1076	pick-up	0	8
45208	2020-04-01 04:05:50	2020-04-01	12	[{"id_menu":1,"count":1}]	1756	pick-up	0	12
45209	2020-04-01 04:07:02	2020-04-01	8	[{"id_menu":5,"count":1}]	113	delivery	5	13
45210	2020-04-01 04:07:30	2020-04-01	12	[{"id_menu":1,"count":1}]	18032	delivery	5	17
45211	2020-04-01 04:20:03	2020-04-01	9	[{"id_menu":7,"count":1}]	574	pick-up	0	9
45212	2020-04-01 04:21:35	2020-04-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	12506	delivery	5	36
45213	2020-04-01 04:22:47	2020-04-01	14	[{"id_menu":2,"count":1}]	1303	pick-up	0	14
45214	2020-04-01 04:32:48	2020-04-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	18044	delivery	5	31
45215	2020-04-01 04:41:08	2020-04-01	9	[{"id_menu":6,"count":1}]	6195	pick-up	0	9
45216	2020-04-01 04:41:33	2020-04-01	9	[{"id_menu":7,"count":1}]	18005	pick-up	0	9
45217	2020-04-01 04:52:32	2020-04-01	9	[{"id_menu":7,"count":1}]	8082	delivery	5	14
45218	2020-04-01 04:53:08	2020-04-01	8	[{"id_menu":5,"count":1}]	13522	delivery	5	13
45219	2020-04-01 05:00:22	2020-04-01	9	[{"id_menu":6,"count":1}]	10735	pick-up	0	9
45220	2020-04-01 05:03:59	2020-04-01	9	[{"id_menu":6,"count":1}]	14775	delivery	5	14
45221	2020-04-01 05:05:09	2020-04-01	17	[{"id_menu":4,"count":1}]	17973	delivery	5	22
45222	2020-04-01 05:11:09	2020-04-01	9	[{"id_menu":6,"count":1}]	18046	delivery	5	14
45223	2020-04-01 05:11:31	2020-04-01	17	[{"id_menu":4,"count":1}]	1296	pick-up	0	17
45224	2020-04-01 05:12:26	2020-04-01	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	4695	delivery	5	23
45225	2020-04-01 05:18:47	2020-04-01	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15344	delivery	5	39
45226	2020-04-01 05:23:50	2020-04-01	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	17970	delivery	5	26
45227	2020-04-01 05:32:16	2020-04-01	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17971	delivery	5	40
45228	2020-04-01 05:32:32	2020-04-01	14	[{"id_menu":2,"count":1}]	18030	delivery	5	19
45229	2020-04-01 05:37:06	2020-04-01	14	[{"id_menu":2,"count":1}]	8751	delivery	5	19
45230	2020-04-01 05:43:42	2020-04-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	18015	pick-up	0	23
45231	2020-04-01 05:47:14	2020-04-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	18047	pick-up	0	26
45232	2020-04-01 05:48:18	2020-04-01	9	[{"id_menu":6,"count":1}]	2090	pick-up	0	9
45233	2020-04-01 05:56:05	2020-04-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	18074	delivery	5	28
45234	2020-04-01 06:08:07	2020-04-01	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	11431	delivery	5	26
45235	2020-04-01 06:17:28	2020-04-01	14	[{"id_menu":2,"count":1}]	16926	pick-up	0	14
45236	2020-04-01 06:18:01	2020-04-01	14	[{"id_menu":2,"count":1}]	5107	delivery	5	19
45237	2020-04-01 06:18:56	2020-04-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9147	delivery	5	22
45238	2020-04-01 06:19:22	2020-04-01	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	18062	delivery	5	31
45239	2020-04-01 06:20:30	2020-04-01	17	[{"id_menu":4,"count":1}]	482	delivery	5	22
45240	2020-04-01 06:25:15	2020-04-01	12	[{"id_menu":1,"count":1}]	6980	delivery	5	17
45241	2020-04-01 06:28:17	2020-04-01	8	[{"id_menu":5,"count":1}]	11973	delivery	5	13
45242	2020-04-01 06:30:16	2020-04-01	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	17091	delivery	5	31
45243	2020-04-01 06:34:53	2020-04-01	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	18029	delivery	5	45
45244	2020-04-01 06:42:23	2020-04-01	9	[{"id_menu":6,"count":1}]	5868	delivery	5	14
45245	2020-04-01 06:54:18	2020-04-01	9	[{"id_menu":7,"count":1}]	17314	delivery	5	14
45246	2020-04-01 07:01:57	2020-04-01	12	[{"id_menu":1,"count":1}]	4005	pick-up	0	12
45247	2020-04-01 07:01:57	2020-04-01	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12159	delivery	5	31
45248	2020-04-01 07:04:32	2020-04-01	9	[{"id_menu":7,"count":1}]	9682	pick-up	0	9
45249	2020-04-01 07:12:22	2020-04-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	18026	delivery	5	28
45250	2020-04-01 07:16:01	2020-04-01	14	[{"id_menu":2,"count":1}]	18003	delivery	5	19
45251	2020-04-01 07:18:01	2020-04-01	12	[{"id_menu":1,"count":1}]	12958	delivery	5	17
45252	2020-04-01 07:21:57	2020-04-01	8	[{"id_menu":5,"count":1}]	1088	pick-up	0	8
45253	2020-04-01 07:26:13	2020-04-01	14	[{"id_menu":2,"count":1}]	18016	delivery	5	19
45254	2020-04-01 07:30:13	2020-04-01	12	[{"id_menu":1,"count":1}]	2668	pick-up	0	12
45255	2020-04-01 07:31:17	2020-04-01	33	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	17005	delivery	5	38
45256	2020-04-01 07:33:49	2020-04-01	14	[{"id_menu":2,"count":1}]	2085	pick-up	0	14
45257	2020-04-01 07:37:34	2020-04-01	8	[{"id_menu":5,"count":2}]	18050	delivery	5	13
45258	2020-04-01 07:38:51	2020-04-01	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	11285	delivery	5	31
45259	2020-04-01 07:42:21	2020-04-01	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	9227	delivery	5	45
45260	2020-04-01 07:52:04	2020-04-01	17	[{"id_menu":4,"count":1}]	1916	pick-up	0	17
45261	2020-04-01 07:59:01	2020-04-01	12	[{"id_menu":1,"count":1}]	18027	pick-up	0	12
45262	2020-04-01 08:05:13	2020-04-01	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	13189	delivery	5	40
45263	2020-04-01 08:10:03	2020-04-01	9	[{"id_menu":7,"count":1}]	13627	delivery	5	14
45264	2020-04-01 08:10:12	2020-04-01	9	[{"id_menu":7,"count":1}]	18041	delivery	5	14
45265	2020-04-01 08:11:20	2020-04-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3101	delivery	5	28
45266	2020-04-01 08:13:32	2020-04-01	17	[{"id_menu":4,"count":1}]	18021	pick-up	0	17
45267	2020-04-01 08:17:40	2020-04-01	9	[{"id_menu":7,"count":2}]	13528	pick-up	0	9
45268	2020-04-01 08:18:22	2020-04-01	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	18017	delivery	5	35
45269	2020-04-01 08:20:45	2020-04-01	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	5006	delivery	5	25
45270	2020-04-01 08:26:29	2020-04-01	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17421	delivery	5	43
45271	2020-04-01 08:41:40	2020-04-01	12	[{"id_menu":1,"count":1}]	2528	delivery	5	17
45272	2020-04-01 08:42:31	2020-04-01	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1979	pick-up	0	43
45273	2020-04-01 08:50:14	2020-04-01	9	[{"id_menu":6,"count":1}]	18049	pick-up	0	9
45274	2020-04-01 09:06:04	2020-04-01	9	[{"id_menu":6,"count":1}]	9233	delivery	5	14
45275	2020-04-01 09:11:56	2020-04-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	6419	delivery	5	26
45276	2020-04-01 09:14:25	2020-04-01	17	[{"id_menu":4,"count":1}]	5303	pick-up	0	17
45277	2020-04-01 09:16:25	2020-04-01	14	[{"id_menu":2,"count":1}]	12970	pick-up	0	14
45278	2020-04-01 09:19:56	2020-04-01	9	[{"id_menu":7,"count":1}]	14930	delivery	5	14
45279	2020-04-01 09:20:39	2020-04-01	12	[{"id_menu":1,"count":2}]	11271	delivery	5	17
45280	2020-04-01 09:22:47	2020-04-01	12	[{"id_menu":3,"count":1}]	9125	delivery	5	17
45281	2020-04-01 09:27:11	2020-04-01	12	[{"id_menu":3,"count":1}]	17108	delivery	5	17
45282	2020-04-01 09:38:02	2020-04-01	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	10948	pick-up	0	24
45283	2020-04-01 09:39:58	2020-04-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	10843	delivery	5	28
45284	2020-04-01 09:45:02	2020-04-01	9	[{"id_menu":7,"count":1}]	18010	delivery	5	14
45285	2020-04-01 09:52:01	2020-04-01	12	[{"id_menu":1,"count":1}]	7096	pick-up	0	12
45286	2020-04-01 09:52:22	2020-04-01	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	14448	delivery	5	25
45287	2020-04-01 09:56:23	2020-04-01	14	[{"id_menu":2,"count":1}]	17979	delivery	5	19
45288	2020-04-01 09:59:41	2020-04-01	12	[{"id_menu":3,"count":1}]	16434	pick-up	0	12
45289	2020-04-01 10:01:58	2020-04-01	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	17991	delivery	5	22
45290	2020-04-01 10:02:25	2020-04-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	5049	pick-up	0	21
45291	2020-04-01 10:04:12	2020-04-01	9	[{"id_menu":6,"count":1}]	17962	delivery	5	14
45292	2020-04-01 10:11:31	2020-04-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10362	delivery	5	22
45293	2020-04-01 10:13:58	2020-04-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15713	delivery	5	31
45294	2020-04-01 10:19:25	2020-04-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	17996	delivery	5	26
45295	2020-04-01 10:20:22	2020-04-01	9	[{"id_menu":7,"count":1}]	8362	delivery	5	14
45296	2020-04-01 10:32:20	2020-04-01	12	[{"id_menu":1,"count":1}]	396	delivery	5	17
45297	2020-04-01 10:38:53	2020-04-01	12	[{"id_menu":3,"count":1}]	7604	delivery	5	17
45298	2020-04-01 10:40:38	2020-04-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5293	delivery	5	23
45299	2020-04-01 10:43:30	2020-04-01	9	[{"id_menu":6,"count":1}]	14679	pick-up	0	9
45300	2020-04-01 10:49:19	2020-04-01	12	[{"id_menu":1,"count":1}]	2897	delivery	5	17
45301	2020-04-01 10:54:52	2020-04-01	9	[{"id_menu":6,"count":1}]	18036	delivery	5	14
45302	2020-04-01 10:58:37	2020-04-01	9	[{"id_menu":6,"count":1}]	4356	pick-up	0	9
45303	2020-04-01 11:00:01	2020-04-01	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	4158	delivery	5	40
45304	2020-04-01 11:09:48	2020-04-01	9	[{"id_menu":6,"count":1}]	17974	delivery	5	14
45305	2020-04-01 11:13:31	2020-04-01	8	[{"id_menu":5,"count":1}]	17041	delivery	5	13
45306	2020-04-01 11:22:14	2020-04-01	12	[{"id_menu":1,"count":1}]	12578	pick-up	0	12
45307	2020-04-01 11:26:25	2020-04-01	14	[{"id_menu":2,"count":1}]	4890	delivery	5	19
45308	2020-04-01 11:33:37	2020-04-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	18045	delivery	5	31
45309	2020-04-01 11:35:14	2020-04-01	12	[{"id_menu":3,"count":1}]	6633	delivery	5	17
45310	2020-04-01 11:42:30	2020-04-01	9	[{"id_menu":7,"count":1}]	8149	delivery	5	14
45311	2020-04-01 11:45:19	2020-04-01	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	4362	delivery	5	25
45312	2020-04-01 11:48:37	2020-04-01	9	[{"id_menu":7,"count":1}]	1170	pick-up	0	9
45313	2020-04-01 11:54:32	2020-04-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	11994	delivery	5	23
45314	2020-04-01 12:01:23	2020-04-01	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":2}]	18060	pick-up	0	26
45315	2020-04-01 12:04:19	2020-04-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	18008	delivery	5	28
45316	2020-04-01 12:05:34	2020-04-01	9	[{"id_menu":6,"count":1}]	15788	delivery	5	14
45317	2020-04-01 12:06:21	2020-04-01	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	18064	delivery	5	34
45318	2020-04-01 12:07:32	2020-04-01	12	[{"id_menu":1,"count":1}]	18023	delivery	5	17
45319	2020-04-01 12:07:49	2020-04-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17975	delivery	5	22
45320	2020-04-01 12:11:02	2020-04-01	12	[{"id_menu":1,"count":1}]	5960	delivery	5	17
45321	2020-04-01 12:11:04	2020-04-01	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18054	delivery	5	53
45322	2020-04-01 12:12:42	2020-04-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	16656	delivery	5	36
45323	2020-04-01 12:14:48	2020-04-01	9	[{"id_menu":7,"count":1}]	17982	delivery	5	14
45324	2020-04-01 12:15:17	2020-04-01	9	[{"id_menu":7,"count":1}]	2032	pick-up	0	9
45325	2020-04-01 12:16:29	2020-04-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	17960	delivery	5	28
45326	2020-04-01 12:26:12	2020-04-01	14	[{"id_menu":2,"count":1}]	16239	delivery	5	19
45327	2020-04-01 12:28:59	2020-04-01	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	15103	delivery	5	40
45328	2020-04-01 12:30:37	2020-04-01	9	[{"id_menu":6,"count":1}]	3295	pick-up	0	9
45329	2020-04-01 12:32:35	2020-04-01	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9680	delivery	5	39
45330	2020-04-01 12:34:51	2020-04-01	17	[{"id_menu":4,"count":1}]	6080	delivery	5	22
45331	2020-04-01 12:35:22	2020-04-01	12	[{"id_menu":3,"count":1}]	1934	pick-up	0	12
45332	2020-04-01 12:38:42	2020-04-01	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3283	pick-up	0	26
45333	2020-04-01 12:40:04	2020-04-01	9	[{"id_menu":6,"count":1}]	18063	pick-up	0	9
45334	2020-04-01 12:44:20	2020-04-01	12	[{"id_menu":3,"count":2}]	702	delivery	5	17
45335	2020-04-01 12:50:14	2020-04-01	14	[{"id_menu":2,"count":1}]	18080	pick-up	0	14
45336	2020-04-01 13:05:48	2020-04-01	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	14290	pick-up	0	29
45337	2020-04-01 13:11:54	2020-04-01	12	[{"id_menu":3,"count":1}]	18053	delivery	5	17
45338	2020-04-01 13:15:13	2020-04-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	17809	delivery	5	23
45339	2020-04-01 13:16:51	2020-04-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	12990	pick-up	0	21
45340	2020-04-01 13:19:32	2020-04-01	12	[{"id_menu":1,"count":1}]	11314	pick-up	0	12
45341	2020-04-01 13:20:47	2020-04-01	14	[{"id_menu":2,"count":3}]	17292	delivery	5	19
45342	2020-04-01 13:32:42	2020-04-01	14	[{"id_menu":2,"count":1}]	2513	pick-up	0	14
45343	2020-04-01 13:39:51	2020-04-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16014	delivery	5	23
45344	2020-04-01 13:47:15	2020-04-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1659	pick-up	0	31
45345	2020-04-01 13:48:08	2020-04-01	17	[{"id_menu":4,"count":1}]	5430	pick-up	0	17
45346	2020-04-01 13:48:15	2020-04-01	14	[{"id_menu":2,"count":1}]	18071	delivery	5	19
45347	2020-04-01 13:51:10	2020-04-01	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15294	delivery	5	39
45348	2020-04-01 14:03:27	2020-04-01	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17985	delivery	5	35
45349	2020-04-01 14:06:43	2020-04-01	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	17968	delivery	5	38
45350	2020-04-01 14:17:51	2020-04-01	8	[{"id_menu":5,"count":1}]	16346	delivery	5	13
45351	2020-04-01 14:24:29	2020-04-01	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	17977	delivery	5	48
45352	2020-04-01 14:28:14	2020-04-01	9	[{"id_menu":7,"count":2}]	15910	pick-up	0	9
45353	2020-04-01 14:28:19	2020-04-01	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11586	delivery	5	54
45354	2020-04-01 14:38:57	2020-04-01	9	[{"id_menu":6,"count":1}]	3820	pick-up	0	9
45355	2020-04-01 14:44:07	2020-04-01	12	[{"id_menu":3,"count":1}]	18076	delivery	5	17
45356	2020-04-01 14:54:02	2020-04-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	17711	delivery	5	23
45357	2020-04-01 14:55:56	2020-04-01	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	9346	delivery	5	34
45358	2020-04-01 14:56:34	2020-04-01	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	18056	delivery	5	40
45359	2020-04-01 14:57:32	2020-04-01	14	[{"id_menu":2,"count":2}]	17958	delivery	5	19
45360	2020-04-01 14:59:23	2020-04-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	18020	delivery	5	36
45361	2020-04-01 15:08:09	2020-04-01	14	[{"id_menu":2,"count":1}]	13939	pick-up	0	14
45362	2020-04-01 15:08:40	2020-04-01	17	[{"id_menu":4,"count":1}]	17987	delivery	5	22
45363	2020-04-01 15:18:46	2020-04-01	8	[{"id_menu":5,"count":1}]	8947	delivery	5	13
45364	2020-04-01 15:20:52	2020-04-01	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	6798	pick-up	0	35
45365	2020-04-01 15:22:48	2020-04-01	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17981	delivery	5	35
45366	2020-04-01 15:25:08	2020-04-01	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	763	delivery	5	25
45367	2020-04-01 15:28:54	2020-04-01	8	[{"id_menu":5,"count":1}]	18042	delivery	5	13
45368	2020-04-01 15:33:56	2020-04-01	9	[{"id_menu":6,"count":1}]	17990	delivery	5	14
45369	2020-04-01 15:43:15	2020-04-01	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15425	delivery	5	31
45370	2020-04-01 15:52:03	2020-04-01	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3401	pick-up	0	21
45371	2020-04-01 15:56:46	2020-04-01	8	[{"id_menu":5,"count":1}]	17983	delivery	5	13
45372	2020-04-01 15:58:55	2020-04-01	14	[{"id_menu":2,"count":1}]	17978	delivery	5	19
45373	2020-04-01 16:00:18	2020-04-01	12	[{"id_menu":3,"count":1}]	16875	delivery	5	17
45374	2020-04-01 16:09:35	2020-04-01	8	[{"id_menu":5,"count":1}]	17963	delivery	5	13
45375	2020-04-01 16:15:11	2020-04-01	12	[{"id_menu":1,"count":1}]	15829	pick-up	0	12
45376	2020-04-01 16:17:54	2020-04-01	8	[{"id_menu":5,"count":1}]	12124	pick-up	0	8
45377	2020-04-01 16:19:23	2020-04-01	17	[{"id_menu":4,"count":1}]	17097	delivery	5	22
45378	2020-04-01 16:22:33	2020-04-01	9	[{"id_menu":7,"count":1}]	7189	delivery	5	14
45379	2020-04-01 16:30:08	2020-04-01	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	5338	pick-up	0	20
45380	2020-04-01 16:31:08	2020-04-01	12	[{"id_menu":3,"count":1}]	17989	pick-up	0	12
45381	2020-04-01 16:32:24	2020-04-01	14	[{"id_menu":2,"count":2}]	18067	delivery	5	19
45382	2020-04-01 16:36:47	2020-04-01	9	[{"id_menu":6,"count":1}]	14202	delivery	5	14
45383	2020-04-01 16:45:48	2020-04-01	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	4588	delivery	5	22
45384	2020-04-01 16:51:20	2020-04-01	12	[{"id_menu":1,"count":1}]	17959	delivery	5	17
45385	2020-04-01 16:52:27	2020-04-01	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3260	pick-up	0	21
45386	2020-04-01 16:52:37	2020-04-01	8	[{"id_menu":5,"count":1}]	17993	pick-up	0	8
45387	2020-04-01 16:58:01	2020-04-01	14	[{"id_menu":2,"count":1}]	5292	pick-up	0	14
45388	2020-04-01 16:58:16	2020-04-01	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	15599	pick-up	0	29
45389	2020-04-01 17:07:02	2020-04-01	12	[{"id_menu":1,"count":1}]	17438	delivery	5	17
45390	2020-04-01 17:08:26	2020-04-01	12	[{"id_menu":3,"count":1}]	12132	delivery	5	17
45391	2020-04-01 17:09:18	2020-04-01	9	[{"id_menu":7,"count":1}]	18011	delivery	5	14
45392	2020-04-01 17:12:20	2020-04-01	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17629	delivery	5	34
45393	2020-04-01 17:14:25	2020-04-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	10922	delivery	5	26
45394	2020-04-01 17:14:34	2020-04-01	12	[{"id_menu":3,"count":1}]	18051	delivery	5	17
45395	2020-04-01 17:25:47	2020-04-01	9	[{"id_menu":6,"count":1}]	18066	delivery	5	14
45531	2020-04-02 03:13:12	2020-04-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5930	delivery	5	28
45396	2020-04-01 17:26:45	2020-04-01	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	7844	delivery	5	36
45397	2020-04-01 17:33:50	2020-04-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	10907	delivery	5	28
45398	2020-04-01 17:39:53	2020-04-01	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	5153	delivery	5	36
45399	2020-04-01 17:42:16	2020-04-01	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	17976	delivery	5	25
45400	2020-04-01 17:54:02	2020-04-01	17	[{"id_menu":4,"count":1}]	7787	pick-up	0	17
45401	2020-04-01 17:55:28	2020-04-01	14	[{"id_menu":2,"count":1}]	2301	pick-up	0	14
45402	2020-04-01 18:03:38	2020-04-01	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10814	delivery	5	48
45403	2020-04-01 18:14:13	2020-04-01	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	1044	pick-up	0	41
45404	2020-04-01 18:14:17	2020-04-01	12	[{"id_menu":1,"count":1}]	18052	delivery	5	17
45405	2020-04-01 18:18:31	2020-04-01	8	[{"id_menu":5,"count":1}]	16401	delivery	5	13
45406	2020-04-01 18:22:35	2020-04-01	17	[{"id_menu":4,"count":1}]	18039	delivery	5	22
45407	2020-04-01 18:32:31	2020-04-01	8	[{"id_menu":5,"count":1}]	9903	delivery	5	13
45408	2020-04-01 18:33:30	2020-04-01	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6354	delivery	5	31
45409	2020-04-01 18:36:36	2020-04-01	14	[{"id_menu":2,"count":1}]	5075	delivery	5	19
45410	2020-04-01 18:40:47	2020-04-01	14	[{"id_menu":2,"count":1}]	1490	pick-up	0	14
45411	2020-04-01 18:41:32	2020-04-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	18077	delivery	5	28
45412	2020-04-01 18:47:58	2020-04-01	8	[{"id_menu":5,"count":1}]	4622	delivery	5	13
45413	2020-04-01 18:55:23	2020-04-01	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":2}]	18040	delivery	5	26
45414	2020-04-01 18:59:00	2020-04-01	12	[{"id_menu":1,"count":1}]	18075	delivery	5	17
45415	2020-04-01 19:03:49	2020-04-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4094	pick-up	0	23
45416	2020-04-01 19:11:45	2020-04-01	17	[{"id_menu":5,"count":3},{"id_menu":6,"count":1}]	18061	delivery	5	22
45417	2020-04-01 19:12:59	2020-04-01	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	5169	pick-up	0	26
45418	2020-04-01 19:15:17	2020-04-01	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	15931	delivery	5	31
45419	2020-04-01 19:15:31	2020-04-01	17	[{"id_menu":4,"count":1}]	18038	pick-up	0	17
45420	2020-04-01 19:15:57	2020-04-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17935	delivery	5	23
45421	2020-04-01 19:19:30	2020-04-01	9	[{"id_menu":6,"count":1}]	4478	delivery	5	14
45422	2020-04-01 19:27:47	2020-04-01	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	6396	pick-up	0	31
45423	2020-04-01 19:31:32	2020-04-01	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	18078	delivery	5	23
45424	2020-04-01 19:38:15	2020-04-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	16585	delivery	5	28
45425	2020-04-01 19:40:08	2020-04-01	9	[{"id_menu":6,"count":1}]	18073	pick-up	0	9
45426	2020-04-01 19:40:16	2020-04-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	17964	delivery	5	28
45427	2020-04-01 19:40:48	2020-04-01	17	[{"id_menu":4,"count":1}]	17965	delivery	5	22
45428	2020-04-01 19:41:22	2020-04-01	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	10000	delivery	5	26
45429	2020-04-01 19:44:32	2020-04-01	17	[{"id_menu":4,"count":2}]	6484	pick-up	0	17
45430	2020-04-01 19:44:55	2020-04-01	14	[{"id_menu":2,"count":1}]	18057	delivery	5	19
45431	2020-04-01 19:45:27	2020-04-01	17	[{"id_menu":4,"count":2}]	36	pick-up	0	17
45432	2020-04-01 19:51:44	2020-04-01	8	[{"id_menu":5,"count":2}]	18065	delivery	5	13
45433	2020-04-01 19:51:56	2020-04-01	14	[{"id_menu":2,"count":1}]	7431	delivery	5	19
45434	2020-04-01 19:58:54	2020-04-01	9	[{"id_menu":7,"count":1}]	14747	delivery	5	14
45435	2020-04-01 20:00:02	2020-04-01	8	[{"id_menu":5,"count":1}]	13070	delivery	5	13
45436	2020-04-01 20:12:25	2020-04-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7566	pick-up	0	31
45437	2020-04-01 20:16:57	2020-04-01	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	10719	delivery	5	40
45438	2020-04-01 20:25:36	2020-04-01	14	[{"id_menu":2,"count":1}]	334	delivery	5	19
45439	2020-04-01 20:33:59	2020-04-01	12	[{"id_menu":3,"count":1}]	6741	delivery	5	17
45440	2020-04-01 20:36:53	2020-04-01	8	[{"id_menu":5,"count":1}]	17956	pick-up	0	8
45441	2020-04-01 20:40:36	2020-04-01	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	17967	delivery	5	44
45442	2020-04-01 20:45:50	2020-04-01	9	[{"id_menu":7,"count":1}]	18000	delivery	5	14
45443	2020-04-01 20:46:02	2020-04-01	12	[{"id_menu":3,"count":1}]	12102	delivery	5	17
45444	2020-04-01 20:53:28	2020-04-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	9798	delivery	5	31
45445	2020-04-01 20:55:35	2020-04-01	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	18085	delivery	5	26
45446	2020-04-01 20:58:19	2020-04-01	12	[{"id_menu":1,"count":1}]	591	delivery	5	17
45447	2020-04-01 21:02:24	2020-04-01	9	[{"id_menu":7,"count":1}]	2520	pick-up	0	9
45448	2020-04-01 21:05:50	2020-04-01	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	15815	pick-up	0	24
45449	2020-04-01 21:19:07	2020-04-01	9	[{"id_menu":6,"count":1}]	6471	delivery	5	14
45450	2020-04-01 21:21:09	2020-04-01	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	18013	delivery	5	37
45451	2020-04-01 21:28:01	2020-04-01	8	[{"id_menu":5,"count":1}]	16376	delivery	5	13
45452	2020-04-01 21:38:10	2020-04-01	12	[{"id_menu":3,"count":1}]	18033	delivery	5	17
45453	2020-04-01 21:38:19	2020-04-01	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16916	delivery	5	45
45454	2020-04-01 21:38:56	2020-04-01	14	[{"id_menu":2,"count":1}]	18002	delivery	5	19
45455	2020-04-01 21:43:06	2020-04-01	12	[{"id_menu":3,"count":1}]	10008	pick-up	0	12
45456	2020-04-01 21:53:35	2020-04-01	9	[{"id_menu":6,"count":1}]	16753	pick-up	0	9
45457	2020-04-01 22:10:16	2020-04-01	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	12210	pick-up	0	26
45458	2020-04-01 22:18:03	2020-04-01	14	[{"id_menu":2,"count":1}]	2662	pick-up	0	14
45459	2020-04-01 22:26:43	2020-04-01	17	[{"id_menu":4,"count":1}]	5354	pick-up	0	17
45460	2020-04-01 22:32:51	2020-04-01	17	[{"id_menu":4,"count":1}]	4714	pick-up	0	17
45461	2020-04-01 22:33:18	2020-04-01	9	[{"id_menu":6,"count":1}]	10792	delivery	5	14
45462	2020-04-01 22:33:19	2020-04-01	12	[{"id_menu":3,"count":1}]	17995	pick-up	0	12
45463	2020-04-01 22:43:32	2020-04-01	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17997	delivery	5	36
45464	2020-04-01 22:47:35	2020-04-01	14	[{"id_menu":2,"count":1}]	638	delivery	5	19
45465	2020-04-01 22:51:32	2020-04-01	9	[{"id_menu":7,"count":1}]	13523	delivery	5	14
45466	2020-04-01 22:52:15	2020-04-01	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2224	pick-up	0	21
45467	2020-04-01 22:54:15	2020-04-01	17	[{"id_menu":4,"count":1}]	3124	pick-up	0	17
45468	2020-04-01 22:58:13	2020-04-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7994	delivery	5	28
45469	2020-04-01 22:59:36	2020-04-01	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1166	delivery	5	39
45470	2020-04-01 23:15:04	2020-04-01	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	17961	delivery	5	43
45471	2020-04-01 23:15:54	2020-04-01	9	[{"id_menu":6,"count":1}]	1900	delivery	5	14
45472	2020-04-01 23:18:49	2020-04-01	12	[{"id_menu":3,"count":1}]	1148	delivery	5	17
45473	2020-04-01 23:24:45	2020-04-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	13625	delivery	5	36
45474	2020-04-01 23:30:38	2020-04-01	14	[{"id_menu":2,"count":1}]	18055	delivery	5	19
45475	2020-04-01 23:36:27	2020-04-01	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	13950	pick-up	0	26
45476	2020-04-01 23:41:14	2020-04-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	18069	delivery	5	36
45477	2020-04-01 23:43:32	2020-04-01	9	[{"id_menu":7,"count":1}]	18083	delivery	5	14
45478	2020-04-01 23:49:08	2020-04-01	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5643	pick-up	0	26
45479	2020-04-01 23:52:03	2020-04-01	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17966	delivery	5	31
45480	2020-04-01 23:53:06	2020-04-01	8	[{"id_menu":5,"count":1}]	17986	delivery	5	13
45481	2020-04-01 23:54:08	2020-04-01	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	12462	delivery	5	40
45482	2020-04-01 23:54:37	2020-04-01	8	[{"id_menu":5,"count":1}]	13220	delivery	5	13
45483	2020-04-02 00:00:00	2020-04-02	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9933	delivery	5	52
45484	2020-04-02 00:00:47	2020-04-02	14	[{"id_menu":2,"count":1}]	11544	pick-up	0	14
45485	2020-04-02 00:04:19	2020-04-02	17	[{"id_menu":4,"count":1}]	2353	pick-up	0	17
45486	2020-04-02 00:09:54	2020-04-02	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	18172	delivery	5	23
45487	2020-04-02 00:11:40	2020-04-02	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18214	pick-up	0	34
45488	2020-04-02 00:17:22	2020-04-02	9	[{"id_menu":7,"count":3}]	18096	delivery	5	14
45489	2020-04-02 00:20:41	2020-04-02	9	[{"id_menu":7,"count":1}]	684	pick-up	0	9
45490	2020-04-02 00:26:46	2020-04-02	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	6216	delivery	5	29
45491	2020-04-02 00:28:00	2020-04-02	9	[{"id_menu":7,"count":1}]	14038	delivery	5	14
45492	2020-04-02 00:30:59	2020-04-02	9	[{"id_menu":6,"count":1}]	18213	delivery	5	14
45493	2020-04-02 00:31:49	2020-04-02	9	[{"id_menu":6,"count":1}]	18110	delivery	5	14
45494	2020-04-02 00:32:57	2020-04-02	12	[{"id_menu":1,"count":1}]	18026	delivery	5	17
45495	2020-04-02 00:34:05	2020-04-02	8	[{"id_menu":5,"count":1}]	10352	delivery	5	13
45496	2020-04-02 00:35:19	2020-04-02	12	[{"id_menu":3,"count":1}]	1289	pick-up	0	12
45497	2020-04-02 00:40:44	2020-04-02	12	[{"id_menu":1,"count":1}]	837	pick-up	0	12
45498	2020-04-02 00:41:18	2020-04-02	14	[{"id_menu":2,"count":1}]	338	delivery	5	19
45499	2020-04-02 00:41:52	2020-04-02	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	3410	delivery	5	23
45500	2020-04-02 00:47:23	2020-04-02	9	[{"id_menu":7,"count":1}]	18198	pick-up	0	9
45501	2020-04-02 00:47:54	2020-04-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	9805	delivery	5	23
45502	2020-04-02 00:53:45	2020-04-02	9	[{"id_menu":6,"count":1}]	10096	delivery	5	14
45503	2020-04-02 00:54:20	2020-04-02	9	[{"id_menu":7,"count":1}]	14175	delivery	5	14
45504	2020-04-02 01:00:25	2020-04-02	9	[{"id_menu":6,"count":1}]	16346	delivery	5	14
45505	2020-04-02 01:03:06	2020-04-02	14	[{"id_menu":2,"count":1}]	4872	pick-up	0	14
45506	2020-04-02 01:04:54	2020-04-02	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	13442	delivery	5	31
45507	2020-04-02 01:12:55	2020-04-02	14	[{"id_menu":2,"count":1}]	18176	delivery	5	19
45508	2020-04-02 01:14:38	2020-04-02	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5676	delivery	5	22
45509	2020-04-02 01:16:32	2020-04-02	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	18208	delivery	5	31
45510	2020-04-02 01:19:46	2020-04-02	14	[{"id_menu":2,"count":1}]	440	delivery	5	19
45511	2020-04-02 01:20:10	2020-04-02	8	[{"id_menu":5,"count":3}]	12736	delivery	5	13
45512	2020-04-02 01:21:02	2020-04-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12166	delivery	5	31
45513	2020-04-02 01:25:16	2020-04-02	12	[{"id_menu":3,"count":1}]	8348	delivery	5	17
45514	2020-04-02 01:37:26	2020-04-02	17	[{"id_menu":4,"count":1}]	9906	delivery	5	22
45515	2020-04-02 01:54:14	2020-04-02	12	[{"id_menu":1,"count":1}]	18113	delivery	5	17
45516	2020-04-02 01:58:59	2020-04-02	12	[{"id_menu":1,"count":1}]	18122	pick-up	0	12
45517	2020-04-02 02:04:27	2020-04-02	17	[{"id_menu":4,"count":1}]	10315	delivery	5	22
45518	2020-04-02 02:05:32	2020-04-02	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	4710	pick-up	0	29
45519	2020-04-02 02:05:35	2020-04-02	9	[{"id_menu":7,"count":1}]	121	pick-up	0	9
45520	2020-04-02 02:16:18	2020-04-02	9	[{"id_menu":6,"count":1}]	1422	delivery	5	14
45521	2020-04-02 02:27:24	2020-04-02	9	[{"id_menu":6,"count":2}]	7476	delivery	5	14
45522	2020-04-02 02:28:25	2020-04-02	14	[{"id_menu":2,"count":1}]	9238	delivery	5	19
45523	2020-04-02 02:33:29	2020-04-02	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18211	delivery	5	34
45524	2020-04-02 02:34:34	2020-04-02	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	12139	delivery	5	29
45525	2020-04-02 02:34:57	2020-04-02	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18205	delivery	5	34
45526	2020-04-02 02:36:56	2020-04-02	9	[{"id_menu":6,"count":1}]	18212	delivery	5	14
45527	2020-04-02 02:44:17	2020-04-02	12	[{"id_menu":1,"count":1}]	4594	delivery	5	17
45528	2020-04-02 02:44:32	2020-04-02	12	[{"id_menu":1,"count":1}]	136	pick-up	0	12
45529	2020-04-02 02:52:46	2020-04-02	14	[{"id_menu":2,"count":1}]	18180	delivery	5	19
45530	2020-04-02 03:02:38	2020-04-02	12	[{"id_menu":3,"count":1}]	10810	pick-up	0	12
45532	2020-04-02 03:16:09	2020-04-02	17	[{"id_menu":4,"count":1}]	9340	delivery	5	22
45533	2020-04-02 03:17:14	2020-04-02	9	[{"id_menu":6,"count":1}]	18217	delivery	5	14
45534	2020-04-02 03:21:58	2020-04-02	9	[{"id_menu":7,"count":1}]	18095	delivery	5	14
45535	2020-04-02 03:22:26	2020-04-02	8	[{"id_menu":5,"count":1}]	15457	delivery	5	13
45536	2020-04-02 03:22:28	2020-04-02	9	[{"id_menu":7,"count":1}]	18118	pick-up	0	9
45537	2020-04-02 03:27:22	2020-04-02	17	[{"id_menu":4,"count":1}]	16127	delivery	5	22
45538	2020-04-02 03:30:53	2020-04-02	12	[{"id_menu":1,"count":1}]	16452	delivery	5	17
45539	2020-04-02 03:38:22	2020-04-02	17	[{"id_menu":5,"count":3},{"id_menu":7,"count":1}]	18164	delivery	5	22
45540	2020-04-02 03:46:18	2020-04-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12666	delivery	5	23
45541	2020-04-02 03:47:56	2020-04-02	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	18147	pick-up	0	21
45542	2020-04-02 03:54:00	2020-04-02	8	[{"id_menu":5,"count":1}]	18109	delivery	5	13
45543	2020-04-02 04:01:15	2020-04-02	17	[{"id_menu":4,"count":1}]	9318	delivery	5	22
45544	2020-04-02 04:03:49	2020-04-02	9	[{"id_menu":6,"count":1}]	18162	delivery	5	14
45545	2020-04-02 04:14:07	2020-04-02	17	[{"id_menu":4,"count":1}]	15827	delivery	5	22
45546	2020-04-02 04:14:36	2020-04-02	12	[{"id_menu":1,"count":1}]	14519	delivery	5	17
45547	2020-04-02 04:35:19	2020-04-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15864	delivery	5	31
45548	2020-04-02 04:44:49	2020-04-02	17	[{"id_menu":4,"count":1}]	8918	delivery	5	22
45549	2020-04-02 04:48:44	2020-04-02	17	[{"id_menu":4,"count":1}]	18144	pick-up	0	17
45550	2020-04-02 04:49:25	2020-04-02	8	[{"id_menu":5,"count":1}]	9631	pick-up	0	8
45551	2020-04-02 04:52:21	2020-04-02	9	[{"id_menu":6,"count":1}]	3887	delivery	5	14
45552	2020-04-02 04:55:45	2020-04-02	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	18097	delivery	5	39
45553	2020-04-02 04:56:11	2020-04-02	12	[{"id_menu":1,"count":1}]	18224	delivery	5	17
45554	2020-04-02 04:58:20	2020-04-02	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	18197	delivery	5	27
45555	2020-04-02 05:02:58	2020-04-02	12	[{"id_menu":1,"count":1}]	17905	delivery	5	17
45556	2020-04-02 05:06:28	2020-04-02	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6276	delivery	5	43
45557	2020-04-02 05:07:46	2020-04-02	8	[{"id_menu":5,"count":1}]	9004	delivery	5	13
45558	2020-04-02 05:12:34	2020-04-02	9	[{"id_menu":7,"count":1}]	13937	delivery	5	14
45559	2020-04-02 05:15:49	2020-04-02	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	980	pick-up	0	22
45560	2020-04-02 05:16:33	2020-04-02	8	[{"id_menu":5,"count":1}]	11524	delivery	5	13
45561	2020-04-02 05:24:18	2020-04-02	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	9107	delivery	5	34
45562	2020-04-02 05:33:01	2020-04-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	12936	delivery	5	28
45563	2020-04-02 05:34:57	2020-04-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18117	delivery	5	23
45564	2020-04-02 05:35:59	2020-04-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11822	delivery	5	22
45565	2020-04-02 05:43:29	2020-04-02	14	[{"id_menu":2,"count":1}]	12287	delivery	5	19
45566	2020-04-02 05:45:50	2020-04-02	9	[{"id_menu":7,"count":1}]	2573	pick-up	0	9
45567	2020-04-02 05:47:29	2020-04-02	9	[{"id_menu":6,"count":2}]	18115	delivery	5	14
45568	2020-04-02 06:03:55	2020-04-02	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	9017	delivery	5	26
45569	2020-04-02 06:05:48	2020-04-02	8	[{"id_menu":5,"count":1}]	3447	pick-up	0	8
45570	2020-04-02 06:07:34	2020-04-02	9	[{"id_menu":6,"count":1}]	15437	delivery	5	14
45571	2020-04-02 06:07:52	2020-04-02	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	14075	delivery	5	28
45572	2020-04-02 06:11:46	2020-04-02	9	[{"id_menu":6,"count":1}]	1273	pick-up	0	9
45573	2020-04-02 06:20:06	2020-04-02	9	[{"id_menu":7,"count":1}]	12934	delivery	5	14
45574	2020-04-02 06:24:28	2020-04-02	14	[{"id_menu":2,"count":1}]	4577	pick-up	0	14
45575	2020-04-02 06:26:39	2020-04-02	14	[{"id_menu":2,"count":1}]	12282	delivery	5	19
45576	2020-04-02 06:28:32	2020-04-02	9	[{"id_menu":7,"count":1}]	18149	delivery	5	14
45577	2020-04-02 06:31:07	2020-04-02	8	[{"id_menu":5,"count":1}]	13985	delivery	5	13
45578	2020-04-02 06:32:52	2020-04-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6341	delivery	5	22
45579	2020-04-02 06:34:49	2020-04-02	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	18158	delivery	5	31
45580	2020-04-02 06:35:13	2020-04-02	14	[{"id_menu":2,"count":1}]	16136	delivery	5	19
45581	2020-04-02 06:45:29	2020-04-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5486	delivery	5	31
45582	2020-04-02 06:47:03	2020-04-02	8	[{"id_menu":5,"count":1}]	10216	delivery	5	13
45583	2020-04-02 06:50:23	2020-04-02	9	[{"id_menu":6,"count":1}]	17799	delivery	5	14
45584	2020-04-02 07:00:00	2020-04-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	15027	delivery	5	23
45585	2020-04-02 07:06:49	2020-04-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7190	pick-up	0	23
45586	2020-04-02 07:12:25	2020-04-02	14	[{"id_menu":2,"count":3}]	18111	delivery	5	19
45587	2020-04-02 07:20:27	2020-04-02	12	[{"id_menu":1,"count":1}]	7882	delivery	5	17
45588	2020-04-02 07:22:56	2020-04-02	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	14052	pick-up	0	22
45589	2020-04-02 07:23:17	2020-04-02	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	15384	delivery	5	40
45590	2020-04-02 07:34:11	2020-04-02	9	[{"id_menu":7,"count":1}]	18142	delivery	5	14
45591	2020-04-02 07:35:30	2020-04-02	12	[{"id_menu":1,"count":1}]	15995	delivery	5	17
45592	2020-04-02 07:36:35	2020-04-02	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	13341	delivery	5	26
45593	2020-04-02 07:38:14	2020-04-02	12	[{"id_menu":1,"count":1}]	5260	pick-up	0	12
45594	2020-04-02 07:44:09	2020-04-02	12	[{"id_menu":1,"count":1}]	18209	delivery	5	17
45595	2020-04-02 07:48:23	2020-04-02	12	[{"id_menu":1,"count":1}]	8355	delivery	5	17
45596	2020-04-02 07:51:50	2020-04-02	14	[{"id_menu":2,"count":2}]	2136	pick-up	0	14
45597	2020-04-02 07:54:56	2020-04-02	8	[{"id_menu":5,"count":3}]	1841	pick-up	0	8
45598	2020-04-02 08:05:57	2020-04-02	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	18105	delivery	5	26
45599	2020-04-02 08:07:04	2020-04-02	8	[{"id_menu":5,"count":2}]	18199	delivery	5	13
45600	2020-04-02 08:09:01	2020-04-02	17	[{"id_menu":4,"count":1}]	18219	delivery	5	22
45601	2020-04-02 08:11:32	2020-04-02	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	18222	pick-up	0	21
45602	2020-04-02 08:13:10	2020-04-02	12	[{"id_menu":1,"count":1}]	8024	delivery	5	17
45603	2020-04-02 08:18:52	2020-04-02	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11969	pick-up	0	35
45604	2020-04-02 08:21:06	2020-04-02	17	[{"id_menu":4,"count":1}]	12420	pick-up	0	17
45605	2020-04-02 08:25:47	2020-04-02	9	[{"id_menu":7,"count":1}]	18194	delivery	5	14
45606	2020-04-02 08:30:16	2020-04-02	9	[{"id_menu":7,"count":1}]	18078	delivery	5	14
45607	2020-04-02 08:36:21	2020-04-02	9	[{"id_menu":6,"count":1}]	15449	pick-up	0	9
45608	2020-04-02 08:36:54	2020-04-02	9	[{"id_menu":7,"count":1}]	5321	delivery	5	14
45609	2020-04-02 08:38:51	2020-04-02	12	[{"id_menu":3,"count":1}]	6163	delivery	5	17
45610	2020-04-02 08:44:26	2020-04-02	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	18206	delivery	5	43
45611	2020-04-02 08:44:55	2020-04-02	14	[{"id_menu":2,"count":1}]	1557	pick-up	0	14
45612	2020-04-02 08:45:12	2020-04-02	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	21	pick-up	0	26
45613	2020-04-02 08:46:01	2020-04-02	17	[{"id_menu":4,"count":1}]	2272	delivery	5	22
45614	2020-04-02 08:51:44	2020-04-02	12	[{"id_menu":3,"count":1}]	18188	delivery	5	17
45615	2020-04-02 09:04:29	2020-04-02	14	[{"id_menu":2,"count":1}]	7093	delivery	5	19
45616	2020-04-02 09:06:13	2020-04-02	9	[{"id_menu":6,"count":1}]	3238	delivery	5	14
45617	2020-04-02 09:07:18	2020-04-02	14	[{"id_menu":2,"count":1}]	4799	delivery	5	19
45618	2020-04-02 09:07:45	2020-04-02	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5064	pick-up	0	25
45619	2020-04-02 09:10:55	2020-04-02	8	[{"id_menu":5,"count":1}]	4243	delivery	5	13
45620	2020-04-02 09:14:52	2020-04-02	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8112	delivery	5	31
45621	2020-04-02 09:17:32	2020-04-02	12	[{"id_menu":1,"count":1}]	8090	delivery	5	17
45622	2020-04-02 09:18:26	2020-04-02	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	18146	delivery	5	26
45623	2020-04-02 09:19:27	2020-04-02	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	18167	delivery	5	36
45624	2020-04-02 09:36:16	2020-04-02	9	[{"id_menu":6,"count":1}]	14422	delivery	5	14
45625	2020-04-02 09:36:21	2020-04-02	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16162	delivery	5	43
45626	2020-04-02 09:37:39	2020-04-02	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	12368	delivery	5	39
45627	2020-04-02 09:39:01	2020-04-02	14	[{"id_menu":2,"count":1}]	18098	delivery	5	19
45628	2020-04-02 09:42:51	2020-04-02	14	[{"id_menu":2,"count":1}]	14660	delivery	5	19
45629	2020-04-02 09:44:44	2020-04-02	8	[{"id_menu":5,"count":2}]	18134	delivery	5	13
45630	2020-04-02 10:08:11	2020-04-02	8	[{"id_menu":5,"count":1}]	6821	delivery	5	13
45631	2020-04-02 10:14:32	2020-04-02	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15236	delivery	5	43
45632	2020-04-02 10:16:49	2020-04-02	17	[{"id_menu":4,"count":1}]	1794	pick-up	0	17
45633	2020-04-02 10:19:37	2020-04-02	9	[{"id_menu":7,"count":1}]	18125	delivery	5	14
45634	2020-04-02 10:35:06	2020-04-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11888	delivery	5	23
45635	2020-04-02 10:38:44	2020-04-02	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18091	delivery	5	53
45636	2020-04-02 10:39:26	2020-04-02	8	[{"id_menu":5,"count":1}]	18101	delivery	5	13
45637	2020-04-02 10:39:34	2020-04-02	55	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4600	pick-up	0	55
45638	2020-04-02 10:49:48	2020-04-02	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	18102	delivery	5	26
45639	2020-04-02 10:52:56	2020-04-02	12	[{"id_menu":3,"count":1}]	2715	pick-up	0	12
45640	2020-04-02 10:54:48	2020-04-02	9	[{"id_menu":6,"count":1}]	9946	delivery	5	14
45641	2020-04-02 10:59:16	2020-04-02	17	[{"id_menu":4,"count":1}]	1549	pick-up	0	17
45642	2020-04-02 11:02:49	2020-04-02	9	[{"id_menu":7,"count":1}]	18159	delivery	5	14
45643	2020-04-02 11:07:35	2020-04-02	9	[{"id_menu":7,"count":1}]	9712	delivery	5	14
45644	2020-04-02 11:07:44	2020-04-02	9	[{"id_menu":6,"count":1}]	16108	delivery	5	14
45645	2020-04-02 11:10:54	2020-04-02	9	[{"id_menu":7,"count":1}]	765	pick-up	0	9
45646	2020-04-02 11:11:55	2020-04-02	14	[{"id_menu":2,"count":1}]	15896	delivery	5	19
45647	2020-04-02 11:13:24	2020-04-02	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	511	pick-up	0	26
45648	2020-04-02 11:14:00	2020-04-02	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13613	pick-up	0	43
45649	2020-04-02 11:16:51	2020-04-02	14	[{"id_menu":2,"count":1}]	7821	delivery	5	19
45650	2020-04-02 11:18:05	2020-04-02	9	[{"id_menu":7,"count":1}]	1144	pick-up	0	9
45651	2020-04-02 11:23:03	2020-04-02	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17116	delivery	5	36
45652	2020-04-02 11:25:56	2020-04-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	13185	delivery	5	28
45653	2020-04-02 11:32:30	2020-04-02	9	[{"id_menu":7,"count":1}]	18107	delivery	5	14
45654	2020-04-02 11:33:45	2020-04-02	17	[{"id_menu":4,"count":1}]	11276	pick-up	0	17
45655	2020-04-02 11:33:48	2020-04-02	9	[{"id_menu":6,"count":1}]	18100	delivery	5	14
45656	2020-04-02 11:35:03	2020-04-02	14	[{"id_menu":2,"count":2}]	12129	delivery	5	19
45657	2020-04-02 11:40:22	2020-04-02	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	5314	pick-up	0	21
45658	2020-04-02 11:46:27	2020-04-02	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	18116	delivery	5	28
45659	2020-04-02 11:50:09	2020-04-02	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	18103	delivery	5	31
45660	2020-04-02 11:54:58	2020-04-02	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16207	delivery	5	31
45661	2020-04-02 12:00:37	2020-04-02	9	[{"id_menu":6,"count":1}]	1074	delivery	5	14
45662	2020-04-02 12:03:57	2020-04-02	12	[{"id_menu":3,"count":1}]	15694	delivery	5	17
45663	2020-04-02 12:06:23	2020-04-02	17	[{"id_menu":4,"count":1}]	18177	delivery	5	22
45664	2020-04-02 12:06:29	2020-04-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	18093	delivery	5	31
45665	2020-04-02 12:08:05	2020-04-02	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	18104	delivery	5	22
45666	2020-04-02 12:13:27	2020-04-02	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1727	pick-up	0	21
45667	2020-04-02 12:14:44	2020-04-02	49	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	17685	pick-up	0	49
45668	2020-04-02 12:19:30	2020-04-02	14	[{"id_menu":2,"count":1}]	18143	delivery	5	19
45669	2020-04-02 12:24:54	2020-04-02	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	931	pick-up	0	26
45670	2020-04-02 12:28:47	2020-04-02	9	[{"id_menu":6,"count":1}]	18141	delivery	5	14
45671	2020-04-02 12:43:18	2020-04-02	14	[{"id_menu":2,"count":1}]	11054	delivery	5	19
45672	2020-04-02 12:44:23	2020-04-02	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	18155	delivery	5	27
45673	2020-04-02 12:48:45	2020-04-02	9	[{"id_menu":6,"count":1}]	18207	pick-up	0	9
45674	2020-04-02 12:50:22	2020-04-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	18171	delivery	5	28
45675	2020-04-02 12:55:11	2020-04-02	17	[{"id_menu":4,"count":1}]	16264	pick-up	0	17
45676	2020-04-02 13:03:52	2020-04-02	9	[{"id_menu":6,"count":1}]	2943	delivery	5	14
45677	2020-04-02 13:05:47	2020-04-02	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	3251	delivery	5	34
45678	2020-04-02 13:10:47	2020-04-02	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12628	delivery	5	31
45679	2020-04-02 13:17:22	2020-04-02	12	[{"id_menu":3,"count":2}]	9816	pick-up	0	12
45680	2020-04-02 13:18:06	2020-04-02	17	[{"id_menu":4,"count":1}]	4658	pick-up	0	17
45681	2020-04-02 13:26:51	2020-04-02	17	[{"id_menu":4,"count":1}]	15776	delivery	5	22
45682	2020-04-02 13:33:11	2020-04-02	9	[{"id_menu":7,"count":1}]	11295	delivery	5	14
45683	2020-04-02 13:41:58	2020-04-02	9	[{"id_menu":6,"count":1}]	18165	delivery	5	14
45684	2020-04-02 13:43:22	2020-04-02	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18087	delivery	5	22
45685	2020-04-02 13:44:47	2020-04-02	14	[{"id_menu":2,"count":1}]	3494	pick-up	0	14
45686	2020-04-02 13:50:39	2020-04-02	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	7395	delivery	5	31
45687	2020-04-02 13:51:08	2020-04-02	9	[{"id_menu":6,"count":1}]	10433	delivery	5	14
45688	2020-04-02 13:54:01	2020-04-02	17	[{"id_menu":4,"count":1}]	8530	delivery	5	22
45689	2020-04-02 13:59:52	2020-04-02	12	[{"id_menu":1,"count":2}]	5192	delivery	5	17
45690	2020-04-02 14:01:00	2020-04-02	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18216	pick-up	0	26
45691	2020-04-02 14:07:53	2020-04-02	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	18190	delivery	5	22
45692	2020-04-02 14:16:46	2020-04-02	8	[{"id_menu":5,"count":1}]	18186	delivery	5	13
45693	2020-04-02 14:22:32	2020-04-02	9	[{"id_menu":7,"count":1}]	18218	delivery	5	14
45694	2020-04-02 14:30:41	2020-04-02	8	[{"id_menu":5,"count":1}]	18226	delivery	5	13
45695	2020-04-02 14:33:55	2020-04-02	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4124	delivery	5	39
45696	2020-04-02 14:35:34	2020-04-02	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	16280	pick-up	0	23
45697	2020-04-02 14:37:22	2020-04-02	9	[{"id_menu":7,"count":1}]	18120	delivery	5	14
45698	2020-04-02 14:46:41	2020-04-02	17	[{"id_menu":4,"count":1}]	12431	pick-up	0	17
45699	2020-04-02 14:51:21	2020-04-02	9	[{"id_menu":6,"count":1}]	11831	delivery	5	14
45700	2020-04-02 14:53:33	2020-04-02	17	[{"id_menu":4,"count":1}]	18126	delivery	5	22
45701	2020-04-02 14:59:06	2020-04-02	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	18086	delivery	5	23
45702	2020-04-02 14:59:44	2020-04-02	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	18223	delivery	5	26
45703	2020-04-02 15:01:52	2020-04-02	17	[{"id_menu":4,"count":1}]	868	delivery	5	22
45704	2020-04-02 15:01:56	2020-04-02	9	[{"id_menu":7,"count":1}]	5704	delivery	5	14
45705	2020-04-02 15:03:18	2020-04-02	9	[{"id_menu":6,"count":1}]	9114	delivery	5	14
45706	2020-04-02 15:03:52	2020-04-02	17	[{"id_menu":4,"count":1}]	18145	delivery	5	22
45707	2020-04-02 15:04:19	2020-04-02	14	[{"id_menu":2,"count":1}]	13732	pick-up	0	14
45708	2020-04-02 15:16:53	2020-04-02	9	[{"id_menu":6,"count":1}]	5184	delivery	5	14
45709	2020-04-02 15:18:07	2020-04-02	9	[{"id_menu":7,"count":1}]	13400	delivery	5	14
45710	2020-04-02 15:18:42	2020-04-02	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	11244	pick-up	0	23
45711	2020-04-02 15:38:24	2020-04-02	17	[{"id_menu":4,"count":1}]	3555	pick-up	0	17
45712	2020-04-02 15:42:39	2020-04-02	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	12600	delivery	5	25
45713	2020-04-02 15:46:00	2020-04-02	9	[{"id_menu":7,"count":1}]	18139	delivery	5	14
45714	2020-04-02 15:50:01	2020-04-02	12	[{"id_menu":3,"count":1}]	11795	pick-up	0	12
45715	2020-04-02 15:51:46	2020-04-02	12	[{"id_menu":1,"count":1}]	15780	pick-up	0	12
45716	2020-04-02 15:52:22	2020-04-02	17	[{"id_menu":4,"count":1}]	10434	delivery	5	22
45717	2020-04-02 15:57:59	2020-04-02	9	[{"id_menu":7,"count":1}]	11661	delivery	5	14
45718	2020-04-02 15:58:14	2020-04-02	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	7700	delivery	5	28
45719	2020-04-02 16:00:47	2020-04-02	9	[{"id_menu":6,"count":1}]	205	pick-up	0	9
45720	2020-04-02 16:02:29	2020-04-02	8	[{"id_menu":5,"count":1}]	4023	delivery	5	13
45721	2020-04-02 16:07:27	2020-04-02	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	18128	delivery	5	57
45722	2020-04-02 16:08:13	2020-04-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16607	delivery	5	23
45723	2020-04-02 16:10:14	2020-04-02	14	[{"id_menu":2,"count":1}]	9766	delivery	5	19
45724	2020-04-02 16:13:33	2020-04-02	12	[{"id_menu":1,"count":1}]	9354	pick-up	0	12
45725	2020-04-02 16:14:00	2020-04-02	9	[{"id_menu":6,"count":1}]	13692	pick-up	0	9
45726	2020-04-02 16:14:55	2020-04-02	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	18195	delivery	5	35
45727	2020-04-02 16:15:54	2020-04-02	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	33	delivery	5	25
45728	2020-04-02 16:24:20	2020-04-02	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18196	delivery	5	22
45729	2020-04-02 16:26:04	2020-04-02	14	[{"id_menu":2,"count":1}]	2111	delivery	5	19
45730	2020-04-02 16:27:23	2020-04-02	9	[{"id_menu":7,"count":1}]	6340	delivery	5	14
45731	2020-04-02 16:31:23	2020-04-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	18201	delivery	5	28
45732	2020-04-02 16:38:41	2020-04-02	8	[{"id_menu":5,"count":1}]	10553	pick-up	0	8
45733	2020-04-02 16:40:13	2020-04-02	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	18185	delivery	5	31
45734	2020-04-02 16:41:06	2020-04-02	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	18135	delivery	5	40
45735	2020-04-02 16:51:39	2020-04-02	17	[{"id_menu":4,"count":1}]	177	pick-up	0	17
45736	2020-04-02 16:53:15	2020-04-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	18160	delivery	5	22
45737	2020-04-02 16:55:11	2020-04-02	8	[{"id_menu":5,"count":1}]	7980	delivery	5	13
45738	2020-04-02 17:00:13	2020-04-02	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1330	pick-up	0	31
45739	2020-04-02 17:06:33	2020-04-02	12	[{"id_menu":1,"count":1}]	18108	delivery	5	17
45740	2020-04-02 17:14:43	2020-04-02	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	11890	delivery	5	30
45741	2020-04-02 17:19:35	2020-04-02	9	[{"id_menu":6,"count":1}]	18183	delivery	5	14
45742	2020-04-02 17:21:46	2020-04-02	14	[{"id_menu":2,"count":1}]	18170	pick-up	0	14
45743	2020-04-02 17:25:30	2020-04-02	8	[{"id_menu":5,"count":1}]	8286	pick-up	0	8
45744	2020-04-02 17:25:42	2020-04-02	17	[{"id_menu":4,"count":1}]	18175	delivery	5	22
45745	2020-04-02 17:26:22	2020-04-02	14	[{"id_menu":2,"count":1}]	7	pick-up	0	14
45746	2020-04-02 17:27:53	2020-04-02	14	[{"id_menu":2,"count":1}]	15619	pick-up	0	14
45747	2020-04-02 17:35:02	2020-04-02	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3568	delivery	5	30
45748	2020-04-02 17:36:00	2020-04-02	9	[{"id_menu":7,"count":1}]	5449	delivery	5	14
45749	2020-04-02 17:37:37	2020-04-02	14	[{"id_menu":2,"count":1}]	8145	delivery	5	19
45750	2020-04-02 17:39:13	2020-04-02	9	[{"id_menu":6,"count":1}]	3786	delivery	5	14
45751	2020-04-02 17:39:42	2020-04-02	12	[{"id_menu":1,"count":1}]	18088	delivery	5	17
45752	2020-04-02 17:42:30	2020-04-02	12	[{"id_menu":1,"count":1}]	2870	delivery	5	17
45753	2020-04-02 17:44:14	2020-04-02	9	[{"id_menu":6,"count":1}]	917	delivery	5	14
45754	2020-04-02 17:47:51	2020-04-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5075	pick-up	0	26
45755	2020-04-02 17:49:28	2020-04-02	8	[{"id_menu":5,"count":1}]	18174	delivery	5	13
45756	2020-04-02 17:52:14	2020-04-02	14	[{"id_menu":2,"count":1}]	3940	delivery	5	19
45757	2020-04-02 17:58:00	2020-04-02	12	[{"id_menu":3,"count":1}]	18150	delivery	5	17
45758	2020-04-02 18:01:39	2020-04-02	14	[{"id_menu":2,"count":1}]	2391	delivery	5	19
45759	2020-04-02 18:04:01	2020-04-02	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3066	pick-up	0	31
45760	2020-04-02 18:10:48	2020-04-02	14	[{"id_menu":2,"count":1}]	18169	delivery	5	19
45761	2020-04-02 18:20:55	2020-04-02	14	[{"id_menu":2,"count":1}]	3324	pick-up	0	14
45762	2020-04-02 18:26:52	2020-04-02	14	[{"id_menu":2,"count":1}]	6785	delivery	5	19
45763	2020-04-02 18:30:34	2020-04-02	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2392	pick-up	0	43
45764	2020-04-02 18:42:07	2020-04-02	9	[{"id_menu":6,"count":1}]	18123	delivery	5	14
45765	2020-04-02 18:42:07	2020-04-02	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	12538	delivery	5	26
45766	2020-04-02 18:45:55	2020-04-02	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":3}]	18156	delivery	5	31
45767	2020-04-02 18:56:06	2020-04-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	12268	pick-up	0	23
45768	2020-04-02 18:57:23	2020-04-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	876	delivery	5	23
45769	2020-04-02 19:00:37	2020-04-02	14	[{"id_menu":2,"count":1}]	18166	delivery	5	19
45770	2020-04-02 19:05:16	2020-04-02	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	654	pick-up	0	21
45771	2020-04-02 19:06:09	2020-04-02	17	[{"id_menu":4,"count":1}]	9682	pick-up	0	17
45772	2020-04-02 19:21:30	2020-04-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11389	delivery	5	31
45773	2020-04-02 19:21:51	2020-04-02	17	[{"id_menu":4,"count":1}]	13413	delivery	5	22
45774	2020-04-02 19:24:43	2020-04-02	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	13290	delivery	5	23
45775	2020-04-02 19:32:46	2020-04-02	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	18184	delivery	5	26
45776	2020-04-02 19:41:48	2020-04-02	14	[{"id_menu":2,"count":1}]	1934	pick-up	0	14
45777	2020-04-02 19:43:43	2020-04-02	14	[{"id_menu":2,"count":1}]	6304	delivery	5	19
45778	2020-04-02 19:49:07	2020-04-02	12	[{"id_menu":1,"count":1}]	16486	delivery	5	17
45779	2020-04-02 19:53:23	2020-04-02	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5680	delivery	5	36
45780	2020-04-02 19:58:00	2020-04-02	9	[{"id_menu":6,"count":1}]	16079	pick-up	0	9
45781	2020-04-02 20:02:53	2020-04-02	8	[{"id_menu":5,"count":1}]	1856	delivery	5	13
45782	2020-04-02 20:03:07	2020-04-02	9	[{"id_menu":7,"count":1}]	4539	delivery	5	14
45783	2020-04-02 20:03:48	2020-04-02	14	[{"id_menu":2,"count":1}]	18090	delivery	5	19
45784	2020-04-02 20:05:05	2020-04-02	12	[{"id_menu":1,"count":1}]	18215	delivery	5	17
45785	2020-04-02 20:06:47	2020-04-02	12	[{"id_menu":1,"count":1}]	10034	delivery	5	17
45786	2020-04-02 20:07:33	2020-04-02	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	5183	delivery	5	38
45787	2020-04-02 20:14:01	2020-04-02	9	[{"id_menu":7,"count":1}]	11074	pick-up	0	9
45788	2020-04-02 20:15:37	2020-04-02	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	14775	delivery	5	26
45789	2020-04-02 20:17:05	2020-04-02	17	[{"id_menu":4,"count":1}]	18148	delivery	5	22
45790	2020-04-02 20:19:42	2020-04-02	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8009	delivery	5	43
45791	2020-04-02 20:20:58	2020-04-02	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	18204	delivery	5	40
45792	2020-04-02 20:22:43	2020-04-02	9	[{"id_menu":7,"count":1}]	1743	delivery	5	14
45793	2020-04-02 20:23:26	2020-04-02	17	[{"id_menu":4,"count":2}]	2590	pick-up	0	17
45794	2020-04-02 20:27:10	2020-04-02	12	[{"id_menu":3,"count":1}]	15720	delivery	5	17
45795	2020-04-02 20:30:25	2020-04-02	9	[{"id_menu":7,"count":1}]	564	pick-up	0	9
45796	2020-04-02 20:31:41	2020-04-02	9	[{"id_menu":6,"count":1}]	18221	delivery	5	14
45797	2020-04-02 20:34:30	2020-04-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3095	pick-up	0	23
45798	2020-04-02 20:43:41	2020-04-02	12	[{"id_menu":3,"count":1}]	16583	delivery	5	17
45799	2020-04-02 20:48:44	2020-04-02	9	[{"id_menu":6,"count":1}]	2449	pick-up	0	9
45800	2020-04-02 20:51:55	2020-04-02	8	[{"id_menu":5,"count":1}]	9941	pick-up	0	8
45801	2020-04-02 20:58:27	2020-04-02	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	15284	delivery	5	26
45802	2020-04-02 21:02:37	2020-04-02	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	5325	delivery	5	39
45803	2020-04-02 21:06:43	2020-04-02	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18137	delivery	5	36
45804	2020-04-02 21:08:25	2020-04-02	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	10331	pick-up	0	26
45805	2020-04-02 21:13:12	2020-04-02	14	[{"id_menu":2,"count":2}]	18151	delivery	5	19
45806	2020-04-02 21:15:45	2020-04-02	9	[{"id_menu":6,"count":1}]	10625	delivery	5	14
45807	2020-04-02 21:16:35	2020-04-02	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	13042	delivery	5	31
45808	2020-04-02 21:18:31	2020-04-02	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	9452	delivery	5	48
45809	2020-04-02 21:18:38	2020-04-02	8	[{"id_menu":5,"count":1}]	18099	delivery	5	13
45810	2020-04-02 21:26:27	2020-04-02	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	17527	delivery	5	26
45811	2020-04-02 21:28:04	2020-04-02	9	[{"id_menu":7,"count":1}]	8104	pick-up	0	9
45812	2020-04-02 21:28:07	2020-04-02	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	18157	pick-up	0	25
45813	2020-04-02 21:33:04	2020-04-02	9	[{"id_menu":7,"count":1}]	18127	delivery	5	14
45814	2020-04-02 21:33:29	2020-04-02	9	[{"id_menu":6,"count":1}]	15266	delivery	5	14
45815	2020-04-02 21:35:52	2020-04-02	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6525	delivery	5	34
45816	2020-04-02 21:37:43	2020-04-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9985	pick-up	0	26
45817	2020-04-02 21:48:23	2020-04-02	14	[{"id_menu":2,"count":2}]	18154	pick-up	0	14
45818	2020-04-02 21:49:09	2020-04-02	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12426	delivery	5	34
45819	2020-04-02 21:49:26	2020-04-02	9	[{"id_menu":6,"count":1}]	18220	delivery	5	14
45820	2020-04-02 21:50:29	2020-04-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	3316	delivery	5	22
45821	2020-04-02 21:54:58	2020-04-02	12	[{"id_menu":3,"count":1}]	8044	delivery	5	17
45822	2020-04-02 21:57:56	2020-04-02	9	[{"id_menu":7,"count":1}]	939	delivery	5	14
45823	2020-04-02 21:59:08	2020-04-02	8	[{"id_menu":5,"count":1}]	18163	delivery	5	13
45824	2020-04-02 21:59:48	2020-04-02	9	[{"id_menu":6,"count":1}]	18189	pick-up	0	9
45825	2020-04-02 22:00:01	2020-04-02	14	[{"id_menu":2,"count":1}]	18192	delivery	5	19
45826	2020-04-02 22:01:36	2020-04-02	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	15076	delivery	5	28
45827	2020-04-02 22:05:25	2020-04-02	14	[{"id_menu":2,"count":1}]	18129	delivery	5	19
45828	2020-04-02 22:08:00	2020-04-02	9	[{"id_menu":6,"count":1}]	6080	delivery	5	14
45829	2020-04-02 22:08:49	2020-04-02	9	[{"id_menu":6,"count":1}]	18161	delivery	5	14
45830	2020-04-02 22:17:33	2020-04-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3659	pick-up	0	18
45831	2020-04-02 22:19:11	2020-04-02	9	[{"id_menu":7,"count":1}]	18179	delivery	5	14
45832	2020-04-02 22:21:53	2020-04-02	14	[{"id_menu":2,"count":1}]	18136	delivery	5	19
45833	2020-04-02 22:30:38	2020-04-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	18089	pick-up	0	26
45834	2020-04-02 22:31:22	2020-04-02	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	8622	delivery	5	46
45835	2020-04-02 22:33:42	2020-04-02	8	[{"id_menu":5,"count":1}]	11109	delivery	5	13
45836	2020-04-02 22:44:17	2020-04-02	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	18191	delivery	5	36
45837	2020-04-02 22:48:47	2020-04-02	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	12952	delivery	5	22
45838	2020-04-02 22:57:34	2020-04-02	9	[{"id_menu":6,"count":1}]	11367	delivery	5	14
45839	2020-04-02 22:58:28	2020-04-02	14	[{"id_menu":2,"count":1}]	233	pick-up	0	14
45840	2020-04-02 23:02:30	2020-04-02	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	8317	delivery	5	26
45841	2020-04-02 23:09:31	2020-04-02	9	[{"id_menu":7,"count":1}]	2415	delivery	5	14
45842	2020-04-02 23:26:00	2020-04-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3648	delivery	5	22
45843	2020-04-02 23:28:03	2020-04-02	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	18114	pick-up	0	29
45844	2020-04-02 23:34:20	2020-04-02	9	[{"id_menu":6,"count":1}]	18132	delivery	5	14
45845	2020-04-02 23:42:55	2020-04-02	14	[{"id_menu":2,"count":1}]	18106	delivery	5	19
45846	2020-04-02 23:45:05	2020-04-02	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5097	delivery	5	37
45847	2020-04-02 23:48:43	2020-04-02	9	[{"id_menu":7,"count":1}]	1931	pick-up	0	9
45848	2020-04-02 23:50:53	2020-04-02	12	[{"id_menu":1,"count":1}]	12040	delivery	5	17
45849	2020-04-02 23:51:00	2020-04-02	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18173	delivery	5	47
45850	2020-04-02 23:57:29	2020-04-02	9	[{"id_menu":7,"count":1}]	4316	pick-up	0	9
45851	2020-04-03 00:00:24	2020-04-03	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	6123	delivery	5	22
45852	2020-04-03 00:08:38	2020-04-03	9	[{"id_menu":7,"count":1}]	9525	delivery	5	14
45853	2020-04-03 00:11:42	2020-04-03	12	[{"id_menu":1,"count":1}]	10525	pick-up	0	12
45854	2020-04-03 00:21:41	2020-04-03	12	[{"id_menu":1,"count":1}]	4120	pick-up	0	12
45855	2020-04-03 00:27:05	2020-04-03	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7834	pick-up	0	38
45856	2020-04-03 00:30:24	2020-04-03	14	[{"id_menu":2,"count":1}]	18233	delivery	5	19
45857	2020-04-03 00:32:33	2020-04-03	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	18300	delivery	5	37
45858	2020-04-03 00:32:56	2020-04-03	9	[{"id_menu":6,"count":1}]	1156	pick-up	0	9
45859	2020-04-03 00:36:14	2020-04-03	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	9584	delivery	5	36
45860	2020-04-03 00:39:58	2020-04-03	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1110	pick-up	0	26
45861	2020-04-03 00:45:36	2020-04-03	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	97	pick-up	0	35
45862	2020-04-03 00:47:07	2020-04-03	9	[{"id_menu":7,"count":1}]	10999	delivery	5	14
45863	2020-04-03 01:01:29	2020-04-03	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12383	delivery	5	34
45864	2020-04-03 01:04:26	2020-04-03	12	[{"id_menu":1,"count":1}]	2957	delivery	5	17
45865	2020-04-03 01:21:47	2020-04-03	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18250	delivery	5	23
45866	2020-04-03 01:30:40	2020-04-03	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	6355	delivery	5	26
45867	2020-04-03 01:32:46	2020-04-03	12	[{"id_menu":3,"count":1}]	18278	delivery	5	17
45868	2020-04-03 01:34:31	2020-04-03	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":2}]	17607	delivery	5	26
45869	2020-04-03 01:38:22	2020-04-03	14	[{"id_menu":2,"count":1}]	9920	pick-up	0	14
45870	2020-04-03 01:39:29	2020-04-03	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	3996	delivery	5	22
45871	2020-04-03 01:42:29	2020-04-03	12	[{"id_menu":1,"count":1}]	18264	delivery	5	17
45872	2020-04-03 01:49:16	2020-04-03	17	[{"id_menu":4,"count":1}]	6203	delivery	5	22
45873	2020-04-03 02:00:37	2020-04-03	14	[{"id_menu":2,"count":1}]	11148	delivery	5	19
45874	2020-04-03 02:03:06	2020-04-03	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6690	delivery	5	53
45875	2020-04-03 02:05:15	2020-04-03	9	[{"id_menu":7,"count":2}]	5961	delivery	5	14
45876	2020-04-03 02:07:58	2020-04-03	9	[{"id_menu":6,"count":1}]	10159	delivery	5	14
45877	2020-04-03 02:13:39	2020-04-03	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15283	delivery	5	36
45878	2020-04-03 02:19:51	2020-04-03	9	[{"id_menu":6,"count":1}]	4492	delivery	5	14
45879	2020-04-03 02:21:24	2020-04-03	8	[{"id_menu":5,"count":1}]	18245	delivery	5	13
45880	2020-04-03 02:22:11	2020-04-03	14	[{"id_menu":2,"count":1}]	11319	delivery	5	19
45881	2020-04-03 02:31:34	2020-04-03	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18323	delivery	5	40
45882	2020-04-03 02:39:58	2020-04-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	18339	delivery	5	28
45883	2020-04-03 02:58:05	2020-04-03	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	18358	delivery	5	26
45884	2020-04-03 03:04:15	2020-04-03	12	[{"id_menu":3,"count":1}]	8072	delivery	5	17
45885	2020-04-03 03:06:18	2020-04-03	9	[{"id_menu":7,"count":1}]	18284	delivery	5	14
45886	2020-04-03 03:19:25	2020-04-03	9	[{"id_menu":6,"count":1}]	7374	delivery	5	14
45887	2020-04-03 03:30:24	2020-04-03	14	[{"id_menu":2,"count":1}]	10936	delivery	5	19
45888	2020-04-03 03:34:52	2020-04-03	12	[{"id_menu":1,"count":2}]	18328	pick-up	0	12
45889	2020-04-03 03:43:40	2020-04-03	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12294	delivery	5	52
45890	2020-04-03 03:47:48	2020-04-03	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18241	delivery	5	22
45891	2020-04-03 03:49:42	2020-04-03	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	18321	delivery	5	31
45892	2020-04-03 03:56:21	2020-04-03	12	[{"id_menu":1,"count":1}]	623	pick-up	0	12
45893	2020-04-03 03:59:30	2020-04-03	9	[{"id_menu":7,"count":1}]	18305	delivery	5	14
45894	2020-04-03 04:02:59	2020-04-03	17	[{"id_menu":4,"count":1}]	8358	pick-up	0	17
45895	2020-04-03 04:09:26	2020-04-03	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	13893	pick-up	0	29
45896	2020-04-03 04:16:48	2020-04-03	9	[{"id_menu":6,"count":1}]	18342	delivery	5	14
45897	2020-04-03 04:19:52	2020-04-03	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	11628	delivery	5	30
45898	2020-04-03 04:30:33	2020-04-03	8	[{"id_menu":5,"count":1}]	18360	delivery	5	13
45899	2020-04-03 04:33:05	2020-04-03	14	[{"id_menu":2,"count":1}]	18357	delivery	5	19
45900	2020-04-03 04:33:19	2020-04-03	17	[{"id_menu":4,"count":1}]	2551	delivery	5	22
45901	2020-04-03 04:36:47	2020-04-03	9	[{"id_menu":6,"count":1}]	6036	delivery	5	14
45902	2020-04-03 04:40:12	2020-04-03	14	[{"id_menu":2,"count":1}]	18352	delivery	5	19
45903	2020-04-03 04:43:50	2020-04-03	9	[{"id_menu":7,"count":1}]	17091	delivery	5	14
45904	2020-04-03 04:50:43	2020-04-03	14	[{"id_menu":2,"count":1}]	7410	pick-up	0	14
45905	2020-04-03 04:53:33	2020-04-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	13850	delivery	5	28
45906	2020-04-03 04:56:16	2020-04-03	9	[{"id_menu":6,"count":1}]	18228	delivery	5	14
45907	2020-04-03 04:58:01	2020-04-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	15683	pick-up	0	23
45908	2020-04-03 05:44:23	2020-04-03	8	[{"id_menu":5,"count":1}]	4779	delivery	5	13
45909	2020-04-03 05:45:16	2020-04-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	16288	delivery	5	28
45910	2020-04-03 05:54:12	2020-04-03	9	[{"id_menu":6,"count":1}]	18272	delivery	5	14
45911	2020-04-03 06:01:01	2020-04-03	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	18343	delivery	5	28
45912	2020-04-03 06:07:01	2020-04-03	8	[{"id_menu":5,"count":1}]	18243	delivery	5	13
45913	2020-04-03 06:10:27	2020-04-03	9	[{"id_menu":7,"count":1}]	18345	delivery	5	14
45914	2020-04-03 06:12:44	2020-04-03	14	[{"id_menu":2,"count":1}]	18313	delivery	5	19
45915	2020-04-03 06:14:39	2020-04-03	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	4794	delivery	5	26
45916	2020-04-03 06:17:09	2020-04-03	9	[{"id_menu":7,"count":1}]	18246	delivery	5	14
45917	2020-04-03 06:20:07	2020-04-03	14	[{"id_menu":2,"count":1}]	6342	pick-up	0	14
45918	2020-04-03 06:27:33	2020-04-03	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6917	pick-up	0	18
45919	2020-04-03 06:29:53	2020-04-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	18330	delivery	5	28
45920	2020-04-03 06:31:11	2020-04-03	12	[{"id_menu":3,"count":1}]	18336	pick-up	0	12
45921	2020-04-03 06:35:02	2020-04-03	9	[{"id_menu":7,"count":1}]	12908	delivery	5	14
45922	2020-04-03 06:35:56	2020-04-03	12	[{"id_menu":1,"count":1}]	18316	pick-up	0	12
45923	2020-04-03 06:46:43	2020-04-03	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	13711	delivery	5	34
45924	2020-04-03 06:56:59	2020-04-03	14	[{"id_menu":2,"count":1}]	18349	delivery	5	19
45925	2020-04-03 06:57:43	2020-04-03	12	[{"id_menu":1,"count":1}]	14239	pick-up	0	12
45926	2020-04-03 07:00:05	2020-04-03	9	[{"id_menu":6,"count":1}]	18247	delivery	5	14
45927	2020-04-03 07:06:56	2020-04-03	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	63	pick-up	0	38
45928	2020-04-03 07:16:19	2020-04-03	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	18317	delivery	5	30
45929	2020-04-03 07:19:37	2020-04-03	12	[{"id_menu":3,"count":1}]	9014	delivery	5	17
45930	2020-04-03 07:22:48	2020-04-03	14	[{"id_menu":2,"count":1}]	15701	delivery	5	19
45931	2020-04-03 07:26:04	2020-04-03	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	18280	delivery	5	25
45932	2020-04-03 07:30:57	2020-04-03	9	[{"id_menu":7,"count":1}]	4280	delivery	5	14
45933	2020-04-03 07:35:40	2020-04-03	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	619	delivery	5	34
45934	2020-04-03 07:43:06	2020-04-03	14	[{"id_menu":2,"count":1}]	16020	delivery	5	19
45935	2020-04-03 07:47:43	2020-04-03	9	[{"id_menu":6,"count":1}]	15546	delivery	5	14
45936	2020-04-03 07:54:27	2020-04-03	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	12550	delivery	5	40
45937	2020-04-03 07:55:21	2020-04-03	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	4685	pick-up	0	29
45938	2020-04-03 07:56:57	2020-04-03	12	[{"id_menu":3,"count":1}]	18285	delivery	5	17
45939	2020-04-03 08:00:58	2020-04-03	9	[{"id_menu":7,"count":1}]	11367	delivery	5	14
45940	2020-04-03 08:09:26	2020-04-03	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	7582	pick-up	0	22
45941	2020-04-03 08:11:28	2020-04-03	9	[{"id_menu":6,"count":1}]	346	pick-up	0	9
45942	2020-04-03 08:11:50	2020-04-03	9	[{"id_menu":7,"count":1}]	2173	pick-up	0	9
45943	2020-04-03 08:14:13	2020-04-03	12	[{"id_menu":3,"count":1}]	13068	pick-up	0	12
45944	2020-04-03 08:19:15	2020-04-03	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	14701	pick-up	0	47
45945	2020-04-03 08:21:26	2020-04-03	17	[{"id_menu":4,"count":1}]	3931	pick-up	0	17
45946	2020-04-03 08:22:43	2020-04-03	9	[{"id_menu":7,"count":1}]	18354	delivery	5	14
45947	2020-04-03 08:33:37	2020-04-03	17	[{"id_menu":4,"count":1}]	12014	delivery	5	22
45948	2020-04-03 08:38:34	2020-04-03	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	5630	delivery	5	27
45949	2020-04-03 08:39:55	2020-04-03	17	[{"id_menu":4,"count":1}]	18240	delivery	5	22
45950	2020-04-03 08:50:05	2020-04-03	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	18304	pick-up	0	22
45951	2020-04-03 08:52:25	2020-04-03	14	[{"id_menu":2,"count":1}]	5495	pick-up	0	14
45952	2020-04-03 08:55:10	2020-04-03	14	[{"id_menu":2,"count":2}]	5311	pick-up	0	14
45953	2020-04-03 08:59:22	2020-04-03	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3040	delivery	5	23
45954	2020-04-03 09:03:44	2020-04-03	8	[{"id_menu":5,"count":1}]	15965	delivery	5	13
45955	2020-04-03 09:15:57	2020-04-03	9	[{"id_menu":7,"count":1}]	12934	delivery	5	14
45956	2020-04-03 09:16:12	2020-04-03	9	[{"id_menu":7,"count":2}]	6729	delivery	5	14
45957	2020-04-03 09:22:13	2020-04-03	9	[{"id_menu":6,"count":1}]	10212	pick-up	0	9
45958	2020-04-03 09:24:57	2020-04-03	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15594	delivery	5	31
45959	2020-04-03 09:28:42	2020-04-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3065	delivery	5	28
45960	2020-04-03 09:36:00	2020-04-03	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	18271	delivery	5	40
45961	2020-04-03 09:41:57	2020-04-03	12	[{"id_menu":1,"count":1}]	15400	pick-up	0	12
45962	2020-04-03 09:43:17	2020-04-03	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	18286	delivery	5	34
45963	2020-04-03 09:44:00	2020-04-03	14	[{"id_menu":2,"count":1}]	18327	delivery	5	19
45964	2020-04-03 09:44:56	2020-04-03	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	18359	delivery	5	52
45965	2020-04-03 09:46:56	2020-04-03	8	[{"id_menu":5,"count":1}]	11834	delivery	5	13
45966	2020-04-03 09:47:19	2020-04-03	14	[{"id_menu":2,"count":1}]	12078	delivery	5	19
45967	2020-04-03 09:53:42	2020-04-03	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	5097	delivery	5	25
45968	2020-04-03 09:54:27	2020-04-03	17	[{"id_menu":4,"count":1}]	15550	pick-up	0	17
45969	2020-04-03 09:58:18	2020-04-03	9	[{"id_menu":7,"count":1}]	17904	delivery	5	14
45970	2020-04-03 09:59:50	2020-04-03	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	113	pick-up	0	29
45971	2020-04-03 10:04:30	2020-04-03	9	[{"id_menu":7,"count":1}]	6288	delivery	5	14
45972	2020-04-03 10:07:37	2020-04-03	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	7823	delivery	5	39
45973	2020-04-03 10:09:21	2020-04-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	18257	delivery	5	28
45974	2020-04-03 10:10:10	2020-04-03	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13935	delivery	5	39
45975	2020-04-03 10:13:08	2020-04-03	14	[{"id_menu":2,"count":1}]	7041	delivery	5	19
45976	2020-04-03 10:16:36	2020-04-03	14	[{"id_menu":2,"count":1}]	491	pick-up	0	14
45977	2020-04-03 10:18:10	2020-04-03	17	[{"id_menu":4,"count":1}]	8123	pick-up	0	17
45978	2020-04-03 10:18:31	2020-04-03	12	[{"id_menu":1,"count":1}]	11378	delivery	5	17
45979	2020-04-03 10:28:30	2020-04-03	14	[{"id_menu":2,"count":1}]	1266	pick-up	0	14
45980	2020-04-03 10:28:35	2020-04-03	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	10690	delivery	5	26
45981	2020-04-03 10:32:01	2020-04-03	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15855	delivery	5	34
45982	2020-04-03 10:34:31	2020-04-03	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8600	delivery	5	44
45983	2020-04-03 10:34:41	2020-04-03	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	18236	delivery	5	40
45984	2020-04-03 10:45:51	2020-04-03	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	18283	delivery	5	39
45985	2020-04-03 10:48:46	2020-04-03	9	[{"id_menu":6,"count":1}]	9562	delivery	5	14
45986	2020-04-03 10:49:37	2020-04-03	12	[{"id_menu":3,"count":1}]	6332	delivery	5	17
45987	2020-04-03 10:56:11	2020-04-03	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	11052	delivery	5	27
45988	2020-04-03 10:56:18	2020-04-03	14	[{"id_menu":2,"count":1}]	5248	pick-up	0	14
45989	2020-04-03 10:59:07	2020-04-03	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	17128	delivery	5	26
45990	2020-04-03 11:13:39	2020-04-03	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13191	delivery	5	31
45991	2020-04-03 11:15:18	2020-04-03	9	[{"id_menu":6,"count":1}]	18312	delivery	5	14
45992	2020-04-03 11:19:32	2020-04-03	8	[{"id_menu":5,"count":1}]	4495	delivery	5	13
45993	2020-04-03 11:23:21	2020-04-03	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":3}]	3445	delivery	5	25
45994	2020-04-03 11:27:31	2020-04-03	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	13779	delivery	5	31
45995	2020-04-03 11:29:49	2020-04-03	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11731	delivery	5	37
45996	2020-04-03 11:30:16	2020-04-03	17	[{"id_menu":4,"count":1}]	374	pick-up	0	17
45997	2020-04-03 11:30:30	2020-04-03	14	[{"id_menu":2,"count":1}]	2776	delivery	5	19
45998	2020-04-03 11:32:53	2020-04-03	17	[{"id_menu":4,"count":1}]	14190	delivery	5	22
45999	2020-04-03 11:33:42	2020-04-03	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18276	delivery	5	31
46000	2020-04-03 11:40:00	2020-04-03	14	[{"id_menu":2,"count":1}]	820	pick-up	0	14
46001	2020-04-03 11:40:17	2020-04-03	17	[{"id_menu":4,"count":1}]	18320	pick-up	0	17
46002	2020-04-03 11:40:22	2020-04-03	12	[{"id_menu":1,"count":1}]	5292	pick-up	0	12
46003	2020-04-03 11:42:35	2020-04-03	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":3}]	12073	delivery	5	26
46004	2020-04-03 11:51:53	2020-04-03	14	[{"id_menu":2,"count":2}]	9716	pick-up	0	14
46005	2020-04-03 11:53:23	2020-04-03	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	6891	delivery	5	34
46006	2020-04-03 11:59:03	2020-04-03	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9847	pick-up	0	17
46007	2020-04-03 12:04:31	2020-04-03	9	[{"id_menu":6,"count":1}]	1104	delivery	5	14
46008	2020-04-03 12:11:13	2020-04-03	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	18227	delivery	5	26
46009	2020-04-03 12:19:03	2020-04-03	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	17841	delivery	5	31
46010	2020-04-03 12:28:15	2020-04-03	17	[{"id_menu":4,"count":1}]	14536	delivery	5	22
46011	2020-04-03 12:34:07	2020-04-03	17	[{"id_menu":4,"count":1}]	3125	delivery	5	22
46012	2020-04-03 12:35:02	2020-04-03	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2089	pick-up	0	39
46013	2020-04-03 12:37:42	2020-04-03	14	[{"id_menu":2,"count":1}]	18346	delivery	5	19
46014	2020-04-03 12:38:17	2020-04-03	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15122	delivery	5	43
46015	2020-04-03 12:42:28	2020-04-03	12	[{"id_menu":3,"count":1}]	18231	pick-up	0	12
46016	2020-04-03 12:49:56	2020-04-03	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	18341	delivery	5	39
46017	2020-04-03 12:53:25	2020-04-03	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	16850	delivery	5	42
46018	2020-04-03 12:57:07	2020-04-03	17	[{"id_menu":4,"count":1}]	9885	delivery	5	22
46019	2020-04-03 12:58:11	2020-04-03	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10444	delivery	5	39
46020	2020-04-03 12:58:39	2020-04-03	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18311	delivery	5	39
46021	2020-04-03 13:00:43	2020-04-03	8	[{"id_menu":5,"count":1}]	18253	pick-up	0	8
46022	2020-04-03 13:05:27	2020-04-03	17	[{"id_menu":4,"count":1}]	3228	pick-up	0	17
46023	2020-04-03 13:10:45	2020-04-03	14	[{"id_menu":2,"count":1}]	13187	delivery	5	19
46024	2020-04-03 13:12:32	2020-04-03	9	[{"id_menu":7,"count":1}]	18332	delivery	5	14
46025	2020-04-03 13:14:09	2020-04-03	9	[{"id_menu":7,"count":2}]	18295	delivery	5	14
46026	2020-04-03 13:18:46	2020-04-03	12	[{"id_menu":3,"count":1}]	18292	delivery	5	17
46027	2020-04-03 13:19:15	2020-04-03	17	[{"id_menu":4,"count":1}]	18353	pick-up	0	17
46028	2020-04-03 13:33:29	2020-04-03	9	[{"id_menu":7,"count":1}]	16660	delivery	5	14
46029	2020-04-03 13:50:18	2020-04-03	12	[{"id_menu":3,"count":1}]	1258	delivery	5	17
46030	2020-04-03 13:57:32	2020-04-03	9	[{"id_menu":6,"count":1}]	1385	pick-up	0	9
46031	2020-04-03 13:57:42	2020-04-03	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	18297	delivery	5	34
46032	2020-04-03 14:04:47	2020-04-03	8	[{"id_menu":5,"count":1}]	7044	delivery	5	13
46033	2020-04-03 14:04:50	2020-04-03	17	[{"id_menu":4,"count":1}]	7919	pick-up	0	17
46034	2020-04-03 14:05:17	2020-04-03	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17328	pick-up	0	26
46035	2020-04-03 14:08:51	2020-04-03	12	[{"id_menu":1,"count":1}]	18232	pick-up	0	12
46036	2020-04-03 14:11:48	2020-04-03	12	[{"id_menu":3,"count":1}]	11682	pick-up	0	12
46037	2020-04-03 14:11:48	2020-04-03	17	[{"id_menu":4,"count":1}]	90	delivery	5	22
46038	2020-04-03 14:18:50	2020-04-03	9	[{"id_menu":6,"count":1}]	207	delivery	5	14
46039	2020-04-03 14:25:36	2020-04-03	9	[{"id_menu":6,"count":1}]	18256	delivery	5	14
46040	2020-04-03 14:25:53	2020-04-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8574	pick-up	0	26
46041	2020-04-03 14:35:54	2020-04-03	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	18331	pick-up	0	35
46042	2020-04-03 14:39:57	2020-04-03	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18344	pick-up	0	34
46043	2020-04-03 14:44:57	2020-04-03	9	[{"id_menu":7,"count":1}]	18238	delivery	5	14
46044	2020-04-03 14:54:04	2020-04-03	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	18289	delivery	5	27
46045	2020-04-03 15:03:55	2020-04-03	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	5580	delivery	5	29
46046	2020-04-03 15:08:06	2020-04-03	12	[{"id_menu":3,"count":1}]	3907	pick-up	0	12
46047	2020-04-03 15:09:53	2020-04-03	14	[{"id_menu":2,"count":1}]	3271	pick-up	0	14
46048	2020-04-03 15:12:54	2020-04-03	14	[{"id_menu":2,"count":1}]	127	delivery	5	19
46049	2020-04-03 15:28:34	2020-04-03	17	[{"id_menu":4,"count":1}]	5526	delivery	5	22
46050	2020-04-03 15:34:52	2020-04-03	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	6846	delivery	5	43
46051	2020-04-03 15:36:56	2020-04-03	8	[{"id_menu":5,"count":1}]	8083	pick-up	0	8
46052	2020-04-03 15:40:01	2020-04-03	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	14852	delivery	5	26
46053	2020-04-03 15:41:13	2020-04-03	9	[{"id_menu":6,"count":1}]	8411	delivery	5	14
46054	2020-04-03 15:49:43	2020-04-03	14	[{"id_menu":2,"count":1}]	18301	delivery	5	19
46055	2020-04-03 15:51:36	2020-04-03	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	18329	delivery	5	30
46056	2020-04-03 15:59:01	2020-04-03	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	18274	delivery	5	31
46057	2020-04-03 16:06:17	2020-04-03	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	9713	delivery	5	27
46058	2020-04-03 16:07:35	2020-04-03	14	[{"id_menu":2,"count":1}]	2508	pick-up	0	14
46059	2020-04-03 16:08:14	2020-04-03	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	16295	delivery	5	25
46060	2020-04-03 16:09:54	2020-04-03	8	[{"id_menu":5,"count":1}]	11006	delivery	5	13
46061	2020-04-03 16:14:49	2020-04-03	8	[{"id_menu":5,"count":1}]	6722	delivery	5	13
46062	2020-04-03 16:14:49	2020-04-03	9	[{"id_menu":6,"count":1}]	18248	delivery	5	14
46063	2020-04-03 16:24:53	2020-04-03	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7798	delivery	5	42
46064	2020-04-03 16:26:42	2020-04-03	9	[{"id_menu":7,"count":1}]	18314	delivery	5	14
46065	2020-04-03 16:30:15	2020-04-03	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14484	delivery	5	37
46066	2020-04-03 16:38:52	2020-04-03	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	18239	pick-up	0	40
46067	2020-04-03 16:42:04	2020-04-03	9	[{"id_menu":6,"count":1}]	17145	pick-up	0	9
46068	2020-04-03 16:42:11	2020-04-03	9	[{"id_menu":7,"count":1}]	18307	delivery	5	14
46069	2020-04-03 16:42:14	2020-04-03	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4594	delivery	5	39
46070	2020-04-03 16:48:16	2020-04-03	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	18242	delivery	5	38
46071	2020-04-03 16:56:24	2020-04-03	14	[{"id_menu":2,"count":1}]	18308	delivery	5	19
46072	2020-04-03 16:56:41	2020-04-03	9	[{"id_menu":6,"count":1}]	18340	delivery	5	14
46073	2020-04-03 16:57:42	2020-04-03	12	[{"id_menu":3,"count":2}]	16581	delivery	5	17
46074	2020-04-03 17:05:45	2020-04-03	9	[{"id_menu":7,"count":1}]	7297	pick-up	0	9
46075	2020-04-03 17:08:47	2020-04-03	17	[{"id_menu":4,"count":1}]	18309	pick-up	0	17
46076	2020-04-03 17:09:10	2020-04-03	17	[{"id_menu":4,"count":1}]	18269	delivery	5	22
46077	2020-04-03 17:11:46	2020-04-03	9	[{"id_menu":6,"count":1}]	18266	delivery	5	14
46078	2020-04-03 17:14:11	2020-04-03	9	[{"id_menu":7,"count":1}]	6446	pick-up	0	9
46079	2020-04-03 17:19:34	2020-04-03	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17683	delivery	5	35
46080	2020-04-03 17:21:45	2020-04-03	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	18273	delivery	5	31
46081	2020-04-03 17:22:01	2020-04-03	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6276	delivery	5	34
46082	2020-04-03 17:27:02	2020-04-03	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5768	delivery	5	40
46083	2020-04-03 17:27:08	2020-04-03	9	[{"id_menu":6,"count":1}]	10772	pick-up	0	9
46084	2020-04-03 17:31:59	2020-04-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16901	delivery	5	31
46085	2020-04-03 17:35:07	2020-04-03	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	18306	delivery	5	34
46086	2020-04-03 17:40:10	2020-04-03	9	[{"id_menu":6,"count":1}]	14566	delivery	5	14
46087	2020-04-03 17:59:45	2020-04-03	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16996	delivery	5	43
46088	2020-04-03 18:01:26	2020-04-03	8	[{"id_menu":5,"count":1}]	10323	delivery	5	13
46089	2020-04-03 18:09:15	2020-04-03	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17366	delivery	5	31
46090	2020-04-03 18:14:22	2020-04-03	9	[{"id_menu":6,"count":1}]	18350	delivery	5	14
46091	2020-04-03 18:16:17	2020-04-03	9	[{"id_menu":7,"count":1}]	18348	delivery	5	14
46092	2020-04-03 18:17:18	2020-04-03	9	[{"id_menu":6,"count":1}]	3012	pick-up	0	9
46093	2020-04-03 18:30:34	2020-04-03	17	[{"id_menu":4,"count":1}]	1088	delivery	5	22
46094	2020-04-03 18:37:17	2020-04-03	12	[{"id_menu":1,"count":1}]	1834	pick-up	0	12
46095	2020-04-03 18:43:01	2020-04-03	9	[{"id_menu":6,"count":1}]	14636	delivery	5	14
46096	2020-04-03 18:44:29	2020-04-03	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16500	delivery	5	34
46097	2020-04-03 18:50:55	2020-04-03	9	[{"id_menu":6,"count":1}]	17654	delivery	5	14
46098	2020-04-03 18:52:57	2020-04-03	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18303	delivery	5	49
46099	2020-04-03 18:56:14	2020-04-03	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	18268	delivery	5	40
46100	2020-04-03 18:58:53	2020-04-03	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	18263	delivery	5	31
46101	2020-04-03 19:05:11	2020-04-03	14	[{"id_menu":2,"count":1}]	2168	delivery	5	19
46102	2020-04-03 19:05:19	2020-04-03	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	18255	delivery	5	40
46103	2020-04-03 19:18:20	2020-04-03	9	[{"id_menu":6,"count":1}]	3260	pick-up	0	9
46104	2020-04-03 19:28:28	2020-04-03	8	[{"id_menu":5,"count":1}]	14014	pick-up	0	8
46105	2020-04-03 19:29:39	2020-04-03	8	[{"id_menu":5,"count":1}]	18000	delivery	5	13
46106	2020-04-03 19:42:39	2020-04-03	14	[{"id_menu":2,"count":1}]	1183	pick-up	0	14
46107	2020-04-03 19:43:08	2020-04-03	9	[{"id_menu":6,"count":1}]	18262	pick-up	0	9
46108	2020-04-03 19:52:33	2020-04-03	8	[{"id_menu":5,"count":1}]	3889	delivery	5	13
46109	2020-04-03 19:56:16	2020-04-03	9	[{"id_menu":7,"count":1}]	3986	pick-up	0	9
46110	2020-04-03 20:02:42	2020-04-03	8	[{"id_menu":5,"count":1}]	18244	delivery	5	13
46111	2020-04-03 20:03:40	2020-04-03	9	[{"id_menu":7,"count":1}]	3807	delivery	5	14
46112	2020-04-03 20:06:41	2020-04-03	8	[{"id_menu":5,"count":1}]	18267	pick-up	0	8
46113	2020-04-03 20:07:11	2020-04-03	9	[{"id_menu":7,"count":1}]	12084	delivery	5	14
46114	2020-04-03 20:07:12	2020-04-03	9	[{"id_menu":6,"count":2}]	18326	delivery	5	14
46115	2020-04-03 20:08:19	2020-04-03	17	[{"id_menu":4,"count":1}]	14654	delivery	5	22
46116	2020-04-03 20:10:37	2020-04-03	12	[{"id_menu":1,"count":1}]	7140	pick-up	0	12
46117	2020-04-03 20:13:21	2020-04-03	12	[{"id_menu":3,"count":1}]	500	pick-up	0	12
46118	2020-04-03 20:26:50	2020-04-03	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12089	delivery	5	43
46119	2020-04-03 20:33:05	2020-04-03	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1013	delivery	5	28
46120	2020-04-03 20:33:40	2020-04-03	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	18302	delivery	5	36
46121	2020-04-03 20:45:28	2020-04-03	17	[{"id_menu":4,"count":1}]	13059	delivery	5	22
46122	2020-04-03 20:49:02	2020-04-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	466	delivery	5	28
46123	2020-04-03 21:04:32	2020-04-03	9	[{"id_menu":6,"count":1}]	18229	delivery	5	14
46124	2020-04-03 21:14:34	2020-04-03	9	[{"id_menu":6,"count":1}]	18351	delivery	5	14
46125	2020-04-03 21:14:48	2020-04-03	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3971	pick-up	0	25
46126	2020-04-03 21:16:09	2020-04-03	9	[{"id_menu":6,"count":1}]	9688	delivery	5	14
46127	2020-04-03 21:16:58	2020-04-03	17	[{"id_menu":4,"count":1}]	5136	delivery	5	22
46128	2020-04-03 21:35:25	2020-04-03	17	[{"id_menu":4,"count":1}]	691	pick-up	0	17
46129	2020-04-03 21:36:18	2020-04-03	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4986	pick-up	0	25
46130	2020-04-03 21:42:00	2020-04-03	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	13461	pick-up	0	43
46131	2020-04-03 21:44:25	2020-04-03	9	[{"id_menu":6,"count":1}]	18282	delivery	5	14
46132	2020-04-03 21:49:24	2020-04-03	9	[{"id_menu":7,"count":1}]	3633	delivery	5	14
46133	2020-04-03 21:52:46	2020-04-03	12	[{"id_menu":1,"count":1}]	18275	delivery	5	17
46134	2020-04-03 21:57:42	2020-04-03	14	[{"id_menu":2,"count":1}]	14764	delivery	5	19
46135	2020-04-03 22:03:12	2020-04-03	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	13707	pick-up	0	37
46136	2020-04-03 22:07:25	2020-04-03	12	[{"id_menu":3,"count":1}]	5555	delivery	5	17
46137	2020-04-03 22:07:34	2020-04-03	12	[{"id_menu":1,"count":1}]	17174	pick-up	0	12
46138	2020-04-03 22:08:04	2020-04-03	14	[{"id_menu":2,"count":1}]	13335	pick-up	0	14
46139	2020-04-03 22:09:51	2020-04-03	14	[{"id_menu":2,"count":3}]	11407	pick-up	0	14
46140	2020-04-03 22:13:16	2020-04-03	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	10972	delivery	5	31
46141	2020-04-03 22:17:13	2020-04-03	14	[{"id_menu":2,"count":2}]	18234	delivery	5	19
46142	2020-04-03 22:19:50	2020-04-03	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	11172	delivery	5	43
46143	2020-04-03 22:22:08	2020-04-03	9	[{"id_menu":7,"count":1}]	12586	delivery	5	14
46144	2020-04-03 22:23:43	2020-04-03	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1735	pick-up	0	26
46145	2020-04-03 22:23:47	2020-04-03	8	[{"id_menu":5,"count":1}]	18294	pick-up	0	8
46146	2020-04-03 22:27:18	2020-04-03	8	[{"id_menu":5,"count":2}]	3438	delivery	5	13
46147	2020-04-03 22:41:11	2020-04-03	8	[{"id_menu":5,"count":1}]	11620	delivery	5	13
46148	2020-04-03 22:43:31	2020-04-03	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	18258	delivery	5	28
46149	2020-04-03 22:47:06	2020-04-03	17	[{"id_menu":4,"count":1}]	3919	pick-up	0	17
46150	2020-04-03 22:49:49	2020-04-03	9	[{"id_menu":7,"count":1}]	15157	delivery	5	14
46151	2020-04-03 22:52:06	2020-04-03	9	[{"id_menu":7,"count":1}]	2943	delivery	5	14
46152	2020-04-03 22:55:33	2020-04-03	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	11010	pick-up	0	21
46153	2020-04-03 22:57:23	2020-04-03	8	[{"id_menu":5,"count":1}]	5837	delivery	5	13
46154	2020-04-03 23:08:19	2020-04-03	12	[{"id_menu":3,"count":1}]	9449	delivery	5	17
46155	2020-04-03 23:17:29	2020-04-03	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12180	delivery	5	22
46156	2020-04-03 23:20:23	2020-04-03	9	[{"id_menu":7,"count":1}]	18254	delivery	5	14
46157	2020-04-03 23:36:26	2020-04-03	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	18259	pick-up	0	21
46158	2020-04-03 23:40:10	2020-04-03	9	[{"id_menu":6,"count":1}]	1368	pick-up	0	9
46159	2020-04-03 23:40:54	2020-04-03	9	[{"id_menu":6,"count":1}]	18324	delivery	5	14
46160	2020-04-03 23:44:19	2020-04-03	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	18279	pick-up	0	20
46161	2020-04-03 23:45:26	2020-04-03	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	6168	delivery	5	25
46162	2020-04-03 23:55:08	2020-04-03	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1759	pick-up	0	25
46163	2020-04-03 23:55:26	2020-04-03	9	[{"id_menu":6,"count":1}]	5635	delivery	5	14
46164	2020-04-04 00:00:37	2020-04-04	9	[{"id_menu":7,"count":1}]	7878	delivery	5	14
46165	2020-04-04 00:00:56	2020-04-04	8	[{"id_menu":5,"count":1}]	4191	pick-up	0	8
46166	2020-04-04 00:01:53	2020-04-04	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17084	delivery	5	31
46167	2020-04-04 00:01:54	2020-04-04	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	18464	delivery	5	26
46168	2020-04-04 00:03:08	2020-04-04	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	18380	delivery	5	48
46169	2020-04-04 00:08:35	2020-04-04	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	11298	delivery	5	26
46170	2020-04-04 00:11:50	2020-04-04	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	13335	pick-up	0	21
46171	2020-04-04 00:16:12	2020-04-04	14	[{"id_menu":2,"count":1}]	6091	pick-up	0	14
46172	2020-04-04 00:17:48	2020-04-04	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1369	pick-up	0	21
46173	2020-04-04 00:18:04	2020-04-04	17	[{"id_menu":4,"count":1}]	993	pick-up	0	17
46174	2020-04-04 00:24:15	2020-04-04	12	[{"id_menu":3,"count":1}]	14165	delivery	5	17
46175	2020-04-04 00:24:37	2020-04-04	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	15350	delivery	5	30
46176	2020-04-04 00:25:12	2020-04-04	9	[{"id_menu":6,"count":1}]	14362	delivery	5	14
46177	2020-04-04 00:27:04	2020-04-04	9	[{"id_menu":6,"count":1}]	4862	pick-up	0	9
46178	2020-04-04 00:30:15	2020-04-04	9	[{"id_menu":6,"count":1}]	2172	delivery	5	14
46179	2020-04-04 00:34:49	2020-04-04	8	[{"id_menu":5,"count":1}]	18421	delivery	5	13
46180	2020-04-04 00:35:07	2020-04-04	17	[{"id_menu":4,"count":1}]	18455	delivery	5	22
46181	2020-04-04 00:38:48	2020-04-04	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5426	pick-up	0	25
46182	2020-04-04 00:41:35	2020-04-04	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8355	pick-up	0	18
46183	2020-04-04 00:44:37	2020-04-04	9	[{"id_menu":6,"count":1}]	17238	delivery	5	14
46184	2020-04-04 00:46:12	2020-04-04	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7766	delivery	5	23
46185	2020-04-04 00:50:47	2020-04-04	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18365	delivery	5	23
46186	2020-04-04 00:57:38	2020-04-04	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	6811	delivery	5	26
46187	2020-04-04 01:00:09	2020-04-04	8	[{"id_menu":5,"count":1}]	10176	delivery	5	13
46188	2020-04-04 01:05:18	2020-04-04	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11284	delivery	5	39
46189	2020-04-04 01:09:37	2020-04-04	9	[{"id_menu":6,"count":1}]	10705	delivery	5	14
46190	2020-04-04 01:12:17	2020-04-04	12	[{"id_menu":3,"count":1}]	3066	pick-up	0	12
46191	2020-04-04 01:14:46	2020-04-04	12	[{"id_menu":3,"count":1}]	766	pick-up	0	12
46192	2020-04-04 01:15:14	2020-04-04	9	[{"id_menu":7,"count":1}]	519	pick-up	0	9
46193	2020-04-04 01:19:09	2020-04-04	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	790	delivery	5	26
46194	2020-04-04 01:23:47	2020-04-04	8	[{"id_menu":5,"count":1}]	18426	pick-up	0	8
46195	2020-04-04 01:26:16	2020-04-04	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10461	delivery	5	43
46196	2020-04-04 01:30:30	2020-04-04	14	[{"id_menu":2,"count":1}]	18462	delivery	5	19
46197	2020-04-04 01:33:34	2020-04-04	14	[{"id_menu":2,"count":1}]	15828	delivery	5	19
46198	2020-04-04 01:38:18	2020-04-04	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	18393	pick-up	0	34
46199	2020-04-04 01:54:02	2020-04-04	17	[{"id_menu":4,"count":1}]	15518	pick-up	0	17
46200	2020-04-04 01:58:14	2020-04-04	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17784	pick-up	0	18
46201	2020-04-04 02:02:52	2020-04-04	12	[{"id_menu":1,"count":1}]	1208	delivery	5	17
46202	2020-04-04 02:08:36	2020-04-04	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12615	delivery	5	43
46203	2020-04-04 02:10:08	2020-04-04	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	18443	delivery	5	26
46204	2020-04-04 02:20:49	2020-04-04	12	[{"id_menu":1,"count":1}]	4051	pick-up	0	12
46205	2020-04-04 02:27:59	2020-04-04	9	[{"id_menu":7,"count":1}]	15186	delivery	5	14
46206	2020-04-04 02:32:29	2020-04-04	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	34	pick-up	0	43
46207	2020-04-04 02:34:44	2020-04-04	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	14844	delivery	5	28
46208	2020-04-04 02:35:28	2020-04-04	8	[{"id_menu":5,"count":1}]	18388	delivery	5	13
46209	2020-04-04 02:35:28	2020-04-04	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1485	pick-up	0	35
46210	2020-04-04 02:36:24	2020-04-04	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5787	delivery	5	36
46211	2020-04-04 02:37:12	2020-04-04	9	[{"id_menu":6,"count":1}]	376	delivery	5	14
46212	2020-04-04 02:40:47	2020-04-04	9	[{"id_menu":7,"count":1}]	17780	delivery	5	14
46213	2020-04-04 02:41:47	2020-04-04	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	5379	delivery	5	43
46214	2020-04-04 02:44:43	2020-04-04	9	[{"id_menu":6,"count":1}]	4735	delivery	5	14
46215	2020-04-04 02:44:44	2020-04-04	23	[{"id_menu":2,"count":3},{"id_menu":6,"count":1}]	13578	delivery	5	28
46216	2020-04-04 02:45:04	2020-04-04	12	[{"id_menu":3,"count":1}]	5416	pick-up	0	12
46217	2020-04-04 02:45:58	2020-04-04	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	18441	pick-up	0	29
46218	2020-04-04 02:59:23	2020-04-04	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	10144	delivery	5	35
46219	2020-04-04 03:02:22	2020-04-04	9	[{"id_menu":7,"count":1}]	683	pick-up	0	9
46220	2020-04-04 03:02:36	2020-04-04	8	[{"id_menu":5,"count":1}]	5375	delivery	5	13
46221	2020-04-04 03:02:57	2020-04-04	9	[{"id_menu":6,"count":2}]	8753	delivery	5	14
46222	2020-04-04 03:07:16	2020-04-04	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	985	pick-up	0	18
46223	2020-04-04 03:07:54	2020-04-04	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	10497	delivery	5	27
46224	2020-04-04 03:08:29	2020-04-04	12	[{"id_menu":1,"count":1}]	16956	delivery	5	17
46225	2020-04-04 03:14:26	2020-04-04	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	5382	delivery	5	26
46226	2020-04-04 03:15:25	2020-04-04	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	6499	delivery	5	23
46227	2020-04-04 03:43:38	2020-04-04	14	[{"id_menu":2,"count":1}]	18475	delivery	5	19
46228	2020-04-04 03:43:47	2020-04-04	17	[{"id_menu":4,"count":1}]	18384	pick-up	0	17
46229	2020-04-04 03:48:32	2020-04-04	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8877	delivery	5	22
46230	2020-04-04 03:48:50	2020-04-04	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3740	delivery	5	36
46231	2020-04-04 03:50:01	2020-04-04	12	[{"id_menu":3,"count":1}]	9204	pick-up	0	12
46232	2020-04-04 03:51:53	2020-04-04	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	4	pick-up	0	23
46233	2020-04-04 03:58:30	2020-04-04	14	[{"id_menu":2,"count":1}]	1296	delivery	5	19
46234	2020-04-04 04:00:32	2020-04-04	9	[{"id_menu":7,"count":1}]	9366	delivery	5	14
46235	2020-04-04 04:05:41	2020-04-04	9	[{"id_menu":6,"count":1}]	3363	delivery	5	14
46236	2020-04-04 04:14:29	2020-04-04	9	[{"id_menu":7,"count":1}]	18440	delivery	5	14
46237	2020-04-04 04:19:06	2020-04-04	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17205	delivery	5	48
46238	2020-04-04 04:19:13	2020-04-04	9	[{"id_menu":6,"count":1}]	5269	delivery	5	14
46239	2020-04-04 04:24:58	2020-04-04	14	[{"id_menu":2,"count":1}]	8494	delivery	5	19
46240	2020-04-04 04:36:22	2020-04-04	8	[{"id_menu":5,"count":1}]	12423	pick-up	0	8
46241	2020-04-04 04:36:23	2020-04-04	38	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	18398	delivery	5	43
46242	2020-04-04 04:40:25	2020-04-04	9	[{"id_menu":6,"count":1}]	18403	delivery	5	14
46243	2020-04-04 04:40:38	2020-04-04	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	169	pick-up	0	23
46244	2020-04-04 04:44:01	2020-04-04	17	[{"id_menu":4,"count":1}]	18338	delivery	5	22
46245	2020-04-04 04:45:50	2020-04-04	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18487	delivery	5	34
46246	2020-04-04 04:46:35	2020-04-04	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1674	pick-up	0	21
46247	2020-04-04 04:49:25	2020-04-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	18456	delivery	5	28
46248	2020-04-04 04:56:49	2020-04-04	12	[{"id_menu":1,"count":1}]	4878	delivery	5	17
46249	2020-04-04 04:57:23	2020-04-04	12	[{"id_menu":1,"count":1}]	16463	pick-up	0	12
46250	2020-04-04 04:59:23	2020-04-04	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	16823	delivery	5	26
46251	2020-04-04 05:05:14	2020-04-04	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	18439	delivery	5	26
46252	2020-04-04 05:09:50	2020-04-04	9	[{"id_menu":7,"count":1}]	18463	delivery	5	14
46253	2020-04-04 05:12:02	2020-04-04	9	[{"id_menu":7,"count":1}]	4193	pick-up	0	9
46254	2020-04-04 05:14:05	2020-04-04	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	3521	delivery	5	36
46255	2020-04-04 05:14:54	2020-04-04	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	18412	delivery	5	36
46256	2020-04-04 05:14:59	2020-04-04	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5997	delivery	5	31
46257	2020-04-04 05:18:49	2020-04-04	9	[{"id_menu":6,"count":4}]	17260	delivery	5	14
46258	2020-04-04 05:20:11	2020-04-04	9	[{"id_menu":6,"count":2}]	18389	delivery	5	14
46259	2020-04-04 05:28:42	2020-04-04	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	9166	delivery	5	31
46260	2020-04-04 05:29:36	2020-04-04	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	18433	delivery	5	22
46261	2020-04-04 05:47:08	2020-04-04	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	18471	delivery	5	43
46262	2020-04-04 05:47:39	2020-04-04	17	[{"id_menu":4,"count":2}]	1131	pick-up	0	17
46263	2020-04-04 05:52:08	2020-04-04	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18445	pick-up	0	17
46264	2020-04-04 06:00:45	2020-04-04	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15121	delivery	5	53
46265	2020-04-04 06:06:48	2020-04-04	9	[{"id_menu":7,"count":1}]	2783	delivery	5	14
46266	2020-04-04 06:07:08	2020-04-04	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	6235	pick-up	0	26
46267	2020-04-04 06:09:23	2020-04-04	9	[{"id_menu":6,"count":1}]	11550	delivery	5	14
46268	2020-04-04 06:11:50	2020-04-04	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":2}]	4649	delivery	5	31
46269	2020-04-04 06:17:50	2020-04-04	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7289	delivery	5	40
46270	2020-04-04 06:26:16	2020-04-04	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	18396	delivery	5	26
46271	2020-04-04 06:29:31	2020-04-04	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18457	delivery	5	34
46272	2020-04-04 06:36:34	2020-04-04	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	14221	delivery	5	43
46273	2020-04-04 06:39:43	2020-04-04	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	8659	delivery	5	22
46274	2020-04-04 06:39:47	2020-04-04	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3002	pick-up	0	25
46275	2020-04-04 06:43:23	2020-04-04	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	18372	delivery	5	22
46276	2020-04-04 06:43:48	2020-04-04	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	10729	delivery	5	28
46277	2020-04-04 06:43:52	2020-04-04	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16366	delivery	5	36
46278	2020-04-04 06:49:20	2020-04-04	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18474	delivery	5	37
46279	2020-04-04 06:53:54	2020-04-04	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2912	delivery	5	40
46280	2020-04-04 06:58:57	2020-04-04	9	[{"id_menu":7,"count":1}]	5783	pick-up	0	9
46281	2020-04-04 07:00:24	2020-04-04	9	[{"id_menu":6,"count":1}]	18361	delivery	5	14
46282	2020-04-04 07:03:16	2020-04-04	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18437	delivery	5	48
46283	2020-04-04 07:05:11	2020-04-04	8	[{"id_menu":5,"count":1}]	18383	delivery	5	13
46284	2020-04-04 07:05:27	2020-04-04	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	18374	pick-up	0	21
46285	2020-04-04 07:11:12	2020-04-04	9	[{"id_menu":6,"count":1}]	18447	delivery	5	14
46286	2020-04-04 07:12:49	2020-04-04	8	[{"id_menu":5,"count":4}]	14749	delivery	5	13
46287	2020-04-04 07:13:05	2020-04-04	17	[{"id_menu":4,"count":1}]	14352	delivery	5	22
46288	2020-04-04 07:15:30	2020-04-04	8	[{"id_menu":5,"count":1}]	11589	delivery	5	13
46289	2020-04-04 07:22:01	2020-04-04	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3137	delivery	5	34
46290	2020-04-04 07:24:04	2020-04-04	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3992	delivery	5	37
46291	2020-04-04 07:26:32	2020-04-04	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16341	delivery	5	39
46292	2020-04-04 07:27:19	2020-04-04	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7418	delivery	5	42
46293	2020-04-04 07:27:42	2020-04-04	9	[{"id_menu":6,"count":1}]	9436	delivery	5	14
46294	2020-04-04 07:29:15	2020-04-04	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	18432	delivery	5	29
46295	2020-04-04 07:30:07	2020-04-04	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7730	delivery	5	43
46296	2020-04-04 07:31:29	2020-04-04	12	[{"id_menu":1,"count":1}]	586	delivery	5	17
46297	2020-04-04 07:32:06	2020-04-04	9	[{"id_menu":7,"count":1}]	6003	pick-up	0	9
46298	2020-04-04 07:32:06	2020-04-04	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	18468	delivery	5	39
46299	2020-04-04 07:40:08	2020-04-04	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	877	pick-up	0	35
46300	2020-04-04 07:41:13	2020-04-04	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	15966	delivery	5	39
46301	2020-04-04 07:41:34	2020-04-04	9	[{"id_menu":7,"count":1}]	5068	pick-up	0	9
46302	2020-04-04 07:46:34	2020-04-04	12	[{"id_menu":3,"count":1}]	4453	pick-up	0	12
46303	2020-04-04 07:53:21	2020-04-04	14	[{"id_menu":2,"count":1}]	12472	pick-up	0	14
46304	2020-04-04 07:54:57	2020-04-04	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14201	delivery	5	23
46305	2020-04-04 07:55:36	2020-04-04	14	[{"id_menu":2,"count":2}]	18301	delivery	5	19
46306	2020-04-04 07:58:58	2020-04-04	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18446	delivery	5	22
46307	2020-04-04 08:05:59	2020-04-04	12	[{"id_menu":3,"count":1}]	15991	delivery	5	17
46308	2020-04-04 08:06:03	2020-04-04	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	18470	delivery	5	30
46309	2020-04-04 08:07:28	2020-04-04	9	[{"id_menu":6,"count":1}]	4008	delivery	5	14
46310	2020-04-04 08:11:42	2020-04-04	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	10935	delivery	5	26
46311	2020-04-04 08:13:07	2020-04-04	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	13131	delivery	5	34
46312	2020-04-04 08:13:55	2020-04-04	12	[{"id_menu":3,"count":1}]	9941	pick-up	0	12
46313	2020-04-04 08:24:02	2020-04-04	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	18400	delivery	5	26
46314	2020-04-04 08:26:38	2020-04-04	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18478	delivery	5	31
46315	2020-04-04 08:31:21	2020-04-04	17	[{"id_menu":4,"count":1}]	15614	delivery	5	22
46316	2020-04-04 08:33:18	2020-04-04	12	[{"id_menu":3,"count":1}]	1796	pick-up	0	12
46317	2020-04-04 08:33:32	2020-04-04	17	[{"id_menu":4,"count":1}]	13465	delivery	5	22
46318	2020-04-04 08:34:57	2020-04-04	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4870	pick-up	0	35
46319	2020-04-04 08:35:24	2020-04-04	9	[{"id_menu":6,"count":1}]	14542	delivery	5	14
46320	2020-04-04 08:36:30	2020-04-04	12	[{"id_menu":3,"count":1}]	5308	delivery	5	17
46321	2020-04-04 08:38:16	2020-04-04	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15727	delivery	5	45
46322	2020-04-04 08:42:54	2020-04-04	12	[{"id_menu":3,"count":1}]	2455	pick-up	0	12
46323	2020-04-04 08:51:04	2020-04-04	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	18363	pick-up	0	29
46324	2020-04-04 08:51:56	2020-04-04	9	[{"id_menu":6,"count":2}]	10027	delivery	5	14
46325	2020-04-04 08:54:23	2020-04-04	12	[{"id_menu":3,"count":1}]	18448	delivery	5	17
46326	2020-04-04 09:00:17	2020-04-04	9	[{"id_menu":6,"count":1}]	9273	delivery	5	14
46327	2020-04-04 09:03:13	2020-04-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	10317	delivery	5	28
46328	2020-04-04 09:03:39	2020-04-04	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	1988	pick-up	0	21
46329	2020-04-04 09:05:36	2020-04-04	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8920	delivery	5	22
46330	2020-04-04 09:13:32	2020-04-04	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12546	delivery	5	51
46331	2020-04-04 09:16:50	2020-04-04	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2933	pick-up	0	25
46332	2020-04-04 09:21:33	2020-04-04	14	[{"id_menu":2,"count":1}]	18405	pick-up	0	14
46333	2020-04-04 09:28:01	2020-04-04	9	[{"id_menu":6,"count":1}]	13846	delivery	5	14
46334	2020-04-04 09:32:57	2020-04-04	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	431	pick-up	0	38
46335	2020-04-04 09:36:15	2020-04-04	9	[{"id_menu":6,"count":1}]	10990	pick-up	0	9
46336	2020-04-04 09:37:58	2020-04-04	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11603	delivery	5	34
46337	2020-04-04 09:38:39	2020-04-04	12	[{"id_menu":3,"count":1}]	6512	pick-up	0	12
46338	2020-04-04 09:40:05	2020-04-04	17	[{"id_menu":4,"count":1}]	806	pick-up	0	17
46339	2020-04-04 09:42:27	2020-04-04	12	[{"id_menu":1,"count":1}]	177	delivery	5	17
46340	2020-04-04 09:42:56	2020-04-04	9	[{"id_menu":7,"count":1}]	18376	delivery	5	14
46341	2020-04-04 09:43:57	2020-04-04	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18257	delivery	5	43
46342	2020-04-04 09:53:43	2020-04-04	9	[{"id_menu":6,"count":1}]	18407	delivery	5	14
46343	2020-04-04 09:54:24	2020-04-04	8	[{"id_menu":5,"count":1}]	5508	pick-up	0	8
46344	2020-04-04 09:58:59	2020-04-04	9	[{"id_menu":7,"count":1}]	4138	pick-up	0	9
46345	2020-04-04 10:05:23	2020-04-04	12	[{"id_menu":3,"count":1}]	73	pick-up	0	12
46346	2020-04-04 10:07:55	2020-04-04	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	18394	delivery	5	34
46347	2020-04-04 10:10:54	2020-04-04	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	18391	delivery	5	26
46348	2020-04-04 10:11:36	2020-04-04	9	[{"id_menu":6,"count":1}]	18451	delivery	5	14
46349	2020-04-04 10:13:06	2020-04-04	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5002	delivery	5	23
46350	2020-04-04 10:14:15	2020-04-04	8	[{"id_menu":5,"count":1}]	607	pick-up	0	8
46351	2020-04-04 10:19:09	2020-04-04	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	18410	delivery	5	31
46352	2020-04-04 10:21:53	2020-04-04	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14816	delivery	5	22
46353	2020-04-04 10:24:19	2020-04-04	17	[{"id_menu":4,"count":2}]	18444	delivery	5	22
46354	2020-04-04 10:26:36	2020-04-04	12	[{"id_menu":1,"count":1}]	9125	pick-up	0	12
46355	2020-04-04 10:31:58	2020-04-04	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	18408	delivery	5	30
46356	2020-04-04 10:32:35	2020-04-04	8	[{"id_menu":5,"count":1}]	17993	delivery	5	13
46357	2020-04-04 10:40:15	2020-04-04	12	[{"id_menu":3,"count":1}]	3752	pick-up	0	12
46358	2020-04-04 10:48:48	2020-04-04	9	[{"id_menu":6,"count":1}]	16974	delivery	5	14
46359	2020-04-04 10:54:35	2020-04-04	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6916	pick-up	0	26
46360	2020-04-04 11:00:46	2020-04-04	9	[{"id_menu":6,"count":1}]	5385	delivery	5	14
46361	2020-04-04 11:05:13	2020-04-04	17	[{"id_menu":4,"count":1}]	313	delivery	5	22
46362	2020-04-04 11:05:53	2020-04-04	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	18377	pick-up	0	26
46363	2020-04-04 11:07:01	2020-04-04	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	18369	pick-up	0	26
46364	2020-04-04 11:15:26	2020-04-04	14	[{"id_menu":2,"count":1}]	3600	pick-up	0	14
46365	2020-04-04 11:27:44	2020-04-04	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	11260	delivery	5	31
46366	2020-04-04 11:31:02	2020-04-04	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18486	delivery	5	37
46367	2020-04-04 11:32:51	2020-04-04	8	[{"id_menu":5,"count":1}]	10052	delivery	5	13
46368	2020-04-04 11:33:26	2020-04-04	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7933	delivery	5	31
46369	2020-04-04 11:41:52	2020-04-04	12	[{"id_menu":1,"count":1}]	11089	pick-up	0	12
46370	2020-04-04 11:43:22	2020-04-04	8	[{"id_menu":5,"count":1}]	18431	delivery	5	13
46371	2020-04-04 11:44:33	2020-04-04	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	591	delivery	5	34
46372	2020-04-04 11:45:38	2020-04-04	14	[{"id_menu":2,"count":1}]	4795	delivery	5	19
46373	2020-04-04 11:47:19	2020-04-04	9	[{"id_menu":7,"count":1}]	17757	delivery	5	14
46374	2020-04-04 11:47:52	2020-04-04	9	[{"id_menu":7,"count":1}]	18449	delivery	5	14
46375	2020-04-04 11:55:44	2020-04-04	9	[{"id_menu":6,"count":1}]	18395	delivery	5	14
46376	2020-04-04 12:13:32	2020-04-04	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3472	delivery	5	36
46377	2020-04-04 12:18:18	2020-04-04	12	[{"id_menu":1,"count":1}]	3630	delivery	5	17
46378	2020-04-04 12:23:05	2020-04-04	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	11735	delivery	5	31
46379	2020-04-04 12:23:25	2020-04-04	8	[{"id_menu":5,"count":1}]	18442	delivery	5	13
46380	2020-04-04 12:26:59	2020-04-04	9	[{"id_menu":7,"count":1}]	12207	delivery	5	14
46381	2020-04-04 12:28:45	2020-04-04	8	[{"id_menu":5,"count":1}]	7379	delivery	5	13
46382	2020-04-04 12:29:28	2020-04-04	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	18381	delivery	5	31
46383	2020-04-04 12:31:44	2020-04-04	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18458	delivery	5	35
46384	2020-04-04 12:36:32	2020-04-04	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3312	delivery	5	37
46385	2020-04-04 12:39:27	2020-04-04	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	3392	delivery	5	39
46386	2020-04-04 12:51:29	2020-04-04	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	18417	delivery	5	43
46387	2020-04-04 13:08:19	2020-04-04	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	18429	delivery	5	26
46388	2020-04-04 13:09:39	2020-04-04	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3825	delivery	5	34
46389	2020-04-04 13:16:26	2020-04-04	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":3}]	18427	delivery	5	26
46390	2020-04-04 13:19:52	2020-04-04	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	18406	delivery	5	27
46391	2020-04-04 13:21:22	2020-04-04	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	18390	delivery	5	25
46392	2020-04-04 13:21:52	2020-04-04	9	[{"id_menu":6,"count":1}]	8913	delivery	5	14
46393	2020-04-04 13:27:09	2020-04-04	12	[{"id_menu":1,"count":1}]	9920	pick-up	0	12
46394	2020-04-04 13:30:40	2020-04-04	9	[{"id_menu":7,"count":1}]	18404	delivery	5	14
46395	2020-04-04 13:32:23	2020-04-04	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	3401	pick-up	0	20
46396	2020-04-04 13:32:41	2020-04-04	12	[{"id_menu":3,"count":1}]	2979	delivery	5	17
46397	2020-04-04 13:41:21	2020-04-04	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	17046	pick-up	0	25
46398	2020-04-04 13:42:48	2020-04-04	14	[{"id_menu":2,"count":2}]	13822	delivery	5	19
46399	2020-04-04 13:49:29	2020-04-04	17	[{"id_menu":4,"count":1}]	6965	delivery	5	22
46400	2020-04-04 14:02:03	2020-04-04	17	[{"id_menu":4,"count":1}]	18428	pick-up	0	17
46401	2020-04-04 14:08:47	2020-04-04	17	[{"id_menu":4,"count":1}]	5221	delivery	5	22
46402	2020-04-04 14:15:06	2020-04-04	12	[{"id_menu":3,"count":1}]	18378	pick-up	0	12
46403	2020-04-04 14:15:27	2020-04-04	14	[{"id_menu":2,"count":2}]	16347	delivery	5	19
46404	2020-04-04 14:16:03	2020-04-04	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14421	delivery	5	43
46405	2020-04-04 14:17:05	2020-04-04	8	[{"id_menu":5,"count":1}]	15141	delivery	5	13
46406	2020-04-04 14:17:31	2020-04-04	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	18438	delivery	5	26
46407	2020-04-04 14:21:09	2020-04-04	12	[{"id_menu":3,"count":1}]	9889	delivery	5	17
46408	2020-04-04 14:24:54	2020-04-04	9	[{"id_menu":7,"count":1}]	16569	delivery	5	14
46409	2020-04-04 14:29:09	2020-04-04	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2850	delivery	5	31
46410	2020-04-04 14:29:44	2020-04-04	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18483	delivery	5	49
46411	2020-04-04 14:33:30	2020-04-04	12	[{"id_menu":3,"count":1}]	16430	delivery	5	17
46412	2020-04-04 14:36:43	2020-04-04	12	[{"id_menu":3,"count":1}]	2764	delivery	5	17
46413	2020-04-04 14:45:05	2020-04-04	33	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	4436	pick-up	0	33
46414	2020-04-04 14:49:07	2020-04-04	9	[{"id_menu":6,"count":1}]	18430	pick-up	0	9
46415	2020-04-04 14:51:09	2020-04-04	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5574	delivery	5	53
46416	2020-04-04 14:55:03	2020-04-04	12	[{"id_menu":3,"count":1}]	4929	pick-up	0	12
46417	2020-04-04 14:56:06	2020-04-04	14	[{"id_menu":2,"count":1}]	18467	delivery	5	19
46418	2020-04-04 15:00:25	2020-04-04	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13620	delivery	5	23
46419	2020-04-04 15:05:11	2020-04-04	12	[{"id_menu":3,"count":1}]	4047	delivery	5	17
46420	2020-04-04 15:08:42	2020-04-04	8	[{"id_menu":5,"count":1}]	10801	pick-up	0	8
46421	2020-04-04 15:18:13	2020-04-04	12	[{"id_menu":3,"count":1}]	27	delivery	5	17
46422	2020-04-04 15:21:49	2020-04-04	17	[{"id_menu":4,"count":1}]	2567	pick-up	0	17
46423	2020-04-04 15:22:28	2020-04-04	9	[{"id_menu":6,"count":1}]	5078	delivery	5	14
46424	2020-04-04 15:23:21	2020-04-04	9	[{"id_menu":6,"count":1}]	18422	delivery	5	14
46425	2020-04-04 15:25:14	2020-04-04	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3007	pick-up	0	26
46426	2020-04-04 15:28:27	2020-04-04	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	18482	delivery	5	26
46427	2020-04-04 15:33:12	2020-04-04	14	[{"id_menu":2,"count":1}]	18485	delivery	5	19
46428	2020-04-04 15:37:39	2020-04-04	12	[{"id_menu":1,"count":1}]	13697	pick-up	0	12
46429	2020-04-04 15:37:43	2020-04-04	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	18414	delivery	5	40
46430	2020-04-04 15:38:43	2020-04-04	14	[{"id_menu":2,"count":1}]	4634	pick-up	0	14
46431	2020-04-04 15:39:49	2020-04-04	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	8856	delivery	5	26
46432	2020-04-04 15:44:26	2020-04-04	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	7806	pick-up	0	18
46433	2020-04-04 15:47:45	2020-04-04	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	6798	delivery	5	26
46434	2020-04-04 15:48:10	2020-04-04	9	[{"id_menu":7,"count":1}]	18460	delivery	5	14
46435	2020-04-04 15:50:50	2020-04-04	9	[{"id_menu":6,"count":1}]	10481	delivery	5	14
46436	2020-04-04 15:51:41	2020-04-04	14	[{"id_menu":2,"count":1}]	18418	delivery	5	19
46437	2020-04-04 15:51:54	2020-04-04	9	[{"id_menu":7,"count":1}]	5875	delivery	5	14
46438	2020-04-04 15:52:54	2020-04-04	12	[{"id_menu":3,"count":1}]	5816	delivery	5	17
46439	2020-04-04 15:53:12	2020-04-04	14	[{"id_menu":2,"count":1}]	17769	delivery	5	19
46440	2020-04-04 15:53:31	2020-04-04	9	[{"id_menu":6,"count":1}]	18158	delivery	5	14
46441	2020-04-04 15:54:44	2020-04-04	9	[{"id_menu":6,"count":1}]	440	delivery	5	14
46442	2020-04-04 15:58:36	2020-04-04	14	[{"id_menu":2,"count":1}]	18452	delivery	5	19
46443	2020-04-04 15:59:28	2020-04-04	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	18477	delivery	5	22
46444	2020-04-04 16:00:15	2020-04-04	14	[{"id_menu":2,"count":1}]	6365	delivery	5	19
46445	2020-04-04 16:03:28	2020-04-04	9	[{"id_menu":6,"count":1}]	2119	pick-up	0	9
46446	2020-04-04 16:10:37	2020-04-04	8	[{"id_menu":5,"count":1}]	1546	pick-up	0	8
46447	2020-04-04 16:11:30	2020-04-04	9	[{"id_menu":6,"count":1}]	18480	delivery	5	14
46448	2020-04-04 16:12:38	2020-04-04	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	6296	delivery	5	27
46449	2020-04-04 16:23:15	2020-04-04	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	7204	delivery	5	26
46450	2020-04-04 16:26:31	2020-04-04	12	[{"id_menu":1,"count":1}]	1337	delivery	5	17
46451	2020-04-04 16:33:07	2020-04-04	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	18453	delivery	5	23
46452	2020-04-04 16:35:53	2020-04-04	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	18479	delivery	5	45
46453	2020-04-04 16:38:20	2020-04-04	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4797	delivery	5	36
46454	2020-04-04 16:38:23	2020-04-04	9	[{"id_menu":7,"count":1}]	16240	delivery	5	14
46455	2020-04-04 16:40:50	2020-04-04	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18469	delivery	5	48
46456	2020-04-04 16:41:21	2020-04-04	9	[{"id_menu":7,"count":1}]	44	pick-up	0	9
46457	2020-04-04 16:42:35	2020-04-04	12	[{"id_menu":1,"count":1}]	18387	pick-up	0	12
46458	2020-04-04 16:43:00	2020-04-04	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	18397	delivery	5	40
46459	2020-04-04 16:46:43	2020-04-04	12	[{"id_menu":3,"count":1}]	18490	pick-up	0	12
46460	2020-04-04 16:54:48	2020-04-04	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5311	pick-up	0	38
46461	2020-04-04 16:55:31	2020-04-04	12	[{"id_menu":3,"count":1}]	1039	delivery	5	17
46462	2020-04-04 17:00:29	2020-04-04	12	[{"id_menu":1,"count":1}]	4137	pick-up	0	12
46463	2020-04-04 17:08:32	2020-04-04	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	845	delivery	5	22
46464	2020-04-04 17:17:44	2020-04-04	14	[{"id_menu":2,"count":1}]	2149	delivery	5	19
46465	2020-04-04 17:25:52	2020-04-04	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4594	delivery	5	23
46466	2020-04-04 17:26:08	2020-04-04	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	18489	delivery	5	22
46467	2020-04-04 17:28:45	2020-04-04	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	18413	delivery	5	29
46468	2020-04-04 17:47:39	2020-04-04	9	[{"id_menu":6,"count":1}]	18424	pick-up	0	9
46469	2020-04-04 17:48:01	2020-04-04	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	13570	delivery	5	39
46470	2020-04-04 17:50:29	2020-04-04	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	18476	delivery	5	31
46471	2020-04-04 17:51:07	2020-04-04	9	[{"id_menu":6,"count":1}]	3371	delivery	5	14
46472	2020-04-04 17:51:11	2020-04-04	9	[{"id_menu":6,"count":1}]	1751	pick-up	0	9
46473	2020-04-04 17:58:01	2020-04-04	9	[{"id_menu":7,"count":1}]	6645	pick-up	0	9
46474	2020-04-04 17:58:08	2020-04-04	14	[{"id_menu":2,"count":1}]	1526	pick-up	0	14
46475	2020-04-04 17:58:34	2020-04-04	9	[{"id_menu":7,"count":1}]	13968	delivery	5	14
46476	2020-04-04 18:02:17	2020-04-04	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	12819	delivery	5	26
46477	2020-04-04 18:05:51	2020-04-04	8	[{"id_menu":5,"count":1}]	9766	pick-up	0	8
46478	2020-04-04 18:11:06	2020-04-04	12	[{"id_menu":3,"count":1}]	10850	pick-up	0	12
46479	2020-04-04 18:11:38	2020-04-04	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	5822	delivery	5	40
46480	2020-04-04 18:12:53	2020-04-04	14	[{"id_menu":2,"count":1}]	2897	pick-up	0	14
46481	2020-04-04 18:15:03	2020-04-04	12	[{"id_menu":3,"count":1}]	337	pick-up	0	12
46482	2020-04-04 18:15:47	2020-04-04	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	18385	delivery	5	38
46483	2020-04-04 18:17:00	2020-04-04	9	[{"id_menu":7,"count":1}]	1070	pick-up	0	9
46484	2020-04-04 18:20:02	2020-04-04	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	18364	delivery	5	39
46485	2020-04-04 18:20:31	2020-04-04	17	[{"id_menu":4,"count":1}]	6221	pick-up	0	17
46486	2020-04-04 18:30:49	2020-04-04	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4937	pick-up	0	18
46487	2020-04-04 18:37:25	2020-04-04	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	11353	delivery	5	25
46488	2020-04-04 18:47:19	2020-04-04	12	[{"id_menu":3,"count":1}]	18399	delivery	5	17
46489	2020-04-04 18:47:19	2020-04-04	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	18379	delivery	5	34
46490	2020-04-04 18:49:20	2020-04-04	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	184	pick-up	0	26
46491	2020-04-04 18:54:44	2020-04-04	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	3059	delivery	5	31
46492	2020-04-04 19:00:59	2020-04-04	14	[{"id_menu":2,"count":1}]	18392	pick-up	0	14
46493	2020-04-04 19:02:12	2020-04-04	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	12206	delivery	5	23
46494	2020-04-04 19:10:00	2020-04-04	12	[{"id_menu":1,"count":1}]	18425	pick-up	0	12
46495	2020-04-04 19:10:11	2020-04-04	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	15284	delivery	5	26
46496	2020-04-04 19:11:35	2020-04-04	12	[{"id_menu":1,"count":1}]	18488	delivery	5	17
46497	2020-04-04 19:16:56	2020-04-04	9	[{"id_menu":7,"count":2}]	10733	delivery	5	14
46498	2020-04-04 19:17:22	2020-04-04	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	15109	delivery	5	26
46499	2020-04-04 19:18:01	2020-04-04	17	[{"id_menu":4,"count":1}]	15780	pick-up	0	17
46500	2020-04-04 19:19:05	2020-04-04	34	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	8613	delivery	5	39
46501	2020-04-04 19:21:58	2020-04-04	8	[{"id_menu":5,"count":2}]	13264	pick-up	0	8
46502	2020-04-04 19:25:58	2020-04-04	9	[{"id_menu":7,"count":1}]	12327	delivery	5	14
46503	2020-04-04 19:26:00	2020-04-04	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	18435	delivery	5	34
46504	2020-04-04 19:28:40	2020-04-04	9	[{"id_menu":6,"count":1}]	2103	pick-up	0	9
46505	2020-04-04 19:31:58	2020-04-04	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	15283	delivery	5	40
46506	2020-04-04 19:34:29	2020-04-04	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	17002	delivery	5	26
46507	2020-04-04 19:37:36	2020-04-04	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4022	delivery	5	39
46508	2020-04-04 19:41:16	2020-04-04	9	[{"id_menu":6,"count":1}]	12444	pick-up	0	9
46509	2020-04-04 19:46:04	2020-04-04	14	[{"id_menu":2,"count":1}]	18375	delivery	5	19
46510	2020-04-04 19:47:34	2020-04-04	12	[{"id_menu":3,"count":1}]	17568	delivery	5	17
46511	2020-04-04 19:56:00	2020-04-04	12	[{"id_menu":3,"count":1}]	9420	delivery	5	17
46512	2020-04-04 19:59:45	2020-04-04	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	15201	delivery	5	22
46513	2020-04-04 20:00:09	2020-04-04	8	[{"id_menu":5,"count":2}]	18461	delivery	5	13
46514	2020-04-04 20:10:05	2020-04-04	14	[{"id_menu":2,"count":1}]	18362	pick-up	0	14
46515	2020-04-04 20:13:21	2020-04-04	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	14392	delivery	5	31
46516	2020-04-04 20:14:18	2020-04-04	12	[{"id_menu":3,"count":1}]	15195	delivery	5	17
46517	2020-04-04 20:24:09	2020-04-04	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18465	delivery	5	23
46518	2020-04-04 20:29:17	2020-04-04	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	18401	delivery	5	42
46519	2020-04-04 20:35:57	2020-04-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	5882	delivery	5	28
46520	2020-04-04 20:37:29	2020-04-04	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	227	pick-up	0	26
46521	2020-04-04 20:37:39	2020-04-04	12	[{"id_menu":1,"count":3}]	3634	delivery	5	17
46522	2020-04-04 20:37:49	2020-04-04	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	17667	delivery	5	39
46523	2020-04-04 20:37:55	2020-04-04	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15022	delivery	5	22
46524	2020-04-04 20:38:26	2020-04-04	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	18382	delivery	5	30
46525	2020-04-04 20:38:58	2020-04-04	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7410	delivery	5	28
46526	2020-04-04 20:41:27	2020-04-04	9	[{"id_menu":6,"count":1}]	4113	delivery	5	14
46527	2020-04-04 21:01:21	2020-04-04	14	[{"id_menu":2,"count":1}]	18402	delivery	5	19
46528	2020-04-04 21:02:29	2020-04-04	12	[{"id_menu":1,"count":1}]	4824	delivery	5	17
46529	2020-04-04 21:05:14	2020-04-04	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	7862	pick-up	0	21
46530	2020-04-04 21:05:19	2020-04-04	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18454	delivery	5	22
46531	2020-04-04 21:07:55	2020-04-04	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11395	pick-up	0	17
46532	2020-04-04 21:10:16	2020-04-04	14	[{"id_menu":2,"count":1}]	9011	delivery	5	19
46533	2020-04-04 21:14:00	2020-04-04	8	[{"id_menu":5,"count":1}]	1254	pick-up	0	8
46534	2020-04-04 21:27:46	2020-04-04	8	[{"id_menu":5,"count":1}]	3083	delivery	5	13
46535	2020-04-04 21:29:19	2020-04-04	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	18367	delivery	5	45
46536	2020-04-04 21:31:38	2020-04-04	12	[{"id_menu":3,"count":1}]	17676	delivery	5	17
46537	2020-04-04 21:34:09	2020-04-04	12	[{"id_menu":1,"count":1}]	18434	delivery	5	17
46538	2020-04-04 21:38:04	2020-04-04	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9367	delivery	5	23
46539	2020-04-04 21:45:49	2020-04-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	18472	delivery	5	28
46540	2020-04-04 21:50:31	2020-04-04	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13228	delivery	5	22
46541	2020-04-04 21:51:02	2020-04-04	17	[{"id_menu":4,"count":1}]	18409	pick-up	0	17
46542	2020-04-04 21:51:20	2020-04-04	9	[{"id_menu":7,"count":1}]	16384	delivery	5	14
46543	2020-04-04 21:56:11	2020-04-04	14	[{"id_menu":2,"count":1}]	18419	delivery	5	19
46544	2020-04-04 21:56:58	2020-04-04	8	[{"id_menu":5,"count":1}]	18423	delivery	5	13
46545	2020-04-04 21:58:00	2020-04-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	18031	delivery	5	28
46546	2020-04-04 22:06:30	2020-04-04	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1513	delivery	5	22
46547	2020-04-04 22:07:17	2020-04-04	8	[{"id_menu":5,"count":1}]	16442	pick-up	0	8
46548	2020-04-04 22:07:39	2020-04-04	17	[{"id_menu":4,"count":1}]	6778	delivery	5	22
46549	2020-04-04 22:10:57	2020-04-04	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	16250	delivery	5	26
46550	2020-04-04 22:15:17	2020-04-04	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	18466	delivery	5	44
46551	2020-04-04 22:25:14	2020-04-04	9	[{"id_menu":7,"count":1}]	9466	delivery	5	14
46552	2020-04-04 22:36:03	2020-04-04	12	[{"id_menu":3,"count":1}]	18370	delivery	5	17
46553	2020-04-04 22:38:04	2020-04-04	14	[{"id_menu":2,"count":1}]	3666	delivery	5	19
46554	2020-04-04 22:43:48	2020-04-04	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12500	pick-up	0	26
46555	2020-04-04 22:44:03	2020-04-04	9	[{"id_menu":6,"count":1}]	15052	pick-up	0	9
46556	2020-04-04 22:44:57	2020-04-04	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	749	pick-up	0	17
46557	2020-04-04 22:47:57	2020-04-04	12	[{"id_menu":1,"count":1}]	763	pick-up	0	12
46558	2020-04-04 22:50:06	2020-04-04	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	18079	delivery	5	38
46559	2020-04-04 22:57:55	2020-04-04	8	[{"id_menu":5,"count":1}]	18386	delivery	5	13
46560	2020-04-04 23:00:10	2020-04-04	8	[{"id_menu":5,"count":1}]	1797	pick-up	0	8
46561	2020-04-04 23:04:01	2020-04-04	8	[{"id_menu":5,"count":1}]	2470	delivery	5	13
46562	2020-04-04 23:06:51	2020-04-04	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	18459	delivery	5	28
46563	2020-04-04 23:16:47	2020-04-04	17	[{"id_menu":4,"count":1}]	18473	delivery	5	22
46564	2020-04-04 23:31:03	2020-04-04	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	8363	delivery	5	30
46565	2020-04-04 23:35:17	2020-04-04	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	18420	delivery	5	26
46566	2020-04-04 23:38:12	2020-04-04	17	[{"id_menu":4,"count":1}]	18371	delivery	5	22
46567	2020-04-04 23:42:19	2020-04-04	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	11091	delivery	5	44
46568	2020-04-04 23:44:01	2020-04-04	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5667	delivery	5	31
46569	2020-04-04 23:51:40	2020-04-04	8	[{"id_menu":5,"count":1}]	18415	delivery	5	13
46570	2020-04-04 23:55:11	2020-04-04	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3509	pick-up	0	38
46571	2020-04-05 00:02:43	2020-04-05	9	[{"id_menu":6,"count":1}]	8180	pick-up	0	9
46572	2020-04-05 00:03:35	2020-04-05	9	[{"id_menu":7,"count":1}]	4925	delivery	5	14
46573	2020-04-05 00:05:49	2020-04-05	14	[{"id_menu":2,"count":1}]	3148	pick-up	0	14
46574	2020-04-05 00:06:10	2020-04-05	9	[{"id_menu":7,"count":1}]	18617	delivery	5	14
46575	2020-04-05 00:12:29	2020-04-05	12	[{"id_menu":3,"count":1}]	18591	delivery	5	17
46576	2020-04-05 00:16:15	2020-04-05	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	18632	delivery	5	57
46577	2020-04-05 00:17:31	2020-04-05	8	[{"id_menu":5,"count":1}]	18602	delivery	5	13
46578	2020-04-05 00:18:57	2020-04-05	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	10829	delivery	5	26
46579	2020-04-05 00:21:01	2020-04-05	14	[{"id_menu":2,"count":1}]	7574	pick-up	0	14
46580	2020-04-05 00:24:21	2020-04-05	9	[{"id_menu":6,"count":1}]	14824	pick-up	0	9
46581	2020-04-05 00:27:40	2020-04-05	14	[{"id_menu":2,"count":1}]	1591	pick-up	0	14
46582	2020-04-05 00:29:41	2020-04-05	9	[{"id_menu":6,"count":1}]	18550	delivery	5	14
46583	2020-04-05 00:38:18	2020-04-05	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7388	delivery	5	57
46584	2020-04-05 00:39:14	2020-04-05	17	[{"id_menu":4,"count":1}]	18493	delivery	5	22
46585	2020-04-05 00:40:43	2020-04-05	12	[{"id_menu":1,"count":1}]	1379	pick-up	0	12
46586	2020-04-05 00:43:18	2020-04-05	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	18502	delivery	5	28
46587	2020-04-05 00:45:14	2020-04-05	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	14739	delivery	5	31
46588	2020-04-05 00:59:17	2020-04-05	12	[{"id_menu":1,"count":1}]	5245	delivery	5	17
46589	2020-04-05 01:00:46	2020-04-05	12	[{"id_menu":3,"count":1}]	1902	delivery	5	17
46590	2020-04-05 01:01:56	2020-04-05	26	[{"id_menu":4,"count":3},{"id_menu":6,"count":1}]	18577	delivery	5	31
46591	2020-04-05 01:02:46	2020-04-05	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	15722	delivery	5	31
46592	2020-04-05 01:03:18	2020-04-05	9	[{"id_menu":7,"count":1}]	12704	delivery	5	14
46593	2020-04-05 01:03:40	2020-04-05	14	[{"id_menu":2,"count":3}]	7967	pick-up	0	14
46594	2020-04-05 01:11:46	2020-04-05	9	[{"id_menu":6,"count":1}]	18551	pick-up	0	9
46595	2020-04-05 01:16:53	2020-04-05	12	[{"id_menu":3,"count":1}]	18622	pick-up	0	12
46596	2020-04-05 01:18:20	2020-04-05	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	15126	delivery	5	40
46597	2020-04-05 01:19:59	2020-04-05	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	3851	pick-up	0	21
46598	2020-04-05 01:27:17	2020-04-05	8	[{"id_menu":5,"count":1}]	4561	delivery	5	13
46599	2020-04-05 01:28:09	2020-04-05	17	[{"id_menu":4,"count":1}]	18552	delivery	5	22
46600	2020-04-05 01:28:14	2020-04-05	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	18555	delivery	5	22
46601	2020-04-05 01:38:55	2020-04-05	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	18590	delivery	5	40
46602	2020-04-05 01:40:20	2020-04-05	14	[{"id_menu":2,"count":1}]	18601	delivery	5	19
46603	2020-04-05 01:40:32	2020-04-05	9	[{"id_menu":6,"count":1}]	1742	delivery	5	14
46604	2020-04-05 01:45:11	2020-04-05	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18606	delivery	5	36
46605	2020-04-05 01:46:41	2020-04-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":3}]	18592	delivery	5	23
46606	2020-04-05 01:49:21	2020-04-05	17	[{"id_menu":4,"count":1}]	18584	delivery	5	22
46607	2020-04-05 01:52:42	2020-04-05	17	[{"id_menu":4,"count":1}]	5167	delivery	5	22
46608	2020-04-05 01:53:46	2020-04-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	10023	delivery	5	28
46609	2020-04-05 01:57:02	2020-04-05	14	[{"id_menu":2,"count":1}]	13812	delivery	5	19
46610	2020-04-05 01:58:32	2020-04-05	9	[{"id_menu":7,"count":1}]	15164	delivery	5	14
46611	2020-04-05 02:00:53	2020-04-05	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8546	pick-up	0	17
46612	2020-04-05 02:04:07	2020-04-05	14	[{"id_menu":2,"count":1}]	6301	pick-up	0	14
46613	2020-04-05 02:06:01	2020-04-05	17	[{"id_menu":4,"count":1}]	12132	delivery	5	22
46614	2020-04-05 02:06:46	2020-04-05	12	[{"id_menu":1,"count":1}]	14929	delivery	5	17
46615	2020-04-05 02:09:50	2020-04-05	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	12559	delivery	5	36
46616	2020-04-05 02:10:42	2020-04-05	14	[{"id_menu":2,"count":1}]	1537	pick-up	0	14
46617	2020-04-05 02:16:11	2020-04-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	11017	delivery	5	28
46618	2020-04-05 02:20:36	2020-04-05	9	[{"id_menu":6,"count":1}]	18510	delivery	5	14
46619	2020-04-05 02:21:34	2020-04-05	12	[{"id_menu":3,"count":1}]	18598	delivery	5	17
46620	2020-04-05 02:22:27	2020-04-05	12	[{"id_menu":3,"count":1}]	18523	pick-up	0	12
46621	2020-04-05 02:26:40	2020-04-05	12	[{"id_menu":3,"count":1}]	18638	delivery	5	17
46622	2020-04-05 02:29:42	2020-04-05	9	[{"id_menu":7,"count":1}]	18640	delivery	5	14
46623	2020-04-05 02:33:08	2020-04-05	9	[{"id_menu":7,"count":1}]	2844	pick-up	0	9
46624	2020-04-05 02:33:12	2020-04-05	9	[{"id_menu":6,"count":1}]	6872	delivery	5	14
46625	2020-04-05 02:33:27	2020-04-05	17	[{"id_menu":4,"count":1}]	18491	delivery	5	22
46626	2020-04-05 02:35:01	2020-04-05	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	16549	pick-up	0	34
46627	2020-04-05 02:36:23	2020-04-05	17	[{"id_menu":4,"count":1}]	10632	delivery	5	22
46628	2020-04-05 02:36:36	2020-04-05	9	[{"id_menu":6,"count":2}]	18542	delivery	5	14
46629	2020-04-05 02:40:01	2020-04-05	12	[{"id_menu":3,"count":1}]	11615	pick-up	0	12
46630	2020-04-05 02:42:40	2020-04-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	18579	delivery	5	31
46631	2020-04-05 02:44:20	2020-04-05	12	[{"id_menu":1,"count":1}]	337	pick-up	0	12
46632	2020-04-05 02:47:36	2020-04-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	778	pick-up	0	18
46633	2020-04-05 02:48:20	2020-04-05	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17884	delivery	5	45
46634	2020-04-05 02:50:14	2020-04-05	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3605	delivery	5	37
46635	2020-04-05 02:53:57	2020-04-05	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	16992	delivery	5	36
46636	2020-04-05 02:59:13	2020-04-05	12	[{"id_menu":3,"count":1}]	18517	delivery	5	17
46637	2020-04-05 03:03:30	2020-04-05	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1928	delivery	5	35
46638	2020-04-05 03:07:03	2020-04-05	43	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	14190	pick-up	0	43
46639	2020-04-05 03:11:44	2020-04-05	14	[{"id_menu":2,"count":1}]	2957	pick-up	0	14
46640	2020-04-05 03:12:01	2020-04-05	9	[{"id_menu":6,"count":1}]	18547	delivery	5	14
46641	2020-04-05 03:12:19	2020-04-05	17	[{"id_menu":4,"count":1}]	13636	delivery	5	22
46642	2020-04-05 03:13:08	2020-04-05	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	18644	delivery	5	26
46643	2020-04-05 03:19:52	2020-04-05	9	[{"id_menu":6,"count":1}]	18499	delivery	5	14
46644	2020-04-05 03:22:30	2020-04-05	17	[{"id_menu":4,"count":1}]	18565	delivery	5	22
46645	2020-04-05 03:24:30	2020-04-05	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	111	pick-up	0	20
46646	2020-04-05 03:28:04	2020-04-05	9	[{"id_menu":6,"count":1}]	7204	delivery	5	14
46647	2020-04-05 03:33:10	2020-04-05	9	[{"id_menu":7,"count":1}]	17742	delivery	5	14
46648	2020-04-05 03:37:06	2020-04-05	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2748	pick-up	0	26
46649	2020-04-05 03:37:09	2020-04-05	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4979	delivery	5	39
46650	2020-04-05 03:38:52	2020-04-05	9	[{"id_menu":7,"count":1}]	15272	delivery	5	14
46651	2020-04-05 03:53:12	2020-04-05	9	[{"id_menu":6,"count":1}]	8166	delivery	5	14
46652	2020-04-05 03:56:30	2020-04-05	14	[{"id_menu":2,"count":1}]	9160	delivery	5	19
46653	2020-04-05 03:56:52	2020-04-05	9	[{"id_menu":6,"count":1}]	9379	delivery	5	14
46654	2020-04-05 03:57:18	2020-04-05	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18607	delivery	5	35
46655	2020-04-05 03:59:13	2020-04-05	12	[{"id_menu":1,"count":1}]	13643	pick-up	0	12
46656	2020-04-05 03:59:42	2020-04-05	17	[{"id_menu":4,"count":1}]	18631	delivery	5	22
46657	2020-04-05 04:05:58	2020-04-05	17	[{"id_menu":4,"count":1}]	11518	delivery	5	22
46658	2020-04-05 04:09:33	2020-04-05	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17807	pick-up	0	26
46659	2020-04-05 04:11:50	2020-04-05	9	[{"id_menu":6,"count":1}]	16221	delivery	5	14
46660	2020-04-05 04:12:01	2020-04-05	12	[{"id_menu":1,"count":1}]	18576	pick-up	0	12
46661	2020-04-05 04:18:49	2020-04-05	9	[{"id_menu":7,"count":1}]	18562	delivery	5	14
46662	2020-04-05 04:19:14	2020-04-05	9	[{"id_menu":6,"count":1}]	14085	delivery	5	14
46663	2020-04-05 04:20:06	2020-04-05	17	[{"id_menu":4,"count":1}]	18519	delivery	5	22
46664	2020-04-05 04:25:49	2020-04-05	9	[{"id_menu":6,"count":1}]	14391	pick-up	0	9
46665	2020-04-05 04:28:14	2020-04-05	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	11491	pick-up	0	31
46666	2020-04-05 04:29:40	2020-04-05	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	135	pick-up	0	30
46667	2020-04-05 04:30:21	2020-04-05	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2867	delivery	5	40
46668	2020-04-05 04:38:00	2020-04-05	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1946	delivery	5	46
46669	2020-04-05 04:39:15	2020-04-05	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	11276	delivery	5	40
46670	2020-04-05 04:43:49	2020-04-05	9	[{"id_menu":7,"count":1}]	6174	delivery	5	14
46671	2020-04-05 04:44:01	2020-04-05	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	14127	pick-up	0	21
46672	2020-04-05 04:46:00	2020-04-05	14	[{"id_menu":2,"count":1}]	1513	pick-up	0	14
46673	2020-04-05 04:47:19	2020-04-05	12	[{"id_menu":1,"count":2}]	18522	pick-up	0	12
46674	2020-04-05 04:49:16	2020-04-05	9	[{"id_menu":7,"count":2}]	2111	delivery	5	14
46675	2020-04-05 04:55:32	2020-04-05	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	907	delivery	5	26
46676	2020-04-05 05:00:18	2020-04-05	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	12265	pick-up	0	34
46677	2020-04-05 05:00:46	2020-04-05	12	[{"id_menu":3,"count":1}]	529	delivery	5	17
46678	2020-04-05 05:05:57	2020-04-05	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1129	delivery	5	40
46679	2020-04-05 05:13:39	2020-04-05	12	[{"id_menu":1,"count":1}]	16018	delivery	5	17
46680	2020-04-05 05:17:33	2020-04-05	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	260	pick-up	0	26
46681	2020-04-05 05:18:54	2020-04-05	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":2}]	6200	delivery	5	28
46682	2020-04-05 05:29:09	2020-04-05	12	[{"id_menu":1,"count":1}]	15291	delivery	5	17
46683	2020-04-05 05:32:28	2020-04-05	14	[{"id_menu":2,"count":1}]	14760	delivery	5	19
46684	2020-04-05 05:42:58	2020-04-05	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	18585	pick-up	0	31
46685	2020-04-05 05:43:39	2020-04-05	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	17531	delivery	5	31
46686	2020-04-05 05:47:13	2020-04-05	14	[{"id_menu":2,"count":1}]	16895	pick-up	0	14
46687	2020-04-05 05:50:47	2020-04-05	12	[{"id_menu":3,"count":1}]	879	pick-up	0	12
46688	2020-04-05 05:53:53	2020-04-05	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9554	delivery	5	36
46689	2020-04-05 05:58:48	2020-04-05	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	18596	delivery	5	31
46690	2020-04-05 05:59:47	2020-04-05	9	[{"id_menu":7,"count":1}]	1484	pick-up	0	9
46691	2020-04-05 06:00:48	2020-04-05	9	[{"id_menu":6,"count":1}]	18560	delivery	5	14
46692	2020-04-05 06:05:20	2020-04-05	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6652	delivery	5	43
46693	2020-04-05 06:07:02	2020-04-05	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	18509	delivery	5	26
46694	2020-04-05 06:23:06	2020-04-05	12	[{"id_menu":1,"count":1}]	1754	pick-up	0	12
46695	2020-04-05 06:25:14	2020-04-05	9	[{"id_menu":7,"count":2}]	5588	pick-up	0	9
46696	2020-04-05 06:26:53	2020-04-05	14	[{"id_menu":2,"count":1}]	9804	pick-up	0	14
46697	2020-04-05 06:30:28	2020-04-05	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	18545	delivery	5	40
46698	2020-04-05 06:30:51	2020-04-05	9	[{"id_menu":7,"count":1}]	2446	delivery	5	14
46699	2020-04-05 06:31:00	2020-04-05	14	[{"id_menu":2,"count":1}]	4636	pick-up	0	14
46700	2020-04-05 06:33:55	2020-04-05	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	6163	pick-up	0	22
46701	2020-04-05 06:35:09	2020-04-05	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	12414	delivery	5	40
46702	2020-04-05 06:36:51	2020-04-05	17	[{"id_menu":4,"count":1}]	6908	pick-up	0	17
46703	2020-04-05 06:36:57	2020-04-05	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11397	delivery	5	34
46704	2020-04-05 06:39:52	2020-04-05	9	[{"id_menu":6,"count":1}]	4943	pick-up	0	9
46705	2020-04-05 06:40:34	2020-04-05	17	[{"id_menu":4,"count":1}]	3968	pick-up	0	17
46706	2020-04-05 06:41:22	2020-04-05	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	15267	pick-up	0	26
46707	2020-04-05 06:42:46	2020-04-05	9	[{"id_menu":6,"count":1}]	18593	delivery	5	14
46708	2020-04-05 06:43:03	2020-04-05	9	[{"id_menu":6,"count":1}]	18262	pick-up	0	9
46709	2020-04-05 06:51:39	2020-04-05	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18613	delivery	5	36
46710	2020-04-05 06:52:56	2020-04-05	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	6219	delivery	5	43
46711	2020-04-05 06:58:52	2020-04-05	12	[{"id_menu":3,"count":1}]	13656	pick-up	0	12
46712	2020-04-05 07:03:15	2020-04-05	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	18518	delivery	5	43
46713	2020-04-05 07:05:44	2020-04-05	17	[{"id_menu":4,"count":1}]	10152	delivery	5	22
46714	2020-04-05 07:06:37	2020-04-05	9	[{"id_menu":7,"count":1}]	9485	delivery	5	14
46715	2020-04-05 07:07:29	2020-04-05	14	[{"id_menu":2,"count":1}]	6009	pick-up	0	14
46716	2020-04-05 07:11:18	2020-04-05	9	[{"id_menu":7,"count":1}]	2261	pick-up	0	9
46717	2020-04-05 07:19:30	2020-04-05	8	[{"id_menu":5,"count":1}]	4050	pick-up	0	8
46718	2020-04-05 07:23:00	2020-04-05	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	16680	delivery	5	38
46719	2020-04-05 07:24:16	2020-04-05	9	[{"id_menu":6,"count":1}]	4673	pick-up	0	9
46720	2020-04-05 07:24:29	2020-04-05	9	[{"id_menu":7,"count":1}]	749	pick-up	0	9
46721	2020-04-05 07:25:14	2020-04-05	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9225	pick-up	0	25
46722	2020-04-05 07:25:14	2020-04-05	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	18505	delivery	5	39
46723	2020-04-05 07:35:46	2020-04-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8730	pick-up	0	17
46724	2020-04-05 07:37:45	2020-04-05	9	[{"id_menu":6,"count":1}]	71	pick-up	0	9
46725	2020-04-05 07:37:51	2020-04-05	12	[{"id_menu":1,"count":1}]	18537	delivery	5	17
46726	2020-04-05 07:41:35	2020-04-05	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	18520	delivery	5	36
46727	2020-04-05 07:42:18	2020-04-05	9	[{"id_menu":7,"count":1}]	18561	pick-up	0	9
46728	2020-04-05 07:47:58	2020-04-05	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15384	delivery	5	43
46729	2020-04-05 07:51:06	2020-04-05	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	12268	pick-up	0	23
46730	2020-04-05 07:51:25	2020-04-05	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4855	delivery	5	31
46731	2020-04-05 07:54:30	2020-04-05	17	[{"id_menu":4,"count":1}]	12314	delivery	5	22
46732	2020-04-05 07:54:52	2020-04-05	12	[{"id_menu":3,"count":1}]	18508	delivery	5	17
46733	2020-04-05 07:56:24	2020-04-05	12	[{"id_menu":1,"count":1}]	1255	pick-up	0	12
46734	2020-04-05 08:00:49	2020-04-05	17	[{"id_menu":4,"count":1}]	4451	delivery	5	22
46735	2020-04-05 08:02:23	2020-04-05	17	[{"id_menu":4,"count":1}]	4794	delivery	5	22
46736	2020-04-05 08:02:35	2020-04-05	12	[{"id_menu":3,"count":1}]	2656	delivery	5	17
46737	2020-04-05 08:07:01	2020-04-05	12	[{"id_menu":1,"count":1}]	2197	pick-up	0	12
46738	2020-04-05 08:07:06	2020-04-05	12	[{"id_menu":1,"count":1}]	18530	pick-up	0	12
46739	2020-04-05 08:10:04	2020-04-05	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	18568	delivery	5	30
46740	2020-04-05 08:13:30	2020-04-05	9	[{"id_menu":6,"count":1}]	15972	delivery	5	14
46741	2020-04-05 08:14:03	2020-04-05	14	[{"id_menu":2,"count":1}]	18527	delivery	5	19
46742	2020-04-05 08:25:31	2020-04-05	9	[{"id_menu":6,"count":1}]	5655	delivery	5	14
46743	2020-04-05 08:25:46	2020-04-05	9	[{"id_menu":7,"count":3}]	18581	delivery	5	14
46744	2020-04-05 08:30:45	2020-04-05	14	[{"id_menu":2,"count":1}]	11342	delivery	5	19
46745	2020-04-05 08:30:57	2020-04-05	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	1006	delivery	5	37
46746	2020-04-05 08:32:06	2020-04-05	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	18639	delivery	5	26
46747	2020-04-05 08:34:23	2020-04-05	14	[{"id_menu":2,"count":1}]	16802	delivery	5	19
46748	2020-04-05 08:35:08	2020-04-05	17	[{"id_menu":4,"count":1}]	18526	pick-up	0	17
46749	2020-04-05 08:35:47	2020-04-05	9	[{"id_menu":7,"count":1}]	7134	delivery	5	14
46750	2020-04-05 08:40:25	2020-04-05	8	[{"id_menu":5,"count":1}]	1812	pick-up	0	8
46751	2020-04-05 08:47:25	2020-04-05	17	[{"id_menu":4,"count":1}]	7846	delivery	5	22
46752	2020-04-05 08:51:19	2020-04-05	9	[{"id_menu":7,"count":1}]	1263	pick-up	0	9
46753	2020-04-05 08:51:38	2020-04-05	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	18528	delivery	5	31
46754	2020-04-05 08:53:56	2020-04-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18619	delivery	5	23
46755	2020-04-05 08:56:14	2020-04-05	14	[{"id_menu":2,"count":1}]	9934	delivery	5	19
46756	2020-04-05 08:57:46	2020-04-05	9	[{"id_menu":6,"count":1}]	413	pick-up	0	9
46757	2020-04-05 09:00:06	2020-04-05	9	[{"id_menu":7,"count":1}]	1266	delivery	5	14
46758	2020-04-05 09:08:26	2020-04-05	14	[{"id_menu":2,"count":1}]	18574	delivery	5	19
46759	2020-04-05 09:08:50	2020-04-05	12	[{"id_menu":1,"count":1}]	18629	delivery	5	17
46760	2020-04-05 09:09:05	2020-04-05	9	[{"id_menu":6,"count":1}]	11950	delivery	5	14
46761	2020-04-05 09:14:42	2020-04-05	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4356	pick-up	0	29
46762	2020-04-05 09:16:29	2020-04-05	9	[{"id_menu":7,"count":1}]	10366	delivery	5	14
46763	2020-04-05 09:17:11	2020-04-05	12	[{"id_menu":3,"count":1}]	13020	delivery	5	17
46764	2020-04-05 09:22:16	2020-04-05	12	[{"id_menu":3,"count":1}]	12750	delivery	5	17
46765	2020-04-05 09:24:33	2020-04-05	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	13950	delivery	5	29
46766	2020-04-05 09:25:37	2020-04-05	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10354	delivery	5	36
46767	2020-04-05 09:26:24	2020-04-05	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	14756	pick-up	0	38
46768	2020-04-05 09:26:43	2020-04-05	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18626	delivery	5	47
46769	2020-04-05 09:27:19	2020-04-05	8	[{"id_menu":5,"count":2}]	18587	delivery	5	13
46770	2020-04-05 09:27:59	2020-04-05	12	[{"id_menu":1,"count":1}]	10638	delivery	5	17
46771	2020-04-05 09:29:48	2020-04-05	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	18610	delivery	5	40
46772	2020-04-05 09:33:25	2020-04-05	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	5707	delivery	5	26
46773	2020-04-05 09:35:08	2020-04-05	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	11488	delivery	5	31
46774	2020-04-05 09:35:21	2020-04-05	9	[{"id_menu":6,"count":1}]	18503	delivery	5	14
46775	2020-04-05 09:36:31	2020-04-05	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	18532	delivery	5	25
46776	2020-04-05 09:41:09	2020-04-05	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	10032	delivery	5	39
46777	2020-04-05 09:49:05	2020-04-05	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	10772	delivery	5	27
46778	2020-04-05 09:50:54	2020-04-05	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	13948	delivery	5	25
46779	2020-04-05 09:51:07	2020-04-05	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	14807	delivery	5	43
46780	2020-04-05 09:51:11	2020-04-05	9	[{"id_menu":7,"count":1}]	2605	delivery	5	14
46781	2020-04-05 09:56:10	2020-04-05	9	[{"id_menu":6,"count":1}]	16445	delivery	5	14
46782	2020-04-05 10:04:36	2020-04-05	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	4994	delivery	5	36
46783	2020-04-05 10:06:14	2020-04-05	8	[{"id_menu":5,"count":1}]	9743	delivery	5	13
46784	2020-04-05 10:31:43	2020-04-05	9	[{"id_menu":7,"count":1}]	9104	pick-up	0	9
46785	2020-04-05 10:36:11	2020-04-05	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	18608	delivery	5	31
46786	2020-04-05 10:38:49	2020-04-05	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	18603	delivery	5	30
46787	2020-04-05 10:38:53	2020-04-05	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18589	pick-up	0	48
46788	2020-04-05 10:47:17	2020-04-05	14	[{"id_menu":2,"count":1}]	13547	pick-up	0	14
46789	2020-04-05 10:49:05	2020-04-05	8	[{"id_menu":5,"count":1}]	17794	delivery	5	13
46790	2020-04-05 10:50:17	2020-04-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13907	delivery	5	31
46791	2020-04-05 10:52:49	2020-04-05	12	[{"id_menu":3,"count":1}]	15013	delivery	5	17
46792	2020-04-05 10:53:15	2020-04-05	12	[{"id_menu":3,"count":1}]	18513	pick-up	0	12
46793	2020-04-05 10:55:48	2020-04-05	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3476	delivery	5	38
46794	2020-04-05 10:56:33	2020-04-05	17	[{"id_menu":4,"count":1}]	18641	delivery	5	22
46795	2020-04-05 10:59:58	2020-04-05	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	18506	delivery	5	35
46796	2020-04-05 11:00:34	2020-04-05	9	[{"id_menu":7,"count":1}]	2079	pick-up	0	9
46797	2020-04-05 11:04:14	2020-04-05	9	[{"id_menu":7,"count":1}]	6341	delivery	5	14
46798	2020-04-05 11:06:06	2020-04-05	14	[{"id_menu":2,"count":1}]	1931	pick-up	0	14
46799	2020-04-05 11:06:37	2020-04-05	17	[{"id_menu":4,"count":2}]	12338	pick-up	0	17
46800	2020-04-05 11:06:45	2020-04-05	17	[{"id_menu":4,"count":1}]	4624	pick-up	0	17
46801	2020-04-05 11:25:02	2020-04-05	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9348	delivery	5	36
46802	2020-04-05 11:29:25	2020-04-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	623	pick-up	0	26
46803	2020-04-05 11:43:48	2020-04-05	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3289	pick-up	0	26
46804	2020-04-05 11:44:00	2020-04-05	9	[{"id_menu":6,"count":1}]	15120	delivery	5	14
46805	2020-04-05 11:48:00	2020-04-05	9	[{"id_menu":6,"count":1}]	18615	delivery	5	14
46806	2020-04-05 12:00:48	2020-04-05	14	[{"id_menu":2,"count":1}]	2173	pick-up	0	14
46807	2020-04-05 12:00:58	2020-04-05	12	[{"id_menu":1,"count":1}]	1432	pick-up	0	12
46808	2020-04-05 12:04:03	2020-04-05	9	[{"id_menu":7,"count":1}]	15829	pick-up	0	9
46809	2020-04-05 12:04:28	2020-04-05	9	[{"id_menu":6,"count":2}]	11006	delivery	5	14
46810	2020-04-05 12:04:29	2020-04-05	9	[{"id_menu":6,"count":1}]	18546	delivery	5	14
46811	2020-04-05 12:05:23	2020-04-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11923	delivery	5	31
46812	2020-04-05 12:06:15	2020-04-05	12	[{"id_menu":1,"count":1}]	18494	delivery	5	17
46813	2020-04-05 12:14:02	2020-04-05	9	[{"id_menu":6,"count":1}]	1963	pick-up	0	9
46814	2020-04-05 12:20:56	2020-04-05	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3619	pick-up	0	29
46815	2020-04-05 12:21:10	2020-04-05	9	[{"id_menu":6,"count":1}]	15530	delivery	5	14
46816	2020-04-05 12:22:45	2020-04-05	9	[{"id_menu":6,"count":3}]	12546	delivery	5	14
46817	2020-04-05 12:28:19	2020-04-05	9	[{"id_menu":6,"count":1}]	14358	pick-up	0	9
46818	2020-04-05 12:28:20	2020-04-05	8	[{"id_menu":5,"count":1}]	18634	delivery	5	13
46819	2020-04-05 12:33:45	2020-04-05	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	132	pick-up	0	29
46820	2020-04-05 12:40:03	2020-04-05	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9867	delivery	5	39
46821	2020-04-05 12:41:51	2020-04-05	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4876	delivery	5	36
46822	2020-04-05 12:43:44	2020-04-05	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	18627	delivery	5	31
46823	2020-04-05 12:49:15	2020-04-05	9	[{"id_menu":7,"count":1}]	158	pick-up	0	9
46824	2020-04-05 12:49:27	2020-04-05	17	[{"id_menu":4,"count":1}]	3937	pick-up	0	17
46825	2020-04-05 12:53:59	2020-04-05	9	[{"id_menu":6,"count":1}]	18570	delivery	5	14
46826	2020-04-05 12:57:01	2020-04-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	18612	delivery	5	23
46827	2020-04-05 13:00:03	2020-04-05	14	[{"id_menu":2,"count":1}]	10727	pick-up	0	14
46828	2020-04-05 13:04:24	2020-04-05	14	[{"id_menu":2,"count":1}]	7203	pick-up	0	14
46829	2020-04-05 13:07:29	2020-04-05	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	1657	pick-up	0	23
46830	2020-04-05 13:10:22	2020-04-05	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	18563	delivery	5	43
46831	2020-04-05 13:11:03	2020-04-05	17	[{"id_menu":4,"count":1}]	16816	delivery	5	22
46832	2020-04-05 13:11:06	2020-04-05	9	[{"id_menu":6,"count":1}]	18597	delivery	5	14
46833	2020-04-05 13:15:17	2020-04-05	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3616	pick-up	0	26
46834	2020-04-05 13:16:41	2020-04-05	9	[{"id_menu":7,"count":1}]	11550	delivery	5	14
46835	2020-04-05 13:18:03	2020-04-05	17	[{"id_menu":4,"count":1}]	18600	delivery	5	22
46836	2020-04-05 13:19:10	2020-04-05	9	[{"id_menu":7,"count":1}]	1618	pick-up	0	9
46837	2020-04-05 13:22:00	2020-04-05	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	659	delivery	5	34
46838	2020-04-05 13:23:29	2020-04-05	12	[{"id_menu":1,"count":1}]	6397	delivery	5	17
46839	2020-04-05 13:31:27	2020-04-05	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3609	pick-up	0	31
46840	2020-04-05 13:31:49	2020-04-05	9	[{"id_menu":6,"count":1}]	8130	delivery	5	14
46841	2020-04-05 13:32:15	2020-04-05	9	[{"id_menu":7,"count":1}]	11872	delivery	5	14
46842	2020-04-05 13:41:50	2020-04-05	9	[{"id_menu":6,"count":1}]	17805	pick-up	0	9
46843	2020-04-05 13:41:52	2020-04-05	12	[{"id_menu":1,"count":1}]	5183	delivery	5	17
46844	2020-04-05 13:46:02	2020-04-05	9	[{"id_menu":6,"count":1}]	18533	pick-up	0	9
46845	2020-04-05 13:47:15	2020-04-05	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	18637	delivery	5	44
46846	2020-04-05 13:47:17	2020-04-05	9	[{"id_menu":6,"count":1}]	18614	delivery	5	14
46847	2020-04-05 13:51:18	2020-04-05	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	13708	delivery	5	26
46848	2020-04-05 13:53:51	2020-04-05	17	[{"id_menu":4,"count":1}]	16271	delivery	5	22
46849	2020-04-05 13:57:16	2020-04-05	9	[{"id_menu":7,"count":1}]	380	delivery	5	14
46850	2020-04-05 13:59:19	2020-04-05	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	1309	pick-up	0	26
46851	2020-04-05 14:01:04	2020-04-05	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1546	delivery	5	42
46852	2020-04-05 14:02:36	2020-04-05	8	[{"id_menu":5,"count":1}]	13023	delivery	5	13
46853	2020-04-05 14:04:17	2020-04-05	9	[{"id_menu":7,"count":1}]	18569	pick-up	0	9
46854	2020-04-05 14:06:10	2020-04-05	9	[{"id_menu":6,"count":1}]	292	delivery	5	14
46855	2020-04-05 14:08:11	2020-04-05	17	[{"id_menu":4,"count":1}]	2657	delivery	5	22
46856	2020-04-05 14:09:52	2020-04-05	14	[{"id_menu":2,"count":1}]	1542	delivery	5	19
46857	2020-04-05 14:11:10	2020-04-05	8	[{"id_menu":5,"count":1}]	11737	pick-up	0	8
46858	2020-04-05 14:12:14	2020-04-05	8	[{"id_menu":5,"count":1}]	143	delivery	5	13
46859	2020-04-05 14:18:25	2020-04-05	9	[{"id_menu":6,"count":1}]	1143	pick-up	0	9
46860	2020-04-05 14:20:30	2020-04-05	9	[{"id_menu":6,"count":1}]	833	pick-up	0	9
46861	2020-04-05 14:24:41	2020-04-05	17	[{"id_menu":4,"count":1}]	16228	pick-up	0	17
46862	2020-04-05 14:28:45	2020-04-05	12	[{"id_menu":1,"count":1}]	18476	delivery	5	17
46863	2020-04-05 14:34:44	2020-04-05	17	[{"id_menu":4,"count":1}]	3283	pick-up	0	17
46864	2020-04-05 14:34:54	2020-04-05	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18514	delivery	5	34
46865	2020-04-05 14:45:17	2020-04-05	12	[{"id_menu":1,"count":1}]	15009	delivery	5	17
46866	2020-04-05 14:46:26	2020-04-05	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	15452	delivery	5	26
46867	2020-04-05 14:48:18	2020-04-05	9	[{"id_menu":7,"count":1}]	18580	delivery	5	14
46868	2020-04-05 14:56:16	2020-04-05	12	[{"id_menu":3,"count":1}]	6678	delivery	5	17
46869	2020-04-05 14:56:41	2020-04-05	14	[{"id_menu":2,"count":1}]	10234	delivery	5	19
46870	2020-04-05 14:57:58	2020-04-05	8	[{"id_menu":5,"count":1}]	8763	delivery	5	13
46871	2020-04-05 15:01:40	2020-04-05	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	10552	delivery	5	31
46872	2020-04-05 15:03:27	2020-04-05	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	16384	delivery	5	43
46873	2020-04-05 15:19:01	2020-04-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	18624	delivery	5	31
46874	2020-04-05 15:20:54	2020-04-05	8	[{"id_menu":5,"count":1}]	18405	pick-up	0	8
46875	2020-04-05 15:27:11	2020-04-05	17	[{"id_menu":4,"count":1}]	229	delivery	5	22
46876	2020-04-05 15:28:36	2020-04-05	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	18375	delivery	5	28
46877	2020-04-05 15:32:47	2020-04-05	14	[{"id_menu":2,"count":1}]	18583	delivery	5	19
46878	2020-04-05 15:33:01	2020-04-05	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18567	delivery	5	35
46879	2020-04-05 15:34:04	2020-04-05	9	[{"id_menu":6,"count":1}]	10170	delivery	5	14
46880	2020-04-05 15:39:26	2020-04-05	12	[{"id_menu":3,"count":1}]	8201	delivery	5	17
46881	2020-04-05 15:41:04	2020-04-05	9	[{"id_menu":6,"count":1}]	12899	delivery	5	14
46882	2020-04-05 15:41:37	2020-04-05	9	[{"id_menu":7,"count":1}]	17707	delivery	5	14
46883	2020-04-05 15:41:58	2020-04-05	8	[{"id_menu":5,"count":1}]	7108	delivery	5	13
46884	2020-04-05 15:43:15	2020-04-05	9	[{"id_menu":6,"count":1}]	5508	pick-up	0	9
46885	2020-04-05 15:43:19	2020-04-05	8	[{"id_menu":5,"count":1}]	18531	pick-up	0	8
46886	2020-04-05 15:43:26	2020-04-05	17	[{"id_menu":4,"count":1}]	5975	delivery	5	22
46887	2020-04-05 15:44:46	2020-04-05	12	[{"id_menu":3,"count":1}]	3679	delivery	5	17
46888	2020-04-05 15:52:58	2020-04-05	9	[{"id_menu":6,"count":1}]	13176	delivery	5	14
46889	2020-04-05 16:03:19	2020-04-05	17	[{"id_menu":4,"count":1}]	18516	delivery	5	22
46890	2020-04-05 16:05:02	2020-04-05	12	[{"id_menu":3,"count":1}]	6235	pick-up	0	12
46891	2020-04-05 16:05:23	2020-04-05	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2320	pick-up	0	31
46892	2020-04-05 16:12:40	2020-04-05	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2020	delivery	5	31
46893	2020-04-05 16:18:12	2020-04-05	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	18633	delivery	5	31
46894	2020-04-05 16:19:13	2020-04-05	12	[{"id_menu":3,"count":1}]	3827	pick-up	0	12
46895	2020-04-05 16:23:45	2020-04-05	17	[{"id_menu":4,"count":1}]	467	pick-up	0	17
46896	2020-04-05 16:24:51	2020-04-05	9	[{"id_menu":6,"count":1}]	3085	pick-up	0	9
46897	2020-04-05 16:26:15	2020-04-05	9	[{"id_menu":7,"count":1}]	11756	delivery	5	14
46898	2020-04-05 16:28:00	2020-04-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	18609	delivery	5	23
46899	2020-04-05 16:33:16	2020-04-05	14	[{"id_menu":2,"count":1}]	12905	pick-up	0	14
46900	2020-04-05 16:35:30	2020-04-05	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6680	pick-up	0	25
46901	2020-04-05 16:38:00	2020-04-05	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	18529	delivery	5	39
46902	2020-04-05 16:39:51	2020-04-05	17	[{"id_menu":4,"count":1}]	996	pick-up	0	17
46903	2020-04-05 16:40:17	2020-04-05	8	[{"id_menu":5,"count":1}]	18501	pick-up	0	8
46904	2020-04-05 16:41:15	2020-04-05	14	[{"id_menu":2,"count":1}]	18536	delivery	5	19
46905	2020-04-05 16:46:58	2020-04-05	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	7687	delivery	5	31
46906	2020-04-05 16:48:07	2020-04-05	17	[{"id_menu":4,"count":1}]	806	delivery	5	22
46907	2020-04-05 16:48:39	2020-04-05	12	[{"id_menu":3,"count":1}]	18604	pick-up	0	12
46908	2020-04-05 16:49:04	2020-04-05	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	18554	delivery	5	26
46909	2020-04-05 16:53:23	2020-04-05	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18566	delivery	5	35
46910	2020-04-05 16:54:21	2020-04-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":3}]	11366	delivery	5	22
46911	2020-04-05 16:56:13	2020-04-05	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	9295	pick-up	0	31
46912	2020-04-05 16:56:43	2020-04-05	9	[{"id_menu":6,"count":1}]	7733	delivery	5	14
46913	2020-04-05 16:56:57	2020-04-05	12	[{"id_menu":3,"count":1}]	13597	delivery	5	17
46914	2020-04-05 17:00:40	2020-04-05	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	18628	delivery	5	34
46915	2020-04-05 17:03:05	2020-04-05	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	13055	delivery	5	31
46916	2020-04-05 17:06:26	2020-04-05	17	[{"id_menu":4,"count":1}]	18418	delivery	5	22
46917	2020-04-05 17:07:26	2020-04-05	8	[{"id_menu":5,"count":1}]	18535	delivery	5	13
46918	2020-04-05 17:09:33	2020-04-05	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	18564	delivery	5	25
46919	2020-04-05 17:14:33	2020-04-05	17	[{"id_menu":4,"count":1}]	10273	pick-up	0	17
46920	2020-04-05 17:19:46	2020-04-05	14	[{"id_menu":2,"count":1}]	136	delivery	5	19
46921	2020-04-05 17:22:37	2020-04-05	12	[{"id_menu":1,"count":2}]	9304	pick-up	0	12
46922	2020-04-05 17:24:09	2020-04-05	9	[{"id_menu":6,"count":1}]	4028	pick-up	0	9
46923	2020-04-05 17:28:32	2020-04-05	12	[{"id_menu":1,"count":1}]	8065	pick-up	0	12
46924	2020-04-05 17:30:53	2020-04-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11693	delivery	5	23
46925	2020-04-05 17:32:25	2020-04-05	17	[{"id_menu":4,"count":1}]	18575	pick-up	0	17
46926	2020-04-05 17:32:41	2020-04-05	9	[{"id_menu":7,"count":1}]	17322	delivery	5	14
46927	2020-04-05 17:33:12	2020-04-05	9	[{"id_menu":6,"count":1}]	10810	delivery	5	14
46928	2020-04-05 17:54:48	2020-04-05	8	[{"id_menu":5,"count":1}]	1076	pick-up	0	8
46929	2020-04-05 17:56:02	2020-04-05	17	[{"id_menu":4,"count":1}]	8799	pick-up	0	17
46930	2020-04-05 17:59:31	2020-04-05	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3703	delivery	5	36
46931	2020-04-05 18:01:33	2020-04-05	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	13639	pick-up	0	26
46932	2020-04-05 18:03:33	2020-04-05	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	13758	delivery	5	22
46933	2020-04-05 18:11:30	2020-04-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	12997	delivery	5	28
46934	2020-04-05 18:19:02	2020-04-05	8	[{"id_menu":5,"count":1}]	18543	delivery	5	13
46935	2020-04-05 18:19:28	2020-04-05	9	[{"id_menu":7,"count":1}]	18541	pick-up	0	9
46936	2020-04-05 18:22:03	2020-04-05	14	[{"id_menu":2,"count":1}]	4870	pick-up	0	14
46937	2020-04-05 18:26:05	2020-04-05	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3415	delivery	5	45
46938	2020-04-05 18:29:16	2020-04-05	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	18625	delivery	5	26
46939	2020-04-05 18:35:33	2020-04-05	12	[{"id_menu":1,"count":1}]	18524	delivery	5	17
46940	2020-04-05 18:36:27	2020-04-05	14	[{"id_menu":2,"count":1}]	18558	delivery	5	19
46941	2020-04-05 18:40:06	2020-04-05	9	[{"id_menu":6,"count":1}]	12224	delivery	5	14
46942	2020-04-05 18:45:57	2020-04-05	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18586	delivery	5	48
46943	2020-04-05 18:47:29	2020-04-05	14	[{"id_menu":2,"count":1}]	4132	pick-up	0	14
46944	2020-04-05 18:48:36	2020-04-05	12	[{"id_menu":1,"count":1}]	7098	delivery	5	17
46945	2020-04-05 18:50:01	2020-04-05	14	[{"id_menu":2,"count":1}]	7436	delivery	5	19
46946	2020-04-05 18:50:46	2020-04-05	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	18548	delivery	5	31
46947	2020-04-05 18:56:58	2020-04-05	12	[{"id_menu":1,"count":1}]	18557	delivery	5	17
46948	2020-04-05 18:57:36	2020-04-05	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3519	delivery	5	22
46949	2020-04-05 18:58:22	2020-04-05	14	[{"id_menu":2,"count":1}]	18642	delivery	5	19
46950	2020-04-05 18:59:17	2020-04-05	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	18540	delivery	5	27
46951	2020-04-05 19:06:50	2020-04-05	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	18521	delivery	5	31
46952	2020-04-05 19:09:15	2020-04-05	12	[{"id_menu":1,"count":1}]	10504	delivery	5	17
46953	2020-04-05 19:11:41	2020-04-05	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	18611	delivery	5	23
46954	2020-04-05 19:15:03	2020-04-05	17	[{"id_menu":4,"count":1}]	13463	pick-up	0	17
46955	2020-04-05 19:17:12	2020-04-05	12	[{"id_menu":3,"count":1}]	1809	pick-up	0	12
46956	2020-04-05 19:22:27	2020-04-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11543	delivery	5	23
46957	2020-04-05 19:23:23	2020-04-05	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	18500	delivery	5	40
46958	2020-04-05 19:25:07	2020-04-05	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	17870	delivery	5	26
46959	2020-04-05 19:25:43	2020-04-05	14	[{"id_menu":2,"count":1}]	1891	pick-up	0	14
46960	2020-04-05 19:26:07	2020-04-05	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	16603	delivery	5	52
46961	2020-04-05 19:29:14	2020-04-05	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18549	delivery	5	34
46962	2020-04-05 19:30:37	2020-04-05	8	[{"id_menu":5,"count":1}]	9356	pick-up	0	8
46963	2020-04-05 19:31:48	2020-04-05	12	[{"id_menu":3,"count":1}]	1427	delivery	5	17
46964	2020-04-05 19:31:56	2020-04-05	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1215	pick-up	0	29
46965	2020-04-05 19:32:06	2020-04-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	351	pick-up	0	18
46966	2020-04-05 19:32:43	2020-04-05	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1731	pick-up	0	31
46967	2020-04-05 19:34:43	2020-04-05	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	18636	delivery	5	42
46968	2020-04-05 19:38:30	2020-04-05	9	[{"id_menu":6,"count":1}]	18645	delivery	5	14
46969	2020-04-05 19:38:47	2020-04-05	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	16670	delivery	5	34
46970	2020-04-05 19:39:29	2020-04-05	17	[{"id_menu":4,"count":1}]	2275	pick-up	0	17
46971	2020-04-05 19:40:18	2020-04-05	14	[{"id_menu":2,"count":1}]	6176	pick-up	0	14
46972	2020-04-05 19:43:26	2020-04-05	12	[{"id_menu":1,"count":1}]	18623	delivery	5	17
46973	2020-04-05 19:44:41	2020-04-05	8	[{"id_menu":5,"count":1}]	2041	pick-up	0	8
46974	2020-04-05 19:48:00	2020-04-05	8	[{"id_menu":5,"count":1}]	6791	delivery	5	13
46975	2020-04-05 19:52:06	2020-04-05	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18578	delivery	5	51
46976	2020-04-05 19:52:55	2020-04-05	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":2}]	7025	delivery	5	34
46977	2020-04-05 19:53:44	2020-04-05	12	[{"id_menu":1,"count":1}]	18556	delivery	5	17
46978	2020-04-05 19:55:09	2020-04-05	17	[{"id_menu":4,"count":1}]	18511	pick-up	0	17
46979	2020-04-05 20:03:54	2020-04-05	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2847	pick-up	0	23
46980	2020-04-05 20:04:42	2020-04-05	17	[{"id_menu":4,"count":1}]	1916	pick-up	0	17
46981	2020-04-05 20:06:58	2020-04-05	14	[{"id_menu":2,"count":1}]	3552	delivery	5	19
46982	2020-04-05 20:07:36	2020-04-05	17	[{"id_menu":4,"count":1}]	17809	delivery	5	22
46983	2020-04-05 20:09:58	2020-04-05	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11040	pick-up	0	26
46984	2020-04-05 20:12:20	2020-04-05	9	[{"id_menu":6,"count":1}]	18525	pick-up	0	9
46985	2020-04-05 20:15:37	2020-04-05	14	[{"id_menu":2,"count":1}]	1101	pick-up	0	14
46986	2020-04-05 20:25:22	2020-04-05	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1106	pick-up	0	21
46987	2020-04-05 20:25:57	2020-04-05	9	[{"id_menu":6,"count":1}]	18496	delivery	5	14
46988	2020-04-05 20:29:46	2020-04-05	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	3211	delivery	5	26
46989	2020-04-05 20:32:44	2020-04-05	9	[{"id_menu":6,"count":1}]	16754	delivery	5	14
46990	2020-04-05 20:37:10	2020-04-05	8	[{"id_menu":5,"count":1}]	16021	delivery	5	13
46991	2020-04-05 20:37:56	2020-04-05	17	[{"id_menu":4,"count":1}]	18559	delivery	5	22
46992	2020-04-05 20:38:19	2020-04-05	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	18507	delivery	5	29
46993	2020-04-05 20:41:08	2020-04-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11983	delivery	5	22
46994	2020-04-05 20:43:40	2020-04-05	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18472	delivery	5	35
46995	2020-04-05 20:45:54	2020-04-05	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18635	delivery	5	35
46996	2020-04-05 20:51:33	2020-04-05	9	[{"id_menu":6,"count":1}]	699	delivery	5	14
46997	2020-04-05 20:55:29	2020-04-05	9	[{"id_menu":7,"count":1}]	18544	delivery	5	14
46998	2020-04-05 20:56:28	2020-04-05	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17268	delivery	5	37
46999	2020-04-05 20:57:00	2020-04-05	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	18588	delivery	5	31
47000	2020-04-05 21:01:35	2020-04-05	14	[{"id_menu":2,"count":1}]	2483	delivery	5	19
47001	2020-04-05 21:03:58	2020-04-05	14	[{"id_menu":2,"count":1}]	2937	pick-up	0	14
47002	2020-04-05 21:10:33	2020-04-05	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	17013	delivery	5	38
47003	2020-04-05 21:11:12	2020-04-05	8	[{"id_menu":5,"count":3}]	18594	delivery	5	13
47004	2020-04-05 21:13:25	2020-04-05	12	[{"id_menu":3,"count":1}]	4982	delivery	5	17
47005	2020-04-05 21:13:54	2020-04-05	14	[{"id_menu":2,"count":1}]	15109	delivery	5	19
47006	2020-04-05 21:17:04	2020-04-05	9	[{"id_menu":6,"count":1}]	13676	delivery	5	14
47007	2020-04-05 21:19:49	2020-04-05	8	[{"id_menu":5,"count":1}]	15265	pick-up	0	8
47008	2020-04-05 21:25:39	2020-04-05	17	[{"id_menu":4,"count":1}]	18605	delivery	5	22
47009	2020-04-05 21:26:50	2020-04-05	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18498	delivery	5	35
47010	2020-04-05 21:27:29	2020-04-05	14	[{"id_menu":2,"count":1}]	11779	delivery	5	19
47011	2020-04-05 21:27:42	2020-04-05	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	5761	pick-up	0	26
47012	2020-04-05 21:30:40	2020-04-05	9	[{"id_menu":7,"count":1}]	6510	delivery	5	14
47013	2020-04-05 21:35:09	2020-04-05	14	[{"id_menu":2,"count":1}]	10820	delivery	5	19
47014	2020-04-05 21:39:21	2020-04-05	12	[{"id_menu":1,"count":1}]	235	pick-up	0	12
47015	2020-04-05 21:40:15	2020-04-05	17	[{"id_menu":4,"count":2}]	15365	delivery	5	22
47016	2020-04-05 21:42:13	2020-04-05	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1174	pick-up	0	21
47017	2020-04-05 21:47:08	2020-04-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	18504	delivery	5	22
47018	2020-04-05 21:48:26	2020-04-05	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	15780	pick-up	0	29
47019	2020-04-05 21:49:37	2020-04-05	9	[{"id_menu":7,"count":1}]	18534	delivery	5	14
47020	2020-04-05 22:02:06	2020-04-05	9	[{"id_menu":7,"count":1}]	18630	delivery	5	14
47021	2020-04-05 22:06:53	2020-04-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":3}]	9182	delivery	5	28
47022	2020-04-05 22:08:35	2020-04-05	9	[{"id_menu":7,"count":1}]	8755	delivery	5	14
47023	2020-04-05 22:08:39	2020-04-05	9	[{"id_menu":7,"count":1}]	13994	delivery	5	14
47024	2020-04-05 22:11:14	2020-04-05	8	[{"id_menu":5,"count":1}]	16040	delivery	5	13
47025	2020-04-05 22:13:16	2020-04-05	9	[{"id_menu":7,"count":1}]	18539	delivery	5	14
47026	2020-04-05 22:13:58	2020-04-05	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	18492	delivery	5	26
47027	2020-04-05 22:15:21	2020-04-05	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	9733	delivery	5	45
47028	2020-04-05 22:16:25	2020-04-05	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3447	pick-up	0	34
47029	2020-04-05 22:18:34	2020-04-05	12	[{"id_menu":1,"count":1}]	320	pick-up	0	12
47030	2020-04-05 22:19:46	2020-04-05	14	[{"id_menu":2,"count":1}]	18515	delivery	5	19
47031	2020-04-05 22:25:24	2020-04-05	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	16039	pick-up	0	21
47032	2020-04-05 22:34:09	2020-04-05	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	18512	delivery	5	45
47033	2020-04-05 22:42:07	2020-04-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2689	delivery	5	31
47034	2020-04-05 22:44:41	2020-04-05	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	18621	delivery	5	31
47035	2020-04-05 22:47:52	2020-04-05	17	[{"id_menu":4,"count":1}]	12183	pick-up	0	17
47036	2020-04-05 22:49:01	2020-04-05	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	18616	delivery	5	26
47037	2020-04-05 22:51:29	2020-04-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14475	delivery	5	23
47038	2020-04-05 22:53:17	2020-04-05	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	10738	delivery	5	25
47039	2020-04-05 22:53:57	2020-04-05	9	[{"id_menu":7,"count":1}]	7032	delivery	5	14
47040	2020-04-05 22:56:16	2020-04-05	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	18386	delivery	5	26
47041	2020-04-05 23:00:16	2020-04-05	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	7918	delivery	5	27
47042	2020-04-05 23:01:03	2020-04-05	17	[{"id_menu":4,"count":1}]	5729	pick-up	0	17
47043	2020-04-05 23:04:39	2020-04-05	8	[{"id_menu":5,"count":2}]	14996	delivery	5	13
47044	2020-04-05 23:05:49	2020-04-05	12	[{"id_menu":3,"count":1}]	16397	delivery	5	17
47045	2020-04-05 23:09:50	2020-04-05	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	18643	pick-up	0	33
47046	2020-04-05 23:13:03	2020-04-05	9	[{"id_menu":7,"count":1}]	2602	pick-up	0	9
47047	2020-04-05 23:14:23	2020-04-05	8	[{"id_menu":5,"count":1}]	18495	delivery	5	13
47048	2020-04-05 23:15:32	2020-04-05	9	[{"id_menu":7,"count":1}]	18599	delivery	5	14
47049	2020-04-05 23:19:50	2020-04-05	12	[{"id_menu":1,"count":1}]	3172	pick-up	0	12
47050	2020-04-05 23:21:48	2020-04-05	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	13012	delivery	5	28
47051	2020-04-05 23:21:57	2020-04-05	9	[{"id_menu":7,"count":1}]	12211	delivery	5	14
47052	2020-04-05 23:22:01	2020-04-05	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	18571	delivery	5	26
47053	2020-04-05 23:23:04	2020-04-05	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	18573	delivery	5	26
47054	2020-04-05 23:23:42	2020-04-05	12	[{"id_menu":3,"count":1}]	8181	delivery	5	17
47055	2020-04-05 23:25:11	2020-04-05	9	[{"id_menu":6,"count":1}]	18174	delivery	5	14
47056	2020-04-05 23:29:44	2020-04-05	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	18572	delivery	5	45
47057	2020-04-05 23:30:14	2020-04-05	8	[{"id_menu":5,"count":1}]	18553	delivery	5	13
47058	2020-04-05 23:31:26	2020-04-05	8	[{"id_menu":5,"count":1}]	12016	delivery	5	13
47059	2020-04-05 23:34:23	2020-04-05	12	[{"id_menu":3,"count":1}]	5472	delivery	5	17
47060	2020-04-05 23:37:13	2020-04-05	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":3}]	18595	delivery	5	26
47061	2020-04-05 23:43:22	2020-04-05	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18497	delivery	5	22
47062	2020-04-05 23:44:38	2020-04-05	12	[{"id_menu":3,"count":1}]	12367	pick-up	0	12
47063	2020-04-05 23:47:58	2020-04-05	8	[{"id_menu":5,"count":1}]	18582	delivery	5	13
47064	2020-04-05 23:51:46	2020-04-05	9	[{"id_menu":6,"count":1}]	8190	delivery	5	14
47065	2020-04-05 23:53:23	2020-04-05	14	[{"id_menu":2,"count":1}]	13068	pick-up	0	14
47066	2020-04-05 23:54:34	2020-04-05	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13933	delivery	5	31
47067	2020-04-05 23:56:07	2020-04-05	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18620	delivery	5	39
47068	2020-04-05 23:56:41	2020-04-05	9	[{"id_menu":6,"count":1}]	5712	delivery	5	14
47069	2020-04-05 23:57:03	2020-04-05	17	[{"id_menu":4,"count":1}]	7462	delivery	5	22
47070	2020-04-05 23:57:05	2020-04-05	14	[{"id_menu":2,"count":1}]	18538	delivery	5	19
47071	2020-04-06 00:08:51	2020-04-06	9	[{"id_menu":7,"count":1}]	6844	pick-up	0	9
47072	2020-04-06 00:13:33	2020-04-06	14	[{"id_menu":2,"count":1}]	10387	pick-up	0	14
47073	2020-04-06 00:19:14	2020-04-06	9	[{"id_menu":7,"count":1}]	13572	delivery	5	14
47074	2020-04-06 00:42:45	2020-04-06	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	17423	pick-up	0	22
47075	2020-04-06 01:09:38	2020-04-06	9	[{"id_menu":6,"count":1}]	18740	delivery	5	14
47076	2020-04-06 01:10:19	2020-04-06	9	[{"id_menu":6,"count":1}]	1345	pick-up	0	9
47077	2020-04-06 01:12:42	2020-04-06	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	18227	pick-up	0	35
47078	2020-04-06 01:14:27	2020-04-06	14	[{"id_menu":2,"count":1}]	18695	delivery	5	19
47079	2020-04-06 01:14:30	2020-04-06	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	9810	delivery	5	31
47080	2020-04-06 01:14:49	2020-04-06	14	[{"id_menu":2,"count":1}]	11161	delivery	5	19
47081	2020-04-06 01:15:24	2020-04-06	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	17100	delivery	5	26
47082	2020-04-06 01:17:50	2020-04-06	12	[{"id_menu":1,"count":1}]	3372	pick-up	0	12
47083	2020-04-06 01:33:21	2020-04-06	9	[{"id_menu":6,"count":2}]	7925	delivery	5	14
47084	2020-04-06 01:34:15	2020-04-06	12	[{"id_menu":3,"count":1}]	6641	delivery	5	17
47085	2020-04-06 01:39:31	2020-04-06	43	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	16822	pick-up	0	43
47086	2020-04-06 01:53:41	2020-04-06	8	[{"id_menu":5,"count":1}]	12971	delivery	5	13
47087	2020-04-06 02:06:19	2020-04-06	17	[{"id_menu":4,"count":1}]	7428	delivery	5	22
47088	2020-04-06 02:20:29	2020-04-06	8	[{"id_menu":5,"count":1}]	9304	delivery	5	13
47089	2020-04-06 02:27:44	2020-04-06	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	18730	delivery	5	40
47090	2020-04-06 02:35:19	2020-04-06	12	[{"id_menu":3,"count":1}]	7150	pick-up	0	12
47091	2020-04-06 02:35:24	2020-04-06	17	[{"id_menu":4,"count":1}]	4243	delivery	5	22
47092	2020-04-06 02:40:13	2020-04-06	9	[{"id_menu":7,"count":1}]	2152	delivery	5	14
47093	2020-04-06 02:49:30	2020-04-06	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	18721	delivery	5	28
47094	2020-04-06 02:51:48	2020-04-06	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8094	delivery	5	36
47095	2020-04-06 03:00:49	2020-04-06	8	[{"id_menu":5,"count":1}]	15348	delivery	5	13
47096	2020-04-06 03:07:37	2020-04-06	9	[{"id_menu":7,"count":1}]	18654	delivery	5	14
47097	2020-04-06 03:09:02	2020-04-06	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	8213	delivery	5	37
47098	2020-04-06 03:19:09	2020-04-06	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7852	delivery	5	31
47099	2020-04-06 03:20:57	2020-04-06	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	3567	delivery	5	39
47100	2020-04-06 03:29:49	2020-04-06	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	18714	pick-up	0	26
47101	2020-04-06 03:44:41	2020-04-06	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	16298	delivery	5	31
47102	2020-04-06 03:46:50	2020-04-06	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	18710	delivery	5	30
47103	2020-04-06 04:02:21	2020-04-06	12	[{"id_menu":1,"count":1}]	1993	delivery	5	17
47104	2020-04-06 04:04:24	2020-04-06	12	[{"id_menu":1,"count":2}]	16205	delivery	5	17
47105	2020-04-06 04:04:40	2020-04-06	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4605	delivery	5	27
47106	2020-04-06 04:33:53	2020-04-06	9	[{"id_menu":7,"count":1}]	18231	pick-up	0	9
47107	2020-04-06 04:37:36	2020-04-06	17	[{"id_menu":4,"count":1}]	9533	pick-up	0	17
47108	2020-04-06 04:39:55	2020-04-06	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	3887	delivery	5	26
47109	2020-04-06 04:46:11	2020-04-06	9	[{"id_menu":6,"count":1}]	8210	delivery	5	14
47110	2020-04-06 04:50:30	2020-04-06	14	[{"id_menu":2,"count":1}]	12194	delivery	5	19
47111	2020-04-06 04:56:04	2020-04-06	9	[{"id_menu":7,"count":1}]	18712	delivery	5	14
47112	2020-04-06 05:12:27	2020-04-06	8	[{"id_menu":5,"count":1}]	1915	pick-up	0	8
47113	2020-04-06 05:15:07	2020-04-06	9	[{"id_menu":6,"count":1}]	18707	delivery	5	14
47114	2020-04-06 05:15:27	2020-04-06	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7050	pick-up	0	40
47115	2020-04-06 05:17:43	2020-04-06	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	499	delivery	5	31
47116	2020-04-06 05:34:10	2020-04-06	14	[{"id_menu":2,"count":1}]	18722	delivery	5	19
47117	2020-04-06 05:45:06	2020-04-06	17	[{"id_menu":4,"count":1}]	18731	delivery	5	22
47118	2020-04-06 05:45:49	2020-04-06	12	[{"id_menu":1,"count":2}]	5981	pick-up	0	12
47119	2020-04-06 05:52:55	2020-04-06	9	[{"id_menu":6,"count":1}]	12888	pick-up	0	9
47120	2020-04-06 05:56:17	2020-04-06	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	17351	delivery	5	26
47121	2020-04-06 05:59:17	2020-04-06	9	[{"id_menu":6,"count":1}]	14159	delivery	5	14
47122	2020-04-06 06:01:07	2020-04-06	9	[{"id_menu":6,"count":1}]	18678	delivery	5	14
47123	2020-04-06 06:04:54	2020-04-06	8	[{"id_menu":5,"count":1}]	477	pick-up	0	8
47124	2020-04-06 06:15:16	2020-04-06	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	18666	delivery	5	31
47125	2020-04-06 06:16:29	2020-04-06	14	[{"id_menu":2,"count":1}]	18698	delivery	5	19
47126	2020-04-06 06:19:30	2020-04-06	12	[{"id_menu":1,"count":1}]	6423	delivery	5	17
47127	2020-04-06 06:22:01	2020-04-06	12	[{"id_menu":3,"count":1}]	169	pick-up	0	12
47128	2020-04-06 06:23:23	2020-04-06	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	15048	delivery	5	27
47129	2020-04-06 06:29:44	2020-04-06	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	18773	delivery	5	25
47130	2020-04-06 06:34:08	2020-04-06	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	17436	delivery	5	30
47131	2020-04-06 06:36:51	2020-04-06	8	[{"id_menu":5,"count":1}]	2507	delivery	5	13
47132	2020-04-06 06:43:37	2020-04-06	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	18745	delivery	5	48
47133	2020-04-06 06:48:43	2020-04-06	17	[{"id_menu":4,"count":1}]	18706	delivery	5	22
47134	2020-04-06 06:52:07	2020-04-06	9	[{"id_menu":7,"count":1}]	2287	pick-up	0	9
47135	2020-04-06 06:54:58	2020-04-06	12	[{"id_menu":3,"count":1}]	18362	pick-up	0	12
47136	2020-04-06 06:56:31	2020-04-06	9	[{"id_menu":6,"count":1}]	18675	delivery	5	14
47137	2020-04-06 07:05:10	2020-04-06	9	[{"id_menu":6,"count":1}]	2635	delivery	5	14
47138	2020-04-06 07:23:11	2020-04-06	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18658	delivery	5	22
47139	2020-04-06 07:35:00	2020-04-06	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	18646	delivery	5	31
47140	2020-04-06 08:00:34	2020-04-06	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	16041	delivery	5	43
47141	2020-04-06 08:11:42	2020-04-06	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	16498	delivery	5	22
47142	2020-04-06 08:14:28	2020-04-06	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	18668	delivery	5	43
47143	2020-04-06 08:19:13	2020-04-06	9	[{"id_menu":6,"count":1}]	18718	delivery	5	14
47144	2020-04-06 08:44:11	2020-04-06	9	[{"id_menu":7,"count":1}]	3509	pick-up	0	9
47145	2020-04-06 08:51:20	2020-04-06	8	[{"id_menu":5,"count":2}]	15193	delivery	5	13
47146	2020-04-06 08:58:11	2020-04-06	9	[{"id_menu":6,"count":1}]	18771	delivery	5	14
47147	2020-04-06 08:58:41	2020-04-06	9	[{"id_menu":6,"count":1}]	18674	delivery	5	14
47148	2020-04-06 09:12:00	2020-04-06	17	[{"id_menu":4,"count":1}]	7735	pick-up	0	17
47149	2020-04-06 09:25:15	2020-04-06	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	18680	delivery	5	31
47150	2020-04-06 09:25:32	2020-04-06	12	[{"id_menu":1,"count":1}]	624	pick-up	0	12
47151	2020-04-06 09:26:40	2020-04-06	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	18652	delivery	5	26
47152	2020-04-06 09:29:11	2020-04-06	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5843	delivery	5	39
47153	2020-04-06 09:30:25	2020-04-06	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6137	delivery	5	42
47154	2020-04-06 09:44:32	2020-04-06	9	[{"id_menu":7,"count":1}]	14273	delivery	5	14
47155	2020-04-06 09:45:07	2020-04-06	9	[{"id_menu":6,"count":1}]	10694	pick-up	0	9
47156	2020-04-06 09:47:43	2020-04-06	9	[{"id_menu":6,"count":1}]	18734	delivery	5	14
47157	2020-04-06 09:47:46	2020-04-06	12	[{"id_menu":3,"count":1}]	11574	pick-up	0	12
47158	2020-04-06 09:51:37	2020-04-06	9	[{"id_menu":6,"count":1}]	8358	pick-up	0	9
47159	2020-04-06 10:03:53	2020-04-06	9	[{"id_menu":7,"count":1}]	18750	delivery	5	14
47160	2020-04-06 10:09:15	2020-04-06	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4786	delivery	5	40
47161	2020-04-06 10:23:49	2020-04-06	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	18682	delivery	5	40
47162	2020-04-06 10:36:23	2020-04-06	9	[{"id_menu":6,"count":1}]	18729	pick-up	0	9
47163	2020-04-06 10:36:24	2020-04-06	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	13167	delivery	5	34
47164	2020-04-06 10:53:47	2020-04-06	12	[{"id_menu":1,"count":2}]	18755	delivery	5	17
47165	2020-04-06 10:59:52	2020-04-06	9	[{"id_menu":6,"count":1}]	16422	pick-up	0	9
47166	2020-04-06 11:05:36	2020-04-06	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	9102	delivery	5	38
47167	2020-04-06 11:06:34	2020-04-06	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	18765	delivery	5	31
47168	2020-04-06 11:09:00	2020-04-06	9	[{"id_menu":6,"count":1}]	18701	delivery	5	14
47169	2020-04-06 11:13:50	2020-04-06	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	8822	delivery	5	36
47170	2020-04-06 11:17:04	2020-04-06	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	12198	delivery	5	25
47171	2020-04-06 11:19:10	2020-04-06	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11570	delivery	5	31
47172	2020-04-06 11:28:15	2020-04-06	9	[{"id_menu":6,"count":1}]	18716	delivery	5	14
47173	2020-04-06 11:29:51	2020-04-06	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2210	delivery	5	43
47174	2020-04-06 11:36:34	2020-04-06	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17732	delivery	5	40
47175	2020-04-06 11:36:58	2020-04-06	17	[{"id_menu":4,"count":1}]	2513	pick-up	0	17
47176	2020-04-06 11:49:48	2020-04-06	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16687	delivery	5	39
47177	2020-04-06 11:50:32	2020-04-06	12	[{"id_menu":1,"count":1}]	18703	delivery	5	17
47178	2020-04-06 11:51:16	2020-04-06	9	[{"id_menu":6,"count":1}]	18772	delivery	5	14
47179	2020-04-06 11:55:47	2020-04-06	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	17777	pick-up	0	23
47180	2020-04-06 12:03:31	2020-04-06	12	[{"id_menu":1,"count":1}]	18664	pick-up	0	12
47181	2020-04-06 12:04:55	2020-04-06	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7815	pick-up	0	31
47182	2020-04-06 12:05:18	2020-04-06	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	17329	delivery	5	26
47183	2020-04-06 12:12:52	2020-04-06	9	[{"id_menu":7,"count":1}]	18498	delivery	5	14
47184	2020-04-06 12:24:36	2020-04-06	8	[{"id_menu":5,"count":1}]	3863	pick-up	0	8
47185	2020-04-06 12:28:15	2020-04-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4342	pick-up	0	23
47186	2020-04-06 12:28:53	2020-04-06	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	8010	delivery	5	37
47187	2020-04-06 12:37:12	2020-04-06	14	[{"id_menu":2,"count":1}]	684	pick-up	0	14
47188	2020-04-06 12:48:52	2020-04-06	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2054	pick-up	0	21
47189	2020-04-06 13:18:05	2020-04-06	12	[{"id_menu":1,"count":1}]	18683	delivery	5	17
47190	2020-04-06 13:39:16	2020-04-06	12	[{"id_menu":3,"count":1}]	14176	pick-up	0	12
47191	2020-04-06 13:44:58	2020-04-06	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11402	delivery	5	35
47192	2020-04-06 13:54:57	2020-04-06	9	[{"id_menu":7,"count":1}]	18653	delivery	5	14
47193	2020-04-06 13:58:46	2020-04-06	9	[{"id_menu":7,"count":1}]	1858	pick-up	0	9
47194	2020-04-06 14:00:02	2020-04-06	8	[{"id_menu":5,"count":1}]	7596	delivery	5	13
47195	2020-04-06 14:07:19	2020-04-06	17	[{"id_menu":4,"count":1}]	18753	pick-up	0	17
47196	2020-04-06 14:17:29	2020-04-06	9	[{"id_menu":6,"count":1}]	18713	delivery	5	14
47197	2020-04-06 14:22:06	2020-04-06	17	[{"id_menu":4,"count":1}]	10425	pick-up	0	17
47198	2020-04-06 14:40:02	2020-04-06	8	[{"id_menu":5,"count":1}]	18763	delivery	5	13
47199	2020-04-06 14:40:53	2020-04-06	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	18766	pick-up	0	31
47200	2020-04-06 14:48:44	2020-04-06	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	9908	delivery	5	30
47201	2020-04-06 14:48:48	2020-04-06	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	7450	delivery	5	22
47202	2020-04-06 15:04:41	2020-04-06	9	[{"id_menu":7,"count":1}]	5643	pick-up	0	9
47203	2020-04-06 15:04:46	2020-04-06	17	[{"id_menu":4,"count":1}]	3361	delivery	5	22
47204	2020-04-06 15:10:46	2020-04-06	9	[{"id_menu":7,"count":1}]	18669	delivery	5	14
47205	2020-04-06 15:16:21	2020-04-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	16406	pick-up	0	23
47206	2020-04-06 15:21:43	2020-04-06	9	[{"id_menu":6,"count":1}]	18533	delivery	5	14
47207	2020-04-06 15:29:06	2020-04-06	9	[{"id_menu":6,"count":1}]	17007	delivery	5	14
47208	2020-04-06 15:34:35	2020-04-06	9	[{"id_menu":7,"count":1}]	1656	pick-up	0	9
47209	2020-04-06 15:43:27	2020-04-06	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	18724	delivery	5	26
47210	2020-04-06 15:43:56	2020-04-06	8	[{"id_menu":5,"count":1}]	7382	delivery	5	13
47211	2020-04-06 15:44:17	2020-04-06	9	[{"id_menu":7,"count":1}]	15022	delivery	5	14
47212	2020-04-06 15:46:56	2020-04-06	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	10218	delivery	5	36
47213	2020-04-06 15:47:02	2020-04-06	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	18657	delivery	5	26
47214	2020-04-06 15:55:47	2020-04-06	12	[{"id_menu":1,"count":1}]	2875	delivery	5	17
47215	2020-04-06 16:01:19	2020-04-06	8	[{"id_menu":5,"count":1}]	6575	pick-up	0	8
47216	2020-04-06 16:01:58	2020-04-06	9	[{"id_menu":7,"count":1}]	5116	delivery	5	14
47217	2020-04-06 16:02:36	2020-04-06	9	[{"id_menu":7,"count":1}]	13535	delivery	5	14
47218	2020-04-06 16:27:38	2020-04-06	9	[{"id_menu":6,"count":1}]	3647	pick-up	0	9
47219	2020-04-06 16:29:37	2020-04-06	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	18739	delivery	5	26
47220	2020-04-06 16:34:38	2020-04-06	8	[{"id_menu":5,"count":2}]	14764	pick-up	0	8
47221	2020-04-06 16:38:33	2020-04-06	8	[{"id_menu":5,"count":1}]	7855	delivery	5	13
47222	2020-04-06 16:39:38	2020-04-06	9	[{"id_menu":6,"count":1}]	18656	delivery	5	14
47223	2020-04-06 16:41:22	2020-04-06	9	[{"id_menu":7,"count":1}]	4100	delivery	5	14
47224	2020-04-06 16:48:11	2020-04-06	8	[{"id_menu":5,"count":1}]	18768	delivery	5	13
47225	2020-04-06 16:53:33	2020-04-06	9	[{"id_menu":7,"count":1}]	5886	delivery	5	14
47226	2020-04-06 17:17:33	2020-04-06	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	15837	delivery	5	23
47227	2020-04-06 17:19:08	2020-04-06	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	17467	delivery	5	30
47228	2020-04-06 17:19:28	2020-04-06	17	[{"id_menu":4,"count":2}]	16328	pick-up	0	17
47229	2020-04-06 17:27:14	2020-04-06	8	[{"id_menu":5,"count":1}]	18752	delivery	5	13
47230	2020-04-06 17:27:46	2020-04-06	12	[{"id_menu":3,"count":1}]	18775	delivery	5	17
47231	2020-04-06 17:33:23	2020-04-06	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	2056	pick-up	0	29
47232	2020-04-06 17:35:08	2020-04-06	12	[{"id_menu":1,"count":1}]	18676	delivery	5	17
47233	2020-04-06 17:35:31	2020-04-06	9	[{"id_menu":6,"count":1}]	16742	delivery	5	14
47234	2020-04-06 17:37:49	2020-04-06	8	[{"id_menu":5,"count":1}]	4634	delivery	5	13
47235	2020-04-06 17:37:54	2020-04-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	8322	delivery	5	28
47236	2020-04-06 17:38:19	2020-04-06	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	12596	delivery	5	25
47237	2020-04-06 17:51:21	2020-04-06	17	[{"id_menu":4,"count":1}]	18700	delivery	5	22
47238	2020-04-06 17:52:26	2020-04-06	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	4522	delivery	5	22
47239	2020-04-06 17:59:43	2020-04-06	9	[{"id_menu":7,"count":1}]	683	delivery	5	14
47240	2020-04-06 18:00:54	2020-04-06	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18655	delivery	5	22
47241	2020-04-06 18:31:36	2020-04-06	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	18723	delivery	5	28
47242	2020-04-06 18:33:27	2020-04-06	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	18735	delivery	5	39
47243	2020-04-06 18:53:32	2020-04-06	9	[{"id_menu":7,"count":1}]	5985	delivery	5	14
47244	2020-04-06 18:56:38	2020-04-06	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	18744	pick-up	0	21
47245	2020-04-06 19:02:06	2020-04-06	14	[{"id_menu":2,"count":1}]	4206	pick-up	0	14
47246	2020-04-06 19:04:47	2020-04-06	9	[{"id_menu":6,"count":1}]	18662	delivery	5	14
47247	2020-04-06 19:05:05	2020-04-06	9	[{"id_menu":6,"count":1}]	18725	delivery	5	14
47248	2020-04-06 19:12:23	2020-04-06	9	[{"id_menu":6,"count":1}]	4877	pick-up	0	9
47249	2020-04-06 19:14:41	2020-04-06	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	4396	delivery	5	27
47250	2020-04-06 19:15:07	2020-04-06	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4973	pick-up	0	22
47251	2020-04-06 19:20:28	2020-04-06	12	[{"id_menu":3,"count":1}]	5881	pick-up	0	12
47252	2020-04-06 19:20:55	2020-04-06	17	[{"id_menu":4,"count":1}]	5025	delivery	5	22
47253	2020-04-06 19:35:21	2020-04-06	17	[{"id_menu":4,"count":1}]	1940	pick-up	0	17
47254	2020-04-06 19:37:15	2020-04-06	14	[{"id_menu":2,"count":1}]	16790	pick-up	0	14
47255	2020-04-06 19:41:36	2020-04-06	12	[{"id_menu":1,"count":1}]	4262	delivery	5	17
47256	2020-04-06 19:46:14	2020-04-06	9	[{"id_menu":6,"count":1}]	18689	delivery	5	14
47257	2020-04-06 19:49:12	2020-04-06	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	18692	delivery	5	36
47258	2020-04-06 19:54:06	2020-04-06	14	[{"id_menu":2,"count":1}]	14813	delivery	5	19
47259	2020-04-06 19:58:26	2020-04-06	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	5735	delivery	5	28
47260	2020-04-06 20:01:48	2020-04-06	14	[{"id_menu":2,"count":1}]	18665	delivery	5	19
47261	2020-04-06 20:14:59	2020-04-06	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	13450	pick-up	0	20
47262	2020-04-06 20:26:23	2020-04-06	12	[{"id_menu":1,"count":1}]	18704	pick-up	0	12
47263	2020-04-06 20:27:28	2020-04-06	9	[{"id_menu":7,"count":1}]	11403	delivery	5	14
47264	2020-04-06 20:36:13	2020-04-06	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18742	delivery	5	37
47265	2020-04-06 20:43:44	2020-04-06	9	[{"id_menu":6,"count":1}]	16810	pick-up	0	9
47266	2020-04-06 21:06:29	2020-04-06	9	[{"id_menu":6,"count":1}]	6508	delivery	5	14
47267	2020-04-06 21:07:15	2020-04-06	8	[{"id_menu":5,"count":1}]	15818	delivery	5	13
47268	2020-04-06 21:07:28	2020-04-06	14	[{"id_menu":2,"count":1}]	878	pick-up	0	14
47269	2020-04-06 21:08:11	2020-04-06	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18769	delivery	5	34
47270	2020-04-06 21:11:48	2020-04-06	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	11944	pick-up	0	31
47271	2020-04-06 21:15:12	2020-04-06	17	[{"id_menu":4,"count":1}]	18649	delivery	5	22
47272	2020-04-06 21:17:12	2020-04-06	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16136	delivery	5	49
47273	2020-04-06 21:17:12	2020-04-06	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	10533	delivery	5	26
47274	2020-04-06 21:22:20	2020-04-06	17	[{"id_menu":4,"count":1}]	18659	delivery	5	22
47275	2020-04-06 21:23:26	2020-04-06	9	[{"id_menu":7,"count":1}]	9307	delivery	5	14
47276	2020-04-06 21:33:53	2020-04-06	9	[{"id_menu":7,"count":1}]	1189	pick-up	0	9
47277	2020-04-06 21:41:13	2020-04-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	12098	delivery	5	28
47278	2020-04-06 21:42:46	2020-04-06	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	14651	delivery	5	26
47279	2020-04-06 21:47:19	2020-04-06	17	[{"id_menu":4,"count":1}]	18732	delivery	5	22
47280	2020-04-06 21:48:54	2020-04-06	8	[{"id_menu":5,"count":2}]	18667	delivery	5	13
47281	2020-04-06 21:50:09	2020-04-06	14	[{"id_menu":2,"count":1}]	8054	pick-up	0	14
47282	2020-04-06 21:57:33	2020-04-06	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	17739	delivery	5	40
47283	2020-04-06 22:00:36	2020-04-06	9	[{"id_menu":6,"count":1}]	4700	pick-up	0	9
47284	2020-04-06 22:05:07	2020-04-06	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	18699	delivery	5	31
47285	2020-04-06 22:12:51	2020-04-06	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	18687	delivery	5	27
47286	2020-04-06 22:30:52	2020-04-06	14	[{"id_menu":2,"count":1}]	6301	delivery	5	19
47287	2020-04-06 22:33:47	2020-04-06	8	[{"id_menu":5,"count":1}]	18738	delivery	5	13
47288	2020-04-06 22:51:36	2020-04-06	9	[{"id_menu":7,"count":1}]	18709	delivery	5	14
47289	2020-04-06 22:57:02	2020-04-06	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6221	delivery	5	30
47290	2020-04-06 23:02:14	2020-04-06	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	13352	delivery	5	31
47291	2020-04-06 23:05:50	2020-04-06	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5310	pick-up	0	17
47292	2020-04-06 23:15:08	2020-04-06	8	[{"id_menu":5,"count":2}]	16850	delivery	5	13
47293	2020-04-06 23:16:13	2020-04-06	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	18757	delivery	5	31
47294	2020-04-06 23:18:03	2020-04-06	9	[{"id_menu":7,"count":1}]	2613	pick-up	0	9
47295	2020-04-06 23:20:17	2020-04-06	12	[{"id_menu":3,"count":1}]	8743	pick-up	0	12
47296	2020-04-06 23:25:08	2020-04-06	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3616	pick-up	0	18
47297	2020-04-06 23:31:32	2020-04-06	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	18688	delivery	5	23
47298	2020-04-06 23:31:35	2020-04-06	9	[{"id_menu":7,"count":1}]	18671	delivery	5	14
47299	2020-04-06 23:36:23	2020-04-06	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2289	delivery	5	48
47300	2020-04-06 23:39:02	2020-04-06	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1055	pick-up	0	43
47301	2020-04-06 23:54:26	2020-04-06	9	[{"id_menu":6,"count":1}]	8407	pick-up	0	9
47302	2020-04-06 23:55:26	2020-04-06	9	[{"id_menu":7,"count":1}]	18758	pick-up	0	9
47303	2020-04-06 23:57:22	2020-04-06	9	[{"id_menu":6,"count":1}]	5701	pick-up	0	9
47304	2020-04-06 23:57:30	2020-04-06	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	7258	delivery	5	22
47305	2020-04-06 23:58:27	2020-04-06	17	[{"id_menu":4,"count":1}]	18760	delivery	5	22
47306	2020-04-07 00:11:59	2020-04-07	8	[{"id_menu":5,"count":1}]	9000	delivery	5	13
47307	2020-04-07 00:14:32	2020-04-07	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	13643	pick-up	0	26
47308	2020-04-07 00:33:32	2020-04-07	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	17941	delivery	5	31
47309	2020-04-07 00:47:15	2020-04-07	14	[{"id_menu":2,"count":1}]	11287	delivery	5	19
47310	2020-04-07 00:50:37	2020-04-07	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	9231	pick-up	0	21
47311	2020-04-07 00:51:14	2020-04-07	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	18780	delivery	5	40
47312	2020-04-07 00:54:34	2020-04-07	14	[{"id_menu":2,"count":1}]	14662	pick-up	0	14
47313	2020-04-07 01:05:08	2020-04-07	9	[{"id_menu":7,"count":1}]	18892	delivery	5	14
47314	2020-04-07 01:05:18	2020-04-07	12	[{"id_menu":3,"count":2}]	9029	delivery	5	17
47315	2020-04-07 01:05:24	2020-04-07	14	[{"id_menu":2,"count":1}]	18887	delivery	5	19
47316	2020-04-07 01:07:11	2020-04-07	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	4982	delivery	5	23
47317	2020-04-07 01:12:18	2020-04-07	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	18803	delivery	5	27
47318	2020-04-07 01:18:04	2020-04-07	12	[{"id_menu":3,"count":1}]	18426	pick-up	0	12
47319	2020-04-07 01:19:55	2020-04-07	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	18865	delivery	5	27
47320	2020-04-07 01:23:31	2020-04-07	12	[{"id_menu":1,"count":1}]	2617	delivery	5	17
47321	2020-04-07 01:24:33	2020-04-07	8	[{"id_menu":5,"count":1}]	7606	delivery	5	13
47322	2020-04-07 01:25:25	2020-04-07	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3626	delivery	5	39
47323	2020-04-07 01:27:47	2020-04-07	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	18879	delivery	5	43
47324	2020-04-07 01:43:38	2020-04-07	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9374	delivery	5	48
47325	2020-04-07 01:44:57	2020-04-07	9	[{"id_menu":6,"count":1}]	18842	delivery	5	14
47326	2020-04-07 01:47:24	2020-04-07	9	[{"id_menu":6,"count":1}]	13707	delivery	5	14
47327	2020-04-07 01:53:18	2020-04-07	17	[{"id_menu":4,"count":1}]	2347	pick-up	0	17
47328	2020-04-07 01:57:53	2020-04-07	14	[{"id_menu":2,"count":1}]	11616	delivery	5	19
47329	2020-04-07 02:03:39	2020-04-07	12	[{"id_menu":1,"count":1}]	14081	delivery	5	17
47330	2020-04-07 02:20:24	2020-04-07	38	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1837	delivery	5	43
47331	2020-04-07 02:21:27	2020-04-07	17	[{"id_menu":4,"count":1}]	3123	delivery	5	22
47332	2020-04-07 02:24:49	2020-04-07	8	[{"id_menu":5,"count":1}]	18147	pick-up	0	8
47333	2020-04-07 02:29:46	2020-04-07	12	[{"id_menu":1,"count":1}]	18781	delivery	5	17
47334	2020-04-07 02:38:14	2020-04-07	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	18801	delivery	5	39
47335	2020-04-07 02:43:40	2020-04-07	9	[{"id_menu":7,"count":2}]	18851	delivery	5	14
47336	2020-04-07 03:04:34	2020-04-07	12	[{"id_menu":1,"count":1}]	18830	delivery	5	17
47337	2020-04-07 03:06:27	2020-04-07	12	[{"id_menu":3,"count":1}]	1883	pick-up	0	12
47338	2020-04-07 03:14:33	2020-04-07	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	18816	delivery	5	40
47339	2020-04-07 03:21:21	2020-04-07	12	[{"id_menu":3,"count":1}]	4932	delivery	5	17
47340	2020-04-07 03:28:16	2020-04-07	8	[{"id_menu":5,"count":1}]	541	delivery	5	13
47341	2020-04-07 03:31:28	2020-04-07	8	[{"id_menu":5,"count":1}]	18860	delivery	5	13
47342	2020-04-07 03:33:41	2020-04-07	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3760	delivery	5	52
47343	2020-04-07 03:37:17	2020-04-07	12	[{"id_menu":3,"count":1}]	12447	delivery	5	17
47344	2020-04-07 03:43:17	2020-04-07	8	[{"id_menu":5,"count":1}]	18846	delivery	5	13
47345	2020-04-07 04:09:04	2020-04-07	14	[{"id_menu":2,"count":1}]	13811	delivery	5	19
47346	2020-04-07 04:16:21	2020-04-07	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	6403	delivery	5	30
47347	2020-04-07 04:18:02	2020-04-07	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":3}]	17038	delivery	5	27
47348	2020-04-07 04:20:01	2020-04-07	8	[{"id_menu":5,"count":1}]	3506	delivery	5	13
47349	2020-04-07 04:22:16	2020-04-07	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	3372	pick-up	0	21
47350	2020-04-07 04:24:14	2020-04-07	8	[{"id_menu":5,"count":1}]	5109	delivery	5	13
47351	2020-04-07 04:27:30	2020-04-07	9	[{"id_menu":7,"count":1}]	18859	delivery	5	14
47352	2020-04-07 04:31:02	2020-04-07	17	[{"id_menu":4,"count":1}]	18849	delivery	5	22
47353	2020-04-07 04:34:59	2020-04-07	9	[{"id_menu":6,"count":1}]	18858	delivery	5	14
47354	2020-04-07 04:39:33	2020-04-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	18779	pick-up	0	17
47355	2020-04-07 04:48:13	2020-04-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	13947	delivery	5	28
47356	2020-04-07 04:50:46	2020-04-07	14	[{"id_menu":2,"count":1}]	18133	pick-up	0	14
47357	2020-04-07 05:05:43	2020-04-07	9	[{"id_menu":7,"count":1}]	18896	delivery	5	14
47358	2020-04-07 05:10:58	2020-04-07	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10350	delivery	5	46
47359	2020-04-07 05:11:25	2020-04-07	12	[{"id_menu":3,"count":1}]	6861	delivery	5	17
47360	2020-04-07 05:19:15	2020-04-07	17	[{"id_menu":4,"count":1}]	18814	delivery	5	22
47361	2020-04-07 05:25:52	2020-04-07	9	[{"id_menu":7,"count":1}]	2480	pick-up	0	9
47362	2020-04-07 05:31:57	2020-04-07	12	[{"id_menu":3,"count":1}]	18854	delivery	5	17
47363	2020-04-07 05:33:56	2020-04-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	3012	pick-up	0	21
47364	2020-04-07 05:39:07	2020-04-07	9	[{"id_menu":6,"count":1}]	18857	delivery	5	14
47365	2020-04-07 05:41:23	2020-04-07	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	18869	delivery	5	31
47366	2020-04-07 05:45:43	2020-04-07	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	18791	delivery	5	22
47367	2020-04-07 05:53:38	2020-04-07	9	[{"id_menu":7,"count":2}]	18899	delivery	5	14
47368	2020-04-07 05:55:15	2020-04-07	9	[{"id_menu":6,"count":1}]	12665	delivery	5	14
47369	2020-04-07 06:17:07	2020-04-07	9	[{"id_menu":7,"count":1}]	14411	delivery	5	14
47370	2020-04-07 06:29:23	2020-04-07	9	[{"id_menu":6,"count":1}]	1597	pick-up	0	9
47371	2020-04-07 06:38:10	2020-04-07	17	[{"id_menu":4,"count":1}]	17049	delivery	5	22
47372	2020-04-07 06:41:37	2020-04-07	9	[{"id_menu":6,"count":1}]	10012	delivery	5	14
47373	2020-04-07 06:42:45	2020-04-07	12	[{"id_menu":3,"count":1}]	11385	pick-up	0	12
47374	2020-04-07 06:43:51	2020-04-07	12	[{"id_menu":3,"count":1}]	18783	delivery	5	17
47375	2020-04-07 07:01:00	2020-04-07	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	398	delivery	5	45
47376	2020-04-07 07:01:36	2020-04-07	14	[{"id_menu":2,"count":2}]	6511	pick-up	0	14
47377	2020-04-07 07:07:16	2020-04-07	14	[{"id_menu":2,"count":1}]	1679	pick-up	0	14
47378	2020-04-07 07:10:41	2020-04-07	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5473	pick-up	0	26
47379	2020-04-07 07:27:51	2020-04-07	9	[{"id_menu":6,"count":1}]	1526	delivery	5	14
47380	2020-04-07 07:28:08	2020-04-07	12	[{"id_menu":3,"count":1}]	3751	delivery	5	17
47381	2020-04-07 07:28:25	2020-04-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	14972	pick-up	0	23
47382	2020-04-07 07:39:09	2020-04-07	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	8421	delivery	5	31
47383	2020-04-07 07:40:29	2020-04-07	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	14735	pick-up	0	35
47384	2020-04-07 07:41:15	2020-04-07	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17622	delivery	5	43
47385	2020-04-07 07:43:39	2020-04-07	9	[{"id_menu":7,"count":1}]	18820	delivery	5	14
47386	2020-04-07 07:44:20	2020-04-07	12	[{"id_menu":3,"count":1}]	3544	pick-up	0	12
47387	2020-04-07 07:48:10	2020-04-07	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	5030	delivery	5	26
47388	2020-04-07 07:51:32	2020-04-07	12	[{"id_menu":3,"count":1}]	15310	delivery	5	17
47389	2020-04-07 07:52:47	2020-04-07	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	18283	delivery	5	27
47390	2020-04-07 07:53:01	2020-04-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	18792	delivery	5	26
47391	2020-04-07 07:53:58	2020-04-07	12	[{"id_menu":1,"count":1}]	18468	delivery	5	17
47392	2020-04-07 08:03:50	2020-04-07	14	[{"id_menu":2,"count":1}]	18847	delivery	5	19
47393	2020-04-07 08:08:20	2020-04-07	8	[{"id_menu":5,"count":1}]	7490	delivery	5	13
47394	2020-04-07 08:11:59	2020-04-07	12	[{"id_menu":3,"count":1}]	12962	pick-up	0	12
47395	2020-04-07 08:20:57	2020-04-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	18903	delivery	5	22
47396	2020-04-07 08:28:27	2020-04-07	12	[{"id_menu":3,"count":1}]	12005	delivery	5	17
47397	2020-04-07 08:36:43	2020-04-07	14	[{"id_menu":2,"count":1}]	18784	pick-up	0	14
47398	2020-04-07 08:37:01	2020-04-07	8	[{"id_menu":5,"count":1}]	4475	delivery	5	13
47399	2020-04-07 08:38:18	2020-04-07	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5003	delivery	5	36
47400	2020-04-07 08:49:41	2020-04-07	9	[{"id_menu":7,"count":1}]	18821	delivery	5	14
47401	2020-04-07 08:50:19	2020-04-07	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17839	delivery	5	43
47402	2020-04-07 09:15:10	2020-04-07	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	16834	delivery	5	26
47403	2020-04-07 09:16:20	2020-04-07	14	[{"id_menu":2,"count":1}]	4094	delivery	5	19
47404	2020-04-07 09:34:09	2020-04-07	9	[{"id_menu":7,"count":1}]	9419	delivery	5	14
47405	2020-04-07 09:34:42	2020-04-07	9	[{"id_menu":7,"count":1}]	16633	delivery	5	14
47406	2020-04-07 09:35:24	2020-04-07	8	[{"id_menu":5,"count":1}]	15400	pick-up	0	8
47407	2020-04-07 09:37:05	2020-04-07	12	[{"id_menu":1,"count":1}]	857	pick-up	0	12
47408	2020-04-07 09:43:34	2020-04-07	9	[{"id_menu":7,"count":1}]	18819	delivery	5	14
47409	2020-04-07 10:01:31	2020-04-07	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	18813	delivery	5	56
47410	2020-04-07 10:04:30	2020-04-07	9	[{"id_menu":7,"count":1}]	581	delivery	5	14
47411	2020-04-07 10:05:17	2020-04-07	9	[{"id_menu":7,"count":1}]	18867	delivery	5	14
47412	2020-04-07 10:08:23	2020-04-07	12	[{"id_menu":3,"count":1}]	18825	pick-up	0	12
47413	2020-04-07 10:12:12	2020-04-07	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	14644	delivery	5	27
47414	2020-04-07 10:12:59	2020-04-07	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	18852	delivery	5	36
47415	2020-04-07 10:17:16	2020-04-07	9	[{"id_menu":7,"count":1}]	18040	delivery	5	14
47416	2020-04-07 10:17:53	2020-04-07	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	18853	delivery	5	57
47417	2020-04-07 10:36:18	2020-04-07	12	[{"id_menu":1,"count":1}]	477	delivery	5	17
47418	2020-04-07 10:51:01	2020-04-07	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17251	delivery	5	31
47419	2020-04-07 10:55:27	2020-04-07	12	[{"id_menu":1,"count":1}]	17527	delivery	5	17
47420	2020-04-07 11:02:20	2020-04-07	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	188	pick-up	0	20
47421	2020-04-07 11:21:47	2020-04-07	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	18815	delivery	5	26
47422	2020-04-07 11:23:51	2020-04-07	8	[{"id_menu":5,"count":1}]	18856	pick-up	0	8
47423	2020-04-07 11:31:48	2020-04-07	14	[{"id_menu":2,"count":1}]	14354	delivery	5	19
47424	2020-04-07 11:31:57	2020-04-07	17	[{"id_menu":4,"count":1}]	13026	pick-up	0	17
47425	2020-04-07 11:36:26	2020-04-07	17	[{"id_menu":4,"count":1}]	14969	delivery	5	22
47426	2020-04-07 11:36:46	2020-04-07	9	[{"id_menu":7,"count":1}]	18811	delivery	5	14
47427	2020-04-07 11:43:56	2020-04-07	9	[{"id_menu":6,"count":1}]	15938	delivery	5	14
47428	2020-04-07 11:47:28	2020-04-07	12	[{"id_menu":3,"count":1}]	394	pick-up	0	12
47429	2020-04-07 11:59:24	2020-04-07	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8977	delivery	5	57
47430	2020-04-07 12:01:16	2020-04-07	8	[{"id_menu":5,"count":1}]	13555	pick-up	0	8
47431	2020-04-07 12:04:47	2020-04-07	9	[{"id_menu":7,"count":1}]	13441	delivery	5	14
47432	2020-04-07 12:05:42	2020-04-07	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	8521	pick-up	0	21
47433	2020-04-07 12:06:58	2020-04-07	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4638	delivery	5	31
47434	2020-04-07 12:07:34	2020-04-07	8	[{"id_menu":5,"count":1}]	18839	pick-up	0	8
47435	2020-04-07 12:09:47	2020-04-07	14	[{"id_menu":2,"count":1}]	18890	pick-up	0	14
47436	2020-04-07 12:14:47	2020-04-07	9	[{"id_menu":7,"count":1}]	18797	delivery	5	14
47437	2020-04-07 12:21:28	2020-04-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18822	delivery	5	23
47438	2020-04-07 12:21:39	2020-04-07	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	14290	pick-up	0	21
47439	2020-04-07 12:23:28	2020-04-07	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	18893	delivery	5	46
47440	2020-04-07 12:23:35	2020-04-07	14	[{"id_menu":2,"count":1}]	18844	delivery	5	19
47441	2020-04-07 12:26:46	2020-04-07	17	[{"id_menu":4,"count":1}]	18873	delivery	5	22
47442	2020-04-07 12:34:54	2020-04-07	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	18798	pick-up	0	40
47443	2020-04-07 12:37:48	2020-04-07	9	[{"id_menu":7,"count":1}]	4107	delivery	5	14
47444	2020-04-07 12:56:50	2020-04-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	17100	delivery	5	28
47445	2020-04-07 13:04:29	2020-04-07	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1316	pick-up	0	26
47446	2020-04-07 13:12:53	2020-04-07	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	12254	delivery	5	26
47447	2020-04-07 13:21:02	2020-04-07	17	[{"id_menu":4,"count":1}]	5411	delivery	5	22
47448	2020-04-07 13:26:53	2020-04-07	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	229	pick-up	0	26
47449	2020-04-07 13:34:38	2020-04-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6965	pick-up	0	23
47450	2020-04-07 13:39:20	2020-04-07	14	[{"id_menu":2,"count":1}]	13381	delivery	5	19
47451	2020-04-07 14:01:45	2020-04-07	8	[{"id_menu":5,"count":1}]	3459	pick-up	0	8
47452	2020-04-07 14:04:11	2020-04-07	12	[{"id_menu":3,"count":1}]	1687	pick-up	0	12
47453	2020-04-07 14:10:09	2020-04-07	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	18894	delivery	5	31
47454	2020-04-07 14:12:05	2020-04-07	8	[{"id_menu":5,"count":1}]	11838	delivery	5	13
47455	2020-04-07 14:14:12	2020-04-07	14	[{"id_menu":2,"count":1}]	3425	delivery	5	19
47456	2020-04-07 14:15:33	2020-04-07	9	[{"id_menu":6,"count":2}]	15547	delivery	5	14
47457	2020-04-07 14:22:34	2020-04-07	8	[{"id_menu":5,"count":1}]	18900	delivery	5	13
47458	2020-04-07 14:25:49	2020-04-07	17	[{"id_menu":4,"count":1}]	18831	delivery	5	22
47459	2020-04-07 14:38:00	2020-04-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2543	pick-up	0	21
47460	2020-04-07 14:51:52	2020-04-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1618	pick-up	0	23
47461	2020-04-07 15:01:27	2020-04-07	14	[{"id_menu":2,"count":1}]	11946	delivery	5	19
47462	2020-04-07 15:03:50	2020-04-07	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9058	delivery	5	34
47463	2020-04-07 15:04:40	2020-04-07	12	[{"id_menu":3,"count":2}]	18895	delivery	5	17
47464	2020-04-07 15:04:57	2020-04-07	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	12231	delivery	5	36
47465	2020-04-07 15:07:48	2020-04-07	9	[{"id_menu":6,"count":1}]	18878	delivery	5	14
47466	2020-04-07 15:12:02	2020-04-07	9	[{"id_menu":6,"count":1}]	15750	delivery	5	14
47467	2020-04-07 15:12:17	2020-04-07	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	18808	delivery	5	40
47468	2020-04-07 15:15:15	2020-04-07	17	[{"id_menu":4,"count":1}]	7306	pick-up	0	17
47469	2020-04-07 15:17:27	2020-04-07	14	[{"id_menu":2,"count":1}]	12095	pick-up	0	14
47470	2020-04-07 15:46:59	2020-04-07	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	16911	delivery	5	31
47471	2020-04-07 15:48:56	2020-04-07	12	[{"id_menu":3,"count":1}]	18881	delivery	5	17
47472	2020-04-07 15:54:34	2020-04-07	12	[{"id_menu":3,"count":1}]	3040	delivery	5	17
47473	2020-04-07 16:01:31	2020-04-07	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	15365	delivery	5	36
47474	2020-04-07 16:02:50	2020-04-07	9	[{"id_menu":7,"count":1}]	5192	delivery	5	14
47475	2020-04-07 16:03:46	2020-04-07	9	[{"id_menu":6,"count":1}]	3493	delivery	5	14
47476	2020-04-07 16:10:19	2020-04-07	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	11418	delivery	5	39
47477	2020-04-07 16:12:33	2020-04-07	14	[{"id_menu":2,"count":1}]	3230	pick-up	0	14
47478	2020-04-07 16:18:06	2020-04-07	8	[{"id_menu":5,"count":1}]	18862	delivery	5	13
47479	2020-04-07 16:33:40	2020-04-07	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18871	delivery	5	39
47480	2020-04-07 16:48:33	2020-04-07	17	[{"id_menu":4,"count":1}]	13427	pick-up	0	17
47481	2020-04-07 16:50:31	2020-04-07	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	600	pick-up	0	38
47482	2020-04-07 16:50:34	2020-04-07	14	[{"id_menu":2,"count":1}]	18818	delivery	5	19
47483	2020-04-07 17:06:59	2020-04-07	14	[{"id_menu":2,"count":1}]	18901	delivery	5	19
47484	2020-04-07 17:09:30	2020-04-07	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18835	delivery	5	37
47485	2020-04-07 17:18:37	2020-04-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12043	pick-up	0	18
47486	2020-04-07 17:26:02	2020-04-07	9	[{"id_menu":6,"count":1}]	11401	pick-up	0	9
47487	2020-04-07 17:26:10	2020-04-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	8519	pick-up	0	21
47488	2020-04-07 17:26:47	2020-04-07	8	[{"id_menu":5,"count":1}]	13619	delivery	5	13
47489	2020-04-07 17:32:36	2020-04-07	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	18875	delivery	5	48
47490	2020-04-07 17:33:31	2020-04-07	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	3835	delivery	5	40
47491	2020-04-07 17:41:17	2020-04-07	9	[{"id_menu":6,"count":1}]	13303	delivery	5	14
47492	2020-04-07 17:42:32	2020-04-07	17	[{"id_menu":4,"count":1}]	9749	pick-up	0	17
47493	2020-04-07 17:59:02	2020-04-07	17	[{"id_menu":4,"count":2}]	15292	pick-up	0	17
47494	2020-04-07 18:02:52	2020-04-07	9	[{"id_menu":7,"count":1}]	8403	delivery	5	14
47495	2020-04-07 18:10:28	2020-04-07	12	[{"id_menu":1,"count":1}]	18824	delivery	5	17
47496	2020-04-07 18:10:36	2020-04-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	3066	pick-up	0	23
47497	2020-04-07 18:10:46	2020-04-07	12	[{"id_menu":1,"count":2}]	9303	pick-up	0	12
47498	2020-04-07 18:14:48	2020-04-07	8	[{"id_menu":5,"count":1}]	18848	delivery	5	13
47499	2020-04-07 18:28:30	2020-04-07	12	[{"id_menu":3,"count":1}]	18807	pick-up	0	12
47500	2020-04-07 18:28:51	2020-04-07	12	[{"id_menu":3,"count":1}]	8887	delivery	5	17
47501	2020-04-07 18:30:59	2020-04-07	8	[{"id_menu":5,"count":1}]	18876	pick-up	0	8
47502	2020-04-07 18:31:07	2020-04-07	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":2}]	1352	pick-up	0	21
47503	2020-04-07 18:31:17	2020-04-07	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18827	delivery	5	22
47504	2020-04-07 18:35:26	2020-04-07	14	[{"id_menu":2,"count":1}]	270	delivery	5	19
47505	2020-04-07 19:03:10	2020-04-07	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	18882	delivery	5	45
47506	2020-04-07 19:14:32	2020-04-07	12	[{"id_menu":1,"count":1}]	18785	delivery	5	17
47507	2020-04-07 19:20:36	2020-04-07	9	[{"id_menu":6,"count":2}]	2390	delivery	5	14
47508	2020-04-07 19:31:42	2020-04-07	14	[{"id_menu":2,"count":1}]	7211	delivery	5	19
47509	2020-04-07 19:34:22	2020-04-07	8	[{"id_menu":5,"count":1}]	3234	delivery	5	13
47510	2020-04-07 19:34:50	2020-04-07	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18810	pick-up	0	17
47511	2020-04-07 19:40:44	2020-04-07	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	10823	delivery	5	31
47512	2020-04-07 19:42:51	2020-04-07	14	[{"id_menu":2,"count":1}]	15614	delivery	5	19
47513	2020-04-07 20:00:05	2020-04-07	9	[{"id_menu":7,"count":1}]	6445	delivery	5	14
47514	2020-04-07 20:01:27	2020-04-07	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	18836	delivery	5	31
47515	2020-04-07 20:07:16	2020-04-07	17	[{"id_menu":4,"count":1}]	18837	delivery	5	22
47516	2020-04-07 20:09:10	2020-04-07	17	[{"id_menu":4,"count":1}]	18888	delivery	5	22
47517	2020-04-07 20:22:48	2020-04-07	17	[{"id_menu":4,"count":1}]	18864	delivery	5	22
47518	2020-04-07 20:26:48	2020-04-07	17	[{"id_menu":4,"count":1}]	5860	delivery	5	22
47519	2020-04-07 20:31:57	2020-04-07	12	[{"id_menu":1,"count":1}]	11451	delivery	5	17
47520	2020-04-07 20:32:02	2020-04-07	12	[{"id_menu":1,"count":1}]	14558	delivery	5	17
47521	2020-04-07 20:42:07	2020-04-07	17	[{"id_menu":4,"count":1}]	11791	pick-up	0	17
47522	2020-04-07 20:55:44	2020-04-07	8	[{"id_menu":5,"count":1}]	18886	pick-up	0	8
47523	2020-04-07 21:05:59	2020-04-07	46	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	6192	delivery	5	51
47524	2020-04-07 21:17:42	2020-04-07	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	6390	delivery	5	34
47525	2020-04-07 21:31:55	2020-04-07	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	18795	delivery	5	57
47526	2020-04-07 21:37:27	2020-04-07	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	4503	delivery	5	23
47527	2020-04-07 21:44:02	2020-04-07	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6287	delivery	5	22
47528	2020-04-07 21:47:13	2020-04-07	9	[{"id_menu":7,"count":2}]	18682	delivery	5	14
47529	2020-04-07 21:56:13	2020-04-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	18782	delivery	5	28
47530	2020-04-07 22:02:39	2020-04-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	3540	delivery	5	26
47531	2020-04-07 22:07:42	2020-04-07	8	[{"id_menu":5,"count":1}]	18840	delivery	5	13
47532	2020-04-07 22:10:14	2020-04-07	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	44	pick-up	0	29
47533	2020-04-07 22:21:32	2020-04-07	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	17363	delivery	5	27
47534	2020-04-07 22:28:25	2020-04-07	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	11187	delivery	5	26
47535	2020-04-07 22:35:36	2020-04-07	17	[{"id_menu":4,"count":1}]	18880	pick-up	0	17
47536	2020-04-07 22:38:19	2020-04-07	12	[{"id_menu":1,"count":1}]	11391	delivery	5	17
47537	2020-04-07 22:38:49	2020-04-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	61	delivery	5	26
47538	2020-04-07 22:42:56	2020-04-07	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	16594	delivery	5	31
47539	2020-04-07 22:48:19	2020-04-07	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3318	pick-up	0	25
47540	2020-04-07 22:52:18	2020-04-07	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	18828	delivery	5	29
47541	2020-04-07 23:00:40	2020-04-07	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	18885	delivery	5	26
47542	2020-04-07 23:02:49	2020-04-07	9	[{"id_menu":7,"count":1}]	4605	delivery	5	14
47543	2020-04-07 23:03:09	2020-04-07	9	[{"id_menu":7,"count":1}]	18861	delivery	5	14
47544	2020-04-07 23:06:08	2020-04-07	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11374	delivery	5	36
47545	2020-04-07 23:08:08	2020-04-07	49	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2668	delivery	5	54
47546	2020-04-07 23:08:46	2020-04-07	9	[{"id_menu":7,"count":1}]	3006	delivery	5	14
47547	2020-04-07 23:17:11	2020-04-07	14	[{"id_menu":2,"count":1}]	9175	delivery	5	19
47548	2020-04-07 23:21:14	2020-04-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6462	delivery	5	23
47549	2020-04-07 23:23:41	2020-04-07	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	18823	delivery	5	37
47550	2020-04-07 23:26:03	2020-04-07	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	18834	delivery	5	42
47551	2020-04-07 23:28:37	2020-04-07	12	[{"id_menu":1,"count":1}]	16785	delivery	5	17
47552	2020-04-07 23:29:39	2020-04-07	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11590	delivery	5	31
47553	2020-04-07 23:31:33	2020-04-07	9	[{"id_menu":6,"count":1}]	11709	delivery	5	14
47554	2020-04-07 23:37:59	2020-04-07	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18870	delivery	5	22
47555	2020-04-07 23:38:14	2020-04-07	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18863	delivery	5	36
47556	2020-04-07 23:41:23	2020-04-07	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	18883	delivery	5	36
47557	2020-04-07 23:45:52	2020-04-07	9	[{"id_menu":7,"count":1}]	76	delivery	5	14
47558	2020-04-07 23:48:48	2020-04-07	9	[{"id_menu":6,"count":1}]	5647	delivery	5	14
47559	2020-04-07 23:49:55	2020-04-07	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18794	delivery	5	48
47560	2020-04-08 00:07:27	2020-04-08	17	[{"id_menu":4,"count":1}]	10880	pick-up	0	17
47561	2020-04-08 00:08:45	2020-04-08	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	18968	delivery	5	27
47562	2020-04-08 00:15:41	2020-04-08	14	[{"id_menu":2,"count":1}]	17325	delivery	5	19
47563	2020-04-08 00:22:16	2020-04-08	9	[{"id_menu":7,"count":1}]	18947	delivery	5	14
47564	2020-04-08 00:27:09	2020-04-08	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	13720	delivery	5	30
47565	2020-04-08 00:35:04	2020-04-08	12	[{"id_menu":3,"count":1}]	2047	pick-up	0	12
47566	2020-04-08 00:40:12	2020-04-08	14	[{"id_menu":2,"count":1}]	10174	pick-up	0	14
47567	2020-04-08 00:41:35	2020-04-08	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	11041	delivery	5	36
47568	2020-04-08 00:48:12	2020-04-08	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2287	pick-up	0	25
47569	2020-04-08 00:58:56	2020-04-08	12	[{"id_menu":1,"count":1}]	5387	delivery	5	17
47570	2020-04-08 01:02:09	2020-04-08	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	20	pick-up	0	26
47571	2020-04-08 01:06:18	2020-04-08	14	[{"id_menu":2,"count":1}]	6407	delivery	5	19
47572	2020-04-08 01:08:35	2020-04-08	14	[{"id_menu":2,"count":1}]	8182	delivery	5	19
47573	2020-04-08 01:13:31	2020-04-08	14	[{"id_menu":2,"count":1}]	4054	pick-up	0	14
47574	2020-04-08 01:15:35	2020-04-08	12	[{"id_menu":1,"count":1}]	11005	pick-up	0	12
47575	2020-04-08 01:15:36	2020-04-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	18906	pick-up	0	23
47576	2020-04-08 01:17:25	2020-04-08	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	18375	delivery	5	31
47577	2020-04-08 01:19:27	2020-04-08	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	4564	delivery	5	37
47578	2020-04-08 01:19:31	2020-04-08	8	[{"id_menu":5,"count":1}]	19004	delivery	5	13
47579	2020-04-08 01:28:40	2020-04-08	8	[{"id_menu":5,"count":1}]	18957	delivery	5	13
47580	2020-04-08 01:32:23	2020-04-08	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	9060	pick-up	0	34
47581	2020-04-08 01:32:40	2020-04-08	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18910	delivery	5	52
47582	2020-04-08 01:33:07	2020-04-08	9	[{"id_menu":6,"count":1}]	16858	pick-up	0	9
47583	2020-04-08 01:33:40	2020-04-08	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":3}]	8834	delivery	5	31
47584	2020-04-08 01:35:56	2020-04-08	8	[{"id_menu":5,"count":1}]	5979	delivery	5	13
47585	2020-04-08 01:41:42	2020-04-08	8	[{"id_menu":5,"count":1}]	18956	delivery	5	13
47586	2020-04-08 01:43:18	2020-04-08	14	[{"id_menu":2,"count":1}]	3711	pick-up	0	14
47587	2020-04-08 01:54:29	2020-04-08	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	519	pick-up	0	32
47588	2020-04-08 02:00:54	2020-04-08	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	13221	pick-up	0	21
47589	2020-04-08 02:01:37	2020-04-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18990	delivery	5	22
47590	2020-04-08 02:05:22	2020-04-08	12	[{"id_menu":3,"count":1}]	1464	delivery	5	17
47591	2020-04-08 02:06:49	2020-04-08	12	[{"id_menu":3,"count":1}]	19005	delivery	5	17
47592	2020-04-08 02:08:51	2020-04-08	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	17667	delivery	5	26
47593	2020-04-08 02:16:07	2020-04-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	15407	delivery	5	22
47594	2020-04-08 02:24:40	2020-04-08	9	[{"id_menu":7,"count":1}]	18993	delivery	5	14
47595	2020-04-08 02:26:29	2020-04-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	217	pick-up	0	23
47596	2020-04-08 02:34:40	2020-04-08	8	[{"id_menu":5,"count":2}]	19039	delivery	5	13
47597	2020-04-08 02:35:21	2020-04-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	14686	delivery	5	28
47598	2020-04-08 02:35:48	2020-04-08	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14820	delivery	5	36
47599	2020-04-08 02:37:17	2020-04-08	9	[{"id_menu":6,"count":1}]	14921	pick-up	0	9
47600	2020-04-08 02:37:25	2020-04-08	8	[{"id_menu":5,"count":1}]	18915	delivery	5	13
47601	2020-04-08 02:39:47	2020-04-08	9	[{"id_menu":7,"count":1}]	17337	delivery	5	14
47602	2020-04-08 02:42:03	2020-04-08	9	[{"id_menu":6,"count":1}]	18964	pick-up	0	9
47603	2020-04-08 02:57:23	2020-04-08	12	[{"id_menu":3,"count":1}]	10644	delivery	5	17
47604	2020-04-08 02:57:40	2020-04-08	9	[{"id_menu":7,"count":1}]	9381	delivery	5	14
47605	2020-04-08 03:05:32	2020-04-08	12	[{"id_menu":1,"count":1}]	18944	delivery	5	17
47606	2020-04-08 03:06:23	2020-04-08	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	8202	delivery	5	22
47607	2020-04-08 03:08:14	2020-04-08	17	[{"id_menu":4,"count":1}]	7261	delivery	5	22
47608	2020-04-08 03:10:10	2020-04-08	14	[{"id_menu":2,"count":1}]	9243	delivery	5	19
47609	2020-04-08 03:10:18	2020-04-08	39	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	15155	delivery	5	44
47610	2020-04-08 03:11:44	2020-04-08	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	10062	delivery	5	26
47611	2020-04-08 03:12:45	2020-04-08	9	[{"id_menu":6,"count":1}]	19043	delivery	5	14
47612	2020-04-08 03:19:51	2020-04-08	9	[{"id_menu":6,"count":1}]	12495	delivery	5	14
47613	2020-04-08 03:32:03	2020-04-08	9	[{"id_menu":6,"count":1}]	13520	delivery	5	14
47614	2020-04-08 03:43:44	2020-04-08	8	[{"id_menu":5,"count":1}]	7638	delivery	5	13
47615	2020-04-08 03:49:49	2020-04-08	12	[{"id_menu":1,"count":1}]	5822	delivery	5	17
47616	2020-04-08 03:55:54	2020-04-08	9	[{"id_menu":6,"count":1}]	18911	delivery	5	14
47617	2020-04-08 04:06:16	2020-04-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	16483	pick-up	0	23
47618	2020-04-08 04:10:43	2020-04-08	9	[{"id_menu":7,"count":1}]	18907	delivery	5	14
47619	2020-04-08 04:17:51	2020-04-08	17	[{"id_menu":4,"count":1}]	18905	pick-up	0	17
47620	2020-04-08 04:22:10	2020-04-08	12	[{"id_menu":3,"count":1}]	18934	delivery	5	17
47621	2020-04-08 04:23:02	2020-04-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8781	delivery	5	23
47622	2020-04-08 04:30:59	2020-04-08	12	[{"id_menu":1,"count":1}]	126	pick-up	0	12
47623	2020-04-08 04:31:06	2020-04-08	12	[{"id_menu":3,"count":1}]	18998	delivery	5	17
47624	2020-04-08 04:48:40	2020-04-08	17	[{"id_menu":4,"count":1}]	9040	delivery	5	22
47625	2020-04-08 04:51:21	2020-04-08	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":3}]	12359	delivery	5	22
47626	2020-04-08 04:53:48	2020-04-08	9	[{"id_menu":6,"count":1}]	13473	delivery	5	14
47627	2020-04-08 05:01:36	2020-04-08	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	19025	delivery	5	31
47628	2020-04-08 05:05:35	2020-04-08	12	[{"id_menu":1,"count":2}]	13794	delivery	5	17
47629	2020-04-08 05:13:46	2020-04-08	12	[{"id_menu":3,"count":1}]	3524	pick-up	0	12
47630	2020-04-08 05:19:40	2020-04-08	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	806	pick-up	0	21
47631	2020-04-08 05:23:16	2020-04-08	9	[{"id_menu":6,"count":1}]	18936	delivery	5	14
47632	2020-04-08 05:26:01	2020-04-08	17	[{"id_menu":4,"count":1}]	19038	delivery	5	22
47633	2020-04-08 05:29:15	2020-04-08	17	[{"id_menu":4,"count":1}]	7260	pick-up	0	17
47634	2020-04-08 05:31:13	2020-04-08	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11458	pick-up	0	17
47635	2020-04-08 05:32:28	2020-04-08	17	[{"id_menu":4,"count":1}]	19042	pick-up	0	17
47636	2020-04-08 05:34:02	2020-04-08	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	5928	delivery	5	25
47637	2020-04-08 05:36:02	2020-04-08	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	18937	delivery	5	27
47638	2020-04-08 05:37:05	2020-04-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	18981	pick-up	0	23
47639	2020-04-08 05:40:44	2020-04-08	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	9355	pick-up	0	22
47640	2020-04-08 05:43:52	2020-04-08	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	15114	delivery	5	29
47641	2020-04-08 05:44:40	2020-04-08	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	2951	delivery	5	31
47642	2020-04-08 06:00:07	2020-04-08	12	[{"id_menu":3,"count":1}]	18952	delivery	5	17
47643	2020-04-08 06:05:47	2020-04-08	17	[{"id_menu":4,"count":1}]	18959	delivery	5	22
47644	2020-04-08 06:08:14	2020-04-08	9	[{"id_menu":6,"count":1}]	17817	delivery	5	14
47645	2020-04-08 06:10:09	2020-04-08	14	[{"id_menu":2,"count":1}]	4176	delivery	5	19
47646	2020-04-08 06:12:44	2020-04-08	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9839	delivery	5	30
47647	2020-04-08 06:16:46	2020-04-08	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16147	delivery	5	43
47648	2020-04-08 06:17:05	2020-04-08	14	[{"id_menu":2,"count":2}]	3172	pick-up	0	14
47649	2020-04-08 06:17:53	2020-04-08	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	16346	delivery	5	22
47650	2020-04-08 06:19:21	2020-04-08	12	[{"id_menu":3,"count":1}]	4248	pick-up	0	12
47651	2020-04-08 06:22:36	2020-04-08	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1435	pick-up	0	25
47652	2020-04-08 06:25:53	2020-04-08	14	[{"id_menu":2,"count":1}]	173	pick-up	0	14
47653	2020-04-08 06:30:30	2020-04-08	9	[{"id_menu":6,"count":1}]	18983	delivery	5	14
47654	2020-04-08 06:39:42	2020-04-08	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	11156	pick-up	0	21
47655	2020-04-08 06:41:42	2020-04-08	8	[{"id_menu":5,"count":1}]	18977	delivery	5	13
47656	2020-04-08 06:53:48	2020-04-08	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	11635	delivery	5	31
47657	2020-04-08 06:58:17	2020-04-08	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18302	delivery	5	31
47658	2020-04-08 06:59:19	2020-04-08	14	[{"id_menu":2,"count":1}]	1919	pick-up	0	14
47659	2020-04-08 07:01:14	2020-04-08	17	[{"id_menu":4,"count":1}]	18979	delivery	5	22
47660	2020-04-08 07:03:38	2020-04-08	8	[{"id_menu":5,"count":1}]	18916	delivery	5	13
47661	2020-04-08 07:04:05	2020-04-08	14	[{"id_menu":2,"count":1}]	4434	delivery	5	19
47662	2020-04-08 07:05:19	2020-04-08	14	[{"id_menu":2,"count":1}]	13844	delivery	5	19
47663	2020-04-08 07:17:00	2020-04-08	9	[{"id_menu":7,"count":1}]	18955	delivery	5	14
47664	2020-04-08 07:28:56	2020-04-08	17	[{"id_menu":4,"count":1}]	16165	pick-up	0	17
47665	2020-04-08 07:29:38	2020-04-08	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	19003	delivery	5	31
47666	2020-04-08 07:33:41	2020-04-08	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2579	delivery	5	26
47667	2020-04-08 07:38:27	2020-04-08	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3912	delivery	5	42
47668	2020-04-08 07:47:12	2020-04-08	12	[{"id_menu":1,"count":1}]	12760	delivery	5	17
47669	2020-04-08 07:47:26	2020-04-08	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2367	pick-up	0	20
47670	2020-04-08 07:53:46	2020-04-08	9	[{"id_menu":6,"count":1}]	18922	delivery	5	14
47671	2020-04-08 07:54:59	2020-04-08	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	19049	delivery	5	35
47672	2020-04-08 07:56:04	2020-04-08	14	[{"id_menu":2,"count":1}]	18144	pick-up	0	14
47673	2020-04-08 07:57:57	2020-04-08	12	[{"id_menu":1,"count":1}]	1307	delivery	5	17
47674	2020-04-08 08:13:56	2020-04-08	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4981	pick-up	0	34
47675	2020-04-08 08:15:10	2020-04-08	14	[{"id_menu":2,"count":1}]	18999	delivery	5	19
47676	2020-04-08 08:15:28	2020-04-08	9	[{"id_menu":7,"count":1}]	6615	pick-up	0	9
47677	2020-04-08 08:16:54	2020-04-08	9	[{"id_menu":6,"count":1}]	18973	delivery	5	14
47678	2020-04-08 08:18:29	2020-04-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	18940	delivery	5	23
47679	2020-04-08 08:22:32	2020-04-08	12	[{"id_menu":3,"count":1}]	771	pick-up	0	12
47680	2020-04-08 08:26:36	2020-04-08	8	[{"id_menu":5,"count":1}]	213	pick-up	0	8
47681	2020-04-08 08:31:14	2020-04-08	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7416	delivery	5	45
47682	2020-04-08 08:34:04	2020-04-08	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	18927	delivery	5	26
47683	2020-04-08 08:37:18	2020-04-08	12	[{"id_menu":3,"count":1}]	788	pick-up	0	12
47684	2020-04-08 08:41:48	2020-04-08	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1780	pick-up	0	21
47685	2020-04-08 08:42:11	2020-04-08	17	[{"id_menu":4,"count":1}]	15417	delivery	5	22
47686	2020-04-08 08:52:04	2020-04-08	8	[{"id_menu":5,"count":1}]	18970	delivery	5	13
47687	2020-04-08 08:54:43	2020-04-08	12	[{"id_menu":1,"count":1}]	18946	delivery	5	17
47688	2020-04-08 08:56:03	2020-04-08	8	[{"id_menu":5,"count":1}]	19048	delivery	5	13
47689	2020-04-08 09:01:24	2020-04-08	9	[{"id_menu":7,"count":1}]	3048	delivery	5	14
47690	2020-04-08 09:07:24	2020-04-08	9	[{"id_menu":6,"count":1}]	2884	delivery	5	14
47691	2020-04-08 09:11:08	2020-04-08	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19007	delivery	5	31
47692	2020-04-08 09:16:42	2020-04-08	14	[{"id_menu":2,"count":1}]	19002	delivery	5	19
47693	2020-04-08 09:19:38	2020-04-08	17	[{"id_menu":4,"count":1}]	14745	delivery	5	22
47694	2020-04-08 09:19:42	2020-04-08	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	13012	delivery	5	39
47695	2020-04-08 09:26:50	2020-04-08	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	9449	delivery	5	40
47696	2020-04-08 09:27:30	2020-04-08	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10679	pick-up	0	26
47697	2020-04-08 09:35:16	2020-04-08	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1577	pick-up	0	21
47698	2020-04-08 09:36:56	2020-04-08	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	17227	delivery	5	40
47699	2020-04-08 09:38:16	2020-04-08	9	[{"id_menu":7,"count":1}]	6435	delivery	5	14
47700	2020-04-08 09:40:20	2020-04-08	14	[{"id_menu":2,"count":1}]	14831	delivery	5	19
47701	2020-04-08 09:42:27	2020-04-08	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19033	delivery	5	51
47702	2020-04-08 09:44:24	2020-04-08	8	[{"id_menu":5,"count":1}]	1849	pick-up	0	8
47703	2020-04-08 09:50:06	2020-04-08	12	[{"id_menu":1,"count":1}]	17081	delivery	5	17
47704	2020-04-08 09:58:47	2020-04-08	39	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10161	delivery	5	44
47705	2020-04-08 10:01:48	2020-04-08	8	[{"id_menu":5,"count":1}]	18921	delivery	5	13
47706	2020-04-08 10:03:46	2020-04-08	9	[{"id_menu":7,"count":1}]	5854	delivery	5	14
47707	2020-04-08 10:06:08	2020-04-08	9	[{"id_menu":6,"count":1}]	1902	pick-up	0	9
47708	2020-04-08 10:06:15	2020-04-08	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	15966	delivery	5	26
47709	2020-04-08 10:09:31	2020-04-08	14	[{"id_menu":2,"count":1}]	18755	pick-up	0	14
47710	2020-04-08 10:12:05	2020-04-08	9	[{"id_menu":6,"count":1}]	19017	delivery	5	14
47711	2020-04-08 10:14:27	2020-04-08	12	[{"id_menu":1,"count":1}]	19029	delivery	5	17
47712	2020-04-08 10:20:59	2020-04-08	9	[{"id_menu":7,"count":1}]	19019	delivery	5	14
47713	2020-04-08 10:21:35	2020-04-08	14	[{"id_menu":2,"count":1}]	9847	delivery	5	19
47714	2020-04-08 10:24:52	2020-04-08	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14258	pick-up	0	26
47715	2020-04-08 10:25:44	2020-04-08	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6182	delivery	5	31
47716	2020-04-08 10:26:02	2020-04-08	14	[{"id_menu":2,"count":1}]	9878	delivery	5	19
47717	2020-04-08 10:33:02	2020-04-08	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10442	delivery	5	36
47718	2020-04-08 10:35:08	2020-04-08	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	18962	delivery	5	31
47719	2020-04-08 10:42:23	2020-04-08	9	[{"id_menu":7,"count":1}]	18948	delivery	5	14
47720	2020-04-08 10:42:55	2020-04-08	17	[{"id_menu":4,"count":2}]	1208	pick-up	0	17
47721	2020-04-08 10:49:19	2020-04-08	9	[{"id_menu":6,"count":1}]	18966	delivery	5	14
47722	2020-04-08 10:57:38	2020-04-08	8	[{"id_menu":5,"count":1}]	10436	delivery	5	13
47723	2020-04-08 10:59:36	2020-04-08	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	13079	delivery	5	37
47724	2020-04-08 11:01:53	2020-04-08	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	6028	delivery	5	26
47725	2020-04-08 11:02:15	2020-04-08	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	138	pick-up	0	21
47726	2020-04-08 11:06:53	2020-04-08	12	[{"id_menu":1,"count":1}]	4550	pick-up	0	12
47727	2020-04-08 11:19:21	2020-04-08	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	19024	pick-up	0	34
47728	2020-04-08 11:20:39	2020-04-08	9	[{"id_menu":6,"count":1}]	12338	pick-up	0	9
47729	2020-04-08 11:21:05	2020-04-08	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18938	delivery	5	39
47730	2020-04-08 11:25:04	2020-04-08	9	[{"id_menu":6,"count":1}]	895	delivery	5	14
47731	2020-04-08 11:32:16	2020-04-08	17	[{"id_menu":4,"count":1}]	8068	delivery	5	22
47732	2020-04-08 11:33:57	2020-04-08	9	[{"id_menu":6,"count":1}]	18994	delivery	5	14
47733	2020-04-08 11:34:14	2020-04-08	9	[{"id_menu":6,"count":1}]	4605	delivery	5	14
47734	2020-04-08 11:35:25	2020-04-08	9	[{"id_menu":6,"count":3}]	15995	delivery	5	14
47735	2020-04-08 11:48:15	2020-04-08	14	[{"id_menu":2,"count":1}]	18918	delivery	5	19
47736	2020-04-08 11:57:10	2020-04-08	14	[{"id_menu":2,"count":1}]	1178	pick-up	0	14
47737	2020-04-08 12:01:19	2020-04-08	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	19036	delivery	5	43
47738	2020-04-08 12:01:43	2020-04-08	17	[{"id_menu":4,"count":1}]	19026	delivery	5	22
47739	2020-04-08 12:09:07	2020-04-08	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	6634	pick-up	0	43
47740	2020-04-08 12:13:37	2020-04-08	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	18963	delivery	5	26
47741	2020-04-08 12:13:47	2020-04-08	17	[{"id_menu":4,"count":1}]	15798	pick-up	0	17
47742	2020-04-08 12:14:29	2020-04-08	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	19018	delivery	5	34
47743	2020-04-08 12:18:31	2020-04-08	14	[{"id_menu":2,"count":1}]	16295	delivery	5	19
47744	2020-04-08 12:20:32	2020-04-08	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1212	delivery	5	31
47745	2020-04-08 12:26:12	2020-04-08	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19028	delivery	5	34
47746	2020-04-08 12:27:57	2020-04-08	9	[{"id_menu":6,"count":1}]	15810	delivery	5	14
47747	2020-04-08 12:28:48	2020-04-08	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8054	delivery	5	31
47748	2020-04-08 12:32:55	2020-04-08	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	19041	delivery	5	26
47749	2020-04-08 12:37:40	2020-04-08	14	[{"id_menu":2,"count":1}]	18951	delivery	5	19
47750	2020-04-08 12:40:13	2020-04-08	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	16681	delivery	5	26
47751	2020-04-08 12:48:06	2020-04-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6404	delivery	5	23
47752	2020-04-08 12:48:22	2020-04-08	17	[{"id_menu":4,"count":1}]	1979	pick-up	0	17
47753	2020-04-08 12:49:33	2020-04-08	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	16277	delivery	5	25
47754	2020-04-08 12:56:28	2020-04-08	17	[{"id_menu":4,"count":1}]	18950	pick-up	0	17
47755	2020-04-08 13:07:26	2020-04-08	9	[{"id_menu":7,"count":1}]	2088	delivery	5	14
47756	2020-04-08 13:10:04	2020-04-08	9	[{"id_menu":7,"count":1}]	18909	delivery	5	14
47757	2020-04-08 13:14:06	2020-04-08	9	[{"id_menu":7,"count":1}]	19034	pick-up	0	9
47758	2020-04-08 13:15:02	2020-04-08	9	[{"id_menu":6,"count":1}]	10593	delivery	5	14
47759	2020-04-08 13:17:07	2020-04-08	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	18985	delivery	5	31
47760	2020-04-08 13:17:42	2020-04-08	12	[{"id_menu":1,"count":1}]	18974	pick-up	0	12
47761	2020-04-08 13:20:02	2020-04-08	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11729	delivery	5	45
47762	2020-04-08 13:22:02	2020-04-08	17	[{"id_menu":4,"count":1}]	18987	delivery	5	22
47763	2020-04-08 13:26:26	2020-04-08	9	[{"id_menu":6,"count":1}]	8166	delivery	5	14
47764	2020-04-08 13:37:03	2020-04-08	8	[{"id_menu":5,"count":2}]	19045	delivery	5	13
47765	2020-04-08 13:39:18	2020-04-08	12	[{"id_menu":3,"count":1}]	743	pick-up	0	12
47766	2020-04-08 13:40:40	2020-04-08	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	4057	delivery	5	25
47767	2020-04-08 13:41:35	2020-04-08	8	[{"id_menu":5,"count":2}]	15525	delivery	5	13
47768	2020-04-08 13:44:13	2020-04-08	9	[{"id_menu":7,"count":1}]	5699	delivery	5	14
47769	2020-04-08 13:55:49	2020-04-08	12	[{"id_menu":3,"count":1}]	17059	delivery	5	17
47770	2020-04-08 13:57:52	2020-04-08	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10966	delivery	5	36
47771	2020-04-08 13:58:50	2020-04-08	17	[{"id_menu":4,"count":1}]	18997	delivery	5	22
47772	2020-04-08 13:59:39	2020-04-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6945	pick-up	0	17
47773	2020-04-08 14:04:59	2020-04-08	14	[{"id_menu":2,"count":1}]	4658	delivery	5	19
47774	2020-04-08 14:06:50	2020-04-08	12	[{"id_menu":1,"count":1}]	14656	delivery	5	17
47775	2020-04-08 14:15:37	2020-04-08	12	[{"id_menu":3,"count":1}]	340	pick-up	0	12
47776	2020-04-08 14:19:44	2020-04-08	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	552	pick-up	0	22
47777	2020-04-08 14:22:05	2020-04-08	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	5141	pick-up	0	24
47778	2020-04-08 14:33:07	2020-04-08	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2425	pick-up	0	29
47779	2020-04-08 14:33:47	2020-04-08	9	[{"id_menu":6,"count":1}]	12494	delivery	5	14
47780	2020-04-08 14:36:30	2020-04-08	8	[{"id_menu":5,"count":1}]	18953	delivery	5	13
47781	2020-04-08 14:58:41	2020-04-08	12	[{"id_menu":3,"count":2}]	12352	pick-up	0	12
47782	2020-04-08 15:05:49	2020-04-08	8	[{"id_menu":5,"count":1}]	7821	delivery	5	13
47783	2020-04-08 15:06:42	2020-04-08	12	[{"id_menu":1,"count":1}]	3496	pick-up	0	12
47784	2020-04-08 15:08:42	2020-04-08	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	19044	delivery	5	26
47785	2020-04-08 15:11:24	2020-04-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	344	pick-up	0	18
47786	2020-04-08 15:13:13	2020-04-08	17	[{"id_menu":4,"count":1}]	1314	pick-up	0	17
47787	2020-04-08 15:18:10	2020-04-08	17	[{"id_menu":4,"count":1}]	18930	delivery	5	22
47788	2020-04-08 15:19:35	2020-04-08	12	[{"id_menu":3,"count":2}]	19011	pick-up	0	12
47789	2020-04-08 15:29:12	2020-04-08	9	[{"id_menu":7,"count":1}]	6665	delivery	5	14
47790	2020-04-08 15:35:49	2020-04-08	12	[{"id_menu":1,"count":1}]	695	delivery	5	17
47791	2020-04-08 15:38:00	2020-04-08	9	[{"id_menu":7,"count":1}]	19050	delivery	5	14
47792	2020-04-08 15:38:20	2020-04-08	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	19016	delivery	5	28
47793	2020-04-08 15:43:29	2020-04-08	17	[{"id_menu":4,"count":1}]	1288	delivery	5	22
47794	2020-04-08 15:44:39	2020-04-08	14	[{"id_menu":2,"count":1}]	1555	delivery	5	19
47795	2020-04-08 15:44:57	2020-04-08	26	[{"id_menu":1,"count":3},{"id_menu":2,"count":1}]	19035	delivery	5	31
47796	2020-04-08 15:49:02	2020-04-08	8	[{"id_menu":5,"count":1}]	5091	delivery	5	13
47797	2020-04-08 15:49:40	2020-04-08	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	5691	delivery	5	39
47798	2020-04-08 15:51:00	2020-04-08	9	[{"id_menu":7,"count":1}]	4254	delivery	5	14
47799	2020-04-08 15:59:05	2020-04-08	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	14002	pick-up	0	26
47800	2020-04-08 16:04:41	2020-04-08	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	2059	pick-up	0	35
47801	2020-04-08 16:14:36	2020-04-08	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	18972	delivery	5	34
47802	2020-04-08 16:16:37	2020-04-08	12	[{"id_menu":3,"count":1}]	15323	delivery	5	17
47803	2020-04-08 16:18:35	2020-04-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	13512	delivery	5	28
47804	2020-04-08 16:32:46	2020-04-08	17	[{"id_menu":4,"count":1}]	18932	delivery	5	22
47805	2020-04-08 16:34:16	2020-04-08	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	19015	delivery	5	28
47806	2020-04-08 16:36:49	2020-04-08	14	[{"id_menu":2,"count":1}]	1689	delivery	5	19
47807	2020-04-08 16:36:50	2020-04-08	12	[{"id_menu":3,"count":2}]	9467	delivery	5	17
47808	2020-04-08 16:40:38	2020-04-08	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6134	pick-up	0	29
47809	2020-04-08 16:41:15	2020-04-08	37	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	18996	delivery	5	42
47810	2020-04-08 16:44:58	2020-04-08	8	[{"id_menu":5,"count":1}]	19046	pick-up	0	8
47811	2020-04-08 16:45:43	2020-04-08	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18935	delivery	5	45
47812	2020-04-08 16:45:46	2020-04-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	18912	delivery	5	28
47813	2020-04-08 16:53:44	2020-04-08	14	[{"id_menu":2,"count":1}]	821	pick-up	0	14
47814	2020-04-08 16:57:35	2020-04-08	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8903	delivery	5	31
47815	2020-04-08 16:58:33	2020-04-08	17	[{"id_menu":4,"count":1}]	13758	delivery	5	22
47816	2020-04-08 17:03:31	2020-04-08	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1097	delivery	5	40
47817	2020-04-08 17:04:44	2020-04-08	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	7891	delivery	5	27
47818	2020-04-08 17:07:04	2020-04-08	12	[{"id_menu":1,"count":1}]	16406	pick-up	0	12
47819	2020-04-08 17:08:27	2020-04-08	9	[{"id_menu":7,"count":1}]	3052	pick-up	0	9
47820	2020-04-08 17:10:11	2020-04-08	9	[{"id_menu":6,"count":1}]	18914	delivery	5	14
47821	2020-04-08 17:13:21	2020-04-08	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2618	pick-up	0	25
47822	2020-04-08 17:17:11	2020-04-08	17	[{"id_menu":4,"count":1}]	7365	delivery	5	22
47823	2020-04-08 17:23:29	2020-04-08	14	[{"id_menu":2,"count":1}]	13373	delivery	5	19
47824	2020-04-08 17:23:36	2020-04-08	14	[{"id_menu":2,"count":1}]	960	pick-up	0	14
47825	2020-04-08 17:27:24	2020-04-08	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":2}]	19000	delivery	5	22
47826	2020-04-08 17:37:57	2020-04-08	9	[{"id_menu":6,"count":1}]	18941	delivery	5	14
47827	2020-04-08 17:49:35	2020-04-08	9	[{"id_menu":6,"count":3}]	13861	delivery	5	14
47828	2020-04-08 17:50:01	2020-04-08	9	[{"id_menu":6,"count":1}]	4703	delivery	5	14
47829	2020-04-08 17:51:21	2020-04-08	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2890	pick-up	0	33
47830	2020-04-08 17:51:25	2020-04-08	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	12699	delivery	5	36
47831	2020-04-08 17:55:16	2020-04-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	18929	delivery	5	28
47832	2020-04-08 18:10:35	2020-04-08	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	8901	delivery	5	26
47833	2020-04-08 18:10:47	2020-04-08	17	[{"id_menu":4,"count":1}]	4342	pick-up	0	17
47834	2020-04-08 18:14:47	2020-04-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	15202	pick-up	0	23
47835	2020-04-08 18:19:27	2020-04-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5264	delivery	5	22
47836	2020-04-08 18:31:44	2020-04-08	12	[{"id_menu":1,"count":1}]	2207	pick-up	0	12
47837	2020-04-08 18:37:06	2020-04-08	9	[{"id_menu":7,"count":1}]	19014	delivery	5	14
47838	2020-04-08 18:41:48	2020-04-08	9	[{"id_menu":7,"count":1}]	18925	delivery	5	14
47839	2020-04-08 18:42:32	2020-04-08	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	10103	delivery	5	38
47840	2020-04-08 18:52:45	2020-04-08	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	18965	delivery	5	30
47841	2020-04-08 18:57:52	2020-04-08	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18945	delivery	5	40
47842	2020-04-08 18:59:31	2020-04-08	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	12095	delivery	5	26
47843	2020-04-08 19:02:53	2020-04-08	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	14417	delivery	5	42
47844	2020-04-08 19:04:53	2020-04-08	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	5361	pick-up	0	26
47845	2020-04-08 19:05:53	2020-04-08	8	[{"id_menu":5,"count":1}]	18057	pick-up	0	8
47846	2020-04-08 19:07:06	2020-04-08	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	784	delivery	5	35
47847	2020-04-08 19:15:10	2020-04-08	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":2}]	19032	delivery	5	28
47848	2020-04-08 19:16:29	2020-04-08	9	[{"id_menu":6,"count":1}]	18967	delivery	5	14
47849	2020-04-08 19:21:30	2020-04-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	18920	pick-up	0	23
47850	2020-04-08 19:21:49	2020-04-08	17	[{"id_menu":4,"count":1}]	14585	pick-up	0	17
47851	2020-04-08 19:24:45	2020-04-08	12	[{"id_menu":1,"count":1}]	11394	pick-up	0	12
47852	2020-04-08 19:30:31	2020-04-08	12	[{"id_menu":1,"count":1}]	6242	pick-up	0	12
47853	2020-04-08 19:35:29	2020-04-08	8	[{"id_menu":5,"count":1}]	5201	pick-up	0	8
47854	2020-04-08 19:42:14	2020-04-08	9	[{"id_menu":6,"count":1}]	19012	delivery	5	14
47855	2020-04-08 19:45:21	2020-04-08	9	[{"id_menu":6,"count":1}]	18995	delivery	5	14
47856	2020-04-08 19:51:30	2020-04-08	14	[{"id_menu":2,"count":1}]	18976	delivery	5	19
47857	2020-04-08 19:53:25	2020-04-08	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	3332	pick-up	0	40
47858	2020-04-08 20:12:59	2020-04-08	12	[{"id_menu":3,"count":1}]	9295	pick-up	0	12
47859	2020-04-08 20:14:10	2020-04-08	17	[{"id_menu":4,"count":2}]	15216	delivery	5	22
47860	2020-04-08 20:19:47	2020-04-08	14	[{"id_menu":2,"count":2}]	15698	delivery	5	19
47861	2020-04-08 20:23:24	2020-04-08	17	[{"id_menu":4,"count":1}]	10024	delivery	5	22
47862	2020-04-08 20:23:51	2020-04-08	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	15241	delivery	5	39
47863	2020-04-08 20:26:04	2020-04-08	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	17649	pick-up	0	20
47864	2020-04-08 20:30:14	2020-04-08	8	[{"id_menu":5,"count":1}]	1386	delivery	5	13
47865	2020-04-08 20:32:30	2020-04-08	17	[{"id_menu":4,"count":1}]	1282	pick-up	0	17
47866	2020-04-08 20:35:09	2020-04-08	9	[{"id_menu":7,"count":1}]	9061	pick-up	0	9
47867	2020-04-08 20:37:10	2020-04-08	12	[{"id_menu":3,"count":1}]	3568	delivery	5	17
47868	2020-04-08 20:40:48	2020-04-08	14	[{"id_menu":2,"count":1}]	2933	delivery	5	19
47869	2020-04-08 20:45:34	2020-04-08	12	[{"id_menu":1,"count":1}]	15313	delivery	5	17
47870	2020-04-08 20:48:47	2020-04-08	17	[{"id_menu":4,"count":1}]	7248	pick-up	0	17
47871	2020-04-08 20:55:09	2020-04-08	12	[{"id_menu":3,"count":1}]	18991	delivery	5	17
47872	2020-04-08 20:58:03	2020-04-08	17	[{"id_menu":4,"count":1}]	1726	pick-up	0	17
47873	2020-04-08 21:01:53	2020-04-08	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2748	pick-up	0	26
47874	2020-04-08 21:12:02	2020-04-08	8	[{"id_menu":5,"count":1}]	18939	delivery	5	13
47875	2020-04-08 21:19:39	2020-04-08	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19023	delivery	5	34
47876	2020-04-08 21:20:23	2020-04-08	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	18960	delivery	5	31
47877	2020-04-08 21:22:11	2020-04-08	9	[{"id_menu":7,"count":1}]	8693	pick-up	0	9
47878	2020-04-08 21:26:12	2020-04-08	9	[{"id_menu":6,"count":1}]	15867	delivery	5	14
47879	2020-04-08 21:27:14	2020-04-08	17	[{"id_menu":4,"count":1}]	5379	delivery	5	22
47880	2020-04-08 21:29:06	2020-04-08	14	[{"id_menu":2,"count":1}]	2731	pick-up	0	14
47881	2020-04-08 21:29:30	2020-04-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	6229	delivery	5	28
47882	2020-04-08 21:31:44	2020-04-08	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	837	pick-up	0	26
47883	2020-04-08 21:33:58	2020-04-08	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5642	pick-up	0	38
47884	2020-04-08 21:44:58	2020-04-08	14	[{"id_menu":2,"count":1}]	7407	delivery	5	19
47885	2020-04-08 21:45:58	2020-04-08	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	18926	delivery	5	40
47886	2020-04-08 21:55:39	2020-04-08	9	[{"id_menu":7,"count":2}]	18933	delivery	5	14
47887	2020-04-08 21:59:26	2020-04-08	9	[{"id_menu":6,"count":1}]	10373	delivery	5	14
47888	2020-04-08 22:00:47	2020-04-08	17	[{"id_menu":4,"count":1}]	5974	delivery	5	22
47889	2020-04-08 22:08:45	2020-04-08	17	[{"id_menu":4,"count":1}]	18320	delivery	5	22
47890	2020-04-08 22:09:31	2020-04-08	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9787	delivery	5	31
47891	2020-04-08 22:12:43	2020-04-08	17	[{"id_menu":4,"count":1}]	11027	delivery	5	22
47892	2020-04-08 22:12:57	2020-04-08	8	[{"id_menu":5,"count":1}]	11454	delivery	5	13
47893	2020-04-08 22:19:12	2020-04-08	12	[{"id_menu":1,"count":1}]	1797	pick-up	0	12
47894	2020-04-08 22:20:47	2020-04-08	14	[{"id_menu":2,"count":1}]	18119	pick-up	0	14
47895	2020-04-08 22:21:58	2020-04-08	8	[{"id_menu":5,"count":1}]	11789	delivery	5	13
47896	2020-04-08 22:26:04	2020-04-08	17	[{"id_menu":4,"count":1}]	18484	delivery	5	22
47897	2020-04-08 22:27:24	2020-04-08	9	[{"id_menu":6,"count":1}]	15461	delivery	5	14
47898	2020-04-08 22:29:37	2020-04-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	13734	delivery	5	28
47899	2020-04-08 22:30:05	2020-04-08	9	[{"id_menu":7,"count":1}]	7749	delivery	5	14
47900	2020-04-08 22:30:42	2020-04-08	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2557	pick-up	0	20
47901	2020-04-08 22:32:03	2020-04-08	9	[{"id_menu":7,"count":1}]	17259	delivery	5	14
47902	2020-04-08 22:35:25	2020-04-08	17	[{"id_menu":4,"count":1}]	6320	delivery	5	22
47903	2020-04-08 22:42:09	2020-04-08	14	[{"id_menu":2,"count":1}]	18931	delivery	5	19
47904	2020-04-08 22:55:09	2020-04-08	17	[{"id_menu":4,"count":1}]	19001	pick-up	0	17
47905	2020-04-08 23:04:49	2020-04-08	17	[{"id_menu":4,"count":1}]	18980	pick-up	0	17
47906	2020-04-08 23:05:39	2020-04-08	12	[{"id_menu":1,"count":1}]	9404	pick-up	0	12
47907	2020-04-08 23:07:31	2020-04-08	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	399	pick-up	0	26
47908	2020-04-08 23:10:20	2020-04-08	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	5407	delivery	5	26
47909	2020-04-08 23:17:27	2020-04-08	12	[{"id_menu":1,"count":1}]	10676	delivery	5	17
47910	2020-04-08 23:21:39	2020-04-08	17	[{"id_menu":4,"count":1}]	10598	pick-up	0	17
47911	2020-04-08 23:30:13	2020-04-08	12	[{"id_menu":1,"count":1}]	18958	pick-up	0	12
47912	2020-04-08 23:34:01	2020-04-08	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5817	delivery	5	31
47913	2020-04-08 23:36:25	2020-04-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17683	delivery	5	22
47914	2020-04-08 23:37:10	2020-04-08	12	[{"id_menu":1,"count":1}]	1819	pick-up	0	12
47915	2020-04-08 23:41:43	2020-04-08	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15828	delivery	5	39
47916	2020-04-08 23:41:56	2020-04-08	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	18917	delivery	5	31
47917	2020-04-08 23:42:00	2020-04-08	9	[{"id_menu":7,"count":1}]	1982	delivery	5	14
47918	2020-04-08 23:45:46	2020-04-08	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	19006	delivery	5	26
47919	2020-04-08 23:51:42	2020-04-08	12	[{"id_menu":1,"count":1}]	15559	delivery	5	17
47920	2020-04-08 23:53:28	2020-04-08	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	19010	delivery	5	31
47921	2020-04-08 23:54:28	2020-04-08	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	7157	delivery	5	23
47922	2020-04-09 00:04:46	2020-04-09	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12613	delivery	5	45
47923	2020-04-09 00:06:23	2020-04-09	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	19166	delivery	5	26
47924	2020-04-09 00:08:59	2020-04-09	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8242	delivery	5	31
47925	2020-04-09 00:11:13	2020-04-09	12	[{"id_menu":3,"count":1}]	15035	delivery	5	17
47926	2020-04-09 00:11:32	2020-04-09	9	[{"id_menu":7,"count":2}]	13621	delivery	5	14
47927	2020-04-09 00:11:34	2020-04-09	12	[{"id_menu":1,"count":1}]	519	pick-up	0	12
47928	2020-04-09 00:13:14	2020-04-09	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7022	delivery	5	42
47929	2020-04-09 00:17:15	2020-04-09	8	[{"id_menu":5,"count":1}]	19169	pick-up	0	8
47930	2020-04-09 00:17:49	2020-04-09	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	286	pick-up	0	38
47931	2020-04-09 00:18:15	2020-04-09	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	19167	delivery	5	42
47932	2020-04-09 00:20:48	2020-04-09	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	19089	delivery	5	26
47933	2020-04-09 00:22:32	2020-04-09	14	[{"id_menu":2,"count":1}]	7337	delivery	5	19
47934	2020-04-09 00:23:23	2020-04-09	8	[{"id_menu":5,"count":1}]	19152	delivery	5	13
47935	2020-04-09 00:34:53	2020-04-09	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	15437	delivery	5	22
47936	2020-04-09 00:39:37	2020-04-09	9	[{"id_menu":7,"count":1}]	6173	pick-up	0	9
47937	2020-04-09 00:40:59	2020-04-09	9	[{"id_menu":6,"count":1}]	19078	pick-up	0	9
47938	2020-04-09 00:45:22	2020-04-09	8	[{"id_menu":5,"count":1}]	4133	delivery	5	13
47939	2020-04-09 00:47:43	2020-04-09	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	19159	pick-up	0	29
47940	2020-04-09 00:48:23	2020-04-09	17	[{"id_menu":4,"count":1}]	2004	pick-up	0	17
47941	2020-04-09 00:50:39	2020-04-09	9	[{"id_menu":7,"count":1}]	17472	pick-up	0	9
47942	2020-04-09 01:04:23	2020-04-09	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	13418	delivery	5	25
47943	2020-04-09 01:07:40	2020-04-09	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19090	delivery	5	22
47944	2020-04-09 01:11:39	2020-04-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19073	delivery	5	23
47945	2020-04-09 01:12:19	2020-04-09	9	[{"id_menu":6,"count":1}]	19171	delivery	5	14
47946	2020-04-09 01:19:19	2020-04-09	12	[{"id_menu":1,"count":1}]	1922	delivery	5	17
47947	2020-04-09 01:31:23	2020-04-09	9	[{"id_menu":6,"count":1}]	4069	delivery	5	14
47948	2020-04-09 01:32:24	2020-04-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	19162	delivery	5	28
47949	2020-04-09 01:35:23	2020-04-09	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	19115	delivery	5	36
47950	2020-04-09 01:36:22	2020-04-09	12	[{"id_menu":3,"count":1}]	1427	pick-up	0	12
47951	2020-04-09 01:44:07	2020-04-09	9	[{"id_menu":6,"count":1}]	9584	delivery	5	14
47952	2020-04-09 01:45:35	2020-04-09	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11115	delivery	5	22
47953	2020-04-09 01:47:07	2020-04-09	9	[{"id_menu":7,"count":1}]	10681	delivery	5	14
47954	2020-04-09 01:50:14	2020-04-09	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	9934	pick-up	0	21
47955	2020-04-09 01:54:06	2020-04-09	12	[{"id_menu":1,"count":1}]	19110	delivery	5	17
47956	2020-04-09 01:58:59	2020-04-09	8	[{"id_menu":5,"count":1}]	6113	delivery	5	13
47957	2020-04-09 02:03:45	2020-04-09	9	[{"id_menu":7,"count":1}]	9750	pick-up	0	9
47958	2020-04-09 02:05:19	2020-04-09	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	13477	pick-up	0	26
47959	2020-04-09 02:06:50	2020-04-09	9	[{"id_menu":6,"count":1}]	19102	delivery	5	14
47960	2020-04-09 02:17:05	2020-04-09	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	19145	delivery	5	26
47961	2020-04-09 02:18:18	2020-04-09	9	[{"id_menu":6,"count":1}]	5263	delivery	5	14
47962	2020-04-09 02:28:38	2020-04-09	8	[{"id_menu":5,"count":1}]	9315	delivery	5	13
47963	2020-04-09 02:41:56	2020-04-09	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	14764	pick-up	0	26
47964	2020-04-09 02:51:55	2020-04-09	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	15410	delivery	5	30
47965	2020-04-09 02:54:48	2020-04-09	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	10289	delivery	5	34
47966	2020-04-09 03:28:22	2020-04-09	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	11159	delivery	5	40
47967	2020-04-09 03:28:40	2020-04-09	17	[{"id_menu":4,"count":1}]	389	pick-up	0	17
47968	2020-04-09 03:36:45	2020-04-09	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	14997	pick-up	0	26
47969	2020-04-09 03:37:40	2020-04-09	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1149	delivery	5	31
47970	2020-04-09 03:45:17	2020-04-09	14	[{"id_menu":2,"count":1}]	12589	delivery	5	19
47971	2020-04-09 03:49:15	2020-04-09	17	[{"id_menu":4,"count":1}]	1715	pick-up	0	17
47972	2020-04-09 03:51:11	2020-04-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3619	pick-up	0	17
47973	2020-04-09 04:01:25	2020-04-09	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	17775	delivery	5	31
47974	2020-04-09 04:09:02	2020-04-09	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	12930	delivery	5	25
47975	2020-04-09 04:09:03	2020-04-09	12	[{"id_menu":3,"count":1}]	19137	pick-up	0	12
47976	2020-04-09 04:09:09	2020-04-09	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	15889	delivery	5	26
47977	2020-04-09 04:12:33	2020-04-09	12	[{"id_menu":1,"count":1}]	12543	delivery	5	17
47978	2020-04-09 04:12:45	2020-04-09	9	[{"id_menu":7,"count":1}]	3001	pick-up	0	9
47979	2020-04-09 04:15:43	2020-04-09	8	[{"id_menu":5,"count":2}]	19140	delivery	5	13
47980	2020-04-09 04:26:46	2020-04-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	10950	delivery	5	28
47981	2020-04-09 04:34:00	2020-04-09	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2085	delivery	5	26
47982	2020-04-09 04:36:43	2020-04-09	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	10690	delivery	5	27
47983	2020-04-09 04:38:24	2020-04-09	9	[{"id_menu":7,"count":1}]	19064	pick-up	0	9
47984	2020-04-09 04:46:01	2020-04-09	8	[{"id_menu":5,"count":2}]	9214	delivery	5	13
47985	2020-04-09 04:47:37	2020-04-09	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1072	pick-up	0	26
47986	2020-04-09 05:00:50	2020-04-09	17	[{"id_menu":4,"count":1}]	19158	delivery	5	22
47987	2020-04-09 05:03:12	2020-04-09	14	[{"id_menu":2,"count":1}]	10377	delivery	5	19
47988	2020-04-09 05:05:16	2020-04-09	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11320	delivery	5	36
47989	2020-04-09 05:09:02	2020-04-09	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13412	delivery	5	35
47990	2020-04-09 05:13:11	2020-04-09	12	[{"id_menu":3,"count":1}]	5865	delivery	5	17
47991	2020-04-09 05:15:03	2020-04-09	8	[{"id_menu":5,"count":1}]	19091	pick-up	0	8
47992	2020-04-09 05:18:06	2020-04-09	12	[{"id_menu":1,"count":1}]	2317	pick-up	0	12
47993	2020-04-09 05:20:29	2020-04-09	17	[{"id_menu":4,"count":1}]	5064	pick-up	0	17
47994	2020-04-09 05:23:27	2020-04-09	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	14737	delivery	5	35
47995	2020-04-09 05:24:58	2020-04-09	9	[{"id_menu":6,"count":1}]	2296	delivery	5	14
47996	2020-04-09 05:25:12	2020-04-09	14	[{"id_menu":2,"count":1}]	12791	pick-up	0	14
47997	2020-04-09 05:26:11	2020-04-09	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	6548	pick-up	0	21
47998	2020-04-09 05:31:21	2020-04-09	9	[{"id_menu":6,"count":1}]	19139	delivery	5	14
47999	2020-04-09 05:40:53	2020-04-09	12	[{"id_menu":3,"count":1}]	3520	pick-up	0	12
48000	2020-04-09 05:46:08	2020-04-09	17	[{"id_menu":4,"count":1}]	19154	delivery	5	22
48001	2020-04-09 05:46:16	2020-04-09	9	[{"id_menu":7,"count":1}]	19123	delivery	5	14
48002	2020-04-09 05:57:28	2020-04-09	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11587	delivery	5	43
48003	2020-04-09 06:05:08	2020-04-09	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	19163	delivery	5	39
48004	2020-04-09 06:06:09	2020-04-09	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16320	delivery	5	31
48005	2020-04-09 06:07:06	2020-04-09	9	[{"id_menu":6,"count":1}]	19146	delivery	5	14
48006	2020-04-09 06:08:56	2020-04-09	17	[{"id_menu":4,"count":1}]	10393	delivery	5	22
48007	2020-04-09 06:15:07	2020-04-09	23	[{"id_menu":2,"count":3},{"id_menu":7,"count":1}]	19061	delivery	5	28
48008	2020-04-09 06:17:04	2020-04-09	14	[{"id_menu":2,"count":1}]	12635	delivery	5	19
48009	2020-04-09 06:20:45	2020-04-09	9	[{"id_menu":6,"count":1}]	3871	pick-up	0	9
48010	2020-04-09 06:30:35	2020-04-09	17	[{"id_menu":4,"count":2}]	7151	pick-up	0	17
48011	2020-04-09 06:31:10	2020-04-09	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2739	pick-up	0	29
48012	2020-04-09 06:31:18	2020-04-09	17	[{"id_menu":4,"count":1}]	1956	pick-up	0	17
48013	2020-04-09 06:35:07	2020-04-09	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1889	pick-up	0	37
48014	2020-04-09 06:35:30	2020-04-09	12	[{"id_menu":1,"count":1}]	14485	pick-up	0	12
48015	2020-04-09 06:36:32	2020-04-09	14	[{"id_menu":2,"count":3}]	5776	delivery	5	19
48016	2020-04-09 06:46:53	2020-04-09	14	[{"id_menu":2,"count":1}]	9627	delivery	5	19
48017	2020-04-09 06:54:12	2020-04-09	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	19176	delivery	5	31
48018	2020-04-09 06:54:38	2020-04-09	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	839	pick-up	0	24
48019	2020-04-09 06:57:42	2020-04-09	9	[{"id_menu":6,"count":1}]	6581	pick-up	0	9
48020	2020-04-09 07:02:47	2020-04-09	9	[{"id_menu":6,"count":1}]	15456	pick-up	0	9
48021	2020-04-09 07:03:03	2020-04-09	8	[{"id_menu":5,"count":1}]	1860	pick-up	0	8
48022	2020-04-09 07:07:14	2020-04-09	14	[{"id_menu":2,"count":1}]	17283	delivery	5	19
48023	2020-04-09 07:13:22	2020-04-09	9	[{"id_menu":7,"count":1}]	831	delivery	5	14
48024	2020-04-09 07:14:14	2020-04-09	9	[{"id_menu":7,"count":1}]	15247	delivery	5	14
48025	2020-04-09 07:14:46	2020-04-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	19144	pick-up	0	23
48026	2020-04-09 07:15:53	2020-04-09	8	[{"id_menu":5,"count":1}]	19107	delivery	5	13
48027	2020-04-09 07:23:21	2020-04-09	8	[{"id_menu":5,"count":1}]	2509	pick-up	0	8
48028	2020-04-09 07:31:59	2020-04-09	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3887	delivery	5	42
48029	2020-04-09 07:38:43	2020-04-09	12	[{"id_menu":1,"count":1}]	5109	delivery	5	17
48030	2020-04-09 07:38:50	2020-04-09	12	[{"id_menu":3,"count":1}]	10545	delivery	5	17
48031	2020-04-09 07:39:06	2020-04-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	18434	delivery	5	28
48032	2020-04-09 07:39:50	2020-04-09	14	[{"id_menu":2,"count":1}]	18110	delivery	5	19
48033	2020-04-09 07:41:06	2020-04-09	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	19063	pick-up	0	20
48034	2020-04-09 07:44:01	2020-04-09	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	17278	delivery	5	40
48035	2020-04-09 07:49:14	2020-04-09	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	13324	pick-up	0	32
48036	2020-04-09 07:57:47	2020-04-09	17	[{"id_menu":4,"count":1}]	19114	delivery	5	22
48037	2020-04-09 08:13:02	2020-04-09	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	19153	delivery	5	31
48038	2020-04-09 08:14:48	2020-04-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	19076	delivery	5	28
48039	2020-04-09 08:15:55	2020-04-09	8	[{"id_menu":5,"count":1}]	15076	delivery	5	13
48040	2020-04-09 08:18:30	2020-04-09	12	[{"id_menu":3,"count":1}]	17619	delivery	5	17
48041	2020-04-09 08:19:37	2020-04-09	9	[{"id_menu":7,"count":1}]	19148	delivery	5	14
48042	2020-04-09 08:20:17	2020-04-09	17	[{"id_menu":4,"count":1}]	10706	pick-up	0	17
48043	2020-04-09 08:20:28	2020-04-09	9	[{"id_menu":7,"count":1}]	8234	delivery	5	14
48044	2020-04-09 08:21:07	2020-04-09	9	[{"id_menu":7,"count":1}]	11507	delivery	5	14
48045	2020-04-09 08:30:50	2020-04-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15361	pick-up	0	17
48046	2020-04-09 08:31:19	2020-04-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	19093	delivery	5	28
48047	2020-04-09 08:31:55	2020-04-09	12	[{"id_menu":3,"count":1}]	17251	delivery	5	17
48048	2020-04-09 08:36:29	2020-04-09	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	19112	delivery	5	44
48049	2020-04-09 08:36:33	2020-04-09	9	[{"id_menu":6,"count":1}]	19085	delivery	5	14
48050	2020-04-09 08:37:27	2020-04-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	19132	delivery	5	28
48051	2020-04-09 08:42:07	2020-04-09	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	19081	pick-up	0	21
48052	2020-04-09 08:45:47	2020-04-09	12	[{"id_menu":1,"count":1}]	14290	pick-up	0	12
48053	2020-04-09 08:48:39	2020-04-09	8	[{"id_menu":5,"count":1}]	3842	pick-up	0	8
48054	2020-04-09 08:58:02	2020-04-09	9	[{"id_menu":6,"count":1}]	19138	delivery	5	14
48055	2020-04-09 09:08:56	2020-04-09	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	6202	delivery	5	31
48056	2020-04-09 09:10:59	2020-04-09	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10365	delivery	5	34
48057	2020-04-09 09:16:23	2020-04-09	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	19059	delivery	5	25
48058	2020-04-09 09:17:05	2020-04-09	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8934	delivery	5	31
48059	2020-04-09 09:26:43	2020-04-09	9	[{"id_menu":6,"count":1}]	12701	delivery	5	14
48060	2020-04-09 09:31:31	2020-04-09	14	[{"id_menu":2,"count":1}]	19126	delivery	5	19
48061	2020-04-09 09:32:34	2020-04-09	17	[{"id_menu":4,"count":1}]	19124	delivery	5	22
48062	2020-04-09 09:33:32	2020-04-09	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6901	delivery	5	30
48063	2020-04-09 09:38:17	2020-04-09	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	2131	delivery	5	31
48064	2020-04-09 09:47:40	2020-04-09	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	19105	delivery	5	39
48065	2020-04-09 09:55:42	2020-04-09	12	[{"id_menu":1,"count":1}]	6470	pick-up	0	12
48066	2020-04-09 09:55:54	2020-04-09	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	12666	delivery	5	34
48067	2020-04-09 10:00:54	2020-04-09	17	[{"id_menu":4,"count":1}]	6410	delivery	5	22
48068	2020-04-09 10:02:34	2020-04-09	17	[{"id_menu":4,"count":1}]	19087	pick-up	0	17
48069	2020-04-09 10:06:40	2020-04-09	9	[{"id_menu":6,"count":1}]	15587	delivery	5	14
48070	2020-04-09 10:07:34	2020-04-09	14	[{"id_menu":2,"count":1}]	19130	delivery	5	19
48071	2020-04-09 10:15:53	2020-04-09	12	[{"id_menu":3,"count":1}]	7840	delivery	5	17
48072	2020-04-09 10:17:17	2020-04-09	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18755	pick-up	0	35
48073	2020-04-09 10:26:38	2020-04-09	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	19104	delivery	5	43
48074	2020-04-09 10:34:55	2020-04-09	9	[{"id_menu":6,"count":1}]	6007	delivery	5	14
48075	2020-04-09 10:38:13	2020-04-09	17	[{"id_menu":4,"count":1}]	12689	delivery	5	22
48076	2020-04-09 10:39:17	2020-04-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6950	pick-up	0	23
48077	2020-04-09 10:39:39	2020-04-09	12	[{"id_menu":3,"count":1}]	5491	pick-up	0	12
48078	2020-04-09 10:45:10	2020-04-09	9	[{"id_menu":6,"count":1}]	14090	delivery	5	14
48079	2020-04-09 10:47:43	2020-04-09	12	[{"id_menu":1,"count":1}]	16182	delivery	5	17
48080	2020-04-09 10:48:51	2020-04-09	9	[{"id_menu":6,"count":1}]	19129	pick-up	0	9
48081	2020-04-09 10:49:21	2020-04-09	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	11385	pick-up	0	26
48082	2020-04-09 11:00:04	2020-04-09	9	[{"id_menu":6,"count":2}]	2182	delivery	5	14
48083	2020-04-09 11:03:13	2020-04-09	9	[{"id_menu":6,"count":1}]	15385	pick-up	0	9
48084	2020-04-09 11:05:34	2020-04-09	8	[{"id_menu":5,"count":3}]	19109	delivery	5	13
48085	2020-04-09 11:08:20	2020-04-09	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5400	delivery	5	31
48086	2020-04-09 11:10:21	2020-04-09	17	[{"id_menu":4,"count":1}]	4629	delivery	5	22
48087	2020-04-09 11:11:28	2020-04-09	8	[{"id_menu":5,"count":1}]	19128	delivery	5	13
48088	2020-04-09 11:13:23	2020-04-09	8	[{"id_menu":5,"count":1}]	11612	delivery	5	13
48089	2020-04-09 11:13:56	2020-04-09	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	6566	delivery	5	25
48090	2020-04-09 11:16:00	2020-04-09	12	[{"id_menu":3,"count":1}]	4397	pick-up	0	12
48091	2020-04-09 11:17:37	2020-04-09	14	[{"id_menu":2,"count":1}]	6140	delivery	5	19
48092	2020-04-09 11:21:30	2020-04-09	14	[{"id_menu":2,"count":1}]	9696	delivery	5	19
48093	2020-04-09 11:27:51	2020-04-09	8	[{"id_menu":5,"count":1}]	1246	delivery	5	13
48094	2020-04-09 11:29:04	2020-04-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	18514	delivery	5	28
48095	2020-04-09 11:29:53	2020-04-09	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	6645	pick-up	0	21
48096	2020-04-09 11:33:24	2020-04-09	12	[{"id_menu":3,"count":1}]	8265	pick-up	0	12
48097	2020-04-09 11:49:55	2020-04-09	9	[{"id_menu":6,"count":1}]	316	delivery	5	14
48098	2020-04-09 11:54:27	2020-04-09	12	[{"id_menu":3,"count":1}]	11696	pick-up	0	12
48099	2020-04-09 12:02:07	2020-04-09	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19155	delivery	5	31
48100	2020-04-09 12:02:32	2020-04-09	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12772	delivery	5	43
48101	2020-04-09 12:03:12	2020-04-09	8	[{"id_menu":5,"count":1}]	17871	delivery	5	13
48102	2020-04-09 12:06:25	2020-04-09	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17171	delivery	5	34
48103	2020-04-09 12:08:43	2020-04-09	17	[{"id_menu":4,"count":1}]	18054	delivery	5	22
48104	2020-04-09 12:08:47	2020-04-09	9	[{"id_menu":6,"count":1}]	14519	pick-up	0	9
48105	2020-04-09 12:09:11	2020-04-09	14	[{"id_menu":2,"count":2}]	19071	delivery	5	19
48106	2020-04-09 12:09:30	2020-04-09	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	18306	delivery	5	34
48107	2020-04-09 12:15:39	2020-04-09	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	19164	delivery	5	30
48108	2020-04-09 12:20:04	2020-04-09	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	19054	delivery	5	30
48109	2020-04-09 12:20:17	2020-04-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19075	pick-up	0	18
48110	2020-04-09 12:22:41	2020-04-09	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	584	pick-up	0	29
48111	2020-04-09 12:30:59	2020-04-09	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	19055	pick-up	0	20
48112	2020-04-09 12:31:14	2020-04-09	12	[{"id_menu":1,"count":1}]	16926	pick-up	0	12
48113	2020-04-09 12:32:41	2020-04-09	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	543	pick-up	0	52
48114	2020-04-09 12:33:13	2020-04-09	8	[{"id_menu":5,"count":1}]	19082	delivery	5	13
48115	2020-04-09 12:34:02	2020-04-09	9	[{"id_menu":6,"count":2}]	19083	delivery	5	14
48116	2020-04-09 12:34:25	2020-04-09	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17652	delivery	5	36
48117	2020-04-09 12:37:26	2020-04-09	12	[{"id_menu":1,"count":2}]	19173	delivery	5	17
48118	2020-04-09 12:42:58	2020-04-09	9	[{"id_menu":7,"count":1}]	585	delivery	5	14
48119	2020-04-09 12:45:21	2020-04-09	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	19100	pick-up	0	20
48120	2020-04-09 12:47:42	2020-04-09	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6905	delivery	5	52
48121	2020-04-09 12:53:35	2020-04-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19103	delivery	5	22
48122	2020-04-09 12:53:57	2020-04-09	12	[{"id_menu":3,"count":1}]	19119	delivery	5	17
48123	2020-04-09 12:56:54	2020-04-09	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11932	delivery	5	34
48124	2020-04-09 13:04:33	2020-04-09	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3689	delivery	5	31
48125	2020-04-09 13:13:09	2020-04-09	9	[{"id_menu":7,"count":1}]	8989	delivery	5	14
48126	2020-04-09 13:19:44	2020-04-09	14	[{"id_menu":2,"count":1}]	9688	pick-up	0	14
48127	2020-04-09 13:33:20	2020-04-09	17	[{"id_menu":4,"count":1}]	4524	pick-up	0	17
48128	2020-04-09 13:41:07	2020-04-09	12	[{"id_menu":1,"count":1}]	3674	pick-up	0	12
48129	2020-04-09 13:41:19	2020-04-09	17	[{"id_menu":4,"count":1}]	19147	delivery	5	22
48130	2020-04-09 13:53:52	2020-04-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3125	delivery	5	23
48131	2020-04-09 13:56:44	2020-04-09	17	[{"id_menu":4,"count":1}]	19157	delivery	5	22
48132	2020-04-09 13:58:23	2020-04-09	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	12150	pick-up	0	29
48133	2020-04-09 14:00:02	2020-04-09	9	[{"id_menu":6,"count":1}]	3614	delivery	5	14
48134	2020-04-09 14:02:42	2020-04-09	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	18032	delivery	5	34
48135	2020-04-09 14:10:06	2020-04-09	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19096	pick-up	0	31
48136	2020-04-09 14:10:32	2020-04-09	9	[{"id_menu":6,"count":1}]	19172	delivery	5	14
48137	2020-04-09 14:10:52	2020-04-09	9	[{"id_menu":6,"count":1}]	14735	pick-up	0	9
48138	2020-04-09 14:12:53	2020-04-09	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	9466	delivery	5	31
48139	2020-04-09 14:13:32	2020-04-09	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4912	delivery	5	52
48140	2020-04-09 14:19:56	2020-04-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	19052	pick-up	0	23
48141	2020-04-09 14:21:01	2020-04-09	14	[{"id_menu":2,"count":1}]	19099	delivery	5	19
48142	2020-04-09 14:22:21	2020-04-09	12	[{"id_menu":1,"count":1}]	19117	delivery	5	17
48143	2020-04-09 14:23:26	2020-04-09	12	[{"id_menu":1,"count":1}]	13656	delivery	5	17
48144	2020-04-09 14:24:24	2020-04-09	9	[{"id_menu":7,"count":2}]	2477	delivery	5	14
48145	2020-04-09 14:27:14	2020-04-09	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10954	pick-up	0	26
48146	2020-04-09 14:32:20	2020-04-09	9	[{"id_menu":6,"count":1}]	5786	delivery	5	14
48147	2020-04-09 14:34:47	2020-04-09	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	9442	pick-up	0	35
48148	2020-04-09 14:38:37	2020-04-09	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	19092	pick-up	0	38
48149	2020-04-09 14:40:59	2020-04-09	9	[{"id_menu":6,"count":1}]	4870	pick-up	0	9
48150	2020-04-09 14:42:21	2020-04-09	8	[{"id_menu":5,"count":1}]	19118	delivery	5	13
48151	2020-04-09 14:43:33	2020-04-09	12	[{"id_menu":1,"count":1}]	14072	delivery	5	17
48152	2020-04-09 14:49:19	2020-04-09	9	[{"id_menu":6,"count":1}]	11354	delivery	5	14
48153	2020-04-09 14:54:09	2020-04-09	12	[{"id_menu":1,"count":1}]	17502	pick-up	0	12
48154	2020-04-09 14:55:34	2020-04-09	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	456	pick-up	0	26
48155	2020-04-09 14:55:48	2020-04-09	12	[{"id_menu":1,"count":1}]	4995	pick-up	0	12
48156	2020-04-09 14:56:26	2020-04-09	12	[{"id_menu":3,"count":1}]	19094	delivery	5	17
48157	2020-04-09 15:02:20	2020-04-09	9	[{"id_menu":7,"count":1}]	12453	delivery	5	14
48158	2020-04-09 15:04:17	2020-04-09	9	[{"id_menu":6,"count":1}]	19088	delivery	5	14
48159	2020-04-09 15:05:03	2020-04-09	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	13559	delivery	5	27
48160	2020-04-09 15:05:23	2020-04-09	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	17116	delivery	5	26
48161	2020-04-09 15:06:03	2020-04-09	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4865	pick-up	0	22
48162	2020-04-09 15:06:05	2020-04-09	9	[{"id_menu":7,"count":2}]	1076	pick-up	0	9
48163	2020-04-09 15:06:51	2020-04-09	9	[{"id_menu":7,"count":1}]	4634	pick-up	0	9
48164	2020-04-09 15:10:30	2020-04-09	9	[{"id_menu":7,"count":1}]	16590	delivery	5	14
48165	2020-04-09 15:10:47	2020-04-09	12	[{"id_menu":1,"count":1}]	1657	pick-up	0	12
48166	2020-04-09 15:10:50	2020-04-09	12	[{"id_menu":1,"count":1}]	729	pick-up	0	12
48167	2020-04-09 15:15:02	2020-04-09	8	[{"id_menu":5,"count":1}]	16311	delivery	5	13
48168	2020-04-09 15:17:55	2020-04-09	8	[{"id_menu":5,"count":1}]	4754	delivery	5	13
48169	2020-04-09 15:19:36	2020-04-09	9	[{"id_menu":6,"count":1}]	7997	delivery	5	14
48170	2020-04-09 15:23:12	2020-04-09	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19168	delivery	5	39
48171	2020-04-09 15:26:30	2020-04-09	12	[{"id_menu":1,"count":1}]	19142	delivery	5	17
48172	2020-04-09 15:28:03	2020-04-09	12	[{"id_menu":3,"count":1}]	11760	delivery	5	17
48173	2020-04-09 15:33:29	2020-04-09	9	[{"id_menu":6,"count":1}]	19116	delivery	5	14
48174	2020-04-09 15:33:53	2020-04-09	9	[{"id_menu":7,"count":1}]	19149	delivery	5	14
48175	2020-04-09 15:40:57	2020-04-09	14	[{"id_menu":2,"count":1}]	7306	delivery	5	19
48176	2020-04-09 15:43:48	2020-04-09	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2952	delivery	5	39
48177	2020-04-09 15:44:55	2020-04-09	17	[{"id_menu":4,"count":1}]	709	delivery	5	22
48178	2020-04-09 15:48:56	2020-04-09	9	[{"id_menu":6,"count":1}]	19053	delivery	5	14
48179	2020-04-09 15:56:26	2020-04-09	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14392	pick-up	0	26
48180	2020-04-09 15:56:49	2020-04-09	12	[{"id_menu":1,"count":1}]	18143	delivery	5	17
48181	2020-04-09 15:58:04	2020-04-09	14	[{"id_menu":2,"count":1}]	16870	delivery	5	19
48182	2020-04-09 16:02:15	2020-04-09	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	13542	delivery	5	25
48183	2020-04-09 16:28:31	2020-04-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4856	pick-up	0	23
48184	2020-04-09 16:38:07	2020-04-09	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	19143	delivery	5	45
48185	2020-04-09 16:53:43	2020-04-09	9	[{"id_menu":6,"count":1}]	19084	delivery	5	14
48186	2020-04-09 17:01:12	2020-04-09	17	[{"id_menu":4,"count":1}]	15142	delivery	5	22
48187	2020-04-09 17:03:10	2020-04-09	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18612	delivery	5	22
48188	2020-04-09 17:15:02	2020-04-09	12	[{"id_menu":1,"count":1}]	14480	delivery	5	17
48189	2020-04-09 17:16:01	2020-04-09	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19160	delivery	5	31
48190	2020-04-09 17:17:50	2020-04-09	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19150	delivery	5	22
48191	2020-04-09 17:28:51	2020-04-09	9	[{"id_menu":7,"count":1}]	19086	delivery	5	14
48192	2020-04-09 17:34:37	2020-04-09	9	[{"id_menu":7,"count":1}]	19134	delivery	5	14
48193	2020-04-09 17:39:38	2020-04-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15009	delivery	5	23
48194	2020-04-09 17:50:01	2020-04-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13047	delivery	5	23
48195	2020-04-09 17:51:56	2020-04-09	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2492	delivery	5	26
48196	2020-04-09 17:56:06	2020-04-09	9	[{"id_menu":6,"count":1}]	1314	pick-up	0	9
48197	2020-04-09 17:59:09	2020-04-09	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	15563	delivery	5	25
48198	2020-04-09 18:02:33	2020-04-09	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	19106	delivery	5	45
48199	2020-04-09 18:07:13	2020-04-09	14	[{"id_menu":2,"count":1}]	19170	delivery	5	19
48200	2020-04-09 18:11:06	2020-04-09	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15034	delivery	5	45
48201	2020-04-09 18:13:41	2020-04-09	9	[{"id_menu":7,"count":1}]	9358	delivery	5	14
48202	2020-04-09 18:15:56	2020-04-09	9	[{"id_menu":6,"count":1}]	6813	delivery	5	14
48203	2020-04-09 18:23:02	2020-04-09	12	[{"id_menu":1,"count":1}]	19060	delivery	5	17
48204	2020-04-09 18:31:41	2020-04-09	17	[{"id_menu":4,"count":1}]	14218	delivery	5	22
48205	2020-04-09 18:34:27	2020-04-09	12	[{"id_menu":1,"count":1}]	16561	delivery	5	17
48206	2020-04-09 18:36:18	2020-04-09	12	[{"id_menu":3,"count":1}]	9071	delivery	5	17
48207	2020-04-09 18:37:55	2020-04-09	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2729	delivery	5	34
48208	2020-04-09 18:42:19	2020-04-09	9	[{"id_menu":6,"count":1}]	19077	delivery	5	14
48209	2020-04-09 19:04:22	2020-04-09	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	9467	pick-up	0	38
48210	2020-04-09 19:05:30	2020-04-09	8	[{"id_menu":5,"count":1}]	13601	delivery	5	13
48211	2020-04-09 19:13:11	2020-04-09	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12541	pick-up	0	38
48212	2020-04-09 19:14:25	2020-04-09	8	[{"id_menu":5,"count":1}]	7726	pick-up	0	8
48213	2020-04-09 19:18:43	2020-04-09	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	16431	delivery	5	26
48214	2020-04-09 19:29:55	2020-04-09	12	[{"id_menu":1,"count":1}]	6394	delivery	5	17
48215	2020-04-09 19:32:20	2020-04-09	14	[{"id_menu":2,"count":1}]	19165	delivery	5	19
48216	2020-04-09 19:32:40	2020-04-09	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	19072	pick-up	0	31
48217	2020-04-09 19:33:47	2020-04-09	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15407	delivery	5	22
48218	2020-04-09 19:39:54	2020-04-09	14	[{"id_menu":2,"count":1}]	939	delivery	5	19
48219	2020-04-09 19:40:00	2020-04-09	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	19101	delivery	5	31
48220	2020-04-09 19:43:23	2020-04-09	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	19062	delivery	5	31
48221	2020-04-09 19:54:49	2020-04-09	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	15902	delivery	5	26
48222	2020-04-09 19:55:54	2020-04-09	12	[{"id_menu":3,"count":1}]	18036	delivery	5	17
48223	2020-04-09 19:57:52	2020-04-09	14	[{"id_menu":2,"count":2}]	14722	pick-up	0	14
48224	2020-04-09 20:02:09	2020-04-09	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	10244	pick-up	0	21
48225	2020-04-09 20:17:43	2020-04-09	12	[{"id_menu":1,"count":1}]	16500	delivery	5	17
48226	2020-04-09 20:20:45	2020-04-09	9	[{"id_menu":7,"count":1}]	563	pick-up	0	9
48227	2020-04-09 20:24:54	2020-04-09	12	[{"id_menu":1,"count":1}]	1979	pick-up	0	12
48228	2020-04-09 20:26:24	2020-04-09	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11093	delivery	5	53
48229	2020-04-09 20:26:55	2020-04-09	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	13261	delivery	5	37
48230	2020-04-09 20:40:20	2020-04-09	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8454	pick-up	0	31
48231	2020-04-09 20:44:39	2020-04-09	8	[{"id_menu":5,"count":1}]	15110	delivery	5	13
48232	2020-04-09 21:01:24	2020-04-09	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6444	delivery	5	43
48233	2020-04-09 21:01:41	2020-04-09	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3730	delivery	5	36
48234	2020-04-09 21:07:13	2020-04-09	8	[{"id_menu":5,"count":1}]	7785	delivery	5	13
48235	2020-04-09 21:15:11	2020-04-09	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	11647	delivery	5	35
48236	2020-04-09 21:16:44	2020-04-09	12	[{"id_menu":1,"count":1}]	1303	pick-up	0	12
48237	2020-04-09 21:17:23	2020-04-09	9	[{"id_menu":7,"count":1}]	5662	delivery	5	14
48238	2020-04-09 21:17:54	2020-04-09	17	[{"id_menu":4,"count":1}]	19122	delivery	5	22
48239	2020-04-09 21:19:57	2020-04-09	9	[{"id_menu":6,"count":1}]	1159	pick-up	0	9
48240	2020-04-09 21:28:34	2020-04-09	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	19161	delivery	5	38
48241	2020-04-09 21:31:45	2020-04-09	17	[{"id_menu":4,"count":2}]	19056	delivery	5	22
48242	2020-04-09 21:35:32	2020-04-09	14	[{"id_menu":2,"count":1}]	19133	delivery	5	19
48243	2020-04-09 21:36:47	2020-04-09	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19070	delivery	5	22
48244	2020-04-09 21:37:40	2020-04-09	37	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	12650	delivery	5	42
48245	2020-04-09 21:55:52	2020-04-09	9	[{"id_menu":6,"count":2}]	16671	delivery	5	14
48246	2020-04-09 21:57:37	2020-04-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7	pick-up	0	17
48247	2020-04-09 22:00:03	2020-04-09	14	[{"id_menu":2,"count":2}]	19125	delivery	5	19
48248	2020-04-09 22:04:04	2020-04-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	19175	delivery	5	28
48249	2020-04-09 22:08:16	2020-04-09	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19120	delivery	5	34
48250	2020-04-09 22:08:38	2020-04-09	8	[{"id_menu":5,"count":1}]	13602	delivery	5	13
48251	2020-04-09 22:12:21	2020-04-09	9	[{"id_menu":7,"count":1}]	3803	delivery	5	14
48252	2020-04-09 22:13:37	2020-04-09	14	[{"id_menu":2,"count":1}]	9178	pick-up	0	14
48253	2020-04-09 22:19:19	2020-04-09	14	[{"id_menu":2,"count":1}]	19068	delivery	5	19
48254	2020-04-09 22:21:24	2020-04-09	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7017	pick-up	0	34
48255	2020-04-09 22:31:57	2020-04-09	12	[{"id_menu":3,"count":1}]	17060	pick-up	0	12
48256	2020-04-09 22:32:18	2020-04-09	9	[{"id_menu":6,"count":1}]	19127	delivery	5	14
48257	2020-04-09 22:38:06	2020-04-09	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10284	delivery	5	39
48258	2020-04-09 22:40:19	2020-04-09	9	[{"id_menu":6,"count":1}]	12073	delivery	5	14
48259	2020-04-09 22:48:37	2020-04-09	12	[{"id_menu":3,"count":1}]	19095	delivery	5	17
48260	2020-04-09 22:55:03	2020-04-09	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	15189	delivery	5	26
48261	2020-04-09 22:59:53	2020-04-09	12	[{"id_menu":1,"count":1}]	1182	pick-up	0	12
48262	2020-04-09 23:08:11	2020-04-09	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	19131	delivery	5	25
48263	2020-04-09 23:21:10	2020-04-09	9	[{"id_menu":7,"count":1}]	2637	delivery	5	14
48264	2020-04-09 23:22:32	2020-04-09	14	[{"id_menu":2,"count":1}]	847	pick-up	0	14
48265	2020-04-09 23:22:47	2020-04-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	19156	delivery	5	23
48266	2020-04-09 23:30:29	2020-04-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9563	delivery	5	28
48267	2020-04-09 23:32:28	2020-04-09	14	[{"id_menu":2,"count":1}]	835	pick-up	0	14
48268	2020-04-09 23:36:06	2020-04-09	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	10313	delivery	5	46
48269	2020-04-09 23:38:26	2020-04-09	8	[{"id_menu":5,"count":1}]	5503	pick-up	0	8
48270	2020-04-09 23:44:06	2020-04-09	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	19066	delivery	5	31
48271	2020-04-09 23:46:20	2020-04-09	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	14089	pick-up	0	26
48272	2020-04-09 23:50:55	2020-04-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9628	delivery	5	28
48273	2020-04-09 23:53:46	2020-04-09	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19141	delivery	5	31
48274	2020-04-09 23:57:40	2020-04-09	14	[{"id_menu":2,"count":1}]	19113	delivery	5	19
48275	2020-04-10 00:06:45	2020-04-10	9	[{"id_menu":7,"count":1}]	3174	pick-up	0	9
48276	2020-04-10 00:10:57	2020-04-10	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	807	pick-up	0	26
48277	2020-04-10 00:18:34	2020-04-10	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	4342	pick-up	0	41
48278	2020-04-10 00:24:13	2020-04-10	14	[{"id_menu":2,"count":1}]	16114	pick-up	0	14
48279	2020-04-10 00:27:42	2020-04-10	14	[{"id_menu":2,"count":1}]	13477	pick-up	0	14
48280	2020-04-10 00:27:58	2020-04-10	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	13413	delivery	5	43
48281	2020-04-10 00:29:40	2020-04-10	8	[{"id_menu":5,"count":1}]	10243	delivery	5	13
48282	2020-04-10 00:38:33	2020-04-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	19246	delivery	5	28
48283	2020-04-10 00:44:17	2020-04-10	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	19276	pick-up	0	24
48284	2020-04-10 00:59:47	2020-04-10	9	[{"id_menu":6,"count":1}]	14569	pick-up	0	9
48285	2020-04-10 01:03:37	2020-04-10	8	[{"id_menu":5,"count":1}]	19278	delivery	5	13
48286	2020-04-10 01:06:39	2020-04-10	14	[{"id_menu":2,"count":1}]	15083	delivery	5	19
48287	2020-04-10 01:13:34	2020-04-10	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	2078	pick-up	0	26
48288	2020-04-10 01:17:07	2020-04-10	9	[{"id_menu":7,"count":2}]	13172	delivery	5	14
48289	2020-04-10 01:26:12	2020-04-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	17664	delivery	5	28
48290	2020-04-10 01:35:52	2020-04-10	9	[{"id_menu":7,"count":2}]	17578	pick-up	0	9
48291	2020-04-10 01:41:07	2020-04-10	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	372	pick-up	0	25
48292	2020-04-10 01:46:20	2020-04-10	12	[{"id_menu":1,"count":1}]	17387	delivery	5	17
48293	2020-04-10 01:46:25	2020-04-10	17	[{"id_menu":4,"count":1}]	1963	pick-up	0	17
48294	2020-04-10 01:48:33	2020-04-10	29	[{"id_menu":1,"count":3},{"id_menu":4,"count":1}]	19179	pick-up	0	29
48295	2020-04-10 01:51:58	2020-04-10	9	[{"id_menu":7,"count":1}]	2857	pick-up	0	9
48296	2020-04-10 02:05:49	2020-04-10	8	[{"id_menu":5,"count":1}]	18860	delivery	5	13
48297	2020-04-10 02:18:13	2020-04-10	17	[{"id_menu":4,"count":1}]	18408	delivery	5	22
48298	2020-04-10 02:23:03	2020-04-10	9	[{"id_menu":7,"count":1}]	4319	delivery	5	14
48299	2020-04-10 02:24:13	2020-04-10	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	19185	delivery	5	25
48300	2020-04-10 02:24:38	2020-04-10	9	[{"id_menu":7,"count":1}]	2072	pick-up	0	9
48301	2020-04-10 02:25:52	2020-04-10	9	[{"id_menu":6,"count":1}]	19313	pick-up	0	9
48302	2020-04-10 02:28:20	2020-04-10	8	[{"id_menu":5,"count":1}]	19300	pick-up	0	8
48303	2020-04-10 02:47:29	2020-04-10	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	19260	delivery	5	22
48304	2020-04-10 02:47:38	2020-04-10	9	[{"id_menu":7,"count":1}]	9610	delivery	5	14
48305	2020-04-10 02:53:14	2020-04-10	12	[{"id_menu":1,"count":1}]	5082	pick-up	0	12
48306	2020-04-10 02:54:04	2020-04-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	19232	delivery	5	28
48307	2020-04-10 02:55:02	2020-04-10	14	[{"id_menu":2,"count":1}]	10890	pick-up	0	14
48308	2020-04-10 02:57:10	2020-04-10	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	2415	pick-up	0	31
48309	2020-04-10 02:57:38	2020-04-10	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	8002	delivery	5	26
48310	2020-04-10 03:02:51	2020-04-10	12	[{"id_menu":3,"count":1}]	13563	delivery	5	17
48311	2020-04-10 03:05:46	2020-04-10	9	[{"id_menu":6,"count":1}]	7675	delivery	5	14
48312	2020-04-10 03:07:01	2020-04-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	19258	delivery	5	28
48313	2020-04-10 03:13:20	2020-04-10	12	[{"id_menu":3,"count":1}]	2170	pick-up	0	12
48314	2020-04-10 03:15:32	2020-04-10	17	[{"id_menu":4,"count":1}]	13363	delivery	5	22
48315	2020-04-10 03:17:26	2020-04-10	9	[{"id_menu":6,"count":1}]	1979	pick-up	0	9
48316	2020-04-10 03:18:10	2020-04-10	9	[{"id_menu":6,"count":1}]	19325	delivery	5	14
48317	2020-04-10 03:18:34	2020-04-10	12	[{"id_menu":3,"count":1}]	174	delivery	5	17
48318	2020-04-10 03:22:11	2020-04-10	9	[{"id_menu":6,"count":1}]	12280	delivery	5	14
48319	2020-04-10 03:22:56	2020-04-10	12	[{"id_menu":1,"count":1}]	6097	delivery	5	17
48320	2020-04-10 03:34:44	2020-04-10	8	[{"id_menu":5,"count":1}]	19327	delivery	5	13
48321	2020-04-10 03:38:20	2020-04-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	19326	delivery	5	22
48322	2020-04-10 03:39:27	2020-04-10	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	18330	delivery	5	22
48323	2020-04-10 03:39:32	2020-04-10	9	[{"id_menu":7,"count":1}]	13631	delivery	5	14
48324	2020-04-10 03:41:18	2020-04-10	9	[{"id_menu":6,"count":1}]	14499	delivery	5	14
48325	2020-04-10 03:46:41	2020-04-10	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	15766	delivery	5	30
48326	2020-04-10 03:50:27	2020-04-10	9	[{"id_menu":7,"count":1}]	2351	pick-up	0	9
48327	2020-04-10 04:11:03	2020-04-10	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19251	delivery	5	48
48328	2020-04-10 04:14:44	2020-04-10	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	19277	delivery	5	40
48329	2020-04-10 04:16:07	2020-04-10	9	[{"id_menu":6,"count":1}]	19220	pick-up	0	9
48330	2020-04-10 04:18:46	2020-04-10	12	[{"id_menu":3,"count":1}]	19177	delivery	5	17
48331	2020-04-10 04:21:14	2020-04-10	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	19234	delivery	5	26
48332	2020-04-10 04:24:16	2020-04-10	9	[{"id_menu":7,"count":1}]	14734	pick-up	0	9
48333	2020-04-10 04:27:44	2020-04-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	19305	delivery	5	28
48334	2020-04-10 04:31:20	2020-04-10	8	[{"id_menu":5,"count":1}]	19274	delivery	5	13
48335	2020-04-10 04:32:00	2020-04-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19228	delivery	5	22
48336	2020-04-10 04:34:58	2020-04-10	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	8339	delivery	5	34
48337	2020-04-10 04:35:33	2020-04-10	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	19218	pick-up	0	35
48338	2020-04-10 04:36:13	2020-04-10	9	[{"id_menu":7,"count":1}]	5783	delivery	5	14
48339	2020-04-10 04:42:06	2020-04-10	9	[{"id_menu":6,"count":2}]	9973	delivery	5	14
48340	2020-04-10 04:57:11	2020-04-10	14	[{"id_menu":2,"count":2}]	4320	delivery	5	19
48341	2020-04-10 05:08:13	2020-04-10	9	[{"id_menu":6,"count":1}]	356	pick-up	0	9
48342	2020-04-10 05:12:24	2020-04-10	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	19213	delivery	5	26
48343	2020-04-10 05:17:19	2020-04-10	14	[{"id_menu":2,"count":1}]	19317	delivery	5	19
48344	2020-04-10 05:17:41	2020-04-10	14	[{"id_menu":2,"count":1}]	19207	delivery	5	19
48345	2020-04-10 05:18:43	2020-04-10	8	[{"id_menu":5,"count":1}]	1978	delivery	5	13
48346	2020-04-10 05:21:04	2020-04-10	9	[{"id_menu":6,"count":1}]	5558	delivery	5	14
48347	2020-04-10 05:30:46	2020-04-10	14	[{"id_menu":2,"count":1}]	7007	delivery	5	19
48348	2020-04-10 05:32:50	2020-04-10	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	9235	delivery	5	23
48349	2020-04-10 05:33:30	2020-04-10	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	3940	pick-up	0	21
48350	2020-04-10 05:34:54	2020-04-10	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7341	pick-up	0	31
48351	2020-04-10 05:36:11	2020-04-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	13951	pick-up	0	23
48352	2020-04-10 05:41:11	2020-04-10	12	[{"id_menu":3,"count":1}]	15653	pick-up	0	12
48353	2020-04-10 05:47:17	2020-04-10	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	19205	delivery	5	31
48354	2020-04-10 05:52:17	2020-04-10	9	[{"id_menu":7,"count":2}]	19252	delivery	5	14
48355	2020-04-10 05:56:31	2020-04-10	8	[{"id_menu":5,"count":1}]	19272	pick-up	0	8
48356	2020-04-10 06:00:57	2020-04-10	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19320	delivery	5	35
48357	2020-04-10 06:04:54	2020-04-10	9	[{"id_menu":7,"count":1}]	19298	pick-up	0	9
48358	2020-04-10 06:06:26	2020-04-10	12	[{"id_menu":3,"count":1}]	19223	delivery	5	17
48359	2020-04-10 06:06:54	2020-04-10	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	19269	delivery	5	48
48360	2020-04-10 06:13:41	2020-04-10	33	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	12648	pick-up	0	33
48361	2020-04-10 06:14:53	2020-04-10	9	[{"id_menu":7,"count":1}]	16367	delivery	5	14
48362	2020-04-10 06:20:14	2020-04-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19294	delivery	5	23
48363	2020-04-10 06:22:25	2020-04-10	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6371	pick-up	0	31
48364	2020-04-10 06:23:28	2020-04-10	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2384	pick-up	0	43
48365	2020-04-10 06:26:44	2020-04-10	12	[{"id_menu":3,"count":1}]	19243	pick-up	0	12
48366	2020-04-10 06:28:35	2020-04-10	12	[{"id_menu":1,"count":1}]	19221	delivery	5	17
48367	2020-04-10 06:31:26	2020-04-10	17	[{"id_menu":4,"count":1}]	12455	delivery	5	22
48368	2020-04-10 06:32:17	2020-04-10	14	[{"id_menu":2,"count":1}]	7476	delivery	5	19
48369	2020-04-10 06:36:38	2020-04-10	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10666	delivery	5	44
48370	2020-04-10 06:37:09	2020-04-10	9	[{"id_menu":7,"count":1}]	19261	delivery	5	14
48371	2020-04-10 06:41:34	2020-04-10	9	[{"id_menu":6,"count":1}]	19299	delivery	5	14
48372	2020-04-10 06:43:03	2020-04-10	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	16443	delivery	5	40
48373	2020-04-10 06:44:14	2020-04-10	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	19257	delivery	5	26
48374	2020-04-10 06:44:23	2020-04-10	9	[{"id_menu":7,"count":1}]	13984	delivery	5	14
48375	2020-04-10 06:44:44	2020-04-10	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	19291	delivery	5	35
48376	2020-04-10 06:46:43	2020-04-10	14	[{"id_menu":2,"count":1}]	1104	pick-up	0	14
48377	2020-04-10 06:49:09	2020-04-10	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2556	delivery	5	31
48378	2020-04-10 06:50:07	2020-04-10	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	19308	delivery	5	39
48379	2020-04-10 06:54:37	2020-04-10	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	7983	pick-up	0	24
48380	2020-04-10 06:56:19	2020-04-10	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19242	delivery	5	48
48381	2020-04-10 07:10:21	2020-04-10	12	[{"id_menu":3,"count":1}]	11165	delivery	5	17
48382	2020-04-10 07:15:25	2020-04-10	14	[{"id_menu":2,"count":1}]	5773	delivery	5	19
48383	2020-04-10 07:17:24	2020-04-10	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	9535	delivery	5	23
48384	2020-04-10 07:19:58	2020-04-10	12	[{"id_menu":3,"count":1}]	19215	delivery	5	17
48385	2020-04-10 07:23:43	2020-04-10	14	[{"id_menu":2,"count":1}]	17790	pick-up	0	14
48386	2020-04-10 07:24:10	2020-04-10	8	[{"id_menu":5,"count":1}]	2729	delivery	5	13
48387	2020-04-10 07:28:41	2020-04-10	17	[{"id_menu":4,"count":1}]	9793	pick-up	0	17
48388	2020-04-10 07:30:09	2020-04-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":3}]	15426	delivery	5	28
48389	2020-04-10 07:32:23	2020-04-10	14	[{"id_menu":2,"count":1}]	19281	delivery	5	19
48390	2020-04-10 07:33:14	2020-04-10	17	[{"id_menu":4,"count":1}]	6883	delivery	5	22
48391	2020-04-10 07:35:29	2020-04-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19183	pick-up	0	18
48392	2020-04-10 07:42:27	2020-04-10	14	[{"id_menu":2,"count":1}]	2630	pick-up	0	14
48393	2020-04-10 07:43:24	2020-04-10	14	[{"id_menu":2,"count":1}]	19310	delivery	5	19
48394	2020-04-10 07:45:23	2020-04-10	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	12263	pick-up	0	20
48395	2020-04-10 07:47:49	2020-04-10	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	18602	delivery	5	29
48396	2020-04-10 07:58:32	2020-04-10	9	[{"id_menu":6,"count":1}]	19193	delivery	5	14
48397	2020-04-10 07:59:40	2020-04-10	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	11031	delivery	5	31
48398	2020-04-10 08:00:25	2020-04-10	8	[{"id_menu":5,"count":1}]	332	delivery	5	13
48399	2020-04-10 08:01:23	2020-04-10	37	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	19236	delivery	5	42
48400	2020-04-10 08:04:55	2020-04-10	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	17794	delivery	5	46
48401	2020-04-10 08:12:15	2020-04-10	14	[{"id_menu":2,"count":1}]	19265	delivery	5	19
48402	2020-04-10 08:16:42	2020-04-10	8	[{"id_menu":5,"count":1}]	10785	pick-up	0	8
48403	2020-04-10 08:19:47	2020-04-10	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2434	pick-up	0	21
48404	2020-04-10 08:20:42	2020-04-10	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	10296	delivery	5	36
48405	2020-04-10 08:22:27	2020-04-10	12	[{"id_menu":3,"count":1}]	19208	pick-up	0	12
48406	2020-04-10 08:24:59	2020-04-10	12	[{"id_menu":1,"count":1}]	6711	delivery	5	17
48407	2020-04-10 08:26:49	2020-04-10	9	[{"id_menu":6,"count":1}]	10958	delivery	5	14
48408	2020-04-10 08:27:05	2020-04-10	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	17412	delivery	5	31
48409	2020-04-10 08:28:41	2020-04-10	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	19198	delivery	5	34
48410	2020-04-10 08:35:38	2020-04-10	9	[{"id_menu":7,"count":1}]	9934	pick-up	0	9
48411	2020-04-10 08:36:47	2020-04-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1106	pick-up	0	18
48412	2020-04-10 08:41:29	2020-04-10	12	[{"id_menu":1,"count":1}]	3851	pick-up	0	12
48413	2020-04-10 08:42:36	2020-04-10	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	19323	delivery	5	25
48414	2020-04-10 08:43:01	2020-04-10	12	[{"id_menu":3,"count":1}]	19304	delivery	5	17
48415	2020-04-10 09:02:33	2020-04-10	14	[{"id_menu":2,"count":1}]	19247	delivery	5	19
48416	2020-04-10 09:14:56	2020-04-10	8	[{"id_menu":5,"count":1}]	9183	delivery	5	13
48417	2020-04-10 09:16:11	2020-04-10	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	15490	delivery	5	42
48418	2020-04-10 09:16:45	2020-04-10	12	[{"id_menu":1,"count":1}]	17924	delivery	5	17
48419	2020-04-10 09:16:56	2020-04-10	8	[{"id_menu":5,"count":1}]	11594	delivery	5	13
48420	2020-04-10 09:17:52	2020-04-10	14	[{"id_menu":2,"count":1}]	5572	delivery	5	19
48421	2020-04-10 09:29:05	2020-04-10	9	[{"id_menu":6,"count":1}]	19255	pick-up	0	9
48422	2020-04-10 09:31:33	2020-04-10	9	[{"id_menu":6,"count":1}]	13324	pick-up	0	9
48423	2020-04-10 09:32:29	2020-04-10	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	19315	delivery	5	38
48424	2020-04-10 09:38:08	2020-04-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	19283	delivery	5	28
48425	2020-04-10 09:57:28	2020-04-10	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	19203	delivery	5	26
48426	2020-04-10 10:04:15	2020-04-10	12	[{"id_menu":1,"count":1}]	19182	pick-up	0	12
48427	2020-04-10 10:05:12	2020-04-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	19322	delivery	5	28
48428	2020-04-10 10:05:16	2020-04-10	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	18122	pick-up	0	21
48429	2020-04-10 10:06:38	2020-04-10	14	[{"id_menu":2,"count":1}]	8620	pick-up	0	14
48430	2020-04-10 10:09:37	2020-04-10	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	19235	delivery	5	31
48431	2020-04-10 10:11:14	2020-04-10	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11283	delivery	5	22
48432	2020-04-10 10:16:55	2020-04-10	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7682	delivery	5	36
48433	2020-04-10 10:18:09	2020-04-10	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7044	delivery	5	22
48434	2020-04-10 10:23:38	2020-04-10	8	[{"id_menu":5,"count":1}]	19256	pick-up	0	8
48435	2020-04-10 10:25:03	2020-04-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	17889	delivery	5	28
48436	2020-04-10 10:39:45	2020-04-10	9	[{"id_menu":6,"count":2}]	19253	delivery	5	14
48437	2020-04-10 10:46:08	2020-04-10	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	14248	delivery	5	40
48438	2020-04-10 10:49:59	2020-04-10	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	268	delivery	5	31
48439	2020-04-10 10:53:12	2020-04-10	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	7338	delivery	5	29
48440	2020-04-10 10:55:24	2020-04-10	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	15528	pick-up	0	21
48441	2020-04-10 10:56:12	2020-04-10	9	[{"id_menu":7,"count":1}]	19296	delivery	5	14
48442	2020-04-10 10:58:56	2020-04-10	8	[{"id_menu":5,"count":1}]	19286	delivery	5	13
48443	2020-04-10 10:59:26	2020-04-10	8	[{"id_menu":5,"count":1}]	19287	pick-up	0	8
48444	2020-04-10 11:01:04	2020-04-10	9	[{"id_menu":7,"count":1}]	19329	delivery	5	14
48445	2020-04-10 11:13:35	2020-04-10	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	1638	delivery	5	28
48446	2020-04-10 11:18:53	2020-04-10	9	[{"id_menu":7,"count":1}]	19009	delivery	5	14
48447	2020-04-10 11:29:30	2020-04-10	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":2}]	19262	delivery	5	31
48448	2020-04-10 11:32:38	2020-04-10	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	19267	delivery	5	25
48449	2020-04-10 11:36:13	2020-04-10	14	[{"id_menu":2,"count":1}]	6182	delivery	5	19
48450	2020-04-10 11:45:45	2020-04-10	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	19204	delivery	5	26
48451	2020-04-10 11:59:01	2020-04-10	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	3979	delivery	5	37
48452	2020-04-10 12:03:41	2020-04-10	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	13602	delivery	5	39
48453	2020-04-10 12:03:49	2020-04-10	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	11146	delivery	5	26
48454	2020-04-10 12:04:30	2020-04-10	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	19083	delivery	5	52
48455	2020-04-10 12:05:52	2020-04-10	12	[{"id_menu":1,"count":1}]	19270	delivery	5	17
48456	2020-04-10 12:11:21	2020-04-10	9	[{"id_menu":7,"count":1}]	19233	pick-up	0	9
48457	2020-04-10 12:11:25	2020-04-10	9	[{"id_menu":7,"count":1}]	19301	delivery	5	14
48458	2020-04-10 12:19:53	2020-04-10	8	[{"id_menu":5,"count":1}]	11904	pick-up	0	8
48459	2020-04-10 12:21:28	2020-04-10	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15235	delivery	5	35
48460	2020-04-10 12:22:26	2020-04-10	12	[{"id_menu":3,"count":1}]	16560	delivery	5	17
48461	2020-04-10 12:22:52	2020-04-10	12	[{"id_menu":3,"count":1}]	19268	pick-up	0	12
48462	2020-04-10 12:23:40	2020-04-10	14	[{"id_menu":2,"count":1}]	7293	delivery	5	19
48463	2020-04-10 12:31:43	2020-04-10	12	[{"id_menu":3,"count":1}]	3634	pick-up	0	12
48464	2020-04-10 12:32:48	2020-04-10	9	[{"id_menu":6,"count":2}]	19197	delivery	5	14
48465	2020-04-10 12:32:54	2020-04-10	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	3231	delivery	5	22
48466	2020-04-10 12:32:59	2020-04-10	8	[{"id_menu":5,"count":2}]	14585	pick-up	0	8
48467	2020-04-10 12:40:39	2020-04-10	9	[{"id_menu":7,"count":1}]	15568	delivery	5	14
48468	2020-04-10 12:42:10	2020-04-10	17	[{"id_menu":4,"count":1}]	13393	delivery	5	22
48469	2020-04-10 12:42:47	2020-04-10	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	13303	delivery	5	25
48470	2020-04-10 12:55:19	2020-04-10	9	[{"id_menu":7,"count":1}]	19184	delivery	5	14
48471	2020-04-10 12:57:16	2020-04-10	9	[{"id_menu":6,"count":1}]	19330	delivery	5	14
48472	2020-04-10 12:57:53	2020-04-10	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	4471	delivery	5	26
48473	2020-04-10 12:58:31	2020-04-10	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	19244	delivery	5	25
48474	2020-04-10 12:58:47	2020-04-10	17	[{"id_menu":4,"count":1}]	19186	pick-up	0	17
48475	2020-04-10 13:09:25	2020-04-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15690	delivery	5	23
48476	2020-04-10 13:17:03	2020-04-10	12	[{"id_menu":3,"count":1}]	9509	pick-up	0	12
48477	2020-04-10 13:21:46	2020-04-10	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":2}]	15600	delivery	5	22
48478	2020-04-10 13:23:52	2020-04-10	9	[{"id_menu":7,"count":1}]	13007	pick-up	0	9
48479	2020-04-10 13:33:35	2020-04-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	16501	pick-up	0	23
48480	2020-04-10 13:38:03	2020-04-10	17	[{"id_menu":4,"count":1}]	19254	delivery	5	22
48481	2020-04-10 13:43:53	2020-04-10	12	[{"id_menu":3,"count":1}]	19282	delivery	5	17
48482	2020-04-10 13:45:58	2020-04-10	12	[{"id_menu":1,"count":1}]	5780	pick-up	0	12
48483	2020-04-10 13:46:51	2020-04-10	14	[{"id_menu":2,"count":1}]	14710	delivery	5	19
48484	2020-04-10 13:50:36	2020-04-10	12	[{"id_menu":1,"count":1}]	2519	pick-up	0	12
48485	2020-04-10 13:51:27	2020-04-10	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10651	delivery	5	22
48486	2020-04-10 13:51:55	2020-04-10	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	18409	pick-up	0	24
48487	2020-04-10 13:53:05	2020-04-10	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5975	delivery	5	53
48488	2020-04-10 14:00:47	2020-04-10	12	[{"id_menu":1,"count":1}]	19312	delivery	5	17
48489	2020-04-10 14:01:15	2020-04-10	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	11681	pick-up	0	20
48490	2020-04-10 14:10:42	2020-04-10	14	[{"id_menu":2,"count":2}]	5687	delivery	5	19
48491	2020-04-10 14:23:00	2020-04-10	17	[{"id_menu":4,"count":1}]	2937	pick-up	0	17
48492	2020-04-10 14:24:02	2020-04-10	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19216	delivery	5	31
48493	2020-04-10 14:27:52	2020-04-10	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6526	delivery	5	31
48494	2020-04-10 14:36:17	2020-04-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	8188	delivery	5	28
48495	2020-04-10 14:46:42	2020-04-10	12	[{"id_menu":3,"count":1}]	29	pick-up	0	12
48496	2020-04-10 14:47:59	2020-04-10	9	[{"id_menu":7,"count":2}]	19309	pick-up	0	9
48497	2020-04-10 15:01:17	2020-04-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	497	pick-up	0	23
48498	2020-04-10 15:01:25	2020-04-10	9	[{"id_menu":7,"count":1}]	3173	delivery	5	14
48499	2020-04-10 15:05:26	2020-04-10	9	[{"id_menu":6,"count":1}]	19241	delivery	5	14
48500	2020-04-10 15:18:38	2020-04-10	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	19195	delivery	5	28
48501	2020-04-10 15:20:29	2020-04-10	17	[{"id_menu":4,"count":1}]	730	pick-up	0	17
48502	2020-04-10 15:20:30	2020-04-10	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	7103	pick-up	0	37
48503	2020-04-10 15:21:49	2020-04-10	9	[{"id_menu":7,"count":1}]	369	pick-up	0	9
48504	2020-04-10 15:23:22	2020-04-10	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	3332	pick-up	0	21
48505	2020-04-10 15:46:26	2020-04-10	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	2780	delivery	5	26
48506	2020-04-10 15:48:33	2020-04-10	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	11217	delivery	5	40
48507	2020-04-10 15:48:54	2020-04-10	8	[{"id_menu":5,"count":1}]	19209	delivery	5	13
48508	2020-04-10 15:50:46	2020-04-10	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	18500	delivery	5	31
48509	2020-04-10 15:55:29	2020-04-10	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	19290	delivery	5	31
48510	2020-04-10 15:56:52	2020-04-10	14	[{"id_menu":2,"count":1}]	17736	delivery	5	19
48511	2020-04-10 15:58:18	2020-04-10	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	19212	pick-up	0	21
48512	2020-04-10 16:09:13	2020-04-10	9	[{"id_menu":6,"count":1}]	18593	delivery	5	14
48513	2020-04-10 16:17:55	2020-04-10	9	[{"id_menu":6,"count":1}]	8136	delivery	5	14
48514	2020-04-10 16:18:42	2020-04-10	9	[{"id_menu":6,"count":1}]	19319	delivery	5	14
48515	2020-04-10 16:30:32	2020-04-10	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	11334	pick-up	0	21
48516	2020-04-10 16:30:45	2020-04-10	14	[{"id_menu":2,"count":1}]	17180	pick-up	0	14
48517	2020-04-10 16:37:13	2020-04-10	9	[{"id_menu":7,"count":1}]	19196	pick-up	0	9
48518	2020-04-10 16:38:33	2020-04-10	14	[{"id_menu":2,"count":1}]	17464	delivery	5	19
48519	2020-04-10 16:47:06	2020-04-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14711	delivery	5	23
48520	2020-04-10 16:49:20	2020-04-10	30	[{"id_menu":1,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19264	delivery	5	35
48521	2020-04-10 16:50:48	2020-04-10	14	[{"id_menu":2,"count":1}]	9737	delivery	5	19
48522	2020-04-10 16:52:28	2020-04-10	9	[{"id_menu":7,"count":1}]	4227	delivery	5	14
48523	2020-04-10 16:55:45	2020-04-10	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	19263	delivery	5	22
48524	2020-04-10 16:56:40	2020-04-10	12	[{"id_menu":3,"count":1}]	19237	delivery	5	17
48525	2020-04-10 16:59:48	2020-04-10	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16677	pick-up	0	38
48526	2020-04-10 17:00:28	2020-04-10	12	[{"id_menu":1,"count":1}]	9995	delivery	5	17
48527	2020-04-10 17:05:55	2020-04-10	9	[{"id_menu":6,"count":1}]	12293	delivery	5	14
48528	2020-04-10 17:09:23	2020-04-10	8	[{"id_menu":5,"count":1}]	19231	delivery	5	13
48529	2020-04-10 17:10:25	2020-04-10	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5511	delivery	5	37
48530	2020-04-10 17:11:57	2020-04-10	9	[{"id_menu":7,"count":2}]	19230	delivery	5	14
48531	2020-04-10 17:17:32	2020-04-10	17	[{"id_menu":4,"count":1}]	19217	delivery	5	22
48532	2020-04-10 17:40:10	2020-04-10	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	719	pick-up	0	44
48533	2020-04-10 17:44:49	2020-04-10	8	[{"id_menu":5,"count":1}]	5094	delivery	5	13
48534	2020-04-10 17:47:04	2020-04-10	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	12199	delivery	5	23
48535	2020-04-10 17:50:20	2020-04-10	12	[{"id_menu":1,"count":1}]	9181	delivery	5	17
48536	2020-04-10 18:00:36	2020-04-10	14	[{"id_menu":2,"count":1}]	1166	pick-up	0	14
48537	2020-04-10 18:01:22	2020-04-10	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	72	delivery	5	26
48538	2020-04-10 18:06:14	2020-04-10	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	12811	delivery	5	26
48539	2020-04-10 18:08:26	2020-04-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	12180	delivery	5	28
48540	2020-04-10 18:08:27	2020-04-10	17	[{"id_menu":4,"count":3}]	19201	delivery	5	22
48541	2020-04-10 18:12:52	2020-04-10	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	5523	delivery	5	22
48542	2020-04-10 18:15:17	2020-04-10	12	[{"id_menu":1,"count":1}]	1544	delivery	5	17
48543	2020-04-10 18:17:22	2020-04-10	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	17472	delivery	5	25
48544	2020-04-10 18:23:58	2020-04-10	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	4465	pick-up	0	29
48545	2020-04-10 18:31:21	2020-04-10	12	[{"id_menu":1,"count":1}]	19273	delivery	5	17
48546	2020-04-10 18:32:45	2020-04-10	9	[{"id_menu":6,"count":1}]	3883	delivery	5	14
48547	2020-04-10 18:35:38	2020-04-10	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	8074	delivery	5	40
48548	2020-04-10 18:36:14	2020-04-10	17	[{"id_menu":4,"count":2}]	17295	pick-up	0	17
48549	2020-04-10 18:37:46	2020-04-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	19333	delivery	5	28
48550	2020-04-10 18:38:08	2020-04-10	8	[{"id_menu":5,"count":1}]	1470	pick-up	0	8
48551	2020-04-10 18:48:04	2020-04-10	9	[{"id_menu":7,"count":1}]	13100	delivery	5	14
48552	2020-04-10 18:53:18	2020-04-10	12	[{"id_menu":1,"count":1}]	4739	delivery	5	17
48553	2020-04-10 18:55:29	2020-04-10	9	[{"id_menu":6,"count":1}]	14474	delivery	5	14
48554	2020-04-10 18:56:45	2020-04-10	9	[{"id_menu":7,"count":1}]	19210	delivery	5	14
48555	2020-04-10 18:58:12	2020-04-10	12	[{"id_menu":1,"count":1}]	19194	delivery	5	17
48556	2020-04-10 19:00:29	2020-04-10	8	[{"id_menu":5,"count":1}]	6372	delivery	5	13
48557	2020-04-10 19:09:18	2020-04-10	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	19192	delivery	5	26
48558	2020-04-10 19:09:55	2020-04-10	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	19295	delivery	5	27
48559	2020-04-10 19:20:04	2020-04-10	12	[{"id_menu":1,"count":1}]	352	pick-up	0	12
48560	2020-04-10 19:21:17	2020-04-10	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19239	delivery	5	34
48561	2020-04-10 19:37:27	2020-04-10	9	[{"id_menu":7,"count":1}]	2613	pick-up	0	9
48562	2020-04-10 19:58:05	2020-04-10	17	[{"id_menu":4,"count":1}]	1052	delivery	5	22
48563	2020-04-10 19:59:13	2020-04-10	14	[{"id_menu":2,"count":1}]	5919	delivery	5	19
48564	2020-04-10 19:59:41	2020-04-10	17	[{"id_menu":4,"count":1}]	9175	delivery	5	22
48565	2020-04-10 19:59:44	2020-04-10	14	[{"id_menu":2,"count":1}]	19128	delivery	5	19
48566	2020-04-10 20:04:36	2020-04-10	12	[{"id_menu":1,"count":1}]	11076	delivery	5	17
48567	2020-04-10 20:13:59	2020-04-10	14	[{"id_menu":2,"count":1}]	19206	delivery	5	19
48568	2020-04-10 20:15:17	2020-04-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19288	delivery	5	23
48569	2020-04-10 20:17:51	2020-04-10	12	[{"id_menu":3,"count":1}]	19311	delivery	5	17
48570	2020-04-10 20:19:22	2020-04-10	17	[{"id_menu":4,"count":1}]	12664	delivery	5	22
48571	2020-04-10 20:21:39	2020-04-10	14	[{"id_menu":2,"count":1}]	19222	delivery	5	19
48572	2020-04-10 20:22:21	2020-04-10	17	[{"id_menu":4,"count":1}]	7834	delivery	5	22
48573	2020-04-10 20:31:22	2020-04-10	9	[{"id_menu":7,"count":1}]	17138	delivery	5	14
48574	2020-04-10 20:32:17	2020-04-10	12	[{"id_menu":1,"count":1}]	17963	delivery	5	17
48575	2020-04-10 20:47:35	2020-04-10	9	[{"id_menu":6,"count":1}]	4527	delivery	5	14
48576	2020-04-10 20:47:40	2020-04-10	17	[{"id_menu":4,"count":1}]	7782	delivery	5	22
48577	2020-04-10 20:52:13	2020-04-10	9	[{"id_menu":6,"count":1}]	13979	delivery	5	14
48578	2020-04-10 20:52:32	2020-04-10	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	19226	delivery	5	26
48579	2020-04-10 20:56:17	2020-04-10	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":2}]	4641	pick-up	0	26
48580	2020-04-10 21:12:05	2020-04-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19280	delivery	5	22
48581	2020-04-10 21:14:04	2020-04-10	9	[{"id_menu":6,"count":1}]	11545	delivery	5	14
48582	2020-04-10 21:19:39	2020-04-10	9	[{"id_menu":7,"count":1}]	670	delivery	5	14
48583	2020-04-10 21:24:54	2020-04-10	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	4061	delivery	5	22
48584	2020-04-10 21:30:59	2020-04-10	9	[{"id_menu":7,"count":1}]	9022	delivery	5	14
48585	2020-04-10 21:38:11	2020-04-10	14	[{"id_menu":2,"count":2}]	2301	delivery	5	19
48586	2020-04-10 21:38:48	2020-04-10	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16749	delivery	5	43
48587	2020-04-10 21:43:21	2020-04-10	9	[{"id_menu":7,"count":1}]	16217	pick-up	0	9
48588	2020-04-10 21:44:42	2020-04-10	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	19271	delivery	5	30
48589	2020-04-10 21:44:49	2020-04-10	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	562	delivery	5	42
48590	2020-04-10 21:45:37	2020-04-10	8	[{"id_menu":5,"count":1}]	19249	delivery	5	13
48591	2020-04-10 21:49:40	2020-04-10	12	[{"id_menu":1,"count":1}]	16627	pick-up	0	12
48592	2020-04-10 21:51:31	2020-04-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7705	delivery	5	28
48593	2020-04-10 21:53:32	2020-04-10	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19328	delivery	5	34
48594	2020-04-10 21:58:37	2020-04-10	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5019	delivery	5	44
48595	2020-04-10 22:00:33	2020-04-10	9	[{"id_menu":6,"count":1}]	3733	delivery	5	14
48596	2020-04-10 22:02:13	2020-04-10	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	19219	delivery	5	30
48597	2020-04-10 22:02:25	2020-04-10	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	18793	pick-up	0	29
48598	2020-04-10 22:04:56	2020-04-10	9	[{"id_menu":7,"count":1}]	14903	delivery	5	14
48599	2020-04-10 22:06:58	2020-04-10	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	19292	delivery	5	40
48600	2020-04-10 22:10:11	2020-04-10	9	[{"id_menu":7,"count":1}]	12385	delivery	5	14
48601	2020-04-10 22:11:20	2020-04-10	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	16840	delivery	5	26
48602	2020-04-10 22:15:08	2020-04-10	9	[{"id_menu":6,"count":1}]	5299	pick-up	0	9
48603	2020-04-10 22:16:38	2020-04-10	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	9725	delivery	5	22
48604	2020-04-10 22:19:55	2020-04-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	527	delivery	5	28
48605	2020-04-10 22:20:58	2020-04-10	12	[{"id_menu":1,"count":1}]	19238	pick-up	0	12
48606	2020-04-10 22:25:27	2020-04-10	12	[{"id_menu":3,"count":1}]	19302	delivery	5	17
48607	2020-04-10 22:34:54	2020-04-10	12	[{"id_menu":1,"count":1}]	5401	delivery	5	17
48608	2020-04-10 22:39:53	2020-04-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	19307	delivery	5	28
48609	2020-04-10 22:46:27	2020-04-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7451	delivery	5	28
48610	2020-04-10 22:50:08	2020-04-10	17	[{"id_menu":4,"count":1}]	19324	delivery	5	22
48611	2020-04-10 22:52:10	2020-04-10	8	[{"id_menu":5,"count":1}]	8877	delivery	5	13
48612	2020-04-10 22:53:47	2020-04-10	12	[{"id_menu":3,"count":1}]	5247	delivery	5	17
48613	2020-04-10 23:01:40	2020-04-10	12	[{"id_menu":3,"count":1}]	19321	pick-up	0	12
48614	2020-04-10 23:03:07	2020-04-10	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	19191	delivery	5	27
48615	2020-04-10 23:07:54	2020-04-10	12	[{"id_menu":1,"count":1}]	16321	pick-up	0	12
48616	2020-04-10 23:11:54	2020-04-10	12	[{"id_menu":1,"count":1}]	19211	delivery	5	17
48617	2020-04-10 23:12:26	2020-04-10	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1079	delivery	5	25
48618	2020-04-10 23:22:13	2020-04-10	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	19266	delivery	5	31
48619	2020-04-10 23:30:27	2020-04-10	14	[{"id_menu":2,"count":1}]	6250	pick-up	0	14
48620	2020-04-10 23:30:40	2020-04-10	17	[{"id_menu":4,"count":1}]	2517	delivery	5	22
48621	2020-04-10 23:31:10	2020-04-10	12	[{"id_menu":1,"count":1}]	19225	delivery	5	17
48622	2020-04-10 23:32:58	2020-04-10	9	[{"id_menu":6,"count":1}]	19284	delivery	5	14
48623	2020-04-10 23:36:04	2020-04-10	12	[{"id_menu":3,"count":1}]	19259	delivery	5	17
48624	2020-04-10 23:36:27	2020-04-10	8	[{"id_menu":5,"count":1}]	19229	delivery	5	13
48625	2020-04-10 23:38:51	2020-04-10	14	[{"id_menu":2,"count":1}]	177	delivery	5	19
48626	2020-04-10 23:45:59	2020-04-10	17	[{"id_menu":4,"count":1}]	19250	delivery	5	22
48627	2020-04-10 23:50:37	2020-04-10	9	[{"id_menu":6,"count":1}]	14834	delivery	5	14
48628	2020-04-10 23:50:53	2020-04-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	4618	delivery	5	23
48629	2020-04-11 00:00:14	2020-04-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	19509	delivery	5	23
48630	2020-04-11 00:08:33	2020-04-11	9	[{"id_menu":6,"count":1}]	19420	pick-up	0	9
48631	2020-04-11 00:10:06	2020-04-11	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	17370	delivery	5	56
48632	2020-04-11 00:10:35	2020-04-11	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	17431	delivery	5	31
48633	2020-04-11 00:12:03	2020-04-11	9	[{"id_menu":7,"count":1}]	4595	pick-up	0	9
48634	2020-04-11 00:19:13	2020-04-11	9	[{"id_menu":6,"count":1}]	19468	delivery	5	14
48635	2020-04-11 00:20:25	2020-04-11	9	[{"id_menu":6,"count":1}]	19486	pick-up	0	9
48636	2020-04-11 00:22:56	2020-04-11	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14813	delivery	5	34
48637	2020-04-11 00:25:08	2020-04-11	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16951	delivery	5	22
48638	2020-04-11 00:27:13	2020-04-11	9	[{"id_menu":6,"count":1}]	131	delivery	5	14
48639	2020-04-11 00:29:43	2020-04-11	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	14089	pick-up	0	26
48640	2020-04-11 00:29:50	2020-04-11	17	[{"id_menu":4,"count":1}]	9483	pick-up	0	17
48641	2020-04-11 00:30:22	2020-04-11	9	[{"id_menu":6,"count":1}]	11773	delivery	5	14
48642	2020-04-11 00:33:56	2020-04-11	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	3040	delivery	5	26
48643	2020-04-11 00:40:47	2020-04-11	14	[{"id_menu":2,"count":1}]	1445	delivery	5	19
48644	2020-04-11 00:40:49	2020-04-11	9	[{"id_menu":6,"count":1}]	19334	delivery	5	14
48645	2020-04-11 00:40:55	2020-04-11	12	[{"id_menu":1,"count":1}]	19508	delivery	5	17
48646	2020-04-11 00:41:04	2020-04-11	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	11686	pick-up	0	26
48647	2020-04-11 00:50:19	2020-04-11	14	[{"id_menu":2,"count":1}]	19452	pick-up	0	14
48648	2020-04-11 01:02:54	2020-04-11	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	19343	delivery	5	42
48649	2020-04-11 01:08:16	2020-04-11	17	[{"id_menu":4,"count":1}]	19421	delivery	5	22
48650	2020-04-11 01:17:44	2020-04-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":3}]	3579	delivery	5	23
48651	2020-04-11 01:27:58	2020-04-11	9	[{"id_menu":7,"count":1}]	351	delivery	5	14
48652	2020-04-11 01:29:54	2020-04-11	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19459	delivery	5	46
48653	2020-04-11 01:33:14	2020-04-11	17	[{"id_menu":4,"count":1}]	11586	delivery	5	22
48654	2020-04-11 01:34:43	2020-04-11	9	[{"id_menu":7,"count":1}]	14710	pick-up	0	9
48655	2020-04-11 01:35:01	2020-04-11	8	[{"id_menu":5,"count":1}]	1080	pick-up	0	8
48656	2020-04-11 01:45:51	2020-04-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	12024	delivery	5	28
48657	2020-04-11 01:46:00	2020-04-11	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":3}]	16954	delivery	5	28
48658	2020-04-11 01:46:56	2020-04-11	12	[{"id_menu":1,"count":1}]	5972	delivery	5	17
48659	2020-04-11 01:47:23	2020-04-11	9	[{"id_menu":6,"count":1}]	11401	delivery	5	14
48660	2020-04-11 01:47:48	2020-04-11	9	[{"id_menu":7,"count":1}]	12970	pick-up	0	9
48661	2020-04-11 01:50:51	2020-04-11	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	19418	delivery	5	40
48662	2020-04-11 01:51:51	2020-04-11	8	[{"id_menu":5,"count":1}]	19360	pick-up	0	8
48663	2020-04-11 01:52:02	2020-04-11	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	14547	delivery	5	26
48664	2020-04-11 01:57:00	2020-04-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9976	delivery	5	23
48665	2020-04-11 01:59:44	2020-04-11	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	5292	delivery	5	26
48666	2020-04-11 02:00:35	2020-04-11	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	15776	delivery	5	31
48667	2020-04-11 02:07:03	2020-04-11	14	[{"id_menu":2,"count":1}]	6848	pick-up	0	14
48668	2020-04-11 02:07:50	2020-04-11	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	14081	delivery	5	36
48669	2020-04-11 02:12:13	2020-04-11	14	[{"id_menu":2,"count":1}]	13670	delivery	5	19
48670	2020-04-11 02:14:53	2020-04-11	9	[{"id_menu":6,"count":1}]	12208	delivery	5	14
48671	2020-04-11 02:18:31	2020-04-11	9	[{"id_menu":6,"count":2}]	6009	pick-up	0	9
48672	2020-04-11 02:21:55	2020-04-11	12	[{"id_menu":1,"count":1}]	19403	delivery	5	17
48673	2020-04-11 02:22:53	2020-04-11	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14263	delivery	5	31
48674	2020-04-11 02:27:23	2020-04-11	17	[{"id_menu":4,"count":1}]	19506	pick-up	0	17
48675	2020-04-11 02:29:01	2020-04-11	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	6740	delivery	5	22
48676	2020-04-11 02:31:21	2020-04-11	9	[{"id_menu":6,"count":1}]	19075	pick-up	0	9
48677	2020-04-11 02:40:41	2020-04-11	9	[{"id_menu":7,"count":1}]	3877	pick-up	0	9
48678	2020-04-11 02:42:15	2020-04-11	32	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	19447	pick-up	0	32
48679	2020-04-11 02:46:50	2020-04-11	14	[{"id_menu":2,"count":1}]	14052	delivery	5	19
48680	2020-04-11 02:46:57	2020-04-11	9	[{"id_menu":7,"count":1}]	16136	delivery	5	14
48681	2020-04-11 02:49:53	2020-04-11	17	[{"id_menu":4,"count":1}]	3598	delivery	5	22
48682	2020-04-11 02:50:11	2020-04-11	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	19511	delivery	5	31
48683	2020-04-11 02:53:31	2020-04-11	12	[{"id_menu":3,"count":1}]	4022	delivery	5	17
48684	2020-04-11 02:55:04	2020-04-11	9	[{"id_menu":6,"count":1}]	7460	delivery	5	14
48685	2020-04-11 02:59:33	2020-04-11	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3964	delivery	5	27
48686	2020-04-11 03:01:31	2020-04-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14290	delivery	5	23
48687	2020-04-11 03:01:39	2020-04-11	17	[{"id_menu":4,"count":1}]	17145	pick-up	0	17
48688	2020-04-11 03:02:20	2020-04-11	14	[{"id_menu":2,"count":1}]	572	delivery	5	19
48689	2020-04-11 03:03:56	2020-04-11	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	19475	delivery	5	45
48690	2020-04-11 03:04:31	2020-04-11	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	19453	delivery	5	31
48691	2020-04-11 03:08:47	2020-04-11	9	[{"id_menu":6,"count":1}]	11268	delivery	5	14
48692	2020-04-11 03:11:58	2020-04-11	9	[{"id_menu":7,"count":1}]	19481	delivery	5	14
48693	2020-04-11 03:12:55	2020-04-11	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	19371	delivery	5	25
48694	2020-04-11 03:13:20	2020-04-11	14	[{"id_menu":2,"count":2}]	17649	pick-up	0	14
48695	2020-04-11 03:13:34	2020-04-11	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	15829	pick-up	0	21
48696	2020-04-11 03:17:33	2020-04-11	26	[{"id_menu":4,"count":3},{"id_menu":7,"count":1}]	19407	delivery	5	31
48697	2020-04-11 03:19:23	2020-04-11	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19500	delivery	5	45
48698	2020-04-11 03:23:01	2020-04-11	14	[{"id_menu":2,"count":1}]	19455	pick-up	0	14
48699	2020-04-11 03:26:12	2020-04-11	9	[{"id_menu":6,"count":1}]	8801	delivery	5	14
48700	2020-04-11 03:27:24	2020-04-11	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	19375	delivery	5	44
48701	2020-04-11 03:30:34	2020-04-11	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	19436	delivery	5	26
48702	2020-04-11 03:43:11	2020-04-11	9	[{"id_menu":6,"count":1}]	14065	delivery	5	14
48703	2020-04-11 03:55:09	2020-04-11	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	19445	delivery	5	26
48704	2020-04-11 03:58:00	2020-04-11	9	[{"id_menu":6,"count":1}]	19472	delivery	5	14
48705	2020-04-11 03:59:37	2020-04-11	12	[{"id_menu":1,"count":1}]	3275	pick-up	0	12
48706	2020-04-11 04:00:23	2020-04-11	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	17790	pick-up	0	21
48707	2020-04-11 04:07:08	2020-04-11	9	[{"id_menu":7,"count":1}]	19395	delivery	5	14
48708	2020-04-11 04:09:51	2020-04-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4060	delivery	5	22
48709	2020-04-11 04:12:44	2020-04-11	17	[{"id_menu":4,"count":1}]	2187	delivery	5	22
48710	2020-04-11 04:26:35	2020-04-11	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	19380	delivery	5	27
48711	2020-04-11 04:30:43	2020-04-11	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	11260	pick-up	0	21
48712	2020-04-11 04:36:31	2020-04-11	14	[{"id_menu":2,"count":1}]	2434	pick-up	0	14
48713	2020-04-11 04:40:32	2020-04-11	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	19457	delivery	5	34
48714	2020-04-11 04:49:56	2020-04-11	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	19351	delivery	5	29
48715	2020-04-11 04:52:48	2020-04-11	9	[{"id_menu":6,"count":2}]	19400	delivery	5	14
48716	2020-04-11 04:56:50	2020-04-11	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	11087	delivery	5	23
48717	2020-04-11 05:05:09	2020-04-11	9	[{"id_menu":7,"count":1}]	19406	delivery	5	14
48718	2020-04-11 05:05:37	2020-04-11	8	[{"id_menu":5,"count":1}]	1716	pick-up	0	8
48719	2020-04-11 05:07:12	2020-04-11	12	[{"id_menu":3,"count":1}]	14036	delivery	5	17
48720	2020-04-11 05:09:08	2020-04-11	12	[{"id_menu":1,"count":1}]	19388	pick-up	0	12
48721	2020-04-11 05:10:07	2020-04-11	9	[{"id_menu":7,"count":1}]	11558	delivery	5	14
48722	2020-04-11 05:18:44	2020-04-11	14	[{"id_menu":2,"count":1}]	19342	delivery	5	19
48723	2020-04-11 05:21:09	2020-04-11	12	[{"id_menu":3,"count":1}]	19493	delivery	5	17
48724	2020-04-11 05:22:00	2020-04-11	38	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12907	delivery	5	43
48725	2020-04-11 05:23:20	2020-04-11	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9941	pick-up	0	39
48726	2020-04-11 05:23:59	2020-04-11	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	19485	delivery	5	31
48727	2020-04-11 05:25:34	2020-04-11	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	14167	delivery	5	26
48728	2020-04-11 05:30:13	2020-04-11	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	204	delivery	5	38
48729	2020-04-11 05:31:58	2020-04-11	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	19346	delivery	5	26
48730	2020-04-11 05:33:24	2020-04-11	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	19419	delivery	5	38
48731	2020-04-11 05:33:57	2020-04-11	12	[{"id_menu":1,"count":1}]	24	pick-up	0	12
48732	2020-04-11 05:37:41	2020-04-11	12	[{"id_menu":3,"count":1}]	16659	pick-up	0	12
48733	2020-04-11 05:38:46	2020-04-11	12	[{"id_menu":1,"count":1}]	4287	delivery	5	17
48734	2020-04-11 05:44:51	2020-04-11	14	[{"id_menu":2,"count":1}]	171	pick-up	0	14
48735	2020-04-11 05:49:28	2020-04-11	9	[{"id_menu":6,"count":1}]	11764	pick-up	0	9
48736	2020-04-11 05:50:34	2020-04-11	17	[{"id_menu":4,"count":1}]	2520	pick-up	0	17
48737	2020-04-11 05:55:31	2020-04-11	9	[{"id_menu":7,"count":1}]	7086	pick-up	0	9
48738	2020-04-11 05:56:05	2020-04-11	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	19424	delivery	5	31
48739	2020-04-11 05:57:23	2020-04-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19498	delivery	5	23
48740	2020-04-11 05:59:39	2020-04-11	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	19411	delivery	5	45
48741	2020-04-11 06:01:10	2020-04-11	9	[{"id_menu":7,"count":1}]	19415	delivery	5	14
48742	2020-04-11 06:03:34	2020-04-11	17	[{"id_menu":4,"count":1}]	1545	pick-up	0	17
48743	2020-04-11 06:05:01	2020-04-11	9	[{"id_menu":6,"count":1}]	8487	delivery	5	14
48744	2020-04-11 06:08:54	2020-04-11	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	9742	delivery	5	36
48745	2020-04-11 06:09:06	2020-04-11	17	[{"id_menu":4,"count":1}]	19340	delivery	5	22
48746	2020-04-11 06:14:03	2020-04-11	17	[{"id_menu":4,"count":1}]	7296	delivery	5	22
48747	2020-04-11 06:14:18	2020-04-11	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	44	pick-up	0	29
48748	2020-04-11 06:16:31	2020-04-11	12	[{"id_menu":1,"count":1}]	2244	pick-up	0	12
48749	2020-04-11 06:24:13	2020-04-11	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	10809	delivery	5	40
48750	2020-04-11 06:24:33	2020-04-11	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	10590	delivery	5	27
48751	2020-04-11 06:31:51	2020-04-11	12	[{"id_menu":1,"count":1}]	886	delivery	5	17
48752	2020-04-11 06:33:57	2020-04-11	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	6918	delivery	5	31
48753	2020-04-11 06:37:40	2020-04-11	8	[{"id_menu":5,"count":1}]	16667	delivery	5	13
48754	2020-04-11 06:38:38	2020-04-11	9	[{"id_menu":6,"count":1}]	4856	pick-up	0	9
48755	2020-04-11 06:41:59	2020-04-11	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	19451	delivery	5	25
48756	2020-04-11 06:43:25	2020-04-11	8	[{"id_menu":5,"count":1}]	19390	delivery	5	13
48757	2020-04-11 06:50:24	2020-04-11	9	[{"id_menu":6,"count":1}]	19461	pick-up	0	9
48758	2020-04-11 06:52:56	2020-04-11	17	[{"id_menu":4,"count":1}]	685	pick-up	0	17
48759	2020-04-11 06:53:36	2020-04-11	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	19250	delivery	5	34
48760	2020-04-11 06:54:01	2020-04-11	14	[{"id_menu":2,"count":1}]	7098	delivery	5	19
48761	2020-04-11 06:58:42	2020-04-11	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	19448	delivery	5	45
48762	2020-04-11 07:01:54	2020-04-11	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19480	delivery	5	49
48763	2020-04-11 07:04:41	2020-04-11	9	[{"id_menu":6,"count":1}]	4068	pick-up	0	9
48764	2020-04-11 07:05:03	2020-04-11	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	19491	pick-up	0	40
48765	2020-04-11 07:07:07	2020-04-11	9	[{"id_menu":6,"count":1}]	8408	delivery	5	14
48766	2020-04-11 07:07:28	2020-04-11	8	[{"id_menu":5,"count":1}]	5917	pick-up	0	8
48767	2020-04-11 07:07:44	2020-04-11	14	[{"id_menu":2,"count":1}]	4943	delivery	5	19
48768	2020-04-11 07:08:23	2020-04-11	12	[{"id_menu":3,"count":1}]	19477	delivery	5	17
48769	2020-04-11 07:13:09	2020-04-11	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	6163	pick-up	0	26
48770	2020-04-11 07:16:23	2020-04-11	12	[{"id_menu":1,"count":1}]	19364	delivery	5	17
48771	2020-04-11 07:17:55	2020-04-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	19348	delivery	5	28
48772	2020-04-11 07:18:37	2020-04-11	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17066	delivery	5	34
48773	2020-04-11 07:23:02	2020-04-11	9	[{"id_menu":6,"count":1}]	18150	delivery	5	14
48774	2020-04-11 07:27:02	2020-04-11	12	[{"id_menu":3,"count":1}]	19490	pick-up	0	12
48775	2020-04-11 07:28:30	2020-04-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	19431	delivery	5	28
48776	2020-04-11 07:33:52	2020-04-11	12	[{"id_menu":1,"count":1}]	4762	pick-up	0	12
48777	2020-04-11 07:35:40	2020-04-11	14	[{"id_menu":2,"count":1}]	19355	delivery	5	19
48778	2020-04-11 07:44:24	2020-04-11	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13977	delivery	5	45
48779	2020-04-11 07:46:49	2020-04-11	9	[{"id_menu":6,"count":1}]	9436	delivery	5	14
48780	2020-04-11 07:49:41	2020-04-11	14	[{"id_menu":2,"count":1}]	1415	pick-up	0	14
48781	2020-04-11 07:55:31	2020-04-11	12	[{"id_menu":3,"count":1}]	16548	delivery	5	17
48782	2020-04-11 07:55:34	2020-04-11	8	[{"id_menu":5,"count":1}]	19478	delivery	5	13
48783	2020-04-11 07:56:02	2020-04-11	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5894	delivery	5	43
48784	2020-04-11 07:56:25	2020-04-11	8	[{"id_menu":5,"count":1}]	19429	delivery	5	13
48785	2020-04-11 07:56:35	2020-04-11	12	[{"id_menu":3,"count":1}]	10273	pick-up	0	12
48786	2020-04-11 07:58:29	2020-04-11	9	[{"id_menu":6,"count":1}]	19495	delivery	5	14
48787	2020-04-11 08:01:33	2020-04-11	12	[{"id_menu":3,"count":1}]	19354	delivery	5	17
48788	2020-04-11 08:07:22	2020-04-11	14	[{"id_menu":2,"count":1}]	14410	pick-up	0	14
48789	2020-04-11 08:09:06	2020-04-11	8	[{"id_menu":5,"count":2}]	1858	pick-up	0	8
48790	2020-04-11 08:12:10	2020-04-11	12	[{"id_menu":1,"count":1}]	19335	delivery	5	17
48791	2020-04-11 08:12:52	2020-04-11	9	[{"id_menu":7,"count":1}]	9575	pick-up	0	9
48792	2020-04-11 08:20:56	2020-04-11	9	[{"id_menu":7,"count":1}]	5138	pick-up	0	9
48793	2020-04-11 08:21:40	2020-04-11	12	[{"id_menu":1,"count":1}]	19474	pick-up	0	12
48794	2020-04-11 08:27:18	2020-04-11	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	19402	delivery	5	40
48795	2020-04-11 08:32:50	2020-04-11	8	[{"id_menu":5,"count":1}]	8581	delivery	5	13
48796	2020-04-11 08:44:07	2020-04-11	12	[{"id_menu":1,"count":1}]	2956	delivery	5	17
48797	2020-04-11 08:44:41	2020-04-11	8	[{"id_menu":5,"count":1}]	17520	pick-up	0	8
48798	2020-04-11 08:49:47	2020-04-11	9	[{"id_menu":6,"count":1}]	7314	delivery	5	14
48799	2020-04-11 08:49:55	2020-04-11	12	[{"id_menu":1,"count":2}]	722	delivery	5	17
48800	2020-04-11 08:53:20	2020-04-11	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	935	delivery	5	39
48801	2020-04-11 09:01:23	2020-04-11	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15292	delivery	5	57
48802	2020-04-11 09:03:11	2020-04-11	9	[{"id_menu":7,"count":1}]	19507	delivery	5	14
48803	2020-04-11 09:04:43	2020-04-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1557	pick-up	0	18
48804	2020-04-11 09:05:03	2020-04-11	9	[{"id_menu":7,"count":1}]	12184	delivery	5	14
48805	2020-04-11 09:05:57	2020-04-11	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	17154	delivery	5	39
48806	2020-04-11 09:07:43	2020-04-11	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3440	pick-up	0	31
48807	2020-04-11 09:13:11	2020-04-11	9	[{"id_menu":6,"count":1}]	10801	pick-up	0	9
48808	2020-04-11 09:19:12	2020-04-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12127	delivery	5	22
48809	2020-04-11 09:22:31	2020-04-11	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	786	pick-up	0	21
48810	2020-04-11 09:25:10	2020-04-11	9	[{"id_menu":7,"count":1}]	11534	pick-up	0	9
48811	2020-04-11 09:26:11	2020-04-11	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8706	pick-up	0	23
48812	2020-04-11 09:32:31	2020-04-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19483	delivery	5	23
48813	2020-04-11 09:38:17	2020-04-11	14	[{"id_menu":2,"count":1}]	743	pick-up	0	14
48814	2020-04-11 09:40:41	2020-04-11	9	[{"id_menu":6,"count":1}]	7695	delivery	5	14
48815	2020-04-11 09:41:05	2020-04-11	8	[{"id_menu":5,"count":1}]	184	delivery	5	13
48816	2020-04-11 09:46:23	2020-04-11	17	[{"id_menu":4,"count":1}]	19336	delivery	5	22
48817	2020-04-11 09:50:20	2020-04-11	9	[{"id_menu":7,"count":1}]	18928	pick-up	0	9
48818	2020-04-11 10:05:56	2020-04-11	12	[{"id_menu":3,"count":1}]	2491	delivery	5	17
48819	2020-04-11 10:06:27	2020-04-11	9	[{"id_menu":6,"count":1}]	776	delivery	5	14
48820	2020-04-11 10:11:34	2020-04-11	12	[{"id_menu":1,"count":1}]	19503	delivery	5	17
48821	2020-04-11 10:19:33	2020-04-11	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	19377	delivery	5	34
48822	2020-04-11 10:19:39	2020-04-11	9	[{"id_menu":7,"count":1}]	19425	delivery	5	14
48823	2020-04-11 10:20:15	2020-04-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	19363	delivery	5	28
48824	2020-04-11 10:26:52	2020-04-11	8	[{"id_menu":5,"count":1}]	7253	delivery	5	13
48825	2020-04-11 10:27:20	2020-04-11	12	[{"id_menu":3,"count":1}]	511	delivery	5	17
48826	2020-04-11 10:35:32	2020-04-11	17	[{"id_menu":4,"count":1}]	19376	delivery	5	22
48827	2020-04-11 10:39:31	2020-04-11	9	[{"id_menu":7,"count":1}]	3989	delivery	5	14
48828	2020-04-11 10:41:19	2020-04-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8861	delivery	5	22
48829	2020-04-11 10:52:01	2020-04-11	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	16261	delivery	5	34
48830	2020-04-11 10:57:17	2020-04-11	8	[{"id_menu":5,"count":1}]	19456	delivery	5	13
48831	2020-04-11 10:59:21	2020-04-11	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15768	delivery	5	31
48832	2020-04-11 11:00:22	2020-04-11	9	[{"id_menu":6,"count":1}]	19345	delivery	5	14
48833	2020-04-11 11:03:06	2020-04-11	14	[{"id_menu":2,"count":1}]	5394	delivery	5	19
48834	2020-04-11 11:04:19	2020-04-11	9	[{"id_menu":6,"count":3}]	8609	delivery	5	14
48835	2020-04-11 11:05:36	2020-04-11	17	[{"id_menu":4,"count":1}]	10401	delivery	5	22
48836	2020-04-11 11:09:28	2020-04-11	17	[{"id_menu":4,"count":1}]	8046	delivery	5	22
48837	2020-04-11 11:18:53	2020-04-11	17	[{"id_menu":4,"count":1}]	19399	delivery	5	22
48838	2020-04-11 11:20:16	2020-04-11	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	19444	delivery	5	26
48839	2020-04-11 11:20:22	2020-04-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4489	delivery	5	28
48840	2020-04-11 11:27:07	2020-04-11	17	[{"id_menu":4,"count":2}]	2573	pick-up	0	17
48841	2020-04-11 11:30:28	2020-04-11	12	[{"id_menu":1,"count":1}]	437	delivery	5	17
48842	2020-04-11 11:31:13	2020-04-11	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	19383	delivery	5	36
48843	2020-04-11 11:37:05	2020-04-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	19496	delivery	5	23
48844	2020-04-11 11:40:15	2020-04-11	14	[{"id_menu":2,"count":1}]	6873	delivery	5	19
48845	2020-04-11 11:43:19	2020-04-11	39	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	19482	delivery	5	44
48846	2020-04-11 11:45:50	2020-04-11	9	[{"id_menu":6,"count":1}]	19442	pick-up	0	9
48847	2020-04-11 11:47:12	2020-04-11	9	[{"id_menu":6,"count":1}]	19499	delivery	5	14
48848	2020-04-11 11:47:39	2020-04-11	12	[{"id_menu":1,"count":1}]	14845	delivery	5	17
48849	2020-04-11 11:47:46	2020-04-11	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19501	delivery	5	22
48850	2020-04-11 11:59:11	2020-04-11	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	7741	pick-up	0	20
48851	2020-04-11 12:02:21	2020-04-11	9	[{"id_menu":6,"count":1}]	19396	pick-up	0	9
48852	2020-04-11 12:05:26	2020-04-11	9	[{"id_menu":7,"count":1}]	19433	delivery	5	14
48853	2020-04-11 12:08:12	2020-04-11	17	[{"id_menu":4,"count":1}]	19405	delivery	5	22
48854	2020-04-11 12:09:04	2020-04-11	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	4411	pick-up	0	29
48855	2020-04-11 12:09:51	2020-04-11	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2662	pick-up	0	17
48856	2020-04-11 12:13:07	2020-04-11	12	[{"id_menu":1,"count":1}]	506	pick-up	0	12
48857	2020-04-11 12:13:56	2020-04-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	11735	delivery	5	28
48858	2020-04-11 12:15:17	2020-04-11	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	9910	delivery	5	31
48859	2020-04-11 12:15:27	2020-04-11	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19464	delivery	5	22
48860	2020-04-11 12:17:39	2020-04-11	9	[{"id_menu":6,"count":2}]	19382	pick-up	0	9
48861	2020-04-11 12:19:44	2020-04-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19422	delivery	5	23
48862	2020-04-11 12:23:32	2020-04-11	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	19512	delivery	5	31
48863	2020-04-11 12:24:10	2020-04-11	14	[{"id_menu":2,"count":1}]	8595	pick-up	0	14
48864	2020-04-11 12:28:32	2020-04-11	17	[{"id_menu":4,"count":1}]	12240	pick-up	0	17
48865	2020-04-11 12:33:30	2020-04-11	9	[{"id_menu":7,"count":1}]	640	pick-up	0	9
48866	2020-04-11 12:37:00	2020-04-11	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11666	delivery	5	45
48867	2020-04-11 12:41:43	2020-04-11	12	[{"id_menu":1,"count":1}]	19426	pick-up	0	12
48868	2020-04-11 12:58:57	2020-04-11	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	19502	delivery	5	40
48869	2020-04-11 13:04:41	2020-04-11	14	[{"id_menu":2,"count":1}]	19462	pick-up	0	14
48870	2020-04-11 13:07:39	2020-04-11	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	16045	delivery	5	22
48871	2020-04-11 13:07:46	2020-04-11	9	[{"id_menu":7,"count":1}]	19409	delivery	5	14
48872	2020-04-11 13:11:22	2020-04-11	9	[{"id_menu":6,"count":1}]	17728	delivery	5	14
48873	2020-04-11 13:12:04	2020-04-11	9	[{"id_menu":7,"count":1}]	19437	delivery	5	14
48874	2020-04-11 13:14:18	2020-04-11	17	[{"id_menu":4,"count":1}]	19344	delivery	5	22
48875	2020-04-11 13:16:00	2020-04-11	14	[{"id_menu":2,"count":1}]	11738	delivery	5	19
48876	2020-04-11 13:18:13	2020-04-11	8	[{"id_menu":5,"count":1}]	6104	delivery	5	13
48877	2020-04-11 13:23:11	2020-04-11	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	19387	delivery	5	31
48878	2020-04-11 13:26:00	2020-04-11	12	[{"id_menu":3,"count":1}]	19450	delivery	5	17
48879	2020-04-11 13:26:33	2020-04-11	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19484	delivery	5	34
48880	2020-04-11 13:28:44	2020-04-11	12	[{"id_menu":1,"count":1}]	2571	delivery	5	17
48881	2020-04-11 13:29:08	2020-04-11	17	[{"id_menu":4,"count":1}]	730	pick-up	0	17
48882	2020-04-11 13:36:24	2020-04-11	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15525	delivery	5	52
48883	2020-04-11 13:38:00	2020-04-11	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19361	pick-up	0	31
48884	2020-04-11 13:38:33	2020-04-11	14	[{"id_menu":2,"count":1}]	3125	delivery	5	19
48885	2020-04-11 13:40:34	2020-04-11	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	19489	delivery	5	22
48886	2020-04-11 13:44:17	2020-04-11	12	[{"id_menu":1,"count":1}]	12197	delivery	5	17
48887	2020-04-11 13:46:00	2020-04-11	9	[{"id_menu":6,"count":1}]	19341	delivery	5	14
48888	2020-04-11 13:47:36	2020-04-11	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	11535	delivery	5	26
48889	2020-04-11 13:47:38	2020-04-11	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	5654	delivery	5	44
48890	2020-04-11 13:47:59	2020-04-11	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17725	delivery	5	22
48891	2020-04-11 14:01:31	2020-04-11	8	[{"id_menu":5,"count":1}]	19449	delivery	5	13
48892	2020-04-11 14:03:40	2020-04-11	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7647	delivery	5	42
48893	2020-04-11 14:06:05	2020-04-11	8	[{"id_menu":5,"count":1}]	17902	delivery	5	13
48894	2020-04-11 14:06:39	2020-04-11	14	[{"id_menu":2,"count":1}]	3478	pick-up	0	14
48895	2020-04-11 14:07:39	2020-04-11	8	[{"id_menu":5,"count":1}]	19440	delivery	5	13
48896	2020-04-11 14:09:16	2020-04-11	14	[{"id_menu":2,"count":1}]	7842	delivery	5	19
48897	2020-04-11 14:13:18	2020-04-11	8	[{"id_menu":5,"count":1}]	10331	delivery	5	13
48898	2020-04-11 14:13:23	2020-04-11	9	[{"id_menu":7,"count":1}]	18476	delivery	5	14
48899	2020-04-11 14:27:22	2020-04-11	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2799	delivery	5	30
48900	2020-04-11 14:30:52	2020-04-11	9	[{"id_menu":7,"count":1}]	19372	delivery	5	14
48901	2020-04-11 14:31:49	2020-04-11	14	[{"id_menu":2,"count":1}]	6711	pick-up	0	14
48902	2020-04-11 14:49:43	2020-04-11	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	15249	delivery	5	43
48903	2020-04-11 14:50:29	2020-04-11	8	[{"id_menu":5,"count":1}]	19494	delivery	5	13
48904	2020-04-11 14:51:32	2020-04-11	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6206	delivery	5	28
48905	2020-04-11 14:57:39	2020-04-11	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	6164	pick-up	0	29
48906	2020-04-11 14:58:50	2020-04-11	17	[{"id_menu":4,"count":1}]	14838	delivery	5	22
48907	2020-04-11 15:01:14	2020-04-11	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	19362	pick-up	0	26
48908	2020-04-11 15:02:17	2020-04-11	17	[{"id_menu":4,"count":1}]	2697	pick-up	0	17
48909	2020-04-11 15:09:10	2020-04-11	14	[{"id_menu":2,"count":1}]	19492	delivery	5	19
48910	2020-04-11 15:09:12	2020-04-11	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	19470	delivery	5	31
48911	2020-04-11 15:10:28	2020-04-11	9	[{"id_menu":7,"count":1}]	14688	pick-up	0	9
48912	2020-04-11 15:17:40	2020-04-11	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1087	pick-up	0	26
48913	2020-04-11 15:21:47	2020-04-11	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	7527	pick-up	0	26
48914	2020-04-11 15:23:27	2020-04-11	8	[{"id_menu":5,"count":2}]	19398	delivery	5	13
48915	2020-04-11 15:27:08	2020-04-11	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2753	pick-up	0	20
48916	2020-04-11 15:34:21	2020-04-11	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	17186	delivery	5	40
48917	2020-04-11 15:37:31	2020-04-11	12	[{"id_menu":1,"count":1}]	14252	pick-up	0	12
48918	2020-04-11 15:41:04	2020-04-11	14	[{"id_menu":2,"count":1}]	19471	delivery	5	19
48919	2020-04-11 15:42:36	2020-04-11	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	13754	delivery	5	36
48920	2020-04-11 15:43:12	2020-04-11	8	[{"id_menu":5,"count":1}]	19381	delivery	5	13
48921	2020-04-11 15:46:54	2020-04-11	17	[{"id_menu":4,"count":1}]	19379	delivery	5	22
48922	2020-04-11 15:50:36	2020-04-11	14	[{"id_menu":2,"count":1}]	10000	delivery	5	19
48923	2020-04-11 15:54:17	2020-04-11	14	[{"id_menu":2,"count":1}]	19488	delivery	5	19
48924	2020-04-11 15:56:07	2020-04-11	9	[{"id_menu":6,"count":1}]	8900	pick-up	0	9
48925	2020-04-11 16:00:02	2020-04-11	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7306	pick-up	0	25
48926	2020-04-11 16:03:03	2020-04-11	14	[{"id_menu":2,"count":1}]	19357	pick-up	0	14
48927	2020-04-11 16:06:18	2020-04-11	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19473	delivery	5	36
48928	2020-04-11 16:07:52	2020-04-11	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1943	delivery	5	26
48929	2020-04-11 16:08:22	2020-04-11	12	[{"id_menu":1,"count":1}]	19428	delivery	5	17
48930	2020-04-11 16:08:46	2020-04-11	12	[{"id_menu":3,"count":1}]	19369	delivery	5	17
48931	2020-04-11 16:08:56	2020-04-11	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11077	delivery	5	34
48932	2020-04-11 16:09:21	2020-04-11	8	[{"id_menu":5,"count":1}]	15679	delivery	5	13
48933	2020-04-11 16:11:16	2020-04-11	17	[{"id_menu":4,"count":1}]	19353	delivery	5	22
48934	2020-04-11 16:36:01	2020-04-11	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1113	delivery	5	28
48935	2020-04-11 16:40:41	2020-04-11	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	19366	delivery	5	28
48936	2020-04-11 16:41:23	2020-04-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3251	delivery	5	28
48937	2020-04-11 16:43:18	2020-04-11	17	[{"id_menu":4,"count":2}]	19367	delivery	5	22
48938	2020-04-11 16:45:42	2020-04-11	12	[{"id_menu":3,"count":1}]	17874	delivery	5	17
48939	2020-04-11 16:48:27	2020-04-11	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4869	delivery	5	30
48940	2020-04-11 16:51:20	2020-04-11	9	[{"id_menu":7,"count":1}]	19337	delivery	5	14
48941	2020-04-11 16:55:12	2020-04-11	9	[{"id_menu":6,"count":1}]	13817	delivery	5	14
48942	2020-04-11 16:55:12	2020-04-11	14	[{"id_menu":2,"count":1}]	16957	pick-up	0	14
48943	2020-04-11 16:56:21	2020-04-11	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	138	pick-up	0	34
48944	2020-04-11 16:59:00	2020-04-11	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	18916	delivery	5	31
48945	2020-04-11 17:03:52	2020-04-11	8	[{"id_menu":5,"count":1}]	13806	pick-up	0	8
48946	2020-04-11 17:07:56	2020-04-11	17	[{"id_menu":4,"count":1}]	19356	delivery	5	22
48947	2020-04-11 17:08:23	2020-04-11	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	9560	delivery	5	39
48948	2020-04-11 17:14:51	2020-04-11	9	[{"id_menu":7,"count":1}]	15326	pick-up	0	9
48949	2020-04-11 17:16:23	2020-04-11	14	[{"id_menu":2,"count":1}]	16026	delivery	5	19
48950	2020-04-11 17:16:49	2020-04-11	9	[{"id_menu":6,"count":1}]	5387	delivery	5	14
48951	2020-04-11 17:17:43	2020-04-11	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	19374	delivery	5	26
48952	2020-04-11 17:21:13	2020-04-11	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	19349	delivery	5	26
48953	2020-04-11 17:23:39	2020-04-11	9	[{"id_menu":7,"count":1}]	19454	delivery	5	14
48954	2020-04-11 17:27:20	2020-04-11	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	17736	delivery	5	34
48955	2020-04-11 17:29:02	2020-04-11	8	[{"id_menu":5,"count":1}]	8821	delivery	5	13
48956	2020-04-11 17:31:43	2020-04-11	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	6661	pick-up	0	26
48957	2020-04-11 17:32:37	2020-04-11	14	[{"id_menu":2,"count":1}]	19434	pick-up	0	14
48958	2020-04-11 17:39:41	2020-04-11	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	4594	delivery	5	26
48959	2020-04-11 17:43:18	2020-04-11	9	[{"id_menu":7,"count":1}]	19370	delivery	5	14
48960	2020-04-11 17:45:32	2020-04-11	9	[{"id_menu":6,"count":1}]	19487	delivery	5	14
48961	2020-04-11 17:47:07	2020-04-11	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7771	pick-up	0	43
48962	2020-04-11 17:55:33	2020-04-11	55	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	14330	delivery	5	60
48963	2020-04-11 18:11:53	2020-04-11	14	[{"id_menu":2,"count":1}]	11471	delivery	5	19
48964	2020-04-11 18:12:02	2020-04-11	9	[{"id_menu":6,"count":1}]	19358	delivery	5	14
48965	2020-04-11 18:12:49	2020-04-11	8	[{"id_menu":5,"count":1}]	18499	delivery	5	13
48966	2020-04-11 18:17:18	2020-04-11	9	[{"id_menu":6,"count":1}]	3031	pick-up	0	9
48967	2020-04-11 18:28:42	2020-04-11	9	[{"id_menu":7,"count":1}]	19413	delivery	5	14
48968	2020-04-11 18:28:49	2020-04-11	9	[{"id_menu":6,"count":1}]	19504	pick-up	0	9
48969	2020-04-11 18:33:17	2020-04-11	8	[{"id_menu":5,"count":1}]	5361	delivery	5	13
48970	2020-04-11 18:43:36	2020-04-11	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	9991	delivery	5	26
48971	2020-04-11 18:44:56	2020-04-11	14	[{"id_menu":2,"count":1}]	19476	pick-up	0	14
48972	2020-04-11 18:54:00	2020-04-11	14	[{"id_menu":2,"count":1}]	18379	delivery	5	19
48973	2020-04-11 18:55:12	2020-04-11	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	6301	pick-up	0	17
48974	2020-04-11 18:59:32	2020-04-11	9	[{"id_menu":6,"count":1}]	19435	delivery	5	14
48975	2020-04-11 19:00:01	2020-04-11	8	[{"id_menu":5,"count":1}]	19463	delivery	5	13
48976	2020-04-11 19:00:11	2020-04-11	9	[{"id_menu":6,"count":1}]	19350	delivery	5	14
48977	2020-04-11 19:11:11	2020-04-11	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	19401	delivery	5	36
48978	2020-04-11 19:14:39	2020-04-11	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10013	delivery	5	31
48979	2020-04-11 19:19:47	2020-04-11	21	[{"id_menu":1,"count":3},{"id_menu":7,"count":1}]	19417	delivery	5	26
48980	2020-04-11 19:25:51	2020-04-11	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	4502	pick-up	0	26
48981	2020-04-11 19:26:04	2020-04-11	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1581	pick-up	0	26
48982	2020-04-11 19:31:07	2020-04-11	9	[{"id_menu":7,"count":2}]	19347	delivery	5	14
48983	2020-04-11 19:36:55	2020-04-11	17	[{"id_menu":4,"count":1}]	8873	pick-up	0	17
48984	2020-04-11 19:38:54	2020-04-11	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	19458	delivery	5	36
48985	2020-04-11 19:42:34	2020-04-11	12	[{"id_menu":1,"count":1}]	19365	delivery	5	17
48986	2020-04-11 19:44:26	2020-04-11	14	[{"id_menu":2,"count":1}]	3940	pick-up	0	14
48987	2020-04-11 19:45:28	2020-04-11	9	[{"id_menu":6,"count":1}]	19352	delivery	5	14
48988	2020-04-11 19:52:14	2020-04-11	9	[{"id_menu":6,"count":1}]	19373	delivery	5	14
48989	2020-04-11 19:52:28	2020-04-11	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	16550	pick-up	0	31
48990	2020-04-11 19:52:43	2020-04-11	17	[{"id_menu":4,"count":1}]	6048	pick-up	0	17
48991	2020-04-11 19:52:45	2020-04-11	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	19460	delivery	5	42
48992	2020-04-11 19:52:51	2020-04-11	9	[{"id_menu":6,"count":1}]	19469	delivery	5	14
48993	2020-04-11 19:55:02	2020-04-11	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10945	delivery	5	39
48994	2020-04-11 19:55:47	2020-04-11	12	[{"id_menu":3,"count":1}]	19467	delivery	5	17
48995	2020-04-11 19:57:42	2020-04-11	9	[{"id_menu":7,"count":1}]	1118	delivery	5	14
48996	2020-04-11 20:01:36	2020-04-11	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19378	delivery	5	48
48997	2020-04-11 20:07:30	2020-04-11	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4645	pick-up	0	38
48998	2020-04-11 20:14:16	2020-04-11	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3944	pick-up	0	29
48999	2020-04-11 20:15:06	2020-04-11	8	[{"id_menu":5,"count":1}]	7893	delivery	5	13
49000	2020-04-11 20:17:44	2020-04-11	14	[{"id_menu":2,"count":2}]	741	delivery	5	19
49001	2020-04-11 20:21:56	2020-04-11	9	[{"id_menu":6,"count":1}]	19497	delivery	5	14
49002	2020-04-11 20:23:19	2020-04-11	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	19443	delivery	5	40
49003	2020-04-11 20:25:36	2020-04-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1155	pick-up	0	18
49004	2020-04-11 20:26:02	2020-04-11	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	18036	delivery	5	43
49005	2020-04-11 20:26:04	2020-04-11	14	[{"id_menu":2,"count":1}]	9039	delivery	5	19
49006	2020-04-11 20:33:53	2020-04-11	9	[{"id_menu":6,"count":1}]	19207	delivery	5	14
49007	2020-04-11 20:33:54	2020-04-11	9	[{"id_menu":7,"count":1}]	3487	delivery	5	14
49008	2020-04-11 20:36:12	2020-04-11	14	[{"id_menu":2,"count":2}]	7606	delivery	5	19
49009	2020-04-11 20:36:38	2020-04-11	9	[{"id_menu":6,"count":1}]	19368	delivery	5	14
49010	2020-04-11 20:37:31	2020-04-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	19479	delivery	5	22
49011	2020-04-11 20:38:33	2020-04-11	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	2064	delivery	5	38
49012	2020-04-11 20:38:42	2020-04-11	9	[{"id_menu":6,"count":1}]	8145	pick-up	0	9
49013	2020-04-11 20:39:15	2020-04-11	9	[{"id_menu":7,"count":1}]	7671	pick-up	0	9
49014	2020-04-11 20:40:08	2020-04-11	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19416	delivery	5	54
49015	2020-04-11 20:44:53	2020-04-11	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	19391	pick-up	0	25
49016	2020-04-11 20:45:00	2020-04-11	9	[{"id_menu":6,"count":1}]	12015	delivery	5	14
49017	2020-04-11 20:45:13	2020-04-11	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19397	delivery	5	35
49018	2020-04-11 20:59:40	2020-04-11	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	440	delivery	5	38
49019	2020-04-11 21:00:09	2020-04-11	12	[{"id_menu":3,"count":1}]	936	delivery	5	17
49020	2020-04-11 21:02:24	2020-04-11	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	13520	delivery	5	39
49021	2020-04-11 21:02:26	2020-04-11	9	[{"id_menu":6,"count":1}]	10486	delivery	5	14
49022	2020-04-11 21:06:35	2020-04-11	17	[{"id_menu":4,"count":1}]	19414	delivery	5	22
49023	2020-04-11 21:08:46	2020-04-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5666	delivery	5	23
49024	2020-04-11 21:13:30	2020-04-11	9	[{"id_menu":7,"count":1}]	19393	delivery	5	14
49025	2020-04-11 21:14:41	2020-04-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3010	pick-up	0	23
49026	2020-04-11 21:16:59	2020-04-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2932	delivery	5	28
49027	2020-04-11 21:21:31	2020-04-11	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	15029	pick-up	0	29
49028	2020-04-11 21:22:31	2020-04-11	14	[{"id_menu":2,"count":1}]	19338	pick-up	0	14
49029	2020-04-11 21:24:25	2020-04-11	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	19446	delivery	5	30
49030	2020-04-11 21:30:40	2020-04-11	17	[{"id_menu":4,"count":1}]	4970	delivery	5	22
49031	2020-04-11 21:30:50	2020-04-11	14	[{"id_menu":2,"count":1}]	721	delivery	5	19
49032	2020-04-11 21:34:03	2020-04-11	9	[{"id_menu":7,"count":1}]	17430	delivery	5	14
49033	2020-04-11 21:36:26	2020-04-11	9	[{"id_menu":7,"count":3}]	19432	delivery	5	14
49034	2020-04-11 21:38:54	2020-04-11	17	[{"id_menu":4,"count":1}]	19430	delivery	5	22
49035	2020-04-11 21:44:10	2020-04-11	9	[{"id_menu":6,"count":1}]	7418	delivery	5	14
49036	2020-04-11 21:45:01	2020-04-11	9	[{"id_menu":7,"count":1}]	13593	pick-up	0	9
49037	2020-04-11 21:45:03	2020-04-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6249	delivery	5	28
49038	2020-04-11 21:50:53	2020-04-11	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	19505	pick-up	0	21
49039	2020-04-11 21:53:52	2020-04-11	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	8705	delivery	5	26
49040	2020-04-11 21:55:49	2020-04-11	9	[{"id_menu":6,"count":1}]	18839	pick-up	0	9
49041	2020-04-11 22:02:33	2020-04-11	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	16916	delivery	5	26
49042	2020-04-11 22:06:43	2020-04-11	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1021	pick-up	0	24
49043	2020-04-11 22:07:59	2020-04-11	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	19404	delivery	5	31
49044	2020-04-11 22:16:31	2020-04-11	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15468	delivery	5	39
49045	2020-04-11 22:19:31	2020-04-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7772	pick-up	0	23
49046	2020-04-11 22:22:46	2020-04-11	9	[{"id_menu":6,"count":1}]	19465	delivery	5	14
49047	2020-04-11 22:28:18	2020-04-11	9	[{"id_menu":6,"count":1}]	10619	delivery	5	14
49048	2020-04-11 22:35:02	2020-04-11	9	[{"id_menu":6,"count":2}]	341	pick-up	0	9
49049	2020-04-11 22:35:49	2020-04-11	17	[{"id_menu":4,"count":1}]	4436	pick-up	0	17
49050	2020-04-11 22:38:19	2020-04-11	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	14211	delivery	5	43
49051	2020-04-11 22:39:46	2020-04-11	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	12675	delivery	5	26
49052	2020-04-11 22:40:03	2020-04-11	12	[{"id_menu":1,"count":1}]	15603	delivery	5	17
49053	2020-04-11 22:46:20	2020-04-11	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8884	delivery	5	22
49054	2020-04-11 22:47:24	2020-04-11	17	[{"id_menu":4,"count":1}]	350	pick-up	0	17
49055	2020-04-11 22:48:02	2020-04-11	8	[{"id_menu":5,"count":1}]	19427	delivery	5	13
49056	2020-04-11 22:52:15	2020-04-11	9	[{"id_menu":6,"count":1}]	19441	delivery	5	14
49057	2020-04-11 22:54:28	2020-04-11	9	[{"id_menu":7,"count":1}]	14563	delivery	5	14
49058	2020-04-11 22:55:42	2020-04-11	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	16803	pick-up	0	26
49059	2020-04-11 22:58:32	2020-04-11	12	[{"id_menu":3,"count":1}]	7940	delivery	5	17
49060	2020-04-11 22:59:39	2020-04-11	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	19339	delivery	5	28
49061	2020-04-11 23:00:05	2020-04-11	8	[{"id_menu":5,"count":1}]	4590	pick-up	0	8
49062	2020-04-11 23:01:43	2020-04-11	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	4271	delivery	5	23
49063	2020-04-11 23:03:51	2020-04-11	12	[{"id_menu":3,"count":1}]	5286	pick-up	0	12
49064	2020-04-11 23:04:08	2020-04-11	14	[{"id_menu":2,"count":1}]	9456	delivery	5	19
49065	2020-04-11 23:12:13	2020-04-11	12	[{"id_menu":1,"count":1}]	19359	delivery	5	17
49066	2020-04-11 23:21:09	2020-04-11	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	19384	delivery	5	26
49067	2020-04-11 23:25:51	2020-04-11	9	[{"id_menu":7,"count":1}]	7436	delivery	5	14
49068	2020-04-11 23:27:12	2020-04-11	9	[{"id_menu":6,"count":2}]	12143	delivery	5	14
49069	2020-04-11 23:28:21	2020-04-11	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4216	pick-up	0	29
49070	2020-04-11 23:28:58	2020-04-11	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1266	delivery	5	36
49071	2020-04-11 23:32:06	2020-04-11	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	19439	delivery	5	42
49072	2020-04-11 23:33:25	2020-04-11	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	19410	delivery	5	34
49073	2020-04-11 23:37:21	2020-04-11	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15365	delivery	5	35
49074	2020-04-11 23:39:39	2020-04-11	14	[{"id_menu":2,"count":1}]	10905	delivery	5	19
49075	2020-04-11 23:41:13	2020-04-11	9	[{"id_menu":6,"count":1}]	19408	delivery	5	14
49076	2020-04-11 23:42:50	2020-04-11	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	19386	delivery	5	25
49077	2020-04-11 23:45:26	2020-04-11	22	[{"id_menu":2,"count":3},{"id_menu":5,"count":1}]	11973	delivery	5	27
49078	2020-04-11 23:48:23	2020-04-11	17	[{"id_menu":4,"count":2}]	19466	delivery	5	22
49079	2020-04-11 23:49:01	2020-04-11	17	[{"id_menu":4,"count":1}]	17724	delivery	5	22
49080	2020-04-11 23:52:03	2020-04-11	14	[{"id_menu":2,"count":1}]	11822	delivery	5	19
49081	2020-04-11 23:54:15	2020-04-11	8	[{"id_menu":5,"count":1}]	19389	delivery	5	13
49082	2020-04-11 23:56:21	2020-04-11	12	[{"id_menu":3,"count":1}]	2384	pick-up	0	12
49083	2020-04-11 23:56:39	2020-04-11	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	5838	delivery	5	31
49084	2020-04-11 23:59:18	2020-04-11	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3467	delivery	5	44
49085	2020-04-12 00:08:07	2020-04-12	9	[{"id_menu":6,"count":1}]	19622	delivery	5	14
49086	2020-04-12 00:18:06	2020-04-12	12	[{"id_menu":3,"count":1}]	19575	delivery	5	17
49087	2020-04-12 00:19:15	2020-04-12	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	887	delivery	5	22
49088	2020-04-12 00:19:27	2020-04-12	9	[{"id_menu":6,"count":1}]	13537	delivery	5	14
49089	2020-04-12 00:20:58	2020-04-12	17	[{"id_menu":4,"count":1}]	11771	delivery	5	22
49090	2020-04-12 00:24:04	2020-04-12	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	17036	pick-up	0	20
49091	2020-04-12 00:26:27	2020-04-12	9	[{"id_menu":6,"count":1}]	16750	delivery	5	14
49092	2020-04-12 00:27:14	2020-04-12	12	[{"id_menu":3,"count":1}]	16785	delivery	5	17
49093	2020-04-12 00:31:05	2020-04-12	9	[{"id_menu":6,"count":2}]	19543	delivery	5	14
49094	2020-04-12 00:31:24	2020-04-12	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	15752	delivery	5	28
49095	2020-04-12 00:32:59	2020-04-12	9	[{"id_menu":6,"count":1}]	19582	delivery	5	14
49096	2020-04-12 00:34:42	2020-04-12	8	[{"id_menu":5,"count":1}]	19617	delivery	5	13
49097	2020-04-12 00:35:04	2020-04-12	17	[{"id_menu":4,"count":1}]	19514	pick-up	0	17
49098	2020-04-12 00:36:26	2020-04-12	9	[{"id_menu":6,"count":1}]	19592	delivery	5	14
49099	2020-04-12 00:37:10	2020-04-12	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6056	delivery	5	45
49100	2020-04-12 00:37:22	2020-04-12	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2464	pick-up	0	34
49101	2020-04-12 00:38:26	2020-04-12	17	[{"id_menu":4,"count":1}]	12907	delivery	5	22
49102	2020-04-12 00:39:00	2020-04-12	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	4356	delivery	5	25
49103	2020-04-12 00:44:48	2020-04-12	14	[{"id_menu":2,"count":1}]	2699	delivery	5	19
49104	2020-04-12 00:48:51	2020-04-12	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	74	pick-up	0	24
49105	2020-04-12 00:49:16	2020-04-12	14	[{"id_menu":2,"count":1}]	13882	delivery	5	19
49106	2020-04-12 00:50:02	2020-04-12	12	[{"id_menu":1,"count":1}]	7306	pick-up	0	12
49107	2020-04-12 00:52:43	2020-04-12	14	[{"id_menu":2,"count":1}]	7772	delivery	5	19
49108	2020-04-12 00:56:21	2020-04-12	9	[{"id_menu":6,"count":1}]	9563	delivery	5	14
49109	2020-04-12 01:02:47	2020-04-12	12	[{"id_menu":3,"count":1}]	8271	delivery	5	17
49110	2020-04-12 01:06:07	2020-04-12	17	[{"id_menu":4,"count":1}]	12648	pick-up	0	17
49111	2020-04-12 01:06:29	2020-04-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	19630	delivery	5	31
49112	2020-04-12 01:07:45	2020-04-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	12800	pick-up	0	17
49113	2020-04-12 01:08:59	2020-04-12	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	19652	delivery	5	30
49114	2020-04-12 01:10:04	2020-04-12	14	[{"id_menu":2,"count":1}]	6118	delivery	5	19
49115	2020-04-12 01:24:06	2020-04-12	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1727	pick-up	0	29
49116	2020-04-12 01:24:40	2020-04-12	9	[{"id_menu":6,"count":1}]	368	pick-up	0	9
49117	2020-04-12 01:28:29	2020-04-12	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12263	delivery	5	43
49118	2020-04-12 01:29:43	2020-04-12	12	[{"id_menu":1,"count":1}]	2855	pick-up	0	12
49119	2020-04-12 01:30:48	2020-04-12	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	19647	delivery	5	38
49120	2020-04-12 01:32:05	2020-04-12	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2843	delivery	5	25
49121	2020-04-12 01:34:15	2020-04-12	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	9520	delivery	5	26
49122	2020-04-12 01:36:28	2020-04-12	14	[{"id_menu":2,"count":1}]	13798	delivery	5	19
49123	2020-04-12 01:36:30	2020-04-12	14	[{"id_menu":2,"count":2}]	14258	pick-up	0	14
49124	2020-04-12 01:44:18	2020-04-12	9	[{"id_menu":6,"count":1}]	19615	pick-up	0	9
49125	2020-04-12 01:50:38	2020-04-12	12	[{"id_menu":1,"count":1}]	149	pick-up	0	12
49126	2020-04-12 01:51:18	2020-04-12	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12208	delivery	5	48
49127	2020-04-12 01:51:47	2020-04-12	14	[{"id_menu":2,"count":1}]	1016	delivery	5	19
49128	2020-04-12 01:52:17	2020-04-12	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	7354	pick-up	0	21
49129	2020-04-12 01:55:03	2020-04-12	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	9273	delivery	5	27
49130	2020-04-12 01:56:26	2020-04-12	14	[{"id_menu":2,"count":3}]	19645	pick-up	0	14
49131	2020-04-12 01:59:48	2020-04-12	9	[{"id_menu":6,"count":1}]	15391	delivery	5	14
49132	2020-04-12 02:13:14	2020-04-12	17	[{"id_menu":4,"count":1}]	19626	delivery	5	22
49133	2020-04-12 02:14:07	2020-04-12	17	[{"id_menu":4,"count":1}]	19607	delivery	5	22
49134	2020-04-12 02:17:20	2020-04-12	17	[{"id_menu":4,"count":1}]	13858	pick-up	0	17
49135	2020-04-12 02:18:25	2020-04-12	12	[{"id_menu":1,"count":1}]	16518	delivery	5	17
49136	2020-04-12 02:18:52	2020-04-12	12	[{"id_menu":3,"count":1}]	1053	pick-up	0	12
49137	2020-04-12 02:20:52	2020-04-12	8	[{"id_menu":5,"count":1}]	2132	pick-up	0	8
49138	2020-04-12 02:21:56	2020-04-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	9685	delivery	5	31
49139	2020-04-12 02:22:37	2020-04-12	8	[{"id_menu":5,"count":1}]	19518	delivery	5	13
49140	2020-04-12 02:27:39	2020-04-12	9	[{"id_menu":7,"count":1}]	19554	pick-up	0	9
49141	2020-04-12 02:29:11	2020-04-12	8	[{"id_menu":5,"count":1}]	3511	pick-up	0	8
49142	2020-04-12 02:29:18	2020-04-12	9	[{"id_menu":6,"count":1}]	18099	delivery	5	14
49143	2020-04-12 02:29:19	2020-04-12	8	[{"id_menu":5,"count":1}]	19519	delivery	5	13
49144	2020-04-12 02:29:33	2020-04-12	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	19623	delivery	5	35
49145	2020-04-12 02:30:34	2020-04-12	14	[{"id_menu":2,"count":1}]	3324	pick-up	0	14
49146	2020-04-12 02:31:04	2020-04-12	9	[{"id_menu":6,"count":1}]	3688	delivery	5	14
49147	2020-04-12 02:31:27	2020-04-12	9	[{"id_menu":7,"count":1}]	15653	pick-up	0	9
49148	2020-04-12 02:33:31	2020-04-12	9	[{"id_menu":6,"count":1}]	12098	delivery	5	14
49149	2020-04-12 02:35:33	2020-04-12	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	3494	pick-up	0	21
49150	2020-04-12 02:37:01	2020-04-12	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	19544	delivery	5	26
49151	2020-04-12 02:39:26	2020-04-12	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	15187	pick-up	0	25
49152	2020-04-12 02:39:31	2020-04-12	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	19618	delivery	5	26
49153	2020-04-12 02:41:44	2020-04-12	9	[{"id_menu":7,"count":1}]	10244	pick-up	0	9
49154	2020-04-12 02:42:22	2020-04-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	15555	delivery	5	28
49155	2020-04-12 02:43:21	2020-04-12	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	16693	delivery	5	29
49156	2020-04-12 02:45:12	2020-04-12	9	[{"id_menu":7,"count":1}]	19537	delivery	5	14
49157	2020-04-12 02:47:54	2020-04-12	9	[{"id_menu":7,"count":1}]	6195	delivery	5	14
49158	2020-04-12 02:57:07	2020-04-12	8	[{"id_menu":5,"count":1}]	19586	delivery	5	13
49159	2020-04-12 03:03:57	2020-04-12	14	[{"id_menu":2,"count":1}]	2124	delivery	5	19
49160	2020-04-12 03:04:17	2020-04-12	17	[{"id_menu":4,"count":1}]	17475	delivery	5	22
49161	2020-04-12 03:04:28	2020-04-12	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	19535	delivery	5	35
49162	2020-04-12 03:05:33	2020-04-12	9	[{"id_menu":7,"count":1}]	1453	pick-up	0	9
49163	2020-04-12 03:06:03	2020-04-12	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6489	pick-up	0	31
49164	2020-04-12 03:06:58	2020-04-12	14	[{"id_menu":2,"count":1}]	5332	pick-up	0	14
49165	2020-04-12 03:11:35	2020-04-12	8	[{"id_menu":5,"count":1}]	1505	pick-up	0	8
49166	2020-04-12 03:19:11	2020-04-12	8	[{"id_menu":5,"count":1}]	1541	pick-up	0	8
49167	2020-04-12 03:21:46	2020-04-12	12	[{"id_menu":3,"count":1}]	8757	pick-up	0	12
49168	2020-04-12 03:36:48	2020-04-12	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	8939	delivery	5	31
49169	2020-04-12 03:39:49	2020-04-12	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	14526	delivery	5	26
49170	2020-04-12 03:45:07	2020-04-12	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	502	delivery	5	30
49171	2020-04-12 03:45:36	2020-04-12	8	[{"id_menu":5,"count":1}]	19560	delivery	5	13
49172	2020-04-12 03:47:48	2020-04-12	9	[{"id_menu":6,"count":2}]	19566	delivery	5	14
49173	2020-04-12 03:48:19	2020-04-12	12	[{"id_menu":3,"count":1}]	6844	pick-up	0	12
49174	2020-04-12 03:50:45	2020-04-12	9	[{"id_menu":6,"count":1}]	6013	delivery	5	14
49175	2020-04-12 03:52:19	2020-04-12	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	8797	delivery	5	25
49176	2020-04-12 03:59:13	2020-04-12	9	[{"id_menu":6,"count":2}]	8431	delivery	5	14
49177	2020-04-12 04:01:05	2020-04-12	17	[{"id_menu":4,"count":1}]	19584	delivery	5	22
49178	2020-04-12 04:04:35	2020-04-12	8	[{"id_menu":5,"count":1}]	11225	pick-up	0	8
49179	2020-04-12 04:04:39	2020-04-12	9	[{"id_menu":7,"count":1}]	7451	delivery	5	14
49180	2020-04-12 04:09:44	2020-04-12	14	[{"id_menu":2,"count":1}]	9283	delivery	5	19
49181	2020-04-12 04:10:30	2020-04-12	14	[{"id_menu":2,"count":1}]	19549	delivery	5	19
49182	2020-04-12 04:12:18	2020-04-12	12	[{"id_menu":1,"count":1}]	19550	pick-up	0	12
49183	2020-04-12 04:16:47	2020-04-12	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	237	pick-up	0	34
49184	2020-04-12 04:19:08	2020-04-12	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	519	pick-up	0	49
49185	2020-04-12 04:20:45	2020-04-12	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19527	delivery	5	36
49186	2020-04-12 04:24:59	2020-04-12	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":2}]	14074	delivery	5	25
49187	2020-04-12 04:27:22	2020-04-12	9	[{"id_menu":7,"count":1}]	8660	delivery	5	14
49188	2020-04-12 04:27:59	2020-04-12	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	5901	pick-up	0	26
49189	2020-04-12 04:28:01	2020-04-12	12	[{"id_menu":1,"count":1}]	3706	delivery	5	17
49190	2020-04-12 04:35:17	2020-04-12	12	[{"id_menu":1,"count":1}]	1900	pick-up	0	12
49191	2020-04-12 04:36:00	2020-04-12	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	15022	delivery	5	40
49192	2020-04-12 04:36:35	2020-04-12	8	[{"id_menu":5,"count":1}]	19551	delivery	5	13
49193	2020-04-12 04:36:48	2020-04-12	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	19542	delivery	5	43
49194	2020-04-12 04:38:24	2020-04-12	8	[{"id_menu":5,"count":1}]	19649	delivery	5	13
49195	2020-04-12 04:38:51	2020-04-12	9	[{"id_menu":6,"count":3}]	19638	delivery	5	14
49196	2020-04-12 04:42:03	2020-04-12	17	[{"id_menu":4,"count":1}]	4090	pick-up	0	17
49197	2020-04-12 04:44:19	2020-04-12	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	8977	delivery	5	29
49198	2020-04-12 04:46:35	2020-04-12	12	[{"id_menu":3,"count":1}]	3259	delivery	5	17
49199	2020-04-12 04:47:52	2020-04-12	17	[{"id_menu":4,"count":2}]	3491	pick-up	0	17
49200	2020-04-12 04:49:10	2020-04-12	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	19531	delivery	5	27
49201	2020-04-12 04:52:43	2020-04-12	12	[{"id_menu":1,"count":1}]	3533	pick-up	0	12
49202	2020-04-12 04:56:43	2020-04-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7125	delivery	5	23
49203	2020-04-12 04:59:27	2020-04-12	12	[{"id_menu":3,"count":1}]	17625	delivery	5	17
49204	2020-04-12 05:01:18	2020-04-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5700	delivery	5	22
49205	2020-04-12 05:01:49	2020-04-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3256	delivery	5	31
49206	2020-04-12 05:03:17	2020-04-12	14	[{"id_menu":2,"count":1}]	3696	delivery	5	19
49207	2020-04-12 05:05:47	2020-04-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	19632	delivery	5	31
49208	2020-04-12 05:11:04	2020-04-12	8	[{"id_menu":5,"count":1}]	10857	pick-up	0	8
49209	2020-04-12 05:13:24	2020-04-12	8	[{"id_menu":5,"count":1}]	5125	delivery	5	13
49210	2020-04-12 05:13:32	2020-04-12	9	[{"id_menu":6,"count":1}]	19567	delivery	5	14
49211	2020-04-12 05:14:51	2020-04-12	17	[{"id_menu":4,"count":1}]	2851	pick-up	0	17
49212	2020-04-12 05:15:01	2020-04-12	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	19563	delivery	5	40
49213	2020-04-12 05:17:53	2020-04-12	9	[{"id_menu":7,"count":1}]	3204	delivery	5	14
49214	2020-04-12 05:18:04	2020-04-12	8	[{"id_menu":5,"count":1}]	11351	pick-up	0	8
49215	2020-04-12 05:20:46	2020-04-12	9	[{"id_menu":6,"count":1}]	16052	delivery	5	14
49216	2020-04-12 05:21:03	2020-04-12	9	[{"id_menu":7,"count":1}]	2123	pick-up	0	9
49217	2020-04-12 05:24:14	2020-04-12	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	8397	delivery	5	36
49218	2020-04-12 05:25:35	2020-04-12	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	371	delivery	5	22
49219	2020-04-12 05:25:42	2020-04-12	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2595	pick-up	0	22
49220	2020-04-12 05:31:32	2020-04-12	14	[{"id_menu":2,"count":1}]	17887	delivery	5	19
49221	2020-04-12 05:34:13	2020-04-12	12	[{"id_menu":3,"count":1}]	16844	pick-up	0	12
49222	2020-04-12 05:35:12	2020-04-12	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	19595	delivery	5	48
49223	2020-04-12 05:35:52	2020-04-12	12	[{"id_menu":1,"count":1}]	19572	delivery	5	17
49224	2020-04-12 05:38:28	2020-04-12	12	[{"id_menu":1,"count":1}]	4538	pick-up	0	12
49225	2020-04-12 05:40:43	2020-04-12	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	18040	delivery	5	37
49226	2020-04-12 05:41:10	2020-04-12	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	9099	delivery	5	29
49227	2020-04-12 05:41:15	2020-04-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	19569	delivery	5	31
49228	2020-04-12 05:41:46	2020-04-12	12	[{"id_menu":3,"count":1}]	270	delivery	5	17
49229	2020-04-12 05:48:13	2020-04-12	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1592	pick-up	0	52
49230	2020-04-12 05:53:51	2020-04-12	9	[{"id_menu":7,"count":1}]	19625	delivery	5	14
49231	2020-04-12 05:56:29	2020-04-12	12	[{"id_menu":1,"count":1}]	19614	delivery	5	17
49232	2020-04-12 05:57:26	2020-04-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13939	delivery	5	31
49233	2020-04-12 05:57:33	2020-04-12	9	[{"id_menu":7,"count":1}]	8656	pick-up	0	9
49234	2020-04-12 05:59:26	2020-04-12	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	10951	pick-up	0	43
49235	2020-04-12 06:01:39	2020-04-12	14	[{"id_menu":2,"count":1}]	9852	pick-up	0	14
49236	2020-04-12 06:03:24	2020-04-12	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	5192	delivery	5	43
49237	2020-04-12 06:06:19	2020-04-12	9	[{"id_menu":7,"count":1}]	5935	delivery	5	14
49238	2020-04-12 06:08:19	2020-04-12	12	[{"id_menu":1,"count":1}]	19606	pick-up	0	12
49239	2020-04-12 06:14:07	2020-04-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1049	delivery	5	28
49240	2020-04-12 06:21:20	2020-04-12	17	[{"id_menu":4,"count":1}]	12124	pick-up	0	17
49241	2020-04-12 06:21:59	2020-04-12	12	[{"id_menu":1,"count":1}]	15152	delivery	5	17
49242	2020-04-12 06:22:25	2020-04-12	14	[{"id_menu":2,"count":1}]	1992	pick-up	0	14
49243	2020-04-12 06:27:19	2020-04-12	8	[{"id_menu":5,"count":1}]	19523	delivery	5	13
49244	2020-04-12 06:28:09	2020-04-12	12	[{"id_menu":1,"count":1}]	3986	delivery	5	17
49245	2020-04-12 06:36:37	2020-04-12	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19644	delivery	5	36
49246	2020-04-12 06:39:50	2020-04-12	14	[{"id_menu":2,"count":1}]	17046	pick-up	0	14
49247	2020-04-12 06:41:59	2020-04-12	9	[{"id_menu":7,"count":1}]	3701	delivery	5	14
49248	2020-04-12 06:44:44	2020-04-12	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10787	delivery	5	57
49249	2020-04-12 06:45:28	2020-04-12	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4515	delivery	5	31
49250	2020-04-12 06:45:42	2020-04-12	8	[{"id_menu":5,"count":1}]	7261	delivery	5	13
49251	2020-04-12 06:48:08	2020-04-12	9	[{"id_menu":6,"count":1}]	16253	delivery	5	14
49252	2020-04-12 06:49:55	2020-04-12	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	13953	delivery	5	26
49253	2020-04-12 06:50:59	2020-04-12	9	[{"id_menu":6,"count":1}]	10354	delivery	5	14
49254	2020-04-12 06:54:12	2020-04-12	12	[{"id_menu":1,"count":1}]	15686	pick-up	0	12
49255	2020-04-12 06:57:08	2020-04-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	16422	pick-up	0	23
49256	2020-04-12 06:59:31	2020-04-12	9	[{"id_menu":7,"count":1}]	5318	pick-up	0	9
49257	2020-04-12 06:59:46	2020-04-12	9	[{"id_menu":7,"count":1}]	19528	delivery	5	14
49258	2020-04-12 07:01:24	2020-04-12	14	[{"id_menu":2,"count":1}]	9500	delivery	5	19
49259	2020-04-12 07:02:33	2020-04-12	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	19616	delivery	5	40
49260	2020-04-12 07:04:01	2020-04-12	9	[{"id_menu":7,"count":1}]	1523	delivery	5	14
49261	2020-04-12 07:05:55	2020-04-12	9	[{"id_menu":7,"count":1}]	8558	delivery	5	14
49262	2020-04-12 07:08:35	2020-04-12	17	[{"id_menu":4,"count":1}]	19571	delivery	5	22
49263	2020-04-12 07:12:15	2020-04-12	12	[{"id_menu":1,"count":1}]	9262	delivery	5	17
49264	2020-04-12 07:21:18	2020-04-12	9	[{"id_menu":6,"count":1}]	7	pick-up	0	9
49265	2020-04-12 07:22:48	2020-04-12	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	4794	delivery	5	26
49266	2020-04-12 07:22:57	2020-04-12	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6885	pick-up	0	23
49267	2020-04-12 07:28:14	2020-04-12	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	18392	pick-up	0	31
49268	2020-04-12 07:33:16	2020-04-12	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	19621	delivery	5	31
49269	2020-04-12 07:33:30	2020-04-12	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	4055	delivery	5	31
49270	2020-04-12 07:34:06	2020-04-12	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	11339	delivery	5	40
49271	2020-04-12 07:35:22	2020-04-12	12	[{"id_menu":3,"count":1}]	10018	delivery	5	17
49272	2020-04-12 07:40:14	2020-04-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	14233	pick-up	0	23
49273	2020-04-12 07:41:33	2020-04-12	9	[{"id_menu":7,"count":3}]	19307	delivery	5	14
49274	2020-04-12 07:42:47	2020-04-12	14	[{"id_menu":2,"count":1}]	7571	pick-up	0	14
49275	2020-04-12 07:44:37	2020-04-12	9	[{"id_menu":7,"count":1}]	11947	delivery	5	14
49276	2020-04-12 07:51:54	2020-04-12	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	19620	delivery	5	43
49277	2020-04-12 07:52:11	2020-04-12	14	[{"id_menu":2,"count":1}]	14519	pick-up	0	14
49278	2020-04-12 07:53:20	2020-04-12	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	19539	pick-up	0	23
49279	2020-04-12 07:54:43	2020-04-12	17	[{"id_menu":4,"count":1}]	17515	pick-up	0	17
49280	2020-04-12 08:00:00	2020-04-12	9	[{"id_menu":6,"count":1}]	11799	delivery	5	14
49281	2020-04-12 08:00:57	2020-04-12	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	19113	delivery	5	28
49282	2020-04-12 08:03:22	2020-04-12	9	[{"id_menu":6,"count":1}]	1058	pick-up	0	9
49283	2020-04-12 08:03:24	2020-04-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11366	delivery	5	22
49284	2020-04-12 08:06:37	2020-04-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6970	delivery	5	22
49285	2020-04-12 08:15:31	2020-04-12	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	19628	delivery	5	36
49286	2020-04-12 08:16:56	2020-04-12	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13673	delivery	5	34
49287	2020-04-12 08:24:00	2020-04-12	9	[{"id_menu":7,"count":1}]	6835	delivery	5	14
49288	2020-04-12 08:29:16	2020-04-12	9	[{"id_menu":6,"count":1}]	17906	delivery	5	14
49289	2020-04-12 08:32:54	2020-04-12	17	[{"id_menu":4,"count":1}]	19561	delivery	5	22
49290	2020-04-12 08:36:42	2020-04-12	12	[{"id_menu":3,"count":1}]	19564	delivery	5	17
49291	2020-04-12 08:40:53	2020-04-12	9	[{"id_menu":6,"count":1}]	19611	delivery	5	14
49292	2020-04-12 08:41:25	2020-04-12	9	[{"id_menu":7,"count":1}]	17852	delivery	5	14
49293	2020-04-12 08:43:06	2020-04-12	9	[{"id_menu":7,"count":1}]	19627	delivery	5	14
49294	2020-04-12 08:44:27	2020-04-12	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19562	delivery	5	43
49295	2020-04-12 08:44:57	2020-04-12	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	17792	delivery	5	26
49296	2020-04-12 08:46:04	2020-04-12	17	[{"id_menu":4,"count":1}]	19624	pick-up	0	17
49297	2020-04-12 08:47:10	2020-04-12	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1166	pick-up	0	20
49298	2020-04-12 08:49:00	2020-04-12	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19590	delivery	5	34
49299	2020-04-12 08:50:26	2020-04-12	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	16672	delivery	5	43
49300	2020-04-12 08:50:27	2020-04-12	17	[{"id_menu":4,"count":1}]	16857	delivery	5	22
49301	2020-04-12 08:51:17	2020-04-12	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6049	pick-up	0	26
49302	2020-04-12 08:51:22	2020-04-12	12	[{"id_menu":1,"count":1}]	5729	pick-up	0	12
49303	2020-04-12 08:58:26	2020-04-12	17	[{"id_menu":4,"count":1}]	19034	pick-up	0	17
49304	2020-04-12 09:02:52	2020-04-12	8	[{"id_menu":5,"count":1}]	739	delivery	5	13
49305	2020-04-12 09:05:23	2020-04-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	11564	delivery	5	22
49306	2020-04-12 09:06:46	2020-04-12	9	[{"id_menu":6,"count":1}]	19581	delivery	5	14
49307	2020-04-12 09:08:53	2020-04-12	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	17306	pick-up	0	21
49308	2020-04-12 09:09:29	2020-04-12	9	[{"id_menu":6,"count":1}]	5657	delivery	5	14
49309	2020-04-12 09:10:25	2020-04-12	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	19548	delivery	5	44
49310	2020-04-12 09:11:50	2020-04-12	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	19583	delivery	5	34
49311	2020-04-12 09:12:23	2020-04-12	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	19587	delivery	5	26
49312	2020-04-12 09:16:43	2020-04-12	17	[{"id_menu":4,"count":1}]	3407	delivery	5	22
49313	2020-04-12 09:16:54	2020-04-12	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	19574	delivery	5	26
49314	2020-04-12 09:17:02	2020-04-12	14	[{"id_menu":2,"count":1}]	19642	delivery	5	19
49315	2020-04-12 09:21:18	2020-04-12	17	[{"id_menu":4,"count":1}]	638	pick-up	0	17
49316	2020-04-12 09:30:30	2020-04-12	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9135	delivery	5	35
49317	2020-04-12 09:30:58	2020-04-12	8	[{"id_menu":5,"count":1}]	1673	delivery	5	13
49318	2020-04-12 09:33:25	2020-04-12	12	[{"id_menu":1,"count":1}]	17472	pick-up	0	12
49319	2020-04-12 09:33:54	2020-04-12	12	[{"id_menu":1,"count":1}]	299	pick-up	0	12
49320	2020-04-12 09:34:55	2020-04-12	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18558	delivery	5	37
49321	2020-04-12 09:37:15	2020-04-12	14	[{"id_menu":2,"count":1}]	18148	delivery	5	19
49322	2020-04-12 09:38:22	2020-04-12	9	[{"id_menu":6,"count":3}]	2752	pick-up	0	9
49323	2020-04-12 09:38:32	2020-04-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19604	delivery	5	22
49324	2020-04-12 09:42:36	2020-04-12	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2026	pick-up	0	26
49325	2020-04-12 09:46:08	2020-04-12	9	[{"id_menu":7,"count":1}]	820	pick-up	0	9
49326	2020-04-12 09:48:05	2020-04-12	9	[{"id_menu":6,"count":1}]	5022	delivery	5	14
49327	2020-04-12 09:49:02	2020-04-12	9	[{"id_menu":6,"count":1}]	19643	delivery	5	14
49328	2020-04-12 09:56:55	2020-04-12	12	[{"id_menu":1,"count":1}]	8146	pick-up	0	12
49329	2020-04-12 10:02:03	2020-04-12	12	[{"id_menu":3,"count":1}]	19520	pick-up	0	12
49330	2020-04-12 10:03:08	2020-04-12	9	[{"id_menu":7,"count":1}]	11905	delivery	5	14
49331	2020-04-12 10:05:16	2020-04-12	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	7388	delivery	5	25
49332	2020-04-12 10:05:35	2020-04-12	17	[{"id_menu":4,"count":1}]	2016	delivery	5	22
49333	2020-04-12 10:07:03	2020-04-12	9	[{"id_menu":6,"count":1}]	3807	delivery	5	14
49334	2020-04-12 10:12:49	2020-04-12	9	[{"id_menu":6,"count":1}]	9995	pick-up	0	9
49335	2020-04-12 10:13:37	2020-04-12	23	[{"id_menu":2,"count":3},{"id_menu":7,"count":1}]	19557	delivery	5	28
49336	2020-04-12 10:13:48	2020-04-12	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	19532	delivery	5	22
49337	2020-04-12 10:14:30	2020-04-12	12	[{"id_menu":3,"count":1}]	5149	pick-up	0	12
49338	2020-04-12 10:16:05	2020-04-12	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9850	delivery	5	37
49339	2020-04-12 10:16:38	2020-04-12	8	[{"id_menu":5,"count":1}]	3619	pick-up	0	8
49340	2020-04-12 10:17:43	2020-04-12	12	[{"id_menu":3,"count":1}]	15645	delivery	5	17
49341	2020-04-12 10:19:19	2020-04-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7142	delivery	5	31
49342	2020-04-12 10:20:27	2020-04-12	9	[{"id_menu":6,"count":1}]	1097	pick-up	0	9
49343	2020-04-12 10:22:10	2020-04-12	9	[{"id_menu":7,"count":1}]	1149	pick-up	0	9
49344	2020-04-12 10:30:04	2020-04-12	12	[{"id_menu":1,"count":1}]	19546	delivery	5	17
49345	2020-04-12 10:32:37	2020-04-12	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	19545	delivery	5	39
49346	2020-04-12 10:35:13	2020-04-12	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	19536	delivery	5	42
49347	2020-04-12 10:37:12	2020-04-12	12	[{"id_menu":3,"count":1}]	7151	pick-up	0	12
49348	2020-04-12 10:42:01	2020-04-12	12	[{"id_menu":3,"count":1}]	1263	pick-up	0	12
49349	2020-04-12 10:42:27	2020-04-12	17	[{"id_menu":4,"count":1}]	19603	delivery	5	22
49350	2020-04-12 10:44:56	2020-04-12	17	[{"id_menu":4,"count":1}]	3197	delivery	5	22
49351	2020-04-12 10:47:42	2020-04-12	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	440	delivery	5	36
49352	2020-04-12 10:50:29	2020-04-12	17	[{"id_menu":4,"count":1}]	379	pick-up	0	17
49353	2020-04-12 10:51:01	2020-04-12	17	[{"id_menu":4,"count":1}]	285	pick-up	0	17
49354	2020-04-12 10:51:24	2020-04-12	9	[{"id_menu":7,"count":1}]	8240	pick-up	0	9
49355	2020-04-12 11:00:42	2020-04-12	17	[{"id_menu":4,"count":1}]	9025	delivery	5	22
49356	2020-04-12 11:02:52	2020-04-12	9	[{"id_menu":7,"count":1}]	6091	delivery	5	14
49357	2020-04-12 11:04:26	2020-04-12	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19640	delivery	5	36
49358	2020-04-12 11:05:29	2020-04-12	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	19637	pick-up	0	29
49359	2020-04-12 11:06:44	2020-04-12	12	[{"id_menu":3,"count":1}]	19639	delivery	5	17
49360	2020-04-12 11:12:05	2020-04-12	9	[{"id_menu":7,"count":1}]	19605	delivery	5	14
49361	2020-04-12 11:13:36	2020-04-12	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1537	pick-up	0	29
49362	2020-04-12 11:14:09	2020-04-12	8	[{"id_menu":5,"count":1}]	15201	delivery	5	13
49363	2020-04-12 11:15:09	2020-04-12	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	19585	delivery	5	31
49364	2020-04-12 11:15:47	2020-04-12	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	1582	pick-up	0	35
49365	2020-04-12 11:16:31	2020-04-12	9	[{"id_menu":7,"count":1}]	12808	pick-up	0	9
49366	2020-04-12 11:18:41	2020-04-12	9	[{"id_menu":6,"count":1}]	19568	delivery	5	14
49367	2020-04-12 11:19:11	2020-04-12	9	[{"id_menu":7,"count":2}]	12905	pick-up	0	9
49368	2020-04-12 11:29:49	2020-04-12	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	5817	delivery	5	31
49369	2020-04-12 11:31:04	2020-04-12	9	[{"id_menu":6,"count":1}]	19609	delivery	5	14
49370	2020-04-12 11:31:13	2020-04-12	12	[{"id_menu":1,"count":1}]	1933	pick-up	0	12
49371	2020-04-12 11:35:12	2020-04-12	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	5975	delivery	5	38
49372	2020-04-12 11:35:36	2020-04-12	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9348	delivery	5	43
49373	2020-04-12 11:37:45	2020-04-12	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	10432	delivery	5	28
49374	2020-04-12 11:42:09	2020-04-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15178	delivery	5	23
49375	2020-04-12 11:42:54	2020-04-12	14	[{"id_menu":2,"count":1}]	15314	delivery	5	19
49376	2020-04-12 11:44:13	2020-04-12	12	[{"id_menu":3,"count":1}]	19597	delivery	5	17
49377	2020-04-12 11:46:57	2020-04-12	12	[{"id_menu":3,"count":1}]	10437	delivery	5	17
49378	2020-04-12 11:51:46	2020-04-12	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19379	delivery	5	37
49379	2020-04-12 11:52:16	2020-04-12	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	201	pick-up	0	38
49380	2020-04-12 11:59:16	2020-04-12	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	12207	delivery	5	26
49381	2020-04-12 12:03:43	2020-04-12	9	[{"id_menu":7,"count":1}]	14252	pick-up	0	9
49382	2020-04-12 12:10:03	2020-04-12	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17874	delivery	5	52
49383	2020-04-12 12:10:17	2020-04-12	12	[{"id_menu":3,"count":1}]	9990	delivery	5	17
49384	2020-04-12 12:12:45	2020-04-12	12	[{"id_menu":1,"count":1}]	2566	pick-up	0	12
49385	2020-04-12 12:15:04	2020-04-12	9	[{"id_menu":6,"count":1}]	2168	delivery	5	14
49386	2020-04-12 12:23:18	2020-04-12	9	[{"id_menu":7,"count":1}]	1288	pick-up	0	9
49387	2020-04-12 12:25:25	2020-04-12	8	[{"id_menu":5,"count":1}]	19646	delivery	5	13
49388	2020-04-12 12:26:06	2020-04-12	9	[{"id_menu":7,"count":1}]	11175	delivery	5	14
49389	2020-04-12 12:26:49	2020-04-12	8	[{"id_menu":5,"count":1}]	11703	delivery	5	13
49390	2020-04-12 12:29:36	2020-04-12	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":2}]	19651	delivery	5	22
49391	2020-04-12 12:30:18	2020-04-12	14	[{"id_menu":2,"count":2}]	19552	delivery	5	19
49392	2020-04-12 12:32:46	2020-04-12	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1659	delivery	5	28
49393	2020-04-12 12:33:35	2020-04-12	12	[{"id_menu":1,"count":1}]	6773	delivery	5	17
49394	2020-04-12 12:34:43	2020-04-12	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10499	delivery	5	34
49395	2020-04-12 12:37:17	2020-04-12	9	[{"id_menu":7,"count":1}]	6872	delivery	5	14
49396	2020-04-12 12:38:20	2020-04-12	17	[{"id_menu":4,"count":2}]	10060	delivery	5	22
49397	2020-04-12 12:40:11	2020-04-12	12	[{"id_menu":1,"count":1}]	19579	delivery	5	17
49398	2020-04-12 12:48:10	2020-04-12	12	[{"id_menu":1,"count":1}]	19534	delivery	5	17
49399	2020-04-12 12:55:48	2020-04-12	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3913	delivery	5	52
49400	2020-04-12 12:56:36	2020-04-12	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	4190	delivery	5	26
49401	2020-04-12 13:04:07	2020-04-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19556	delivery	5	22
49402	2020-04-12 13:05:22	2020-04-12	17	[{"id_menu":4,"count":1}]	197	pick-up	0	17
49403	2020-04-12 13:07:17	2020-04-12	17	[{"id_menu":4,"count":1}]	2729	delivery	5	22
49404	2020-04-12 13:09:08	2020-04-12	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	19599	delivery	5	36
49405	2020-04-12 13:12:35	2020-04-12	9	[{"id_menu":7,"count":1}]	7931	pick-up	0	9
49406	2020-04-12 13:14:59	2020-04-12	12	[{"id_menu":1,"count":1}]	6887	pick-up	0	12
49407	2020-04-12 13:19:20	2020-04-12	49	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10796	delivery	5	54
49408	2020-04-12 13:21:35	2020-04-12	17	[{"id_menu":4,"count":1}]	3848	pick-up	0	17
49409	2020-04-12 13:25:39	2020-04-12	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	19634	delivery	5	26
49410	2020-04-12 13:25:40	2020-04-12	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	37	pick-up	0	20
49411	2020-04-12 13:27:19	2020-04-12	14	[{"id_menu":2,"count":1}]	14710	delivery	5	19
49412	2020-04-12 13:29:01	2020-04-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10694	pick-up	0	17
49413	2020-04-12 13:30:10	2020-04-12	17	[{"id_menu":4,"count":1}]	11620	delivery	5	22
49414	2020-04-12 13:33:14	2020-04-12	14	[{"id_menu":2,"count":1}]	19596	delivery	5	19
49415	2020-04-12 13:37:26	2020-04-12	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":3}]	2209	pick-up	0	23
49416	2020-04-12 13:39:30	2020-04-12	8	[{"id_menu":5,"count":1}]	17470	delivery	5	13
49417	2020-04-12 13:42:31	2020-04-12	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15483	delivery	5	31
49418	2020-04-12 13:44:48	2020-04-12	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	19600	delivery	5	27
49419	2020-04-12 13:46:46	2020-04-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	19540	delivery	5	28
49420	2020-04-12 13:48:38	2020-04-12	9	[{"id_menu":6,"count":1}]	19513	delivery	5	14
49421	2020-04-12 13:55:26	2020-04-12	12	[{"id_menu":3,"count":2}]	18374	delivery	5	17
49422	2020-04-12 14:02:01	2020-04-12	9	[{"id_menu":7,"count":1}]	19559	pick-up	0	9
49423	2020-04-12 14:07:29	2020-04-12	8	[{"id_menu":5,"count":1}]	634	pick-up	0	8
49424	2020-04-12 14:15:10	2020-04-12	12	[{"id_menu":1,"count":1}]	19576	delivery	5	17
49425	2020-04-12 14:20:24	2020-04-12	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	19577	delivery	5	34
49426	2020-04-12 14:24:24	2020-04-12	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12234	delivery	5	51
49427	2020-04-12 14:26:24	2020-04-12	9	[{"id_menu":7,"count":1}]	18846	delivery	5	14
49428	2020-04-12 14:27:22	2020-04-12	9	[{"id_menu":6,"count":1}]	19526	delivery	5	14
49429	2020-04-12 14:28:40	2020-04-12	8	[{"id_menu":5,"count":1}]	16660	delivery	5	13
49430	2020-04-12 14:33:51	2020-04-12	12	[{"id_menu":3,"count":1}]	7550	delivery	5	17
49431	2020-04-12 14:34:43	2020-04-12	9	[{"id_menu":7,"count":1}]	19521	delivery	5	14
49432	2020-04-12 14:35:46	2020-04-12	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	19530	delivery	5	25
49433	2020-04-12 14:35:57	2020-04-12	14	[{"id_menu":2,"count":1}]	2351	pick-up	0	14
49434	2020-04-12 14:42:31	2020-04-12	14	[{"id_menu":2,"count":2}]	17866	delivery	5	19
49435	2020-04-12 14:44:24	2020-04-12	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	19553	delivery	5	40
49436	2020-04-12 14:45:45	2020-04-12	9	[{"id_menu":6,"count":1}]	13226	delivery	5	14
49437	2020-04-12 14:48:20	2020-04-12	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	12056	delivery	5	25
49438	2020-04-12 14:54:41	2020-04-12	9	[{"id_menu":7,"count":1}]	16858	pick-up	0	9
49439	2020-04-12 14:55:40	2020-04-12	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7148	pick-up	0	23
49440	2020-04-12 15:05:59	2020-04-12	14	[{"id_menu":2,"count":1}]	12699	pick-up	0	14
49441	2020-04-12 15:06:31	2020-04-12	9	[{"id_menu":6,"count":1}]	8550	pick-up	0	9
49442	2020-04-12 15:07:45	2020-04-12	12	[{"id_menu":3,"count":1}]	19593	delivery	5	17
49443	2020-04-12 15:09:15	2020-04-12	12	[{"id_menu":3,"count":1}]	19598	pick-up	0	12
49444	2020-04-12 15:12:15	2020-04-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	18649	delivery	5	28
49445	2020-04-12 15:25:22	2020-04-12	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18403	delivery	5	40
49446	2020-04-12 15:28:11	2020-04-12	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	10815	delivery	5	26
49447	2020-04-12 15:32:36	2020-04-12	9	[{"id_menu":7,"count":1}]	1509	pick-up	0	9
49448	2020-04-12 15:33:18	2020-04-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14726	delivery	5	31
49449	2020-04-12 15:33:45	2020-04-12	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	19602	pick-up	0	26
49450	2020-04-12 15:39:44	2020-04-12	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19558	delivery	5	48
49451	2020-04-12 15:39:55	2020-04-12	9	[{"id_menu":6,"count":1}]	2783	delivery	5	14
49452	2020-04-12 15:43:29	2020-04-12	9	[{"id_menu":7,"count":1}]	19529	delivery	5	14
49453	2020-04-12 15:44:07	2020-04-12	14	[{"id_menu":2,"count":1}]	6164	pick-up	0	14
49454	2020-04-12 15:45:11	2020-04-12	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19573	delivery	5	52
49455	2020-04-12 15:48:26	2020-04-12	12	[{"id_menu":1,"count":1}]	14125	delivery	5	17
49456	2020-04-12 15:49:22	2020-04-12	8	[{"id_menu":5,"count":1}]	16412	delivery	5	13
49457	2020-04-12 15:50:56	2020-04-12	12	[{"id_menu":1,"count":1}]	1233	pick-up	0	12
49458	2020-04-12 15:55:39	2020-04-12	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	19610	delivery	5	40
49459	2020-04-12 15:58:38	2020-04-12	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6905	delivery	5	34
49460	2020-04-12 15:59:08	2020-04-12	9	[{"id_menu":6,"count":1}]	19533	delivery	5	14
49461	2020-04-12 16:00:03	2020-04-12	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	7589	pick-up	0	26
49462	2020-04-12 16:00:39	2020-04-12	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	13911	pick-up	0	23
49463	2020-04-12 16:01:25	2020-04-12	14	[{"id_menu":2,"count":1}]	4306	delivery	5	19
49464	2020-04-12 16:02:39	2020-04-12	9	[{"id_menu":6,"count":1}]	6030	delivery	5	14
49465	2020-04-12 16:03:40	2020-04-12	9	[{"id_menu":6,"count":2}]	19547	delivery	5	14
49466	2020-04-12 16:03:55	2020-04-12	9	[{"id_menu":6,"count":1}]	16694	delivery	5	14
49467	2020-04-12 16:06:41	2020-04-12	14	[{"id_menu":2,"count":1}]	19157	delivery	5	19
49468	2020-04-12 16:15:26	2020-04-12	14	[{"id_menu":2,"count":1}]	19541	pick-up	0	14
49469	2020-04-12 16:18:30	2020-04-12	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	19636	delivery	5	34
49470	2020-04-12 16:18:34	2020-04-12	9	[{"id_menu":6,"count":2}]	19580	delivery	5	14
49471	2020-04-12 16:22:16	2020-04-12	14	[{"id_menu":2,"count":1}]	14679	delivery	5	19
49472	2020-04-12 16:24:22	2020-04-12	8	[{"id_menu":5,"count":1}]	9209	delivery	5	13
49473	2020-04-12 16:27:21	2020-04-12	9	[{"id_menu":7,"count":1}]	16270	delivery	5	14
49474	2020-04-12 16:35:01	2020-04-12	9	[{"id_menu":6,"count":1}]	10871	delivery	5	14
49475	2020-04-12 16:36:25	2020-04-12	14	[{"id_menu":2,"count":1}]	792	pick-up	0	14
49476	2020-04-12 16:42:25	2020-04-12	9	[{"id_menu":6,"count":1}]	19538	delivery	5	14
49477	2020-04-12 16:53:41	2020-04-12	8	[{"id_menu":5,"count":1}]	11469	delivery	5	13
49478	2020-04-12 16:59:59	2020-04-12	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	19635	delivery	5	25
49479	2020-04-12 17:01:24	2020-04-12	8	[{"id_menu":5,"count":1}]	19075	pick-up	0	8
49480	2020-04-12 17:02:54	2020-04-12	14	[{"id_menu":2,"count":1}]	1536	pick-up	0	14
49481	2020-04-12 17:09:15	2020-04-12	12	[{"id_menu":3,"count":1}]	11010	pick-up	0	12
49482	2020-04-12 17:12:41	2020-04-12	34	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	2498	pick-up	0	34
49483	2020-04-12 17:13:53	2020-04-12	9	[{"id_menu":7,"count":1}]	2928	delivery	5	14
49484	2020-04-12 17:18:59	2020-04-12	17	[{"id_menu":4,"count":1}]	8021	delivery	5	22
49485	2020-04-12 17:20:42	2020-04-12	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	17461	delivery	5	39
49486	2020-04-12 17:24:30	2020-04-12	8	[{"id_menu":5,"count":1}]	2985	delivery	5	13
49487	2020-04-12 17:24:34	2020-04-12	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	5942	delivery	5	37
49488	2020-04-12 17:30:52	2020-04-12	17	[{"id_menu":4,"count":1}]	9830	pick-up	0	17
49489	2020-04-12 17:31:15	2020-04-12	9	[{"id_menu":7,"count":1}]	1557	pick-up	0	9
49490	2020-04-12 17:31:23	2020-04-12	9	[{"id_menu":6,"count":1}]	11239	delivery	5	14
49491	2020-04-12 17:32:28	2020-04-12	9	[{"id_menu":6,"count":1}]	11004	delivery	5	14
49492	2020-04-12 17:34:11	2020-04-12	9	[{"id_menu":6,"count":1}]	19578	delivery	5	14
49493	2020-04-12 17:38:07	2020-04-12	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	15730	delivery	5	28
49494	2020-04-12 17:39:46	2020-04-12	9	[{"id_menu":6,"count":2}]	8600	delivery	5	14
49495	2020-04-12 17:41:04	2020-04-12	9	[{"id_menu":6,"count":1}]	17369	pick-up	0	9
49496	2020-04-12 17:41:46	2020-04-12	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19524	delivery	5	34
49497	2020-04-12 17:44:43	2020-04-12	14	[{"id_menu":2,"count":1}]	1376	pick-up	0	14
49498	2020-04-12 17:46:29	2020-04-12	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	15822	delivery	5	48
49499	2020-04-12 17:46:53	2020-04-12	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15394	pick-up	0	35
49500	2020-04-12 17:47:56	2020-04-12	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	19589	delivery	5	26
49501	2020-04-12 17:48:46	2020-04-12	9	[{"id_menu":6,"count":1}]	1929	pick-up	0	9
49502	2020-04-12 17:52:24	2020-04-12	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	14493	delivery	5	23
49503	2020-04-12 17:59:21	2020-04-12	8	[{"id_menu":5,"count":1}]	6448	delivery	5	13
49504	2020-04-12 17:59:32	2020-04-12	9	[{"id_menu":7,"count":1}]	19612	delivery	5	14
49505	2020-04-12 18:00:57	2020-04-12	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	19517	delivery	5	26
49506	2020-04-12 18:03:21	2020-04-12	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	19565	delivery	5	37
49507	2020-04-12 18:08:22	2020-04-12	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7681	delivery	5	37
49508	2020-04-12 18:09:24	2020-04-12	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15327	delivery	5	31
49509	2020-04-12 18:19:14	2020-04-12	14	[{"id_menu":2,"count":1}]	19380	delivery	5	19
49510	2020-04-12 18:29:57	2020-04-12	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9111	pick-up	0	25
49511	2020-04-12 18:32:22	2020-04-12	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19648	delivery	5	34
49512	2020-04-12 18:36:04	2020-04-12	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	18567	delivery	5	28
49513	2020-04-12 18:38:20	2020-04-12	12	[{"id_menu":1,"count":1}]	19515	delivery	5	17
49514	2020-04-12 18:40:16	2020-04-12	9	[{"id_menu":7,"count":1}]	16185	delivery	5	14
49515	2020-04-12 18:40:39	2020-04-12	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	13711	delivery	5	30
49516	2020-04-12 18:44:17	2020-04-12	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4765	pick-up	0	22
49517	2020-04-12 18:51:53	2020-04-12	14	[{"id_menu":2,"count":1}]	11790	pick-up	0	14
49518	2020-04-12 19:06:07	2020-04-12	9	[{"id_menu":6,"count":1}]	2889	pick-up	0	9
49519	2020-04-12 19:07:00	2020-04-12	12	[{"id_menu":3,"count":1}]	14025	pick-up	0	12
49520	2020-04-12 19:11:43	2020-04-12	14	[{"id_menu":2,"count":1}]	7444	delivery	5	19
49521	2020-04-12 19:21:05	2020-04-12	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10807	pick-up	0	26
49522	2020-04-12 19:21:59	2020-04-12	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16569	delivery	5	55
49523	2020-04-12 19:22:46	2020-04-12	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	5459	delivery	5	31
49524	2020-04-12 19:23:48	2020-04-12	9	[{"id_menu":6,"count":1}]	4076	delivery	5	14
49525	2020-04-12 19:42:42	2020-04-12	9	[{"id_menu":7,"count":1}]	13054	pick-up	0	9
49526	2020-04-12 19:47:27	2020-04-12	8	[{"id_menu":5,"count":1}]	11298	delivery	5	13
49527	2020-04-12 19:51:15	2020-04-12	12	[{"id_menu":1,"count":1}]	6429	delivery	5	17
49528	2020-04-12 19:53:17	2020-04-12	12	[{"id_menu":1,"count":1}]	3268	pick-up	0	12
49529	2020-04-12 19:54:51	2020-04-12	9	[{"id_menu":7,"count":1}]	17784	pick-up	0	9
49530	2020-04-12 20:00:57	2020-04-12	17	[{"id_menu":4,"count":1}]	14006	delivery	5	22
49531	2020-04-12 20:05:52	2020-04-12	17	[{"id_menu":4,"count":1}]	6268	delivery	5	22
49532	2020-04-12 20:14:11	2020-04-12	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	14299	pick-up	0	26
49533	2020-04-12 20:18:27	2020-04-12	14	[{"id_menu":2,"count":1}]	19629	delivery	5	19
49534	2020-04-12 20:19:00	2020-04-12	9	[{"id_menu":6,"count":1}]	8013	delivery	5	14
49535	2020-04-12 20:28:14	2020-04-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9565	delivery	5	31
49536	2020-04-12 20:31:50	2020-04-12	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	8877	delivery	5	37
49537	2020-04-12 20:39:01	2020-04-12	14	[{"id_menu":2,"count":1}]	8205	pick-up	0	14
49538	2020-04-12 20:41:10	2020-04-12	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	9375	pick-up	0	29
49539	2020-04-12 20:46:32	2020-04-12	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8185	pick-up	0	17
49540	2020-04-12 20:49:02	2020-04-12	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	19078	pick-up	0	25
49541	2020-04-12 20:53:24	2020-04-12	17	[{"id_menu":4,"count":1}]	18357	delivery	5	22
49542	2020-04-12 20:53:58	2020-04-12	9	[{"id_menu":6,"count":1}]	13543	delivery	5	14
49543	2020-04-12 20:58:44	2020-04-12	17	[{"id_menu":4,"count":1}]	14982	pick-up	0	17
49544	2020-04-12 20:59:53	2020-04-12	17	[{"id_menu":4,"count":1}]	16056	delivery	5	22
49545	2020-04-12 21:02:17	2020-04-12	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19613	delivery	5	31
49546	2020-04-12 21:03:33	2020-04-12	12	[{"id_menu":3,"count":1}]	4465	pick-up	0	12
49547	2020-04-12 21:04:40	2020-04-12	12	[{"id_menu":1,"count":1}]	13907	delivery	5	17
49548	2020-04-12 21:11:52	2020-04-12	9	[{"id_menu":7,"count":2}]	8135	delivery	5	14
49549	2020-04-12 21:12:08	2020-04-12	8	[{"id_menu":5,"count":1}]	7655	delivery	5	13
49550	2020-04-12 21:15:34	2020-04-12	17	[{"id_menu":4,"count":1}]	17614	pick-up	0	17
49551	2020-04-12 21:16:29	2020-04-12	14	[{"id_menu":2,"count":1}]	19619	delivery	5	19
49552	2020-04-12 21:17:00	2020-04-12	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	19516	pick-up	0	38
49553	2020-04-12 21:17:06	2020-04-12	17	[{"id_menu":4,"count":1}]	7037	delivery	5	22
49554	2020-04-12 21:17:26	2020-04-12	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1423	delivery	5	29
49555	2020-04-12 21:30:44	2020-04-12	9	[{"id_menu":6,"count":1}]	10880	delivery	5	14
49556	2020-04-12 21:34:41	2020-04-12	12	[{"id_menu":3,"count":1}]	3898	delivery	5	17
49557	2020-04-12 21:37:32	2020-04-12	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":2}]	5180	pick-up	0	29
49558	2020-04-12 21:39:16	2020-04-12	9	[{"id_menu":6,"count":1}]	19522	delivery	5	14
49559	2020-04-12 21:43:02	2020-04-12	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	18031	delivery	5	34
49560	2020-04-12 21:47:28	2020-04-12	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7041	delivery	5	30
49561	2020-04-12 21:52:36	2020-04-12	12	[{"id_menu":1,"count":1}]	19570	delivery	5	17
49562	2020-04-12 21:54:15	2020-04-12	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	4862	pick-up	0	29
49563	2020-04-12 22:00:02	2020-04-12	14	[{"id_menu":2,"count":1}]	2590	pick-up	0	14
49564	2020-04-12 22:05:19	2020-04-12	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	19631	delivery	5	40
49565	2020-04-12 22:09:41	2020-04-12	9	[{"id_menu":7,"count":1}]	1683	pick-up	0	9
49566	2020-04-12 22:13:43	2020-04-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	10206	delivery	5	28
49567	2020-04-12 22:20:15	2020-04-12	14	[{"id_menu":2,"count":1}]	19641	delivery	5	19
49568	2020-04-12 22:24:17	2020-04-12	8	[{"id_menu":5,"count":1}]	16173	delivery	5	13
49569	2020-04-12 22:30:05	2020-04-12	8	[{"id_menu":5,"count":2}]	19555	delivery	5	13
49570	2020-04-12 22:31:04	2020-04-12	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	584	delivery	5	26
49571	2020-04-12 22:35:27	2020-04-12	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	8940	delivery	5	27
49572	2020-04-12 22:36:33	2020-04-12	12	[{"id_menu":3,"count":1}]	2004	pick-up	0	12
49573	2020-04-12 22:38:58	2020-04-12	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	14737	delivery	5	26
49574	2020-04-12 22:39:16	2020-04-12	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1310	delivery	5	53
49575	2020-04-12 22:45:19	2020-04-12	9	[{"id_menu":7,"count":1}]	19650	delivery	5	14
49576	2020-04-12 22:49:26	2020-04-12	8	[{"id_menu":5,"count":1}]	19591	delivery	5	13
49577	2020-04-12 22:56:02	2020-04-12	12	[{"id_menu":3,"count":1}]	2439	pick-up	0	12
49578	2020-04-12 22:57:42	2020-04-12	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6074	pick-up	0	26
49579	2020-04-12 22:58:29	2020-04-12	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14691	delivery	5	34
49580	2020-04-12 22:59:56	2020-04-12	17	[{"id_menu":4,"count":1}]	2633	pick-up	0	17
49581	2020-04-12 23:00:41	2020-04-12	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15326	delivery	5	54
49582	2020-04-12 23:07:03	2020-04-12	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	3427	delivery	5	37
49583	2020-04-12 23:11:17	2020-04-12	9	[{"id_menu":7,"count":1}]	19594	delivery	5	14
49584	2020-04-12 23:15:46	2020-04-12	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	784	pick-up	0	21
49585	2020-04-12 23:19:21	2020-04-12	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	19601	pick-up	0	21
49586	2020-04-12 23:19:57	2020-04-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	6820	delivery	5	22
49587	2020-04-12 23:21:03	2020-04-12	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	19608	delivery	5	45
49588	2020-04-12 23:24:52	2020-04-12	14	[{"id_menu":2,"count":1}]	1670	delivery	5	19
49589	2020-04-12 23:27:02	2020-04-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	8461	delivery	5	22
49590	2020-04-12 23:27:12	2020-04-12	14	[{"id_menu":2,"count":1}]	2416	pick-up	0	14
49591	2020-04-12 23:32:40	2020-04-12	9	[{"id_menu":6,"count":1}]	19525	pick-up	0	9
49592	2020-04-12 23:36:15	2020-04-12	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15855	delivery	5	34
49593	2020-04-12 23:44:38	2020-04-12	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	8742	delivery	5	40
49594	2020-04-12 23:47:45	2020-04-12	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2310	pick-up	0	35
49595	2020-04-12 23:50:53	2020-04-12	9	[{"id_menu":7,"count":1}]	16088	delivery	5	14
49596	2020-04-12 23:59:18	2020-04-12	9	[{"id_menu":7,"count":1}]	8039	pick-up	0	9
49597	2020-04-12 23:59:40	2020-04-12	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	19633	pick-up	0	26
49598	2020-04-13 00:00:35	2020-04-13	12	[{"id_menu":3,"count":1}]	13411	delivery	5	17
49599	2020-04-13 00:04:13	2020-04-13	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	9116	delivery	5	34
49600	2020-04-13 00:04:32	2020-04-13	12	[{"id_menu":3,"count":1}]	8967	delivery	5	17
49601	2020-04-13 00:05:27	2020-04-13	17	[{"id_menu":4,"count":1}]	13026	delivery	5	22
49602	2020-04-13 00:06:50	2020-04-13	17	[{"id_menu":4,"count":1}]	9562	delivery	5	22
49603	2020-04-13 00:12:14	2020-04-13	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	19727	delivery	5	25
49604	2020-04-13 00:13:28	2020-04-13	12	[{"id_menu":1,"count":1}]	2089	pick-up	0	12
49605	2020-04-13 00:21:52	2020-04-13	9	[{"id_menu":7,"count":1}]	11377	delivery	5	14
49606	2020-04-13 00:22:31	2020-04-13	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	19670	delivery	5	26
49607	2020-04-13 00:24:56	2020-04-13	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	2071	pick-up	0	21
49608	2020-04-13 00:37:10	2020-04-13	14	[{"id_menu":2,"count":2}]	10034	delivery	5	19
49609	2020-04-13 00:41:05	2020-04-13	8	[{"id_menu":5,"count":1}]	16466	delivery	5	13
49610	2020-04-13 00:47:07	2020-04-13	8	[{"id_menu":5,"count":1}]	651	pick-up	0	8
49611	2020-04-13 00:54:17	2020-04-13	17	[{"id_menu":4,"count":1}]	16914	pick-up	0	17
49612	2020-04-13 00:54:41	2020-04-13	12	[{"id_menu":3,"count":2}]	8195	delivery	5	17
49613	2020-04-13 01:13:20	2020-04-13	9	[{"id_menu":7,"count":1}]	19746	delivery	5	14
49614	2020-04-13 01:31:56	2020-04-13	14	[{"id_menu":2,"count":2}]	678	pick-up	0	14
49615	2020-04-13 01:32:25	2020-04-13	8	[{"id_menu":5,"count":1}]	19739	delivery	5	13
49616	2020-04-13 01:41:33	2020-04-13	14	[{"id_menu":2,"count":1}]	13238	delivery	5	19
49617	2020-04-13 02:06:55	2020-04-13	9	[{"id_menu":7,"count":1}]	19810	pick-up	0	9
49618	2020-04-13 02:17:27	2020-04-13	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	19700	delivery	5	28
49619	2020-04-13 02:18:50	2020-04-13	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":2}]	19747	delivery	5	26
49620	2020-04-13 02:23:06	2020-04-13	8	[{"id_menu":5,"count":1}]	1820	pick-up	0	8
49621	2020-04-13 02:25:25	2020-04-13	9	[{"id_menu":7,"count":1}]	19671	delivery	5	14
49622	2020-04-13 02:25:49	2020-04-13	12	[{"id_menu":3,"count":1}]	16753	pick-up	0	12
49623	2020-04-13 02:26:04	2020-04-13	14	[{"id_menu":2,"count":1}]	19822	delivery	5	19
49624	2020-04-13 02:46:17	2020-04-13	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19749	delivery	5	31
49625	2020-04-13 02:48:21	2020-04-13	17	[{"id_menu":4,"count":1}]	19724	delivery	5	22
49626	2020-04-13 02:50:36	2020-04-13	8	[{"id_menu":5,"count":1}]	19731	delivery	5	13
49627	2020-04-13 02:51:57	2020-04-13	12	[{"id_menu":3,"count":1}]	44	pick-up	0	12
49628	2020-04-13 02:56:59	2020-04-13	9	[{"id_menu":6,"count":1}]	17700	pick-up	0	9
49629	2020-04-13 02:59:52	2020-04-13	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	11527	delivery	5	26
49630	2020-04-13 03:04:49	2020-04-13	9	[{"id_menu":6,"count":1}]	19673	delivery	5	14
49631	2020-04-13 03:08:56	2020-04-13	14	[{"id_menu":2,"count":1}]	8799	delivery	5	19
49632	2020-04-13 03:17:14	2020-04-13	14	[{"id_menu":2,"count":1}]	48	pick-up	0	14
49633	2020-04-13 03:22:08	2020-04-13	9	[{"id_menu":7,"count":1}]	7678	pick-up	0	9
49634	2020-04-13 03:22:21	2020-04-13	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	19669	delivery	5	27
49635	2020-04-13 03:35:00	2020-04-13	9	[{"id_menu":7,"count":1}]	2767	delivery	5	14
49636	2020-04-13 03:35:50	2020-04-13	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	14519	pick-up	0	17
49637	2020-04-13 04:39:10	2020-04-13	14	[{"id_menu":2,"count":1}]	12855	pick-up	0	14
49638	2020-04-13 04:53:32	2020-04-13	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	19668	delivery	5	43
49639	2020-04-13 05:00:44	2020-04-13	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	19800	delivery	5	37
49640	2020-04-13 05:06:33	2020-04-13	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	19735	delivery	5	25
49641	2020-04-13 05:12:31	2020-04-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19782	delivery	5	23
49642	2020-04-13 05:16:26	2020-04-13	9	[{"id_menu":6,"count":1}]	19794	delivery	5	14
49643	2020-04-13 05:34:30	2020-04-13	9	[{"id_menu":6,"count":1}]	7802	delivery	5	14
49644	2020-04-13 05:39:22	2020-04-13	9	[{"id_menu":6,"count":1}]	9749	pick-up	0	9
49645	2020-04-13 05:40:02	2020-04-13	9	[{"id_menu":7,"count":1}]	9308	delivery	5	14
49646	2020-04-13 05:42:41	2020-04-13	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	18729	delivery	5	26
49647	2020-04-13 05:46:10	2020-04-13	9	[{"id_menu":6,"count":1}]	19657	delivery	5	14
49648	2020-04-13 06:02:01	2020-04-13	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	15872	delivery	5	34
49649	2020-04-13 06:09:27	2020-04-13	12	[{"id_menu":3,"count":1}]	2078	delivery	5	17
49650	2020-04-13 06:10:38	2020-04-13	14	[{"id_menu":2,"count":1}]	19823	delivery	5	19
49651	2020-04-13 06:26:00	2020-04-13	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	19753	delivery	5	26
49652	2020-04-13 06:29:29	2020-04-13	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	12387	pick-up	0	43
49653	2020-04-13 06:31:30	2020-04-13	14	[{"id_menu":2,"count":1}]	3447	delivery	5	19
49654	2020-04-13 06:49:03	2020-04-13	9	[{"id_menu":7,"count":1}]	2662	delivery	5	14
49655	2020-04-13 06:56:00	2020-04-13	12	[{"id_menu":3,"count":1}]	19684	pick-up	0	12
49656	2020-04-13 07:01:48	2020-04-13	8	[{"id_menu":5,"count":1}]	1810	delivery	5	13
49657	2020-04-13 07:32:00	2020-04-13	9	[{"id_menu":7,"count":1}]	17336	delivery	5	14
49658	2020-04-13 07:41:28	2020-04-13	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	19690	delivery	5	31
49659	2020-04-13 07:59:33	2020-04-13	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	15787	delivery	5	27
49660	2020-04-13 08:09:00	2020-04-13	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	5213	delivery	5	28
49661	2020-04-13 08:09:02	2020-04-13	9	[{"id_menu":6,"count":1}]	19825	delivery	5	14
49662	2020-04-13 08:12:31	2020-04-13	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12793	delivery	5	45
49663	2020-04-13 08:14:46	2020-04-13	9	[{"id_menu":6,"count":1}]	3757	pick-up	0	9
49664	2020-04-13 08:16:12	2020-04-13	8	[{"id_menu":5,"count":1}]	19759	delivery	5	13
49665	2020-04-13 08:26:16	2020-04-13	9	[{"id_menu":6,"count":1}]	14398	delivery	5	14
49666	2020-04-13 08:41:15	2020-04-13	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19741	delivery	5	39
49667	2020-04-13 08:47:27	2020-04-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	10321	delivery	5	28
49668	2020-04-13 08:47:36	2020-04-13	17	[{"id_menu":4,"count":1}]	16101	delivery	5	22
49669	2020-04-13 09:03:13	2020-04-13	39	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	19733	delivery	5	44
49670	2020-04-13 09:10:56	2020-04-13	12	[{"id_menu":3,"count":1}]	4265	delivery	5	17
49671	2020-04-13 09:22:30	2020-04-13	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	6701	delivery	5	26
49672	2020-04-13 09:27:57	2020-04-13	12	[{"id_menu":3,"count":1}]	15534	delivery	5	17
49673	2020-04-13 09:30:48	2020-04-13	9	[{"id_menu":6,"count":1}]	14191	delivery	5	14
49674	2020-04-13 09:35:48	2020-04-13	9	[{"id_menu":7,"count":1}]	6916	pick-up	0	9
49675	2020-04-13 09:39:21	2020-04-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19798	pick-up	0	18
49676	2020-04-13 09:45:43	2020-04-13	17	[{"id_menu":4,"count":1}]	19786	delivery	5	22
49677	2020-04-13 09:58:12	2020-04-13	14	[{"id_menu":2,"count":1}]	19709	pick-up	0	14
49678	2020-04-13 10:10:42	2020-04-13	9	[{"id_menu":7,"count":1}]	19679	delivery	5	14
49679	2020-04-13 10:15:09	2020-04-13	12	[{"id_menu":3,"count":1}]	10651	delivery	5	17
49680	2020-04-13 10:23:31	2020-04-13	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1079	delivery	5	31
49681	2020-04-13 10:27:02	2020-04-13	14	[{"id_menu":2,"count":1}]	12150	pick-up	0	14
49682	2020-04-13 10:34:29	2020-04-13	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17794	delivery	5	57
49683	2020-04-13 10:37:15	2020-04-13	14	[{"id_menu":2,"count":1}]	14086	pick-up	0	14
49684	2020-04-13 10:47:47	2020-04-13	17	[{"id_menu":4,"count":1}]	19699	delivery	5	22
49685	2020-04-13 10:49:22	2020-04-13	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	14742	delivery	5	28
49686	2020-04-13 10:52:18	2020-04-13	8	[{"id_menu":5,"count":1}]	19778	delivery	5	13
49687	2020-04-13 11:20:24	2020-04-13	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	19715	delivery	5	36
49688	2020-04-13 11:48:53	2020-04-13	12	[{"id_menu":1,"count":1}]	528	delivery	5	17
49689	2020-04-13 11:51:41	2020-04-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19785	delivery	5	23
49690	2020-04-13 11:56:07	2020-04-13	12	[{"id_menu":3,"count":1}]	4546	delivery	5	17
49691	2020-04-13 11:59:21	2020-04-13	9	[{"id_menu":6,"count":1}]	19694	delivery	5	14
49692	2020-04-13 12:04:54	2020-04-13	14	[{"id_menu":2,"count":1}]	19732	delivery	5	19
49693	2020-04-13 12:05:09	2020-04-13	12	[{"id_menu":1,"count":1}]	19617	delivery	5	17
49694	2020-04-13 12:20:31	2020-04-13	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	19743	delivery	5	23
49695	2020-04-13 12:23:29	2020-04-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	16958	delivery	5	28
49696	2020-04-13 12:24:53	2020-04-13	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19666	delivery	5	22
49697	2020-04-13 12:36:19	2020-04-13	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19689	delivery	5	31
49698	2020-04-13 12:39:55	2020-04-13	12	[{"id_menu":3,"count":1}]	8355	pick-up	0	12
49699	2020-04-13 12:51:45	2020-04-13	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19809	delivery	5	35
49700	2020-04-13 12:52:07	2020-04-13	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	19812	delivery	5	43
49701	2020-04-13 12:52:36	2020-04-13	9	[{"id_menu":6,"count":1}]	19718	delivery	5	14
49702	2020-04-13 12:58:30	2020-04-13	9	[{"id_menu":7,"count":1}]	19754	delivery	5	14
49703	2020-04-13 12:59:20	2020-04-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	19792	delivery	5	36
49704	2020-04-13 13:08:17	2020-04-13	12	[{"id_menu":3,"count":1}]	18408	delivery	5	17
49705	2020-04-13 13:08:43	2020-04-13	17	[{"id_menu":4,"count":1}]	19719	delivery	5	22
49706	2020-04-13 13:15:03	2020-04-13	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1984	pick-up	0	24
49707	2020-04-13 13:16:34	2020-04-13	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	19730	pick-up	0	21
49708	2020-04-13 13:18:06	2020-04-13	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19808	delivery	5	36
49709	2020-04-13 13:26:57	2020-04-13	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12315	delivery	5	34
49710	2020-04-13 13:27:37	2020-04-13	12	[{"id_menu":1,"count":1}]	17043	delivery	5	17
49711	2020-04-13 13:35:10	2020-04-13	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19720	delivery	5	39
49712	2020-04-13 13:40:39	2020-04-13	17	[{"id_menu":4,"count":1}]	17747	delivery	5	22
49713	2020-04-13 13:46:51	2020-04-13	9	[{"id_menu":6,"count":1}]	5998	delivery	5	14
49714	2020-04-13 13:50:35	2020-04-13	9	[{"id_menu":6,"count":1}]	19664	pick-up	0	9
49715	2020-04-13 13:51:40	2020-04-13	14	[{"id_menu":2,"count":1}]	19691	delivery	5	19
49716	2020-04-13 13:55:37	2020-04-13	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19772	delivery	5	36
49717	2020-04-13 14:00:45	2020-04-13	17	[{"id_menu":4,"count":1}]	16574	pick-up	0	17
49718	2020-04-13 14:09:03	2020-04-13	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	19740	delivery	5	28
49719	2020-04-13 14:19:05	2020-04-13	8	[{"id_menu":5,"count":1}]	19770	delivery	5	13
49720	2020-04-13 14:23:54	2020-04-13	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	8597	delivery	5	40
49721	2020-04-13 14:38:07	2020-04-13	9	[{"id_menu":6,"count":1}]	362	delivery	5	14
49722	2020-04-13 14:45:18	2020-04-13	9	[{"id_menu":7,"count":1}]	4840	delivery	5	14
49723	2020-04-13 14:49:32	2020-04-13	14	[{"id_menu":2,"count":1}]	19716	delivery	5	19
49724	2020-04-13 15:10:51	2020-04-13	12	[{"id_menu":1,"count":1}]	19799	delivery	5	17
49725	2020-04-13 15:37:13	2020-04-13	14	[{"id_menu":2,"count":1}]	9847	pick-up	0	14
49726	2020-04-13 15:43:50	2020-04-13	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19507	delivery	5	22
49727	2020-04-13 15:49:25	2020-04-13	17	[{"id_menu":4,"count":1}]	10866	delivery	5	22
49728	2020-04-13 16:03:27	2020-04-13	14	[{"id_menu":2,"count":1}]	7202	delivery	5	19
49729	2020-04-13 16:06:56	2020-04-13	9	[{"id_menu":6,"count":1}]	19771	delivery	5	14
49730	2020-04-13 16:10:39	2020-04-13	14	[{"id_menu":2,"count":1}]	15816	delivery	5	19
49731	2020-04-13 16:11:18	2020-04-13	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19796	delivery	5	36
49732	2020-04-13 16:18:57	2020-04-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4175	pick-up	0	23
49733	2020-04-13 16:21:39	2020-04-13	17	[{"id_menu":4,"count":1}]	11681	pick-up	0	17
49734	2020-04-13 16:30:53	2020-04-13	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	2116	pick-up	0	24
49735	2020-04-13 16:37:04	2020-04-13	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	6055	delivery	5	31
49736	2020-04-13 16:41:31	2020-04-13	8	[{"id_menu":5,"count":1}]	3559	delivery	5	13
49737	2020-04-13 16:43:39	2020-04-13	9	[{"id_menu":7,"count":2}]	19788	delivery	5	14
49738	2020-04-13 16:47:46	2020-04-13	14	[{"id_menu":2,"count":1}]	19711	pick-up	0	14
49739	2020-04-13 17:01:43	2020-04-13	17	[{"id_menu":4,"count":1}]	5847	delivery	5	22
49740	2020-04-13 17:17:35	2020-04-13	9	[{"id_menu":7,"count":1}]	10112	delivery	5	14
49741	2020-04-13 17:18:19	2020-04-13	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8065	delivery	5	28
49742	2020-04-13 17:22:44	2020-04-13	14	[{"id_menu":2,"count":1}]	19686	delivery	5	19
49743	2020-04-13 17:25:49	2020-04-13	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19779	delivery	5	37
49744	2020-04-13 17:26:46	2020-04-13	9	[{"id_menu":6,"count":1}]	14267	delivery	5	14
49745	2020-04-13 17:27:54	2020-04-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	18976	pick-up	0	23
49746	2020-04-13 17:28:45	2020-04-13	12	[{"id_menu":1,"count":1}]	19791	delivery	5	17
49747	2020-04-13 17:31:08	2020-04-13	12	[{"id_menu":1,"count":1}]	11676	delivery	5	17
49748	2020-04-13 17:43:25	2020-04-13	12	[{"id_menu":1,"count":1}]	9106	pick-up	0	12
49749	2020-04-13 17:51:13	2020-04-13	12	[{"id_menu":3,"count":1}]	1400	delivery	5	17
49750	2020-04-13 17:55:26	2020-04-13	8	[{"id_menu":5,"count":1}]	15159	delivery	5	13
49751	2020-04-13 17:57:16	2020-04-13	9	[{"id_menu":6,"count":1}]	19258	delivery	5	14
49752	2020-04-13 18:04:29	2020-04-13	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19696	delivery	5	36
49753	2020-04-13 18:12:19	2020-04-13	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":2}]	4929	delivery	5	34
49754	2020-04-13 18:13:08	2020-04-13	12	[{"id_menu":1,"count":1}]	6894	delivery	5	17
49755	2020-04-13 18:16:08	2020-04-13	9	[{"id_menu":7,"count":3}]	18282	delivery	5	14
49756	2020-04-13 18:18:55	2020-04-13	8	[{"id_menu":5,"count":1}]	19662	delivery	5	13
49757	2020-04-13 18:24:13	2020-04-13	12	[{"id_menu":3,"count":1}]	19752	delivery	5	17
49758	2020-04-13 18:34:30	2020-04-13	9	[{"id_menu":7,"count":1}]	3077	delivery	5	14
49759	2020-04-13 18:34:42	2020-04-13	8	[{"id_menu":5,"count":1}]	3170	delivery	5	13
49760	2020-04-13 18:37:03	2020-04-13	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5473	delivery	5	30
49761	2020-04-13 18:42:58	2020-04-13	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	841	pick-up	0	25
49762	2020-04-13 18:43:26	2020-04-13	9	[{"id_menu":6,"count":1}]	7832	pick-up	0	9
49763	2020-04-13 18:49:41	2020-04-13	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	922	delivery	5	26
49764	2020-04-13 18:55:39	2020-04-13	9	[{"id_menu":6,"count":1}]	2240	delivery	5	14
49765	2020-04-13 18:58:10	2020-04-13	12	[{"id_menu":3,"count":1}]	19728	delivery	5	17
49766	2020-04-13 19:08:12	2020-04-13	14	[{"id_menu":2,"count":1}]	19807	delivery	5	19
49767	2020-04-13 19:09:16	2020-04-13	9	[{"id_menu":6,"count":1}]	6366	delivery	5	14
49768	2020-04-13 19:09:25	2020-04-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	19677	delivery	5	28
49769	2020-04-13 19:26:00	2020-04-13	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	18981	pick-up	0	34
49770	2020-04-13 19:27:57	2020-04-13	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	19660	delivery	5	39
49771	2020-04-13 19:28:28	2020-04-13	9	[{"id_menu":6,"count":1}]	4820	delivery	5	14
49772	2020-04-13 19:30:10	2020-04-13	17	[{"id_menu":4,"count":1}]	19793	delivery	5	22
49773	2020-04-13 19:31:51	2020-04-13	14	[{"id_menu":2,"count":1}]	1289	pick-up	0	14
49774	2020-04-13 19:39:40	2020-04-13	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7540	delivery	5	43
49775	2020-04-13 19:46:54	2020-04-13	9	[{"id_menu":6,"count":1}]	19685	delivery	5	14
49776	2020-04-13 19:51:33	2020-04-13	9	[{"id_menu":6,"count":1}]	19745	delivery	5	14
49777	2020-04-13 19:53:36	2020-04-13	14	[{"id_menu":2,"count":1}]	19010	delivery	5	19
49778	2020-04-13 20:15:52	2020-04-13	8	[{"id_menu":5,"count":1}]	19751	delivery	5	13
49779	2020-04-13 20:29:44	2020-04-13	12	[{"id_menu":1,"count":1}]	19762	delivery	5	17
49780	2020-04-13 20:29:48	2020-04-13	9	[{"id_menu":6,"count":1}]	19693	delivery	5	14
49781	2020-04-13 20:30:50	2020-04-13	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19813	delivery	5	34
49782	2020-04-13 20:32:45	2020-04-13	17	[{"id_menu":4,"count":1}]	13883	pick-up	0	17
49783	2020-04-13 20:37:29	2020-04-13	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2541	pick-up	0	21
49784	2020-04-13 20:57:08	2020-04-13	12	[{"id_menu":1,"count":1}]	4841	pick-up	0	12
49785	2020-04-13 20:58:20	2020-04-13	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	19683	delivery	5	22
49786	2020-04-13 20:58:43	2020-04-13	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19736	delivery	5	36
49787	2020-04-13 21:03:49	2020-04-13	9	[{"id_menu":6,"count":3}]	8146	delivery	5	14
49788	2020-04-13 21:05:02	2020-04-13	9	[{"id_menu":6,"count":1}]	15603	delivery	5	14
49789	2020-04-13 21:07:52	2020-04-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	10258	delivery	5	28
49790	2020-04-13 21:08:23	2020-04-13	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	14668	delivery	5	26
49791	2020-04-13 21:10:31	2020-04-13	12	[{"id_menu":1,"count":1}]	19708	delivery	5	17
49792	2020-04-13 21:16:52	2020-04-13	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19698	delivery	5	48
49793	2020-04-13 21:30:52	2020-04-13	17	[{"id_menu":4,"count":1}]	19656	delivery	5	22
49794	2020-04-13 21:44:58	2020-04-13	17	[{"id_menu":4,"count":1}]	9926	delivery	5	22
49795	2020-04-13 22:00:49	2020-04-13	12	[{"id_menu":3,"count":1}]	15187	pick-up	0	12
49796	2020-04-13 22:00:53	2020-04-13	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	19814	delivery	5	28
49797	2020-04-13 22:05:19	2020-04-13	8	[{"id_menu":5,"count":1}]	19713	delivery	5	13
49798	2020-04-13 22:07:48	2020-04-13	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19769	delivery	5	52
49799	2020-04-13 22:10:14	2020-04-13	9	[{"id_menu":6,"count":1}]	9525	delivery	5	14
49800	2020-04-13 22:18:02	2020-04-13	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	4960	delivery	5	31
49801	2020-04-13 22:21:33	2020-04-13	12	[{"id_menu":3,"count":1}]	1484	pick-up	0	12
49802	2020-04-13 22:23:39	2020-04-13	9	[{"id_menu":7,"count":1}]	13721	delivery	5	14
49803	2020-04-13 22:27:43	2020-04-13	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	19738	delivery	5	34
49804	2020-04-13 22:34:30	2020-04-13	14	[{"id_menu":2,"count":1}]	229	pick-up	0	14
49805	2020-04-13 22:36:50	2020-04-13	14	[{"id_menu":2,"count":1}]	12717	pick-up	0	14
49806	2020-04-13 22:37:32	2020-04-13	14	[{"id_menu":2,"count":1}]	19773	delivery	5	19
49807	2020-04-13 22:38:03	2020-04-13	14	[{"id_menu":2,"count":1}]	19541	pick-up	0	14
49808	2020-04-13 22:58:15	2020-04-13	9	[{"id_menu":7,"count":1}]	9030	delivery	5	14
49809	2020-04-13 23:01:35	2020-04-13	14	[{"id_menu":2,"count":1}]	11459	pick-up	0	14
49810	2020-04-13 23:12:07	2020-04-13	14	[{"id_menu":2,"count":1}]	11754	pick-up	0	14
49811	2020-04-13 23:18:16	2020-04-13	14	[{"id_menu":2,"count":1}]	19776	pick-up	0	14
49812	2020-04-13 23:20:38	2020-04-13	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	11233	delivery	5	43
49813	2020-04-13 23:20:53	2020-04-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19765	delivery	5	23
49814	2020-04-13 23:22:23	2020-04-13	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8566	pick-up	0	46
49815	2020-04-13 23:26:41	2020-04-13	12	[{"id_menu":3,"count":1}]	19726	delivery	5	17
49816	2020-04-13 23:27:40	2020-04-13	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	5941	delivery	5	27
49817	2020-04-13 23:30:55	2020-04-13	17	[{"id_menu":4,"count":1}]	19815	pick-up	0	17
49818	2020-04-13 23:36:45	2020-04-13	17	[{"id_menu":4,"count":1}]	10839	delivery	5	22
49819	2020-04-13 23:40:59	2020-04-13	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17949	delivery	5	34
49820	2020-04-13 23:50:30	2020-04-13	12	[{"id_menu":1,"count":1}]	19680	delivery	5	17
49821	2020-04-13 23:54:07	2020-04-13	12	[{"id_menu":3,"count":1}]	19701	delivery	5	17
49822	2020-04-14 00:10:28	2020-04-14	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9128	pick-up	0	46
49823	2020-04-14 00:19:34	2020-04-14	9	[{"id_menu":7,"count":1}]	16501	pick-up	0	9
49824	2020-04-14 00:20:05	2020-04-14	17	[{"id_menu":4,"count":3}]	15778	delivery	5	22
49825	2020-04-14 00:28:05	2020-04-14	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	19877	delivery	5	23
49826	2020-04-14 00:42:19	2020-04-14	9	[{"id_menu":6,"count":1}]	19917	delivery	5	14
49827	2020-04-14 00:47:48	2020-04-14	9	[{"id_menu":7,"count":1}]	19549	delivery	5	14
49828	2020-04-14 00:48:47	2020-04-14	9	[{"id_menu":7,"count":1}]	19873	delivery	5	14
49829	2020-04-14 00:52:42	2020-04-14	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6221	pick-up	0	26
49830	2020-04-14 00:59:33	2020-04-14	17	[{"id_menu":4,"count":1}]	19813	delivery	5	22
49831	2020-04-14 01:03:05	2020-04-14	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	15212	delivery	5	28
49832	2020-04-14 01:05:50	2020-04-14	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	19839	delivery	5	28
49833	2020-04-14 01:06:37	2020-04-14	9	[{"id_menu":6,"count":1}]	3784	delivery	5	14
49834	2020-04-14 01:08:08	2020-04-14	12	[{"id_menu":1,"count":1}]	1172	pick-up	0	12
49835	2020-04-14 01:13:39	2020-04-14	9	[{"id_menu":7,"count":1}]	19859	delivery	5	14
49836	2020-04-14 01:15:34	2020-04-14	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	5661	delivery	5	36
49837	2020-04-14 01:20:14	2020-04-14	14	[{"id_menu":2,"count":1}]	4414	pick-up	0	14
49838	2020-04-14 01:20:21	2020-04-14	9	[{"id_menu":7,"count":1}]	16850	delivery	5	14
49839	2020-04-14 01:20:53	2020-04-14	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	19928	delivery	5	31
49840	2020-04-14 01:26:46	2020-04-14	8	[{"id_menu":5,"count":1}]	12855	delivery	5	13
49841	2020-04-14 01:43:32	2020-04-14	12	[{"id_menu":3,"count":1}]	10264	pick-up	0	12
49842	2020-04-14 01:43:35	2020-04-14	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":3}]	19880	delivery	5	26
49843	2020-04-14 01:45:15	2020-04-14	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1077	pick-up	0	26
49844	2020-04-14 01:45:35	2020-04-14	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	19845	pick-up	0	35
49845	2020-04-14 01:54:47	2020-04-14	8	[{"id_menu":5,"count":1}]	16460	delivery	5	13
49846	2020-04-14 02:06:28	2020-04-14	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	19955	delivery	5	28
49847	2020-04-14 02:09:41	2020-04-14	12	[{"id_menu":3,"count":1}]	19270	delivery	5	17
49848	2020-04-14 02:22:55	2020-04-14	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10818	delivery	5	35
49849	2020-04-14 02:29:50	2020-04-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7611	delivery	5	31
49850	2020-04-14 02:36:45	2020-04-14	17	[{"id_menu":4,"count":1}]	2122	pick-up	0	17
49851	2020-04-14 02:43:49	2020-04-14	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	19830	delivery	5	27
49852	2020-04-14 02:46:07	2020-04-14	9	[{"id_menu":6,"count":1}]	12631	pick-up	0	9
49853	2020-04-14 02:48:02	2020-04-14	9	[{"id_menu":6,"count":1}]	8311	delivery	5	14
49854	2020-04-14 02:51:55	2020-04-14	9	[{"id_menu":6,"count":1}]	12390	delivery	5	14
49855	2020-04-14 02:52:46	2020-04-14	14	[{"id_menu":2,"count":1}]	527	pick-up	0	14
49856	2020-04-14 02:54:07	2020-04-14	9	[{"id_menu":6,"count":1}]	10630	delivery	5	14
49857	2020-04-14 02:54:26	2020-04-14	12	[{"id_menu":1,"count":1}]	12872	delivery	5	17
49858	2020-04-14 02:55:25	2020-04-14	55	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	17720	delivery	5	60
49859	2020-04-14 02:57:36	2020-04-14	12	[{"id_menu":1,"count":1}]	15194	delivery	5	17
49860	2020-04-14 03:01:42	2020-04-14	9	[{"id_menu":7,"count":1}]	5304	delivery	5	14
49861	2020-04-14 03:04:07	2020-04-14	9	[{"id_menu":6,"count":1}]	12505	delivery	5	14
49862	2020-04-14 03:05:33	2020-04-14	9	[{"id_menu":6,"count":1}]	12455	delivery	5	14
49863	2020-04-14 03:11:34	2020-04-14	17	[{"id_menu":4,"count":1}]	19857	delivery	5	22
49864	2020-04-14 03:21:24	2020-04-14	12	[{"id_menu":3,"count":1}]	3731	delivery	5	17
49865	2020-04-14 03:30:10	2020-04-14	14	[{"id_menu":2,"count":1}]	12268	delivery	5	19
49866	2020-04-14 03:33:38	2020-04-14	9	[{"id_menu":7,"count":1}]	19893	pick-up	0	9
49867	2020-04-14 03:41:23	2020-04-14	14	[{"id_menu":2,"count":1}]	13950	delivery	5	19
49868	2020-04-14 03:46:01	2020-04-14	12	[{"id_menu":3,"count":2}]	3238	delivery	5	17
49869	2020-04-14 03:46:18	2020-04-14	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11996	delivery	5	57
49870	2020-04-14 03:48:18	2020-04-14	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	19947	delivery	5	42
49871	2020-04-14 04:04:32	2020-04-14	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	981	pick-up	0	22
49872	2020-04-14 04:07:20	2020-04-14	12	[{"id_menu":1,"count":1}]	5503	pick-up	0	12
49873	2020-04-14 04:10:20	2020-04-14	37	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5569	delivery	5	42
49874	2020-04-14 04:12:07	2020-04-14	9	[{"id_menu":7,"count":1}]	19876	delivery	5	14
49875	2020-04-14 04:14:32	2020-04-14	9	[{"id_menu":7,"count":1}]	19886	delivery	5	14
49876	2020-04-14 04:25:10	2020-04-14	17	[{"id_menu":4,"count":1}]	10421	delivery	5	22
49877	2020-04-14 04:29:31	2020-04-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7845	pick-up	0	23
49878	2020-04-14 04:32:45	2020-04-14	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19897	delivery	5	39
49879	2020-04-14 04:34:21	2020-04-14	9	[{"id_menu":6,"count":1}]	2071	pick-up	0	9
49880	2020-04-14 04:35:47	2020-04-14	9	[{"id_menu":7,"count":2}]	14051	delivery	5	14
49881	2020-04-14 04:37:50	2020-04-14	17	[{"id_menu":4,"count":1}]	6208	delivery	5	22
49882	2020-04-14 04:47:14	2020-04-14	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	11870	delivery	5	26
49883	2020-04-14 05:01:53	2020-04-14	14	[{"id_menu":2,"count":1}]	19853	delivery	5	19
49884	2020-04-14 05:03:44	2020-04-14	14	[{"id_menu":2,"count":1}]	14427	pick-up	0	14
49885	2020-04-14 05:05:19	2020-04-14	9	[{"id_menu":6,"count":1}]	7411	delivery	5	14
49886	2020-04-14 05:16:12	2020-04-14	9	[{"id_menu":6,"count":1}]	19847	delivery	5	14
49887	2020-04-14 05:19:35	2020-04-14	14	[{"id_menu":2,"count":2}]	19871	pick-up	0	14
49888	2020-04-14 05:27:03	2020-04-14	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	635	delivery	5	39
49889	2020-04-14 05:27:06	2020-04-14	14	[{"id_menu":2,"count":1}]	18720	delivery	5	19
49890	2020-04-14 05:28:07	2020-04-14	17	[{"id_menu":4,"count":1}]	1081	delivery	5	22
49891	2020-04-14 05:42:54	2020-04-14	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	19957	delivery	5	43
49892	2020-04-14 05:56:33	2020-04-14	9	[{"id_menu":7,"count":1}]	19960	pick-up	0	9
49893	2020-04-14 06:00:52	2020-04-14	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	15188	delivery	5	38
49894	2020-04-14 06:04:40	2020-04-14	9	[{"id_menu":7,"count":1}]	13138	delivery	5	14
49895	2020-04-14 06:06:37	2020-04-14	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	15565	delivery	5	34
49896	2020-04-14 06:06:50	2020-04-14	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	12214	delivery	5	25
49897	2020-04-14 06:12:04	2020-04-14	9	[{"id_menu":7,"count":1}]	19895	delivery	5	14
49898	2020-04-14 06:16:14	2020-04-14	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	19828	delivery	5	25
49899	2020-04-14 06:17:34	2020-04-14	12	[{"id_menu":3,"count":1}]	4395	pick-up	0	12
49900	2020-04-14 06:17:37	2020-04-14	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	3763	delivery	5	26
49901	2020-04-14 06:19:40	2020-04-14	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	19903	delivery	5	43
49902	2020-04-14 06:20:37	2020-04-14	17	[{"id_menu":4,"count":1}]	19946	delivery	5	22
49903	2020-04-14 06:25:30	2020-04-14	14	[{"id_menu":2,"count":1}]	2232	pick-up	0	14
49904	2020-04-14 06:25:37	2020-04-14	9	[{"id_menu":6,"count":1}]	2520	delivery	5	14
49905	2020-04-14 06:32:25	2020-04-14	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	10287	pick-up	0	21
49906	2020-04-14 06:33:04	2020-04-14	14	[{"id_menu":2,"count":1}]	1687	pick-up	0	14
49907	2020-04-14 06:35:04	2020-04-14	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	19233	pick-up	0	40
49908	2020-04-14 06:37:55	2020-04-14	12	[{"id_menu":3,"count":1}]	213	pick-up	0	12
49909	2020-04-14 06:55:09	2020-04-14	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	13308	delivery	5	27
49910	2020-04-14 07:15:51	2020-04-14	9	[{"id_menu":6,"count":1}]	19921	delivery	5	14
49911	2020-04-14 07:16:31	2020-04-14	8	[{"id_menu":5,"count":2}]	5786	delivery	5	13
49912	2020-04-14 07:16:50	2020-04-14	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8560	delivery	5	43
49913	2020-04-14 07:18:51	2020-04-14	9	[{"id_menu":6,"count":1}]	17472	pick-up	0	9
49914	2020-04-14 07:20:01	2020-04-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	13232	pick-up	0	23
49915	2020-04-14 07:21:36	2020-04-14	8	[{"id_menu":5,"count":1}]	19890	delivery	5	13
49916	2020-04-14 07:28:10	2020-04-14	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	14410	pick-up	0	21
49917	2020-04-14 07:31:02	2020-04-14	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	19909	delivery	5	28
49918	2020-04-14 07:42:34	2020-04-14	9	[{"id_menu":7,"count":1}]	19939	delivery	5	14
49919	2020-04-14 07:43:28	2020-04-14	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6178	delivery	5	45
49920	2020-04-14 07:53:49	2020-04-14	9	[{"id_menu":7,"count":1}]	18940	delivery	5	14
49921	2020-04-14 08:03:27	2020-04-14	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	3863	pick-up	0	24
49922	2020-04-14 08:06:14	2020-04-14	17	[{"id_menu":4,"count":3}]	16469	pick-up	0	17
49923	2020-04-14 08:16:56	2020-04-14	17	[{"id_menu":4,"count":1}]	13767	pick-up	0	17
49924	2020-04-14 08:17:11	2020-04-14	43	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1820	pick-up	0	43
49925	2020-04-14 08:17:30	2020-04-14	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	19951	delivery	5	26
49926	2020-04-14 08:40:51	2020-04-14	14	[{"id_menu":2,"count":1}]	7284	pick-up	0	14
49927	2020-04-14 08:43:09	2020-04-14	14	[{"id_menu":2,"count":2}]	11074	delivery	5	19
49928	2020-04-14 08:49:56	2020-04-14	8	[{"id_menu":5,"count":1}]	10886	delivery	5	13
49929	2020-04-14 08:54:42	2020-04-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":3}]	9214	delivery	5	22
49930	2020-04-14 09:03:42	2020-04-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	16404	delivery	5	28
49931	2020-04-14 09:08:29	2020-04-14	14	[{"id_menu":2,"count":1}]	19923	delivery	5	19
49932	2020-04-14 09:10:40	2020-04-14	8	[{"id_menu":5,"count":1}]	2124	pick-up	0	8
49933	2020-04-14 09:14:11	2020-04-14	12	[{"id_menu":3,"count":1}]	2197	pick-up	0	12
49934	2020-04-14 09:17:44	2020-04-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	19948	pick-up	0	23
49935	2020-04-14 09:19:16	2020-04-14	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	19848	delivery	5	34
49936	2020-04-14 09:21:59	2020-04-14	17	[{"id_menu":4,"count":1}]	5664	delivery	5	22
49937	2020-04-14 09:27:23	2020-04-14	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	19919	delivery	5	28
49938	2020-04-14 09:38:00	2020-04-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7835	pick-up	0	31
49939	2020-04-14 09:51:11	2020-04-14	9	[{"id_menu":6,"count":1}]	5453	delivery	5	14
49940	2020-04-14 09:54:41	2020-04-14	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4546	pick-up	0	21
49941	2020-04-14 09:55:10	2020-04-14	8	[{"id_menu":5,"count":2}]	16432	delivery	5	13
49942	2020-04-14 09:58:49	2020-04-14	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	13713	delivery	5	44
49943	2020-04-14 10:16:38	2020-04-14	14	[{"id_menu":2,"count":1}]	13028	pick-up	0	14
49944	2020-04-14 10:19:45	2020-04-14	9	[{"id_menu":6,"count":1}]	19885	delivery	5	14
49945	2020-04-14 10:21:37	2020-04-14	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	19834	delivery	5	36
49946	2020-04-14 10:21:51	2020-04-14	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6502	pick-up	0	25
49947	2020-04-14 10:28:59	2020-04-14	12	[{"id_menu":3,"count":1}]	19827	pick-up	0	12
49948	2020-04-14 10:29:04	2020-04-14	12	[{"id_menu":3,"count":2}]	5561	delivery	5	17
49949	2020-04-14 10:29:30	2020-04-14	9	[{"id_menu":7,"count":1}]	16734	delivery	5	14
49950	2020-04-14 10:38:56	2020-04-14	9	[{"id_menu":6,"count":1}]	2054	pick-up	0	9
49951	2020-04-14 10:41:32	2020-04-14	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	6746	delivery	5	31
49952	2020-04-14 10:45:48	2020-04-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8877	delivery	5	22
49953	2020-04-14 10:52:46	2020-04-14	26	[{"id_menu":2,"count":3},{"id_menu":3,"count":1}]	6163	pick-up	0	26
49954	2020-04-14 11:06:05	2020-04-14	14	[{"id_menu":2,"count":1}]	19868	pick-up	0	14
49955	2020-04-14 11:10:18	2020-04-14	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6295	delivery	5	23
49956	2020-04-14 11:10:36	2020-04-14	17	[{"id_menu":4,"count":1}]	10785	delivery	5	22
49957	2020-04-14 11:15:47	2020-04-14	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	12602	pick-up	0	29
49958	2020-04-14 11:17:31	2020-04-14	8	[{"id_menu":5,"count":1}]	19896	delivery	5	13
49959	2020-04-14 11:29:09	2020-04-14	9	[{"id_menu":6,"count":1}]	9621	delivery	5	14
49960	2020-04-14 11:39:14	2020-04-14	9	[{"id_menu":7,"count":1}]	4116	delivery	5	14
49961	2020-04-14 11:45:36	2020-04-14	12	[{"id_menu":1,"count":1}]	4462	delivery	5	17
49962	2020-04-14 11:45:47	2020-04-14	12	[{"id_menu":1,"count":1}]	13643	pick-up	0	12
49963	2020-04-14 11:46:42	2020-04-14	14	[{"id_menu":2,"count":1}]	2608	delivery	5	19
49964	2020-04-14 11:51:29	2020-04-14	9	[{"id_menu":6,"count":1}]	19913	delivery	5	14
49965	2020-04-14 12:07:24	2020-04-14	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19849	delivery	5	43
49966	2020-04-14 12:12:02	2020-04-14	9	[{"id_menu":7,"count":1}]	1386	delivery	5	14
49967	2020-04-14 12:13:34	2020-04-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12954	delivery	5	22
49968	2020-04-14 12:19:35	2020-04-14	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18143	delivery	5	35
49969	2020-04-14 12:23:13	2020-04-14	14	[{"id_menu":2,"count":2}]	10739	delivery	5	19
49970	2020-04-14 12:29:51	2020-04-14	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	9116	pick-up	0	43
49971	2020-04-14 12:33:01	2020-04-14	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	18962	delivery	5	34
49972	2020-04-14 12:35:42	2020-04-14	9	[{"id_menu":7,"count":1}]	4200	delivery	5	14
49973	2020-04-14 12:42:46	2020-04-14	9	[{"id_menu":6,"count":1}]	5141	delivery	5	14
49974	2020-04-14 12:43:43	2020-04-14	17	[{"id_menu":4,"count":1}]	2498	pick-up	0	17
49975	2020-04-14 12:45:52	2020-04-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19552	delivery	5	22
49976	2020-04-14 12:47:00	2020-04-14	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	19762	delivery	5	26
49977	2020-04-14 12:47:01	2020-04-14	12	[{"id_menu":3,"count":1}]	16359	delivery	5	17
49978	2020-04-14 12:57:24	2020-04-14	12	[{"id_menu":1,"count":1}]	2753	pick-up	0	12
49979	2020-04-14 13:01:16	2020-04-14	12	[{"id_menu":1,"count":1}]	3155	pick-up	0	12
49980	2020-04-14 13:07:22	2020-04-14	12	[{"id_menu":1,"count":1}]	19933	delivery	5	17
49981	2020-04-14 13:09:23	2020-04-14	8	[{"id_menu":5,"count":1}]	19932	delivery	5	13
49982	2020-04-14 13:15:33	2020-04-14	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	19864	delivery	5	48
49983	2020-04-14 13:26:21	2020-04-14	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":3}]	837	delivery	5	27
49984	2020-04-14 13:26:38	2020-04-14	9	[{"id_menu":7,"count":1}]	19212	pick-up	0	9
49985	2020-04-14 13:32:55	2020-04-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	13026	pick-up	0	23
49986	2020-04-14 13:35:11	2020-04-14	9	[{"id_menu":6,"count":1}]	16455	delivery	5	14
49987	2020-04-14 13:38:45	2020-04-14	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	5970	pick-up	0	22
49988	2020-04-14 13:45:37	2020-04-14	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	19833	pick-up	0	26
49989	2020-04-14 13:49:43	2020-04-14	14	[{"id_menu":2,"count":1}]	5967	delivery	5	19
49990	2020-04-14 13:53:56	2020-04-14	9	[{"id_menu":7,"count":1}]	15474	delivery	5	14
49991	2020-04-14 13:55:28	2020-04-14	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	10217	delivery	5	25
49992	2020-04-14 13:58:11	2020-04-14	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	19865	delivery	5	37
49993	2020-04-14 14:01:44	2020-04-14	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	18293	delivery	5	31
49994	2020-04-14 14:01:56	2020-04-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":3}]	19870	delivery	5	31
49995	2020-04-14 14:11:44	2020-04-14	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	19898	delivery	5	40
49996	2020-04-14 14:18:22	2020-04-14	9	[{"id_menu":7,"count":1}]	19912	delivery	5	14
49997	2020-04-14 14:19:29	2020-04-14	12	[{"id_menu":1,"count":1}]	9337	delivery	5	17
49998	2020-04-14 14:21:28	2020-04-14	12	[{"id_menu":1,"count":1}]	4820	delivery	5	17
49999	2020-04-14 14:24:10	2020-04-14	9	[{"id_menu":6,"count":1}]	5272	delivery	5	14
50000	2020-04-14 14:25:13	2020-04-14	8	[{"id_menu":5,"count":2}]	14529	delivery	5	13
50001	2020-04-14 14:25:34	2020-04-14	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	16483	delivery	5	26
50002	2020-04-14 14:26:58	2020-04-14	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18078	delivery	5	35
50003	2020-04-14 14:28:04	2020-04-14	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	66	delivery	5	25
50004	2020-04-14 14:35:39	2020-04-14	12	[{"id_menu":3,"count":1}]	9976	delivery	5	17
50005	2020-04-14 14:42:08	2020-04-14	9	[{"id_menu":7,"count":1}]	19889	delivery	5	14
50006	2020-04-14 14:52:11	2020-04-14	9	[{"id_menu":7,"count":1}]	18371	delivery	5	14
50007	2020-04-14 14:56:31	2020-04-14	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19887	delivery	5	31
50008	2020-04-14 14:56:40	2020-04-14	14	[{"id_menu":2,"count":1}]	19884	delivery	5	19
50009	2020-04-14 15:01:30	2020-04-14	8	[{"id_menu":5,"count":1}]	12757	delivery	5	13
50010	2020-04-14 15:03:32	2020-04-14	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	16584	delivery	5	30
50011	2020-04-14 15:15:33	2020-04-14	17	[{"id_menu":4,"count":1}]	19867	pick-up	0	17
50012	2020-04-14 15:24:26	2020-04-14	9	[{"id_menu":7,"count":1}]	17697	delivery	5	14
50013	2020-04-14 15:39:56	2020-04-14	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19027	delivery	5	48
50014	2020-04-14 15:46:41	2020-04-14	9	[{"id_menu":6,"count":1}]	15236	delivery	5	14
50015	2020-04-14 15:47:12	2020-04-14	9	[{"id_menu":6,"count":1}]	894	pick-up	0	9
50016	2020-04-14 15:55:17	2020-04-14	9	[{"id_menu":6,"count":1}]	2111	delivery	5	14
50017	2020-04-14 16:01:33	2020-04-14	17	[{"id_menu":4,"count":1}]	7318	delivery	5	22
50018	2020-04-14 16:05:29	2020-04-14	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	13320	pick-up	0	21
50019	2020-04-14 16:17:43	2020-04-14	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	12904	delivery	5	25
50020	2020-04-14 16:18:00	2020-04-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	18787	delivery	5	31
50021	2020-04-14 16:19:03	2020-04-14	9	[{"id_menu":7,"count":1}]	19892	delivery	5	14
50022	2020-04-14 16:24:21	2020-04-14	12	[{"id_menu":1,"count":1}]	10783	delivery	5	17
50023	2020-04-14 16:24:38	2020-04-14	14	[{"id_menu":2,"count":1}]	7109	delivery	5	19
50024	2020-04-14 16:25:56	2020-04-14	12	[{"id_menu":1,"count":1}]	19952	delivery	5	17
50025	2020-04-14 16:34:11	2020-04-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2359	pick-up	0	31
50026	2020-04-14 16:55:36	2020-04-14	12	[{"id_menu":1,"count":2}]	4453	pick-up	0	12
50027	2020-04-14 16:56:13	2020-04-14	9	[{"id_menu":7,"count":3}]	19846	pick-up	0	9
50028	2020-04-14 17:20:37	2020-04-14	9	[{"id_menu":7,"count":1}]	8410	delivery	5	14
50029	2020-04-14 17:40:37	2020-04-14	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	19908	delivery	5	45
50030	2020-04-14 18:02:13	2020-04-14	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	19840	delivery	5	48
50031	2020-04-14 18:08:09	2020-04-14	8	[{"id_menu":5,"count":1}]	14588	delivery	5	13
50032	2020-04-14 18:11:59	2020-04-14	14	[{"id_menu":2,"count":1}]	360	pick-up	0	14
50033	2020-04-14 18:13:06	2020-04-14	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19891	delivery	5	37
50034	2020-04-14 18:20:48	2020-04-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	18936	delivery	5	31
50035	2020-04-14 18:24:34	2020-04-14	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	19911	pick-up	0	26
50036	2020-04-14 18:30:22	2020-04-14	8	[{"id_menu":5,"count":1}]	19856	delivery	5	13
50037	2020-04-14 18:37:15	2020-04-14	8	[{"id_menu":5,"count":1}]	4347	delivery	5	13
50038	2020-04-14 18:51:32	2020-04-14	14	[{"id_menu":2,"count":2}]	3126	pick-up	0	14
50039	2020-04-14 18:52:45	2020-04-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	18436	delivery	5	31
50040	2020-04-14 19:04:38	2020-04-14	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	19916	delivery	5	23
50041	2020-04-14 19:04:47	2020-04-14	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	19920	delivery	5	23
50042	2020-04-14 19:07:06	2020-04-14	9	[{"id_menu":6,"count":1}]	19910	delivery	5	14
50043	2020-04-14 19:09:43	2020-04-14	9	[{"id_menu":7,"count":1}]	3670	pick-up	0	9
50044	2020-04-14 19:13:26	2020-04-14	14	[{"id_menu":2,"count":2}]	1321	pick-up	0	14
50045	2020-04-14 19:31:24	2020-04-14	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	11991	delivery	5	29
50046	2020-04-14 19:42:16	2020-04-14	14	[{"id_menu":2,"count":1}]	15110	pick-up	0	14
50047	2020-04-14 19:46:45	2020-04-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	19842	delivery	5	31
50048	2020-04-14 19:47:05	2020-04-14	12	[{"id_menu":3,"count":1}]	7746	pick-up	0	12
50049	2020-04-14 19:51:51	2020-04-14	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	15791	delivery	5	34
50050	2020-04-14 20:00:40	2020-04-14	8	[{"id_menu":5,"count":1}]	4576	delivery	5	13
50051	2020-04-14 20:10:06	2020-04-14	12	[{"id_menu":1,"count":1}]	19906	delivery	5	17
50052	2020-04-14 20:12:19	2020-04-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16047	delivery	5	31
50053	2020-04-14 20:15:43	2020-04-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	19930	pick-up	0	26
50054	2020-04-14 20:17:17	2020-04-14	8	[{"id_menu":5,"count":1}]	16914	pick-up	0	8
50055	2020-04-14 20:21:54	2020-04-14	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	19936	delivery	5	30
50056	2020-04-14 20:29:53	2020-04-14	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10147	pick-up	0	35
50057	2020-04-14 20:31:24	2020-04-14	17	[{"id_menu":4,"count":1}]	19950	delivery	5	22
50058	2020-04-14 20:37:04	2020-04-14	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7005	delivery	5	40
50059	2020-04-14 20:41:34	2020-04-14	8	[{"id_menu":5,"count":2}]	19959	delivery	5	13
50060	2020-04-14 20:41:38	2020-04-14	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	19956	delivery	5	43
50061	2020-04-14 20:59:58	2020-04-14	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16226	pick-up	0	18
50062	2020-04-14 21:03:32	2020-04-14	38	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10316	delivery	5	43
50063	2020-04-14 21:06:36	2020-04-14	12	[{"id_menu":3,"count":1}]	19837	pick-up	0	12
50064	2020-04-14 21:09:17	2020-04-14	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	19901	delivery	5	40
50065	2020-04-14 21:21:04	2020-04-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6093	delivery	5	36
50066	2020-04-14 21:23:49	2020-04-14	17	[{"id_menu":4,"count":1}]	16755	delivery	5	22
50067	2020-04-14 21:37:04	2020-04-14	8	[{"id_menu":5,"count":1}]	19942	delivery	5	13
50068	2020-04-14 21:45:53	2020-04-14	12	[{"id_menu":3,"count":1}]	13874	pick-up	0	12
50069	2020-04-14 21:47:26	2020-04-14	14	[{"id_menu":2,"count":2}]	19899	pick-up	0	14
50070	2020-04-14 21:54:57	2020-04-14	17	[{"id_menu":4,"count":1}]	19841	pick-up	0	17
50071	2020-04-14 21:57:19	2020-04-14	9	[{"id_menu":7,"count":1}]	4368	delivery	5	14
50072	2020-04-14 21:58:20	2020-04-14	9	[{"id_menu":6,"count":2}]	18425	delivery	5	14
50073	2020-04-14 22:02:19	2020-04-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2911	pick-up	0	17
50074	2020-04-14 22:03:21	2020-04-14	8	[{"id_menu":5,"count":1}]	9525	delivery	5	13
50075	2020-04-14 22:07:51	2020-04-14	12	[{"id_menu":3,"count":1}]	6398	delivery	5	17
50076	2020-04-14 22:11:22	2020-04-14	12	[{"id_menu":1,"count":1}]	19940	delivery	5	17
50077	2020-04-14 22:13:01	2020-04-14	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	18411	delivery	5	36
50078	2020-04-14 22:19:35	2020-04-14	12	[{"id_menu":1,"count":1}]	4824	delivery	5	17
50079	2020-04-14 22:23:18	2020-04-14	9	[{"id_menu":6,"count":1}]	10740	delivery	5	14
50080	2020-04-14 22:23:36	2020-04-14	12	[{"id_menu":1,"count":1}]	19836	delivery	5	17
50081	2020-04-14 22:33:40	2020-04-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15612	delivery	5	22
50082	2020-04-14 22:36:17	2020-04-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17185	delivery	5	31
50083	2020-04-14 22:38:58	2020-04-14	9	[{"id_menu":7,"count":1}]	374	delivery	5	14
50084	2020-04-14 22:50:33	2020-04-14	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19161	delivery	5	36
50085	2020-04-14 22:54:32	2020-04-14	9	[{"id_menu":6,"count":1}]	19065	delivery	5	14
50086	2020-04-14 23:06:56	2020-04-14	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	19941	delivery	5	36
50087	2020-04-14 23:12:28	2020-04-14	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2056	delivery	5	39
50088	2020-04-14 23:14:31	2020-04-14	9	[{"id_menu":7,"count":1}]	3830	delivery	5	14
50089	2020-04-14 23:24:37	2020-04-14	8	[{"id_menu":5,"count":1}]	19943	delivery	5	13
50090	2020-04-14 23:25:44	2020-04-14	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19852	delivery	5	51
50091	2020-04-14 23:27:12	2020-04-14	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	18141	delivery	5	31
50092	2020-04-14 23:27:31	2020-04-14	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2915	delivery	5	43
50093	2020-04-14 23:34:42	2020-04-14	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	17941	delivery	5	22
50094	2020-04-14 23:46:21	2020-04-14	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19927	delivery	5	39
50095	2020-04-14 23:48:30	2020-04-14	9	[{"id_menu":7,"count":1}]	19832	delivery	5	14
50096	2020-04-14 23:52:05	2020-04-14	14	[{"id_menu":2,"count":1}]	9737	delivery	5	19
50097	2020-04-14 23:54:03	2020-04-14	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	9407	delivery	5	39
50098	2020-04-14 23:56:59	2020-04-14	9	[{"id_menu":7,"count":1}]	3843	delivery	5	14
50099	2020-04-14 23:58:56	2020-04-14	14	[{"id_menu":2,"count":1}]	3493	delivery	5	19
50100	2020-04-15 00:00:20	2020-04-15	17	[{"id_menu":4,"count":1}]	15877	delivery	5	22
50101	2020-04-15 00:01:58	2020-04-15	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	16704	pick-up	0	31
50102	2020-04-15 00:08:36	2020-04-15	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	19995	delivery	5	26
50103	2020-04-15 00:09:11	2020-04-15	17	[{"id_menu":4,"count":1}]	5958	delivery	5	22
50104	2020-04-15 00:12:38	2020-04-15	9	[{"id_menu":7,"count":1}]	14534	delivery	5	14
50105	2020-04-15 00:13:25	2020-04-15	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	19124	delivery	5	25
50106	2020-04-15 00:16:46	2020-04-15	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	14090	delivery	5	43
50107	2020-04-15 00:22:09	2020-04-15	17	[{"id_menu":4,"count":1}]	20018	delivery	5	22
50108	2020-04-15 00:22:25	2020-04-15	14	[{"id_menu":2,"count":1}]	20078	pick-up	0	14
50109	2020-04-15 00:24:19	2020-04-15	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	20002	delivery	5	39
50110	2020-04-15 00:25:29	2020-04-15	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	19984	delivery	5	26
50111	2020-04-15 00:26:09	2020-04-15	17	[{"id_menu":4,"count":1}]	16328	pick-up	0	17
50112	2020-04-15 00:28:40	2020-04-15	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20101	delivery	5	22
50113	2020-04-15 00:33:34	2020-04-15	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	20077	delivery	5	31
50114	2020-04-15 00:35:14	2020-04-15	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	20025	delivery	5	22
50115	2020-04-15 00:42:14	2020-04-15	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10386	delivery	5	43
50116	2020-04-15 00:45:28	2020-04-15	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19347	delivery	5	45
50117	2020-04-15 00:47:29	2020-04-15	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	12018	delivery	5	25
50118	2020-04-15 00:48:44	2020-04-15	9	[{"id_menu":7,"count":1}]	9810	delivery	5	14
50119	2020-04-15 00:49:09	2020-04-15	8	[{"id_menu":5,"count":1}]	20116	pick-up	0	8
50120	2020-04-15 00:51:18	2020-04-15	9	[{"id_menu":7,"count":1}]	3910	delivery	5	14
50121	2020-04-15 00:54:13	2020-04-15	14	[{"id_menu":2,"count":1}]	841	pick-up	0	14
50122	2020-04-15 00:59:36	2020-04-15	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20079	delivery	5	45
50123	2020-04-15 01:00:59	2020-04-15	17	[{"id_menu":4,"count":1}]	20039	pick-up	0	17
50124	2020-04-15 01:10:46	2020-04-15	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20068	delivery	5	37
50125	2020-04-15 01:13:35	2020-04-15	12	[{"id_menu":3,"count":1}]	12332	pick-up	0	12
50126	2020-04-15 01:14:54	2020-04-15	29	[{"id_menu":3,"count":3},{"id_menu":4,"count":1}]	18271	delivery	5	34
50127	2020-04-15 01:17:57	2020-04-15	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20014	delivery	5	48
50128	2020-04-15 01:21:40	2020-04-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12021	delivery	5	23
50129	2020-04-15 01:22:40	2020-04-15	9	[{"id_menu":7,"count":1}]	903	pick-up	0	9
50130	2020-04-15 01:23:02	2020-04-15	8	[{"id_menu":5,"count":1}]	18624	pick-up	0	8
50131	2020-04-15 01:28:44	2020-04-15	17	[{"id_menu":4,"count":1}]	20115	delivery	5	22
50132	2020-04-15 01:38:01	2020-04-15	12	[{"id_menu":1,"count":1}]	2661	delivery	5	17
50133	2020-04-15 01:43:34	2020-04-15	12	[{"id_menu":1,"count":1}]	1813	pick-up	0	12
50134	2020-04-15 01:50:37	2020-04-15	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	20109	delivery	5	26
50135	2020-04-15 01:53:44	2020-04-15	12	[{"id_menu":3,"count":2}]	20034	delivery	5	17
50136	2020-04-15 01:54:15	2020-04-15	9	[{"id_menu":7,"count":1}]	18159	delivery	5	14
50137	2020-04-15 01:56:55	2020-04-15	14	[{"id_menu":2,"count":1}]	3385	pick-up	0	14
50138	2020-04-15 02:00:24	2020-04-15	9	[{"id_menu":6,"count":1}]	20119	delivery	5	14
50139	2020-04-15 02:05:15	2020-04-15	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	20044	delivery	5	43
50140	2020-04-15 02:05:56	2020-04-15	12	[{"id_menu":3,"count":1}]	20060	delivery	5	17
50141	2020-04-15 02:06:31	2020-04-15	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17330	delivery	5	39
50142	2020-04-15 02:13:32	2020-04-15	9	[{"id_menu":7,"count":1}]	11005	pick-up	0	9
50143	2020-04-15 02:27:00	2020-04-15	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	17046	pick-up	0	20
50144	2020-04-15 02:28:24	2020-04-15	17	[{"id_menu":4,"count":1}]	13618	delivery	5	22
50145	2020-04-15 02:33:59	2020-04-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	19989	delivery	5	28
50146	2020-04-15 02:36:34	2020-04-15	8	[{"id_menu":5,"count":1}]	20086	delivery	5	13
50147	2020-04-15 02:46:13	2020-04-15	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20091	delivery	5	22
50148	2020-04-15 02:47:45	2020-04-15	12	[{"id_menu":3,"count":1}]	20069	delivery	5	17
50149	2020-04-15 02:53:14	2020-04-15	12	[{"id_menu":3,"count":1}]	8699	delivery	5	17
50150	2020-04-15 03:18:07	2020-04-15	14	[{"id_menu":2,"count":1}]	2829	delivery	5	19
50151	2020-04-15 03:19:52	2020-04-15	12	[{"id_menu":3,"count":2}]	16179	delivery	5	17
50152	2020-04-15 03:21:43	2020-04-15	9	[{"id_menu":7,"count":1}]	16569	delivery	5	14
50153	2020-04-15 03:23:35	2020-04-15	12	[{"id_menu":3,"count":1}]	14696	delivery	5	17
50154	2020-04-15 03:25:02	2020-04-15	17	[{"id_menu":4,"count":1}]	20120	delivery	5	22
50155	2020-04-15 03:35:02	2020-04-15	14	[{"id_menu":2,"count":1}]	3463	delivery	5	19
50156	2020-04-15 03:38:52	2020-04-15	8	[{"id_menu":5,"count":1}]	19969	delivery	5	13
50157	2020-04-15 03:45:15	2020-04-15	9	[{"id_menu":6,"count":1}]	20033	delivery	5	14
50158	2020-04-15 03:46:55	2020-04-15	9	[{"id_menu":7,"count":1}]	20074	pick-up	0	9
50159	2020-04-15 03:53:55	2020-04-15	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12821	delivery	5	40
50160	2020-04-15 04:02:18	2020-04-15	12	[{"id_menu":3,"count":1}]	5721	delivery	5	17
50161	2020-04-15 04:03:46	2020-04-15	8	[{"id_menu":5,"count":1}]	1236	pick-up	0	8
50162	2020-04-15 04:19:14	2020-04-15	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	20000	delivery	5	35
50163	2020-04-15 04:26:20	2020-04-15	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19979	delivery	5	54
50164	2020-04-15 04:54:40	2020-04-15	9	[{"id_menu":7,"count":1}]	20094	delivery	5	14
50165	2020-04-15 04:55:04	2020-04-15	17	[{"id_menu":4,"count":1}]	13882	delivery	5	22
50166	2020-04-15 05:02:04	2020-04-15	12	[{"id_menu":1,"count":1}]	7078	delivery	5	17
50167	2020-04-15 05:02:26	2020-04-15	9	[{"id_menu":6,"count":1}]	4157	delivery	5	14
50168	2020-04-15 05:07:33	2020-04-15	9	[{"id_menu":6,"count":1}]	20021	pick-up	0	9
50169	2020-04-15 05:11:12	2020-04-15	12	[{"id_menu":3,"count":1}]	20089	delivery	5	17
50170	2020-04-15 05:12:01	2020-04-15	12	[{"id_menu":1,"count":1}]	18170	pick-up	0	12
50171	2020-04-15 05:13:15	2020-04-15	9	[{"id_menu":7,"count":2}]	20011	delivery	5	14
50172	2020-04-15 05:18:07	2020-04-15	17	[{"id_menu":4,"count":3}]	1588	delivery	5	22
50173	2020-04-15 05:19:56	2020-04-15	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	20095	delivery	5	57
50174	2020-04-15 05:19:57	2020-04-15	12	[{"id_menu":3,"count":1}]	3077	delivery	5	17
50175	2020-04-15 05:25:22	2020-04-15	14	[{"id_menu":2,"count":1}]	3168	pick-up	0	14
50176	2020-04-15 05:27:47	2020-04-15	12	[{"id_menu":3,"count":1}]	20082	delivery	5	17
50177	2020-04-15 05:28:35	2020-04-15	9	[{"id_menu":6,"count":1}]	18729	pick-up	0	9
50178	2020-04-15 05:33:05	2020-04-15	14	[{"id_menu":2,"count":1}]	14174	delivery	5	19
50179	2020-04-15 05:34:02	2020-04-15	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3393	delivery	5	35
50180	2020-04-15 05:35:49	2020-04-15	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	8036	delivery	5	48
50181	2020-04-15 05:41:27	2020-04-15	9	[{"id_menu":7,"count":1}]	20076	delivery	5	14
50182	2020-04-15 05:42:33	2020-04-15	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	9580	delivery	5	25
50183	2020-04-15 05:45:10	2020-04-15	9	[{"id_menu":7,"count":1}]	19983	delivery	5	14
50184	2020-04-15 05:56:53	2020-04-15	9	[{"id_menu":6,"count":1}]	19964	delivery	5	14
50185	2020-04-15 06:01:51	2020-04-15	12	[{"id_menu":3,"count":1}]	8172	delivery	5	17
50186	2020-04-15 06:05:52	2020-04-15	9	[{"id_menu":7,"count":1}]	20123	delivery	5	14
50187	2020-04-15 06:06:08	2020-04-15	17	[{"id_menu":4,"count":1}]	19968	delivery	5	22
50188	2020-04-15 06:07:10	2020-04-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14459	delivery	5	23
50189	2020-04-15 06:08:30	2020-04-15	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19996	delivery	5	40
50190	2020-04-15 06:09:11	2020-04-15	17	[{"id_menu":4,"count":1}]	19997	delivery	5	22
50191	2020-04-15 06:13:41	2020-04-15	12	[{"id_menu":1,"count":1}]	20081	delivery	5	17
50192	2020-04-15 06:16:49	2020-04-15	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6107	delivery	5	43
50193	2020-04-15 06:17:02	2020-04-15	12	[{"id_menu":1,"count":1}]	20107	pick-up	0	12
50194	2020-04-15 06:18:58	2020-04-15	8	[{"id_menu":5,"count":1}]	10012	delivery	5	13
50195	2020-04-15 06:25:46	2020-04-15	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2599	pick-up	0	34
50196	2020-04-15 06:28:45	2020-04-15	9	[{"id_menu":7,"count":1}]	417	pick-up	0	9
50197	2020-04-15 06:29:51	2020-04-15	8	[{"id_menu":5,"count":1}]	20046	delivery	5	13
50198	2020-04-15 06:48:01	2020-04-15	12	[{"id_menu":1,"count":1}]	20066	delivery	5	17
50199	2020-04-15 06:54:51	2020-04-15	14	[{"id_menu":2,"count":1}]	20029	delivery	5	19
50200	2020-04-15 06:54:52	2020-04-15	12	[{"id_menu":1,"count":1}]	4764	delivery	5	17
50201	2020-04-15 06:58:48	2020-04-15	12	[{"id_menu":3,"count":1}]	15079	delivery	5	17
50202	2020-04-15 07:00:23	2020-04-15	12	[{"id_menu":1,"count":1}]	4206	pick-up	0	12
50203	2020-04-15 07:03:44	2020-04-15	17	[{"id_menu":4,"count":1}]	1649	delivery	5	22
50204	2020-04-15 07:06:06	2020-04-15	8	[{"id_menu":5,"count":1}]	964	delivery	5	13
50205	2020-04-15 07:07:58	2020-04-15	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	13789	delivery	5	26
50206	2020-04-15 07:11:22	2020-04-15	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16240	delivery	5	22
50207	2020-04-15 07:12:00	2020-04-15	9	[{"id_menu":7,"count":1}]	13444	delivery	5	14
50208	2020-04-15 07:13:28	2020-04-15	12	[{"id_menu":3,"count":1}]	20088	delivery	5	17
50209	2020-04-15 07:22:41	2020-04-15	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11624	delivery	5	39
50210	2020-04-15 07:24:55	2020-04-15	14	[{"id_menu":2,"count":1}]	10886	delivery	5	19
50211	2020-04-15 07:27:07	2020-04-15	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	1537	pick-up	0	26
50212	2020-04-15 07:40:12	2020-04-15	8	[{"id_menu":5,"count":1}]	14833	delivery	5	13
50213	2020-04-15 07:46:31	2020-04-15	17	[{"id_menu":4,"count":1}]	6975	pick-up	0	17
50214	2020-04-15 07:56:52	2020-04-15	9	[{"id_menu":6,"count":1}]	13330	delivery	5	14
50215	2020-04-15 07:58:12	2020-04-15	17	[{"id_menu":4,"count":1}]	3684	delivery	5	22
50216	2020-04-15 07:59:54	2020-04-15	12	[{"id_menu":1,"count":1}]	2618	pick-up	0	12
50217	2020-04-15 08:00:41	2020-04-15	9	[{"id_menu":6,"count":1}]	11724	delivery	5	14
50218	2020-04-15 08:03:30	2020-04-15	14	[{"id_menu":2,"count":1}]	20032	delivery	5	19
50219	2020-04-15 08:04:03	2020-04-15	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	19971	delivery	5	40
50220	2020-04-15 08:05:57	2020-04-15	12	[{"id_menu":1,"count":1}]	13968	delivery	5	17
50221	2020-04-15 08:07:53	2020-04-15	17	[{"id_menu":4,"count":1}]	18130	delivery	5	22
50222	2020-04-15 08:08:26	2020-04-15	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14634	delivery	5	34
50223	2020-04-15 08:09:49	2020-04-15	17	[{"id_menu":4,"count":1}]	6406	delivery	5	22
50224	2020-04-15 08:24:32	2020-04-15	8	[{"id_menu":5,"count":1}]	4977	pick-up	0	8
50225	2020-04-15 08:42:45	2020-04-15	12	[{"id_menu":3,"count":1}]	4644	pick-up	0	12
50226	2020-04-15 08:45:59	2020-04-15	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	20024	pick-up	0	20
50227	2020-04-15 08:55:55	2020-04-15	12	[{"id_menu":3,"count":1}]	5102	pick-up	0	12
50228	2020-04-15 08:59:45	2020-04-15	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	7093	delivery	5	35
50229	2020-04-15 09:01:28	2020-04-15	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	11295	delivery	5	42
50230	2020-04-15 09:01:40	2020-04-15	17	[{"id_menu":4,"count":1}]	1507	delivery	5	22
50231	2020-04-15 09:04:26	2020-04-15	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	9185	delivery	5	28
50232	2020-04-15 09:05:52	2020-04-15	9	[{"id_menu":6,"count":1}]	15414	delivery	5	14
50233	2020-04-15 09:06:57	2020-04-15	17	[{"id_menu":4,"count":1}]	20103	delivery	5	22
50234	2020-04-15 09:09:47	2020-04-15	14	[{"id_menu":2,"count":1}]	8831	delivery	5	19
50235	2020-04-15 09:19:55	2020-04-15	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	18108	delivery	5	45
50236	2020-04-15 09:29:35	2020-04-15	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11942	delivery	5	22
50237	2020-04-15 09:34:48	2020-04-15	9	[{"id_menu":7,"count":2}]	11105	delivery	5	14
50238	2020-04-15 09:35:53	2020-04-15	12	[{"id_menu":3,"count":1}]	9859	pick-up	0	12
50239	2020-04-15 09:39:10	2020-04-15	9	[{"id_menu":6,"count":1}]	18959	delivery	5	14
50240	2020-04-15 09:46:35	2020-04-15	9	[{"id_menu":6,"count":1}]	7772	pick-up	0	9
50241	2020-04-15 09:47:45	2020-04-15	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15692	delivery	5	22
50242	2020-04-15 09:51:35	2020-04-15	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	3659	pick-up	0	20
50243	2020-04-15 09:52:29	2020-04-15	14	[{"id_menu":2,"count":1}]	3146	pick-up	0	14
50244	2020-04-15 09:57:15	2020-04-15	9	[{"id_menu":6,"count":1}]	16698	delivery	5	14
50245	2020-04-15 10:00:33	2020-04-15	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15159	delivery	5	51
50246	2020-04-15 10:02:04	2020-04-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	20106	delivery	5	23
50247	2020-04-15 10:08:07	2020-04-15	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	9182	delivery	5	22
50248	2020-04-15 10:08:23	2020-04-15	14	[{"id_menu":2,"count":1}]	8448	delivery	5	19
50249	2020-04-15 10:09:35	2020-04-15	9	[{"id_menu":7,"count":1}]	20099	delivery	5	14
50250	2020-04-15 10:12:01	2020-04-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8573	delivery	5	23
50251	2020-04-15 10:12:49	2020-04-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	19994	delivery	5	31
50252	2020-04-15 10:14:49	2020-04-15	17	[{"id_menu":4,"count":1}]	20009	pick-up	0	17
50253	2020-04-15 10:16:44	2020-04-15	9	[{"id_menu":7,"count":1}]	16412	delivery	5	14
50254	2020-04-15 10:17:00	2020-04-15	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20037	delivery	5	39
50255	2020-04-15 10:20:52	2020-04-15	17	[{"id_menu":4,"count":1}]	20083	delivery	5	22
50256	2020-04-15 10:21:40	2020-04-15	8	[{"id_menu":5,"count":1}]	6147	pick-up	0	8
50257	2020-04-15 10:22:46	2020-04-15	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15376	delivery	5	35
50258	2020-04-15 10:23:43	2020-04-15	8	[{"id_menu":5,"count":1}]	12675	pick-up	0	8
50259	2020-04-15 10:25:01	2020-04-15	14	[{"id_menu":2,"count":1}]	5308	delivery	5	19
50260	2020-04-15 10:29:11	2020-04-15	49	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	20043	delivery	5	54
50261	2020-04-15 10:34:26	2020-04-15	17	[{"id_menu":4,"count":1}]	4027	pick-up	0	17
50262	2020-04-15 10:36:28	2020-04-15	12	[{"id_menu":3,"count":1}]	5780	pick-up	0	12
50263	2020-04-15 10:51:48	2020-04-15	9	[{"id_menu":6,"count":1}]	20072	delivery	5	14
50264	2020-04-15 10:52:49	2020-04-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17384	delivery	5	23
50265	2020-04-15 10:53:30	2020-04-15	12	[{"id_menu":1,"count":1}]	20027	delivery	5	17
50266	2020-04-15 11:00:28	2020-04-15	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5174	delivery	5	37
50267	2020-04-15 11:02:38	2020-04-15	14	[{"id_menu":2,"count":1}]	6369	delivery	5	19
50268	2020-04-15 11:03:38	2020-04-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1101	pick-up	0	26
50269	2020-04-15 11:04:40	2020-04-15	12	[{"id_menu":1,"count":1}]	6798	delivery	5	17
50270	2020-04-15 11:08:24	2020-04-15	14	[{"id_menu":2,"count":1}]	304	pick-up	0	14
50271	2020-04-15 11:20:35	2020-04-15	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	20102	delivery	5	43
50272	2020-04-15 11:29:43	2020-04-15	12	[{"id_menu":3,"count":2}]	19981	delivery	5	17
50273	2020-04-15 11:31:16	2020-04-15	12	[{"id_menu":3,"count":1}]	563	delivery	5	17
50274	2020-04-15 11:31:37	2020-04-15	12	[{"id_menu":1,"count":1}]	20087	delivery	5	17
50275	2020-04-15 11:31:38	2020-04-15	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	193	delivery	5	26
50276	2020-04-15 11:31:55	2020-04-15	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	20055	delivery	5	45
50277	2020-04-15 11:33:15	2020-04-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6664	delivery	5	28
50278	2020-04-15 11:35:20	2020-04-15	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	20110	delivery	5	26
50279	2020-04-15 11:38:35	2020-04-15	9	[{"id_menu":6,"count":1}]	20062	delivery	5	14
50280	2020-04-15 11:42:10	2020-04-15	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	5422	delivery	5	26
50281	2020-04-15 11:42:40	2020-04-15	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	13881	delivery	5	38
50282	2020-04-15 11:50:13	2020-04-15	9	[{"id_menu":7,"count":1}]	10381	delivery	5	14
50283	2020-04-15 11:50:17	2020-04-15	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12973	delivery	5	37
50284	2020-04-15 11:54:31	2020-04-15	17	[{"id_menu":4,"count":1}]	20015	delivery	5	22
50285	2020-04-15 12:00:08	2020-04-15	8	[{"id_menu":5,"count":1}]	17845	delivery	5	13
50286	2020-04-15 12:00:45	2020-04-15	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	18291	delivery	5	31
50287	2020-04-15 12:04:23	2020-04-15	14	[{"id_menu":2,"count":1}]	13763	delivery	5	19
50288	2020-04-15 12:09:45	2020-04-15	12	[{"id_menu":1,"count":1}]	6502	pick-up	0	12
50289	2020-04-15 12:10:30	2020-04-15	8	[{"id_menu":5,"count":1}]	20070	delivery	5	13
50290	2020-04-15 12:11:11	2020-04-15	12	[{"id_menu":1,"count":1}]	786	pick-up	0	12
50291	2020-04-15 12:13:13	2020-04-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	19991	pick-up	0	26
50292	2020-04-15 12:17:40	2020-04-15	17	[{"id_menu":4,"count":1}]	9072	delivery	5	22
50293	2020-04-15 12:19:56	2020-04-15	12	[{"id_menu":1,"count":1}]	19536	delivery	5	17
50294	2020-04-15 12:23:08	2020-04-15	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	20063	delivery	5	45
50295	2020-04-15 12:23:20	2020-04-15	14	[{"id_menu":2,"count":1}]	20054	delivery	5	19
50296	2020-04-15 12:33:35	2020-04-15	17	[{"id_menu":4,"count":1}]	7150	delivery	5	22
50297	2020-04-15 12:39:09	2020-04-15	8	[{"id_menu":5,"count":1}]	73	pick-up	0	8
50298	2020-04-15 12:45:55	2020-04-15	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8781	delivery	5	37
50299	2020-04-15 12:52:03	2020-04-15	12	[{"id_menu":3,"count":1}]	20047	pick-up	0	12
50300	2020-04-15 12:56:09	2020-04-15	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	10234	delivery	5	39
50301	2020-04-15 13:05:21	2020-04-15	9	[{"id_menu":7,"count":1}]	20023	pick-up	0	9
50302	2020-04-15 13:11:33	2020-04-15	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20122	delivery	5	36
50303	2020-04-15 13:16:03	2020-04-15	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	20065	delivery	5	44
50304	2020-04-15 13:19:15	2020-04-15	14	[{"id_menu":2,"count":1}]	20098	pick-up	0	14
50305	2020-04-15 13:22:04	2020-04-15	9	[{"id_menu":7,"count":1}]	7050	delivery	5	14
50306	2020-04-15 13:22:11	2020-04-15	9	[{"id_menu":7,"count":1}]	18804	delivery	5	14
50307	2020-04-15 13:23:15	2020-04-15	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	20003	delivery	5	42
50308	2020-04-15 13:28:30	2020-04-15	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":2}]	16268	delivery	5	26
50309	2020-04-15 13:29:26	2020-04-15	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7122	delivery	5	36
50310	2020-04-15 13:36:47	2020-04-15	14	[{"id_menu":2,"count":2}]	19998	delivery	5	19
50311	2020-04-15 13:38:14	2020-04-15	17	[{"id_menu":4,"count":1}]	1714	pick-up	0	17
50312	2020-04-15 13:38:16	2020-04-15	9	[{"id_menu":6,"count":1}]	5934	delivery	5	14
50313	2020-04-15 13:49:36	2020-04-15	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	20007	delivery	5	36
50314	2020-04-15 13:49:51	2020-04-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10867	pick-up	0	18
50315	2020-04-15 13:50:42	2020-04-15	9	[{"id_menu":6,"count":2}]	20005	delivery	5	14
50316	2020-04-15 13:52:45	2020-04-15	9	[{"id_menu":6,"count":3}]	8582	delivery	5	14
50317	2020-04-15 13:56:44	2020-04-15	8	[{"id_menu":5,"count":1}]	11909	delivery	5	13
50318	2020-04-15 13:59:12	2020-04-15	14	[{"id_menu":2,"count":1}]	19992	delivery	5	19
50319	2020-04-15 13:59:24	2020-04-15	8	[{"id_menu":5,"count":1}]	20016	delivery	5	13
50320	2020-04-15 14:01:29	2020-04-15	17	[{"id_menu":4,"count":1}]	18587	delivery	5	22
50321	2020-04-15 14:02:12	2020-04-15	12	[{"id_menu":3,"count":1}]	13593	pick-up	0	12
50322	2020-04-15 14:03:37	2020-04-15	12	[{"id_menu":1,"count":1}]	185	delivery	5	17
50323	2020-04-15 14:06:57	2020-04-15	14	[{"id_menu":2,"count":1}]	721	pick-up	0	14
50324	2020-04-15 14:15:43	2020-04-15	8	[{"id_menu":5,"count":1}]	5730	delivery	5	13
50325	2020-04-15 14:19:37	2020-04-15	12	[{"id_menu":3,"count":1}]	20114	delivery	5	17
50326	2020-04-15 14:23:13	2020-04-15	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5097	delivery	5	45
50327	2020-04-15 14:25:43	2020-04-15	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	18592	delivery	5	42
50328	2020-04-15 14:28:15	2020-04-15	12	[{"id_menu":1,"count":1}]	20112	delivery	5	17
50329	2020-04-15 14:28:40	2020-04-15	9	[{"id_menu":6,"count":1}]	9212	delivery	5	14
50330	2020-04-15 14:34:39	2020-04-15	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	8813	delivery	5	37
50331	2020-04-15 14:37:46	2020-04-15	9	[{"id_menu":6,"count":1}]	2348	pick-up	0	9
50332	2020-04-15 14:38:27	2020-04-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	20026	delivery	5	31
50333	2020-04-15 14:42:50	2020-04-15	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	20118	delivery	5	45
50334	2020-04-15 14:47:54	2020-04-15	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11517	delivery	5	34
50335	2020-04-15 14:49:02	2020-04-15	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	8145	pick-up	0	31
50336	2020-04-15 14:54:42	2020-04-15	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	20075	delivery	5	40
50337	2020-04-15 15:03:29	2020-04-15	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	2934	delivery	5	35
50338	2020-04-15 15:05:09	2020-04-15	9	[{"id_menu":7,"count":1}]	6790	delivery	5	14
50339	2020-04-15 15:06:06	2020-04-15	9	[{"id_menu":6,"count":1}]	4996	delivery	5	14
50340	2020-04-15 15:06:14	2020-04-15	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11444	delivery	5	39
50341	2020-04-15 15:07:59	2020-04-15	12	[{"id_menu":1,"count":1}]	20010	delivery	5	17
50342	2020-04-15 15:13:46	2020-04-15	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	130	delivery	5	34
50343	2020-04-15 15:15:56	2020-04-15	17	[{"id_menu":4,"count":1}]	19985	pick-up	0	17
50344	2020-04-15 15:21:28	2020-04-15	12	[{"id_menu":3,"count":1}]	18454	delivery	5	17
50345	2020-04-15 15:43:38	2020-04-15	12	[{"id_menu":3,"count":1}]	10488	delivery	5	17
50346	2020-04-15 15:43:49	2020-04-15	9	[{"id_menu":7,"count":1}]	20036	delivery	5	14
50347	2020-04-15 15:48:00	2020-04-15	17	[{"id_menu":4,"count":1}]	11732	pick-up	0	17
50348	2020-04-15 15:54:29	2020-04-15	17	[{"id_menu":4,"count":1}]	11253	pick-up	0	17
50349	2020-04-15 15:57:59	2020-04-15	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8762	delivery	5	57
50350	2020-04-15 15:58:36	2020-04-15	17	[{"id_menu":4,"count":1}]	11152	delivery	5	22
50351	2020-04-15 16:01:22	2020-04-15	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12020	delivery	5	22
50352	2020-04-15 16:03:08	2020-04-15	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	714	pick-up	0	30
50353	2020-04-15 16:05:19	2020-04-15	12	[{"id_menu":1,"count":1}]	19930	pick-up	0	12
50354	2020-04-15 16:08:03	2020-04-15	9	[{"id_menu":6,"count":1}]	20006	delivery	5	14
50355	2020-04-15 16:08:05	2020-04-15	12	[{"id_menu":3,"count":1}]	1599	pick-up	0	12
50356	2020-04-15 16:09:16	2020-04-15	14	[{"id_menu":2,"count":2}]	20017	delivery	5	19
50357	2020-04-15 16:09:27	2020-04-15	9	[{"id_menu":7,"count":1}]	6655	delivery	5	14
50358	2020-04-15 16:09:27	2020-04-15	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19982	delivery	5	39
50359	2020-04-15 16:11:11	2020-04-15	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1566	delivery	5	55
50360	2020-04-15 16:13:30	2020-04-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18012	delivery	5	23
50361	2020-04-15 16:18:22	2020-04-15	14	[{"id_menu":2,"count":1}]	19966	delivery	5	19
50362	2020-04-15 16:22:14	2020-04-15	9	[{"id_menu":6,"count":1}]	11666	delivery	5	14
50363	2020-04-15 16:36:05	2020-04-15	9	[{"id_menu":6,"count":1}]	19999	delivery	5	14
50364	2020-04-15 16:37:14	2020-04-15	12	[{"id_menu":1,"count":1}]	10760	pick-up	0	12
50365	2020-04-15 16:37:20	2020-04-15	9	[{"id_menu":6,"count":1}]	1443	delivery	5	14
50366	2020-04-15 16:42:42	2020-04-15	9	[{"id_menu":7,"count":1}]	14403	delivery	5	14
50367	2020-04-15 16:43:41	2020-04-15	8	[{"id_menu":5,"count":1}]	13923	pick-up	0	8
50368	2020-04-15 16:44:07	2020-04-15	9	[{"id_menu":6,"count":1}]	17637	delivery	5	14
50369	2020-04-15 16:45:20	2020-04-15	12	[{"id_menu":3,"count":1}]	1402	delivery	5	17
50370	2020-04-15 16:49:33	2020-04-15	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11407	pick-up	0	38
50371	2020-04-15 16:54:42	2020-04-15	9	[{"id_menu":6,"count":2}]	11404	delivery	5	14
50372	2020-04-15 16:57:39	2020-04-15	9	[{"id_menu":6,"count":1}]	19970	delivery	5	14
50373	2020-04-15 16:59:02	2020-04-15	8	[{"id_menu":5,"count":1}]	6342	pick-up	0	8
50374	2020-04-15 16:59:31	2020-04-15	12	[{"id_menu":1,"count":1}]	14336	delivery	5	17
50375	2020-04-15 17:03:50	2020-04-15	14	[{"id_menu":2,"count":1}]	10905	delivery	5	19
50376	2020-04-15 17:08:27	2020-04-15	14	[{"id_menu":2,"count":1}]	9299	delivery	5	19
50377	2020-04-15 17:16:06	2020-04-15	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	3767	delivery	5	25
50378	2020-04-15 17:16:53	2020-04-15	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	20050	delivery	5	22
50379	2020-04-15 17:18:14	2020-04-15	9	[{"id_menu":7,"count":1}]	265	pick-up	0	9
50380	2020-04-15 17:20:58	2020-04-15	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19118	delivery	5	46
50381	2020-04-15 17:26:11	2020-04-15	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	360	delivery	5	48
50382	2020-04-15 17:31:20	2020-04-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16710	pick-up	0	18
50383	2020-04-15 17:31:27	2020-04-15	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20097	delivery	5	40
50384	2020-04-15 17:31:48	2020-04-15	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	13568	delivery	5	27
50385	2020-04-15 17:31:56	2020-04-15	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19817	delivery	5	22
50386	2020-04-15 17:33:10	2020-04-15	9	[{"id_menu":7,"count":1}]	20049	delivery	5	14
50387	2020-04-15 17:36:17	2020-04-15	8	[{"id_menu":5,"count":1}]	20058	pick-up	0	8
50388	2020-04-15 17:42:57	2020-04-15	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14112	delivery	5	37
50389	2020-04-15 17:50:05	2020-04-15	17	[{"id_menu":4,"count":1}]	20090	delivery	5	22
50390	2020-04-15 17:54:24	2020-04-15	9	[{"id_menu":6,"count":1}]	1088	delivery	5	14
50391	2020-04-15 17:55:39	2020-04-15	12	[{"id_menu":3,"count":1}]	19974	pick-up	0	12
50392	2020-04-15 17:56:16	2020-04-15	9	[{"id_menu":6,"count":1}]	4007	delivery	5	14
50393	2020-04-15 18:05:03	2020-04-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9593	delivery	5	28
50394	2020-04-15 18:10:16	2020-04-15	9	[{"id_menu":7,"count":2}]	13287	delivery	5	14
50395	2020-04-15 18:10:22	2020-04-15	9	[{"id_menu":6,"count":1}]	20104	delivery	5	14
50396	2020-04-15 18:12:40	2020-04-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	20048	delivery	5	28
50397	2020-04-15 18:16:10	2020-04-15	17	[{"id_menu":4,"count":1}]	16639	delivery	5	22
50398	2020-04-15 18:24:18	2020-04-15	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":2}]	6296	delivery	5	28
50399	2020-04-15 18:27:50	2020-04-15	12	[{"id_menu":1,"count":1}]	15061	delivery	5	17
50400	2020-04-15 18:45:39	2020-04-15	12	[{"id_menu":3,"count":1}]	14086	pick-up	0	12
50401	2020-04-15 18:48:45	2020-04-15	8	[{"id_menu":5,"count":1}]	6190	delivery	5	13
50402	2020-04-15 18:51:03	2020-04-15	9	[{"id_menu":6,"count":1}]	20056	delivery	5	14
50403	2020-04-15 18:51:26	2020-04-15	14	[{"id_menu":2,"count":1}]	19986	delivery	5	19
50404	2020-04-15 18:53:26	2020-04-15	17	[{"id_menu":4,"count":1}]	11004	delivery	5	22
50405	2020-04-15 18:59:57	2020-04-15	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	20108	delivery	5	31
50406	2020-04-15 19:05:04	2020-04-15	8	[{"id_menu":5,"count":1}]	6243	delivery	5	13
50407	2020-04-15 19:07:06	2020-04-15	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	16560	delivery	5	43
50408	2020-04-15 19:22:28	2020-04-15	12	[{"id_menu":1,"count":1}]	19975	delivery	5	17
50409	2020-04-15 19:23:38	2020-04-15	12	[{"id_menu":1,"count":1}]	20080	delivery	5	17
50410	2020-04-15 19:25:45	2020-04-15	9	[{"id_menu":7,"count":1}]	19962	delivery	5	14
50411	2020-04-15 19:28:08	2020-04-15	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	1730	delivery	5	26
50412	2020-04-15 19:30:04	2020-04-15	12	[{"id_menu":1,"count":1}]	3172	pick-up	0	12
50413	2020-04-15 19:32:40	2020-04-15	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	12364	delivery	5	29
50414	2020-04-15 19:40:08	2020-04-15	14	[{"id_menu":2,"count":1}]	7612	pick-up	0	14
50415	2020-04-15 19:40:28	2020-04-15	17	[{"id_menu":4,"count":1}]	16680	delivery	5	22
50416	2020-04-15 19:40:58	2020-04-15	8	[{"id_menu":5,"count":1}]	15497	delivery	5	13
50417	2020-04-15 19:45:03	2020-04-15	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	2050	pick-up	0	24
50418	2020-04-15 19:49:15	2020-04-15	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	13172	delivery	5	52
50419	2020-04-15 19:51:52	2020-04-15	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8410	delivery	5	22
50420	2020-04-15 20:04:22	2020-04-15	8	[{"id_menu":5,"count":1}]	20012	delivery	5	13
50421	2020-04-15 20:07:50	2020-04-15	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	140	pick-up	0	34
50422	2020-04-15 20:10:40	2020-04-15	8	[{"id_menu":5,"count":1}]	20117	delivery	5	13
50423	2020-04-15 20:12:01	2020-04-15	8	[{"id_menu":5,"count":1}]	20073	pick-up	0	8
50424	2020-04-15 20:13:41	2020-04-15	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8791	pick-up	0	26
50425	2020-04-15 20:16:47	2020-04-15	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	19967	delivery	5	26
50426	2020-04-15 20:17:36	2020-04-15	12	[{"id_menu":1,"count":1}]	14263	delivery	5	17
50427	2020-04-15 20:18:44	2020-04-15	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20064	delivery	5	36
50428	2020-04-15 20:25:51	2020-04-15	9	[{"id_menu":6,"count":1}]	10127	delivery	5	14
50429	2020-04-15 20:27:52	2020-04-15	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7833	delivery	5	43
50430	2020-04-15 20:33:32	2020-04-15	14	[{"id_menu":2,"count":1}]	2071	pick-up	0	14
50431	2020-04-15 20:36:29	2020-04-15	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3949	pick-up	0	34
50432	2020-04-15 20:40:35	2020-04-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	20052	delivery	5	23
50433	2020-04-15 20:45:12	2020-04-15	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	13698	delivery	5	26
50434	2020-04-15 20:47:12	2020-04-15	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20085	delivery	5	22
50435	2020-04-15 20:47:18	2020-04-15	14	[{"id_menu":2,"count":1}]	15008	delivery	5	19
50436	2020-04-15 20:51:14	2020-04-15	9	[{"id_menu":7,"count":1}]	1946	pick-up	0	9
50437	2020-04-15 20:51:27	2020-04-15	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1557	delivery	5	36
50438	2020-04-15 20:53:25	2020-04-15	14	[{"id_menu":2,"count":1}]	16387	delivery	5	19
50439	2020-04-15 20:55:23	2020-04-15	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15834	delivery	5	40
50440	2020-04-15 20:55:43	2020-04-15	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	19965	delivery	5	22
50441	2020-04-15 20:57:05	2020-04-15	9	[{"id_menu":7,"count":1}]	11619	delivery	5	14
50442	2020-04-15 20:57:19	2020-04-15	8	[{"id_menu":5,"count":1}]	12889	pick-up	0	8
50443	2020-04-15 21:18:50	2020-04-15	9	[{"id_menu":7,"count":1}]	3052	delivery	5	14
50444	2020-04-15 21:20:28	2020-04-15	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20004	delivery	5	31
50445	2020-04-15 21:21:25	2020-04-15	12	[{"id_menu":1,"count":1}]	13872	delivery	5	17
50446	2020-04-15 21:21:27	2020-04-15	12	[{"id_menu":1,"count":2}]	11944	pick-up	0	12
50447	2020-04-15 21:31:24	2020-04-15	9	[{"id_menu":7,"count":1}]	19312	delivery	5	14
50448	2020-04-15 21:33:22	2020-04-15	17	[{"id_menu":4,"count":1}]	15590	pick-up	0	17
50449	2020-04-15 21:51:09	2020-04-15	9	[{"id_menu":6,"count":1}]	20019	delivery	5	14
50450	2020-04-15 21:52:07	2020-04-15	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	2752	pick-up	0	26
50451	2020-04-15 22:05:06	2020-04-15	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	384	pick-up	0	31
50452	2020-04-15 22:15:17	2020-04-15	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	20038	delivery	5	22
50453	2020-04-15 22:16:39	2020-04-15	9	[{"id_menu":6,"count":1}]	822	delivery	5	14
50454	2020-04-15 22:18:19	2020-04-15	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	9833	delivery	5	26
50455	2020-04-15 22:18:32	2020-04-15	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12217	delivery	5	43
50456	2020-04-15 22:25:36	2020-04-15	9	[{"id_menu":7,"count":1}]	11689	delivery	5	14
50457	2020-04-15 22:29:20	2020-04-15	12	[{"id_menu":1,"count":1}]	2687	delivery	5	17
50458	2020-04-15 22:33:03	2020-04-15	17	[{"id_menu":4,"count":2}]	1727	pick-up	0	17
50459	2020-04-15 22:33:27	2020-04-15	9	[{"id_menu":6,"count":1}]	507	delivery	5	14
50460	2020-04-15 22:34:14	2020-04-15	9	[{"id_menu":7,"count":1}]	17451	delivery	5	14
50461	2020-04-15 22:56:46	2020-04-15	9	[{"id_menu":7,"count":1}]	2401	pick-up	0	9
50462	2020-04-15 22:57:53	2020-04-15	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15109	pick-up	0	40
50463	2020-04-15 23:06:28	2020-04-15	12	[{"id_menu":3,"count":2}]	4812	delivery	5	17
50464	2020-04-15 23:08:10	2020-04-15	17	[{"id_menu":4,"count":1}]	10142	delivery	5	22
50465	2020-04-15 23:09:55	2020-04-15	12	[{"id_menu":1,"count":1}]	1912	pick-up	0	12
50466	2020-04-15 23:11:23	2020-04-15	9	[{"id_menu":6,"count":1}]	456	pick-up	0	9
50467	2020-04-15 23:16:54	2020-04-15	14	[{"id_menu":2,"count":1}]	20092	delivery	5	19
50468	2020-04-15 23:21:54	2020-04-15	8	[{"id_menu":5,"count":1}]	8010	delivery	5	13
50469	2020-04-15 23:23:25	2020-04-15	8	[{"id_menu":5,"count":1}]	8553	delivery	5	13
50470	2020-04-15 23:27:47	2020-04-15	12	[{"id_menu":3,"count":1}]	20040	pick-up	0	12
50471	2020-04-15 23:27:48	2020-04-15	9	[{"id_menu":7,"count":1}]	4943	delivery	5	14
50472	2020-04-15 23:29:14	2020-04-15	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":2}]	19993	delivery	5	34
50473	2020-04-15 23:29:32	2020-04-15	17	[{"id_menu":4,"count":1}]	18766	delivery	5	22
50474	2020-04-15 23:39:13	2020-04-15	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9984	delivery	5	45
50475	2020-04-15 23:42:57	2020-04-15	9	[{"id_menu":6,"count":1}]	1720	pick-up	0	9
50476	2020-04-15 23:43:58	2020-04-15	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1387	delivery	5	31
50477	2020-04-15 23:44:04	2020-04-15	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	19988	delivery	5	27
50478	2020-04-15 23:44:04	2020-04-15	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	6535	pick-up	0	43
50479	2020-04-15 23:48:58	2020-04-15	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	8770	delivery	5	39
50480	2020-04-15 23:53:15	2020-04-15	9	[{"id_menu":6,"count":1}]	12381	delivery	5	14
50481	2020-04-15 23:53:25	2020-04-15	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	437	delivery	5	35
50482	2020-04-15 23:55:00	2020-04-15	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1612	delivery	5	26
50483	2020-04-15 23:58:08	2020-04-15	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	20045	delivery	5	31
50484	2020-04-15 23:59:28	2020-04-15	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	5440	pick-up	0	43
50485	2020-04-16 00:02:43	2020-04-16	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5715	delivery	5	31
50486	2020-04-16 00:03:13	2020-04-16	9	[{"id_menu":6,"count":1}]	6207	delivery	5	14
50487	2020-04-16 00:07:03	2020-04-16	12	[{"id_menu":1,"count":1}]	16865	delivery	5	17
50488	2020-04-16 00:13:07	2020-04-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4885	delivery	5	28
50489	2020-04-16 00:19:08	2020-04-16	17	[{"id_menu":4,"count":1}]	2568	pick-up	0	17
50490	2020-04-16 00:25:52	2020-04-16	14	[{"id_menu":2,"count":1}]	204	pick-up	0	14
50491	2020-04-16 00:28:19	2020-04-16	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	20184	delivery	5	46
50492	2020-04-16 00:32:25	2020-04-16	8	[{"id_menu":5,"count":1}]	20251	delivery	5	13
50493	2020-04-16 00:33:53	2020-04-16	12	[{"id_menu":1,"count":1}]	13009	delivery	5	17
50494	2020-04-16 00:34:47	2020-04-16	9	[{"id_menu":7,"count":1}]	13928	delivery	5	14
50495	2020-04-16 00:36:38	2020-04-16	9	[{"id_menu":6,"count":1}]	20170	delivery	5	14
50496	2020-04-16 00:36:58	2020-04-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20150	delivery	5	23
50497	2020-04-16 00:37:37	2020-04-16	9	[{"id_menu":7,"count":2}]	20271	delivery	5	14
50498	2020-04-16 00:38:51	2020-04-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20124	delivery	5	23
50499	2020-04-16 00:40:07	2020-04-16	17	[{"id_menu":4,"count":1}]	16341	delivery	5	22
50500	2020-04-16 00:40:31	2020-04-16	8	[{"id_menu":5,"count":1}]	4159	delivery	5	13
50501	2020-04-16 00:46:01	2020-04-16	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20256	pick-up	0	31
50502	2020-04-16 00:56:11	2020-04-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	20273	delivery	5	26
50503	2020-04-16 00:58:42	2020-04-16	17	[{"id_menu":4,"count":2}]	12269	delivery	5	22
50504	2020-04-16 00:59:46	2020-04-16	12	[{"id_menu":3,"count":1}]	1344	delivery	5	17
50505	2020-04-16 01:01:13	2020-04-16	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	3102	pick-up	0	31
50506	2020-04-16 01:10:55	2020-04-16	12	[{"id_menu":3,"count":1}]	20163	delivery	5	17
50507	2020-04-16 01:13:11	2020-04-16	17	[{"id_menu":4,"count":1}]	213	pick-up	0	17
50508	2020-04-16 01:17:57	2020-04-16	12	[{"id_menu":1,"count":1}]	20245	delivery	5	17
50509	2020-04-16 01:23:19	2020-04-16	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4281	delivery	5	39
50510	2020-04-16 01:27:07	2020-04-16	12	[{"id_menu":1,"count":1}]	2353	pick-up	0	12
50511	2020-04-16 01:35:50	2020-04-16	12	[{"id_menu":3,"count":1}]	20187	delivery	5	17
50512	2020-04-16 01:35:54	2020-04-16	12	[{"id_menu":3,"count":2}]	2870	delivery	5	17
50513	2020-04-16 01:38:40	2020-04-16	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	20138	delivery	5	25
50514	2020-04-16 01:46:18	2020-04-16	14	[{"id_menu":2,"count":1}]	17685	pick-up	0	14
50515	2020-04-16 01:58:19	2020-04-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17480	pick-up	0	26
50516	2020-04-16 01:59:33	2020-04-16	12	[{"id_menu":1,"count":1}]	11534	delivery	5	17
50517	2020-04-16 02:02:00	2020-04-16	14	[{"id_menu":2,"count":1}]	15440	delivery	5	19
50518	2020-04-16 02:04:25	2020-04-16	14	[{"id_menu":2,"count":1}]	4814	delivery	5	19
50519	2020-04-16 02:13:35	2020-04-16	9	[{"id_menu":6,"count":1}]	3818	pick-up	0	9
50520	2020-04-16 02:13:48	2020-04-16	9	[{"id_menu":7,"count":1}]	4428	pick-up	0	9
50521	2020-04-16 02:16:38	2020-04-16	17	[{"id_menu":5,"count":3},{"id_menu":6,"count":1}]	20212	delivery	5	22
50522	2020-04-16 02:19:03	2020-04-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5207	delivery	5	31
50523	2020-04-16 02:20:19	2020-04-16	12	[{"id_menu":3,"count":1}]	17304	delivery	5	17
50524	2020-04-16 02:21:28	2020-04-16	12	[{"id_menu":1,"count":1}]	17852	delivery	5	17
50525	2020-04-16 02:30:06	2020-04-16	12	[{"id_menu":3,"count":2}]	20134	pick-up	0	12
50526	2020-04-16 02:34:28	2020-04-16	17	[{"id_menu":4,"count":1}]	7585	delivery	5	22
50527	2020-04-16 02:40:44	2020-04-16	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	20176	delivery	5	40
50528	2020-04-16 02:45:32	2020-04-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	16183	delivery	5	28
50529	2020-04-16 02:54:42	2020-04-16	9	[{"id_menu":6,"count":1}]	2287	pick-up	0	9
50530	2020-04-16 02:58:25	2020-04-16	9	[{"id_menu":6,"count":1}]	20151	delivery	5	14
50531	2020-04-16 02:59:23	2020-04-16	9	[{"id_menu":7,"count":1}]	6899	pick-up	0	9
50532	2020-04-16 03:01:16	2020-04-16	17	[{"id_menu":4,"count":2}]	8574	delivery	5	22
50533	2020-04-16 03:08:21	2020-04-16	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	20196	delivery	5	30
50534	2020-04-16 03:10:06	2020-04-16	9	[{"id_menu":7,"count":1}]	20241	delivery	5	14
50535	2020-04-16 03:10:58	2020-04-16	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	20128	delivery	5	25
50536	2020-04-16 03:17:09	2020-04-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	15658	delivery	5	26
50537	2020-04-16 03:17:53	2020-04-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	20210	delivery	5	31
50538	2020-04-16 03:22:18	2020-04-16	8	[{"id_menu":5,"count":1}]	20230	delivery	5	13
50539	2020-04-16 03:29:13	2020-04-16	14	[{"id_menu":2,"count":1}]	11606	pick-up	0	14
50540	2020-04-16 03:29:30	2020-04-16	17	[{"id_menu":4,"count":1}]	20201	delivery	5	22
50541	2020-04-16 03:31:04	2020-04-16	12	[{"id_menu":3,"count":1}]	20221	delivery	5	17
50542	2020-04-16 03:40:12	2020-04-16	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	18114	pick-up	0	29
50543	2020-04-16 03:44:35	2020-04-16	12	[{"id_menu":3,"count":1}]	7025	delivery	5	17
50544	2020-04-16 03:46:08	2020-04-16	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17326	delivery	5	34
50545	2020-04-16 03:51:05	2020-04-16	9	[{"id_menu":6,"count":1}]	15079	delivery	5	14
50546	2020-04-16 03:54:38	2020-04-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19686	delivery	5	23
50547	2020-04-16 04:03:17	2020-04-16	8	[{"id_menu":5,"count":3}]	20164	delivery	5	13
50548	2020-04-16 04:09:49	2020-04-16	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	20220	delivery	5	26
50549	2020-04-16 04:11:50	2020-04-16	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	495	delivery	5	31
50550	2020-04-16 04:12:06	2020-04-16	17	[{"id_menu":4,"count":1}]	18856	pick-up	0	17
50551	2020-04-16 04:13:32	2020-04-16	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	19518	delivery	5	38
50552	2020-04-16 04:16:39	2020-04-16	9	[{"id_menu":6,"count":1}]	7453	delivery	5	14
50553	2020-04-16 04:19:39	2020-04-16	9	[{"id_menu":7,"count":1}]	17409	delivery	5	14
50554	2020-04-16 04:21:50	2020-04-16	12	[{"id_menu":3,"count":2}]	6342	pick-up	0	12
50555	2020-04-16 04:28:28	2020-04-16	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	5945	delivery	5	38
50556	2020-04-16 04:31:48	2020-04-16	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	17038	delivery	5	34
50557	2020-04-16 04:40:26	2020-04-16	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	2613	pick-up	0	20
50558	2020-04-16 04:42:09	2020-04-16	17	[{"id_menu":4,"count":1}]	3399	delivery	5	22
50559	2020-04-16 04:43:15	2020-04-16	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	20243	delivery	5	55
50560	2020-04-16 04:49:11	2020-04-16	9	[{"id_menu":7,"count":1}]	20135	delivery	5	14
50561	2020-04-16 04:53:55	2020-04-16	9	[{"id_menu":6,"count":2}]	2821	delivery	5	14
50562	2020-04-16 04:55:29	2020-04-16	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	20236	delivery	5	36
50563	2020-04-16 04:58:25	2020-04-16	14	[{"id_menu":2,"count":1}]	2799	pick-up	0	14
50564	2020-04-16 05:01:50	2020-04-16	9	[{"id_menu":6,"count":1}]	20264	delivery	5	14
50565	2020-04-16 05:02:21	2020-04-16	9	[{"id_menu":7,"count":1}]	15459	delivery	5	14
50566	2020-04-16 05:07:33	2020-04-16	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7670	delivery	5	34
50567	2020-04-16 05:13:47	2020-04-16	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	9816	pick-up	0	43
50568	2020-04-16 05:19:57	2020-04-16	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	440	delivery	5	28
50569	2020-04-16 05:20:12	2020-04-16	9	[{"id_menu":7,"count":1}]	9603	delivery	5	14
50570	2020-04-16 05:21:40	2020-04-16	12	[{"id_menu":1,"count":1}]	1335	delivery	5	17
50571	2020-04-16 05:22:51	2020-04-16	14	[{"id_menu":2,"count":1}]	935	delivery	5	19
50572	2020-04-16 05:30:32	2020-04-16	12	[{"id_menu":1,"count":1}]	20199	delivery	5	17
50573	2020-04-16 05:31:40	2020-04-16	9	[{"id_menu":7,"count":1}]	20189	delivery	5	14
50574	2020-04-16 05:31:50	2020-04-16	14	[{"id_menu":2,"count":1}]	19837	delivery	5	19
50575	2020-04-16 05:37:09	2020-04-16	14	[{"id_menu":2,"count":1}]	16190	delivery	5	19
50576	2020-04-16 05:41:03	2020-04-16	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	20140	pick-up	0	31
50577	2020-04-16 05:41:14	2020-04-16	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	17868	delivery	5	26
50578	2020-04-16 05:48:23	2020-04-16	8	[{"id_menu":5,"count":1}]	5719	delivery	5	13
50579	2020-04-16 06:00:20	2020-04-16	12	[{"id_menu":3,"count":1}]	20259	pick-up	0	12
50580	2020-04-16 06:03:01	2020-04-16	12	[{"id_menu":3,"count":1}]	14985	delivery	5	17
50581	2020-04-16 06:03:52	2020-04-16	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19197	delivery	5	37
50582	2020-04-16 06:09:29	2020-04-16	17	[{"id_menu":5,"count":3},{"id_menu":6,"count":1}]	20209	delivery	5	22
50583	2020-04-16 06:20:46	2020-04-16	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	9991	delivery	5	23
50584	2020-04-16 06:24:12	2020-04-16	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20239	delivery	5	52
50585	2020-04-16 06:29:17	2020-04-16	9	[{"id_menu":7,"count":1}]	10389	pick-up	0	9
50586	2020-04-16 06:34:32	2020-04-16	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11219	delivery	5	40
50587	2020-04-16 06:35:04	2020-04-16	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":3}]	20125	delivery	5	26
50588	2020-04-16 06:39:30	2020-04-16	12	[{"id_menu":1,"count":1}]	6101	pick-up	0	12
50589	2020-04-16 06:42:54	2020-04-16	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20257	delivery	5	34
50590	2020-04-16 06:44:05	2020-04-16	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	20200	delivery	5	25
50591	2020-04-16 06:45:28	2020-04-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12906	delivery	5	23
50592	2020-04-16 06:45:54	2020-04-16	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	4660	delivery	5	37
50593	2020-04-16 06:46:07	2020-04-16	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	10993	delivery	5	35
50594	2020-04-16 06:46:48	2020-04-16	9	[{"id_menu":7,"count":1}]	13655	delivery	5	14
50595	2020-04-16 06:49:29	2020-04-16	9	[{"id_menu":6,"count":1}]	8604	delivery	5	14
50596	2020-04-16 06:52:04	2020-04-16	12	[{"id_menu":3,"count":1}]	14354	delivery	5	17
50597	2020-04-16 06:53:35	2020-04-16	14	[{"id_menu":2,"count":2}]	20248	delivery	5	19
50598	2020-04-16 06:53:36	2020-04-16	14	[{"id_menu":2,"count":1}]	20165	delivery	5	19
50599	2020-04-16 06:54:53	2020-04-16	9	[{"id_menu":6,"count":1}]	10696	delivery	5	14
50600	2020-04-16 06:54:57	2020-04-16	9	[{"id_menu":7,"count":1}]	20246	delivery	5	14
50601	2020-04-16 06:56:28	2020-04-16	8	[{"id_menu":5,"count":1}]	19725	delivery	5	13
50602	2020-04-16 06:56:41	2020-04-16	9	[{"id_menu":7,"count":1}]	2166	delivery	5	14
50603	2020-04-16 06:57:08	2020-04-16	17	[{"id_menu":4,"count":1}]	9295	delivery	5	22
50604	2020-04-16 07:14:58	2020-04-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7396	delivery	5	28
50605	2020-04-16 07:22:34	2020-04-16	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2658	delivery	5	31
50606	2020-04-16 07:22:54	2020-04-16	14	[{"id_menu":2,"count":1}]	19813	delivery	5	19
50607	2020-04-16 07:27:03	2020-04-16	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	3784	delivery	5	26
50608	2020-04-16 07:27:20	2020-04-16	12	[{"id_menu":1,"count":1}]	16091	delivery	5	17
50609	2020-04-16 07:27:42	2020-04-16	9	[{"id_menu":6,"count":1}]	19488	delivery	5	14
50610	2020-04-16 07:29:27	2020-04-16	12	[{"id_menu":3,"count":1}]	13950	pick-up	0	12
50611	2020-04-16 07:31:26	2020-04-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	13913	pick-up	0	23
50612	2020-04-16 07:45:25	2020-04-16	12	[{"id_menu":1,"count":1}]	4284	delivery	5	17
50613	2020-04-16 07:50:31	2020-04-16	9	[{"id_menu":7,"count":1}]	17294	delivery	5	14
50614	2020-04-16 07:50:44	2020-04-16	17	[{"id_menu":4,"count":1}]	5038	pick-up	0	17
50615	2020-04-16 07:50:56	2020-04-16	17	[{"id_menu":4,"count":1}]	19841	pick-up	0	17
50616	2020-04-16 07:51:18	2020-04-16	17	[{"id_menu":5,"count":3},{"id_menu":7,"count":1}]	13231	delivery	5	22
50617	2020-04-16 07:52:24	2020-04-16	8	[{"id_menu":5,"count":1}]	6962	delivery	5	13
50618	2020-04-16 07:57:44	2020-04-16	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	378	pick-up	0	35
50619	2020-04-16 08:07:44	2020-04-16	9	[{"id_menu":6,"count":1}]	12808	pick-up	0	9
50620	2020-04-16 08:11:45	2020-04-16	8	[{"id_menu":5,"count":1}]	3842	delivery	5	13
50621	2020-04-16 08:16:29	2020-04-16	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	20265	delivery	5	52
50622	2020-04-16 08:16:48	2020-04-16	9	[{"id_menu":6,"count":1}]	20158	delivery	5	14
50623	2020-04-16 08:17:39	2020-04-16	9	[{"id_menu":6,"count":1}]	20194	delivery	5	14
50624	2020-04-16 08:19:34	2020-04-16	9	[{"id_menu":7,"count":1}]	20188	delivery	5	14
50625	2020-04-16 08:28:19	2020-04-16	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	20147	delivery	5	27
50626	2020-04-16 08:31:25	2020-04-16	17	[{"id_menu":4,"count":1}]	13554	delivery	5	22
50627	2020-04-16 08:32:47	2020-04-16	14	[{"id_menu":2,"count":1}]	20252	delivery	5	19
50628	2020-04-16 08:33:50	2020-04-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	9737	delivery	5	28
50629	2020-04-16 08:34:11	2020-04-16	9	[{"id_menu":7,"count":1}]	18174	delivery	5	14
50630	2020-04-16 08:34:16	2020-04-16	9	[{"id_menu":7,"count":1}]	7051	delivery	5	14
50631	2020-04-16 08:38:10	2020-04-16	17	[{"id_menu":4,"count":1}]	20254	delivery	5	22
50632	2020-04-16 08:38:33	2020-04-16	9	[{"id_menu":6,"count":1}]	20145	delivery	5	14
50633	2020-04-16 08:45:33	2020-04-16	12	[{"id_menu":1,"count":1}]	20133	pick-up	0	12
50634	2020-04-16 08:48:04	2020-04-16	9	[{"id_menu":6,"count":1}]	6858	delivery	5	14
50635	2020-04-16 08:53:17	2020-04-16	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	831	delivery	5	36
50636	2020-04-16 08:58:47	2020-04-16	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	318	delivery	5	31
50637	2020-04-16 09:08:00	2020-04-16	14	[{"id_menu":2,"count":1}]	19183	pick-up	0	14
50638	2020-04-16 09:10:04	2020-04-16	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	3052	delivery	5	26
50639	2020-04-16 09:11:19	2020-04-16	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12614	delivery	5	35
50640	2020-04-16 09:13:07	2020-04-16	17	[{"id_menu":4,"count":1}]	20270	pick-up	0	17
50641	2020-04-16 09:18:44	2020-04-16	9	[{"id_menu":7,"count":1}]	20193	delivery	5	14
50642	2020-04-16 09:19:42	2020-04-16	8	[{"id_menu":5,"count":1}]	20146	pick-up	0	8
50643	2020-04-16 09:28:58	2020-04-16	14	[{"id_menu":2,"count":1}]	17941	delivery	5	19
50644	2020-04-16 09:32:52	2020-04-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16581	delivery	5	31
50645	2020-04-16 09:33:56	2020-04-16	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5388	delivery	5	22
50646	2020-04-16 09:44:56	2020-04-16	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	16569	delivery	5	38
50647	2020-04-16 09:45:48	2020-04-16	12	[{"id_menu":3,"count":2}]	17091	delivery	5	17
50648	2020-04-16 09:50:26	2020-04-16	9	[{"id_menu":7,"count":1}]	14366	delivery	5	14
50649	2020-04-16 09:56:41	2020-04-16	9	[{"id_menu":6,"count":1}]	10488	delivery	5	14
50650	2020-04-16 09:59:15	2020-04-16	9	[{"id_menu":6,"count":1}]	20175	pick-up	0	9
50651	2020-04-16 10:00:11	2020-04-16	8	[{"id_menu":5,"count":1}]	18133	pick-up	0	8
50652	2020-04-16 10:00:56	2020-04-16	12	[{"id_menu":3,"count":1}]	4922	delivery	5	17
50653	2020-04-16 10:01:50	2020-04-16	12	[{"id_menu":3,"count":1}]	7210	delivery	5	17
50654	2020-04-16 10:09:21	2020-04-16	17	[{"id_menu":4,"count":1}]	20229	delivery	5	22
50655	2020-04-16 10:10:18	2020-04-16	17	[{"id_menu":4,"count":1}]	4396	delivery	5	22
50656	2020-04-16 10:11:16	2020-04-16	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	19421	delivery	5	40
50657	2020-04-16 10:19:05	2020-04-16	9	[{"id_menu":7,"count":1}]	16829	pick-up	0	9
50658	2020-04-16 10:19:20	2020-04-16	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5445	delivery	5	52
50659	2020-04-16 10:20:14	2020-04-16	9	[{"id_menu":7,"count":1}]	18283	delivery	5	14
50660	2020-04-16 10:22:27	2020-04-16	9	[{"id_menu":7,"count":1}]	11518	delivery	5	14
50661	2020-04-16 10:29:39	2020-04-16	9	[{"id_menu":7,"count":1}]	1393	delivery	5	14
50662	2020-04-16 10:31:43	2020-04-16	12	[{"id_menu":1,"count":1}]	20182	delivery	5	17
50663	2020-04-16 10:31:50	2020-04-16	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	20261	delivery	5	31
50664	2020-04-16 10:37:30	2020-04-16	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6990	pick-up	0	35
50665	2020-04-16 10:39:11	2020-04-16	8	[{"id_menu":5,"count":1}]	14512	delivery	5	13
50666	2020-04-16 10:39:31	2020-04-16	9	[{"id_menu":7,"count":1}]	19212	pick-up	0	9
50667	2020-04-16 10:41:51	2020-04-16	14	[{"id_menu":2,"count":1}]	20233	delivery	5	19
50668	2020-04-16 10:45:58	2020-04-16	12	[{"id_menu":1,"count":1}]	15456	pick-up	0	12
50669	2020-04-16 10:47:20	2020-04-16	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	5605	pick-up	0	29
50670	2020-04-16 10:49:30	2020-04-16	9	[{"id_menu":7,"count":1}]	338	pick-up	0	9
50671	2020-04-16 10:52:06	2020-04-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	20218	delivery	5	26
50672	2020-04-16 10:56:02	2020-04-16	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	7330	delivery	5	26
50673	2020-04-16 11:01:03	2020-04-16	8	[{"id_menu":5,"count":1}]	2232	delivery	5	13
50674	2020-04-16 11:07:44	2020-04-16	14	[{"id_menu":2,"count":1}]	17501	delivery	5	19
50675	2020-04-16 11:11:47	2020-04-16	9	[{"id_menu":6,"count":1}]	1563	pick-up	0	9
50676	2020-04-16 11:13:56	2020-04-16	17	[{"id_menu":4,"count":1}]	20277	delivery	5	22
50677	2020-04-16 11:16:01	2020-04-16	8	[{"id_menu":5,"count":1}]	20231	pick-up	0	8
50678	2020-04-16 11:16:15	2020-04-16	14	[{"id_menu":2,"count":1}]	20148	delivery	5	19
50679	2020-04-16 11:18:00	2020-04-16	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	18157	pick-up	0	22
50680	2020-04-16 11:20:14	2020-04-16	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	18928	delivery	5	31
50681	2020-04-16 11:20:33	2020-04-16	9	[{"id_menu":6,"count":1}]	1258	delivery	5	14
50682	2020-04-16 11:20:56	2020-04-16	12	[{"id_menu":3,"count":1}]	5582	delivery	5	17
50683	2020-04-16 11:21:44	2020-04-16	17	[{"id_menu":4,"count":1}]	4714	delivery	5	22
50684	2020-04-16 11:21:51	2020-04-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4793	delivery	5	31
50685	2020-04-16 11:23:10	2020-04-16	14	[{"id_menu":2,"count":1}]	16422	pick-up	0	14
50686	2020-04-16 11:26:32	2020-04-16	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	20225	delivery	5	25
50687	2020-04-16 11:32:40	2020-04-16	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3614	pick-up	0	22
50688	2020-04-16 11:36:12	2020-04-16	14	[{"id_menu":2,"count":1}]	10087	pick-up	0	14
50689	2020-04-16 11:40:04	2020-04-16	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	20269	delivery	5	30
50690	2020-04-16 11:46:59	2020-04-16	9	[{"id_menu":6,"count":1}]	11152	delivery	5	14
50691	2020-04-16 11:53:19	2020-04-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	17695	pick-up	0	23
50692	2020-04-16 11:53:21	2020-04-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20219	delivery	5	23
50693	2020-04-16 11:55:27	2020-04-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	20173	pick-up	0	23
50694	2020-04-16 11:56:15	2020-04-16	14	[{"id_menu":2,"count":1}]	3504	delivery	5	19
50695	2020-04-16 11:58:34	2020-04-16	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18738	delivery	5	34
50696	2020-04-16 12:01:44	2020-04-16	9	[{"id_menu":6,"count":1}]	20228	delivery	5	14
50697	2020-04-16 12:08:39	2020-04-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10489	delivery	5	23
50698	2020-04-16 12:10:18	2020-04-16	12	[{"id_menu":1,"count":1}]	12476	delivery	5	17
50699	2020-04-16 12:12:45	2020-04-16	12	[{"id_menu":3,"count":1}]	12855	pick-up	0	12
50700	2020-04-16 12:12:53	2020-04-16	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	12833	delivery	5	40
50701	2020-04-16 12:15:05	2020-04-16	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	20260	delivery	5	55
50702	2020-04-16 12:16:51	2020-04-16	12	[{"id_menu":3,"count":1}]	18724	delivery	5	17
50703	2020-04-16 12:24:43	2020-04-16	14	[{"id_menu":2,"count":1}]	4869	pick-up	0	14
50704	2020-04-16 12:28:13	2020-04-16	9	[{"id_menu":6,"count":1}]	19199	delivery	5	14
50705	2020-04-16 12:29:57	2020-04-16	9	[{"id_menu":7,"count":1}]	6476	delivery	5	14
50706	2020-04-16 12:30:31	2020-04-16	9	[{"id_menu":6,"count":1}]	20160	delivery	5	14
50707	2020-04-16 12:33:14	2020-04-16	12	[{"id_menu":3,"count":1}]	744	pick-up	0	12
50708	2020-04-16 12:33:44	2020-04-16	9	[{"id_menu":7,"count":1}]	20255	delivery	5	14
50709	2020-04-16 12:35:12	2020-04-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	20274	pick-up	0	23
50710	2020-04-16 12:46:29	2020-04-16	9	[{"id_menu":6,"count":1}]	20268	delivery	5	14
50711	2020-04-16 12:50:46	2020-04-16	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15822	delivery	5	22
50712	2020-04-16 12:51:58	2020-04-16	9	[{"id_menu":6,"count":1}]	20215	delivery	5	14
50713	2020-04-16 12:52:15	2020-04-16	14	[{"id_menu":2,"count":1}]	5240	pick-up	0	14
50714	2020-04-16 12:55:23	2020-04-16	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	17455	delivery	5	25
50715	2020-04-16 12:58:22	2020-04-16	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20197	delivery	5	49
50716	2020-04-16 13:04:56	2020-04-16	9	[{"id_menu":7,"count":1}]	15478	delivery	5	14
50717	2020-04-16 13:07:26	2020-04-16	14	[{"id_menu":2,"count":1}]	11764	pick-up	0	14
50718	2020-04-16 13:09:05	2020-04-16	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18863	delivery	5	36
50719	2020-04-16 13:11:18	2020-04-16	9	[{"id_menu":6,"count":1}]	9320	delivery	5	14
50720	2020-04-16 13:11:59	2020-04-16	9	[{"id_menu":7,"count":1}]	11443	delivery	5	14
50721	2020-04-16 13:15:25	2020-04-16	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13257	delivery	5	53
50722	2020-04-16 13:19:11	2020-04-16	12	[{"id_menu":1,"count":1}]	20227	pick-up	0	12
50723	2020-04-16 13:21:29	2020-04-16	9	[{"id_menu":7,"count":1}]	17930	delivery	5	14
50724	2020-04-16 13:35:32	2020-04-16	17	[{"id_menu":4,"count":1}]	20232	delivery	5	22
50725	2020-04-16 13:36:00	2020-04-16	14	[{"id_menu":2,"count":1}]	19	delivery	5	19
50726	2020-04-16 13:40:13	2020-04-16	14	[{"id_menu":2,"count":1}]	7945	pick-up	0	14
50727	2020-04-16 13:41:07	2020-04-16	12	[{"id_menu":1,"count":1}]	20214	delivery	5	17
50728	2020-04-16 13:41:27	2020-04-16	9	[{"id_menu":6,"count":1}]	19532	delivery	5	14
50729	2020-04-16 13:42:16	2020-04-16	9	[{"id_menu":7,"count":1}]	20168	delivery	5	14
50730	2020-04-16 13:44:35	2020-04-16	12	[{"id_menu":3,"count":1}]	4818	delivery	5	17
50731	2020-04-16 13:50:02	2020-04-16	17	[{"id_menu":4,"count":1}]	1493	pick-up	0	17
50732	2020-04-16 13:57:21	2020-04-16	14	[{"id_menu":2,"count":1}]	16753	delivery	5	19
50733	2020-04-16 14:00:15	2020-04-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	20127	delivery	5	28
50734	2020-04-16 14:00:32	2020-04-16	14	[{"id_menu":2,"count":1}]	7035	delivery	5	19
50735	2020-04-16 14:05:08	2020-04-16	9	[{"id_menu":7,"count":1}]	20202	delivery	5	14
50736	2020-04-16 14:14:30	2020-04-16	9	[{"id_menu":6,"count":1}]	15719	delivery	5	14
50737	2020-04-16 14:16:12	2020-04-16	8	[{"id_menu":5,"count":1}]	10442	delivery	5	13
50738	2020-04-16 14:17:21	2020-04-16	9	[{"id_menu":7,"count":1}]	12089	delivery	5	14
50739	2020-04-16 14:18:54	2020-04-16	9	[{"id_menu":7,"count":1}]	8836	pick-up	0	9
50740	2020-04-16 14:21:08	2020-04-16	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	6680	pick-up	0	26
50741	2020-04-16 14:32:49	2020-04-16	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	1239	pick-up	0	26
50742	2020-04-16 14:33:15	2020-04-16	12	[{"id_menu":1,"count":1}]	5466	pick-up	0	12
50743	2020-04-16 14:34:20	2020-04-16	17	[{"id_menu":4,"count":1}]	6892	delivery	5	22
50744	2020-04-16 14:34:49	2020-04-16	8	[{"id_menu":5,"count":1}]	1420	delivery	5	13
50745	2020-04-16 14:37:50	2020-04-16	9	[{"id_menu":7,"count":1}]	13648	pick-up	0	9
50746	2020-04-16 14:41:55	2020-04-16	17	[{"id_menu":4,"count":1}]	20237	delivery	5	22
50747	2020-04-16 14:48:41	2020-04-16	12	[{"id_menu":1,"count":1}]	73	pick-up	0	12
50748	2020-04-16 14:49:01	2020-04-16	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	19249	delivery	5	31
50749	2020-04-16 14:51:08	2020-04-16	8	[{"id_menu":5,"count":1}]	20234	delivery	5	13
50750	2020-04-16 14:51:20	2020-04-16	8	[{"id_menu":5,"count":1}]	20198	delivery	5	13
50751	2020-04-16 14:52:19	2020-04-16	14	[{"id_menu":2,"count":1}]	8229	delivery	5	19
50752	2020-04-16 14:52:56	2020-04-16	9	[{"id_menu":7,"count":1}]	20183	delivery	5	14
50753	2020-04-16 14:59:32	2020-04-16	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20247	delivery	5	36
50754	2020-04-16 15:07:59	2020-04-16	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20211	delivery	5	22
50755	2020-04-16 15:13:09	2020-04-16	9	[{"id_menu":6,"count":1}]	15174	delivery	5	14
50756	2020-04-16 15:15:04	2020-04-16	14	[{"id_menu":2,"count":1}]	20181	delivery	5	19
50757	2020-04-16 15:22:24	2020-04-16	12	[{"id_menu":1,"count":1}]	2058	pick-up	0	12
50758	2020-04-16 15:24:51	2020-04-16	12	[{"id_menu":3,"count":1}]	20190	delivery	5	17
50759	2020-04-16 15:25:32	2020-04-16	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20244	delivery	5	36
50760	2020-04-16 15:26:59	2020-04-16	9	[{"id_menu":7,"count":1}]	2794	delivery	5	14
50761	2020-04-16 15:27:42	2020-04-16	9	[{"id_menu":6,"count":1}]	2041	pick-up	0	9
50762	2020-04-16 15:30:09	2020-04-16	14	[{"id_menu":2,"count":1}]	9352	delivery	5	19
50763	2020-04-16 15:32:34	2020-04-16	9	[{"id_menu":6,"count":1}]	20169	delivery	5	14
50764	2020-04-16 15:33:05	2020-04-16	12	[{"id_menu":3,"count":2}]	20216	delivery	5	17
50765	2020-04-16 15:41:19	2020-04-16	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	18440	delivery	5	31
50766	2020-04-16 15:46:56	2020-04-16	14	[{"id_menu":2,"count":1}]	48	delivery	5	19
50767	2020-04-16 15:50:31	2020-04-16	8	[{"id_menu":5,"count":1}]	11343	delivery	5	13
50768	2020-04-16 15:52:25	2020-04-16	17	[{"id_menu":4,"count":1}]	4682	pick-up	0	17
50769	2020-04-16 15:53:50	2020-04-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	16286	delivery	5	26
50770	2020-04-16 15:55:25	2020-04-16	12	[{"id_menu":1,"count":1}]	3513	delivery	5	17
50771	2020-04-16 15:57:56	2020-04-16	12	[{"id_menu":1,"count":1}]	19874	pick-up	0	12
50772	2020-04-16 15:59:37	2020-04-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	20159	delivery	5	31
50773	2020-04-16 16:01:47	2020-04-16	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	20139	delivery	5	56
50774	2020-04-16 16:07:29	2020-04-16	12	[{"id_menu":3,"count":1}]	2936	delivery	5	17
50775	2020-04-16 16:16:20	2020-04-16	9	[{"id_menu":7,"count":1}]	20192	delivery	5	14
50776	2020-04-16 16:17:32	2020-04-16	8	[{"id_menu":5,"count":1}]	12755	delivery	5	13
50777	2020-04-16 16:21:09	2020-04-16	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	6166	delivery	5	27
50778	2020-04-16 16:21:42	2020-04-16	9	[{"id_menu":6,"count":1}]	20153	pick-up	0	9
50779	2020-04-16 16:26:34	2020-04-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	20242	delivery	5	31
50780	2020-04-16 16:27:20	2020-04-16	8	[{"id_menu":5,"count":1}]	20141	delivery	5	13
50781	2020-04-16 16:27:22	2020-04-16	12	[{"id_menu":3,"count":1}]	17876	delivery	5	17
50782	2020-04-16 16:27:49	2020-04-16	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	20137	delivery	5	30
50783	2020-04-16 16:28:34	2020-04-16	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4862	pick-up	0	34
50784	2020-04-16 16:29:54	2020-04-16	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	14263	delivery	5	31
50785	2020-04-16 16:32:45	2020-04-16	8	[{"id_menu":5,"count":1}]	20206	delivery	5	13
50786	2020-04-16 16:32:51	2020-04-16	9	[{"id_menu":7,"count":1}]	1309	pick-up	0	9
50787	2020-04-16 16:34:44	2020-04-16	17	[{"id_menu":4,"count":1}]	6186	pick-up	0	17
50788	2020-04-16 16:36:31	2020-04-16	17	[{"id_menu":4,"count":1}]	16145	delivery	5	22
50789	2020-04-16 16:45:26	2020-04-16	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	9284	delivery	5	40
50790	2020-04-16 16:45:38	2020-04-16	12	[{"id_menu":3,"count":1}]	19218	pick-up	0	12
50791	2020-04-16 16:47:14	2020-04-16	12	[{"id_menu":3,"count":1}]	10613	delivery	5	17
50792	2020-04-16 16:47:42	2020-04-16	8	[{"id_menu":5,"count":1}]	9923	delivery	5	13
50793	2020-04-16 16:48:02	2020-04-16	12	[{"id_menu":1,"count":1}]	2443	pick-up	0	12
50794	2020-04-16 16:53:35	2020-04-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16231	delivery	5	23
50795	2020-04-16 16:56:00	2020-04-16	17	[{"id_menu":4,"count":1}]	3931	pick-up	0	17
50796	2020-04-16 17:12:50	2020-04-16	9	[{"id_menu":7,"count":1}]	802	pick-up	0	9
50797	2020-04-16 17:16:56	2020-04-16	9	[{"id_menu":7,"count":1}]	2954	delivery	5	14
50798	2020-04-16 17:21:04	2020-04-16	14	[{"id_menu":2,"count":1}]	17827	delivery	5	19
50799	2020-04-16 17:22:56	2020-04-16	8	[{"id_menu":5,"count":1}]	707	delivery	5	13
50800	2020-04-16 17:24:26	2020-04-16	17	[{"id_menu":4,"count":1}]	15653	pick-up	0	17
50801	2020-04-16 17:28:19	2020-04-16	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20157	delivery	5	31
50802	2020-04-16 17:29:15	2020-04-16	9	[{"id_menu":6,"count":1}]	856	delivery	5	14
50803	2020-04-16 17:31:05	2020-04-16	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14607	delivery	5	39
50804	2020-04-16 17:32:53	2020-04-16	9	[{"id_menu":6,"count":1}]	5963	delivery	5	14
50805	2020-04-16 17:35:02	2020-04-16	12	[{"id_menu":3,"count":1}]	14841	pick-up	0	12
50806	2020-04-16 17:35:02	2020-04-16	9	[{"id_menu":7,"count":1}]	7691	pick-up	0	9
50807	2020-04-16 17:36:16	2020-04-16	9	[{"id_menu":6,"count":1}]	20272	delivery	5	14
50808	2020-04-16 17:38:54	2020-04-16	12	[{"id_menu":3,"count":1}]	2276	delivery	5	17
50809	2020-04-16 17:39:20	2020-04-16	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2691	pick-up	0	29
50810	2020-04-16 17:45:41	2020-04-16	9	[{"id_menu":7,"count":1}]	20126	delivery	5	14
50811	2020-04-16 17:46:16	2020-04-16	12	[{"id_menu":1,"count":1}]	6397	delivery	5	17
50812	2020-04-16 17:50:35	2020-04-16	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	13012	delivery	5	31
50813	2020-04-16 17:52:18	2020-04-16	12	[{"id_menu":3,"count":1}]	20144	delivery	5	17
50814	2020-04-16 17:52:24	2020-04-16	17	[{"id_menu":4,"count":1}]	4130	delivery	5	22
50815	2020-04-16 17:55:20	2020-04-16	14	[{"id_menu":2,"count":1}]	1537	pick-up	0	14
50816	2020-04-16 17:57:32	2020-04-16	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	726	delivery	5	44
50817	2020-04-16 18:07:05	2020-04-16	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	16416	pick-up	0	31
50818	2020-04-16 18:12:06	2020-04-16	9	[{"id_menu":7,"count":1}]	7128	pick-up	0	9
50819	2020-04-16 18:12:18	2020-04-16	9	[{"id_menu":6,"count":1}]	14786	delivery	5	14
50820	2020-04-16 18:12:37	2020-04-16	17	[{"id_menu":4,"count":1}]	5286	delivery	5	22
50821	2020-04-16 18:17:32	2020-04-16	12	[{"id_menu":3,"count":1}]	9291	pick-up	0	12
50822	2020-04-16 18:23:15	2020-04-16	12	[{"id_menu":1,"count":1}]	14634	delivery	5	17
50823	2020-04-16 18:26:47	2020-04-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	13570	pick-up	0	23
50824	2020-04-16 18:31:15	2020-04-16	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	15400	pick-up	0	29
50825	2020-04-16 18:31:49	2020-04-16	8	[{"id_menu":5,"count":1}]	20136	pick-up	0	8
50826	2020-04-16 18:36:15	2020-04-16	14	[{"id_menu":2,"count":1}]	19711	pick-up	0	14
50827	2020-04-16 18:36:35	2020-04-16	9	[{"id_menu":6,"count":1}]	20013	delivery	5	14
50828	2020-04-16 18:39:04	2020-04-16	12	[{"id_menu":1,"count":1}]	20179	delivery	5	17
50829	2020-04-16 18:39:49	2020-04-16	14	[{"id_menu":2,"count":1}]	6977	pick-up	0	14
50830	2020-04-16 18:50:42	2020-04-16	9	[{"id_menu":7,"count":1}]	18067	delivery	5	14
50831	2020-04-16 18:52:34	2020-04-16	8	[{"id_menu":5,"count":2}]	20162	delivery	5	13
50832	2020-04-16 18:55:16	2020-04-16	14	[{"id_menu":2,"count":1}]	20263	delivery	5	19
50833	2020-04-16 18:55:41	2020-04-16	8	[{"id_menu":5,"count":1}]	12016	delivery	5	13
50834	2020-04-16 18:59:29	2020-04-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4414	delivery	5	31
50835	2020-04-16 19:01:28	2020-04-16	14	[{"id_menu":2,"count":1}]	6837	pick-up	0	14
50836	2020-04-16 19:02:33	2020-04-16	12	[{"id_menu":3,"count":1}]	7835	pick-up	0	12
50837	2020-04-16 19:08:50	2020-04-16	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	230	delivery	5	30
50838	2020-04-16 19:10:04	2020-04-16	14	[{"id_menu":2,"count":1}]	20267	delivery	5	19
50839	2020-04-16 19:16:44	2020-04-16	9	[{"id_menu":6,"count":1}]	978	pick-up	0	9
50840	2020-04-16 19:22:47	2020-04-16	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7298	delivery	5	36
50841	2020-04-16 19:26:36	2020-04-16	14	[{"id_menu":2,"count":1}]	8985	pick-up	0	14
50842	2020-04-16 19:37:05	2020-04-16	12	[{"id_menu":3,"count":1}]	35	pick-up	0	12
50843	2020-04-16 19:37:51	2020-04-16	17	[{"id_menu":4,"count":1}]	4350	pick-up	0	17
50844	2020-04-16 19:39:25	2020-04-16	12	[{"id_menu":3,"count":1}]	8852	delivery	5	17
50845	2020-04-16 19:39:25	2020-04-16	9	[{"id_menu":7,"count":1}]	20155	delivery	5	14
50846	2020-04-16 19:43:56	2020-04-16	9	[{"id_menu":7,"count":1}]	19605	delivery	5	14
50847	2020-04-16 19:45:18	2020-04-16	12	[{"id_menu":1,"count":1}]	1715	pick-up	0	12
50848	2020-04-16 19:47:33	2020-04-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	12007	delivery	5	28
50849	2020-04-16 19:48:41	2020-04-16	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20224	delivery	5	36
50850	2020-04-16 19:53:41	2020-04-16	9	[{"id_menu":6,"count":1}]	20195	delivery	5	14
50851	2020-04-16 19:59:43	2020-04-16	12	[{"id_menu":1,"count":1}]	20191	delivery	5	17
50852	2020-04-16 19:59:55	2020-04-16	12	[{"id_menu":3,"count":1}]	19597	delivery	5	17
50853	2020-04-16 20:00:48	2020-04-16	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	20223	delivery	5	28
50854	2020-04-16 20:07:17	2020-04-16	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18837	delivery	5	34
50855	2020-04-16 20:14:49	2020-04-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	20262	delivery	5	31
50856	2020-04-16 20:17:59	2020-04-16	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	5962	delivery	5	26
50857	2020-04-16 20:19:22	2020-04-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	10287	pick-up	0	23
50858	2020-04-16 20:20:14	2020-04-16	12	[{"id_menu":1,"count":1}]	10580	pick-up	0	12
50859	2020-04-16 20:23:31	2020-04-16	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	19464	delivery	5	26
50860	2020-04-16 20:25:17	2020-04-16	12	[{"id_menu":3,"count":1}]	4983	delivery	5	17
50861	2020-04-16 20:39:01	2020-04-16	17	[{"id_menu":4,"count":1}]	14318	delivery	5	22
50862	2020-04-16 20:44:09	2020-04-16	12	[{"id_menu":1,"count":1}]	19784	delivery	5	17
50863	2020-04-16 20:46:09	2020-04-16	8	[{"id_menu":5,"count":1}]	20156	delivery	5	13
50864	2020-04-16 21:12:56	2020-04-16	17	[{"id_menu":4,"count":1}]	3711	delivery	5	22
50865	2020-04-16 21:12:57	2020-04-16	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	20204	delivery	5	22
50866	2020-04-16 21:23:08	2020-04-16	14	[{"id_menu":2,"count":1}]	11428	delivery	5	19
50867	2020-04-16 21:26:58	2020-04-16	12	[{"id_menu":3,"count":1}]	20249	delivery	5	17
50868	2020-04-16 21:27:38	2020-04-16	14	[{"id_menu":2,"count":1}]	13245	pick-up	0	14
50869	2020-04-16 21:28:39	2020-04-16	9	[{"id_menu":6,"count":1}]	3350	delivery	5	14
50870	2020-04-16 21:29:50	2020-04-16	12	[{"id_menu":3,"count":2}]	20172	delivery	5	17
50871	2020-04-16 21:37:06	2020-04-16	14	[{"id_menu":2,"count":1}]	6182	delivery	5	19
50872	2020-04-16 21:37:10	2020-04-16	14	[{"id_menu":2,"count":1}]	9563	delivery	5	19
50873	2020-04-16 21:38:09	2020-04-16	8	[{"id_menu":5,"count":1}]	1905	pick-up	0	8
50874	2020-04-16 21:40:32	2020-04-16	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	20174	delivery	5	40
50875	2020-04-16 21:44:56	2020-04-16	8	[{"id_menu":5,"count":1}]	20222	delivery	5	13
50876	2020-04-16 21:45:16	2020-04-16	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	20178	delivery	5	45
50877	2020-04-16 21:48:02	2020-04-16	9	[{"id_menu":6,"count":1}]	20226	delivery	5	14
50878	2020-04-16 21:53:52	2020-04-16	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4206	pick-up	0	31
50879	2020-04-16 21:59:14	2020-04-16	9	[{"id_menu":6,"count":1}]	20143	pick-up	0	9
50880	2020-04-16 22:03:27	2020-04-16	12	[{"id_menu":1,"count":1}]	20102	delivery	5	17
50881	2020-04-16 22:04:51	2020-04-16	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	4120	pick-up	0	26
50882	2020-04-16 22:13:33	2020-04-16	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	20253	delivery	5	26
50883	2020-04-16 22:15:39	2020-04-16	12	[{"id_menu":1,"count":1}]	20235	delivery	5	17
50884	2020-04-16 22:19:33	2020-04-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	20266	delivery	5	31
50885	2020-04-16 22:27:25	2020-04-16	8	[{"id_menu":5,"count":2}]	14594	pick-up	0	8
50886	2020-04-16 22:31:21	2020-04-16	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	20167	delivery	5	57
50887	2020-04-16 22:33:10	2020-04-16	14	[{"id_menu":2,"count":1}]	9216	pick-up	0	14
50888	2020-04-16 22:34:55	2020-04-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	6019	delivery	5	31
50889	2020-04-16 22:38:30	2020-04-16	9	[{"id_menu":7,"count":1}]	4388	delivery	5	14
50890	2020-04-16 22:39:58	2020-04-16	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	20161	delivery	5	31
50891	2020-04-16 22:41:51	2020-04-16	9	[{"id_menu":6,"count":1}]	7746	pick-up	0	9
50892	2020-04-16 22:43:01	2020-04-16	8	[{"id_menu":5,"count":1}]	17071	delivery	5	13
50893	2020-04-16 22:44:09	2020-04-16	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	366	delivery	5	26
50894	2020-04-16 22:46:56	2020-04-16	9	[{"id_menu":7,"count":1}]	15154	delivery	5	14
50895	2020-04-16 22:49:46	2020-04-16	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	20186	delivery	5	40
50896	2020-04-16 22:53:04	2020-04-16	8	[{"id_menu":5,"count":1}]	3785	pick-up	0	8
50897	2020-04-16 22:59:31	2020-04-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13723	delivery	5	22
50898	2020-04-16 23:04:46	2020-04-16	8	[{"id_menu":5,"count":1}]	2561	pick-up	0	8
50899	2020-04-16 23:05:10	2020-04-16	14	[{"id_menu":2,"count":1}]	20131	delivery	5	19
50900	2020-04-16 23:08:01	2020-04-16	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	20275	pick-up	0	22
50901	2020-04-16 23:22:13	2020-04-16	9	[{"id_menu":6,"count":1}]	17482	delivery	5	14
50902	2020-04-16 23:27:47	2020-04-16	9	[{"id_menu":7,"count":1}]	4423	pick-up	0	9
50903	2020-04-16 23:29:02	2020-04-16	9	[{"id_menu":6,"count":1}]	17116	delivery	5	14
50904	2020-04-16 23:30:54	2020-04-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15188	delivery	5	31
50905	2020-04-16 23:32:24	2020-04-16	9	[{"id_menu":6,"count":1}]	18557	delivery	5	14
50906	2020-04-16 23:40:01	2020-04-16	17	[{"id_menu":4,"count":1}]	444	pick-up	0	17
50907	2020-04-16 23:43:26	2020-04-16	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5312	delivery	5	56
50908	2020-04-16 23:43:29	2020-04-16	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	13440	delivery	5	27
50909	2020-04-16 23:49:34	2020-04-16	17	[{"id_menu":4,"count":1}]	15907	pick-up	0	17
50910	2020-04-16 23:52:13	2020-04-16	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2054	pick-up	0	29
50911	2020-04-16 23:53:43	2020-04-16	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12390	delivery	5	31
50912	2020-04-16 23:58:15	2020-04-16	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	19735	delivery	5	30
50913	2020-04-17 00:00:01	2020-04-17	12	[{"id_menu":3,"count":1}]	20365	delivery	5	17
50914	2020-04-17 00:02:26	2020-04-17	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	1755	delivery	5	31
50915	2020-04-17 00:07:49	2020-04-17	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	498	pick-up	0	29
50916	2020-04-17 00:08:58	2020-04-17	9	[{"id_menu":6,"count":1}]	20457	delivery	5	14
50917	2020-04-17 00:10:06	2020-04-17	17	[{"id_menu":4,"count":1}]	1538	pick-up	0	17
50918	2020-04-17 00:15:55	2020-04-17	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	3859	pick-up	0	26
50919	2020-04-17 00:19:24	2020-04-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12639	delivery	5	31
50920	2020-04-17 00:20:49	2020-04-17	14	[{"id_menu":2,"count":1}]	9375	pick-up	0	14
50921	2020-04-17 00:26:53	2020-04-17	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	11841	delivery	5	30
50922	2020-04-17 00:28:19	2020-04-17	14	[{"id_menu":2,"count":1}]	20312	pick-up	0	14
50923	2020-04-17 00:28:45	2020-04-17	8	[{"id_menu":5,"count":1}]	15803	pick-up	0	8
50924	2020-04-17 00:30:06	2020-04-17	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	302	delivery	5	31
50925	2020-04-17 00:34:26	2020-04-17	9	[{"id_menu":6,"count":1}]	20405	delivery	5	14
50926	2020-04-17 00:38:37	2020-04-17	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	20295	delivery	5	25
50927	2020-04-17 00:40:49	2020-04-17	12	[{"id_menu":3,"count":1}]	1025	pick-up	0	12
50928	2020-04-17 00:41:32	2020-04-17	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15456	pick-up	0	38
50929	2020-04-17 00:43:48	2020-04-17	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1516	pick-up	0	38
50930	2020-04-17 00:44:58	2020-04-17	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	18870	delivery	5	43
50931	2020-04-17 00:49:59	2020-04-17	9	[{"id_menu":6,"count":1}]	20398	delivery	5	14
50932	2020-04-17 00:51:03	2020-04-17	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20377	delivery	5	22
50933	2020-04-17 00:54:43	2020-04-17	9	[{"id_menu":6,"count":1}]	14666	pick-up	0	9
50934	2020-04-17 00:55:34	2020-04-17	9	[{"id_menu":6,"count":1}]	3634	delivery	5	14
50935	2020-04-17 00:56:57	2020-04-17	9	[{"id_menu":7,"count":1}]	6707	delivery	5	14
50936	2020-04-17 00:59:10	2020-04-17	9	[{"id_menu":6,"count":1}]	8068	pick-up	0	9
50937	2020-04-17 01:19:01	2020-04-17	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	11490	delivery	5	22
50938	2020-04-17 01:23:50	2020-04-17	8	[{"id_menu":5,"count":1}]	13795	delivery	5	13
50939	2020-04-17 01:28:07	2020-04-17	14	[{"id_menu":2,"count":1}]	3314	pick-up	0	14
50940	2020-04-17 01:40:51	2020-04-17	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	7061	pick-up	0	21
50941	2020-04-17 01:42:15	2020-04-17	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1340	delivery	5	51
50942	2020-04-17 01:44:15	2020-04-17	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2341	pick-up	0	17
50943	2020-04-17 01:44:54	2020-04-17	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	7831	delivery	5	37
50944	2020-04-17 01:51:43	2020-04-17	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19566	delivery	5	34
50945	2020-04-17 01:53:26	2020-04-17	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	20460	delivery	5	23
50946	2020-04-17 01:56:24	2020-04-17	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	10772	delivery	5	26
50947	2020-04-17 02:03:12	2020-04-17	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	20320	delivery	5	31
50948	2020-04-17 02:03:41	2020-04-17	9	[{"id_menu":7,"count":1}]	1898	pick-up	0	9
50949	2020-04-17 02:03:45	2020-04-17	9	[{"id_menu":7,"count":1}]	11721	delivery	5	14
50950	2020-04-17 02:04:11	2020-04-17	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2515	pick-up	0	26
50951	2020-04-17 02:04:44	2020-04-17	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	20424	delivery	5	22
50952	2020-04-17 02:12:10	2020-04-17	17	[{"id_menu":4,"count":1}]	20445	delivery	5	22
50953	2020-04-17 02:15:28	2020-04-17	12	[{"id_menu":1,"count":1}]	20286	delivery	5	17
50954	2020-04-17 02:32:34	2020-04-17	12	[{"id_menu":3,"count":1}]	7888	delivery	5	17
50955	2020-04-17 02:37:33	2020-04-17	49	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4655	delivery	5	54
50956	2020-04-17 02:53:53	2020-04-17	12	[{"id_menu":3,"count":1}]	20330	delivery	5	17
50957	2020-04-17 02:57:56	2020-04-17	8	[{"id_menu":5,"count":1}]	18012	delivery	5	13
50958	2020-04-17 03:04:10	2020-04-17	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	20290	delivery	5	26
50959	2020-04-17 03:04:56	2020-04-17	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20352	delivery	5	36
50960	2020-04-17 03:06:03	2020-04-17	14	[{"id_menu":2,"count":1}]	2935	pick-up	0	14
50961	2020-04-17 03:06:33	2020-04-17	9	[{"id_menu":6,"count":2}]	11314	pick-up	0	9
50962	2020-04-17 03:17:42	2020-04-17	9	[{"id_menu":6,"count":1}]	20294	delivery	5	14
50963	2020-04-17 03:19:47	2020-04-17	12	[{"id_menu":1,"count":1}]	18425	pick-up	0	12
50964	2020-04-17 03:27:34	2020-04-17	9	[{"id_menu":6,"count":1}]	20338	pick-up	0	9
50965	2020-04-17 03:28:55	2020-04-17	9	[{"id_menu":6,"count":1}]	20407	delivery	5	14
50966	2020-04-17 03:42:04	2020-04-17	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1461	pick-up	0	17
50967	2020-04-17 03:45:48	2020-04-17	12	[{"id_menu":3,"count":1}]	3877	pick-up	0	12
50968	2020-04-17 03:51:19	2020-04-17	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	20356	delivery	5	30
50969	2020-04-17 03:56:08	2020-04-17	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2733	delivery	5	43
50970	2020-04-17 03:58:22	2020-04-17	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5768	delivery	5	39
50971	2020-04-17 04:02:14	2020-04-17	12	[{"id_menu":1,"count":1}]	6173	delivery	5	17
50972	2020-04-17 04:04:04	2020-04-17	8	[{"id_menu":5,"count":1}]	17392	pick-up	0	8
50973	2020-04-17 04:11:18	2020-04-17	9	[{"id_menu":6,"count":1}]	20426	delivery	5	14
50974	2020-04-17 04:12:45	2020-04-17	8	[{"id_menu":5,"count":1}]	20325	delivery	5	13
50975	2020-04-17 04:16:01	2020-04-17	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	20331	delivery	5	31
50976	2020-04-17 04:28:37	2020-04-17	9	[{"id_menu":6,"count":1}]	1375	pick-up	0	9
50977	2020-04-17 04:30:34	2020-04-17	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	17641	pick-up	0	22
50978	2020-04-17 04:31:01	2020-04-17	8	[{"id_menu":5,"count":1}]	4445	pick-up	0	8
50979	2020-04-17 04:32:56	2020-04-17	12	[{"id_menu":3,"count":1}]	10475	delivery	5	17
50980	2020-04-17 04:45:56	2020-04-17	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	9305	delivery	5	26
50981	2020-04-17 04:46:15	2020-04-17	9	[{"id_menu":7,"count":1}]	11783	delivery	5	14
50982	2020-04-17 04:51:47	2020-04-17	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7017	pick-up	0	31
50983	2020-04-17 04:52:52	2020-04-17	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	20442	delivery	5	26
50984	2020-04-17 05:05:20	2020-04-17	9	[{"id_menu":7,"count":1}]	20396	delivery	5	14
50985	2020-04-17 05:06:25	2020-04-17	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	18172	delivery	5	31
50986	2020-04-17 05:23:28	2020-04-17	8	[{"id_menu":5,"count":1}]	12531	delivery	5	13
50987	2020-04-17 05:28:54	2020-04-17	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	8592	delivery	5	26
50988	2020-04-17 05:29:44	2020-04-17	9	[{"id_menu":6,"count":1}]	754	pick-up	0	9
50989	2020-04-17 05:36:03	2020-04-17	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	20346	delivery	5	52
50990	2020-04-17 05:46:08	2020-04-17	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	20384	delivery	5	26
50991	2020-04-17 05:47:15	2020-04-17	8	[{"id_menu":5,"count":1}]	8367	delivery	5	13
50992	2020-04-17 05:47:23	2020-04-17	9	[{"id_menu":7,"count":1}]	20380	delivery	5	14
50993	2020-04-17 05:49:53	2020-04-17	8	[{"id_menu":5,"count":1}]	8902	pick-up	0	8
50994	2020-04-17 05:56:30	2020-04-17	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	20355	delivery	5	43
50995	2020-04-17 05:57:12	2020-04-17	12	[{"id_menu":1,"count":1}]	9931	pick-up	0	12
50996	2020-04-17 06:00:40	2020-04-17	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	15215	delivery	5	52
50997	2020-04-17 06:05:17	2020-04-17	9	[{"id_menu":7,"count":1}]	20382	delivery	5	14
50998	2020-04-17 06:07:15	2020-04-17	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	20285	delivery	5	45
50999	2020-04-17 06:12:17	2020-04-17	9	[{"id_menu":6,"count":1}]	18422	pick-up	0	9
51000	2020-04-17 06:12:21	2020-04-17	8	[{"id_menu":5,"count":1}]	18847	delivery	5	13
51001	2020-04-17 06:12:46	2020-04-17	17	[{"id_menu":5,"count":3},{"id_menu":7,"count":1}]	18771	delivery	5	22
51002	2020-04-17 06:12:57	2020-04-17	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	20329	delivery	5	26
51003	2020-04-17 06:14:04	2020-04-17	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	20451	delivery	5	26
51004	2020-04-17 06:17:33	2020-04-17	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	20369	delivery	5	28
51005	2020-04-17 06:19:21	2020-04-17	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	111	pick-up	0	20
51006	2020-04-17 06:22:16	2020-04-17	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7857	delivery	5	34
51007	2020-04-17 06:25:13	2020-04-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3278	delivery	5	23
51008	2020-04-17 06:28:11	2020-04-17	9	[{"id_menu":7,"count":2}]	20420	delivery	5	14
51009	2020-04-17 06:28:31	2020-04-17	12	[{"id_menu":1,"count":1}]	4629	delivery	5	17
51010	2020-04-17 06:28:39	2020-04-17	9	[{"id_menu":7,"count":1}]	20350	delivery	5	14
51011	2020-04-17 06:28:54	2020-04-17	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	20357	pick-up	0	20
51012	2020-04-17 06:29:11	2020-04-17	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	143	pick-up	0	40
51013	2020-04-17 06:31:44	2020-04-17	17	[{"id_menu":4,"count":1}]	6551	delivery	5	22
51014	2020-04-17 06:36:52	2020-04-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	20328	pick-up	0	23
51015	2020-04-17 06:40:18	2020-04-17	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20455	delivery	5	37
51016	2020-04-17 06:42:58	2020-04-17	12	[{"id_menu":1,"count":1}]	20297	delivery	5	17
51017	2020-04-17 06:52:41	2020-04-17	8	[{"id_menu":5,"count":1}]	20425	delivery	5	13
51018	2020-04-17 06:55:48	2020-04-17	9	[{"id_menu":6,"count":1}]	17640	delivery	5	14
51019	2020-04-17 06:56:49	2020-04-17	8	[{"id_menu":5,"count":1}]	20287	delivery	5	13
51020	2020-04-17 06:58:01	2020-04-17	8	[{"id_menu":5,"count":1}]	2772	delivery	5	13
51021	2020-04-17 07:00:01	2020-04-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	13400	pick-up	0	23
51022	2020-04-17 07:02:00	2020-04-17	12	[{"id_menu":1,"count":1}]	7686	delivery	5	17
51023	2020-04-17 07:03:10	2020-04-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1687	pick-up	0	23
51024	2020-04-17 07:03:16	2020-04-17	9	[{"id_menu":7,"count":1}]	20432	delivery	5	14
51025	2020-04-17 07:03:28	2020-04-17	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	20372	delivery	5	34
51026	2020-04-17 07:09:20	2020-04-17	9	[{"id_menu":6,"count":1}]	15368	delivery	5	14
51027	2020-04-17 07:12:29	2020-04-17	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	19485	delivery	5	40
51028	2020-04-17 07:24:05	2020-04-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8041	delivery	5	31
51029	2020-04-17 07:27:14	2020-04-17	12	[{"id_menu":3,"count":1}]	4132	pick-up	0	12
51030	2020-04-17 07:29:40	2020-04-17	17	[{"id_menu":4,"count":1}]	4315	pick-up	0	17
51031	2020-04-17 07:35:33	2020-04-17	8	[{"id_menu":5,"count":1}]	20374	delivery	5	13
51032	2020-04-17 07:35:37	2020-04-17	8	[{"id_menu":5,"count":1}]	5110	delivery	5	13
51033	2020-04-17 07:39:08	2020-04-17	9	[{"id_menu":7,"count":1}]	20404	pick-up	0	9
51034	2020-04-17 07:40:07	2020-04-17	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9287	delivery	5	39
51035	2020-04-17 07:42:44	2020-04-17	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10070	delivery	5	34
51036	2020-04-17 07:58:20	2020-04-17	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	149	delivery	5	34
51037	2020-04-17 08:02:08	2020-04-17	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6369	pick-up	0	35
51038	2020-04-17 08:06:06	2020-04-17	8	[{"id_menu":5,"count":1}]	19051	delivery	5	13
51039	2020-04-17 08:06:40	2020-04-17	14	[{"id_menu":2,"count":1}]	20361	pick-up	0	14
51040	2020-04-17 08:10:39	2020-04-17	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20333	delivery	5	31
51041	2020-04-17 08:13:59	2020-04-17	9	[{"id_menu":6,"count":1}]	20413	pick-up	0	9
51042	2020-04-17 08:15:16	2020-04-17	9	[{"id_menu":6,"count":1}]	20316	delivery	5	14
51043	2020-04-17 08:18:31	2020-04-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2774	delivery	5	28
51044	2020-04-17 08:25:21	2020-04-17	8	[{"id_menu":5,"count":1}]	7772	pick-up	0	8
51045	2020-04-17 08:28:39	2020-04-17	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	20443	delivery	5	34
51046	2020-04-17 08:34:05	2020-04-17	9	[{"id_menu":7,"count":1}]	12162	pick-up	0	9
51047	2020-04-17 08:36:09	2020-04-17	12	[{"id_menu":3,"count":1}]	20391	pick-up	0	12
51048	2020-04-17 08:37:31	2020-04-17	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	17636	delivery	5	26
51049	2020-04-17 08:41:08	2020-04-17	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7109	delivery	5	34
51050	2020-04-17 08:43:30	2020-04-17	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	20392	delivery	5	43
51051	2020-04-17 08:48:50	2020-04-17	12	[{"id_menu":1,"count":1}]	15579	delivery	5	17
51052	2020-04-17 08:51:28	2020-04-17	12	[{"id_menu":1,"count":1}]	9707	pick-up	0	12
51053	2020-04-17 08:55:51	2020-04-17	9	[{"id_menu":6,"count":1}]	17443	delivery	5	14
51054	2020-04-17 09:00:12	2020-04-17	14	[{"id_menu":2,"count":1}]	6711	delivery	5	19
51055	2020-04-17 09:01:31	2020-04-17	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20458	delivery	5	48
51056	2020-04-17 09:02:48	2020-04-17	9	[{"id_menu":7,"count":1}]	20323	delivery	5	14
51057	2020-04-17 09:09:02	2020-04-17	9	[{"id_menu":7,"count":1}]	20326	delivery	5	14
51058	2020-04-17 09:09:19	2020-04-17	12	[{"id_menu":1,"count":1}]	8173	delivery	5	17
51059	2020-04-17 09:10:23	2020-04-17	9	[{"id_menu":6,"count":1}]	20292	delivery	5	14
51060	2020-04-17 09:28:09	2020-04-17	12	[{"id_menu":3,"count":1}]	4929	pick-up	0	12
51061	2020-04-17 09:31:29	2020-04-17	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8556	delivery	5	51
51062	2020-04-17 09:32:07	2020-04-17	9	[{"id_menu":7,"count":1}]	20309	delivery	5	14
51063	2020-04-17 09:32:40	2020-04-17	9	[{"id_menu":7,"count":1}]	11407	pick-up	0	9
51064	2020-04-17 09:33:07	2020-04-17	12	[{"id_menu":1,"count":1}]	11227	delivery	5	17
51065	2020-04-17 09:33:41	2020-04-17	14	[{"id_menu":2,"count":1}]	14134	delivery	5	19
51196	2020-04-17 17:45:57	2020-04-17	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	20317	delivery	5	22
51066	2020-04-17 09:33:42	2020-04-17	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	19596	delivery	5	36
51067	2020-04-17 09:34:13	2020-04-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	184	pick-up	0	23
51068	2020-04-17 09:42:51	2020-04-17	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20427	delivery	5	43
51069	2020-04-17 09:47:42	2020-04-17	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18220	delivery	5	53
51070	2020-04-17 10:06:35	2020-04-17	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	17654	delivery	5	27
51071	2020-04-17 10:09:16	2020-04-17	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	11039	delivery	5	29
51072	2020-04-17 10:10:42	2020-04-17	17	[{"id_menu":4,"count":1}]	20430	delivery	5	22
51073	2020-04-17 10:11:28	2020-04-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20340	delivery	5	23
51074	2020-04-17 10:12:54	2020-04-17	9	[{"id_menu":6,"count":1}]	20449	delivery	5	14
51075	2020-04-17 10:20:02	2020-04-17	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	20417	delivery	5	43
51076	2020-04-17 10:20:44	2020-04-17	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	14964	delivery	5	38
51077	2020-04-17 10:20:57	2020-04-17	14	[{"id_menu":2,"count":1}]	95	pick-up	0	14
51078	2020-04-17 10:21:49	2020-04-17	9	[{"id_menu":6,"count":3}]	10576	delivery	5	14
51079	2020-04-17 10:22:11	2020-04-17	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20322	delivery	5	39
51080	2020-04-17 10:26:55	2020-04-17	9	[{"id_menu":6,"count":2}]	13424	delivery	5	14
51081	2020-04-17 10:28:20	2020-04-17	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	11625	delivery	5	48
51082	2020-04-17 10:31:21	2020-04-17	12	[{"id_menu":1,"count":1}]	4090	pick-up	0	12
51083	2020-04-17 10:35:02	2020-04-17	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6439	delivery	5	36
51084	2020-04-17 10:51:18	2020-04-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	11464	delivery	5	28
51085	2020-04-17 10:53:15	2020-04-17	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	12697	delivery	5	56
51086	2020-04-17 10:58:36	2020-04-17	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1415	pick-up	0	25
51087	2020-04-17 11:06:19	2020-04-17	8	[{"id_menu":5,"count":1}]	10503	delivery	5	13
51088	2020-04-17 11:08:32	2020-04-17	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8126	delivery	5	40
51089	2020-04-17 11:14:38	2020-04-17	12	[{"id_menu":1,"count":1}]	8884	delivery	5	17
51090	2020-04-17 11:20:05	2020-04-17	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	9014	delivery	5	27
51091	2020-04-17 11:26:21	2020-04-17	9	[{"id_menu":7,"count":1}]	20393	delivery	5	14
51092	2020-04-17 11:28:21	2020-04-17	17	[{"id_menu":4,"count":1}]	20383	delivery	5	22
51093	2020-04-17 11:28:46	2020-04-17	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	20149	delivery	5	26
51094	2020-04-17 11:37:37	2020-04-17	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1722	pick-up	0	21
51095	2020-04-17 11:39:59	2020-04-17	8	[{"id_menu":5,"count":1}]	18584	delivery	5	13
51096	2020-04-17 11:44:02	2020-04-17	17	[{"id_menu":4,"count":1}]	11498	delivery	5	22
51097	2020-04-17 11:45:15	2020-04-17	9	[{"id_menu":6,"count":1}]	15128	delivery	5	14
51098	2020-04-17 11:49:02	2020-04-17	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2892	pick-up	0	26
51099	2020-04-17 11:52:51	2020-04-17	17	[{"id_menu":4,"count":1}]	20389	delivery	5	22
51100	2020-04-17 12:04:55	2020-04-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	20373	pick-up	0	26
51101	2020-04-17 12:10:00	2020-04-17	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	20414	delivery	5	28
51102	2020-04-17 12:14:15	2020-04-17	14	[{"id_menu":2,"count":1}]	14720	delivery	5	19
51103	2020-04-17 12:14:52	2020-04-17	8	[{"id_menu":5,"count":1}]	20401	delivery	5	13
51104	2020-04-17 12:14:52	2020-04-17	12	[{"id_menu":3,"count":3}]	1574	pick-up	0	12
51105	2020-04-17 12:17:27	2020-04-17	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	18316	pick-up	0	21
51106	2020-04-17 12:17:30	2020-04-17	9	[{"id_menu":6,"count":1}]	20387	delivery	5	14
51107	2020-04-17 12:24:46	2020-04-17	14	[{"id_menu":2,"count":1}]	14483	delivery	5	19
51108	2020-04-17 12:26:03	2020-04-17	9	[{"id_menu":6,"count":1}]	4728	delivery	5	14
51109	2020-04-17 12:26:22	2020-04-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	20298	delivery	5	31
51110	2020-04-17 12:29:49	2020-04-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2051	delivery	5	31
51111	2020-04-17 12:30:51	2020-04-17	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	20321	delivery	5	34
51112	2020-04-17 12:31:52	2020-04-17	8	[{"id_menu":5,"count":1}]	2509	pick-up	0	8
51113	2020-04-17 12:36:53	2020-04-17	30	[{"id_menu":1,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20394	delivery	5	35
51114	2020-04-17 12:37:32	2020-04-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20314	delivery	5	23
51115	2020-04-17 12:47:53	2020-04-17	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	9565	delivery	5	23
51116	2020-04-17 12:50:48	2020-04-17	8	[{"id_menu":5,"count":1}]	20447	delivery	5	13
51117	2020-04-17 13:00:47	2020-04-17	9	[{"id_menu":7,"count":1}]	1565	delivery	5	14
51118	2020-04-17 13:01:45	2020-04-17	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	20381	delivery	5	26
51119	2020-04-17 13:04:03	2020-04-17	9	[{"id_menu":6,"count":2}]	20360	delivery	5	14
51120	2020-04-17 13:04:05	2020-04-17	9	[{"id_menu":6,"count":1}]	20371	delivery	5	14
51121	2020-04-17 13:09:26	2020-04-17	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	18209	delivery	5	27
51122	2020-04-17 13:09:58	2020-04-17	14	[{"id_menu":2,"count":1}]	19029	delivery	5	19
51123	2020-04-17 13:11:17	2020-04-17	14	[{"id_menu":2,"count":1}]	2143	pick-up	0	14
51124	2020-04-17 13:12:11	2020-04-17	9	[{"id_menu":7,"count":1}]	19139	delivery	5	14
51125	2020-04-17 13:21:49	2020-04-17	8	[{"id_menu":5,"count":1}]	9043	delivery	5	13
51126	2020-04-17 13:29:00	2020-04-17	14	[{"id_menu":2,"count":1}]	8640	delivery	5	19
51127	2020-04-17 13:30:58	2020-04-17	9	[{"id_menu":7,"count":1}]	11712	delivery	5	14
51128	2020-04-17 13:38:15	2020-04-17	12	[{"id_menu":1,"count":1}]	20431	pick-up	0	12
51129	2020-04-17 13:43:26	2020-04-17	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14931	delivery	5	39
51130	2020-04-17 13:59:55	2020-04-17	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	17207	delivery	5	39
51131	2020-04-17 14:00:10	2020-04-17	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9107	pick-up	0	25
51132	2020-04-17 14:00:48	2020-04-17	9	[{"id_menu":6,"count":1}]	17436	delivery	5	14
51133	2020-04-17 14:04:24	2020-04-17	8	[{"id_menu":5,"count":1}]	18090	delivery	5	13
51134	2020-04-17 14:08:37	2020-04-17	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	10254	delivery	5	26
51135	2020-04-17 14:11:56	2020-04-17	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18004	delivery	5	22
51136	2020-04-17 14:13:59	2020-04-17	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3268	pick-up	0	31
51137	2020-04-17 14:16:22	2020-04-17	17	[{"id_menu":4,"count":1}]	5680	delivery	5	22
51138	2020-04-17 14:20:01	2020-04-17	12	[{"id_menu":3,"count":1}]	15361	delivery	5	17
51139	2020-04-17 14:25:35	2020-04-17	9	[{"id_menu":6,"count":1}]	20315	delivery	5	14
51140	2020-04-17 14:25:51	2020-04-17	9	[{"id_menu":7,"count":1}]	12169	delivery	5	14
51141	2020-04-17 14:30:54	2020-04-17	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	20363	delivery	5	31
51142	2020-04-17 14:49:46	2020-04-17	9	[{"id_menu":6,"count":1}]	5204	delivery	5	14
51143	2020-04-17 14:53:18	2020-04-17	9	[{"id_menu":7,"count":1}]	20304	delivery	5	14
51144	2020-04-17 14:53:24	2020-04-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	20289	delivery	5	28
51145	2020-04-17 14:53:35	2020-04-17	12	[{"id_menu":3,"count":2}]	12228	delivery	5	17
51146	2020-04-17 14:56:27	2020-04-17	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	20349	delivery	5	26
51147	2020-04-17 15:01:02	2020-04-17	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	14735	pick-up	0	33
51148	2020-04-17 15:02:36	2020-04-17	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11723	delivery	5	36
51149	2020-04-17 15:07:34	2020-04-17	9	[{"id_menu":6,"count":1}]	1618	pick-up	0	9
51150	2020-04-17 15:20:27	2020-04-17	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5403	delivery	5	43
51151	2020-04-17 15:22:06	2020-04-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	9816	pick-up	0	26
51152	2020-04-17 15:24:02	2020-04-17	9	[{"id_menu":6,"count":1}]	408	pick-up	0	9
51153	2020-04-17 15:25:28	2020-04-17	17	[{"id_menu":4,"count":1}]	20418	delivery	5	22
51154	2020-04-17 15:25:51	2020-04-17	9	[{"id_menu":7,"count":1}]	12739	delivery	5	14
51155	2020-04-17 15:26:10	2020-04-17	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	20344	delivery	5	34
51156	2020-04-17 15:29:53	2020-04-17	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18849	delivery	5	34
51157	2020-04-17 15:34:49	2020-04-17	17	[{"id_menu":4,"count":1}]	20280	delivery	5	22
51158	2020-04-17 15:43:27	2020-04-17	14	[{"id_menu":2,"count":1}]	20288	delivery	5	19
51159	2020-04-17 15:51:25	2020-04-17	12	[{"id_menu":1,"count":1}]	14668	delivery	5	17
51160	2020-04-17 15:52:55	2020-04-17	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	20410	delivery	5	40
51161	2020-04-17 15:53:34	2020-04-17	17	[{"id_menu":4,"count":1}]	19082	delivery	5	22
51162	2020-04-17 15:55:45	2020-04-17	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	20282	delivery	5	26
51163	2020-04-17 15:56:32	2020-04-17	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	6763	delivery	5	31
51164	2020-04-17 15:59:26	2020-04-17	12	[{"id_menu":3,"count":1}]	20291	delivery	5	17
51165	2020-04-17 16:01:04	2020-04-17	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	16254	delivery	5	42
51166	2020-04-17 16:03:16	2020-04-17	17	[{"id_menu":4,"count":1}]	18148	delivery	5	22
51167	2020-04-17 16:04:12	2020-04-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20336	delivery	5	23
51168	2020-04-17 16:09:10	2020-04-17	14	[{"id_menu":2,"count":1}]	20342	delivery	5	19
51169	2020-04-17 16:10:00	2020-04-17	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12192	delivery	5	45
51170	2020-04-17 16:10:04	2020-04-17	9	[{"id_menu":7,"count":1}]	4973	pick-up	0	9
51171	2020-04-17 16:10:13	2020-04-17	9	[{"id_menu":6,"count":1}]	20348	delivery	5	14
51172	2020-04-17 16:13:33	2020-04-17	8	[{"id_menu":5,"count":1}]	16828	delivery	5	13
51173	2020-04-17 16:16:25	2020-04-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	20436	delivery	5	28
51174	2020-04-17 16:20:21	2020-04-17	9	[{"id_menu":7,"count":1}]	10798	pick-up	0	9
51175	2020-04-17 16:21:29	2020-04-17	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5094	pick-up	0	40
51176	2020-04-17 16:36:22	2020-04-17	8	[{"id_menu":5,"count":1}]	20421	delivery	5	13
51177	2020-04-17 16:41:30	2020-04-17	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	20428	delivery	5	36
51178	2020-04-17 16:44:26	2020-04-17	8	[{"id_menu":5,"count":1}]	5945	pick-up	0	8
51179	2020-04-17 16:45:22	2020-04-17	14	[{"id_menu":2,"count":1}]	20408	delivery	5	19
51180	2020-04-17 16:45:37	2020-04-17	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	5701	delivery	5	26
51181	2020-04-17 16:47:59	2020-04-17	8	[{"id_menu":5,"count":1}]	2821	delivery	5	13
51182	2020-04-17 16:48:06	2020-04-17	12	[{"id_menu":1,"count":2}]	10365	delivery	5	17
51183	2020-04-17 16:53:57	2020-04-17	17	[{"id_menu":4,"count":1}]	16446	delivery	5	22
51184	2020-04-17 16:55:46	2020-04-17	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	20060	delivery	5	31
51185	2020-04-17 16:57:26	2020-04-17	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	874	delivery	5	29
51186	2020-04-17 17:13:15	2020-04-17	17	[{"id_menu":4,"count":1}]	3748	delivery	5	22
51187	2020-04-17 17:17:18	2020-04-17	12	[{"id_menu":1,"count":1}]	20441	delivery	5	17
51188	2020-04-17 17:18:07	2020-04-17	9	[{"id_menu":6,"count":1}]	16654	delivery	5	14
51189	2020-04-17 17:18:38	2020-04-17	9	[{"id_menu":6,"count":1}]	20461	pick-up	0	9
51190	2020-04-17 17:19:02	2020-04-17	8	[{"id_menu":5,"count":1}]	20306	pick-up	0	8
51191	2020-04-17 17:19:05	2020-04-17	17	[{"id_menu":4,"count":1}]	7923	delivery	5	22
51192	2020-04-17 17:21:56	2020-04-17	14	[{"id_menu":2,"count":1}]	20409	delivery	5	19
51193	2020-04-17 17:25:51	2020-04-17	17	[{"id_menu":4,"count":1}]	7399	delivery	5	22
51194	2020-04-17 17:27:59	2020-04-17	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	20370	delivery	5	38
51195	2020-04-17 17:41:12	2020-04-17	23	[{"id_menu":2,"count":3},{"id_menu":6,"count":1}]	20446	delivery	5	28
51197	2020-04-17 17:47:42	2020-04-17	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	20412	delivery	5	36
51198	2020-04-17 17:48:34	2020-04-17	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	10452	pick-up	0	23
51199	2020-04-17 17:51:48	2020-04-17	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	20375	delivery	5	37
51200	2020-04-17 17:52:54	2020-04-17	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10364	delivery	5	36
51201	2020-04-17 18:00:11	2020-04-17	9	[{"id_menu":6,"count":1}]	20437	delivery	5	14
51202	2020-04-17 18:01:23	2020-04-17	9	[{"id_menu":7,"count":1}]	7361	pick-up	0	9
51203	2020-04-17 18:02:23	2020-04-17	17	[{"id_menu":4,"count":1}]	16907	delivery	5	22
51204	2020-04-17 18:06:25	2020-04-17	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	4120	delivery	5	22
51205	2020-04-17 18:10:30	2020-04-17	12	[{"id_menu":1,"count":1}]	20368	delivery	5	17
51206	2020-04-17 18:15:17	2020-04-17	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5144	pick-up	0	26
51207	2020-04-17 18:17:51	2020-04-17	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	20399	delivery	5	40
51208	2020-04-17 18:17:53	2020-04-17	9	[{"id_menu":7,"count":1}]	11493	pick-up	0	9
51209	2020-04-17 18:18:26	2020-04-17	12	[{"id_menu":3,"count":2}]	1836	pick-up	0	12
51210	2020-04-17 18:21:17	2020-04-17	12	[{"id_menu":3,"count":1}]	11518	pick-up	0	12
51211	2020-04-17 18:24:07	2020-04-17	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7391	delivery	5	40
51212	2020-04-17 18:30:11	2020-04-17	9	[{"id_menu":6,"count":1}]	20293	pick-up	0	9
51213	2020-04-17 18:32:53	2020-04-17	12	[{"id_menu":1,"count":1}]	20353	delivery	5	17
51214	2020-04-17 18:33:18	2020-04-17	17	[{"id_menu":4,"count":1}]	20347	delivery	5	22
51215	2020-04-17 18:34:01	2020-04-17	12	[{"id_menu":1,"count":1}]	9354	pick-up	0	12
51216	2020-04-17 18:34:02	2020-04-17	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	20305	delivery	5	31
51217	2020-04-17 18:34:39	2020-04-17	9	[{"id_menu":6,"count":1}]	1481	delivery	5	14
51218	2020-04-17 18:38:43	2020-04-17	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3439	pick-up	0	26
51219	2020-04-17 18:40:08	2020-04-17	9	[{"id_menu":6,"count":3}]	5509	delivery	5	14
51220	2020-04-17 18:41:47	2020-04-17	9	[{"id_menu":7,"count":1}]	4020	delivery	5	14
51221	2020-04-17 18:44:03	2020-04-17	17	[{"id_menu":4,"count":1}]	20385	delivery	5	22
51222	2020-04-17 18:44:26	2020-04-17	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	20284	delivery	5	45
51223	2020-04-17 18:44:49	2020-04-17	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	7213	delivery	5	31
51224	2020-04-17 18:48:35	2020-04-17	14	[{"id_menu":2,"count":1}]	20386	pick-up	0	14
51225	2020-04-17 18:51:44	2020-04-17	14	[{"id_menu":2,"count":1}]	20411	delivery	5	19
51226	2020-04-17 18:54:25	2020-04-17	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	11119	delivery	5	30
51227	2020-04-17 18:56:21	2020-04-17	9	[{"id_menu":6,"count":1}]	5903	delivery	5	14
51228	2020-04-17 18:57:59	2020-04-17	9	[{"id_menu":6,"count":1}]	18108	delivery	5	14
51229	2020-04-17 18:58:26	2020-04-17	9	[{"id_menu":6,"count":1}]	9881	delivery	5	14
51230	2020-04-17 18:59:06	2020-04-17	17	[{"id_menu":4,"count":1}]	19243	pick-up	0	17
51231	2020-04-17 18:59:56	2020-04-17	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	20422	delivery	5	38
51232	2020-04-17 19:00:42	2020-04-17	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	20395	delivery	5	31
51233	2020-04-17 19:02:57	2020-04-17	9	[{"id_menu":7,"count":1}]	14245	pick-up	0	9
51234	2020-04-17 19:05:11	2020-04-17	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	20452	delivery	5	26
51235	2020-04-17 19:08:17	2020-04-17	9	[{"id_menu":6,"count":1}]	3649	delivery	5	14
51236	2020-04-17 19:08:40	2020-04-17	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	18756	delivery	5	26
51237	2020-04-17 19:09:59	2020-04-17	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9237	pick-up	0	32
51238	2020-04-17 19:10:05	2020-04-17	9	[{"id_menu":6,"count":1}]	18408	delivery	5	14
51239	2020-04-17 19:13:37	2020-04-17	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	10903	delivery	5	37
51240	2020-04-17 19:24:59	2020-04-17	14	[{"id_menu":2,"count":1}]	20283	delivery	5	19
51241	2020-04-17 19:28:01	2020-04-17	9	[{"id_menu":7,"count":2}]	18170	pick-up	0	9
51242	2020-04-17 19:34:22	2020-04-17	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	12226	delivery	5	44
51243	2020-04-17 19:36:42	2020-04-17	8	[{"id_menu":5,"count":1}]	20311	delivery	5	13
51244	2020-04-17 19:49:12	2020-04-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	20313	delivery	5	28
51245	2020-04-17 19:49:33	2020-04-17	8	[{"id_menu":5,"count":1}]	20327	pick-up	0	8
51246	2020-04-17 19:52:09	2020-04-17	17	[{"id_menu":4,"count":1}]	20281	pick-up	0	17
51247	2020-04-17 19:53:58	2020-04-17	12	[{"id_menu":1,"count":1}]	20406	delivery	5	17
51248	2020-04-17 20:00:33	2020-04-17	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11754	delivery	5	31
51249	2020-04-17 20:03:13	2020-04-17	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	16993	delivery	5	23
51250	2020-04-17 20:08:44	2020-04-17	14	[{"id_menu":2,"count":1}]	14371	pick-up	0	14
51251	2020-04-17 20:09:25	2020-04-17	9	[{"id_menu":6,"count":1}]	20332	delivery	5	14
51252	2020-04-17 20:18:31	2020-04-17	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	20307	delivery	5	40
51253	2020-04-17 20:19:28	2020-04-17	17	[{"id_menu":4,"count":1}]	7814	delivery	5	22
51254	2020-04-17 20:21:15	2020-04-17	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20454	delivery	5	36
51255	2020-04-17 20:27:28	2020-04-17	9	[{"id_menu":7,"count":1}]	10011	delivery	5	14
51256	2020-04-17 20:30:04	2020-04-17	9	[{"id_menu":6,"count":3}]	20343	delivery	5	14
51257	2020-04-17 20:33:37	2020-04-17	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10145	delivery	5	43
51258	2020-04-17 20:34:24	2020-04-17	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	4279	pick-up	0	26
51259	2020-04-17 20:34:24	2020-04-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20438	delivery	5	23
51260	2020-04-17 20:39:35	2020-04-17	14	[{"id_menu":2,"count":1}]	20419	delivery	5	19
51261	2020-04-17 20:41:42	2020-04-17	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20434	delivery	5	34
51262	2020-04-17 20:44:45	2020-04-17	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20459	delivery	5	34
51263	2020-04-17 20:46:12	2020-04-17	9	[{"id_menu":6,"count":1}]	13781	delivery	5	14
51264	2020-04-17 20:48:43	2020-04-17	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	20423	delivery	5	36
51265	2020-04-17 20:53:06	2020-04-17	17	[{"id_menu":4,"count":1}]	18912	delivery	5	22
51266	2020-04-17 20:55:56	2020-04-17	14	[{"id_menu":2,"count":1}]	7988	pick-up	0	14
51267	2020-04-17 20:58:02	2020-04-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	19	pick-up	0	23
51268	2020-04-17 21:00:48	2020-04-17	9	[{"id_menu":7,"count":3}]	11624	delivery	5	14
51269	2020-04-17 21:01:36	2020-04-17	17	[{"id_menu":4,"count":1}]	12399	pick-up	0	17
51270	2020-04-17 21:02:56	2020-04-17	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	16136	delivery	5	25
51271	2020-04-17 21:04:32	2020-04-17	9	[{"id_menu":6,"count":1}]	19971	delivery	5	14
51272	2020-04-17 21:11:43	2020-04-17	9	[{"id_menu":7,"count":2}]	20450	delivery	5	14
51273	2020-04-17 21:22:44	2020-04-17	12	[{"id_menu":3,"count":2}]	12574	delivery	5	17
51274	2020-04-17 21:25:46	2020-04-17	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	4594	delivery	5	31
51275	2020-04-17 21:29:33	2020-04-17	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	20453	delivery	5	22
51276	2020-04-17 21:32:56	2020-04-17	14	[{"id_menu":2,"count":1}]	20334	delivery	5	19
51277	2020-04-17 21:32:58	2020-04-17	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	1453	delivery	5	23
51278	2020-04-17 21:36:00	2020-04-17	14	[{"id_menu":2,"count":1}]	5311	pick-up	0	14
51279	2020-04-17 21:36:37	2020-04-17	9	[{"id_menu":7,"count":1}]	9952	delivery	5	14
51280	2020-04-17 21:56:24	2020-04-17	9	[{"id_menu":7,"count":1}]	18468	delivery	5	14
51281	2020-04-17 22:14:24	2020-04-17	12	[{"id_menu":3,"count":1}]	20296	delivery	5	17
51282	2020-04-17 22:14:32	2020-04-17	9	[{"id_menu":6,"count":1}]	17501	delivery	5	14
51283	2020-04-17 22:18:27	2020-04-17	12	[{"id_menu":3,"count":1}]	11056	pick-up	0	12
51284	2020-04-17 22:19:16	2020-04-17	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1311	pick-up	0	21
51285	2020-04-17 22:20:36	2020-04-17	17	[{"id_menu":4,"count":1}]	5743	delivery	5	22
51286	2020-04-17 22:33:13	2020-04-17	12	[{"id_menu":3,"count":1}]	20303	delivery	5	17
51287	2020-04-17 22:36:40	2020-04-17	12	[{"id_menu":1,"count":1}]	10356	delivery	5	17
51288	2020-04-17 22:39:24	2020-04-17	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	20366	delivery	5	26
51289	2020-04-17 22:40:26	2020-04-17	17	[{"id_menu":4,"count":1}]	8109	delivery	5	22
51290	2020-04-17 22:42:03	2020-04-17	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3744	delivery	5	39
51291	2020-04-17 22:42:07	2020-04-17	17	[{"id_menu":4,"count":2}]	1485	pick-up	0	17
51292	2020-04-17 22:42:18	2020-04-17	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	10518	delivery	5	36
51293	2020-04-17 22:45:59	2020-04-17	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	6873	delivery	5	26
51294	2020-04-17 22:48:43	2020-04-17	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2989	pick-up	0	29
51295	2020-04-17 22:49:08	2020-04-17	9	[{"id_menu":6,"count":1}]	20362	delivery	5	14
51296	2020-04-17 22:55:36	2020-04-17	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	20345	delivery	5	22
51297	2020-04-17 22:57:52	2020-04-17	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	20429	delivery	5	38
51298	2020-04-17 22:59:38	2020-04-17	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19742	delivery	5	39
51299	2020-04-17 23:01:22	2020-04-17	12	[{"id_menu":3,"count":1}]	20301	delivery	5	17
51300	2020-04-17 23:01:49	2020-04-17	9	[{"id_menu":7,"count":2}]	20433	delivery	5	14
51301	2020-04-17 23:11:31	2020-04-17	17	[{"id_menu":4,"count":1}]	19738	delivery	5	22
51302	2020-04-17 23:12:35	2020-04-17	9	[{"id_menu":6,"count":1}]	20403	delivery	5	14
51303	2020-04-17 23:17:55	2020-04-17	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	981	pick-up	0	22
51304	2020-04-17 23:20:43	2020-04-17	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	14288	delivery	5	36
51305	2020-04-17 23:26:34	2020-04-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	13105	delivery	5	28
51306	2020-04-17 23:29:41	2020-04-17	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	9478	delivery	5	26
51307	2020-04-17 23:32:10	2020-04-17	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	2544	delivery	5	34
51308	2020-04-17 23:33:27	2020-04-17	8	[{"id_menu":5,"count":1}]	1053	pick-up	0	8
51309	2020-04-17 23:35:46	2020-04-17	9	[{"id_menu":7,"count":1}]	2104	pick-up	0	9
51310	2020-04-17 23:45:05	2020-04-17	12	[{"id_menu":3,"count":1}]	16280	pick-up	0	12
51311	2020-04-17 23:45:34	2020-04-17	8	[{"id_menu":5,"count":1}]	19882	delivery	5	13
51312	2020-04-17 23:51:52	2020-04-17	12	[{"id_menu":1,"count":1}]	20351	delivery	5	17
51313	2020-04-17 23:52:11	2020-04-17	14	[{"id_menu":2,"count":1}]	9513	delivery	5	19
51314	2020-04-17 23:56:33	2020-04-17	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	841	delivery	5	31
51315	2020-04-17 23:56:56	2020-04-17	17	[{"id_menu":4,"count":1}]	2507	delivery	5	22
51316	2020-04-17 23:57:58	2020-04-17	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	12000	delivery	5	39
51317	2020-04-18 00:05:50	2020-04-18	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	16678	delivery	5	26
51318	2020-04-18 00:10:57	2020-04-18	8	[{"id_menu":5,"count":1}]	16321	pick-up	0	8
51319	2020-04-18 00:14:36	2020-04-18	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1571	pick-up	0	31
51320	2020-04-18 00:14:42	2020-04-18	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	16962	delivery	5	26
51321	2020-04-18 00:21:00	2020-04-18	17	[{"id_menu":4,"count":1}]	20496	delivery	5	22
51322	2020-04-18 00:21:36	2020-04-18	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20500	delivery	5	34
51323	2020-04-18 00:26:31	2020-04-18	14	[{"id_menu":2,"count":2}]	13257	delivery	5	19
51324	2020-04-18 00:27:32	2020-04-18	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	17038	delivery	5	38
51325	2020-04-18 00:34:48	2020-04-18	14	[{"id_menu":2,"count":1}]	3425	pick-up	0	14
51326	2020-04-18 00:41:19	2020-04-18	12	[{"id_menu":3,"count":1}]	16571	pick-up	0	12
51327	2020-04-18 00:43:49	2020-04-18	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5097	delivery	5	45
51328	2020-04-18 00:48:57	2020-04-18	17	[{"id_menu":4,"count":1}]	1393	delivery	5	22
51329	2020-04-18 00:52:22	2020-04-18	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20567	delivery	5	31
51330	2020-04-18 00:52:29	2020-04-18	8	[{"id_menu":5,"count":1}]	18125	delivery	5	13
51331	2020-04-18 01:02:10	2020-04-18	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	826	pick-up	0	21
51332	2020-04-18 01:11:40	2020-04-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17106	delivery	5	23
51333	2020-04-18 01:13:12	2020-04-18	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1900	pick-up	0	26
51334	2020-04-18 01:15:21	2020-04-18	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12018	delivery	5	34
51335	2020-04-18 01:32:39	2020-04-18	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1824	delivery	5	35
51336	2020-04-18 01:33:04	2020-04-18	8	[{"id_menu":5,"count":1}]	20613	delivery	5	13
51337	2020-04-18 01:34:22	2020-04-18	12	[{"id_menu":3,"count":1}]	2817	pick-up	0	12
51338	2020-04-18 01:37:34	2020-04-18	14	[{"id_menu":2,"count":1}]	15216	pick-up	0	14
51339	2020-04-18 01:40:22	2020-04-18	9	[{"id_menu":7,"count":1}]	19507	delivery	5	14
51340	2020-04-18 01:50:38	2020-04-18	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7007	delivery	5	35
51341	2020-04-18 01:51:13	2020-04-18	9	[{"id_menu":7,"count":1}]	18228	pick-up	0	9
51342	2020-04-18 01:57:18	2020-04-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20572	delivery	5	23
51343	2020-04-18 02:01:38	2020-04-18	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	20553	delivery	5	27
51344	2020-04-18 02:02:45	2020-04-18	8	[{"id_menu":5,"count":1}]	7595	pick-up	0	8
51345	2020-04-18 02:04:48	2020-04-18	12	[{"id_menu":1,"count":1}]	15361	pick-up	0	12
51346	2020-04-18 02:05:31	2020-04-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	18137	delivery	5	22
51347	2020-04-18 02:11:16	2020-04-18	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1654	pick-up	0	38
51348	2020-04-18 02:13:09	2020-04-18	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2333	pick-up	0	26
51349	2020-04-18 02:13:11	2020-04-18	14	[{"id_menu":2,"count":1}]	2194	pick-up	0	14
51350	2020-04-18 02:15:48	2020-04-18	9	[{"id_menu":7,"count":1}]	20515	pick-up	0	9
51351	2020-04-18 02:16:30	2020-04-18	17	[{"id_menu":4,"count":1}]	18229	pick-up	0	17
51352	2020-04-18 02:18:34	2020-04-18	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	20311	delivery	5	25
51353	2020-04-18 02:18:53	2020-04-18	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	9001	delivery	5	43
51354	2020-04-18 02:27:17	2020-04-18	12	[{"id_menu":3,"count":1}]	20575	delivery	5	17
51355	2020-04-18 02:27:33	2020-04-18	12	[{"id_menu":1,"count":1}]	6873	delivery	5	17
51356	2020-04-18 02:27:42	2020-04-18	14	[{"id_menu":2,"count":1}]	20525	delivery	5	19
51357	2020-04-18 02:29:26	2020-04-18	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	20590	delivery	5	44
51358	2020-04-18 02:31:22	2020-04-18	14	[{"id_menu":2,"count":1}]	19212	pick-up	0	14
51359	2020-04-18 02:33:52	2020-04-18	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	17884	delivery	5	44
51360	2020-04-18 02:37:48	2020-04-18	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20586	delivery	5	37
51361	2020-04-18 02:47:58	2020-04-18	9	[{"id_menu":7,"count":1}]	20480	delivery	5	14
51362	2020-04-18 02:49:08	2020-04-18	9	[{"id_menu":6,"count":1}]	81	pick-up	0	9
51363	2020-04-18 02:56:28	2020-04-18	12	[{"id_menu":3,"count":1}]	10819	pick-up	0	12
51364	2020-04-18 02:57:24	2020-04-18	9	[{"id_menu":6,"count":1}]	13120	pick-up	0	9
51365	2020-04-18 03:03:15	2020-04-18	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	20474	delivery	5	25
51366	2020-04-18 03:06:17	2020-04-18	12	[{"id_menu":3,"count":1}]	18622	delivery	5	17
51367	2020-04-18 03:07:03	2020-04-18	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20592	delivery	5	43
51368	2020-04-18 03:11:44	2020-04-18	9	[{"id_menu":7,"count":1}]	20473	delivery	5	14
51369	2020-04-18 03:22:21	2020-04-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	5885	delivery	5	28
51370	2020-04-18 03:22:34	2020-04-18	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	13311	delivery	5	31
51371	2020-04-18 03:23:13	2020-04-18	9	[{"id_menu":7,"count":1}]	12743	delivery	5	14
51372	2020-04-18 03:29:05	2020-04-18	8	[{"id_menu":5,"count":1}]	20564	delivery	5	13
51373	2020-04-18 03:29:07	2020-04-18	9	[{"id_menu":6,"count":1}]	16026	delivery	5	14
51374	2020-04-18 03:29:47	2020-04-18	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14256	delivery	5	45
51375	2020-04-18 03:30:32	2020-04-18	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	2721	delivery	5	31
51376	2020-04-18 03:31:30	2020-04-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	32	pick-up	0	23
51377	2020-04-18 03:41:22	2020-04-18	14	[{"id_menu":2,"count":1}]	12941	delivery	5	19
51378	2020-04-18 03:45:07	2020-04-18	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14491	delivery	5	48
51379	2020-04-18 03:54:11	2020-04-18	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13914	delivery	5	36
51380	2020-04-18 04:00:21	2020-04-18	12	[{"id_menu":1,"count":1}]	3614	pick-up	0	12
51381	2020-04-18 04:03:51	2020-04-18	14	[{"id_menu":2,"count":1}]	15513	delivery	5	19
51382	2020-04-18 04:07:16	2020-04-18	12	[{"id_menu":1,"count":1}]	16083	delivery	5	17
51383	2020-04-18 04:10:25	2020-04-18	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	20490	delivery	5	26
51384	2020-04-18 04:23:01	2020-04-18	17	[{"id_menu":4,"count":2}]	3447	pick-up	0	17
51385	2020-04-18 04:25:17	2020-04-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15896	delivery	5	23
51386	2020-04-18 04:27:02	2020-04-18	9	[{"id_menu":6,"count":1}]	20534	delivery	5	14
51387	2020-04-18 04:27:54	2020-04-18	9	[{"id_menu":7,"count":1}]	19573	delivery	5	14
51388	2020-04-18 04:30:01	2020-04-18	9	[{"id_menu":6,"count":1}]	4888	delivery	5	14
51389	2020-04-18 04:32:41	2020-04-18	9	[{"id_menu":7,"count":2}]	20495	delivery	5	14
51390	2020-04-18 04:35:17	2020-04-18	14	[{"id_menu":2,"count":1}]	10435	delivery	5	19
51391	2020-04-18 04:39:59	2020-04-18	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1306	pick-up	0	26
51392	2020-04-18 04:40:41	2020-04-18	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3714	delivery	5	30
51459	2020-04-18 08:04:21	2020-04-18	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	16755	delivery	5	27
51393	2020-04-18 04:45:13	2020-04-18	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20513	delivery	5	36
51394	2020-04-18 04:47:03	2020-04-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	20532	delivery	5	23
51395	2020-04-18 04:49:12	2020-04-18	9	[{"id_menu":6,"count":2}]	20467	delivery	5	14
51396	2020-04-18 04:53:04	2020-04-18	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	11157	delivery	5	31
51397	2020-04-18 04:58:57	2020-04-18	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3949	pick-up	0	21
51398	2020-04-18 05:02:33	2020-04-18	9	[{"id_menu":7,"count":1}]	4912	delivery	5	14
51399	2020-04-18 05:06:00	2020-04-18	12	[{"id_menu":1,"count":1}]	20577	delivery	5	17
51400	2020-04-18 05:08:45	2020-04-18	9	[{"id_menu":6,"count":1}]	14146	pick-up	0	9
51401	2020-04-18 05:10:14	2020-04-18	9	[{"id_menu":6,"count":1}]	14790	delivery	5	14
51402	2020-04-18 05:12:15	2020-04-18	9	[{"id_menu":7,"count":1}]	13313	delivery	5	14
51403	2020-04-18 05:12:33	2020-04-18	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20541	delivery	5	34
51404	2020-04-18 05:15:44	2020-04-18	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15597	delivery	5	43
51405	2020-04-18 05:17:20	2020-04-18	12	[{"id_menu":3,"count":2}]	20469	delivery	5	17
51406	2020-04-18 05:18:58	2020-04-18	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	20529	delivery	5	39
51407	2020-04-18 05:23:58	2020-04-18	12	[{"id_menu":3,"count":1}]	6996	pick-up	0	12
51408	2020-04-18 05:25:52	2020-04-18	17	[{"id_menu":4,"count":1}]	4658	delivery	5	22
51409	2020-04-18 05:30:12	2020-04-18	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1118	pick-up	0	21
51410	2020-04-18 05:37:04	2020-04-18	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	643	delivery	5	31
51411	2020-04-18 05:38:19	2020-04-18	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	17763	delivery	5	26
51412	2020-04-18 05:39:30	2020-04-18	8	[{"id_menu":5,"count":1}]	17882	delivery	5	13
51413	2020-04-18 05:40:45	2020-04-18	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20568	delivery	5	31
51414	2020-04-18 05:41:08	2020-04-18	14	[{"id_menu":2,"count":1}]	7942	delivery	5	19
51415	2020-04-18 05:46:38	2020-04-18	9	[{"id_menu":6,"count":1}]	3567	pick-up	0	9
51416	2020-04-18 05:56:47	2020-04-18	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	20527	delivery	5	45
51417	2020-04-18 06:01:00	2020-04-18	9	[{"id_menu":7,"count":1}]	17342	delivery	5	14
51418	2020-04-18 06:02:23	2020-04-18	14	[{"id_menu":2,"count":1}]	20569	delivery	5	19
51419	2020-04-18 06:06:52	2020-04-18	17	[{"id_menu":4,"count":1}]	8382	delivery	5	22
51420	2020-04-18 06:08:40	2020-04-18	17	[{"id_menu":4,"count":1}]	2065	pick-up	0	17
51421	2020-04-18 06:15:20	2020-04-18	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17669	delivery	5	34
51422	2020-04-18 06:21:51	2020-04-18	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	12954	delivery	5	25
51423	2020-04-18 06:23:22	2020-04-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10591	delivery	5	22
51424	2020-04-18 06:27:47	2020-04-18	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	20611	delivery	5	38
51425	2020-04-18 06:32:06	2020-04-18	9	[{"id_menu":7,"count":1}]	20589	delivery	5	14
51426	2020-04-18 06:33:13	2020-04-18	9	[{"id_menu":7,"count":1}]	8262	delivery	5	14
51427	2020-04-18 06:33:45	2020-04-18	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11389	delivery	5	36
51428	2020-04-18 06:40:02	2020-04-18	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1285	pick-up	0	31
51429	2020-04-18 06:41:36	2020-04-18	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	20547	delivery	5	23
51430	2020-04-18 06:42:26	2020-04-18	9	[{"id_menu":6,"count":1}]	13028	delivery	5	14
51431	2020-04-18 06:44:30	2020-04-18	8	[{"id_menu":5,"count":2}]	1239	pick-up	0	8
51432	2020-04-18 06:51:03	2020-04-18	17	[{"id_menu":4,"count":1}]	20603	delivery	5	22
51433	2020-04-18 06:54:44	2020-04-18	9	[{"id_menu":6,"count":1}]	20574	delivery	5	14
51434	2020-04-18 06:55:12	2020-04-18	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3199	delivery	5	31
51435	2020-04-18 06:59:29	2020-04-18	9	[{"id_menu":7,"count":1}]	13892	delivery	5	14
51436	2020-04-18 07:00:55	2020-04-18	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	16159	delivery	5	25
51437	2020-04-18 07:01:47	2020-04-18	9	[{"id_menu":7,"count":1}]	13031	delivery	5	14
51438	2020-04-18 07:02:00	2020-04-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	20501	delivery	5	28
51439	2020-04-18 07:06:51	2020-04-18	9	[{"id_menu":6,"count":1}]	6516	delivery	5	14
51440	2020-04-18 07:08:50	2020-04-18	17	[{"id_menu":4,"count":1}]	19397	delivery	5	22
51441	2020-04-18 07:09:58	2020-04-18	8	[{"id_menu":5,"count":1}]	5417	delivery	5	13
51442	2020-04-18 07:11:13	2020-04-18	12	[{"id_menu":1,"count":1}]	20510	delivery	5	17
51443	2020-04-18 07:11:23	2020-04-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	1176	pick-up	0	23
51444	2020-04-18 07:20:39	2020-04-18	8	[{"id_menu":5,"count":1}]	20479	delivery	5	13
51445	2020-04-18 07:23:32	2020-04-18	9	[{"id_menu":6,"count":1}]	16592	pick-up	0	9
51446	2020-04-18 07:25:32	2020-04-18	9	[{"id_menu":7,"count":1}]	2891	pick-up	0	9
51447	2020-04-18 07:27:46	2020-04-18	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1818	delivery	5	57
51448	2020-04-18 07:36:29	2020-04-18	9	[{"id_menu":6,"count":1}]	1446	pick-up	0	9
51449	2020-04-18 07:36:47	2020-04-18	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6137	pick-up	0	26
51450	2020-04-18 07:37:13	2020-04-18	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	1563	delivery	5	22
51451	2020-04-18 07:37:26	2020-04-18	9	[{"id_menu":6,"count":1}]	3420	delivery	5	14
51452	2020-04-18 07:42:29	2020-04-18	9	[{"id_menu":7,"count":1}]	7866	pick-up	0	9
51453	2020-04-18 07:45:01	2020-04-18	14	[{"id_menu":2,"count":1}]	20556	delivery	5	19
51454	2020-04-18 07:49:55	2020-04-18	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	5048	delivery	5	31
51455	2020-04-18 07:52:36	2020-04-18	12	[{"id_menu":3,"count":1}]	20484	delivery	5	17
51456	2020-04-18 07:52:37	2020-04-18	9	[{"id_menu":6,"count":1}]	17195	delivery	5	14
51457	2020-04-18 07:54:06	2020-04-18	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	20507	delivery	5	40
51458	2020-04-18 07:55:04	2020-04-18	9	[{"id_menu":6,"count":1}]	20594	delivery	5	14
51460	2020-04-18 08:16:42	2020-04-18	14	[{"id_menu":2,"count":1}]	722	pick-up	0	14
51461	2020-04-18 08:24:24	2020-04-18	14	[{"id_menu":2,"count":1}]	3412	delivery	5	19
51462	2020-04-18 08:25:11	2020-04-18	12	[{"id_menu":1,"count":1}]	12685	delivery	5	17
51463	2020-04-18 08:25:20	2020-04-18	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	20483	delivery	5	31
51464	2020-04-18 08:25:51	2020-04-18	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2025	delivery	5	42
51465	2020-04-18 08:26:35	2020-04-18	9	[{"id_menu":6,"count":1}]	13921	delivery	5	14
51466	2020-04-18 08:29:20	2020-04-18	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	7046	pick-up	0	20
51467	2020-04-18 08:29:41	2020-04-18	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3326	pick-up	0	21
51468	2020-04-18 08:34:21	2020-04-18	8	[{"id_menu":5,"count":1}]	2658	delivery	5	13
51469	2020-04-18 08:38:06	2020-04-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5886	delivery	5	22
51470	2020-04-18 08:39:00	2020-04-18	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20531	delivery	5	34
51471	2020-04-18 08:39:39	2020-04-18	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	6469	delivery	5	40
51472	2020-04-18 08:41:03	2020-04-18	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	20596	delivery	5	29
51473	2020-04-18 08:52:29	2020-04-18	12	[{"id_menu":1,"count":1}]	9983	pick-up	0	12
51474	2020-04-18 09:01:08	2020-04-18	9	[{"id_menu":6,"count":1}]	20585	delivery	5	14
51475	2020-04-18 09:09:17	2020-04-18	17	[{"id_menu":4,"count":1}]	14380	delivery	5	22
51476	2020-04-18 09:11:55	2020-04-18	12	[{"id_menu":3,"count":1}]	20570	pick-up	0	12
51477	2020-04-18 09:12:46	2020-04-18	14	[{"id_menu":2,"count":1}]	20524	delivery	5	19
51478	2020-04-18 09:15:35	2020-04-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	11040	pick-up	0	23
51479	2020-04-18 09:15:49	2020-04-18	8	[{"id_menu":5,"count":1}]	12527	pick-up	0	8
51480	2020-04-18 09:16:12	2020-04-18	9	[{"id_menu":7,"count":1}]	2029	pick-up	0	9
51481	2020-04-18 09:19:21	2020-04-18	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20536	delivery	5	34
51482	2020-04-18 09:20:19	2020-04-18	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3403	pick-up	0	26
51483	2020-04-18 09:22:18	2020-04-18	9	[{"id_menu":6,"count":1}]	15058	delivery	5	14
51484	2020-04-18 09:25:31	2020-04-18	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	20485	delivery	5	30
51485	2020-04-18 09:32:45	2020-04-18	8	[{"id_menu":5,"count":1}]	7650	delivery	5	13
51486	2020-04-18 09:44:19	2020-04-18	17	[{"id_menu":4,"count":1}]	20605	delivery	5	22
51487	2020-04-18 09:46:15	2020-04-18	12	[{"id_menu":1,"count":1}]	2325	pick-up	0	12
51488	2020-04-18 09:55:04	2020-04-18	9	[{"id_menu":6,"count":1}]	12162	pick-up	0	9
51489	2020-04-18 09:56:38	2020-04-18	17	[{"id_menu":4,"count":1}]	1208	pick-up	0	17
51490	2020-04-18 09:59:20	2020-04-18	9	[{"id_menu":6,"count":1}]	20604	delivery	5	14
51491	2020-04-18 10:02:12	2020-04-18	12	[{"id_menu":3,"count":1}]	20549	pick-up	0	12
51492	2020-04-18 10:02:17	2020-04-18	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	20302	delivery	5	34
51493	2020-04-18 10:08:44	2020-04-18	14	[{"id_menu":2,"count":1}]	20514	delivery	5	19
51494	2020-04-18 10:10:19	2020-04-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	708	pick-up	0	23
51495	2020-04-18 10:21:19	2020-04-18	9	[{"id_menu":6,"count":1}]	10340	delivery	5	14
51496	2020-04-18 10:25:36	2020-04-18	9	[{"id_menu":6,"count":1}]	20563	delivery	5	14
51497	2020-04-18 10:30:43	2020-04-18	8	[{"id_menu":5,"count":1}]	11609	delivery	5	13
51498	2020-04-18 10:32:30	2020-04-18	17	[{"id_menu":4,"count":1}]	15820	delivery	5	22
51499	2020-04-18 10:33:06	2020-04-18	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20602	delivery	5	35
51500	2020-04-18 10:33:11	2020-04-18	8	[{"id_menu":5,"count":1}]	10007	pick-up	0	8
51501	2020-04-18 10:34:47	2020-04-18	9	[{"id_menu":6,"count":1}]	20476	delivery	5	14
51502	2020-04-18 10:46:26	2020-04-18	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13613	pick-up	0	26
51503	2020-04-18 10:48:36	2020-04-18	12	[{"id_menu":1,"count":1}]	16380	pick-up	0	12
51504	2020-04-18 10:50:19	2020-04-18	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	20597	delivery	5	44
51505	2020-04-18 10:50:34	2020-04-18	9	[{"id_menu":7,"count":1}]	16504	delivery	5	14
51506	2020-04-18 10:51:58	2020-04-18	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	9976	delivery	5	40
51507	2020-04-18 10:55:33	2020-04-18	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	20468	delivery	5	26
51508	2020-04-18 10:58:52	2020-04-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20516	pick-up	0	18
51509	2020-04-18 10:59:40	2020-04-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2272	pick-up	0	23
51510	2020-04-18 10:59:51	2020-04-18	17	[{"id_menu":4,"count":1}]	7953	delivery	5	22
51511	2020-04-18 11:13:18	2020-04-18	9	[{"id_menu":6,"count":1}]	19969	pick-up	0	9
51512	2020-04-18 11:15:54	2020-04-18	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	13425	delivery	5	36
51513	2020-04-18 11:16:06	2020-04-18	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	18174	delivery	5	26
51514	2020-04-18 11:16:43	2020-04-18	14	[{"id_menu":2,"count":1}]	9575	pick-up	0	14
51515	2020-04-18 11:17:05	2020-04-18	8	[{"id_menu":5,"count":1}]	20555	delivery	5	13
51516	2020-04-18 11:17:24	2020-04-18	9	[{"id_menu":7,"count":1}]	17908	delivery	5	14
51517	2020-04-18 11:21:17	2020-04-18	9	[{"id_menu":6,"count":1}]	20506	delivery	5	14
51518	2020-04-18 11:21:35	2020-04-18	14	[{"id_menu":2,"count":2}]	4139	delivery	5	19
51519	2020-04-18 11:28:51	2020-04-18	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	20482	delivery	5	22
51520	2020-04-18 11:31:53	2020-04-18	12	[{"id_menu":1,"count":1}]	4090	delivery	5	17
51521	2020-04-18 11:32:16	2020-04-18	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6549	delivery	5	22
51522	2020-04-18 11:34:22	2020-04-18	8	[{"id_menu":5,"count":1}]	11686	pick-up	0	8
51523	2020-04-18 11:34:59	2020-04-18	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	19701	delivery	5	30
51524	2020-04-18 11:35:29	2020-04-18	12	[{"id_menu":3,"count":1}]	5139	pick-up	0	12
51525	2020-04-18 11:35:45	2020-04-18	14	[{"id_menu":2,"count":1}]	14764	pick-up	0	14
51526	2020-04-18 11:38:28	2020-04-18	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	19075	delivery	5	31
51527	2020-04-18 11:38:42	2020-04-18	17	[{"id_menu":4,"count":1}]	20488	delivery	5	22
51528	2020-04-18 11:38:59	2020-04-18	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20521	delivery	5	34
51529	2020-04-18 11:41:21	2020-04-18	14	[{"id_menu":2,"count":1}]	599	pick-up	0	14
51530	2020-04-18 11:47:54	2020-04-18	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	19486	pick-up	0	29
51531	2020-04-18 11:48:15	2020-04-18	8	[{"id_menu":5,"count":1}]	506	delivery	5	13
51532	2020-04-18 11:53:07	2020-04-18	17	[{"id_menu":4,"count":1}]	20519	pick-up	0	17
51533	2020-04-18 11:57:38	2020-04-18	8	[{"id_menu":5,"count":1}]	7097	pick-up	0	8
51534	2020-04-18 12:00:02	2020-04-18	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20191	delivery	5	36
51535	2020-04-18 12:19:17	2020-04-18	14	[{"id_menu":2,"count":1}]	14086	pick-up	0	14
51536	2020-04-18 12:20:51	2020-04-18	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	6885	pick-up	0	21
51537	2020-04-18 12:27:22	2020-04-18	12	[{"id_menu":3,"count":1}]	15667	delivery	5	17
51538	2020-04-18 12:30:41	2020-04-18	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	6704	pick-up	0	31
51539	2020-04-18 12:30:56	2020-04-18	8	[{"id_menu":5,"count":1}]	5291	delivery	5	13
51540	2020-04-18 12:31:55	2020-04-18	9	[{"id_menu":6,"count":1}]	20520	delivery	5	14
51541	2020-04-18 12:38:09	2020-04-18	9	[{"id_menu":6,"count":1}]	20101	delivery	5	14
51542	2020-04-18 12:41:30	2020-04-18	9	[{"id_menu":7,"count":1}]	20606	delivery	5	14
51543	2020-04-18 12:48:10	2020-04-18	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1727	pick-up	0	21
51544	2020-04-18 12:50:47	2020-04-18	8	[{"id_menu":5,"count":1}]	20545	delivery	5	13
51545	2020-04-18 12:52:50	2020-04-18	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1535	delivery	5	34
51546	2020-04-18 12:56:21	2020-04-18	8	[{"id_menu":5,"count":1}]	11189	delivery	5	13
51547	2020-04-18 12:56:40	2020-04-18	9	[{"id_menu":7,"count":1}]	4948	delivery	5	14
51548	2020-04-18 12:58:40	2020-04-18	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	18025	pick-up	0	26
51549	2020-04-18 13:01:32	2020-04-18	9	[{"id_menu":7,"count":1}]	12	pick-up	0	9
51550	2020-04-18 13:02:34	2020-04-18	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	11785	delivery	5	56
51551	2020-04-18 13:04:19	2020-04-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11718	delivery	5	22
51552	2020-04-18 13:07:10	2020-04-18	8	[{"id_menu":5,"count":1}]	20498	delivery	5	13
51553	2020-04-18 13:07:14	2020-04-18	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	20464	delivery	5	31
51554	2020-04-18 13:10:33	2020-04-18	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	20600	delivery	5	27
51555	2020-04-18 13:11:12	2020-04-18	9	[{"id_menu":7,"count":1}]	5550	delivery	5	14
51556	2020-04-18 13:20:14	2020-04-18	17	[{"id_menu":4,"count":1}]	4998	pick-up	0	17
51557	2020-04-18 13:21:36	2020-04-18	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	8772	delivery	5	37
51558	2020-04-18 13:22:20	2020-04-18	17	[{"id_menu":4,"count":1}]	20546	delivery	5	22
51559	2020-04-18 13:24:22	2020-04-18	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15294	delivery	5	45
51560	2020-04-18 13:31:31	2020-04-18	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":2}]	11973	delivery	5	31
51561	2020-04-18 13:36:55	2020-04-18	14	[{"id_menu":2,"count":1}]	18343	delivery	5	19
51562	2020-04-18 13:37:21	2020-04-18	9	[{"id_menu":7,"count":1}]	12615	delivery	5	14
51563	2020-04-18 13:38:36	2020-04-18	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	14862	delivery	5	34
51564	2020-04-18 13:50:23	2020-04-18	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4199	delivery	5	40
51565	2020-04-18 13:55:40	2020-04-18	12	[{"id_menu":3,"count":1}]	11083	delivery	5	17
51566	2020-04-18 13:57:36	2020-04-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	20551	delivery	5	28
51567	2020-04-18 14:03:14	2020-04-18	14	[{"id_menu":2,"count":1}]	18316	pick-up	0	14
51568	2020-04-18 14:07:55	2020-04-18	14	[{"id_menu":2,"count":1}]	8209	pick-up	0	14
51569	2020-04-18 14:13:40	2020-04-18	8	[{"id_menu":5,"count":1}]	17262	delivery	5	13
51570	2020-04-18 14:14:38	2020-04-18	9	[{"id_menu":7,"count":1}]	20612	delivery	5	14
51571	2020-04-18 14:15:10	2020-04-18	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	20522	delivery	5	27
51572	2020-04-18 14:16:36	2020-04-18	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	5644	delivery	5	26
51573	2020-04-18 14:16:52	2020-04-18	9	[{"id_menu":6,"count":1}]	20601	delivery	5	14
51574	2020-04-18 14:19:12	2020-04-18	9	[{"id_menu":7,"count":1}]	19082	delivery	5	14
51575	2020-04-18 14:20:48	2020-04-18	14	[{"id_menu":2,"count":1}]	12939	delivery	5	19
51576	2020-04-18 14:25:22	2020-04-18	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1780	pick-up	0	37
51577	2020-04-18 14:26:59	2020-04-18	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	20486	delivery	5	26
51578	2020-04-18 14:28:57	2020-04-18	17	[{"id_menu":4,"count":1}]	10850	pick-up	0	17
51579	2020-04-18 14:37:06	2020-04-18	12	[{"id_menu":3,"count":1}]	4242	pick-up	0	12
51580	2020-04-18 14:41:01	2020-04-18	17	[{"id_menu":4,"count":1}]	8423	delivery	5	22
51581	2020-04-18 14:44:11	2020-04-18	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7025	delivery	5	48
51582	2020-04-18 14:45:58	2020-04-18	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	20526	delivery	5	26
51583	2020-04-18 14:45:58	2020-04-18	17	[{"id_menu":4,"count":1}]	6173	pick-up	0	17
51584	2020-04-18 14:50:44	2020-04-18	9	[{"id_menu":7,"count":1}]	20470	delivery	5	14
51585	2020-04-18 14:51:04	2020-04-18	17	[{"id_menu":4,"count":1}]	20493	pick-up	0	17
51586	2020-04-18 14:54:32	2020-04-18	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20578	pick-up	0	34
51587	2020-04-18 14:56:23	2020-04-18	14	[{"id_menu":2,"count":1}]	20539	delivery	5	19
51588	2020-04-18 14:56:33	2020-04-18	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2653	pick-up	0	29
51589	2020-04-18 15:00:02	2020-04-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	20571	delivery	5	28
51590	2020-04-18 15:05:39	2020-04-18	9	[{"id_menu":6,"count":1}]	8757	delivery	5	14
51591	2020-04-18 15:11:13	2020-04-18	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	18580	delivery	5	40
51592	2020-04-18 15:14:53	2020-04-18	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	20502	delivery	5	34
51593	2020-04-18 15:15:59	2020-04-18	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20560	delivery	5	34
51594	2020-04-18 15:22:16	2020-04-18	8	[{"id_menu":5,"count":1}]	12710	delivery	5	13
51595	2020-04-18 15:23:43	2020-04-18	14	[{"id_menu":2,"count":1}]	20523	delivery	5	19
51596	2020-04-18 15:25:40	2020-04-18	8	[{"id_menu":5,"count":1}]	3983	delivery	5	13
51597	2020-04-18 15:30:19	2020-04-18	9	[{"id_menu":7,"count":1}]	6594	delivery	5	14
51598	2020-04-18 15:32:36	2020-04-18	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	13473	pick-up	0	22
51599	2020-04-18 15:37:14	2020-04-18	9	[{"id_menu":7,"count":1}]	20475	delivery	5	14
51600	2020-04-18 15:40:38	2020-04-18	12	[{"id_menu":1,"count":1}]	1700	pick-up	0	12
51601	2020-04-18 15:42:22	2020-04-18	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	7035	delivery	5	43
51602	2020-04-18 15:53:45	2020-04-18	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4737	delivery	5	48
51603	2020-04-18 15:56:12	2020-04-18	8	[{"id_menu":5,"count":1}]	3069	pick-up	0	8
51604	2020-04-18 15:59:41	2020-04-18	9	[{"id_menu":7,"count":1}]	17422	delivery	5	14
51605	2020-04-18 16:00:27	2020-04-18	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	6491	delivery	5	34
51606	2020-04-18 16:01:37	2020-04-18	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10646	delivery	5	39
51607	2020-04-18 16:03:51	2020-04-18	12	[{"id_menu":1,"count":1}]	20557	delivery	5	17
51608	2020-04-18 16:07:19	2020-04-18	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	9627	pick-up	0	26
51609	2020-04-18 16:13:08	2020-04-18	12	[{"id_menu":1,"count":2}]	775	pick-up	0	12
51610	2020-04-18 16:14:32	2020-04-18	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	3185	pick-up	0	26
51611	2020-04-18 16:16:34	2020-04-18	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	20550	delivery	5	43
51612	2020-04-18 16:20:46	2020-04-18	12	[{"id_menu":1,"count":2}]	20552	delivery	5	17
51613	2020-04-18 16:28:53	2020-04-18	9	[{"id_menu":7,"count":1}]	12108	pick-up	0	9
51614	2020-04-18 16:38:57	2020-04-18	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	20504	delivery	5	40
51615	2020-04-18 16:39:38	2020-04-18	8	[{"id_menu":5,"count":1}]	4411	delivery	5	13
51616	2020-04-18 16:43:56	2020-04-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	15386	delivery	5	28
51617	2020-04-18 16:46:20	2020-04-18	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	20562	delivery	5	30
51618	2020-04-18 16:49:19	2020-04-18	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	17657	delivery	5	26
51619	2020-04-18 16:58:28	2020-04-18	17	[{"id_menu":4,"count":1}]	15873	pick-up	0	17
51620	2020-04-18 16:58:56	2020-04-18	12	[{"id_menu":1,"count":1}]	20508	delivery	5	17
51621	2020-04-18 17:01:39	2020-04-18	9	[{"id_menu":7,"count":1}]	19562	delivery	5	14
51622	2020-04-18 17:03:17	2020-04-18	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	19628	delivery	5	31
51623	2020-04-18 17:04:09	2020-04-18	9	[{"id_menu":7,"count":2}]	20538	pick-up	0	9
51624	2020-04-18 17:04:14	2020-04-18	12	[{"id_menu":1,"count":1}]	20533	pick-up	0	12
51625	2020-04-18 17:10:24	2020-04-18	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	20582	delivery	5	43
51626	2020-04-18 17:11:12	2020-04-18	8	[{"id_menu":5,"count":1}]	20478	delivery	5	13
51627	2020-04-18 17:12:30	2020-04-18	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	20581	delivery	5	27
51628	2020-04-18 17:16:33	2020-04-18	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7547	delivery	5	40
51629	2020-04-18 17:17:17	2020-04-18	12	[{"id_menu":3,"count":1}]	18687	pick-up	0	12
51630	2020-04-18 17:18:02	2020-04-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	473	delivery	5	28
51631	2020-04-18 17:18:24	2020-04-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":3}]	13663	delivery	5	23
51632	2020-04-18 17:21:17	2020-04-18	12	[{"id_menu":3,"count":1}]	20554	pick-up	0	12
51633	2020-04-18 17:22:18	2020-04-18	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	7766	pick-up	0	29
51634	2020-04-18 17:25:46	2020-04-18	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3599	delivery	5	26
51635	2020-04-18 17:26:34	2020-04-18	17	[{"id_menu":4,"count":1}]	12699	delivery	5	22
51636	2020-04-18 17:27:54	2020-04-18	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	13233	delivery	5	31
51637	2020-04-18 17:29:21	2020-04-18	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	391	delivery	5	36
51638	2020-04-18 17:29:46	2020-04-18	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10535	delivery	5	45
51639	2020-04-18 17:31:04	2020-04-18	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20528	delivery	5	34
51640	2020-04-18 17:31:55	2020-04-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	17519	delivery	5	28
51641	2020-04-18 17:34:56	2020-04-18	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	20587	delivery	5	36
51642	2020-04-18 17:38:43	2020-04-18	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	19313	pick-up	0	26
51643	2020-04-18 17:40:37	2020-04-18	9	[{"id_menu":7,"count":1}]	20462	delivery	5	14
51644	2020-04-18 17:40:59	2020-04-18	14	[{"id_menu":2,"count":1}]	20518	delivery	5	19
51645	2020-04-18 17:42:19	2020-04-18	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19971	delivery	5	31
51646	2020-04-18 17:42:36	2020-04-18	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15352	delivery	5	48
51647	2020-04-18 17:43:24	2020-04-18	12	[{"id_menu":1,"count":1}]	20558	delivery	5	17
51648	2020-04-18 17:49:35	2020-04-18	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":3}]	15848	delivery	5	26
51649	2020-04-18 17:50:56	2020-04-18	9	[{"id_menu":7,"count":1}]	12478	delivery	5	14
51650	2020-04-18 17:54:23	2020-04-18	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	13568	delivery	5	23
51651	2020-04-18 17:55:11	2020-04-18	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7729	delivery	5	31
51652	2020-04-18 17:56:50	2020-04-18	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20509	delivery	5	36
51653	2020-04-18 17:58:06	2020-04-18	9	[{"id_menu":6,"count":1}]	4184	pick-up	0	9
51654	2020-04-18 18:04:51	2020-04-18	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17392	delivery	5	39
51655	2020-04-18 18:08:22	2020-04-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6901	pick-up	0	23
51656	2020-04-18 18:10:29	2020-04-18	17	[{"id_menu":4,"count":1}]	13175	delivery	5	22
51657	2020-04-18 18:13:00	2020-04-18	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20544	delivery	5	49
51658	2020-04-18 18:19:56	2020-04-18	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	7875	delivery	5	34
51659	2020-04-18 18:22:47	2020-04-18	9	[{"id_menu":6,"count":1}]	9094	delivery	5	14
51660	2020-04-18 18:26:41	2020-04-18	14	[{"id_menu":2,"count":1}]	351	pick-up	0	14
51661	2020-04-18 18:29:47	2020-04-18	14	[{"id_menu":2,"count":2}]	13424	delivery	5	19
51662	2020-04-18 18:32:52	2020-04-18	8	[{"id_menu":5,"count":1}]	20595	pick-up	0	8
51663	2020-04-18 18:41:25	2020-04-18	14	[{"id_menu":2,"count":1}]	20466	delivery	5	19
51664	2020-04-18 18:45:13	2020-04-18	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20583	delivery	5	40
51665	2020-04-18 18:45:41	2020-04-18	8	[{"id_menu":5,"count":1}]	19261	delivery	5	13
51666	2020-04-18 18:45:41	2020-04-18	17	[{"id_menu":4,"count":1}]	7982	delivery	5	22
51667	2020-04-18 18:45:54	2020-04-18	9	[{"id_menu":6,"count":1}]	1731	pick-up	0	9
51668	2020-04-18 18:56:06	2020-04-18	38	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15533	delivery	5	43
51669	2020-04-18 18:58:04	2020-04-18	17	[{"id_menu":4,"count":1}]	20565	delivery	5	22
51670	2020-04-18 18:59:05	2020-04-18	9	[{"id_menu":7,"count":1}]	17661	delivery	5	14
51671	2020-04-18 19:04:19	2020-04-18	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	12150	pick-up	0	26
51672	2020-04-18 19:05:11	2020-04-18	9	[{"id_menu":6,"count":1}]	8129	delivery	5	14
51673	2020-04-18 19:06:04	2020-04-18	14	[{"id_menu":2,"count":1}]	20588	pick-up	0	14
51674	2020-04-18 19:06:35	2020-04-18	8	[{"id_menu":5,"count":1}]	11619	pick-up	0	8
51675	2020-04-18 19:07:16	2020-04-18	9	[{"id_menu":6,"count":1}]	20576	delivery	5	14
51676	2020-04-18 19:09:32	2020-04-18	14	[{"id_menu":2,"count":1}]	9467	pick-up	0	14
51677	2020-04-18 19:09:44	2020-04-18	17	[{"id_menu":4,"count":1}]	19525	pick-up	0	17
51678	2020-04-18 19:21:13	2020-04-18	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	13825	delivery	5	30
51679	2020-04-18 19:22:22	2020-04-18	8	[{"id_menu":5,"count":1}]	13725	delivery	5	13
51680	2020-04-18 19:25:22	2020-04-18	8	[{"id_menu":5,"count":1}]	2172	pick-up	0	8
51681	2020-04-18 19:27:15	2020-04-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8308	delivery	5	23
51682	2020-04-18 19:35:48	2020-04-18	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	20503	delivery	5	26
51683	2020-04-18 19:43:18	2020-04-18	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	11627	delivery	5	36
51684	2020-04-18 19:45:58	2020-04-18	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	20607	delivery	5	25
51685	2020-04-18 19:51:25	2020-04-18	12	[{"id_menu":1,"count":1}]	187	pick-up	0	12
51686	2020-04-18 19:52:10	2020-04-18	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":3}]	20491	delivery	5	26
51687	2020-04-18 19:57:23	2020-04-18	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	20537	delivery	5	28
51688	2020-04-18 20:03:01	2020-04-18	12	[{"id_menu":3,"count":1}]	16325	delivery	5	17
51689	2020-04-18 20:04:09	2020-04-18	9	[{"id_menu":7,"count":1}]	80	delivery	5	14
51690	2020-04-18 20:04:53	2020-04-18	12	[{"id_menu":3,"count":1}]	20561	delivery	5	17
51691	2020-04-18 20:10:05	2020-04-18	9	[{"id_menu":6,"count":1}]	1557	pick-up	0	9
51692	2020-04-18 20:10:05	2020-04-18	12	[{"id_menu":1,"count":1}]	20610	delivery	5	17
51693	2020-04-18 20:11:07	2020-04-18	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	13027	delivery	5	31
51694	2020-04-18 20:11:48	2020-04-18	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	568	delivery	5	30
51695	2020-04-18 20:13:08	2020-04-18	12	[{"id_menu":1,"count":1}]	12133	delivery	5	17
51696	2020-04-18 20:15:43	2020-04-18	14	[{"id_menu":2,"count":1}]	6277	delivery	5	19
51697	2020-04-18 20:16:23	2020-04-18	9	[{"id_menu":7,"count":1}]	5396	delivery	5	14
51698	2020-04-18 20:19:55	2020-04-18	17	[{"id_menu":4,"count":1}]	16557	delivery	5	22
51699	2020-04-18 20:22:43	2020-04-18	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	11511	pick-up	0	25
51700	2020-04-18 20:24:56	2020-04-18	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1781	pick-up	0	31
51701	2020-04-18 20:25:38	2020-04-18	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	20591	delivery	5	31
51702	2020-04-18 20:27:35	2020-04-18	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17412	delivery	5	45
51703	2020-04-18 20:29:13	2020-04-18	9	[{"id_menu":6,"count":1}]	2951	delivery	5	14
51704	2020-04-18 20:31:20	2020-04-18	14	[{"id_menu":2,"count":1}]	5247	delivery	5	19
51705	2020-04-18 20:32:06	2020-04-18	30	[{"id_menu":1,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20573	delivery	5	35
51706	2020-04-18 20:41:02	2020-04-18	17	[{"id_menu":4,"count":1}]	20593	delivery	5	22
51707	2020-04-18 20:41:25	2020-04-18	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20492	delivery	5	31
51708	2020-04-18 20:46:20	2020-04-18	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	9081	delivery	5	26
51709	2020-04-18 20:47:53	2020-04-18	9	[{"id_menu":6,"count":1}]	13071	delivery	5	14
51710	2020-04-18 20:50:38	2020-04-18	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1309	pick-up	0	21
51711	2020-04-18 20:55:40	2020-04-18	9	[{"id_menu":6,"count":1}]	10214	delivery	5	14
51712	2020-04-18 21:04:34	2020-04-18	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	8872	delivery	5	28
51713	2020-04-18 21:08:52	2020-04-18	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20511	delivery	5	34
51714	2020-04-18 21:17:55	2020-04-18	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	20609	delivery	5	37
51715	2020-04-18 21:17:59	2020-04-18	14	[{"id_menu":2,"count":1}]	16910	pick-up	0	14
51716	2020-04-18 21:18:01	2020-04-18	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20497	delivery	5	36
51717	2020-04-18 21:24:13	2020-04-18	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	20472	delivery	5	31
51718	2020-04-18 21:26:03	2020-04-18	12	[{"id_menu":3,"count":1}]	18591	delivery	5	17
51719	2020-04-18 21:33:06	2020-04-18	9	[{"id_menu":7,"count":1}]	4451	delivery	5	14
51720	2020-04-18 21:33:57	2020-04-18	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	135	delivery	5	26
51721	2020-04-18 21:37:08	2020-04-18	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	20543	delivery	5	36
51722	2020-04-18 21:38:29	2020-04-18	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	13060	delivery	5	26
51723	2020-04-18 21:44:58	2020-04-18	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20535	delivery	5	48
51724	2020-04-18 21:49:16	2020-04-18	12	[{"id_menu":1,"count":1}]	20465	delivery	5	17
51725	2020-04-18 21:52:10	2020-04-18	9	[{"id_menu":6,"count":1}]	15188	delivery	5	14
51726	2020-04-18 22:02:07	2020-04-18	12	[{"id_menu":3,"count":1}]	20477	pick-up	0	12
51727	2020-04-18 22:02:07	2020-04-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	5491	pick-up	0	23
51728	2020-04-18 22:04:28	2020-04-18	17	[{"id_menu":4,"count":1}]	572	pick-up	0	17
51729	2020-04-18 22:06:59	2020-04-18	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	6565	delivery	5	25
51730	2020-04-18 22:07:54	2020-04-18	9	[{"id_menu":6,"count":1}]	4127	delivery	5	14
51731	2020-04-18 22:10:48	2020-04-18	9	[{"id_menu":6,"count":1}]	19984	delivery	5	14
51732	2020-04-18 22:13:12	2020-04-18	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	9886	pick-up	0	21
51733	2020-04-18 22:16:15	2020-04-18	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5169	pick-up	0	25
51734	2020-04-18 22:16:23	2020-04-18	9	[{"id_menu":7,"count":1}]	341	delivery	5	14
51735	2020-04-18 22:20:59	2020-04-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9438	delivery	5	23
51736	2020-04-18 22:27:37	2020-04-18	9	[{"id_menu":6,"count":1}]	701	pick-up	0	9
51737	2020-04-18 22:32:26	2020-04-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	16345	delivery	5	28
51738	2020-04-18 22:33:03	2020-04-18	9	[{"id_menu":7,"count":1}]	13486	delivery	5	14
51739	2020-04-18 22:36:11	2020-04-18	17	[{"id_menu":4,"count":2}]	20489	delivery	5	22
51740	2020-04-18 22:36:46	2020-04-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	15194	delivery	5	28
51741	2020-04-18 22:39:13	2020-04-18	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12796	delivery	5	37
51742	2020-04-18 22:41:30	2020-04-18	9	[{"id_menu":7,"count":1}]	20530	delivery	5	14
51743	2020-04-18 22:43:26	2020-04-18	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	20584	delivery	5	39
51744	2020-04-18 22:45:36	2020-04-18	8	[{"id_menu":5,"count":1}]	14025	pick-up	0	8
51745	2020-04-18 22:52:38	2020-04-18	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	578	delivery	5	42
51746	2020-04-18 22:56:17	2020-04-18	17	[{"id_menu":4,"count":1}]	1183	pick-up	0	17
51747	2020-04-18 23:00:19	2020-04-18	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11193	delivery	5	34
51748	2020-04-18 23:03:57	2020-04-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20579	delivery	5	23
51749	2020-04-18 23:10:17	2020-04-18	9	[{"id_menu":7,"count":1}]	6683	delivery	5	14
51750	2020-04-18 23:10:25	2020-04-18	9	[{"id_menu":7,"count":1}]	11760	delivery	5	14
51751	2020-04-18 23:11:18	2020-04-18	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	964	delivery	5	39
51752	2020-04-18 23:17:19	2020-04-18	14	[{"id_menu":2,"count":1}]	20540	pick-up	0	14
51753	2020-04-18 23:19:40	2020-04-18	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	5082	pick-up	0	21
51754	2020-04-18 23:30:22	2020-04-18	9	[{"id_menu":6,"count":1}]	20512	delivery	5	14
51755	2020-04-18 23:32:02	2020-04-18	17	[{"id_menu":4,"count":1}]	9859	pick-up	0	17
51756	2020-04-18 23:34:11	2020-04-18	14	[{"id_menu":2,"count":2}]	7741	pick-up	0	14
51757	2020-04-18 23:34:52	2020-04-18	17	[{"id_menu":4,"count":1}]	274	pick-up	0	17
51758	2020-04-18 23:35:46	2020-04-18	12	[{"id_menu":3,"count":2}]	20598	pick-up	0	12
51759	2020-04-18 23:39:41	2020-04-18	8	[{"id_menu":5,"count":1}]	12089	delivery	5	13
51760	2020-04-18 23:43:58	2020-04-18	9	[{"id_menu":6,"count":1}]	20608	delivery	5	14
51761	2020-04-18 23:44:40	2020-04-18	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20494	delivery	5	34
51762	2020-04-18 23:46:54	2020-04-18	8	[{"id_menu":5,"count":1}]	20487	delivery	5	13
51763	2020-04-18 23:48:47	2020-04-18	12	[{"id_menu":1,"count":2}]	20559	pick-up	0	12
51764	2020-04-18 23:56:05	2020-04-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	20517	pick-up	0	23
51765	2020-04-18 23:56:52	2020-04-18	12	[{"id_menu":3,"count":1}]	12968	delivery	5	17
51766	2020-04-18 23:59:54	2020-04-18	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	20505	delivery	5	27
51767	2020-04-19 00:01:57	2020-04-19	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10311	delivery	5	40
51768	2020-04-19 00:03:48	2020-04-19	12	[{"id_menu":1,"count":1}]	11380	delivery	5	17
51769	2020-04-19 00:06:44	2020-04-19	9	[{"id_menu":7,"count":1}]	20504	pick-up	0	9
51770	2020-04-19 00:08:27	2020-04-19	12	[{"id_menu":1,"count":1}]	20754	pick-up	0	12
51771	2020-04-19 00:14:30	2020-04-19	12	[{"id_menu":3,"count":1}]	10039	pick-up	0	12
51772	2020-04-19 00:17:59	2020-04-19	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	3447	pick-up	0	21
51773	2020-04-19 00:22:51	2020-04-19	14	[{"id_menu":2,"count":1}]	12393	pick-up	0	14
51774	2020-04-19 00:31:09	2020-04-19	9	[{"id_menu":6,"count":1}]	4309	pick-up	0	9
51775	2020-04-19 00:35:59	2020-04-19	9	[{"id_menu":6,"count":1}]	20616	delivery	5	14
51776	2020-04-19 00:36:52	2020-04-19	14	[{"id_menu":2,"count":1}]	20645	delivery	5	19
51777	2020-04-19 00:44:43	2020-04-19	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	20731	delivery	5	30
51778	2020-04-19 00:44:54	2020-04-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	4547	delivery	5	28
51779	2020-04-19 00:46:47	2020-04-19	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	1678	pick-up	0	23
51780	2020-04-19 00:49:13	2020-04-19	9	[{"id_menu":6,"count":1}]	4130	delivery	5	14
51781	2020-04-19 00:54:20	2020-04-19	9	[{"id_menu":7,"count":1}]	5125	pick-up	0	9
51782	2020-04-19 01:06:48	2020-04-19	9	[{"id_menu":6,"count":1}]	11779	pick-up	0	9
51783	2020-04-19 01:16:01	2020-04-19	12	[{"id_menu":3,"count":1}]	18112	delivery	5	17
51784	2020-04-19 01:19:14	2020-04-19	12	[{"id_menu":1,"count":1}]	2479	delivery	5	17
51785	2020-04-19 01:23:34	2020-04-19	17	[{"id_menu":4,"count":1}]	17435	delivery	5	22
51786	2020-04-19 01:23:52	2020-04-19	9	[{"id_menu":7,"count":1}]	5687	pick-up	0	9
51787	2020-04-19 01:24:17	2020-04-19	9	[{"id_menu":6,"count":1}]	11367	delivery	5	14
51788	2020-04-19 01:24:32	2020-04-19	8	[{"id_menu":5,"count":1}]	920	pick-up	0	8
51789	2020-04-19 01:30:36	2020-04-19	14	[{"id_menu":2,"count":1}]	13042	delivery	5	19
51790	2020-04-19 01:32:43	2020-04-19	9	[{"id_menu":7,"count":1}]	12902	delivery	5	14
51791	2020-04-19 01:37:36	2020-04-19	14	[{"id_menu":2,"count":1}]	984	delivery	5	19
51792	2020-04-19 01:38:51	2020-04-19	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	20634	delivery	5	26
51793	2020-04-19 01:41:44	2020-04-19	9	[{"id_menu":7,"count":1}]	14796	delivery	5	14
51794	2020-04-19 01:42:40	2020-04-19	8	[{"id_menu":5,"count":1}]	20621	delivery	5	13
51795	2020-04-19 02:06:54	2020-04-19	14	[{"id_menu":2,"count":1}]	3049	delivery	5	19
51796	2020-04-19 02:08:34	2020-04-19	9	[{"id_menu":6,"count":2}]	12951	pick-up	0	9
51797	2020-04-19 02:10:24	2020-04-19	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	20638	delivery	5	30
51798	2020-04-19 02:11:08	2020-04-19	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	10074	delivery	5	23
51799	2020-04-19 02:17:05	2020-04-19	9	[{"id_menu":6,"count":1}]	20679	delivery	5	14
51800	2020-04-19 02:17:08	2020-04-19	14	[{"id_menu":2,"count":1}]	20750	delivery	5	19
51801	2020-04-19 02:21:29	2020-04-19	12	[{"id_menu":3,"count":1}]	1002	pick-up	0	12
51802	2020-04-19 02:21:46	2020-04-19	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	13329	delivery	5	31
51803	2020-04-19 02:22:26	2020-04-19	8	[{"id_menu":5,"count":1}]	19347	delivery	5	13
51804	2020-04-19 02:23:01	2020-04-19	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	20728	delivery	5	40
51805	2020-04-19 02:29:57	2020-04-19	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19036	delivery	5	39
51806	2020-04-19 02:30:02	2020-04-19	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	20683	delivery	5	25
51807	2020-04-19 02:35:40	2020-04-19	12	[{"id_menu":1,"count":1}]	20742	delivery	5	17
51808	2020-04-19 02:36:58	2020-04-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20011	delivery	5	23
51809	2020-04-19 02:41:07	2020-04-19	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20714	delivery	5	35
51810	2020-04-19 02:41:24	2020-04-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4162	delivery	5	23
51811	2020-04-19 02:52:19	2020-04-19	8	[{"id_menu":5,"count":1}]	2083	pick-up	0	8
51812	2020-04-19 02:53:02	2020-04-19	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	559	delivery	5	36
51813	2020-04-19 02:53:29	2020-04-19	9	[{"id_menu":6,"count":1}]	20697	delivery	5	14
51814	2020-04-19 02:59:17	2020-04-19	9	[{"id_menu":6,"count":1}]	6282	pick-up	0	9
51815	2020-04-19 03:00:22	2020-04-19	12	[{"id_menu":3,"count":1}]	3040	delivery	5	17
51816	2020-04-19 03:00:53	2020-04-19	12	[{"id_menu":1,"count":1}]	12540	delivery	5	17
51817	2020-04-19 03:02:19	2020-04-19	12	[{"id_menu":1,"count":1}]	20746	delivery	5	17
51818	2020-04-19 03:03:07	2020-04-19	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	411	pick-up	0	29
51819	2020-04-19 03:05:47	2020-04-19	12	[{"id_menu":1,"count":1}]	7966	delivery	5	17
51820	2020-04-19 03:09:26	2020-04-19	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	5334	delivery	5	34
51821	2020-04-19 03:11:09	2020-04-19	9	[{"id_menu":6,"count":1}]	20721	delivery	5	14
51822	2020-04-19 03:15:41	2020-04-19	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	20736	delivery	5	26
51823	2020-04-19 03:16:01	2020-04-19	14	[{"id_menu":2,"count":1}]	2087	pick-up	0	14
51824	2020-04-19 03:16:53	2020-04-19	8	[{"id_menu":5,"count":1}]	20614	delivery	5	13
51825	2020-04-19 03:17:01	2020-04-19	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	18519	delivery	5	43
51826	2020-04-19 03:17:48	2020-04-19	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	20694	delivery	5	31
51827	2020-04-19 03:22:52	2020-04-19	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20741	delivery	5	54
51828	2020-04-19 03:24:21	2020-04-19	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9663	delivery	5	48
51829	2020-04-19 03:26:05	2020-04-19	14	[{"id_menu":2,"count":1}]	6962	delivery	5	19
51830	2020-04-19 03:28:35	2020-04-19	9	[{"id_menu":7,"count":1}]	15084	delivery	5	14
51831	2020-04-19 03:28:45	2020-04-19	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20677	pick-up	0	31
51832	2020-04-19 03:30:12	2020-04-19	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20675	delivery	5	34
51833	2020-04-19 03:30:30	2020-04-19	9	[{"id_menu":7,"count":1}]	7882	delivery	5	14
51834	2020-04-19 03:31:48	2020-04-19	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4346	delivery	5	36
51835	2020-04-19 03:34:23	2020-04-19	14	[{"id_menu":2,"count":1}]	20628	delivery	5	19
51836	2020-04-19 03:37:55	2020-04-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	20670	pick-up	0	17
51837	2020-04-19 03:38:51	2020-04-19	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	20737	delivery	5	23
51838	2020-04-19 03:39:27	2020-04-19	8	[{"id_menu":5,"count":1}]	13511	delivery	5	13
51839	2020-04-19 03:43:55	2020-04-19	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	4562	delivery	5	43
51840	2020-04-19 03:44:52	2020-04-19	14	[{"id_menu":2,"count":1}]	20681	delivery	5	19
51841	2020-04-19 03:45:26	2020-04-19	9	[{"id_menu":7,"count":1}]	13899	delivery	5	14
51842	2020-04-19 03:46:46	2020-04-19	12	[{"id_menu":1,"count":1}]	11156	pick-up	0	12
51843	2020-04-19 03:49:54	2020-04-19	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	9975	pick-up	0	26
51844	2020-04-19 03:52:51	2020-04-19	17	[{"id_menu":4,"count":1}]	18468	delivery	5	22
51845	2020-04-19 03:57:10	2020-04-19	9	[{"id_menu":7,"count":1}]	20693	pick-up	0	9
51846	2020-04-19 03:57:13	2020-04-19	14	[{"id_menu":2,"count":1}]	4039	delivery	5	19
51847	2020-04-19 04:06:29	2020-04-19	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8846	delivery	5	31
51848	2020-04-19 04:07:36	2020-04-19	17	[{"id_menu":4,"count":1}]	20716	delivery	5	22
51849	2020-04-19 04:08:51	2020-04-19	12	[{"id_menu":3,"count":1}]	19985	delivery	5	17
51850	2020-04-19 04:10:06	2020-04-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5354	pick-up	0	17
51851	2020-04-19 04:12:40	2020-04-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	5526	pick-up	0	31
51852	2020-04-19 04:12:40	2020-04-19	12	[{"id_menu":3,"count":1}]	6138	pick-up	0	12
51853	2020-04-19 04:19:00	2020-04-19	12	[{"id_menu":1,"count":1}]	1435	pick-up	0	12
51854	2020-04-19 04:23:08	2020-04-19	17	[{"id_menu":4,"count":1}]	18865	delivery	5	22
51855	2020-04-19 04:28:29	2020-04-19	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4996	pick-up	0	21
51856	2020-04-19 04:29:15	2020-04-19	12	[{"id_menu":1,"count":1}]	3105	pick-up	0	12
51857	2020-04-19 04:29:25	2020-04-19	14	[{"id_menu":2,"count":1}]	1653	pick-up	0	14
51858	2020-04-19 04:31:15	2020-04-19	12	[{"id_menu":1,"count":1}]	18445	delivery	5	17
51859	2020-04-19 04:32:14	2020-04-19	14	[{"id_menu":2,"count":2}]	20658	delivery	5	19
51860	2020-04-19 04:33:40	2020-04-19	17	[{"id_menu":4,"count":1}]	401	pick-up	0	17
51861	2020-04-19 04:33:59	2020-04-19	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	153	delivery	5	31
51862	2020-04-19 04:34:08	2020-04-19	9	[{"id_menu":7,"count":1}]	20659	pick-up	0	9
51863	2020-04-19 04:39:10	2020-04-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	20673	delivery	5	28
51864	2020-04-19 04:39:35	2020-04-19	14	[{"id_menu":2,"count":1}]	2731	pick-up	0	14
51865	2020-04-19 04:44:53	2020-04-19	14	[{"id_menu":2,"count":1}]	20700	delivery	5	19
51866	2020-04-19 04:47:59	2020-04-19	9	[{"id_menu":6,"count":1}]	20707	delivery	5	14
51867	2020-04-19 04:51:59	2020-04-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3364	delivery	5	22
51868	2020-04-19 04:55:39	2020-04-19	17	[{"id_menu":4,"count":1}]	10606	pick-up	0	17
51869	2020-04-19 04:57:15	2020-04-19	9	[{"id_menu":6,"count":1}]	8247	delivery	5	14
51870	2020-04-19 05:02:37	2020-04-19	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	20717	delivery	5	27
51871	2020-04-19 05:03:55	2020-04-19	14	[{"id_menu":2,"count":1}]	3848	pick-up	0	14
51872	2020-04-19 05:04:30	2020-04-19	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	9021	delivery	5	26
51873	2020-04-19 05:05:20	2020-04-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20654	delivery	5	23
51874	2020-04-19 05:06:29	2020-04-19	9	[{"id_menu":6,"count":1}]	12228	delivery	5	14
51875	2020-04-19 05:09:21	2020-04-19	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	13432	delivery	5	23
51876	2020-04-19 05:10:51	2020-04-19	8	[{"id_menu":5,"count":1}]	6790	delivery	5	13
51877	2020-04-19 05:15:42	2020-04-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	15907	pick-up	0	23
51878	2020-04-19 05:19:04	2020-04-19	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	20724	delivery	5	34
51879	2020-04-19 05:21:18	2020-04-19	14	[{"id_menu":2,"count":1}]	20629	delivery	5	19
51880	2020-04-19 05:21:48	2020-04-19	12	[{"id_menu":1,"count":1}]	13732	pick-up	0	12
51881	2020-04-19 05:22:02	2020-04-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6465	pick-up	0	31
51882	2020-04-19 05:23:03	2020-04-19	9	[{"id_menu":7,"count":1}]	15859	delivery	5	14
51883	2020-04-19 05:24:09	2020-04-19	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16648	delivery	5	39
51884	2020-04-19 05:25:42	2020-04-19	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20744	delivery	5	39
51885	2020-04-19 05:27:25	2020-04-19	8	[{"id_menu":5,"count":1}]	15044	delivery	5	13
51886	2020-04-19 05:28:58	2020-04-19	12	[{"id_menu":1,"count":1}]	20730	delivery	5	17
51887	2020-04-19 05:36:49	2020-04-19	12	[{"id_menu":3,"count":1}]	6873	delivery	5	17
51888	2020-04-19 05:37:45	2020-04-19	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20727	delivery	5	35
51889	2020-04-19 05:46:47	2020-04-19	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	9307	delivery	5	22
51890	2020-04-19 05:49:01	2020-04-19	12	[{"id_menu":3,"count":1}]	12818	delivery	5	17
51891	2020-04-19 05:49:16	2020-04-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2875	pick-up	0	26
51892	2020-04-19 05:49:45	2020-04-19	9	[{"id_menu":6,"count":1}]	20729	delivery	5	14
51893	2020-04-19 05:50:20	2020-04-19	9	[{"id_menu":7,"count":1}]	10281	delivery	5	14
51894	2020-04-19 05:52:35	2020-04-19	9	[{"id_menu":6,"count":1}]	2191	delivery	5	14
51895	2020-04-19 05:52:48	2020-04-19	17	[{"id_menu":4,"count":1}]	20686	delivery	5	22
51896	2020-04-19 05:52:49	2020-04-19	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	13476	delivery	5	31
51897	2020-04-19 05:53:56	2020-04-19	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	639	delivery	5	27
51898	2020-04-19 05:54:49	2020-04-19	12	[{"id_menu":3,"count":1}]	18399	delivery	5	17
51899	2020-04-19 05:54:55	2020-04-19	8	[{"id_menu":5,"count":1}]	8363	pick-up	0	8
51900	2020-04-19 05:55:18	2020-04-19	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	20657	delivery	5	44
51901	2020-04-19 05:57:22	2020-04-19	12	[{"id_menu":3,"count":1}]	4925	delivery	5	17
51902	2020-04-19 05:57:57	2020-04-19	14	[{"id_menu":2,"count":1}]	20678	delivery	5	19
51903	2020-04-19 05:58:18	2020-04-19	9	[{"id_menu":6,"count":1}]	20699	delivery	5	14
51904	2020-04-19 06:02:28	2020-04-19	14	[{"id_menu":2,"count":1}]	11607	delivery	5	19
51905	2020-04-19 06:02:30	2020-04-19	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	7342	delivery	5	26
51906	2020-04-19 06:03:40	2020-04-19	9	[{"id_menu":7,"count":1}]	8441	delivery	5	14
51907	2020-04-19 06:08:30	2020-04-19	9	[{"id_menu":6,"count":1}]	6883	delivery	5	14
51908	2020-04-19 06:14:33	2020-04-19	9	[{"id_menu":6,"count":1}]	10244	pick-up	0	9
51909	2020-04-19 06:18:48	2020-04-19	12	[{"id_menu":1,"count":1}]	600	pick-up	0	12
51910	2020-04-19 06:20:08	2020-04-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8153	pick-up	0	26
51911	2020-04-19 06:22:56	2020-04-19	8	[{"id_menu":5,"count":1}]	14186	delivery	5	13
51912	2020-04-19 06:23:41	2020-04-19	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17011	delivery	5	57
51913	2020-04-19 06:32:16	2020-04-19	17	[{"id_menu":4,"count":2}]	4459	delivery	5	22
51914	2020-04-19 06:33:22	2020-04-19	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	12255	delivery	5	27
51915	2020-04-19 06:36:20	2020-04-19	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	20620	pick-up	0	34
51916	2020-04-19 06:39:03	2020-04-19	9	[{"id_menu":7,"count":1}]	55	pick-up	0	9
51917	2020-04-19 06:42:36	2020-04-19	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15776	delivery	5	31
51918	2020-04-19 06:44:50	2020-04-19	8	[{"id_menu":5,"count":1}]	14735	pick-up	0	8
51919	2020-04-19 06:49:51	2020-04-19	9	[{"id_menu":6,"count":2}]	13490	delivery	5	14
51920	2020-04-19 06:59:19	2020-04-19	8	[{"id_menu":5,"count":1}]	20668	delivery	5	13
51921	2020-04-19 07:00:09	2020-04-19	17	[{"id_menu":4,"count":1}]	20692	delivery	5	22
51922	2020-04-19 07:01:18	2020-04-19	9	[{"id_menu":6,"count":1}]	20646	delivery	5	14
51923	2020-04-19 07:03:39	2020-04-19	12	[{"id_menu":3,"count":1}]	757	pick-up	0	12
51924	2020-04-19 07:08:16	2020-04-19	9	[{"id_menu":7,"count":2}]	6990	pick-up	0	9
51925	2020-04-19 07:08:48	2020-04-19	8	[{"id_menu":5,"count":1}]	12268	pick-up	0	8
51926	2020-04-19 07:14:04	2020-04-19	12	[{"id_menu":3,"count":1}]	3701	delivery	5	17
51927	2020-04-19 07:17:41	2020-04-19	17	[{"id_menu":4,"count":1}]	4480	pick-up	0	17
51928	2020-04-19 07:19:57	2020-04-19	17	[{"id_menu":4,"count":1}]	16578	delivery	5	22
51929	2020-04-19 07:21:00	2020-04-19	14	[{"id_menu":2,"count":1}]	3535	pick-up	0	14
51930	2020-04-19 07:23:10	2020-04-19	14	[{"id_menu":2,"count":1}]	20680	delivery	5	19
51931	2020-04-19 07:28:09	2020-04-19	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20647	delivery	5	45
51932	2020-04-19 07:28:57	2020-04-19	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2074	delivery	5	49
51933	2020-04-19 07:30:22	2020-04-19	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	9716	pick-up	0	22
51934	2020-04-19 07:34:34	2020-04-19	8	[{"id_menu":5,"count":1}]	8130	delivery	5	13
51935	2020-04-19 07:38:18	2020-04-19	9	[{"id_menu":7,"count":1}]	11470	delivery	5	14
51936	2020-04-19 07:47:18	2020-04-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20623	delivery	5	22
51937	2020-04-19 07:48:24	2020-04-19	8	[{"id_menu":5,"count":1}]	20503	pick-up	0	8
51938	2020-04-19 07:57:01	2020-04-19	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15544	delivery	5	37
51939	2020-04-19 08:02:32	2020-04-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5111	delivery	5	22
51940	2020-04-19 08:05:26	2020-04-19	9	[{"id_menu":7,"count":1}]	20755	delivery	5	14
51941	2020-04-19 08:13:35	2020-04-19	14	[{"id_menu":2,"count":1}]	20579	delivery	5	19
51942	2020-04-19 08:14:27	2020-04-19	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	7994	delivery	5	25
51943	2020-04-19 08:21:14	2020-04-19	12	[{"id_menu":1,"count":1}]	2439	pick-up	0	12
51944	2020-04-19 08:22:55	2020-04-19	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	628	delivery	5	27
51945	2020-04-19 08:25:52	2020-04-19	14	[{"id_menu":2,"count":1}]	14919	delivery	5	19
51946	2020-04-19 08:29:01	2020-04-19	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20743	delivery	5	35
51947	2020-04-19 08:29:02	2020-04-19	12	[{"id_menu":3,"count":1}]	14933	delivery	5	17
51948	2020-04-19 08:29:42	2020-04-19	9	[{"id_menu":6,"count":1}]	2858	delivery	5	14
51949	2020-04-19 08:36:01	2020-04-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20655	delivery	5	22
51950	2020-04-19 08:36:14	2020-04-19	12	[{"id_menu":1,"count":1}]	15156	delivery	5	17
51951	2020-04-19 08:39:48	2020-04-19	9	[{"id_menu":6,"count":1}]	20637	delivery	5	14
51952	2020-04-19 08:40:43	2020-04-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	12935	delivery	5	28
51953	2020-04-19 08:48:52	2020-04-19	9	[{"id_menu":6,"count":2}]	18962	delivery	5	14
51954	2020-04-19 08:59:02	2020-04-19	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13968	delivery	5	43
51955	2020-04-19 09:10:38	2020-04-19	14	[{"id_menu":2,"count":1}]	3898	pick-up	0	14
51956	2020-04-19 09:12:44	2020-04-19	9	[{"id_menu":7,"count":1}]	19302	delivery	5	14
51957	2020-04-19 09:13:07	2020-04-19	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	20667	delivery	5	34
51958	2020-04-19 09:26:55	2020-04-19	8	[{"id_menu":5,"count":1}]	7705	delivery	5	13
51959	2020-04-19 09:27:40	2020-04-19	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	9095	delivery	5	26
51960	2020-04-19 09:28:33	2020-04-19	12	[{"id_menu":1,"count":1}]	2546	pick-up	0	12
51961	2020-04-19 09:32:29	2020-04-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	20462	delivery	5	36
51962	2020-04-19 09:32:43	2020-04-19	14	[{"id_menu":2,"count":1}]	17511	delivery	5	19
51963	2020-04-19 09:32:46	2020-04-19	9	[{"id_menu":7,"count":1}]	15126	delivery	5	14
51964	2020-04-19 09:41:34	2020-04-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	15460	delivery	5	28
51965	2020-04-19 09:45:43	2020-04-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	15682	delivery	5	36
51966	2020-04-19 09:45:52	2020-04-19	8	[{"id_menu":5,"count":1}]	20735	delivery	5	13
51967	2020-04-19 09:46:07	2020-04-19	9	[{"id_menu":7,"count":1}]	20674	delivery	5	14
51968	2020-04-19 09:47:29	2020-04-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	18840	delivery	5	28
51969	2020-04-19 09:51:24	2020-04-19	14	[{"id_menu":2,"count":1}]	20704	delivery	5	19
51970	2020-04-19 10:03:05	2020-04-19	12	[{"id_menu":3,"count":1}]	20671	delivery	5	17
51971	2020-04-19 10:04:02	2020-04-19	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4274	delivery	5	27
51972	2020-04-19 10:04:14	2020-04-19	9	[{"id_menu":6,"count":1}]	20701	delivery	5	14
51973	2020-04-19 10:08:24	2020-04-19	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	19452	delivery	5	25
51974	2020-04-19 10:09:42	2020-04-19	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14293	delivery	5	35
51975	2020-04-19 10:11:11	2020-04-19	9	[{"id_menu":6,"count":2}]	20665	delivery	5	14
51976	2020-04-19 10:12:31	2020-04-19	14	[{"id_menu":2,"count":1}]	7479	delivery	5	19
51977	2020-04-19 10:14:39	2020-04-19	9	[{"id_menu":7,"count":1}]	5408	delivery	5	14
51978	2020-04-19 10:15:40	2020-04-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11938	delivery	5	23
51979	2020-04-19 10:18:24	2020-04-19	9	[{"id_menu":6,"count":1}]	7287	delivery	5	14
51980	2020-04-19 10:21:14	2020-04-19	8	[{"id_menu":5,"count":1}]	14915	delivery	5	13
51981	2020-04-19 10:26:02	2020-04-19	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20641	delivery	5	48
51982	2020-04-19 10:30:04	2020-04-19	12	[{"id_menu":1,"count":1}]	786	delivery	5	17
51983	2020-04-19 10:30:53	2020-04-19	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	20702	delivery	5	38
51984	2020-04-19 10:32:58	2020-04-19	17	[{"id_menu":4,"count":1}]	15360	delivery	5	22
51985	2020-04-19 10:34:08	2020-04-19	9	[{"id_menu":6,"count":1}]	17351	pick-up	0	9
51986	2020-04-19 10:36:01	2020-04-19	9	[{"id_menu":7,"count":1}]	16052	delivery	5	14
51987	2020-04-19 10:38:33	2020-04-19	14	[{"id_menu":2,"count":1}]	14601	pick-up	0	14
51988	2020-04-19 10:41:35	2020-04-19	14	[{"id_menu":2,"count":1}]	2509	delivery	5	19
51989	2020-04-19 10:44:45	2020-04-19	9	[{"id_menu":6,"count":1}]	1067	pick-up	0	9
51990	2020-04-19 10:45:12	2020-04-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7205	delivery	5	31
51991	2020-04-19 10:45:41	2020-04-19	9	[{"id_menu":7,"count":1}]	20663	delivery	5	14
51992	2020-04-19 10:46:28	2020-04-19	8	[{"id_menu":5,"count":1}]	20649	delivery	5	13
51993	2020-04-19 10:47:19	2020-04-19	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8027	delivery	5	31
51994	2020-04-19 10:54:51	2020-04-19	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16974	delivery	5	45
51995	2020-04-19 10:57:18	2020-04-19	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8196	delivery	5	43
51996	2020-04-19 11:00:10	2020-04-19	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	20738	pick-up	0	37
51997	2020-04-19 11:00:47	2020-04-19	9	[{"id_menu":6,"count":1}]	12011	delivery	5	14
51998	2020-04-19 11:01:47	2020-04-19	8	[{"id_menu":5,"count":2}]	20626	delivery	5	13
51999	2020-04-19 11:02:28	2020-04-19	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":3}]	17928	delivery	5	26
52000	2020-04-19 11:11:28	2020-04-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	10873	delivery	5	36
52001	2020-04-19 11:15:56	2020-04-19	12	[{"id_menu":1,"count":1}]	20723	delivery	5	17
52002	2020-04-19 11:20:31	2020-04-19	14	[{"id_menu":2,"count":1}]	16822	delivery	5	19
52003	2020-04-19 11:20:55	2020-04-19	8	[{"id_menu":5,"count":1}]	3409	delivery	5	13
52004	2020-04-19 11:23:01	2020-04-19	9	[{"id_menu":7,"count":1}]	17213	delivery	5	14
52005	2020-04-19 11:28:48	2020-04-19	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2836	pick-up	0	38
52006	2020-04-19 11:28:55	2020-04-19	8	[{"id_menu":5,"count":1}]	14592	delivery	5	13
52007	2020-04-19 11:33:36	2020-04-19	17	[{"id_menu":4,"count":1}]	16226	pick-up	0	17
52008	2020-04-19 11:37:31	2020-04-19	9	[{"id_menu":6,"count":1}]	20640	delivery	5	14
52009	2020-04-19 11:39:38	2020-04-19	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	9053	pick-up	0	21
52010	2020-04-19 11:40:54	2020-04-19	8	[{"id_menu":5,"count":2}]	20656	delivery	5	13
52011	2020-04-19 11:40:59	2020-04-19	12	[{"id_menu":3,"count":1}]	20739	delivery	5	17
52012	2020-04-19 11:41:05	2020-04-19	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	19490	delivery	5	26
52013	2020-04-19 11:41:27	2020-04-19	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	13923	delivery	5	27
52014	2020-04-19 11:41:33	2020-04-19	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14173	delivery	5	45
52015	2020-04-19 11:41:56	2020-04-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8966	pick-up	0	26
52016	2020-04-19 11:48:25	2020-04-19	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20644	delivery	5	39
52017	2020-04-19 11:49:54	2020-04-19	8	[{"id_menu":5,"count":1}]	16042	pick-up	0	8
52018	2020-04-19 11:50:10	2020-04-19	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1626	delivery	5	45
52019	2020-04-19 11:55:28	2020-04-19	17	[{"id_menu":4,"count":1}]	18090	delivery	5	22
52020	2020-04-19 11:58:54	2020-04-19	17	[{"id_menu":4,"count":1}]	7193	pick-up	0	17
52021	2020-04-19 11:59:45	2020-04-19	8	[{"id_menu":5,"count":1}]	17254	delivery	5	13
52022	2020-04-19 12:00:35	2020-04-19	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12700	delivery	5	35
52023	2020-04-19 12:03:39	2020-04-19	8	[{"id_menu":5,"count":1}]	4248	delivery	5	13
52024	2020-04-19 12:04:06	2020-04-19	12	[{"id_menu":1,"count":1}]	18294	delivery	5	17
52025	2020-04-19 12:05:19	2020-04-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	9106	pick-up	0	23
52026	2020-04-19 12:05:37	2020-04-19	12	[{"id_menu":1,"count":1}]	4628	pick-up	0	12
52027	2020-04-19 12:06:02	2020-04-19	9	[{"id_menu":6,"count":1}]	16363	delivery	5	14
52028	2020-04-19 12:08:33	2020-04-19	8	[{"id_menu":5,"count":1}]	18171	delivery	5	13
52029	2020-04-19 12:20:49	2020-04-19	12	[{"id_menu":3,"count":1}]	11686	pick-up	0	12
52030	2020-04-19 12:21:46	2020-04-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	10238	delivery	5	28
52031	2020-04-19 12:21:53	2020-04-19	17	[{"id_menu":4,"count":1}]	13795	delivery	5	22
52032	2020-04-19 12:22:19	2020-04-19	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20689	delivery	5	35
52033	2020-04-19 12:27:42	2020-04-19	14	[{"id_menu":2,"count":1}]	7280	delivery	5	19
52034	2020-04-19 12:27:46	2020-04-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9804	pick-up	0	26
52035	2020-04-19 12:31:07	2020-04-19	9	[{"id_menu":6,"count":1}]	4324	delivery	5	14
52036	2020-04-19 12:31:25	2020-04-19	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	20691	delivery	5	40
52037	2020-04-19 12:32:50	2020-04-19	9	[{"id_menu":7,"count":1}]	11183	pick-up	0	9
52038	2020-04-19 12:35:34	2020-04-19	12	[{"id_menu":1,"count":1}]	7726	pick-up	0	12
52039	2020-04-19 12:40:51	2020-04-19	8	[{"id_menu":5,"count":1}]	20745	pick-up	0	8
52040	2020-04-19 12:41:42	2020-04-19	12	[{"id_menu":1,"count":1}]	20719	delivery	5	17
52041	2020-04-19 12:44:42	2020-04-19	9	[{"id_menu":6,"count":1}]	20682	delivery	5	14
52042	2020-04-19 12:44:53	2020-04-19	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	20107	pick-up	0	22
52043	2020-04-19 12:56:24	2020-04-19	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3567	pick-up	0	26
52044	2020-04-19 12:56:55	2020-04-19	9	[{"id_menu":7,"count":1}]	19909	delivery	5	14
52045	2020-04-19 13:05:40	2020-04-19	9	[{"id_menu":6,"count":1}]	20718	delivery	5	14
52046	2020-04-19 13:12:36	2020-04-19	8	[{"id_menu":5,"count":1}]	8417	delivery	5	13
52047	2020-04-19 13:14:07	2020-04-19	12	[{"id_menu":3,"count":1}]	10212	pick-up	0	12
52048	2020-04-19 13:14:21	2020-04-19	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8036	delivery	5	40
52049	2020-04-19 13:15:24	2020-04-19	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	19857	delivery	5	26
52050	2020-04-19 13:15:51	2020-04-19	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	2567	pick-up	0	22
52051	2020-04-19 13:16:24	2020-04-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6609	pick-up	0	17
52052	2020-04-19 13:18:37	2020-04-19	12	[{"id_menu":1,"count":1}]	2907	delivery	5	17
52053	2020-04-19 13:18:42	2020-04-19	17	[{"id_menu":4,"count":1}]	15604	delivery	5	22
52054	2020-04-19 13:20:48	2020-04-19	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12718	delivery	5	52
52055	2020-04-19 13:21:06	2020-04-19	17	[{"id_menu":4,"count":2}]	20216	pick-up	0	17
52056	2020-04-19 13:25:42	2020-04-19	8	[{"id_menu":5,"count":1}]	8300	pick-up	0	8
52057	2020-04-19 13:28:26	2020-04-19	8	[{"id_menu":5,"count":1}]	1113	pick-up	0	8
52058	2020-04-19 13:31:01	2020-04-19	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	13240	delivery	5	26
52059	2020-04-19 13:35:11	2020-04-19	17	[{"id_menu":4,"count":1}]	6948	delivery	5	22
52060	2020-04-19 13:38:18	2020-04-19	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	5706	delivery	5	34
52061	2020-04-19 13:39:19	2020-04-19	8	[{"id_menu":5,"count":1}]	14086	pick-up	0	8
52062	2020-04-19 13:40:29	2020-04-19	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19135	delivery	5	40
52063	2020-04-19 13:43:26	2020-04-19	9	[{"id_menu":7,"count":1}]	1683	delivery	5	14
52064	2020-04-19 13:43:44	2020-04-19	14	[{"id_menu":2,"count":1}]	20747	pick-up	0	14
52065	2020-04-19 13:48:15	2020-04-19	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8233	delivery	5	44
52066	2020-04-19 13:49:22	2020-04-19	14	[{"id_menu":2,"count":1}]	18047	pick-up	0	14
52067	2020-04-19 13:51:16	2020-04-19	17	[{"id_menu":4,"count":1}]	4081	pick-up	0	17
52068	2020-04-19 13:51:21	2020-04-19	17	[{"id_menu":4,"count":1}]	1050	delivery	5	22
52069	2020-04-19 13:54:20	2020-04-19	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2938	pick-up	0	21
52070	2020-04-19 13:54:38	2020-04-19	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	11802	delivery	5	26
52071	2020-04-19 13:57:46	2020-04-19	9	[{"id_menu":6,"count":1}]	20712	delivery	5	14
52072	2020-04-19 13:57:48	2020-04-19	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	10484	delivery	5	31
52073	2020-04-19 14:03:41	2020-04-19	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20648	delivery	5	37
52074	2020-04-19 14:08:46	2020-04-19	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15284	delivery	5	43
52075	2020-04-19 14:13:07	2020-04-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13738	delivery	5	22
52076	2020-04-19 14:17:38	2020-04-19	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	20650	delivery	5	40
52077	2020-04-19 14:18:33	2020-04-19	12	[{"id_menu":3,"count":1}]	8336	delivery	5	17
52078	2020-04-19 14:19:08	2020-04-19	14	[{"id_menu":2,"count":1}]	5548	pick-up	0	14
52079	2020-04-19 14:23:43	2020-04-19	12	[{"id_menu":3,"count":1}]	8755	pick-up	0	12
52080	2020-04-19 14:25:19	2020-04-19	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	20690	pick-up	0	21
52081	2020-04-19 14:28:53	2020-04-19	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	352	pick-up	0	21
52082	2020-04-19 14:28:54	2020-04-19	9	[{"id_menu":7,"count":1}]	9388	delivery	5	14
52083	2020-04-19 14:29:37	2020-04-19	9	[{"id_menu":7,"count":1}]	4403	delivery	5	14
52084	2020-04-19 14:35:32	2020-04-19	12	[{"id_menu":3,"count":1}]	13370	pick-up	0	12
52085	2020-04-19 14:37:18	2020-04-19	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":3}]	6960	delivery	5	31
52086	2020-04-19 14:37:29	2020-04-19	12	[{"id_menu":1,"count":1}]	6331	delivery	5	17
52087	2020-04-19 14:37:35	2020-04-19	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	6915	delivery	5	31
52088	2020-04-19 14:41:08	2020-04-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	2712	delivery	5	22
52089	2020-04-19 14:44:44	2020-04-19	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	11146	pick-up	0	21
52090	2020-04-19 14:46:16	2020-04-19	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	3341	delivery	5	26
52091	2020-04-19 14:50:12	2020-04-19	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	6046	delivery	5	48
52092	2020-04-19 14:55:57	2020-04-19	8	[{"id_menu":5,"count":1}]	20710	delivery	5	13
52093	2020-04-19 14:56:06	2020-04-19	8	[{"id_menu":5,"count":1}]	15566	pick-up	0	8
52094	2020-04-19 14:56:35	2020-04-19	14	[{"id_menu":2,"count":2}]	3590	delivery	5	19
52095	2020-04-19 15:02:48	2020-04-19	9	[{"id_menu":6,"count":1}]	13184	delivery	5	14
52096	2020-04-19 15:18:35	2020-04-19	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	20666	delivery	5	45
52097	2020-04-19 15:19:14	2020-04-19	14	[{"id_menu":2,"count":1}]	1222	pick-up	0	14
52098	2020-04-19 15:20:30	2020-04-19	17	[{"id_menu":4,"count":1}]	20749	delivery	5	22
52099	2020-04-19 15:22:46	2020-04-19	9	[{"id_menu":7,"count":1}]	5502	delivery	5	14
52100	2020-04-19 15:23:57	2020-04-19	9	[{"id_menu":6,"count":1}]	14258	pick-up	0	9
52101	2020-04-19 15:24:52	2020-04-19	9	[{"id_menu":7,"count":1}]	5202	delivery	5	14
52102	2020-04-19 15:26:03	2020-04-19	12	[{"id_menu":1,"count":1}]	20664	pick-up	0	12
52103	2020-04-19 15:28:42	2020-04-19	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	20753	delivery	5	40
52104	2020-04-19 15:29:17	2020-04-19	12	[{"id_menu":3,"count":1}]	1924	pick-up	0	12
52105	2020-04-19 15:41:33	2020-04-19	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7595	pick-up	0	29
52106	2020-04-19 15:42:17	2020-04-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20359	delivery	5	23
52107	2020-04-19 15:43:27	2020-04-19	9	[{"id_menu":6,"count":1}]	20705	delivery	5	14
52108	2020-04-19 15:46:29	2020-04-19	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	20642	delivery	5	43
52109	2020-04-19 15:50:31	2020-04-19	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	20631	delivery	5	31
52110	2020-04-19 15:52:34	2020-04-19	17	[{"id_menu":4,"count":1}]	1526	pick-up	0	17
52111	2020-04-19 15:57:43	2020-04-19	9	[{"id_menu":7,"count":1}]	20698	delivery	5	14
52112	2020-04-19 15:58:09	2020-04-19	14	[{"id_menu":2,"count":1}]	20687	delivery	5	19
52113	2020-04-19 15:58:12	2020-04-19	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	6231	delivery	5	25
52114	2020-04-19 16:00:22	2020-04-19	17	[{"id_menu":4,"count":1}]	11395	delivery	5	22
52115	2020-04-19 16:06:10	2020-04-19	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	10101	delivery	5	26
52116	2020-04-19 16:07:40	2020-04-19	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	7485	delivery	5	25
52117	2020-04-19 16:07:55	2020-04-19	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	20748	delivery	5	40
52118	2020-04-19 16:10:43	2020-04-19	12	[{"id_menu":1,"count":1}]	3123	pick-up	0	12
52119	2020-04-19 16:11:00	2020-04-19	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	20652	delivery	5	22
52120	2020-04-19 16:15:58	2020-04-19	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	13438	delivery	5	38
52121	2020-04-19 16:29:49	2020-04-19	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	20635	delivery	5	34
52122	2020-04-19 16:29:53	2020-04-19	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	6748	delivery	5	28
52123	2020-04-19 16:31:03	2020-04-19	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	20726	delivery	5	52
52124	2020-04-19 16:34:28	2020-04-19	9	[{"id_menu":7,"count":1}]	20618	delivery	5	14
52125	2020-04-19 16:39:37	2020-04-19	12	[{"id_menu":1,"count":1}]	20183	delivery	5	17
52126	2020-04-19 16:42:55	2020-04-19	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	7853	delivery	5	27
52127	2020-04-19 16:47:36	2020-04-19	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	18723	pick-up	0	38
52128	2020-04-19 16:47:37	2020-04-19	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	20636	delivery	5	31
52129	2020-04-19 16:53:46	2020-04-19	9	[{"id_menu":7,"count":1}]	20643	delivery	5	14
52130	2020-04-19 16:59:43	2020-04-19	14	[{"id_menu":2,"count":1}]	5413	delivery	5	19
52131	2020-04-19 17:02:07	2020-04-19	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	788	pick-up	0	25
52132	2020-04-19 17:03:45	2020-04-19	17	[{"id_menu":4,"count":1}]	20639	delivery	5	22
52133	2020-04-19 17:04:18	2020-04-19	14	[{"id_menu":2,"count":1}]	15430	delivery	5	19
52134	2020-04-19 17:08:45	2020-04-19	12	[{"id_menu":3,"count":1}]	20708	delivery	5	17
52135	2020-04-19 17:09:18	2020-04-19	9	[{"id_menu":6,"count":1}]	20695	delivery	5	14
52136	2020-04-19 17:14:30	2020-04-19	14	[{"id_menu":2,"count":1}]	5248	pick-up	0	14
52137	2020-04-19 17:20:23	2020-04-19	9	[{"id_menu":7,"count":1}]	20615	delivery	5	14
52138	2020-04-19 17:22:47	2020-04-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19301	delivery	5	22
52139	2020-04-19 17:23:05	2020-04-19	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	10354	delivery	5	38
52140	2020-04-19 17:24:04	2020-04-19	12	[{"id_menu":3,"count":1}]	19745	delivery	5	17
52141	2020-04-19 17:26:03	2020-04-19	8	[{"id_menu":5,"count":1}]	3352	pick-up	0	8
52142	2020-04-19 17:27:12	2020-04-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	19284	delivery	5	31
52143	2020-04-19 17:28:48	2020-04-19	14	[{"id_menu":2,"count":1}]	20715	pick-up	0	14
52144	2020-04-19 17:29:58	2020-04-19	12	[{"id_menu":1,"count":1}]	7262	delivery	5	17
52145	2020-04-19 17:31:11	2020-04-19	9	[{"id_menu":6,"count":1}]	20722	delivery	5	14
52146	2020-04-19 17:31:14	2020-04-19	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	3923	delivery	5	30
52147	2020-04-19 17:31:16	2020-04-19	12	[{"id_menu":1,"count":1}]	15507	delivery	5	17
52148	2020-04-19 17:33:01	2020-04-19	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	20734	delivery	5	25
52149	2020-04-19 17:33:12	2020-04-19	9	[{"id_menu":7,"count":1}]	3558	delivery	5	14
52150	2020-04-19 17:34:38	2020-04-19	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16896	delivery	5	45
52151	2020-04-19 17:35:12	2020-04-19	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1548	pick-up	0	38
52152	2020-04-19 17:35:35	2020-04-19	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3997	delivery	5	40
52153	2020-04-19 17:36:16	2020-04-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	981	pick-up	0	17
52154	2020-04-19 17:37:02	2020-04-19	9	[{"id_menu":7,"count":1}]	20630	delivery	5	14
52155	2020-04-19 17:38:16	2020-04-19	9	[{"id_menu":6,"count":1}]	14954	delivery	5	14
52156	2020-04-19 17:38:22	2020-04-19	9	[{"id_menu":7,"count":1}]	10387	pick-up	0	9
52157	2020-04-19 17:44:56	2020-04-19	8	[{"id_menu":5,"count":1}]	15686	pick-up	0	8
52158	2020-04-19 17:46:00	2020-04-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2139	delivery	5	22
52159	2020-04-19 17:46:16	2020-04-19	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6728	delivery	5	31
52160	2020-04-19 17:46:30	2020-04-19	12	[{"id_menu":1,"count":1}]	2413	pick-up	0	12
52161	2020-04-19 17:48:14	2020-04-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6564	delivery	5	28
52162	2020-04-19 17:48:42	2020-04-19	9	[{"id_menu":6,"count":1}]	2009	delivery	5	14
52163	2020-04-19 17:51:40	2020-04-19	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	19628	delivery	5	42
52164	2020-04-19 17:57:43	2020-04-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	19322	delivery	5	36
52165	2020-04-19 17:58:14	2020-04-19	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	20676	pick-up	0	22
52166	2020-04-19 17:58:17	2020-04-19	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	20080	delivery	5	34
52167	2020-04-19 18:02:06	2020-04-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3622	delivery	5	28
52168	2020-04-19 18:05:30	2020-04-19	17	[{"id_menu":4,"count":1}]	11616	delivery	5	22
52169	2020-04-19 18:06:22	2020-04-19	14	[{"id_menu":2,"count":1}]	20669	pick-up	0	14
52170	2020-04-19 18:08:46	2020-04-19	12	[{"id_menu":3,"count":1}]	20653	delivery	5	17
52171	2020-04-19 18:13:02	2020-04-19	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	20751	delivery	5	27
52172	2020-04-19 18:22:26	2020-04-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9103	delivery	5	22
52173	2020-04-19 18:25:52	2020-04-19	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	19847	delivery	5	26
52174	2020-04-19 18:26:14	2020-04-19	9	[{"id_menu":6,"count":1}]	16259	delivery	5	14
52175	2020-04-19 18:34:29	2020-04-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	17874	pick-up	0	17
52176	2020-04-19 18:35:18	2020-04-19	9	[{"id_menu":7,"count":1}]	4302	delivery	5	14
52177	2020-04-19 18:36:51	2020-04-19	9	[{"id_menu":6,"count":1}]	15547	pick-up	0	9
52178	2020-04-19 18:41:53	2020-04-19	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	6444	delivery	5	25
52179	2020-04-19 18:43:17	2020-04-19	12	[{"id_menu":1,"count":1}]	18652	pick-up	0	12
52180	2020-04-19 18:44:41	2020-04-19	14	[{"id_menu":2,"count":1}]	8543	delivery	5	19
52181	2020-04-19 18:46:16	2020-04-19	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	19334	delivery	5	40
52182	2020-04-19 18:46:54	2020-04-19	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	20625	pick-up	0	20
52183	2020-04-19 18:47:15	2020-04-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20633	delivery	5	23
52184	2020-04-19 18:48:44	2020-04-19	9	[{"id_menu":6,"count":2}]	20709	delivery	5	14
52185	2020-04-19 18:56:11	2020-04-19	17	[{"id_menu":4,"count":1}]	20627	delivery	5	22
52186	2020-04-19 18:58:27	2020-04-19	14	[{"id_menu":2,"count":1}]	3851	delivery	5	19
52187	2020-04-19 19:06:26	2020-04-19	14	[{"id_menu":2,"count":1}]	20713	delivery	5	19
52188	2020-04-19 19:06:55	2020-04-19	17	[{"id_menu":4,"count":1}]	5972	delivery	5	22
52189	2020-04-19 19:08:59	2020-04-19	12	[{"id_menu":1,"count":1}]	3122	delivery	5	17
52190	2020-04-19 19:11:46	2020-04-19	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	17176	delivery	5	39
52191	2020-04-19 19:13:57	2020-04-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20706	delivery	5	22
52192	2020-04-19 19:17:13	2020-04-19	12	[{"id_menu":1,"count":1}]	9467	pick-up	0	12
52193	2020-04-19 19:17:21	2020-04-19	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5236	delivery	5	31
52194	2020-04-19 19:17:55	2020-04-19	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16939	delivery	5	34
52195	2020-04-19 19:19:34	2020-04-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	10147	delivery	5	28
52196	2020-04-19 19:20:25	2020-04-19	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10072	delivery	5	34
52197	2020-04-19 19:20:40	2020-04-19	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	754	pick-up	0	31
52198	2020-04-19 19:21:41	2020-04-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19817	delivery	5	23
52199	2020-04-19 19:22:24	2020-04-19	8	[{"id_menu":5,"count":1}]	15823	delivery	5	13
52200	2020-04-19 19:23:08	2020-04-19	9	[{"id_menu":6,"count":1}]	12696	delivery	5	14
52201	2020-04-19 19:25:39	2020-04-19	8	[{"id_menu":5,"count":1}]	4448	delivery	5	13
52202	2020-04-19 19:25:42	2020-04-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20711	delivery	5	22
52203	2020-04-19 19:28:13	2020-04-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	20733	delivery	5	22
52204	2020-04-19 19:31:16	2020-04-19	9	[{"id_menu":6,"count":1}]	17887	delivery	5	14
52205	2020-04-19 19:39:44	2020-04-19	12	[{"id_menu":3,"count":1}]	2633	delivery	5	17
52206	2020-04-19 19:39:58	2020-04-19	12	[{"id_menu":3,"count":1}]	20622	delivery	5	17
52207	2020-04-19 19:40:09	2020-04-19	9	[{"id_menu":6,"count":1}]	11921	delivery	5	14
52208	2020-04-19 19:43:12	2020-04-19	9	[{"id_menu":7,"count":1}]	6775	pick-up	0	9
52209	2020-04-19 19:55:23	2020-04-19	17	[{"id_menu":4,"count":1}]	20651	delivery	5	22
52210	2020-04-19 19:57:34	2020-04-19	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2659	pick-up	0	21
52211	2020-04-19 19:57:46	2020-04-19	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10180	delivery	5	37
52212	2020-04-19 20:00:10	2020-04-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	12455	delivery	5	36
52213	2020-04-19 20:03:09	2020-04-19	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	10578	delivery	5	34
52214	2020-04-19 20:04:10	2020-04-19	14	[{"id_menu":2,"count":1}]	7527	pick-up	0	14
52215	2020-04-19 20:05:33	2020-04-19	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13236	delivery	5	34
52216	2020-04-19 20:11:55	2020-04-19	9	[{"id_menu":7,"count":1}]	111	delivery	5	14
52217	2020-04-19 20:13:46	2020-04-19	14	[{"id_menu":2,"count":1}]	2916	pick-up	0	14
52218	2020-04-19 20:16:12	2020-04-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19432	delivery	5	23
52219	2020-04-19 20:22:17	2020-04-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	16461	pick-up	0	31
52220	2020-04-19 20:25:01	2020-04-19	17	[{"id_menu":4,"count":1}]	6590	delivery	5	22
52221	2020-04-19 20:25:16	2020-04-19	33	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1070	delivery	5	38
52222	2020-04-19 20:26:43	2020-04-19	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	4673	pick-up	0	29
52223	2020-04-19 20:27:40	2020-04-19	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	16829	delivery	5	27
52224	2020-04-19 20:29:20	2020-04-19	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	12091	delivery	5	23
52225	2020-04-19 20:35:56	2020-04-19	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	3010	pick-up	0	21
52226	2020-04-19 20:40:06	2020-04-19	9	[{"id_menu":6,"count":1}]	20725	pick-up	0	9
52227	2020-04-19 20:41:30	2020-04-19	9	[{"id_menu":6,"count":1}]	584	pick-up	0	9
52228	2020-04-19 20:42:29	2020-04-19	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13994	delivery	5	45
52229	2020-04-19 20:43:02	2020-04-19	12	[{"id_menu":1,"count":1}]	20522	delivery	5	17
52230	2020-04-19 20:46:59	2020-04-19	14	[{"id_menu":2,"count":1}]	17641	pick-up	0	14
52231	2020-04-19 20:48:02	2020-04-19	17	[{"id_menu":4,"count":1}]	8843	delivery	5	22
52232	2020-04-19 20:48:06	2020-04-19	12	[{"id_menu":3,"count":1}]	14202	delivery	5	17
52233	2020-04-19 20:48:55	2020-04-19	14	[{"id_menu":2,"count":2}]	20619	delivery	5	19
52234	2020-04-19 20:56:00	2020-04-19	14	[{"id_menu":2,"count":1}]	17794	delivery	5	19
52235	2020-04-19 20:56:20	2020-04-19	8	[{"id_menu":5,"count":1}]	5149	delivery	5	13
52236	2020-04-19 20:59:43	2020-04-19	9	[{"id_menu":7,"count":1}]	13261	delivery	5	14
52237	2020-04-19 21:00:51	2020-04-19	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	20617	delivery	5	31
52238	2020-04-19 21:07:06	2020-04-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15851	pick-up	0	26
52239	2020-04-19 21:10:39	2020-04-19	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	13082	delivery	5	34
52240	2020-04-19 21:11:27	2020-04-19	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12615	delivery	5	43
52241	2020-04-19 21:13:28	2020-04-19	9	[{"id_menu":6,"count":1}]	4234	delivery	5	14
52242	2020-04-19 21:13:35	2020-04-19	17	[{"id_menu":4,"count":1}]	8700	delivery	5	22
52243	2020-04-19 21:15:59	2020-04-19	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1481	pick-up	0	24
52244	2020-04-19 21:18:10	2020-04-19	17	[{"id_menu":4,"count":1}]	9691	pick-up	0	17
52245	2020-04-19 21:19:26	2020-04-19	14	[{"id_menu":2,"count":1}]	20573	delivery	5	19
52246	2020-04-19 21:22:09	2020-04-19	9	[{"id_menu":7,"count":1}]	10365	delivery	5	14
52247	2020-04-19 21:27:15	2020-04-19	9	[{"id_menu":6,"count":1}]	20624	delivery	5	14
52248	2020-04-19 21:29:38	2020-04-19	12	[{"id_menu":1,"count":2}]	16737	pick-up	0	12
52249	2020-04-19 21:30:40	2020-04-19	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	6807	pick-up	0	22
52250	2020-04-19 21:32:38	2020-04-19	12	[{"id_menu":3,"count":1}]	7831	delivery	5	17
52251	2020-04-19 21:40:43	2020-04-19	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	7298	delivery	5	28
52252	2020-04-19 21:42:00	2020-04-19	9	[{"id_menu":6,"count":1}]	9419	delivery	5	14
52253	2020-04-19 21:42:08	2020-04-19	8	[{"id_menu":5,"count":1}]	11914	pick-up	0	8
52254	2020-04-19 21:42:35	2020-04-19	14	[{"id_menu":2,"count":1}]	20632	delivery	5	19
52255	2020-04-19 21:43:34	2020-04-19	14	[{"id_menu":2,"count":1}]	12676	delivery	5	19
52256	2020-04-19 21:44:28	2020-04-19	14	[{"id_menu":2,"count":1}]	3065	pick-up	0	14
52257	2020-04-19 21:51:16	2020-04-19	8	[{"id_menu":5,"count":1}]	2520	pick-up	0	8
52258	2020-04-19 22:03:42	2020-04-19	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	20684	delivery	5	40
52259	2020-04-19 22:04:11	2020-04-19	17	[{"id_menu":4,"count":1}]	11793	pick-up	0	17
52260	2020-04-19 22:06:11	2020-04-19	9	[{"id_menu":6,"count":1}]	408	pick-up	0	9
52261	2020-04-19 22:12:41	2020-04-19	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	4897	delivery	5	28
52262	2020-04-19 22:13:12	2020-04-19	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13799	delivery	5	37
52263	2020-04-19 22:14:19	2020-04-19	9	[{"id_menu":7,"count":1}]	4299	delivery	5	14
52264	2020-04-19 22:15:41	2020-04-19	17	[{"id_menu":4,"count":1}]	1413	pick-up	0	17
52265	2020-04-19 22:16:05	2020-04-19	9	[{"id_menu":6,"count":1}]	20752	delivery	5	14
52266	2020-04-19 22:16:24	2020-04-19	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	11181	delivery	5	26
52267	2020-04-19 22:17:01	2020-04-19	12	[{"id_menu":3,"count":1}]	9375	delivery	5	17
52268	2020-04-19 22:19:44	2020-04-19	9	[{"id_menu":6,"count":1}]	20696	delivery	5	14
52269	2020-04-19 22:19:55	2020-04-19	17	[{"id_menu":4,"count":1}]	13656	delivery	5	22
52270	2020-04-19 22:20:01	2020-04-19	8	[{"id_menu":5,"count":1}]	20660	delivery	5	13
52271	2020-04-19 22:24:46	2020-04-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7746	pick-up	0	26
52272	2020-04-19 22:26:08	2020-04-19	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	7530	delivery	5	31
52273	2020-04-19 22:27:55	2020-04-19	9	[{"id_menu":7,"count":1}]	20672	delivery	5	14
52274	2020-04-19 22:29:19	2020-04-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7050	delivery	5	28
52275	2020-04-19 22:31:48	2020-04-19	8	[{"id_menu":5,"count":1}]	20661	delivery	5	13
52276	2020-04-19 22:36:40	2020-04-19	9	[{"id_menu":7,"count":1}]	3759	delivery	5	14
52277	2020-04-19 22:39:29	2020-04-19	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3544	pick-up	0	26
52278	2020-04-19 22:39:59	2020-04-19	14	[{"id_menu":2,"count":1}]	9632	delivery	5	19
52279	2020-04-19 22:40:29	2020-04-19	14	[{"id_menu":2,"count":1}]	20720	delivery	5	19
52280	2020-04-19 22:44:00	2020-04-19	14	[{"id_menu":2,"count":1}]	20703	delivery	5	19
52281	2020-04-19 22:46:56	2020-04-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8866	delivery	5	23
52282	2020-04-19 22:47:07	2020-04-19	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	15140	delivery	5	26
52283	2020-04-19 22:47:54	2020-04-19	9	[{"id_menu":6,"count":1}]	3251	pick-up	0	9
52284	2020-04-19 22:49:51	2020-04-19	17	[{"id_menu":4,"count":1}]	4281	delivery	5	22
52285	2020-04-19 22:51:17	2020-04-19	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	3125	delivery	5	34
52286	2020-04-19 22:53:57	2020-04-19	8	[{"id_menu":5,"count":1}]	20685	delivery	5	13
52287	2020-04-19 22:55:33	2020-04-19	8	[{"id_menu":5,"count":1}]	6082	delivery	5	13
52288	2020-04-19 22:56:35	2020-04-19	9	[{"id_menu":6,"count":2}]	9342	pick-up	0	9
52289	2020-04-19 22:58:33	2020-04-19	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	15001	delivery	5	25
52290	2020-04-19 23:04:02	2020-04-19	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7821	delivery	5	31
52291	2020-04-19 23:05:13	2020-04-19	26	[{"id_menu":4,"count":3},{"id_menu":7,"count":1}]	20757	delivery	5	31
52292	2020-04-19 23:07:13	2020-04-19	12	[{"id_menu":3,"count":1}]	20732	delivery	5	17
52293	2020-04-19 23:09:06	2020-04-19	14	[{"id_menu":2,"count":1}]	19950	delivery	5	19
52294	2020-04-19 23:09:54	2020-04-19	14	[{"id_menu":2,"count":1}]	2437	pick-up	0	14
52295	2020-04-19 23:13:04	2020-04-19	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	16394	pick-up	0	21
52296	2020-04-19 23:13:37	2020-04-19	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	18150	delivery	5	39
52297	2020-04-19 23:20:31	2020-04-19	9	[{"id_menu":7,"count":1}]	12372	delivery	5	14
52298	2020-04-19 23:23:12	2020-04-19	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	20662	delivery	5	34
52299	2020-04-19 23:24:36	2020-04-19	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	7388	delivery	5	34
52300	2020-04-19 23:26:01	2020-04-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	11690	delivery	5	28
52301	2020-04-19 23:28:32	2020-04-19	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	3000	delivery	5	31
52302	2020-04-19 23:29:10	2020-04-19	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	20740	delivery	5	43
52303	2020-04-19 23:39:13	2020-04-19	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	11376	delivery	5	27
52304	2020-04-19 23:39:53	2020-04-19	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	19994	delivery	5	34
52305	2020-04-19 23:40:36	2020-04-19	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	8773	pick-up	0	21
52306	2020-04-19 23:46:27	2020-04-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20688	pick-up	0	18
52307	2020-04-19 23:48:23	2020-04-19	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2519	delivery	5	26
52308	2020-04-19 23:48:45	2020-04-19	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11518	pick-up	0	47
52309	2020-04-19 23:51:05	2020-04-19	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7566	pick-up	0	38
52310	2020-04-19 23:54:00	2020-04-19	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":3}]	12160	delivery	5	26
52311	2020-04-19 23:54:50	2020-04-19	12	[{"id_menu":1,"count":1}]	20756	delivery	5	17
52312	2020-04-20 00:11:54	2020-04-20	39	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	19760	delivery	5	44
52313	2020-04-20 00:13:05	2020-04-20	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	20852	delivery	5	43
52314	2020-04-20 00:14:24	2020-04-20	12	[{"id_menu":1,"count":1}]	20893	delivery	5	17
52315	2020-04-20 00:14:43	2020-04-20	9	[{"id_menu":6,"count":1}]	20817	delivery	5	14
52316	2020-04-20 00:15:37	2020-04-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20905	pick-up	0	18
52317	2020-04-20 00:19:40	2020-04-20	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	17688	pick-up	0	20
52386	2020-04-20 05:00:15	2020-04-20	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16761	pick-up	0	26
52318	2020-04-20 00:25:18	2020-04-20	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20768	delivery	5	48
52319	2020-04-20 00:31:26	2020-04-20	9	[{"id_menu":7,"count":1}]	2394	delivery	5	14
52320	2020-04-20 00:32:53	2020-04-20	17	[{"id_menu":4,"count":1}]	18271	delivery	5	22
52321	2020-04-20 00:33:30	2020-04-20	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14864	delivery	5	45
52322	2020-04-20 00:37:15	2020-04-20	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	19348	delivery	5	31
52323	2020-04-20 00:39:08	2020-04-20	17	[{"id_menu":4,"count":1}]	203	pick-up	0	17
52324	2020-04-20 00:41:45	2020-04-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	20848	delivery	5	28
52325	2020-04-20 00:41:46	2020-04-20	12	[{"id_menu":1,"count":1}]	18304	pick-up	0	12
52326	2020-04-20 00:48:08	2020-04-20	17	[{"id_menu":4,"count":1}]	766	pick-up	0	17
52327	2020-04-20 00:48:18	2020-04-20	9	[{"id_menu":7,"count":1}]	16270	delivery	5	14
52328	2020-04-20 00:54:30	2020-04-20	17	[{"id_menu":4,"count":1}]	12378	delivery	5	22
52329	2020-04-20 00:55:45	2020-04-20	9	[{"id_menu":7,"count":1}]	7917	delivery	5	14
52330	2020-04-20 00:57:12	2020-04-20	17	[{"id_menu":4,"count":1}]	11383	pick-up	0	17
52331	2020-04-20 01:11:19	2020-04-20	17	[{"id_menu":4,"count":1}]	20353	pick-up	0	17
52332	2020-04-20 01:21:02	2020-04-20	14	[{"id_menu":2,"count":1}]	14134	delivery	5	19
52333	2020-04-20 01:21:29	2020-04-20	12	[{"id_menu":1,"count":1}]	20765	pick-up	0	12
52334	2020-04-20 01:23:41	2020-04-20	12	[{"id_menu":1,"count":1}]	3125	delivery	5	17
52335	2020-04-20 01:27:33	2020-04-20	17	[{"id_menu":4,"count":1}]	14812	delivery	5	22
52336	2020-04-20 01:32:41	2020-04-20	8	[{"id_menu":5,"count":1}]	17784	pick-up	0	8
52337	2020-04-20 01:34:43	2020-04-20	12	[{"id_menu":1,"count":1}]	12285	pick-up	0	12
52338	2020-04-20 01:52:11	2020-04-20	9	[{"id_menu":7,"count":1}]	13987	delivery	5	14
52339	2020-04-20 01:52:55	2020-04-20	8	[{"id_menu":5,"count":1}]	2386	delivery	5	13
52340	2020-04-20 01:53:17	2020-04-20	12	[{"id_menu":3,"count":1}]	690	delivery	5	17
52341	2020-04-20 01:57:05	2020-04-20	9	[{"id_menu":7,"count":1}]	9267	delivery	5	14
52342	2020-04-20 02:15:49	2020-04-20	9	[{"id_menu":7,"count":1}]	20877	delivery	5	14
52343	2020-04-20 02:16:18	2020-04-20	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13775	delivery	5	43
52344	2020-04-20 02:19:28	2020-04-20	17	[{"id_menu":4,"count":2}]	2081	delivery	5	22
52345	2020-04-20 02:23:50	2020-04-20	14	[{"id_menu":2,"count":1}]	20897	delivery	5	19
52346	2020-04-20 02:35:31	2020-04-20	8	[{"id_menu":5,"count":1}]	6141	delivery	5	13
52347	2020-04-20 02:36:57	2020-04-20	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20800	delivery	5	51
52348	2020-04-20 02:37:19	2020-04-20	9	[{"id_menu":6,"count":1}]	2330	delivery	5	14
52349	2020-04-20 02:37:31	2020-04-20	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1714	delivery	5	30
52350	2020-04-20 02:39:59	2020-04-20	9	[{"id_menu":7,"count":1}]	19789	delivery	5	14
52351	2020-04-20 02:40:49	2020-04-20	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	20803	delivery	5	57
52352	2020-04-20 02:41:02	2020-04-20	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	20892	delivery	5	31
52353	2020-04-20 02:43:03	2020-04-20	8	[{"id_menu":5,"count":1}]	10382	pick-up	0	8
52354	2020-04-20 02:47:32	2020-04-20	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	20836	delivery	5	31
52355	2020-04-20 02:53:26	2020-04-20	12	[{"id_menu":1,"count":1}]	20798	delivery	5	17
52356	2020-04-20 02:54:19	2020-04-20	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	515	pick-up	0	31
52357	2020-04-20 02:56:01	2020-04-20	12	[{"id_menu":3,"count":1}]	16847	delivery	5	17
52358	2020-04-20 03:10:58	2020-04-20	8	[{"id_menu":5,"count":1}]	6018	pick-up	0	8
52359	2020-04-20 03:14:13	2020-04-20	14	[{"id_menu":2,"count":1}]	20857	delivery	5	19
52360	2020-04-20 03:16:04	2020-04-20	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3953	delivery	5	48
52361	2020-04-20 03:16:24	2020-04-20	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2843	delivery	5	26
52362	2020-04-20 03:16:56	2020-04-20	14	[{"id_menu":2,"count":1}]	1461	pick-up	0	14
52363	2020-04-20 03:25:08	2020-04-20	17	[{"id_menu":4,"count":1}]	9813	pick-up	0	17
52364	2020-04-20 03:28:22	2020-04-20	9	[{"id_menu":7,"count":1}]	12750	delivery	5	14
52365	2020-04-20 03:31:37	2020-04-20	17	[{"id_menu":4,"count":1}]	18980	pick-up	0	17
52366	2020-04-20 03:37:57	2020-04-20	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	20834	delivery	5	26
52367	2020-04-20 03:38:30	2020-04-20	12	[{"id_menu":1,"count":1}]	10255	delivery	5	17
52368	2020-04-20 03:39:18	2020-04-20	12	[{"id_menu":1,"count":1}]	14364	pick-up	0	12
52369	2020-04-20 03:40:57	2020-04-20	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	20827	pick-up	0	21
52370	2020-04-20 03:41:49	2020-04-20	9	[{"id_menu":7,"count":1}]	20858	delivery	5	14
52371	2020-04-20 03:48:29	2020-04-20	14	[{"id_menu":2,"count":1}]	20779	delivery	5	19
52372	2020-04-20 03:56:46	2020-04-20	9	[{"id_menu":6,"count":2}]	2450	pick-up	0	9
52373	2020-04-20 04:00:45	2020-04-20	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	15350	delivery	5	27
52374	2020-04-20 04:23:31	2020-04-20	17	[{"id_menu":4,"count":1}]	16240	delivery	5	22
52375	2020-04-20 04:25:27	2020-04-20	12	[{"id_menu":1,"count":1}]	204	pick-up	0	12
52376	2020-04-20 04:30:39	2020-04-20	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	20811	delivery	5	26
52377	2020-04-20 04:35:08	2020-04-20	14	[{"id_menu":2,"count":1}]	6511	delivery	5	19
52378	2020-04-20 04:35:57	2020-04-20	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20767	delivery	5	34
52379	2020-04-20 04:39:10	2020-04-20	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	10403	pick-up	0	26
52380	2020-04-20 04:40:26	2020-04-20	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	17770	delivery	5	26
52381	2020-04-20 04:42:23	2020-04-20	9	[{"id_menu":6,"count":1}]	6282	delivery	5	14
52382	2020-04-20 04:45:13	2020-04-20	9	[{"id_menu":6,"count":1}]	11908	delivery	5	14
52383	2020-04-20 04:50:33	2020-04-20	12	[{"id_menu":3,"count":1}]	17588	delivery	5	17
52384	2020-04-20 04:51:54	2020-04-20	14	[{"id_menu":2,"count":1}]	9502	delivery	5	19
52385	2020-04-20 04:59:07	2020-04-20	8	[{"id_menu":5,"count":1}]	20910	delivery	5	13
52387	2020-04-20 05:04:44	2020-04-20	14	[{"id_menu":2,"count":1}]	20810	delivery	5	19
52388	2020-04-20 05:04:58	2020-04-20	9	[{"id_menu":6,"count":2}]	20885	delivery	5	14
52389	2020-04-20 05:05:21	2020-04-20	9	[{"id_menu":6,"count":1}]	12042	delivery	5	14
52390	2020-04-20 05:06:33	2020-04-20	12	[{"id_menu":3,"count":1}]	20820	pick-up	0	12
52391	2020-04-20 05:10:07	2020-04-20	12	[{"id_menu":3,"count":1}]	15595	delivery	5	17
52392	2020-04-20 05:15:11	2020-04-20	9	[{"id_menu":6,"count":1}]	15570	pick-up	0	9
52393	2020-04-20 05:17:31	2020-04-20	9	[{"id_menu":6,"count":1}]	17465	delivery	5	14
52394	2020-04-20 05:22:12	2020-04-20	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20894	delivery	5	22
52395	2020-04-20 05:25:28	2020-04-20	14	[{"id_menu":2,"count":1}]	356	pick-up	0	14
52396	2020-04-20 05:45:04	2020-04-20	9	[{"id_menu":7,"count":1}]	1138	pick-up	0	9
52397	2020-04-20 05:46:55	2020-04-20	9	[{"id_menu":7,"count":1}]	15405	pick-up	0	9
52398	2020-04-20 05:52:41	2020-04-20	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2275	pick-up	0	26
52399	2020-04-20 05:58:30	2020-04-20	8	[{"id_menu":5,"count":1}]	20758	delivery	5	13
52400	2020-04-20 06:02:38	2020-04-20	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20864	delivery	5	35
52401	2020-04-20 06:04:09	2020-04-20	17	[{"id_menu":4,"count":1}]	20784	delivery	5	22
52402	2020-04-20 06:04:53	2020-04-20	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	20831	delivery	5	40
52403	2020-04-20 06:05:52	2020-04-20	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	20861	delivery	5	43
52404	2020-04-20 06:13:18	2020-04-20	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12878	delivery	5	37
52405	2020-04-20 06:24:10	2020-04-20	8	[{"id_menu":5,"count":1}]	19396	pick-up	0	8
52406	2020-04-20 06:27:15	2020-04-20	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	10651	delivery	5	34
52407	2020-04-20 06:35:39	2020-04-20	12	[{"id_menu":1,"count":1}]	20780	delivery	5	17
52408	2020-04-20 06:53:44	2020-04-20	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3129	delivery	5	31
52409	2020-04-20 06:55:38	2020-04-20	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	20776	delivery	5	27
52410	2020-04-20 06:57:18	2020-04-20	9	[{"id_menu":6,"count":1}]	14624	delivery	5	14
52411	2020-04-20 07:04:41	2020-04-20	9	[{"id_menu":7,"count":1}]	7367	pick-up	0	9
52412	2020-04-20 07:16:44	2020-04-20	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14165	delivery	5	35
52413	2020-04-20 07:16:46	2020-04-20	8	[{"id_menu":5,"count":1}]	20880	delivery	5	13
52414	2020-04-20 07:22:46	2020-04-20	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3754	delivery	5	31
52415	2020-04-20 07:24:34	2020-04-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16483	delivery	5	22
52416	2020-04-20 07:38:46	2020-04-20	14	[{"id_menu":2,"count":1}]	6163	pick-up	0	14
52417	2020-04-20 07:41:07	2020-04-20	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	389	pick-up	0	30
52418	2020-04-20 07:41:21	2020-04-20	12	[{"id_menu":3,"count":1}]	6366	delivery	5	17
52419	2020-04-20 07:42:31	2020-04-20	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15271	delivery	5	43
52420	2020-04-20 07:46:44	2020-04-20	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	20900	delivery	5	39
52421	2020-04-20 07:47:17	2020-04-20	17	[{"id_menu":4,"count":1}]	48	delivery	5	22
52422	2020-04-20 07:48:29	2020-04-20	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	3604	delivery	5	31
52423	2020-04-20 07:54:44	2020-04-20	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	7161	delivery	5	22
52424	2020-04-20 07:58:33	2020-04-20	8	[{"id_menu":5,"count":1}]	20853	delivery	5	13
52425	2020-04-20 08:05:31	2020-04-20	14	[{"id_menu":2,"count":1}]	20761	delivery	5	19
52426	2020-04-20 08:07:45	2020-04-20	9	[{"id_menu":7,"count":1}]	20760	delivery	5	14
52427	2020-04-20 08:08:51	2020-04-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20824	delivery	5	22
52428	2020-04-20 08:09:40	2020-04-20	8	[{"id_menu":5,"count":1}]	13519	delivery	5	13
52429	2020-04-20 08:12:12	2020-04-20	9	[{"id_menu":7,"count":1}]	20214	delivery	5	14
52430	2020-04-20 08:18:31	2020-04-20	17	[{"id_menu":4,"count":1}]	3273	pick-up	0	17
52431	2020-04-20 08:20:34	2020-04-20	14	[{"id_menu":2,"count":1}]	4650	pick-up	0	14
52432	2020-04-20 08:25:09	2020-04-20	9	[{"id_menu":7,"count":1}]	8068	pick-up	0	9
52433	2020-04-20 08:28:51	2020-04-20	9	[{"id_menu":7,"count":1}]	5126	delivery	5	14
52434	2020-04-20 08:34:57	2020-04-20	9	[{"id_menu":6,"count":1}]	7567	delivery	5	14
52435	2020-04-20 08:43:22	2020-04-20	14	[{"id_menu":2,"count":1}]	4634	pick-up	0	14
52436	2020-04-20 08:54:38	2020-04-20	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	20847	delivery	5	43
52437	2020-04-20 08:58:46	2020-04-20	12	[{"id_menu":1,"count":1}]	3778	delivery	5	17
52438	2020-04-20 09:02:25	2020-04-20	14	[{"id_menu":2,"count":2}]	5099	pick-up	0	14
52439	2020-04-20 09:05:12	2020-04-20	12	[{"id_menu":1,"count":2}]	20844	delivery	5	17
52440	2020-04-20 09:10:20	2020-04-20	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	20841	delivery	5	57
52441	2020-04-20 09:14:19	2020-04-20	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	20883	pick-up	0	22
52442	2020-04-20 09:22:34	2020-04-20	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10472	delivery	5	44
52443	2020-04-20 09:32:41	2020-04-20	17	[{"id_menu":4,"count":2}]	1349	delivery	5	22
52444	2020-04-20 09:36:19	2020-04-20	9	[{"id_menu":6,"count":1}]	11880	delivery	5	14
52445	2020-04-20 09:42:40	2020-04-20	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	20819	delivery	5	34
52446	2020-04-20 09:43:38	2020-04-20	9	[{"id_menu":6,"count":3}]	2664	delivery	5	14
52447	2020-04-20 09:47:36	2020-04-20	14	[{"id_menu":2,"count":1}]	20875	delivery	5	19
52448	2020-04-20 09:52:31	2020-04-20	9	[{"id_menu":6,"count":2}]	7851	delivery	5	14
52449	2020-04-20 09:54:10	2020-04-20	9	[{"id_menu":7,"count":1}]	20828	delivery	5	14
52450	2020-04-20 10:01:28	2020-04-20	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13699	delivery	5	48
52451	2020-04-20 10:05:41	2020-04-20	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	20822	delivery	5	31
52452	2020-04-20 10:10:23	2020-04-20	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	20809	pick-up	0	52
52453	2020-04-20 10:20:21	2020-04-20	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6778	delivery	5	43
52454	2020-04-20 10:33:25	2020-04-20	14	[{"id_menu":2,"count":1}]	4116	delivery	5	19
52455	2020-04-20 10:34:24	2020-04-20	14	[{"id_menu":2,"count":1}]	20840	delivery	5	19
52456	2020-04-20 10:37:31	2020-04-20	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	16755	delivery	5	26
52457	2020-04-20 10:38:14	2020-04-20	12	[{"id_menu":3,"count":1}]	14688	delivery	5	17
52458	2020-04-20 10:47:02	2020-04-20	12	[{"id_menu":1,"count":1}]	5740	delivery	5	17
52459	2020-04-20 10:47:56	2020-04-20	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	30	delivery	5	31
52460	2020-04-20 10:55:50	2020-04-20	9	[{"id_menu":6,"count":2}]	20906	pick-up	0	9
52461	2020-04-20 10:57:57	2020-04-20	9	[{"id_menu":7,"count":1}]	20797	pick-up	0	9
52462	2020-04-20 11:00:34	2020-04-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	13718	pick-up	0	23
52463	2020-04-20 11:02:50	2020-04-20	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12506	delivery	5	31
52464	2020-04-20 11:03:10	2020-04-20	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	20778	pick-up	0	21
52465	2020-04-20 11:04:36	2020-04-20	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20869	delivery	5	49
52466	2020-04-20 11:09:19	2020-04-20	12	[{"id_menu":1,"count":1}]	11407	pick-up	0	12
52467	2020-04-20 11:12:16	2020-04-20	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	16164	pick-up	0	22
52468	2020-04-20 11:17:35	2020-04-20	9	[{"id_menu":7,"count":1}]	5350	pick-up	0	9
52469	2020-04-20 11:17:45	2020-04-20	17	[{"id_menu":4,"count":1}]	20903	delivery	5	22
52470	2020-04-20 11:26:20	2020-04-20	9	[{"id_menu":6,"count":1}]	3437	delivery	5	14
52471	2020-04-20 11:48:35	2020-04-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7888	delivery	5	28
52472	2020-04-20 11:51:52	2020-04-20	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	20792	delivery	5	25
52473	2020-04-20 11:52:46	2020-04-20	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4728	delivery	5	31
52474	2020-04-20 11:55:33	2020-04-20	9	[{"id_menu":6,"count":1}]	20856	delivery	5	14
52475	2020-04-20 11:57:43	2020-04-20	8	[{"id_menu":5,"count":1}]	2033	delivery	5	13
52476	2020-04-20 12:02:21	2020-04-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17030	delivery	5	22
52477	2020-04-20 12:03:30	2020-04-20	9	[{"id_menu":6,"count":1}]	8641	delivery	5	14
52478	2020-04-20 12:04:31	2020-04-20	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	14869	delivery	5	40
52479	2020-04-20 12:09:30	2020-04-20	9	[{"id_menu":7,"count":1}]	20899	delivery	5	14
52480	2020-04-20 12:40:44	2020-04-20	9	[{"id_menu":7,"count":1}]	16126	delivery	5	14
52481	2020-04-20 12:46:53	2020-04-20	17	[{"id_menu":4,"count":1}]	20913	delivery	5	22
52482	2020-04-20 12:49:22	2020-04-20	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3111	pick-up	0	43
52483	2020-04-20 12:53:31	2020-04-20	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3545	delivery	5	36
52484	2020-04-20 13:06:00	2020-04-20	17	[{"id_menu":4,"count":1}]	1920	delivery	5	22
52485	2020-04-20 13:06:18	2020-04-20	17	[{"id_menu":4,"count":1}]	20759	delivery	5	22
52486	2020-04-20 13:06:32	2020-04-20	9	[{"id_menu":6,"count":1}]	6470	pick-up	0	9
52487	2020-04-20 13:09:28	2020-04-20	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	20781	delivery	5	31
52488	2020-04-20 13:13:01	2020-04-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	20814	delivery	5	23
52489	2020-04-20 13:30:07	2020-04-20	12	[{"id_menu":1,"count":1}]	5169	pick-up	0	12
52490	2020-04-20 13:43:43	2020-04-20	17	[{"id_menu":4,"count":1}]	20796	delivery	5	22
52491	2020-04-20 13:56:53	2020-04-20	9	[{"id_menu":7,"count":1}]	1554	pick-up	0	9
52492	2020-04-20 13:56:58	2020-04-20	12	[{"id_menu":1,"count":1}]	8747	pick-up	0	12
52493	2020-04-20 14:00:09	2020-04-20	12	[{"id_menu":3,"count":1}]	8632	pick-up	0	12
52494	2020-04-20 14:06:38	2020-04-20	17	[{"id_menu":4,"count":1}]	14735	pick-up	0	17
52495	2020-04-20 14:19:02	2020-04-20	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	13049	pick-up	0	29
52496	2020-04-20 14:24:21	2020-04-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	18414	delivery	5	28
52497	2020-04-20 14:26:50	2020-04-20	9	[{"id_menu":7,"count":1}]	20874	delivery	5	14
52498	2020-04-20 14:28:14	2020-04-20	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	4130	pick-up	0	29
52499	2020-04-20 14:29:22	2020-04-20	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20891	delivery	5	36
52500	2020-04-20 14:31:41	2020-04-20	12	[{"id_menu":1,"count":1}]	5972	pick-up	0	12
52501	2020-04-20 14:47:23	2020-04-20	9	[{"id_menu":7,"count":1}]	20896	delivery	5	14
52502	2020-04-20 14:55:51	2020-04-20	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	17225	delivery	5	44
52503	2020-04-20 14:58:06	2020-04-20	14	[{"id_menu":2,"count":1}]	9593	pick-up	0	14
52504	2020-04-20 15:04:02	2020-04-20	12	[{"id_menu":1,"count":1}]	14743	delivery	5	17
52505	2020-04-20 15:16:28	2020-04-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	20901	delivery	5	28
52506	2020-04-20 15:17:21	2020-04-20	8	[{"id_menu":5,"count":1}]	1224	delivery	5	13
52507	2020-04-20 15:17:21	2020-04-20	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	20825	delivery	5	31
52508	2020-04-20 15:17:45	2020-04-20	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20794	delivery	5	40
52509	2020-04-20 15:32:40	2020-04-20	8	[{"id_menu":5,"count":1}]	16330	pick-up	0	8
52510	2020-04-20 15:44:12	2020-04-20	8	[{"id_menu":5,"count":1}]	11542	delivery	5	13
52511	2020-04-20 15:48:35	2020-04-20	8	[{"id_menu":5,"count":1}]	6992	delivery	5	13
52512	2020-04-20 15:54:07	2020-04-20	12	[{"id_menu":1,"count":1}]	20818	delivery	5	17
52513	2020-04-20 15:58:52	2020-04-20	17	[{"id_menu":4,"count":1}]	20871	delivery	5	22
52514	2020-04-20 16:02:18	2020-04-20	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20774	delivery	5	43
52515	2020-04-20 16:09:21	2020-04-20	9	[{"id_menu":6,"count":1}]	20786	delivery	5	14
52516	2020-04-20 16:19:34	2020-04-20	14	[{"id_menu":2,"count":1}]	1993	pick-up	0	14
52517	2020-04-20 16:21:48	2020-04-20	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20838	delivery	5	36
52518	2020-04-20 16:24:10	2020-04-20	17	[{"id_menu":4,"count":1}]	3684	delivery	5	22
52519	2020-04-20 16:27:40	2020-04-20	12	[{"id_menu":3,"count":1}]	20860	delivery	5	17
52520	2020-04-20 16:49:36	2020-04-20	8	[{"id_menu":5,"count":1}]	5958	pick-up	0	8
52521	2020-04-20 16:56:10	2020-04-20	8	[{"id_menu":5,"count":1}]	20762	delivery	5	13
52522	2020-04-20 17:05:17	2020-04-20	12	[{"id_menu":3,"count":1}]	6710	delivery	5	17
52523	2020-04-20 17:10:22	2020-04-20	17	[{"id_menu":4,"count":1}]	2485	pick-up	0	17
52524	2020-04-20 17:40:30	2020-04-20	9	[{"id_menu":6,"count":1}]	20787	delivery	5	14
52525	2020-04-20 17:56:22	2020-04-20	14	[{"id_menu":2,"count":1}]	5048	delivery	5	19
52526	2020-04-20 18:02:35	2020-04-20	9	[{"id_menu":6,"count":1}]	5664	delivery	5	14
52527	2020-04-20 18:13:41	2020-04-20	9	[{"id_menu":6,"count":1}]	20773	delivery	5	14
52528	2020-04-20 18:14:02	2020-04-20	14	[{"id_menu":2,"count":1}]	20802	delivery	5	19
52529	2020-04-20 18:15:27	2020-04-20	17	[{"id_menu":4,"count":1}]	17226	delivery	5	22
52530	2020-04-20 18:17:10	2020-04-20	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2618	pick-up	0	21
52531	2020-04-20 18:30:52	2020-04-20	9	[{"id_menu":6,"count":1}]	17217	delivery	5	14
52532	2020-04-20 18:32:43	2020-04-20	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	20832	delivery	5	40
52533	2020-04-20 18:34:22	2020-04-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8555	delivery	5	23
52534	2020-04-20 18:40:34	2020-04-20	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	14093	delivery	5	31
52535	2020-04-20 18:50:37	2020-04-20	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	187	pick-up	0	31
52536	2020-04-20 19:02:20	2020-04-20	9	[{"id_menu":7,"count":3}]	14009	delivery	5	14
52537	2020-04-20 19:02:21	2020-04-20	8	[{"id_menu":5,"count":1}]	20873	delivery	5	13
52538	2020-04-20 19:11:28	2020-04-20	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3065	delivery	5	31
52539	2020-04-20 19:16:27	2020-04-20	14	[{"id_menu":2,"count":1}]	11753	delivery	5	19
52540	2020-04-20 19:20:14	2020-04-20	12	[{"id_menu":1,"count":1}]	13187	delivery	5	17
52541	2020-04-20 19:30:03	2020-04-20	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	20804	pick-up	0	31
52542	2020-04-20 19:36:54	2020-04-20	8	[{"id_menu":5,"count":1}]	20801	delivery	5	13
52543	2020-04-20 19:56:38	2020-04-20	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	20866	pick-up	0	26
52544	2020-04-20 20:02:11	2020-04-20	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	20870	pick-up	0	43
52545	2020-04-20 20:02:42	2020-04-20	12	[{"id_menu":1,"count":1}]	359	pick-up	0	12
52546	2020-04-20 20:08:54	2020-04-20	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	12664	delivery	5	26
52547	2020-04-20 20:14:47	2020-04-20	9	[{"id_menu":7,"count":1}]	20855	delivery	5	14
52548	2020-04-20 20:18:24	2020-04-20	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	13363	delivery	5	28
52549	2020-04-20 20:19:16	2020-04-20	9	[{"id_menu":6,"count":1}]	20737	delivery	5	14
52550	2020-04-20 20:39:20	2020-04-20	14	[{"id_menu":2,"count":1}]	17527	delivery	5	19
52551	2020-04-20 20:42:16	2020-04-20	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":2}]	20785	delivery	5	31
52552	2020-04-20 20:46:28	2020-04-20	12	[{"id_menu":1,"count":1}]	20815	delivery	5	17
52553	2020-04-20 20:46:52	2020-04-20	14	[{"id_menu":2,"count":1}]	303	pick-up	0	14
52554	2020-04-20 20:47:24	2020-04-20	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11010	pick-up	0	47
52555	2020-04-20 20:48:02	2020-04-20	9	[{"id_menu":7,"count":1}]	3809	pick-up	0	9
52556	2020-04-20 20:55:41	2020-04-20	9	[{"id_menu":6,"count":1}]	17053	delivery	5	14
52557	2020-04-20 21:06:30	2020-04-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20763	delivery	5	22
52558	2020-04-20 21:11:41	2020-04-20	8	[{"id_menu":5,"count":1}]	20782	pick-up	0	8
52559	2020-04-20 21:31:51	2020-04-20	9	[{"id_menu":7,"count":1}]	14962	delivery	5	14
52560	2020-04-20 21:34:48	2020-04-20	9	[{"id_menu":6,"count":1}]	20807	delivery	5	14
52561	2020-04-20 21:35:48	2020-04-20	9	[{"id_menu":6,"count":1}]	20795	delivery	5	14
52562	2020-04-20 21:38:32	2020-04-20	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	20837	delivery	5	45
52563	2020-04-20 21:38:54	2020-04-20	9	[{"id_menu":7,"count":1}]	20829	delivery	5	14
52564	2020-04-20 21:40:24	2020-04-20	12	[{"id_menu":3,"count":1}]	15400	pick-up	0	12
52565	2020-04-20 21:41:22	2020-04-20	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	20846	delivery	5	26
52566	2020-04-20 21:47:33	2020-04-20	17	[{"id_menu":4,"count":1}]	6039	pick-up	0	17
52567	2020-04-20 21:51:06	2020-04-20	17	[{"id_menu":4,"count":1}]	20850	pick-up	0	17
52568	2020-04-20 22:03:28	2020-04-20	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	4733	delivery	5	34
52569	2020-04-20 22:04:22	2020-04-20	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	9988	delivery	5	22
52570	2020-04-20 22:05:30	2020-04-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	11910	delivery	5	23
52571	2020-04-20 22:21:11	2020-04-20	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1334	pick-up	0	21
52572	2020-04-20 22:22:14	2020-04-20	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2419	pick-up	0	31
52573	2020-04-20 22:25:07	2020-04-20	8	[{"id_menu":5,"count":1}]	7204	delivery	5	13
52574	2020-04-20 22:32:20	2020-04-20	17	[{"id_menu":4,"count":1}]	20843	delivery	5	22
52575	2020-04-20 22:40:12	2020-04-20	14	[{"id_menu":2,"count":1}]	841	pick-up	0	14
52576	2020-04-20 22:54:51	2020-04-20	14	[{"id_menu":2,"count":1}]	19366	delivery	5	19
52577	2020-04-20 22:55:19	2020-04-20	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	12236	delivery	5	26
52578	2020-04-20 22:58:50	2020-04-20	17	[{"id_menu":4,"count":1}]	13370	delivery	5	22
52579	2020-04-20 23:00:22	2020-04-20	12	[{"id_menu":3,"count":1}]	4034	pick-up	0	12
52580	2020-04-20 23:08:17	2020-04-20	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8869	delivery	5	43
52581	2020-04-20 23:11:11	2020-04-20	17	[{"id_menu":4,"count":1}]	6195	pick-up	0	17
52582	2020-04-20 23:11:27	2020-04-20	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	5658	delivery	5	22
52583	2020-04-20 23:24:43	2020-04-20	17	[{"id_menu":4,"count":1}]	15272	pick-up	0	17
52584	2020-04-20 23:29:36	2020-04-20	17	[{"id_menu":4,"count":1}]	7094	pick-up	0	17
52585	2020-04-20 23:31:25	2020-04-20	9	[{"id_menu":6,"count":1}]	20839	delivery	5	14
52586	2020-04-20 23:38:06	2020-04-20	12	[{"id_menu":3,"count":1}]	4436	delivery	5	17
52587	2020-04-20 23:45:24	2020-04-20	9	[{"id_menu":6,"count":1}]	8311	delivery	5	14
52588	2020-04-20 23:46:13	2020-04-20	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	20879	pick-up	0	40
52589	2020-04-21 00:04:32	2020-04-21	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1108	delivery	5	31
52590	2020-04-21 00:07:45	2020-04-21	9	[{"id_menu":6,"count":1}]	10459	delivery	5	14
52591	2020-04-21 00:14:22	2020-04-21	14	[{"id_menu":2,"count":1}]	20940	delivery	5	19
52592	2020-04-21 00:15:44	2020-04-21	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10993	delivery	5	46
52593	2020-04-21 00:21:08	2020-04-21	12	[{"id_menu":3,"count":1}]	19183	pick-up	0	12
52594	2020-04-21 00:37:08	2020-04-21	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20936	delivery	5	39
52595	2020-04-21 00:40:19	2020-04-21	14	[{"id_menu":2,"count":1}]	4976	delivery	5	19
52596	2020-04-21 00:41:59	2020-04-21	12	[{"id_menu":1,"count":2}]	20928	delivery	5	17
52597	2020-04-21 00:42:54	2020-04-21	9	[{"id_menu":6,"count":1}]	14756	delivery	5	14
52598	2020-04-21 00:44:53	2020-04-21	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11783	delivery	5	36
52599	2020-04-21 00:47:14	2020-04-21	14	[{"id_menu":2,"count":1}]	11635	delivery	5	19
52600	2020-04-21 00:54:08	2020-04-21	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21048	delivery	5	36
52601	2020-04-21 01:08:54	2020-04-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1075	delivery	5	28
52602	2020-04-21 01:10:51	2020-04-21	14	[{"id_menu":2,"count":1}]	749	pick-up	0	14
52603	2020-04-21 01:14:36	2020-04-21	37	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	688	pick-up	0	37
52604	2020-04-21 01:18:32	2020-04-21	9	[{"id_menu":6,"count":1}]	10022	delivery	5	14
52605	2020-04-21 01:18:40	2020-04-21	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	12920	delivery	5	31
52606	2020-04-21 01:21:03	2020-04-21	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	13320	pick-up	0	29
52607	2020-04-21 01:21:32	2020-04-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21062	delivery	5	22
52608	2020-04-21 01:31:52	2020-04-21	9	[{"id_menu":7,"count":1}]	21019	delivery	5	14
52609	2020-04-21 01:34:11	2020-04-21	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	12180	delivery	5	52
52610	2020-04-21 01:39:27	2020-04-21	12	[{"id_menu":3,"count":1}]	18510	delivery	5	17
52611	2020-04-21 01:39:29	2020-04-21	12	[{"id_menu":1,"count":1}]	4266	pick-up	0	12
52612	2020-04-21 01:40:19	2020-04-21	14	[{"id_menu":2,"count":1}]	20957	delivery	5	19
52613	2020-04-21 01:42:10	2020-04-21	9	[{"id_menu":6,"count":1}]	4582	delivery	5	14
52614	2020-04-21 01:42:15	2020-04-21	8	[{"id_menu":5,"count":1}]	21061	delivery	5	13
52615	2020-04-21 01:42:38	2020-04-21	12	[{"id_menu":3,"count":1}]	1419	pick-up	0	12
52616	2020-04-21 01:49:50	2020-04-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10876	delivery	5	22
52617	2020-04-21 01:52:49	2020-04-21	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7491	delivery	5	40
52618	2020-04-21 01:54:07	2020-04-21	8	[{"id_menu":5,"count":1}]	9300	pick-up	0	8
52619	2020-04-21 01:58:36	2020-04-21	14	[{"id_menu":2,"count":1}]	16941	delivery	5	19
52620	2020-04-21 02:01:57	2020-04-21	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	20977	delivery	5	27
52621	2020-04-21 02:03:44	2020-04-21	8	[{"id_menu":5,"count":1}]	20327	pick-up	0	8
52622	2020-04-21 02:13:39	2020-04-21	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	20929	delivery	5	30
52623	2020-04-21 02:14:52	2020-04-21	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	16475	pick-up	0	22
52624	2020-04-21 02:29:29	2020-04-21	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	21026	delivery	5	26
52625	2020-04-21 02:42:21	2020-04-21	9	[{"id_menu":6,"count":1}]	5066	delivery	5	14
52626	2020-04-21 02:49:13	2020-04-21	9	[{"id_menu":7,"count":1}]	19687	pick-up	0	9
52627	2020-04-21 02:49:24	2020-04-21	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2496	pick-up	0	22
52628	2020-04-21 02:52:14	2020-04-21	12	[{"id_menu":3,"count":1}]	271	pick-up	0	12
52629	2020-04-21 02:53:43	2020-04-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20994	delivery	5	22
52630	2020-04-21 02:55:54	2020-04-21	9	[{"id_menu":6,"count":1}]	3430	delivery	5	14
52631	2020-04-21 02:59:25	2020-04-21	8	[{"id_menu":5,"count":1}]	21014	delivery	5	13
52632	2020-04-21 03:04:02	2020-04-21	12	[{"id_menu":1,"count":1}]	20975	delivery	5	17
52633	2020-04-21 03:07:29	2020-04-21	8	[{"id_menu":5,"count":1}]	16230	delivery	5	13
52634	2020-04-21 03:08:00	2020-04-21	9	[{"id_menu":6,"count":1}]	21074	delivery	5	14
52635	2020-04-21 03:14:50	2020-04-21	17	[{"id_menu":4,"count":1}]	8240	pick-up	0	17
52636	2020-04-21 03:21:10	2020-04-21	12	[{"id_menu":3,"count":1}]	21002	delivery	5	17
52637	2020-04-21 03:21:15	2020-04-21	14	[{"id_menu":2,"count":1}]	7344	pick-up	0	14
52638	2020-04-21 03:27:28	2020-04-21	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	4116	delivery	5	26
52639	2020-04-21 03:29:59	2020-04-21	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	21028	delivery	5	35
52640	2020-04-21 03:30:21	2020-04-21	14	[{"id_menu":2,"count":1}]	17470	delivery	5	19
52641	2020-04-21 03:34:36	2020-04-21	12	[{"id_menu":1,"count":1}]	21036	delivery	5	17
52642	2020-04-21 03:38:50	2020-04-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10598	pick-up	0	18
52643	2020-04-21 03:49:33	2020-04-21	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	9193	pick-up	0	20
52644	2020-04-21 03:51:13	2020-04-21	12	[{"id_menu":1,"count":1}]	21005	delivery	5	17
52645	2020-04-21 03:59:51	2020-04-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	20985	delivery	5	28
52646	2020-04-21 04:19:48	2020-04-21	17	[{"id_menu":4,"count":1}]	10565	delivery	5	22
52647	2020-04-21 04:22:05	2020-04-21	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21039	delivery	5	35
52648	2020-04-21 04:33:37	2020-04-21	9	[{"id_menu":7,"count":1}]	8109	pick-up	0	9
52649	2020-04-21 04:34:28	2020-04-21	12	[{"id_menu":1,"count":1}]	20998	delivery	5	17
52650	2020-04-21 04:35:09	2020-04-21	12	[{"id_menu":1,"count":1}]	21	pick-up	0	12
52651	2020-04-21 04:39:59	2020-04-21	9	[{"id_menu":6,"count":1}]	4166	delivery	5	14
52652	2020-04-21 04:43:53	2020-04-21	14	[{"id_menu":2,"count":1}]	14824	pick-up	0	14
52653	2020-04-21 04:50:34	2020-04-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	20972	delivery	5	31
52654	2020-04-21 04:51:17	2020-04-21	9	[{"id_menu":6,"count":1}]	20956	delivery	5	14
52655	2020-04-21 04:51:51	2020-04-21	8	[{"id_menu":5,"count":1}]	1587	pick-up	0	8
52656	2020-04-21 04:52:49	2020-04-21	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	15995	delivery	5	26
52657	2020-04-21 04:59:38	2020-04-21	12	[{"id_menu":1,"count":2}]	3283	pick-up	0	12
52658	2020-04-21 05:06:37	2020-04-21	17	[{"id_menu":4,"count":1}]	2517	pick-up	0	17
52659	2020-04-21 05:07:50	2020-04-21	12	[{"id_menu":3,"count":1}]	20961	pick-up	0	12
52660	2020-04-21 05:08:21	2020-04-21	8	[{"id_menu":5,"count":1}]	21003	delivery	5	13
52661	2020-04-21 05:19:43	2020-04-21	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20919	delivery	5	39
52662	2020-04-21 05:21:38	2020-04-21	12	[{"id_menu":1,"count":1}]	20916	delivery	5	17
52663	2020-04-21 05:29:11	2020-04-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21071	delivery	5	23
52664	2020-04-21 05:29:38	2020-04-21	9	[{"id_menu":6,"count":1}]	20925	delivery	5	14
52665	2020-04-21 05:31:25	2020-04-21	12	[{"id_menu":3,"count":1}]	20986	delivery	5	17
52666	2020-04-21 05:36:16	2020-04-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	20953	delivery	5	28
52667	2020-04-21 05:38:33	2020-04-21	12	[{"id_menu":1,"count":1}]	3228	pick-up	0	12
52668	2020-04-21 05:43:07	2020-04-21	12	[{"id_menu":1,"count":1}]	15734	pick-up	0	12
52669	2020-04-21 05:53:46	2020-04-21	12	[{"id_menu":1,"count":1}]	203	pick-up	0	12
52670	2020-04-21 06:04:51	2020-04-21	9	[{"id_menu":7,"count":1}]	7097	delivery	5	14
52671	2020-04-21 06:06:22	2020-04-21	14	[{"id_menu":2,"count":1}]	3931	pick-up	0	14
52672	2020-04-21 06:06:24	2020-04-21	12	[{"id_menu":1,"count":1}]	20889	delivery	5	17
52673	2020-04-21 06:08:26	2020-04-21	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	20938	delivery	5	30
52674	2020-04-21 06:10:27	2020-04-21	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	20949	pick-up	0	31
52675	2020-04-21 06:13:55	2020-04-21	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	15361	delivery	5	27
52676	2020-04-21 06:15:12	2020-04-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12282	delivery	5	22
52677	2020-04-21 06:18:42	2020-04-21	9	[{"id_menu":7,"count":1}]	3954	pick-up	0	9
52678	2020-04-21 06:23:03	2020-04-21	14	[{"id_menu":2,"count":1}]	2415	pick-up	0	14
52679	2020-04-21 06:41:37	2020-04-21	14	[{"id_menu":2,"count":1}]	20922	pick-up	0	14
52680	2020-04-21 06:42:12	2020-04-21	9	[{"id_menu":7,"count":1}]	1141	pick-up	0	9
52681	2020-04-21 06:48:06	2020-04-21	8	[{"id_menu":5,"count":3}]	9554	delivery	5	13
52682	2020-04-21 06:48:26	2020-04-21	12	[{"id_menu":3,"count":1}]	21046	delivery	5	17
52683	2020-04-21 06:49:50	2020-04-21	9	[{"id_menu":6,"count":1}]	20970	pick-up	0	9
52684	2020-04-21 06:52:32	2020-04-21	14	[{"id_menu":2,"count":1}]	11898	delivery	5	19
52685	2020-04-21 07:01:45	2020-04-21	9	[{"id_menu":7,"count":1}]	7655	delivery	5	14
52686	2020-04-21 07:04:53	2020-04-21	14	[{"id_menu":2,"count":1}]	15186	pick-up	0	14
52687	2020-04-21 07:12:44	2020-04-21	14	[{"id_menu":2,"count":1}]	6536	delivery	5	19
52688	2020-04-21 07:13:53	2020-04-21	14	[{"id_menu":2,"count":1}]	1815	delivery	5	19
52689	2020-04-21 07:14:08	2020-04-21	14	[{"id_menu":2,"count":1}]	21047	delivery	5	19
52690	2020-04-21 07:16:30	2020-04-21	12	[{"id_menu":3,"count":1}]	10147	pick-up	0	12
52691	2020-04-21 07:17:48	2020-04-21	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	12204	delivery	5	34
52692	2020-04-21 07:24:31	2020-04-21	12	[{"id_menu":3,"count":1}]	16443	delivery	5	17
52693	2020-04-21 07:27:21	2020-04-21	12	[{"id_menu":3,"count":1}]	11021	delivery	5	17
52694	2020-04-21 07:27:28	2020-04-21	14	[{"id_menu":2,"count":1}]	7408	delivery	5	19
52695	2020-04-21 07:28:15	2020-04-21	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	1406	pick-up	0	35
52696	2020-04-21 07:28:41	2020-04-21	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	12646	delivery	5	31
52697	2020-04-21 07:31:30	2020-04-21	12	[{"id_menu":3,"count":1}]	15129	delivery	5	17
52698	2020-04-21 07:31:52	2020-04-21	8	[{"id_menu":5,"count":1}]	20924	delivery	5	13
52699	2020-04-21 07:34:36	2020-04-21	9	[{"id_menu":6,"count":1}]	1819	pick-up	0	9
52700	2020-04-21 07:40:16	2020-04-21	8	[{"id_menu":5,"count":1}]	12948	delivery	5	13
52701	2020-04-21 07:43:53	2020-04-21	12	[{"id_menu":3,"count":1}]	15400	pick-up	0	12
52702	2020-04-21 07:47:01	2020-04-21	8	[{"id_menu":5,"count":1}]	17045	delivery	5	13
52703	2020-04-21 07:47:16	2020-04-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	21031	delivery	5	31
52704	2020-04-21 07:50:46	2020-04-21	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	21004	delivery	5	43
52705	2020-04-21 07:51:01	2020-04-21	14	[{"id_menu":2,"count":1}]	9286	delivery	5	19
52706	2020-04-21 07:54:58	2020-04-21	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	19583	delivery	5	34
52707	2020-04-21 07:57:18	2020-04-21	9	[{"id_menu":6,"count":1}]	1055	pick-up	0	9
52708	2020-04-21 08:02:25	2020-04-21	12	[{"id_menu":3,"count":1}]	21057	pick-up	0	12
52709	2020-04-21 08:04:03	2020-04-21	14	[{"id_menu":2,"count":1}]	7424	pick-up	0	14
52710	2020-04-21 08:05:08	2020-04-21	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	21081	delivery	5	31
52711	2020-04-21 08:25:16	2020-04-21	9	[{"id_menu":7,"count":1}]	7834	pick-up	0	9
52712	2020-04-21 08:33:42	2020-04-21	9	[{"id_menu":7,"count":1}]	1783	pick-up	0	9
52713	2020-04-21 08:40:04	2020-04-21	9	[{"id_menu":7,"count":1}]	9294	delivery	5	14
52714	2020-04-21 08:41:54	2020-04-21	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	13502	pick-up	0	29
52715	2020-04-21 08:45:06	2020-04-21	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20959	delivery	5	46
52716	2020-04-21 08:47:06	2020-04-21	12	[{"id_menu":1,"count":1}]	7213	delivery	5	17
52717	2020-04-21 08:50:37	2020-04-21	9	[{"id_menu":6,"count":1}]	15779	delivery	5	14
52718	2020-04-21 08:52:44	2020-04-21	12	[{"id_menu":3,"count":1}]	21049	delivery	5	17
52719	2020-04-21 08:53:01	2020-04-21	12	[{"id_menu":3,"count":1}]	1685	pick-up	0	12
52720	2020-04-21 08:53:16	2020-04-21	12	[{"id_menu":1,"count":1}]	9318	delivery	5	17
52721	2020-04-21 08:58:48	2020-04-21	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21054	delivery	5	48
52722	2020-04-21 09:05:04	2020-04-21	12	[{"id_menu":1,"count":1}]	12502	delivery	5	17
52723	2020-04-21 09:08:28	2020-04-21	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20967	delivery	5	34
52724	2020-04-21 09:09:29	2020-04-21	9	[{"id_menu":7,"count":1}]	21070	delivery	5	14
52725	2020-04-21 09:12:11	2020-04-21	14	[{"id_menu":2,"count":1}]	20947	delivery	5	19
52726	2020-04-21 09:16:34	2020-04-21	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	20930	delivery	5	30
52727	2020-04-21 09:18:59	2020-04-21	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11822	delivery	5	34
52728	2020-04-21 09:28:41	2020-04-21	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1677	pick-up	0	24
52729	2020-04-21 09:33:38	2020-04-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2599	delivery	5	31
52730	2020-04-21 09:34:58	2020-04-21	17	[{"id_menu":4,"count":2}]	8530	pick-up	0	17
52731	2020-04-21 09:37:04	2020-04-21	8	[{"id_menu":5,"count":1}]	20958	delivery	5	13
52732	2020-04-21 09:38:56	2020-04-21	17	[{"id_menu":4,"count":1}]	20941	delivery	5	22
52733	2020-04-21 09:39:00	2020-04-21	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	7680	delivery	5	26
52734	2020-04-21 09:49:27	2020-04-21	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18667	delivery	5	52
52735	2020-04-21 09:50:59	2020-04-21	9	[{"id_menu":7,"count":1}]	7550	pick-up	0	9
52736	2020-04-21 09:56:43	2020-04-21	9	[{"id_menu":6,"count":2}]	7451	delivery	5	14
52737	2020-04-21 10:00:59	2020-04-21	17	[{"id_menu":4,"count":1}]	2052	delivery	5	22
52738	2020-04-21 10:14:55	2020-04-21	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	3640	delivery	5	28
52739	2020-04-21 10:17:25	2020-04-21	8	[{"id_menu":5,"count":1}]	13066	delivery	5	13
52740	2020-04-21 10:18:36	2020-04-21	9	[{"id_menu":6,"count":1}]	20939	delivery	5	14
52741	2020-04-21 10:18:48	2020-04-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	981	pick-up	0	17
52742	2020-04-21 10:20:31	2020-04-21	17	[{"id_menu":4,"count":1}]	2358	pick-up	0	17
52743	2020-04-21 10:22:36	2020-04-21	9	[{"id_menu":6,"count":1}]	21056	delivery	5	14
52744	2020-04-21 10:27:03	2020-04-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	20991	delivery	5	23
52745	2020-04-21 10:40:12	2020-04-21	14	[{"id_menu":2,"count":2}]	21040	delivery	5	19
52746	2020-04-21 10:43:28	2020-04-21	12	[{"id_menu":3,"count":1}]	17036	pick-up	0	12
52747	2020-04-21 10:46:33	2020-04-21	8	[{"id_menu":5,"count":1}]	12524	delivery	5	13
52748	2020-04-21 10:49:30	2020-04-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	20859	delivery	5	28
52749	2020-04-21 10:54:40	2020-04-21	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6323	delivery	5	53
52750	2020-04-21 10:56:54	2020-04-21	9	[{"id_menu":7,"count":1}]	16904	delivery	5	14
52751	2020-04-21 11:02:18	2020-04-21	12	[{"id_menu":3,"count":1}]	20960	delivery	5	17
52752	2020-04-21 11:02:56	2020-04-21	17	[{"id_menu":4,"count":1}]	21033	delivery	5	22
52753	2020-04-21 11:06:16	2020-04-21	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	8561	pick-up	0	26
52754	2020-04-21 11:08:13	2020-04-21	17	[{"id_menu":4,"count":1}]	21041	delivery	5	22
52755	2020-04-21 11:11:31	2020-04-21	9	[{"id_menu":6,"count":1}]	7421	delivery	5	14
52756	2020-04-21 11:21:24	2020-04-21	17	[{"id_menu":4,"count":1}]	21010	delivery	5	22
52757	2020-04-21 11:25:23	2020-04-21	14	[{"id_menu":2,"count":1}]	20987	delivery	5	19
52758	2020-04-21 11:27:24	2020-04-21	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	20974	delivery	5	43
52759	2020-04-21 11:35:07	2020-04-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8000	delivery	5	23
52760	2020-04-21 11:42:15	2020-04-21	14	[{"id_menu":2,"count":1}]	3457	delivery	5	19
52761	2020-04-21 11:42:41	2020-04-21	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	21000	delivery	5	38
52762	2020-04-21 11:59:03	2020-04-21	9	[{"id_menu":6,"count":1}]	16564	delivery	5	14
52763	2020-04-21 12:00:00	2020-04-21	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21045	delivery	5	35
52764	2020-04-21 12:02:08	2020-04-21	9	[{"id_menu":6,"count":1}]	20950	delivery	5	14
52765	2020-04-21 12:11:28	2020-04-21	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	17383	delivery	5	36
52766	2020-04-21 12:17:05	2020-04-21	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	20918	delivery	5	45
52767	2020-04-21 12:19:00	2020-04-21	12	[{"id_menu":3,"count":1}]	1800	pick-up	0	12
52768	2020-04-21 12:29:11	2020-04-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20984	pick-up	0	18
52769	2020-04-21 12:30:48	2020-04-21	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14922	delivery	5	48
52770	2020-04-21 12:40:15	2020-04-21	12	[{"id_menu":1,"count":1}]	17906	delivery	5	17
52771	2020-04-21 12:41:25	2020-04-21	14	[{"id_menu":2,"count":1}]	21030	delivery	5	19
52772	2020-04-21 12:56:05	2020-04-21	9	[{"id_menu":6,"count":1}]	19827	pick-up	0	9
52773	2020-04-21 12:56:14	2020-04-21	9	[{"id_menu":7,"count":1}]	21077	delivery	5	14
52774	2020-04-21 13:05:10	2020-04-21	9	[{"id_menu":7,"count":1}]	16759	pick-up	0	9
52775	2020-04-21 13:07:06	2020-04-21	8	[{"id_menu":5,"count":1}]	15052	delivery	5	13
52776	2020-04-21 13:08:10	2020-04-21	8	[{"id_menu":5,"count":1}]	21064	delivery	5	13
52777	2020-04-21 13:15:03	2020-04-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8361	delivery	5	23
52778	2020-04-21 13:23:43	2020-04-21	9	[{"id_menu":6,"count":1}]	18067	delivery	5	14
52779	2020-04-21 13:25:52	2020-04-21	9	[{"id_menu":6,"count":2}]	13429	pick-up	0	9
52780	2020-04-21 13:29:19	2020-04-21	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7217	delivery	5	39
52781	2020-04-21 13:29:38	2020-04-21	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	21050	delivery	5	43
52782	2020-04-21 13:34:43	2020-04-21	8	[{"id_menu":5,"count":1}]	6733	pick-up	0	8
52783	2020-04-21 13:39:31	2020-04-21	8	[{"id_menu":5,"count":1}]	12841	delivery	5	13
52784	2020-04-21 14:15:14	2020-04-21	9	[{"id_menu":6,"count":1}]	13220	delivery	5	14
52785	2020-04-21 14:23:31	2020-04-21	14	[{"id_menu":2,"count":1}]	21082	delivery	5	19
52786	2020-04-21 14:37:01	2020-04-21	17	[{"id_menu":4,"count":1}]	17309	delivery	5	22
52787	2020-04-21 14:38:28	2020-04-21	9	[{"id_menu":7,"count":1}]	925	pick-up	0	9
52788	2020-04-21 14:40:21	2020-04-21	14	[{"id_menu":2,"count":1}]	21017	delivery	5	19
52789	2020-04-21 14:40:36	2020-04-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20717	delivery	5	22
52790	2020-04-21 14:45:43	2020-04-21	12	[{"id_menu":3,"count":1}]	21025	delivery	5	17
52791	2020-04-21 14:45:54	2020-04-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":3}]	17088	delivery	5	31
52792	2020-04-21 14:48:07	2020-04-21	9	[{"id_menu":7,"count":1}]	5232	pick-up	0	9
52793	2020-04-21 14:54:09	2020-04-21	12	[{"id_menu":1,"count":1}]	599	pick-up	0	12
52794	2020-04-21 14:54:14	2020-04-21	9	[{"id_menu":6,"count":1}]	17029	delivery	5	14
52795	2020-04-21 14:55:39	2020-04-21	17	[{"id_menu":4,"count":1}]	6116	delivery	5	22
52796	2020-04-21 14:59:51	2020-04-21	9	[{"id_menu":6,"count":1}]	515	pick-up	0	9
52797	2020-04-21 15:07:27	2020-04-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19346	delivery	5	23
52798	2020-04-21 15:07:55	2020-04-21	12	[{"id_menu":1,"count":1}]	12076	delivery	5	17
52799	2020-04-21 15:12:30	2020-04-21	9	[{"id_menu":6,"count":1}]	20989	pick-up	0	9
52800	2020-04-21 15:15:30	2020-04-21	12	[{"id_menu":3,"count":1}]	2476	delivery	5	17
52801	2020-04-21 15:16:08	2020-04-21	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	11719	delivery	5	30
52802	2020-04-21 15:19:31	2020-04-21	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	691	pick-up	0	29
52803	2020-04-21 15:20:45	2020-04-21	9	[{"id_menu":7,"count":1}]	4035	delivery	5	14
52804	2020-04-21 15:24:28	2020-04-21	17	[{"id_menu":4,"count":1}]	21038	delivery	5	22
52805	2020-04-21 15:32:30	2020-04-21	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	14239	delivery	5	34
52806	2020-04-21 15:37:46	2020-04-21	9	[{"id_menu":7,"count":1}]	21066	delivery	5	14
52807	2020-04-21 16:05:14	2020-04-21	12	[{"id_menu":3,"count":1}]	21083	pick-up	0	12
52808	2020-04-21 16:14:53	2020-04-21	17	[{"id_menu":4,"count":1}]	440	delivery	5	22
52809	2020-04-21 16:17:45	2020-04-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6600	delivery	5	31
52810	2020-04-21 16:24:19	2020-04-21	9	[{"id_menu":6,"count":1}]	8460	delivery	5	14
52811	2020-04-21 16:38:26	2020-04-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20955	delivery	5	23
52812	2020-04-21 16:38:33	2020-04-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8729	delivery	5	23
52813	2020-04-21 16:39:25	2020-04-21	12	[{"id_menu":1,"count":1}]	222	delivery	5	17
52814	2020-04-21 16:39:51	2020-04-21	12	[{"id_menu":3,"count":1}]	21012	delivery	5	17
52815	2020-04-21 16:44:08	2020-04-21	14	[{"id_menu":2,"count":1}]	21029	pick-up	0	14
52816	2020-04-21 16:45:22	2020-04-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1098	delivery	5	22
52817	2020-04-21 16:55:23	2020-04-21	14	[{"id_menu":2,"count":1}]	21067	delivery	5	19
52818	2020-04-21 16:56:43	2020-04-21	9	[{"id_menu":7,"count":1}]	1053	delivery	5	14
52819	2020-04-21 16:58:07	2020-04-21	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	9722	delivery	5	30
52820	2020-04-21 17:02:14	2020-04-21	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	3207	pick-up	0	21
52821	2020-04-21 17:03:15	2020-04-21	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2523	pick-up	0	26
52822	2020-04-21 17:07:16	2020-04-21	14	[{"id_menu":2,"count":1}]	19749	delivery	5	19
52823	2020-04-21 17:07:54	2020-04-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	17503	delivery	5	22
52824	2020-04-21 17:11:35	2020-04-21	14	[{"id_menu":2,"count":1}]	5171	delivery	5	19
52825	2020-04-21 17:18:51	2020-04-21	9	[{"id_menu":7,"count":1}]	7923	delivery	5	14
52826	2020-04-21 17:18:57	2020-04-21	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	20983	delivery	5	30
52827	2020-04-21 17:19:39	2020-04-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8392	delivery	5	23
52828	2020-04-21 17:27:26	2020-04-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	10749	delivery	5	22
52829	2020-04-21 17:27:31	2020-04-21	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	9266	delivery	5	25
52830	2020-04-21 17:31:38	2020-04-21	9	[{"id_menu":6,"count":1}]	20935	delivery	5	14
52831	2020-04-21 17:33:08	2020-04-21	8	[{"id_menu":5,"count":1}]	20946	delivery	5	13
52832	2020-04-21 17:33:57	2020-04-21	12	[{"id_menu":1,"count":1}]	5942	delivery	5	17
52833	2020-04-21 17:34:01	2020-04-21	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	3527	pick-up	0	26
52834	2020-04-21 17:39:10	2020-04-21	14	[{"id_menu":2,"count":1}]	129	delivery	5	19
52835	2020-04-21 17:45:58	2020-04-21	17	[{"id_menu":4,"count":1}]	1223	pick-up	0	17
52836	2020-04-21 17:51:36	2020-04-21	17	[{"id_menu":4,"count":1}]	21035	delivery	5	22
52837	2020-04-21 18:02:21	2020-04-21	9	[{"id_menu":6,"count":1}]	3525	delivery	5	14
52838	2020-04-21 18:04:32	2020-04-21	12	[{"id_menu":3,"count":1}]	20591	delivery	5	17
52839	2020-04-21 18:09:06	2020-04-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4436	pick-up	0	26
52840	2020-04-21 18:21:00	2020-04-21	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21024	delivery	5	34
52841	2020-04-21 18:22:17	2020-04-21	14	[{"id_menu":2,"count":1}]	20982	pick-up	0	14
52842	2020-04-21 18:23:40	2020-04-21	14	[{"id_menu":2,"count":1}]	6887	delivery	5	19
52843	2020-04-21 18:42:41	2020-04-21	9	[{"id_menu":6,"count":1}]	14321	delivery	5	14
52844	2020-04-21 18:55:53	2020-04-21	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1569	pick-up	0	35
52845	2020-04-21 18:56:09	2020-04-21	9	[{"id_menu":7,"count":1}]	5129	delivery	5	14
52846	2020-04-21 18:58:12	2020-04-21	12	[{"id_menu":3,"count":1}]	16716	delivery	5	17
52847	2020-04-21 18:58:48	2020-04-21	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	20905	pick-up	0	29
52848	2020-04-21 19:00:45	2020-04-21	17	[{"id_menu":4,"count":1}]	3755	pick-up	0	17
52849	2020-04-21 19:06:21	2020-04-21	17	[{"id_menu":4,"count":1}]	21084	delivery	5	22
52850	2020-04-21 19:08:21	2020-04-21	9	[{"id_menu":6,"count":1}]	835	pick-up	0	9
52851	2020-04-21 19:13:40	2020-04-21	9	[{"id_menu":6,"count":1}]	20937	delivery	5	14
52852	2020-04-21 19:15:06	2020-04-21	17	[{"id_menu":4,"count":1}]	8908	delivery	5	22
52853	2020-04-21 19:17:58	2020-04-21	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	20951	delivery	5	26
52854	2020-04-21 19:23:14	2020-04-21	9	[{"id_menu":6,"count":1}]	6293	delivery	5	14
52855	2020-04-21 19:24:39	2020-04-21	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	20993	delivery	5	38
52856	2020-04-21 19:44:29	2020-04-21	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3230	pick-up	0	31
52857	2020-04-21 19:46:36	2020-04-21	33	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	21053	delivery	5	38
52858	2020-04-21 19:53:43	2020-04-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4360	delivery	5	28
52859	2020-04-21 19:56:08	2020-04-21	12	[{"id_menu":1,"count":1}]	13999	pick-up	0	12
52860	2020-04-21 19:59:15	2020-04-21	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	1693	pick-up	0	29
52861	2020-04-21 20:16:05	2020-04-21	8	[{"id_menu":5,"count":1}]	20933	delivery	5	13
52862	2020-04-21 20:16:15	2020-04-21	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	20944	delivery	5	26
52863	2020-04-21 20:23:12	2020-04-21	14	[{"id_menu":2,"count":1}]	19476	delivery	5	19
52864	2020-04-21 20:23:33	2020-04-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	17811	delivery	5	28
52865	2020-04-21 20:24:56	2020-04-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11118	delivery	5	22
52866	2020-04-21 20:26:15	2020-04-21	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	3180	pick-up	0	26
52867	2020-04-21 20:28:21	2020-04-21	14	[{"id_menu":2,"count":1}]	21044	delivery	5	19
52868	2020-04-21 20:29:17	2020-04-21	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	21016	delivery	5	27
52869	2020-04-21 20:36:34	2020-04-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21015	delivery	5	22
52870	2020-04-21 20:42:41	2020-04-21	14	[{"id_menu":2,"count":1}]	11454	pick-up	0	14
52871	2020-04-21 20:43:53	2020-04-21	17	[{"id_menu":4,"count":1}]	20948	delivery	5	22
52872	2020-04-21 20:44:26	2020-04-21	8	[{"id_menu":5,"count":1}]	17881	delivery	5	13
52873	2020-04-21 20:44:58	2020-04-21	8	[{"id_menu":5,"count":1}]	20932	pick-up	0	8
52874	2020-04-21 20:51:53	2020-04-21	9	[{"id_menu":6,"count":1}]	11979	delivery	5	14
52875	2020-04-21 20:53:31	2020-04-21	12	[{"id_menu":1,"count":1}]	10913	delivery	5	17
52876	2020-04-21 20:58:00	2020-04-21	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	4260	delivery	5	31
52877	2020-04-21 21:00:19	2020-04-21	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2196	pick-up	0	29
52878	2020-04-21 21:03:01	2020-04-21	12	[{"id_menu":3,"count":1}]	19598	delivery	5	17
52879	2020-04-21 21:10:54	2020-04-21	9	[{"id_menu":6,"count":1}]	17576	delivery	5	14
52880	2020-04-21 21:18:41	2020-04-21	8	[{"id_menu":5,"count":1}]	4213	pick-up	0	8
52881	2020-04-21 21:18:54	2020-04-21	12	[{"id_menu":3,"count":1}]	16459	delivery	5	17
52882	2020-04-21 21:27:02	2020-04-21	9	[{"id_menu":7,"count":1}]	20996	delivery	5	14
52883	2020-04-21 21:28:05	2020-04-21	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	20971	delivery	5	23
52884	2020-04-21 21:31:30	2020-04-21	9	[{"id_menu":6,"count":1}]	21055	delivery	5	14
52885	2020-04-21 21:33:43	2020-04-21	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	6221	pick-up	0	43
52886	2020-04-21 21:39:12	2020-04-21	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	20923	delivery	5	31
52887	2020-04-21 21:40:05	2020-04-21	9	[{"id_menu":6,"count":1}]	20978	delivery	5	14
52888	2020-04-21 21:44:42	2020-04-21	9	[{"id_menu":7,"count":1}]	18283	delivery	5	14
52889	2020-04-21 21:46:20	2020-04-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	21023	delivery	5	31
52890	2020-04-21 21:47:49	2020-04-21	14	[{"id_menu":2,"count":1}]	21078	delivery	5	19
52891	2020-04-21 21:52:41	2020-04-21	8	[{"id_menu":5,"count":1}]	11394	pick-up	0	8
52892	2020-04-21 21:52:58	2020-04-21	17	[{"id_menu":4,"count":1}]	17641	pick-up	0	17
52893	2020-04-21 21:55:17	2020-04-21	12	[{"id_menu":3,"count":1}]	13643	delivery	5	17
52894	2020-04-21 21:58:48	2020-04-21	12	[{"id_menu":1,"count":1}]	6040	pick-up	0	12
52895	2020-04-21 22:07:41	2020-04-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6668	delivery	5	22
52896	2020-04-21 22:09:25	2020-04-21	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	7074	pick-up	0	22
52897	2020-04-21 22:13:30	2020-04-21	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13871	delivery	5	31
52898	2020-04-21 22:15:54	2020-04-21	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	20968	delivery	5	30
52899	2020-04-21 22:20:43	2020-04-21	8	[{"id_menu":5,"count":2}]	728	pick-up	0	8
52900	2020-04-21 22:20:43	2020-04-21	9	[{"id_menu":7,"count":1}]	21032	delivery	5	14
52901	2020-04-21 22:22:52	2020-04-21	9	[{"id_menu":7,"count":1}]	21042	delivery	5	14
52902	2020-04-21 22:27:12	2020-04-21	17	[{"id_menu":4,"count":1}]	1174	pick-up	0	17
52903	2020-04-21 22:29:04	2020-04-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	21043	delivery	5	28
52904	2020-04-21 22:29:46	2020-04-21	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	21021	delivery	5	36
52905	2020-04-21 22:30:52	2020-04-21	12	[{"id_menu":3,"count":1}]	10142	pick-up	0	12
52906	2020-04-21 22:53:42	2020-04-21	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	20926	delivery	5	38
52907	2020-04-21 23:02:49	2020-04-21	8	[{"id_menu":5,"count":1}]	20979	delivery	5	13
52908	2020-04-21 23:03:10	2020-04-21	8	[{"id_menu":5,"count":3}]	19371	delivery	5	13
52909	2020-04-21 23:05:24	2020-04-21	9	[{"id_menu":6,"count":1}]	20921	delivery	5	14
52910	2020-04-21 23:06:23	2020-04-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8822	delivery	5	23
52911	2020-04-21 23:10:15	2020-04-21	9	[{"id_menu":6,"count":1}]	6848	pick-up	0	9
52912	2020-04-21 23:18:24	2020-04-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	418	pick-up	0	18
52913	2020-04-21 23:21:23	2020-04-21	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20990	delivery	5	37
52914	2020-04-21 23:24:40	2020-04-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	21059	delivery	5	31
52915	2020-04-21 23:44:02	2020-04-21	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	18901	delivery	5	31
52916	2020-04-21 23:45:44	2020-04-21	14	[{"id_menu":2,"count":1}]	18702	delivery	5	19
52917	2020-04-21 23:51:55	2020-04-21	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	20962	delivery	5	34
52918	2020-04-21 23:55:46	2020-04-21	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9626	delivery	5	34
52919	2020-04-21 23:55:52	2020-04-21	17	[{"id_menu":4,"count":1}]	256	pick-up	0	17
52920	2020-04-22 00:09:05	2020-04-22	8	[{"id_menu":5,"count":1}]	6361	delivery	5	13
52921	2020-04-22 00:38:16	2020-04-22	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7304	pick-up	0	26
52922	2020-04-22 00:43:59	2020-04-22	8	[{"id_menu":5,"count":1}]	21146	delivery	5	13
52989	2020-04-22 06:23:53	2020-04-22	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7595	pick-up	0	25
52923	2020-04-22 00:44:35	2020-04-22	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	487	delivery	5	35
52924	2020-04-22 00:44:58	2020-04-22	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	15578	delivery	5	26
52925	2020-04-22 01:04:28	2020-04-22	17	[{"id_menu":4,"count":1}]	4629	pick-up	0	17
52926	2020-04-22 01:08:41	2020-04-22	9	[{"id_menu":6,"count":1}]	16126	delivery	5	14
52927	2020-04-22 01:10:07	2020-04-22	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	14857	delivery	5	43
52928	2020-04-22 01:10:43	2020-04-22	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6469	pick-up	0	47
52929	2020-04-22 01:16:08	2020-04-22	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	13783	delivery	5	31
52930	2020-04-22 01:21:50	2020-04-22	9	[{"id_menu":6,"count":1}]	21137	delivery	5	14
52931	2020-04-22 01:25:33	2020-04-22	12	[{"id_menu":3,"count":1}]	17145	delivery	5	17
52932	2020-04-22 01:27:25	2020-04-22	9	[{"id_menu":7,"count":1}]	7476	delivery	5	14
52933	2020-04-22 01:27:48	2020-04-22	12	[{"id_menu":1,"count":1}]	9914	delivery	5	17
52934	2020-04-22 01:40:43	2020-04-22	8	[{"id_menu":5,"count":2}]	21128	delivery	5	13
52935	2020-04-22 01:41:00	2020-04-22	12	[{"id_menu":1,"count":1}]	204	pick-up	0	12
52936	2020-04-22 01:50:08	2020-04-22	17	[{"id_menu":4,"count":1}]	11401	delivery	5	22
52937	2020-04-22 01:53:23	2020-04-22	9	[{"id_menu":7,"count":1}]	431	delivery	5	14
52938	2020-04-22 01:58:04	2020-04-22	14	[{"id_menu":2,"count":1}]	12067	delivery	5	19
52939	2020-04-22 01:58:07	2020-04-22	8	[{"id_menu":5,"count":1}]	7186	pick-up	0	8
52940	2020-04-22 02:03:20	2020-04-22	21	[{"id_menu":1,"count":3},{"id_menu":6,"count":1}]	7105	pick-up	0	21
52941	2020-04-22 02:06:48	2020-04-22	26	[{"id_menu":4,"count":3},{"id_menu":7,"count":1}]	18579	delivery	5	31
52942	2020-04-22 02:10:34	2020-04-22	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3321	delivery	5	38
52943	2020-04-22 02:13:02	2020-04-22	9	[{"id_menu":6,"count":1}]	21130	pick-up	0	9
52944	2020-04-22 02:20:04	2020-04-22	12	[{"id_menu":3,"count":1}]	404	pick-up	0	12
52945	2020-04-22 02:20:52	2020-04-22	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	5028	delivery	5	35
52946	2020-04-22 02:28:31	2020-04-22	12	[{"id_menu":1,"count":1}]	14947	delivery	5	17
52947	2020-04-22 02:34:34	2020-04-22	12	[{"id_menu":3,"count":1}]	2450	pick-up	0	12
52948	2020-04-22 02:35:02	2020-04-22	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5619	delivery	5	31
52949	2020-04-22 02:49:49	2020-04-22	9	[{"id_menu":6,"count":1}]	15157	delivery	5	14
52950	2020-04-22 02:52:43	2020-04-22	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	21147	delivery	5	57
52951	2020-04-22 02:55:04	2020-04-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17650	delivery	5	22
52952	2020-04-22 02:55:08	2020-04-22	9	[{"id_menu":6,"count":1}]	8497	delivery	5	14
52953	2020-04-22 03:14:08	2020-04-22	12	[{"id_menu":3,"count":2}]	15378	delivery	5	17
52954	2020-04-22 03:22:16	2020-04-22	14	[{"id_menu":2,"count":1}]	16337	pick-up	0	14
52955	2020-04-22 03:25:04	2020-04-22	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	21099	pick-up	0	35
52956	2020-04-22 03:26:03	2020-04-22	8	[{"id_menu":5,"count":1}]	17720	delivery	5	13
52957	2020-04-22 03:28:57	2020-04-22	9	[{"id_menu":7,"count":1}]	21188	delivery	5	14
52958	2020-04-22 03:31:44	2020-04-22	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21201	delivery	5	34
52959	2020-04-22 03:49:29	2020-04-22	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17534	delivery	5	45
52960	2020-04-22 03:50:35	2020-04-22	9	[{"id_menu":6,"count":1}]	11987	delivery	5	14
52961	2020-04-22 03:53:55	2020-04-22	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	10580	pick-up	0	20
52962	2020-04-22 03:56:03	2020-04-22	14	[{"id_menu":2,"count":1}]	14378	delivery	5	19
52963	2020-04-22 03:58:23	2020-04-22	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3688	delivery	5	56
52964	2020-04-22 03:58:29	2020-04-22	12	[{"id_menu":3,"count":1}]	7689	pick-up	0	12
52965	2020-04-22 03:58:34	2020-04-22	9	[{"id_menu":6,"count":1}]	21198	delivery	5	14
52966	2020-04-22 04:07:03	2020-04-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	5966	pick-up	0	31
52967	2020-04-22 04:11:23	2020-04-22	17	[{"id_menu":4,"count":1}]	21119	delivery	5	22
52968	2020-04-22 04:17:19	2020-04-22	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	14572	delivery	5	34
52969	2020-04-22 04:17:56	2020-04-22	14	[{"id_menu":2,"count":1}]	10905	delivery	5	19
52970	2020-04-22 04:23:54	2020-04-22	9	[{"id_menu":6,"count":1}]	4309	pick-up	0	9
52971	2020-04-22 04:28:13	2020-04-22	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	19207	delivery	5	40
52972	2020-04-22 04:29:16	2020-04-22	17	[{"id_menu":4,"count":1}]	6383	delivery	5	22
52973	2020-04-22 04:34:44	2020-04-22	8	[{"id_menu":5,"count":1}]	21093	delivery	5	13
52974	2020-04-22 04:35:55	2020-04-22	9	[{"id_menu":7,"count":1}]	16086	delivery	5	14
52975	2020-04-22 04:47:04	2020-04-22	14	[{"id_menu":2,"count":1}]	2615	pick-up	0	14
52976	2020-04-22 05:03:30	2020-04-22	9	[{"id_menu":6,"count":1}]	1021	delivery	5	14
52977	2020-04-22 05:08:16	2020-04-22	9	[{"id_menu":6,"count":1}]	18981	pick-up	0	9
52978	2020-04-22 05:16:10	2020-04-22	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1170	pick-up	0	39
52979	2020-04-22 05:16:46	2020-04-22	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17422	delivery	5	22
52980	2020-04-22 05:22:51	2020-04-22	9	[{"id_menu":7,"count":1}]	21160	delivery	5	14
52981	2020-04-22 05:23:30	2020-04-22	14	[{"id_menu":2,"count":1}]	1276	pick-up	0	14
52982	2020-04-22 05:23:38	2020-04-22	9	[{"id_menu":6,"count":1}]	21110	delivery	5	14
52983	2020-04-22 05:25:10	2020-04-22	9	[{"id_menu":6,"count":1}]	2619	pick-up	0	9
52984	2020-04-22 05:41:29	2020-04-22	9	[{"id_menu":7,"count":1}]	21097	delivery	5	14
52985	2020-04-22 05:44:52	2020-04-22	9	[{"id_menu":6,"count":1}]	21195	delivery	5	14
52986	2020-04-22 05:51:00	2020-04-22	14	[{"id_menu":2,"count":1}]	2080	pick-up	0	14
52987	2020-04-22 05:52:14	2020-04-22	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":2}]	2752	pick-up	0	25
52988	2020-04-22 05:54:28	2020-04-22	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16613	delivery	5	31
52990	2020-04-22 06:24:08	2020-04-22	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6417	delivery	5	22
52991	2020-04-22 06:24:22	2020-04-22	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	1665	delivery	5	26
52992	2020-04-22 06:29:15	2020-04-22	14	[{"id_menu":2,"count":1}]	19697	delivery	5	19
52993	2020-04-22 06:34:54	2020-04-22	12	[{"id_menu":3,"count":1}]	15929	delivery	5	17
52994	2020-04-22 06:45:40	2020-04-22	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	18307	delivery	5	43
52995	2020-04-22 07:02:21	2020-04-22	17	[{"id_menu":4,"count":1}]	12650	delivery	5	22
52996	2020-04-22 07:04:39	2020-04-22	12	[{"id_menu":1,"count":1}]	21131	pick-up	0	12
52997	2020-04-22 07:10:53	2020-04-22	9	[{"id_menu":6,"count":1}]	12760	delivery	5	14
52998	2020-04-22 07:13:46	2020-04-22	17	[{"id_menu":4,"count":1}]	17002	delivery	5	22
52999	2020-04-22 07:14:16	2020-04-22	14	[{"id_menu":2,"count":1}]	21156	delivery	5	19
53000	2020-04-22 07:14:20	2020-04-22	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1509	pick-up	0	20
53001	2020-04-22 07:20:50	2020-04-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	640	pick-up	0	23
53002	2020-04-22 07:21:14	2020-04-22	14	[{"id_menu":2,"count":1}]	11704	pick-up	0	14
53003	2020-04-22 07:22:23	2020-04-22	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	21180	delivery	5	48
53004	2020-04-22 07:22:33	2020-04-22	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	4330	pick-up	0	31
53005	2020-04-22 07:24:14	2020-04-22	8	[{"id_menu":5,"count":1}]	1693	delivery	5	13
53006	2020-04-22 07:25:25	2020-04-22	17	[{"id_menu":4,"count":1}]	3719	pick-up	0	17
53007	2020-04-22 07:30:05	2020-04-22	12	[{"id_menu":3,"count":1}]	5501	delivery	5	17
53008	2020-04-22 07:30:30	2020-04-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7505	pick-up	0	23
53009	2020-04-22 07:39:04	2020-04-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2333	pick-up	0	31
53010	2020-04-22 07:47:10	2020-04-22	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	9219	delivery	5	40
53011	2020-04-22 07:47:46	2020-04-22	9	[{"id_menu":6,"count":1}]	10608	pick-up	0	9
53012	2020-04-22 07:50:51	2020-04-22	17	[{"id_menu":4,"count":1}]	7465	pick-up	0	17
53013	2020-04-22 07:51:25	2020-04-22	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	4976	pick-up	0	35
53014	2020-04-22 07:53:53	2020-04-22	14	[{"id_menu":2,"count":1}]	856	pick-up	0	14
53015	2020-04-22 07:54:00	2020-04-22	14	[{"id_menu":2,"count":1}]	13488	delivery	5	19
53016	2020-04-22 07:55:58	2020-04-22	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	7766	delivery	5	27
53017	2020-04-22 07:57:18	2020-04-22	14	[{"id_menu":2,"count":1}]	20524	delivery	5	19
53018	2020-04-22 07:59:53	2020-04-22	14	[{"id_menu":2,"count":2}]	8658	pick-up	0	14
53019	2020-04-22 08:03:49	2020-04-22	17	[{"id_menu":4,"count":1}]	21121	pick-up	0	17
53020	2020-04-22 08:07:48	2020-04-22	8	[{"id_menu":5,"count":1}]	19750	delivery	5	13
53021	2020-04-22 08:11:00	2020-04-22	37	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	12937	delivery	5	42
53022	2020-04-22 08:12:05	2020-04-22	9	[{"id_menu":6,"count":1}]	9829	pick-up	0	9
53023	2020-04-22 08:21:35	2020-04-22	12	[{"id_menu":3,"count":1}]	5144	pick-up	0	12
53024	2020-04-22 08:26:05	2020-04-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	21089	delivery	5	28
53025	2020-04-22 08:30:10	2020-04-22	14	[{"id_menu":2,"count":1}]	15723	delivery	5	19
53026	2020-04-22 08:34:09	2020-04-22	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	21167	delivery	5	45
53027	2020-04-22 08:36:06	2020-04-22	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	688	pick-up	0	43
53028	2020-04-22 08:36:36	2020-04-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	21191	delivery	5	28
53029	2020-04-22 08:38:09	2020-04-22	8	[{"id_menu":5,"count":1}]	18961	delivery	5	13
53030	2020-04-22 08:39:12	2020-04-22	9	[{"id_menu":7,"count":1}]	6	pick-up	0	9
53031	2020-04-22 08:42:32	2020-04-22	12	[{"id_menu":3,"count":1}]	12165	delivery	5	17
53032	2020-04-22 08:43:32	2020-04-22	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15690	delivery	5	45
53033	2020-04-22 08:54:31	2020-04-22	14	[{"id_menu":2,"count":1}]	21170	delivery	5	19
53034	2020-04-22 08:55:08	2020-04-22	12	[{"id_menu":3,"count":1}]	16218	delivery	5	17
53035	2020-04-22 08:55:48	2020-04-22	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12461	delivery	5	22
53036	2020-04-22 08:58:21	2020-04-22	17	[{"id_menu":4,"count":1}]	467	delivery	5	22
53037	2020-04-22 09:04:20	2020-04-22	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	21197	delivery	5	45
53038	2020-04-22 09:04:57	2020-04-22	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9108	delivery	5	35
53039	2020-04-22 09:11:41	2020-04-22	14	[{"id_menu":2,"count":1}]	21202	delivery	5	19
53040	2020-04-22 09:14:33	2020-04-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	21175	delivery	5	28
53041	2020-04-22 09:14:35	2020-04-22	17	[{"id_menu":4,"count":1}]	3460	delivery	5	22
53042	2020-04-22 09:15:37	2020-04-22	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14518	delivery	5	36
53043	2020-04-22 09:22:00	2020-04-22	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	16042	pick-up	0	21
53044	2020-04-22 09:29:08	2020-04-22	14	[{"id_menu":2,"count":2}]	381	pick-up	0	14
53045	2020-04-22 09:32:21	2020-04-22	9	[{"id_menu":6,"count":1}]	15255	delivery	5	14
53046	2020-04-22 09:35:26	2020-04-22	17	[{"id_menu":4,"count":1}]	5602	delivery	5	22
53047	2020-04-22 09:35:41	2020-04-22	12	[{"id_menu":1,"count":1}]	766	pick-up	0	12
53048	2020-04-22 09:38:29	2020-04-22	8	[{"id_menu":5,"count":1}]	9072	delivery	5	13
53049	2020-04-22 09:40:43	2020-04-22	17	[{"id_menu":4,"count":1}]	10434	delivery	5	22
53050	2020-04-22 09:42:22	2020-04-22	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6962	delivery	5	54
53051	2020-04-22 09:46:53	2020-04-22	8	[{"id_menu":5,"count":1}]	5447	pick-up	0	8
53052	2020-04-22 09:51:57	2020-04-22	14	[{"id_menu":2,"count":1}]	12268	delivery	5	19
53053	2020-04-22 09:52:17	2020-04-22	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	21209	delivery	5	26
53054	2020-04-22 09:59:04	2020-04-22	12	[{"id_menu":1,"count":1}]	17639	delivery	5	17
53055	2020-04-22 10:04:09	2020-04-22	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5110	delivery	5	31
53056	2020-04-22 10:10:14	2020-04-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	21145	delivery	5	28
53057	2020-04-22 10:13:30	2020-04-22	9	[{"id_menu":6,"count":1}]	21176	delivery	5	14
53058	2020-04-22 10:13:39	2020-04-22	8	[{"id_menu":5,"count":1}]	4192	delivery	5	13
53059	2020-04-22 10:15:10	2020-04-22	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	10442	delivery	5	31
53060	2020-04-22 10:19:51	2020-04-22	12	[{"id_menu":1,"count":1}]	21184	pick-up	0	12
53061	2020-04-22 10:20:58	2020-04-22	9	[{"id_menu":7,"count":1}]	982	delivery	5	14
53062	2020-04-22 10:30:34	2020-04-22	12	[{"id_menu":3,"count":1}]	21108	delivery	5	17
53063	2020-04-22 10:32:39	2020-04-22	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19916	delivery	5	47
53064	2020-04-22 10:33:41	2020-04-22	17	[{"id_menu":4,"count":1}]	21095	delivery	5	22
53065	2020-04-22 10:36:14	2020-04-22	9	[{"id_menu":6,"count":1}]	6918	delivery	5	14
53066	2020-04-22 10:36:40	2020-04-22	9	[{"id_menu":6,"count":1}]	18879	delivery	5	14
53067	2020-04-22 10:37:28	2020-04-22	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	21134	delivery	5	26
53068	2020-04-22 10:42:30	2020-04-22	9	[{"id_menu":6,"count":1}]	21210	delivery	5	14
53069	2020-04-22 10:44:19	2020-04-22	17	[{"id_menu":4,"count":1}]	21204	delivery	5	22
53070	2020-04-22 10:50:31	2020-04-22	12	[{"id_menu":3,"count":1}]	9835	delivery	5	17
53071	2020-04-22 10:54:35	2020-04-22	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	11160	delivery	5	34
53072	2020-04-22 10:56:25	2020-04-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7815	pick-up	0	18
53073	2020-04-22 10:58:12	2020-04-22	9	[{"id_menu":7,"count":1}]	21190	delivery	5	14
53074	2020-04-22 11:00:40	2020-04-22	9	[{"id_menu":7,"count":1}]	20122	delivery	5	14
53075	2020-04-22 11:01:48	2020-04-22	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2287	pick-up	0	26
53076	2020-04-22 11:04:27	2020-04-22	14	[{"id_menu":2,"count":1}]	1025	pick-up	0	14
53077	2020-04-22 11:08:10	2020-04-22	9	[{"id_menu":7,"count":1}]	21129	delivery	5	14
53078	2020-04-22 11:10:10	2020-04-22	12	[{"id_menu":3,"count":1}]	19657	delivery	5	17
53079	2020-04-22 11:16:32	2020-04-22	17	[{"id_menu":4,"count":1}]	99	pick-up	0	17
53080	2020-04-22 11:23:15	2020-04-22	12	[{"id_menu":3,"count":1}]	21118	delivery	5	17
53081	2020-04-22 11:29:07	2020-04-22	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	7033	pick-up	0	26
53082	2020-04-22 11:39:02	2020-04-22	17	[{"id_menu":4,"count":1}]	1453	pick-up	0	17
53083	2020-04-22 11:40:50	2020-04-22	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11096	delivery	5	48
53084	2020-04-22 11:43:19	2020-04-22	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	21199	delivery	5	34
53085	2020-04-22 11:45:16	2020-04-22	17	[{"id_menu":4,"count":1}]	21193	pick-up	0	17
53086	2020-04-22 11:47:36	2020-04-22	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	21109	pick-up	0	23
53087	2020-04-22 11:48:05	2020-04-22	9	[{"id_menu":6,"count":1}]	176	delivery	5	14
53088	2020-04-22 11:48:13	2020-04-22	9	[{"id_menu":7,"count":1}]	7939	delivery	5	14
53089	2020-04-22 11:49:55	2020-04-22	9	[{"id_menu":7,"count":1}]	10157	delivery	5	14
53090	2020-04-22 11:52:10	2020-04-22	12	[{"id_menu":1,"count":1}]	2124	pick-up	0	12
53091	2020-04-22 11:56:02	2020-04-22	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15300	delivery	5	40
53092	2020-04-22 11:57:40	2020-04-22	14	[{"id_menu":2,"count":1}]	905	pick-up	0	14
53093	2020-04-22 12:18:19	2020-04-22	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	21116	delivery	5	34
53094	2020-04-22 12:18:30	2020-04-22	12	[{"id_menu":3,"count":1}]	634	pick-up	0	12
53095	2020-04-22 12:27:14	2020-04-22	14	[{"id_menu":2,"count":1}]	6247	delivery	5	19
53096	2020-04-22 12:29:08	2020-04-22	12	[{"id_menu":3,"count":1}]	170	pick-up	0	12
53097	2020-04-22 12:33:20	2020-04-22	12	[{"id_menu":3,"count":1}]	14913	pick-up	0	12
53098	2020-04-22 12:36:28	2020-04-22	8	[{"id_menu":5,"count":1}]	12105	delivery	5	13
53099	2020-04-22 12:37:05	2020-04-22	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21135	delivery	5	35
53100	2020-04-22 12:37:10	2020-04-22	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21205	delivery	5	48
53101	2020-04-22 12:44:22	2020-04-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21185	delivery	5	23
53102	2020-04-22 12:46:54	2020-04-22	8	[{"id_menu":5,"count":1}]	21182	delivery	5	13
53103	2020-04-22 12:49:07	2020-04-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	21162	delivery	5	22
53104	2020-04-22 12:53:32	2020-04-22	9	[{"id_menu":7,"count":1}]	10258	pick-up	0	9
53105	2020-04-22 12:54:04	2020-04-22	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21173	delivery	5	48
53106	2020-04-22 12:54:54	2020-04-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	19056	delivery	5	28
53107	2020-04-22 12:56:30	2020-04-22	12	[{"id_menu":1,"count":1}]	21101	delivery	5	17
53108	2020-04-22 13:06:34	2020-04-22	12	[{"id_menu":3,"count":1}]	13507	delivery	5	17
53109	2020-04-22 13:07:30	2020-04-22	14	[{"id_menu":2,"count":1}]	21154	delivery	5	19
53110	2020-04-22 13:13:49	2020-04-22	9	[{"id_menu":7,"count":1}]	12367	pick-up	0	9
53111	2020-04-22 13:15:26	2020-04-22	8	[{"id_menu":5,"count":1}]	21105	delivery	5	13
53112	2020-04-22 13:18:01	2020-04-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4800	pick-up	0	23
53113	2020-04-22 13:24:38	2020-04-22	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19597	delivery	5	39
53114	2020-04-22 13:25:55	2020-04-22	12	[{"id_menu":1,"count":1}]	123	delivery	5	17
53115	2020-04-22 13:27:45	2020-04-22	9	[{"id_menu":6,"count":1}]	13930	pick-up	0	9
53116	2020-04-22 13:30:23	2020-04-22	9	[{"id_menu":7,"count":1}]	9199	delivery	5	14
53117	2020-04-22 13:32:17	2020-04-22	12	[{"id_menu":1,"count":1}]	17815	delivery	5	17
53118	2020-04-22 13:34:04	2020-04-22	17	[{"id_menu":4,"count":1}]	12699	delivery	5	22
53119	2020-04-22 13:35:06	2020-04-22	9	[{"id_menu":7,"count":1}]	4710	pick-up	0	9
53120	2020-04-22 13:40:04	2020-04-22	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":3}]	21132	delivery	5	31
53121	2020-04-22 13:42:31	2020-04-22	8	[{"id_menu":5,"count":1}]	9876	delivery	5	13
53122	2020-04-22 13:45:38	2020-04-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	11181	delivery	5	28
53123	2020-04-22 13:53:18	2020-04-22	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	21149	delivery	5	31
53124	2020-04-22 13:58:18	2020-04-22	9	[{"id_menu":7,"count":1}]	21092	delivery	5	14
53125	2020-04-22 13:58:32	2020-04-22	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8683	delivery	5	39
53126	2020-04-22 13:58:55	2020-04-22	12	[{"id_menu":1,"count":1}]	7151	pick-up	0	12
53127	2020-04-22 14:07:04	2020-04-22	17	[{"id_menu":4,"count":1}]	21098	delivery	5	22
53128	2020-04-22 14:18:36	2020-04-22	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	21085	delivery	5	31
53129	2020-04-22 14:18:39	2020-04-22	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21152	delivery	5	52
53130	2020-04-22 14:29:37	2020-04-22	9	[{"id_menu":7,"count":1}]	7633	delivery	5	14
53131	2020-04-22 14:35:31	2020-04-22	9	[{"id_menu":6,"count":1}]	21124	delivery	5	14
53132	2020-04-22 14:39:55	2020-04-22	9	[{"id_menu":7,"count":1}]	11407	pick-up	0	9
53133	2020-04-22 14:40:10	2020-04-22	9	[{"id_menu":6,"count":1}]	21125	delivery	5	14
53134	2020-04-22 14:46:41	2020-04-22	9	[{"id_menu":7,"count":1}]	21094	delivery	5	14
53135	2020-04-22 14:48:39	2020-04-22	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14110	delivery	5	39
53136	2020-04-22 14:52:56	2020-04-22	12	[{"id_menu":3,"count":1}]	7683	pick-up	0	12
53137	2020-04-22 14:55:42	2020-04-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5345	delivery	5	28
53138	2020-04-22 14:56:56	2020-04-22	9	[{"id_menu":7,"count":1}]	21178	delivery	5	14
53139	2020-04-22 15:00:55	2020-04-22	8	[{"id_menu":5,"count":2}]	8980	delivery	5	13
53140	2020-04-22 15:04:57	2020-04-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	17209	pick-up	0	31
53141	2020-04-22 15:06:18	2020-04-22	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18616	delivery	5	35
53142	2020-04-22 15:09:33	2020-04-22	17	[{"id_menu":4,"count":2}]	541	delivery	5	22
53143	2020-04-22 15:10:04	2020-04-22	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	21114	delivery	5	29
53144	2020-04-22 15:10:58	2020-04-22	9	[{"id_menu":7,"count":1}]	8535	delivery	5	14
53145	2020-04-22 15:14:21	2020-04-22	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14461	delivery	5	43
53146	2020-04-22 15:22:12	2020-04-22	9	[{"id_menu":6,"count":1}]	12110	pick-up	0	9
53147	2020-04-22 15:31:10	2020-04-22	14	[{"id_menu":2,"count":1}]	4223	pick-up	0	14
53148	2020-04-22 15:32:19	2020-04-22	8	[{"id_menu":5,"count":1}]	20554	pick-up	0	8
53149	2020-04-22 15:37:10	2020-04-22	9	[{"id_menu":6,"count":1}]	21139	delivery	5	14
53150	2020-04-22 15:41:31	2020-04-22	9	[{"id_menu":7,"count":1}]	21136	delivery	5	14
53151	2020-04-22 15:45:01	2020-04-22	14	[{"id_menu":2,"count":1}]	628	delivery	5	19
53152	2020-04-22 15:49:38	2020-04-22	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21126	delivery	5	22
53153	2020-04-22 15:51:07	2020-04-22	9	[{"id_menu":6,"count":1}]	9187	delivery	5	14
53154	2020-04-22 16:04:30	2020-04-22	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	7161	delivery	5	36
53155	2020-04-22 16:10:43	2020-04-22	9	[{"id_menu":6,"count":1}]	9610	pick-up	0	9
53156	2020-04-22 16:13:04	2020-04-22	9	[{"id_menu":6,"count":1}]	2056	pick-up	0	9
53157	2020-04-22 16:15:04	2020-04-22	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	21107	delivery	5	38
53158	2020-04-22 16:19:43	2020-04-22	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3869	delivery	5	30
53159	2020-04-22 16:23:55	2020-04-22	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	21158	delivery	5	40
53160	2020-04-22 16:24:52	2020-04-22	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9327	delivery	5	37
53161	2020-04-22 16:26:49	2020-04-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14841	pick-up	0	17
53162	2020-04-22 16:28:26	2020-04-22	14	[{"id_menu":2,"count":1}]	21087	pick-up	0	14
53163	2020-04-22 16:29:45	2020-04-22	17	[{"id_menu":4,"count":1}]	15931	delivery	5	22
53164	2020-04-22 16:32:29	2020-04-22	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	21151	delivery	5	37
53165	2020-04-22 16:35:16	2020-04-22	17	[{"id_menu":4,"count":1}]	21091	delivery	5	22
53166	2020-04-22 16:47:30	2020-04-22	14	[{"id_menu":2,"count":1}]	21207	delivery	5	19
53167	2020-04-22 16:52:30	2020-04-22	14	[{"id_menu":2,"count":1}]	4047	delivery	5	19
53168	2020-04-22 16:53:53	2020-04-22	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	9465	delivery	5	26
53169	2020-04-22 16:57:40	2020-04-22	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16869	delivery	5	31
53170	2020-04-22 17:07:16	2020-04-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	21187	delivery	5	28
53171	2020-04-22 17:11:36	2020-04-22	14	[{"id_menu":2,"count":1}]	5994	delivery	5	19
53172	2020-04-22 17:15:35	2020-04-22	17	[{"id_menu":4,"count":1}]	10389	pick-up	0	17
53173	2020-04-22 17:17:15	2020-04-22	12	[{"id_menu":1,"count":1}]	8866	delivery	5	17
53174	2020-04-22 17:19:09	2020-04-22	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	80	pick-up	0	26
53175	2020-04-22 17:41:13	2020-04-22	17	[{"id_menu":4,"count":1}]	8229	pick-up	0	17
53176	2020-04-22 17:42:29	2020-04-22	9	[{"id_menu":6,"count":1}]	16264	delivery	5	14
53177	2020-04-22 17:47:06	2020-04-22	9	[{"id_menu":6,"count":1}]	5786	delivery	5	14
53178	2020-04-22 17:55:43	2020-04-22	9	[{"id_menu":6,"count":1}]	21064	delivery	5	14
53179	2020-04-22 17:57:49	2020-04-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	17725	delivery	5	28
53180	2020-04-22 18:00:24	2020-04-22	12	[{"id_menu":1,"count":1}]	21203	pick-up	0	12
53181	2020-04-22 18:00:44	2020-04-22	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21206	delivery	5	48
53182	2020-04-22 18:05:44	2020-04-22	8	[{"id_menu":5,"count":1}]	2517	delivery	5	13
53183	2020-04-22 18:05:47	2020-04-22	12	[{"id_menu":1,"count":1}]	778	delivery	5	17
53184	2020-04-22 18:06:59	2020-04-22	9	[{"id_menu":6,"count":1}]	9428	delivery	5	14
53185	2020-04-22 18:13:29	2020-04-22	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1513	pick-up	0	24
53186	2020-04-22 18:14:30	2020-04-22	9	[{"id_menu":7,"count":3}]	8212	delivery	5	14
53187	2020-04-22 18:15:01	2020-04-22	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	21165	delivery	5	25
53188	2020-04-22 18:17:02	2020-04-22	8	[{"id_menu":5,"count":1}]	21102	delivery	5	13
53189	2020-04-22 18:19:05	2020-04-22	12	[{"id_menu":3,"count":1}]	10356	delivery	5	17
53190	2020-04-22 18:19:48	2020-04-22	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	21174	delivery	5	40
53191	2020-04-22 18:21:55	2020-04-22	12	[{"id_menu":3,"count":1}]	21164	delivery	5	17
53192	2020-04-22 18:23:29	2020-04-22	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	21127	delivery	5	26
53193	2020-04-22 18:24:08	2020-04-22	9	[{"id_menu":7,"count":1}]	21117	delivery	5	14
53194	2020-04-22 18:30:45	2020-04-22	8	[{"id_menu":5,"count":1}]	627	pick-up	0	8
53195	2020-04-22 18:45:08	2020-04-22	14	[{"id_menu":2,"count":1}]	15444	delivery	5	19
53196	2020-04-22 18:47:20	2020-04-22	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21196	delivery	5	36
53197	2020-04-22 18:47:33	2020-04-22	12	[{"id_menu":3,"count":1}]	19509	delivery	5	17
53198	2020-04-22 18:50:00	2020-04-22	17	[{"id_menu":4,"count":1}]	11942	delivery	5	22
53199	2020-04-22 18:55:35	2020-04-22	14	[{"id_menu":2,"count":1}]	21148	delivery	5	19
53200	2020-04-22 19:00:44	2020-04-22	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	12855	pick-up	0	20
53201	2020-04-22 19:01:29	2020-04-22	8	[{"id_menu":5,"count":1}]	5004	delivery	5	13
53202	2020-04-22 19:03:06	2020-04-22	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15301	delivery	5	45
53203	2020-04-22 19:05:54	2020-04-22	14	[{"id_menu":2,"count":1}]	11878	pick-up	0	14
53204	2020-04-22 19:10:43	2020-04-22	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4772	delivery	5	39
53205	2020-04-22 19:19:32	2020-04-22	12	[{"id_menu":1,"count":1}]	4846	pick-up	0	12
53206	2020-04-22 19:27:32	2020-04-22	14	[{"id_menu":2,"count":1}]	5550	delivery	5	19
53207	2020-04-22 19:31:48	2020-04-22	8	[{"id_menu":5,"count":1}]	21086	delivery	5	13
53208	2020-04-22 19:32:25	2020-04-22	12	[{"id_menu":1,"count":1}]	21112	delivery	5	17
53209	2020-04-22 19:35:30	2020-04-22	9	[{"id_menu":6,"count":1}]	19060	delivery	5	14
53210	2020-04-22 19:39:03	2020-04-22	9	[{"id_menu":7,"count":1}]	314	delivery	5	14
53211	2020-04-22 19:40:13	2020-04-22	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	21163	delivery	5	26
53212	2020-04-22 19:47:10	2020-04-22	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	21100	delivery	5	31
53213	2020-04-22 19:47:23	2020-04-22	9	[{"id_menu":7,"count":1}]	14354	delivery	5	14
53214	2020-04-22 19:50:46	2020-04-22	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21186	delivery	5	34
53215	2020-04-22 19:56:58	2020-04-22	14	[{"id_menu":2,"count":1}]	11146	pick-up	0	14
53216	2020-04-22 19:59:49	2020-04-22	9	[{"id_menu":6,"count":1}]	20831	delivery	5	14
53217	2020-04-22 20:03:17	2020-04-22	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	17700	delivery	5	25
53218	2020-04-22 20:06:22	2020-04-22	9	[{"id_menu":6,"count":1}]	5069	delivery	5	14
53219	2020-04-22 20:07:32	2020-04-22	9	[{"id_menu":6,"count":1}]	6429	delivery	5	14
53220	2020-04-22 20:08:28	2020-04-22	14	[{"id_menu":2,"count":1}]	14585	pick-up	0	14
53221	2020-04-22 20:10:26	2020-04-22	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	16272	delivery	5	26
53222	2020-04-22 20:13:10	2020-04-22	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	11766	delivery	5	39
53223	2020-04-22 20:19:39	2020-04-22	12	[{"id_menu":1,"count":1}]	14303	delivery	5	17
53224	2020-04-22 20:26:15	2020-04-22	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4347	delivery	5	34
53225	2020-04-22 20:28:05	2020-04-22	12	[{"id_menu":1,"count":2}]	20850	pick-up	0	12
53226	2020-04-22 20:33:07	2020-04-22	8	[{"id_menu":5,"count":1}]	3801	delivery	5	13
53227	2020-04-22 20:38:25	2020-04-22	9	[{"id_menu":7,"count":1}]	6819	delivery	5	14
53228	2020-04-22 20:42:11	2020-04-22	8	[{"id_menu":5,"count":1}]	7361	delivery	5	13
53229	2020-04-22 20:45:44	2020-04-22	17	[{"id_menu":4,"count":1}]	623	delivery	5	22
53230	2020-04-22 20:52:46	2020-04-22	17	[{"id_menu":4,"count":1}]	20159	delivery	5	22
53231	2020-04-22 20:55:26	2020-04-22	14	[{"id_menu":2,"count":1}]	11681	pick-up	0	14
53232	2020-04-22 21:03:08	2020-04-22	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	21133	delivery	5	34
53233	2020-04-22 21:06:15	2020-04-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2885	delivery	5	28
53234	2020-04-22 21:09:15	2020-04-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2272	pick-up	0	31
53235	2020-04-22 21:10:04	2020-04-22	9	[{"id_menu":7,"count":1}]	21194	delivery	5	14
53236	2020-04-22 21:17:48	2020-04-22	8	[{"id_menu":5,"count":1}]	21104	pick-up	0	8
53237	2020-04-22 21:18:31	2020-04-22	12	[{"id_menu":3,"count":1}]	563	pick-up	0	12
53238	2020-04-22 21:20:40	2020-04-22	8	[{"id_menu":5,"count":1}]	10727	pick-up	0	8
53239	2020-04-22 21:23:53	2020-04-22	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	21096	delivery	5	25
53240	2020-04-22 21:30:39	2020-04-22	12	[{"id_menu":1,"count":1}]	6090	pick-up	0	12
53241	2020-04-22 21:34:18	2020-04-22	17	[{"id_menu":4,"count":1}]	150	pick-up	0	17
53242	2020-04-22 21:44:24	2020-04-22	8	[{"id_menu":5,"count":1}]	21183	delivery	5	13
53243	2020-04-22 21:44:46	2020-04-22	17	[{"id_menu":4,"count":1}]	19129	pick-up	0	17
53244	2020-04-22 21:55:12	2020-04-22	17	[{"id_menu":4,"count":1}]	21142	delivery	5	22
53245	2020-04-22 21:59:44	2020-04-22	8	[{"id_menu":5,"count":1}]	6168	delivery	5	13
53246	2020-04-22 21:59:57	2020-04-22	14	[{"id_menu":2,"count":1}]	5040	delivery	5	19
53247	2020-04-22 22:01:44	2020-04-22	12	[{"id_menu":3,"count":1}]	11943	delivery	5	17
53248	2020-04-22 22:02:10	2020-04-22	9	[{"id_menu":6,"count":1}]	19118	delivery	5	14
53249	2020-04-22 22:02:37	2020-04-22	9	[{"id_menu":7,"count":1}]	21153	delivery	5	14
53250	2020-04-22 22:03:03	2020-04-22	38	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16230	delivery	5	43
53251	2020-04-22 22:03:59	2020-04-22	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	14956	delivery	5	25
53252	2020-04-22 22:06:53	2020-04-22	9	[{"id_menu":7,"count":1}]	5456	delivery	5	14
53253	2020-04-22 22:06:54	2020-04-22	9	[{"id_menu":7,"count":1}]	489	pick-up	0	9
53254	2020-04-22 22:08:53	2020-04-22	9	[{"id_menu":7,"count":1}]	12228	delivery	5	14
53255	2020-04-22 22:10:43	2020-04-22	17	[{"id_menu":4,"count":2}]	8628	delivery	5	22
53256	2020-04-22 22:17:40	2020-04-22	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1194	pick-up	0	21
53257	2020-04-22 22:18:04	2020-04-22	12	[{"id_menu":3,"count":1}]	11896	pick-up	0	12
53258	2020-04-22 22:25:35	2020-04-22	14	[{"id_menu":2,"count":1}]	15245	delivery	5	19
53259	2020-04-22 22:25:49	2020-04-22	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21120	delivery	5	22
53260	2020-04-22 22:28:18	2020-04-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	21179	delivery	5	28
53261	2020-04-22 22:28:43	2020-04-22	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1384	pick-up	0	26
53262	2020-04-22 22:31:27	2020-04-22	9	[{"id_menu":6,"count":1}]	3393	delivery	5	14
53263	2020-04-22 22:32:32	2020-04-22	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4325	delivery	5	45
53264	2020-04-22 22:45:01	2020-04-22	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13967	delivery	5	34
53265	2020-04-22 22:50:05	2020-04-22	12	[{"id_menu":1,"count":1}]	9386	delivery	5	17
53266	2020-04-22 23:23:31	2020-04-22	14	[{"id_menu":2,"count":1}]	21155	delivery	5	19
53267	2020-04-22 23:34:17	2020-04-22	14	[{"id_menu":2,"count":1}]	21103	pick-up	0	14
53268	2020-04-22 23:35:12	2020-04-22	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21090	delivery	5	49
53269	2020-04-22 23:35:47	2020-04-22	9	[{"id_menu":6,"count":1}]	15596	delivery	5	14
53270	2020-04-22 23:38:38	2020-04-22	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21140	delivery	5	36
53271	2020-04-22 23:39:15	2020-04-22	12	[{"id_menu":3,"count":1}]	11046	delivery	5	17
53272	2020-04-22 23:42:46	2020-04-22	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	19039	delivery	5	27
53273	2020-04-22 23:50:41	2020-04-22	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	7532	delivery	5	34
53274	2020-04-23 00:00:21	2020-04-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13667	delivery	5	23
53275	2020-04-23 00:02:37	2020-04-23	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	17359	delivery	5	23
53276	2020-04-23 00:09:20	2020-04-23	9	[{"id_menu":6,"count":1}]	21274	delivery	5	14
53277	2020-04-23 00:09:47	2020-04-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	21328	delivery	5	28
53278	2020-04-23 00:17:36	2020-04-23	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	21342	delivery	5	43
53279	2020-04-23 00:20:23	2020-04-23	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	21236	delivery	5	27
53280	2020-04-23 00:21:56	2020-04-23	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21232	delivery	5	37
53281	2020-04-23 00:22:01	2020-04-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	21243	delivery	5	31
53282	2020-04-23 00:24:35	2020-04-23	12	[{"id_menu":3,"count":1}]	4525	pick-up	0	12
53283	2020-04-23 00:31:56	2020-04-23	12	[{"id_menu":1,"count":1}]	1569	pick-up	0	12
53284	2020-04-23 00:37:03	2020-04-23	9	[{"id_menu":7,"count":1}]	21279	delivery	5	14
53285	2020-04-23 00:39:06	2020-04-23	14	[{"id_menu":2,"count":1}]	10440	delivery	5	19
53286	2020-04-23 00:39:56	2020-04-23	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	21221	delivery	5	29
53287	2020-04-23 00:41:08	2020-04-23	9	[{"id_menu":7,"count":1}]	190	pick-up	0	9
53288	2020-04-23 00:42:40	2020-04-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	295	pick-up	0	31
53289	2020-04-23 00:44:34	2020-04-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	10019	delivery	5	36
53290	2020-04-23 00:52:05	2020-04-23	14	[{"id_menu":2,"count":1}]	10576	delivery	5	19
53291	2020-04-23 00:58:17	2020-04-23	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	11992	pick-up	0	21
53292	2020-04-23 00:58:30	2020-04-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	16797	delivery	5	22
53293	2020-04-23 01:00:59	2020-04-23	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20209	delivery	5	40
53294	2020-04-23 01:07:53	2020-04-23	8	[{"id_menu":5,"count":1}]	2631	pick-up	0	8
53295	2020-04-23 01:10:07	2020-04-23	9	[{"id_menu":7,"count":1}]	21341	delivery	5	14
53296	2020-04-23 01:10:42	2020-04-23	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	21295	delivery	5	30
53297	2020-04-23 01:11:00	2020-04-23	9	[{"id_menu":6,"count":2}]	2803	pick-up	0	9
53298	2020-04-23 01:11:31	2020-04-23	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	10072	delivery	5	31
53299	2020-04-23 01:11:56	2020-04-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10556	pick-up	0	26
53300	2020-04-23 01:15:30	2020-04-23	9	[{"id_menu":7,"count":1}]	17857	delivery	5	14
53301	2020-04-23 01:17:48	2020-04-23	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	21231	delivery	5	48
53302	2020-04-23 01:22:42	2020-04-23	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4325	delivery	5	22
53303	2020-04-23 01:23:33	2020-04-23	8	[{"id_menu":5,"count":1}]	21233	delivery	5	13
53304	2020-04-23 01:23:55	2020-04-23	14	[{"id_menu":2,"count":1}]	21258	delivery	5	19
53305	2020-04-23 01:25:02	2020-04-23	12	[{"id_menu":3,"count":1}]	1266	pick-up	0	12
53306	2020-04-23 01:26:40	2020-04-23	8	[{"id_menu":5,"count":1}]	14281	delivery	5	13
53307	2020-04-23 01:30:32	2020-04-23	17	[{"id_menu":4,"count":1}]	13105	delivery	5	22
53308	2020-04-23 01:39:51	2020-04-23	9	[{"id_menu":6,"count":1}]	21259	delivery	5	14
53309	2020-04-23 01:46:15	2020-04-23	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	8512	delivery	5	37
53310	2020-04-23 01:47:31	2020-04-23	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2416	pick-up	0	25
53311	2020-04-23 01:54:35	2020-04-23	9	[{"id_menu":6,"count":1}]	8057	pick-up	0	9
53312	2020-04-23 02:00:18	2020-04-23	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21220	delivery	5	45
53313	2020-04-23 02:01:01	2020-04-23	12	[{"id_menu":3,"count":1}]	17509	delivery	5	17
53314	2020-04-23 02:09:46	2020-04-23	12	[{"id_menu":1,"count":1}]	7882	delivery	5	17
53315	2020-04-23 02:12:09	2020-04-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	10159	delivery	5	28
53316	2020-04-23 02:15:38	2020-04-23	14	[{"id_menu":2,"count":1}]	8995	pick-up	0	14
53317	2020-04-23 02:18:07	2020-04-23	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	14813	delivery	5	39
53318	2020-04-23 02:18:27	2020-04-23	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	21324	delivery	5	26
53319	2020-04-23 02:18:54	2020-04-23	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	21065	delivery	5	31
53320	2020-04-23 02:20:54	2020-04-23	9	[{"id_menu":6,"count":1}]	13182	delivery	5	14
53321	2020-04-23 02:25:06	2020-04-23	9	[{"id_menu":6,"count":1}]	401	pick-up	0	9
53322	2020-04-23 02:25:48	2020-04-23	12	[{"id_menu":3,"count":1}]	21270	pick-up	0	12
53323	2020-04-23 02:32:51	2020-04-23	9	[{"id_menu":6,"count":1}]	6097	pick-up	0	9
53324	2020-04-23 02:33:13	2020-04-23	12	[{"id_menu":1,"count":2}]	628	delivery	5	17
53325	2020-04-23 02:34:50	2020-04-23	9	[{"id_menu":6,"count":1}]	2372	delivery	5	14
53326	2020-04-23 02:35:32	2020-04-23	12	[{"id_menu":1,"count":1}]	18316	pick-up	0	12
53327	2020-04-23 02:37:06	2020-04-23	17	[{"id_menu":4,"count":1}]	3172	pick-up	0	17
53328	2020-04-23 02:37:19	2020-04-23	46	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	16081	pick-up	0	46
53329	2020-04-23 02:39:12	2020-04-23	14	[{"id_menu":2,"count":1}]	2943	pick-up	0	14
53330	2020-04-23 02:39:51	2020-04-23	9	[{"id_menu":7,"count":2}]	16181	delivery	5	14
53331	2020-04-23 02:41:55	2020-04-23	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	19243	pick-up	0	29
53332	2020-04-23 02:44:40	2020-04-23	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	21333	delivery	5	26
53333	2020-04-23 02:56:51	2020-04-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	13987	delivery	5	26
53334	2020-04-23 03:07:13	2020-04-23	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	21242	delivery	5	31
53335	2020-04-23 03:09:57	2020-04-23	12	[{"id_menu":3,"count":1}]	3752	delivery	5	17
53336	2020-04-23 03:10:59	2020-04-23	8	[{"id_menu":5,"count":1}]	21309	delivery	5	13
53337	2020-04-23 03:16:38	2020-04-23	14	[{"id_menu":2,"count":1}]	13940	pick-up	0	14
53338	2020-04-23 03:31:26	2020-04-23	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	20327	pick-up	0	29
53339	2020-04-23 03:35:55	2020-04-23	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	204	pick-up	0	26
53340	2020-04-23 03:43:32	2020-04-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7098	pick-up	0	31
53341	2020-04-23 03:50:53	2020-04-23	14	[{"id_menu":2,"count":1}]	2902	pick-up	0	14
53342	2020-04-23 03:52:53	2020-04-23	9	[{"id_menu":6,"count":1}]	3539	pick-up	0	9
53343	2020-04-23 03:55:48	2020-04-23	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10108	delivery	5	48
53344	2020-04-23 04:01:11	2020-04-23	9	[{"id_menu":6,"count":1}]	7451	delivery	5	14
53345	2020-04-23 04:02:33	2020-04-23	9	[{"id_menu":7,"count":1}]	17396	delivery	5	14
53346	2020-04-23 04:06:47	2020-04-23	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	12108	pick-up	0	26
53347	2020-04-23 04:08:32	2020-04-23	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	21217	delivery	5	52
53348	2020-04-23 04:11:52	2020-04-23	9	[{"id_menu":6,"count":1}]	4793	pick-up	0	9
53349	2020-04-23 04:11:59	2020-04-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	21337	delivery	5	36
53350	2020-04-23 04:16:17	2020-04-23	9	[{"id_menu":7,"count":1}]	1770	pick-up	0	9
53351	2020-04-23 04:17:57	2020-04-23	12	[{"id_menu":3,"count":1}]	13469	delivery	5	17
53352	2020-04-23 04:18:01	2020-04-23	8	[{"id_menu":5,"count":1}]	21227	delivery	5	13
53353	2020-04-23 04:20:17	2020-04-23	14	[{"id_menu":2,"count":1}]	21330	delivery	5	19
53354	2020-04-23 04:26:30	2020-04-23	8	[{"id_menu":5,"count":1}]	21289	delivery	5	13
53355	2020-04-23 04:29:25	2020-04-23	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14155	delivery	5	34
53356	2020-04-23 04:32:19	2020-04-23	12	[{"id_menu":3,"count":1}]	19957	delivery	5	17
53357	2020-04-23 04:38:23	2020-04-23	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3709	pick-up	0	43
53358	2020-04-23 04:40:24	2020-04-23	9	[{"id_menu":7,"count":1}]	5935	delivery	5	14
53359	2020-04-23 04:42:18	2020-04-23	14	[{"id_menu":2,"count":1}]	21318	delivery	5	19
53360	2020-04-23 04:45:14	2020-04-23	9	[{"id_menu":6,"count":1}]	12791	pick-up	0	9
53361	2020-04-23 04:45:35	2020-04-23	9	[{"id_menu":6,"count":1}]	10751	delivery	5	14
53362	2020-04-23 04:47:22	2020-04-23	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	15044	delivery	5	26
53363	2020-04-23 04:55:47	2020-04-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	21335	pick-up	0	23
53364	2020-04-23 05:02:59	2020-04-23	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	12442	pick-up	0	20
53365	2020-04-23 05:04:38	2020-04-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	480	delivery	5	31
53366	2020-04-23 05:04:47	2020-04-23	17	[{"id_menu":4,"count":1}]	21278	delivery	5	22
53367	2020-04-23 05:05:17	2020-04-23	12	[{"id_menu":1,"count":1}]	21331	delivery	5	17
53368	2020-04-23 05:05:55	2020-04-23	14	[{"id_menu":2,"count":1}]	21262	delivery	5	19
53369	2020-04-23 05:09:12	2020-04-23	14	[{"id_menu":2,"count":2}]	2664	delivery	5	19
53370	2020-04-23 05:10:14	2020-04-23	8	[{"id_menu":5,"count":1}]	2237	pick-up	0	8
53371	2020-04-23 05:16:45	2020-04-23	9	[{"id_menu":6,"count":1}]	16710	delivery	5	14
53372	2020-04-23 05:17:50	2020-04-23	9	[{"id_menu":6,"count":1}]	21310	delivery	5	14
53373	2020-04-23 05:27:42	2020-04-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":3}]	13241	delivery	5	31
53374	2020-04-23 05:27:57	2020-04-23	9	[{"id_menu":7,"count":1}]	10143	delivery	5	14
53375	2020-04-23 05:30:09	2020-04-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	4982	delivery	5	31
53376	2020-04-23 05:32:51	2020-04-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6101	pick-up	0	23
53377	2020-04-23 05:38:33	2020-04-23	12	[{"id_menu":3,"count":1}]	16883	pick-up	0	12
53378	2020-04-23 05:45:02	2020-04-23	9	[{"id_menu":6,"count":1}]	21291	delivery	5	14
53379	2020-04-23 05:47:54	2020-04-23	12	[{"id_menu":1,"count":1}]	8385	delivery	5	17
53380	2020-04-23 05:53:45	2020-04-23	49	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	21326	delivery	5	54
53381	2020-04-23 05:56:54	2020-04-23	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8214	delivery	5	31
53382	2020-04-23 05:59:09	2020-04-23	12	[{"id_menu":1,"count":1}]	13497	pick-up	0	12
53383	2020-04-23 05:59:36	2020-04-23	8	[{"id_menu":5,"count":1}]	2007	pick-up	0	8
53384	2020-04-23 06:00:03	2020-04-23	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	179	pick-up	0	34
53385	2020-04-23 06:01:52	2020-04-23	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	14384	delivery	5	40
53386	2020-04-23 06:06:47	2020-04-23	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10518	delivery	5	40
53453	2020-04-23 10:08:01	2020-04-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	19114	delivery	5	26
53387	2020-04-23 06:07:28	2020-04-23	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	21317	delivery	5	43
53388	2020-04-23 06:18:52	2020-04-23	9	[{"id_menu":7,"count":1}]	21296	pick-up	0	9
53389	2020-04-23 06:22:13	2020-04-23	9	[{"id_menu":7,"count":1}]	14314	delivery	5	14
53390	2020-04-23 06:24:33	2020-04-23	9	[{"id_menu":6,"count":2}]	1811	pick-up	0	9
53391	2020-04-23 06:25:46	2020-04-23	12	[{"id_menu":1,"count":1}]	6565	pick-up	0	12
53392	2020-04-23 06:33:05	2020-04-23	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	8071	delivery	5	34
53393	2020-04-23 06:33:48	2020-04-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15005	delivery	5	22
53394	2020-04-23 06:38:46	2020-04-23	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9286	delivery	5	42
53395	2020-04-23 06:40:48	2020-04-23	12	[{"id_menu":1,"count":1}]	10065	delivery	5	17
53396	2020-04-23 06:42:05	2020-04-23	8	[{"id_menu":5,"count":1}]	4060	delivery	5	13
53397	2020-04-23 06:44:47	2020-04-23	9	[{"id_menu":6,"count":1}]	20249	delivery	5	14
53398	2020-04-23 06:45:49	2020-04-23	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4339	delivery	5	40
53399	2020-04-23 06:50:40	2020-04-23	12	[{"id_menu":1,"count":1}]	8632	delivery	5	17
53400	2020-04-23 06:54:10	2020-04-23	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	707	pick-up	0	35
53401	2020-04-23 06:59:36	2020-04-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	20182	delivery	5	36
53402	2020-04-23 07:05:02	2020-04-23	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17720	delivery	5	31
53403	2020-04-23 07:10:56	2020-04-23	12	[{"id_menu":3,"count":1}]	2420	pick-up	0	12
53404	2020-04-23 07:12:07	2020-04-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4400	pick-up	0	18
53405	2020-04-23 07:17:10	2020-04-23	17	[{"id_menu":4,"count":1}]	3180	pick-up	0	17
53406	2020-04-23 07:17:45	2020-04-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	19052	pick-up	0	21
53407	2020-04-23 07:20:03	2020-04-23	12	[{"id_menu":1,"count":1}]	19195	delivery	5	17
53408	2020-04-23 07:26:30	2020-04-23	12	[{"id_menu":1,"count":1}]	1719	pick-up	0	12
53409	2020-04-23 07:26:55	2020-04-23	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	15375	delivery	5	37
53410	2020-04-23 07:28:07	2020-04-23	9	[{"id_menu":7,"count":1}]	21228	delivery	5	14
53411	2020-04-23 07:28:14	2020-04-23	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	21315	delivery	5	26
53412	2020-04-23 07:28:57	2020-04-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	7983	pick-up	0	26
53413	2020-04-23 07:29:30	2020-04-23	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	8705	delivery	5	29
53414	2020-04-23 07:33:36	2020-04-23	14	[{"id_menu":2,"count":1}]	13941	delivery	5	19
53415	2020-04-23 07:44:43	2020-04-23	9	[{"id_menu":7,"count":1}]	4399	delivery	5	14
53416	2020-04-23 07:48:17	2020-04-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21212	delivery	5	23
53417	2020-04-23 07:48:57	2020-04-23	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	15407	delivery	5	29
53418	2020-04-23 08:05:27	2020-04-23	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	21307	delivery	5	30
53419	2020-04-23 08:10:56	2020-04-23	9	[{"id_menu":6,"count":1}]	21255	delivery	5	14
53420	2020-04-23 08:17:51	2020-04-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	20091	delivery	5	26
53421	2020-04-23 08:22:20	2020-04-23	14	[{"id_menu":2,"count":1}]	2980	delivery	5	19
53422	2020-04-23 08:23:58	2020-04-23	9	[{"id_menu":6,"count":1}]	2232	pick-up	0	9
53423	2020-04-23 08:27:55	2020-04-23	14	[{"id_menu":2,"count":1}]	3071	pick-up	0	14
53424	2020-04-23 08:30:18	2020-04-23	12	[{"id_menu":3,"count":1}]	5215	pick-up	0	12
53425	2020-04-23 08:30:20	2020-04-23	12	[{"id_menu":3,"count":1}]	19270	delivery	5	17
53426	2020-04-23 08:32:46	2020-04-23	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	21277	delivery	5	34
53427	2020-04-23 08:35:37	2020-04-23	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15334	delivery	5	53
53428	2020-04-23 08:39:43	2020-04-23	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5023	delivery	5	40
53429	2020-04-23 08:40:24	2020-04-23	9	[{"id_menu":6,"count":1}]	18627	delivery	5	14
53430	2020-04-23 08:43:19	2020-04-23	17	[{"id_menu":4,"count":1}]	2193	pick-up	0	17
53431	2020-04-23 08:46:44	2020-04-23	14	[{"id_menu":2,"count":1}]	3579	delivery	5	19
53432	2020-04-23 08:47:43	2020-04-23	9	[{"id_menu":6,"count":1}]	21294	delivery	5	14
53433	2020-04-23 08:54:58	2020-04-23	9	[{"id_menu":7,"count":1}]	2993	pick-up	0	9
53434	2020-04-23 08:56:14	2020-04-23	9	[{"id_menu":7,"count":1}]	3578	pick-up	0	9
53435	2020-04-23 09:04:42	2020-04-23	17	[{"id_menu":4,"count":2}]	3863	pick-up	0	17
53436	2020-04-23 09:13:54	2020-04-23	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2119	pick-up	0	17
53437	2020-04-23 09:17:20	2020-04-23	9	[{"id_menu":7,"count":1}]	21213	delivery	5	14
53438	2020-04-23 09:23:24	2020-04-23	17	[{"id_menu":4,"count":2}]	7685	delivery	5	22
53439	2020-04-23 09:25:07	2020-04-23	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	21303	delivery	5	30
53440	2020-04-23 09:25:21	2020-04-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2728	pick-up	0	26
53441	2020-04-23 09:30:11	2020-04-23	9	[{"id_menu":7,"count":1}]	1485	pick-up	0	9
53442	2020-04-23 09:32:18	2020-04-23	14	[{"id_menu":2,"count":1}]	16246	pick-up	0	14
53443	2020-04-23 09:41:45	2020-04-23	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	21284	delivery	5	40
53444	2020-04-23 09:52:15	2020-04-23	9	[{"id_menu":7,"count":1}]	20114	delivery	5	14
53445	2020-04-23 09:53:00	2020-04-23	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	186	pick-up	0	26
53446	2020-04-23 09:55:32	2020-04-23	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	21280	delivery	5	26
53447	2020-04-23 09:56:11	2020-04-23	9	[{"id_menu":7,"count":1}]	16926	pick-up	0	9
53448	2020-04-23 09:57:16	2020-04-23	12	[{"id_menu":3,"count":1}]	13758	delivery	5	17
53449	2020-04-23 09:57:22	2020-04-23	12	[{"id_menu":1,"count":1}]	16468	delivery	5	17
53450	2020-04-23 10:00:58	2020-04-23	14	[{"id_menu":2,"count":1}]	12827	delivery	5	19
53451	2020-04-23 10:01:48	2020-04-23	17	[{"id_menu":4,"count":1}]	21298	delivery	5	22
53452	2020-04-23 10:05:46	2020-04-23	8	[{"id_menu":5,"count":1}]	21287	delivery	5	13
53454	2020-04-23 10:09:53	2020-04-23	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11988	delivery	5	36
53455	2020-04-23 10:18:31	2020-04-23	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	519	delivery	5	36
53456	2020-04-23 10:21:13	2020-04-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	21336	delivery	5	28
53457	2020-04-23 10:23:03	2020-04-23	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5130	delivery	5	35
53458	2020-04-23 10:24:52	2020-04-23	9	[{"id_menu":6,"count":1}]	21249	delivery	5	14
53459	2020-04-23 10:27:49	2020-04-23	12	[{"id_menu":3,"count":1}]	21256	delivery	5	17
53460	2020-04-23 10:30:00	2020-04-23	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2752	pick-up	0	21
53461	2020-04-23 10:30:46	2020-04-23	8	[{"id_menu":5,"count":1}]	19300	pick-up	0	8
53462	2020-04-23 10:38:18	2020-04-23	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":2}]	20912	delivery	5	28
53463	2020-04-23 10:39:34	2020-04-23	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20990	delivery	5	49
53464	2020-04-23 10:39:54	2020-04-23	12	[{"id_menu":3,"count":1}]	21285	delivery	5	17
53465	2020-04-23 10:41:52	2020-04-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15881	delivery	5	22
53466	2020-04-23 10:58:40	2020-04-23	9	[{"id_menu":7,"count":1}]	20863	delivery	5	14
53467	2020-04-23 11:01:11	2020-04-23	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4137	pick-up	0	41
53468	2020-04-23 11:11:49	2020-04-23	12	[{"id_menu":1,"count":1}]	10421	delivery	5	17
53469	2020-04-23 11:12:13	2020-04-23	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	4030	delivery	5	26
53470	2020-04-23 11:12:22	2020-04-23	9	[{"id_menu":6,"count":1}]	324	pick-up	0	9
53471	2020-04-23 11:12:46	2020-04-23	17	[{"id_menu":4,"count":1}]	16592	delivery	5	22
53472	2020-04-23 11:12:48	2020-04-23	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10729	delivery	5	34
53473	2020-04-23 11:25:46	2020-04-23	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19663	delivery	5	37
53474	2020-04-23 11:30:50	2020-04-23	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7633	delivery	5	40
53475	2020-04-23 11:31:44	2020-04-23	9	[{"id_menu":7,"count":1}]	21229	delivery	5	14
53476	2020-04-23 11:33:25	2020-04-23	9	[{"id_menu":7,"count":1}]	9194	delivery	5	14
53477	2020-04-23 11:35:25	2020-04-23	9	[{"id_menu":6,"count":3}]	6919	delivery	5	14
53478	2020-04-23 11:36:07	2020-04-23	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21306	delivery	5	48
53479	2020-04-23 11:41:39	2020-04-23	9	[{"id_menu":7,"count":1}]	21325	delivery	5	14
53480	2020-04-23 11:43:48	2020-04-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7546	delivery	5	28
53481	2020-04-23 11:51:15	2020-04-23	9	[{"id_menu":7,"count":1}]	21286	delivery	5	14
53482	2020-04-23 11:52:41	2020-04-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	11756	delivery	5	28
53483	2020-04-23 11:55:31	2020-04-23	14	[{"id_menu":2,"count":2}]	21254	delivery	5	19
53484	2020-04-23 12:05:22	2020-04-23	12	[{"id_menu":3,"count":1}]	1509	delivery	5	17
53485	2020-04-23 12:06:17	2020-04-23	12	[{"id_menu":3,"count":1}]	15400	delivery	5	17
53486	2020-04-23 12:07:46	2020-04-23	9	[{"id_menu":7,"count":1}]	6702	delivery	5	14
53487	2020-04-23 12:13:23	2020-04-23	17	[{"id_menu":4,"count":1}]	12683	delivery	5	22
53488	2020-04-23 12:13:40	2020-04-23	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	106	delivery	5	38
53489	2020-04-23 12:14:35	2020-04-23	9	[{"id_menu":6,"count":1}]	9273	delivery	5	14
53490	2020-04-23 12:15:11	2020-04-23	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	10209	delivery	5	34
53491	2020-04-23 12:26:04	2020-04-23	9	[{"id_menu":7,"count":1}]	20963	delivery	5	14
53492	2020-04-23 12:29:16	2020-04-23	17	[{"id_menu":4,"count":2}]	10130	delivery	5	22
53493	2020-04-23 12:29:50	2020-04-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4694	delivery	5	22
53494	2020-04-23 12:37:04	2020-04-23	9	[{"id_menu":6,"count":1}]	4674	delivery	5	14
53495	2020-04-23 12:41:48	2020-04-23	9	[{"id_menu":6,"count":1}]	7888	delivery	5	14
53496	2020-04-23 12:50:54	2020-04-23	9	[{"id_menu":6,"count":1}]	21238	delivery	5	14
53497	2020-04-23 12:52:08	2020-04-23	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1472	delivery	5	26
53498	2020-04-23 12:57:06	2020-04-23	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	21334	pick-up	0	43
53499	2020-04-23 13:00:12	2020-04-23	9	[{"id_menu":7,"count":1}]	17959	delivery	5	14
53500	2020-04-23 13:02:49	2020-04-23	8	[{"id_menu":5,"count":1}]	12387	pick-up	0	8
53501	2020-04-23 13:04:24	2020-04-23	29	[{"id_menu":3,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21302	delivery	5	34
53502	2020-04-23 13:05:07	2020-04-23	8	[{"id_menu":5,"count":1}]	18186	delivery	5	13
53503	2020-04-23 13:06:38	2020-04-23	12	[{"id_menu":1,"count":1}]	21241	delivery	5	17
53504	2020-04-23 13:06:56	2020-04-23	8	[{"id_menu":5,"count":2}]	21319	delivery	5	13
53505	2020-04-23 13:11:38	2020-04-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	7485	delivery	5	31
53506	2020-04-23 13:13:11	2020-04-23	12	[{"id_menu":3,"count":1}]	21312	pick-up	0	12
53507	2020-04-23 13:14:01	2020-04-23	14	[{"id_menu":2,"count":1}]	12917	delivery	5	19
53508	2020-04-23 13:14:26	2020-04-23	17	[{"id_menu":4,"count":1}]	2110	delivery	5	22
53509	2020-04-23 13:20:22	2020-04-23	12	[{"id_menu":1,"count":1}]	3948	pick-up	0	12
53510	2020-04-23 13:21:10	2020-04-23	17	[{"id_menu":4,"count":1}]	12052	pick-up	0	17
53511	2020-04-23 13:27:58	2020-04-23	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	397	delivery	5	27
53512	2020-04-23 13:29:22	2020-04-23	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21223	delivery	5	53
53513	2020-04-23 13:33:13	2020-04-23	14	[{"id_menu":2,"count":1}]	2410	delivery	5	19
53514	2020-04-23 13:38:51	2020-04-23	9	[{"id_menu":6,"count":1}]	21288	delivery	5	14
53515	2020-04-23 13:41:21	2020-04-23	8	[{"id_menu":5,"count":1}]	12179	delivery	5	13
53516	2020-04-23 13:45:46	2020-04-23	14	[{"id_menu":2,"count":1}]	1098	delivery	5	19
53517	2020-04-23 13:49:08	2020-04-23	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	1568	delivery	5	34
53518	2020-04-23 13:52:06	2020-04-23	17	[{"id_menu":4,"count":1}]	5050	delivery	5	22
53586	2020-04-23 18:15:34	2020-04-23	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1316	pick-up	0	29
53519	2020-04-23 13:55:12	2020-04-23	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	21301	delivery	5	43
53520	2020-04-23 14:02:20	2020-04-23	9	[{"id_menu":7,"count":1}]	2579	pick-up	0	9
53521	2020-04-23 14:04:20	2020-04-23	12	[{"id_menu":3,"count":1}]	18629	delivery	5	17
53522	2020-04-23 14:06:33	2020-04-23	9	[{"id_menu":7,"count":1}]	2559	pick-up	0	9
53523	2020-04-23 14:09:34	2020-04-23	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	17333	delivery	5	25
53524	2020-04-23 14:12:06	2020-04-23	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	21281	delivery	5	43
53525	2020-04-23 14:25:03	2020-04-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18490	pick-up	0	17
53526	2020-04-23 14:27:21	2020-04-23	12	[{"id_menu":3,"count":2}]	21264	delivery	5	17
53527	2020-04-23 14:28:10	2020-04-23	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	21267	delivery	5	40
53528	2020-04-23 14:29:42	2020-04-23	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	21340	delivery	5	31
53529	2020-04-23 14:35:34	2020-04-23	12	[{"id_menu":1,"count":1}]	1674	pick-up	0	12
53530	2020-04-23 14:40:54	2020-04-23	9	[{"id_menu":6,"count":1}]	19381	delivery	5	14
53531	2020-04-23 14:41:23	2020-04-23	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	21271	delivery	5	36
53532	2020-04-23 14:57:25	2020-04-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11898	pick-up	0	18
53533	2020-04-23 15:04:40	2020-04-23	9	[{"id_menu":6,"count":1}]	21248	delivery	5	14
53534	2020-04-23 15:06:07	2020-04-23	17	[{"id_menu":4,"count":1}]	1041	pick-up	0	17
53535	2020-04-23 15:06:57	2020-04-23	9	[{"id_menu":7,"count":1}]	3510	delivery	5	14
53536	2020-04-23 15:07:55	2020-04-23	9	[{"id_menu":6,"count":1}]	21268	delivery	5	14
53537	2020-04-23 15:08:15	2020-04-23	12	[{"id_menu":3,"count":1}]	16251	delivery	5	17
53538	2020-04-23 15:08:16	2020-04-23	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12935	delivery	5	39
53539	2020-04-23 15:12:03	2020-04-23	9	[{"id_menu":6,"count":1}]	21235	delivery	5	14
53540	2020-04-23 15:14:00	2020-04-23	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	20138	delivery	5	31
53541	2020-04-23 15:16:23	2020-04-23	17	[{"id_menu":4,"count":1}]	21214	delivery	5	22
53542	2020-04-23 15:16:43	2020-04-23	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	12167	delivery	5	26
53543	2020-04-23 15:19:00	2020-04-23	14	[{"id_menu":2,"count":1}]	15200	pick-up	0	14
53544	2020-04-23 15:27:15	2020-04-23	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12841	delivery	5	22
53545	2020-04-23 15:28:38	2020-04-23	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21299	delivery	5	35
53546	2020-04-23 15:31:06	2020-04-23	14	[{"id_menu":2,"count":1}]	14710	pick-up	0	14
53547	2020-04-23 15:34:17	2020-04-23	12	[{"id_menu":3,"count":1}]	8181	delivery	5	17
53548	2020-04-23 15:34:23	2020-04-23	14	[{"id_menu":2,"count":1}]	19717	pick-up	0	14
53549	2020-04-23 15:36:43	2020-04-23	9	[{"id_menu":6,"count":1}]	2604	delivery	5	14
53550	2020-04-23 15:43:38	2020-04-23	9	[{"id_menu":6,"count":3}]	21246	delivery	5	14
53551	2020-04-23 15:43:52	2020-04-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	21252	delivery	5	26
53552	2020-04-23 15:45:50	2020-04-23	9	[{"id_menu":6,"count":1}]	15977	delivery	5	14
53553	2020-04-23 15:46:05	2020-04-23	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7204	delivery	5	37
53554	2020-04-23 15:50:13	2020-04-23	9	[{"id_menu":6,"count":1}]	849	delivery	5	14
53555	2020-04-23 15:57:39	2020-04-23	9	[{"id_menu":6,"count":1}]	1667	pick-up	0	9
53556	2020-04-23 16:12:25	2020-04-23	8	[{"id_menu":5,"count":1}]	18589	pick-up	0	8
53557	2020-04-23 16:12:47	2020-04-23	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	21297	delivery	5	27
53558	2020-04-23 16:15:03	2020-04-23	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":3}]	14817	delivery	5	22
53559	2020-04-23 16:26:56	2020-04-23	8	[{"id_menu":5,"count":1}]	20729	delivery	5	13
53560	2020-04-23 16:27:41	2020-04-23	17	[{"id_menu":4,"count":1}]	8581	delivery	5	22
53561	2020-04-23 16:28:55	2020-04-23	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	8747	pick-up	0	29
53562	2020-04-23 16:29:14	2020-04-23	17	[{"id_menu":4,"count":1}]	63	pick-up	0	17
53563	2020-04-23 16:31:34	2020-04-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16342	delivery	5	22
53564	2020-04-23 16:43:35	2020-04-23	12	[{"id_menu":3,"count":1}]	7415	pick-up	0	12
53565	2020-04-23 16:52:41	2020-04-23	9	[{"id_menu":6,"count":1}]	16113	pick-up	0	9
53566	2020-04-23 16:58:48	2020-04-23	9	[{"id_menu":6,"count":1}]	21321	delivery	5	14
53567	2020-04-23 17:02:28	2020-04-23	12	[{"id_menu":3,"count":1}]	21338	delivery	5	17
53568	2020-04-23 17:04:52	2020-04-23	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21293	delivery	5	22
53569	2020-04-23 17:07:23	2020-04-23	9	[{"id_menu":6,"count":1}]	6834	delivery	5	14
53570	2020-04-23 17:10:03	2020-04-23	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	15184	delivery	5	25
53571	2020-04-23 17:10:36	2020-04-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15639	delivery	5	23
53572	2020-04-23 17:11:19	2020-04-23	8	[{"id_menu":5,"count":1}]	172	pick-up	0	8
53573	2020-04-23 17:16:22	2020-04-23	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19741	delivery	5	51
53574	2020-04-23 17:19:23	2020-04-23	17	[{"id_menu":4,"count":1}]	21273	pick-up	0	17
53575	2020-04-23 17:29:47	2020-04-23	17	[{"id_menu":4,"count":1}]	15635	delivery	5	22
53576	2020-04-23 17:32:10	2020-04-23	9	[{"id_menu":7,"count":1}]	21276	delivery	5	14
53577	2020-04-23 17:38:13	2020-04-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	5276	delivery	5	36
53578	2020-04-23 17:51:51	2020-04-23	8	[{"id_menu":5,"count":1}]	17031	delivery	5	13
53579	2020-04-23 17:55:09	2020-04-23	17	[{"id_menu":4,"count":1}]	21244	pick-up	0	17
53580	2020-04-23 17:56:57	2020-04-23	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	17578	delivery	5	30
53581	2020-04-23 17:59:06	2020-04-23	14	[{"id_menu":2,"count":1}]	2383	delivery	5	19
53582	2020-04-23 18:06:49	2020-04-23	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	21230	delivery	5	31
53583	2020-04-23 18:07:14	2020-04-23	9	[{"id_menu":7,"count":1}]	19953	delivery	5	14
53584	2020-04-23 18:08:50	2020-04-23	17	[{"id_menu":4,"count":1}]	21327	pick-up	0	17
53585	2020-04-23 18:08:58	2020-04-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	16622	delivery	5	22
53587	2020-04-23 18:17:21	2020-04-23	14	[{"id_menu":2,"count":2}]	27	pick-up	0	14
53588	2020-04-23 18:17:25	2020-04-23	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":3}]	15280	delivery	5	26
53589	2020-04-23 18:17:52	2020-04-23	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	4346	delivery	5	31
53590	2020-04-23 18:18:37	2020-04-23	9	[{"id_menu":6,"count":1}]	21282	delivery	5	14
53591	2020-04-23 18:20:05	2020-04-23	9	[{"id_menu":6,"count":1}]	21250	delivery	5	14
53592	2020-04-23 18:21:48	2020-04-23	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21245	delivery	5	46
53593	2020-04-23 18:39:49	2020-04-23	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	17085	delivery	5	26
53594	2020-04-23 18:40:35	2020-04-23	12	[{"id_menu":1,"count":1}]	7780	delivery	5	17
53595	2020-04-23 18:43:05	2020-04-23	9	[{"id_menu":7,"count":1}]	21304	pick-up	0	9
53596	2020-04-23 18:43:08	2020-04-23	9	[{"id_menu":7,"count":1}]	21211	delivery	5	14
53597	2020-04-23 18:43:27	2020-04-23	9	[{"id_menu":6,"count":1}]	7328	pick-up	0	9
53598	2020-04-23 18:46:02	2020-04-23	12	[{"id_menu":3,"count":1}]	21322	delivery	5	17
53599	2020-04-23 18:47:30	2020-04-23	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	21247	delivery	5	26
53600	2020-04-23 18:49:34	2020-04-23	9	[{"id_menu":6,"count":1}]	5527	delivery	5	14
53601	2020-04-23 18:51:08	2020-04-23	17	[{"id_menu":4,"count":1}]	15991	pick-up	0	17
53602	2020-04-23 18:54:04	2020-04-23	14	[{"id_menu":2,"count":1}]	153	pick-up	0	14
53603	2020-04-23 19:00:00	2020-04-23	9	[{"id_menu":6,"count":1}]	8423	delivery	5	14
53604	2020-04-23 19:08:19	2020-04-23	17	[{"id_menu":4,"count":1}]	2618	delivery	5	22
53605	2020-04-23 19:10:16	2020-04-23	12	[{"id_menu":3,"count":1}]	21263	pick-up	0	12
53606	2020-04-23 19:17:06	2020-04-23	12	[{"id_menu":1,"count":1}]	21305	delivery	5	17
53607	2020-04-23 19:17:43	2020-04-23	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	9845	delivery	5	40
53608	2020-04-23 19:21:18	2020-04-23	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	10669	delivery	5	48
53609	2020-04-23 19:22:27	2020-04-23	8	[{"id_menu":5,"count":1}]	12929	pick-up	0	8
53610	2020-04-23 19:24:57	2020-04-23	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	19978	delivery	5	34
53611	2020-04-23 19:33:51	2020-04-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8212	delivery	5	22
53612	2020-04-23 19:38:27	2020-04-23	12	[{"id_menu":3,"count":1}]	21237	delivery	5	17
53613	2020-04-23 19:47:14	2020-04-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	21300	delivery	5	28
53614	2020-04-23 19:49:20	2020-04-23	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11481	delivery	5	45
53615	2020-04-23 19:49:37	2020-04-23	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	4110	delivery	5	37
53616	2020-04-23 19:52:42	2020-04-23	14	[{"id_menu":2,"count":1}]	21269	delivery	5	19
53617	2020-04-23 19:55:49	2020-04-23	12	[{"id_menu":3,"count":1}]	10106	pick-up	0	12
53618	2020-04-23 20:02:13	2020-04-23	9	[{"id_menu":6,"count":1}]	6048	pick-up	0	9
53619	2020-04-23 20:02:38	2020-04-23	9	[{"id_menu":6,"count":1}]	5004	delivery	5	14
53620	2020-04-23 20:10:25	2020-04-23	12	[{"id_menu":1,"count":1}]	16071	delivery	5	17
53621	2020-04-23 20:17:57	2020-04-23	12	[{"id_menu":3,"count":1}]	16839	delivery	5	17
53622	2020-04-23 20:18:00	2020-04-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3389	pick-up	0	26
53623	2020-04-23 20:24:03	2020-04-23	14	[{"id_menu":2,"count":1}]	2981	pick-up	0	14
53624	2020-04-23 20:25:27	2020-04-23	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	12420	delivery	5	26
53625	2020-04-23 20:29:23	2020-04-23	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	3181	delivery	5	43
53626	2020-04-23 20:31:02	2020-04-23	9	[{"id_menu":6,"count":1}]	1174	delivery	5	14
53627	2020-04-23 20:33:35	2020-04-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	21283	delivery	5	28
53628	2020-04-23 20:35:25	2020-04-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	12330	delivery	5	26
53629	2020-04-23 20:41:29	2020-04-23	9	[{"id_menu":6,"count":1}]	18013	delivery	5	14
53630	2020-04-23 20:47:06	2020-04-23	12	[{"id_menu":3,"count":1}]	3227	delivery	5	17
53631	2020-04-23 20:55:45	2020-04-23	8	[{"id_menu":5,"count":1}]	21219	delivery	5	13
53632	2020-04-23 20:56:47	2020-04-23	9	[{"id_menu":7,"count":1}]	21257	delivery	5	14
53633	2020-04-23 20:57:34	2020-04-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7572	pick-up	0	26
53634	2020-04-23 21:07:22	2020-04-23	9	[{"id_menu":6,"count":1}]	21017	delivery	5	14
53635	2020-04-23 21:12:08	2020-04-23	23	[{"id_menu":2,"count":3},{"id_menu":6,"count":1}]	11962	delivery	5	28
53636	2020-04-23 21:14:38	2020-04-23	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	13414	delivery	5	25
53637	2020-04-23 21:18:30	2020-04-23	12	[{"id_menu":3,"count":1}]	21311	pick-up	0	12
53638	2020-04-23 21:18:38	2020-04-23	17	[{"id_menu":4,"count":1}]	1528	pick-up	0	17
53639	2020-04-23 21:27:55	2020-04-23	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	5406	delivery	5	26
53640	2020-04-23 21:28:32	2020-04-23	9	[{"id_menu":7,"count":1}]	11314	pick-up	0	9
53641	2020-04-23 21:29:53	2020-04-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7571	pick-up	0	23
53642	2020-04-23 21:35:18	2020-04-23	14	[{"id_menu":2,"count":1}]	4453	pick-up	0	14
53643	2020-04-23 21:35:34	2020-04-23	9	[{"id_menu":7,"count":1}]	21240	delivery	5	14
53644	2020-04-23 21:36:07	2020-04-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	3837	delivery	5	22
53645	2020-04-23 21:54:02	2020-04-23	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14024	delivery	5	34
53646	2020-04-23 22:00:21	2020-04-23	12	[{"id_menu":1,"count":1}]	18374	pick-up	0	12
53647	2020-04-23 22:02:09	2020-04-23	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21332	delivery	5	36
53648	2020-04-23 22:02:43	2020-04-23	8	[{"id_menu":5,"count":1}]	10465	delivery	5	13
53649	2020-04-23 22:05:41	2020-04-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4292	pick-up	0	17
53650	2020-04-23 22:08:30	2020-04-23	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11100	delivery	5	36
53651	2020-04-23 22:09:56	2020-04-23	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21261	delivery	5	54
53652	2020-04-23 22:11:43	2020-04-23	9	[{"id_menu":6,"count":1}]	21320	delivery	5	14
53653	2020-04-23 22:13:55	2020-04-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	21170	delivery	5	36
53654	2020-04-23 22:16:11	2020-04-23	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	17489	delivery	5	35
53655	2020-04-23 22:16:28	2020-04-23	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3042	delivery	5	22
53656	2020-04-23 22:20:09	2020-04-23	9	[{"id_menu":7,"count":1}]	7146	delivery	5	14
53657	2020-04-23 22:21:20	2020-04-23	9	[{"id_menu":6,"count":1}]	374	delivery	5	14
53658	2020-04-23 22:22:52	2020-04-23	9	[{"id_menu":7,"count":1}]	774	delivery	5	14
53659	2020-04-23 22:23:21	2020-04-23	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	5354	pick-up	0	43
53660	2020-04-23 22:24:13	2020-04-23	9	[{"id_menu":6,"count":1}]	4794	delivery	5	14
53661	2020-04-23 22:25:56	2020-04-23	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1900	pick-up	0	26
53662	2020-04-23 22:28:01	2020-04-23	17	[{"id_menu":4,"count":1}]	9564	delivery	5	22
53663	2020-04-23 22:28:20	2020-04-23	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7756	delivery	5	22
53664	2020-04-23 22:28:30	2020-04-23	17	[{"id_menu":4,"count":1}]	2731	pick-up	0	17
53665	2020-04-23 22:32:20	2020-04-23	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	21224	delivery	5	34
53666	2020-04-23 22:34:56	2020-04-23	12	[{"id_menu":3,"count":1}]	376	pick-up	0	12
53667	2020-04-23 22:39:08	2020-04-23	12	[{"id_menu":1,"count":1}]	21215	delivery	5	17
53668	2020-04-23 22:44:27	2020-04-23	8	[{"id_menu":5,"count":1}]	7428	delivery	5	13
53669	2020-04-23 22:45:45	2020-04-23	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	21239	pick-up	0	24
53670	2020-04-23 22:46:08	2020-04-23	17	[{"id_menu":4,"count":2}]	3025	pick-up	0	17
53671	2020-04-23 22:46:52	2020-04-23	12	[{"id_menu":1,"count":1}]	21266	delivery	5	17
53672	2020-04-23 22:48:06	2020-04-23	9	[{"id_menu":7,"count":1}]	12273	delivery	5	14
53673	2020-04-23 22:53:12	2020-04-23	9	[{"id_menu":7,"count":1}]	8355	delivery	5	14
53674	2020-04-23 22:54:30	2020-04-23	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6239	delivery	5	43
53675	2020-04-23 23:02:14	2020-04-23	17	[{"id_menu":4,"count":1}]	5520	pick-up	0	17
53676	2020-04-23 23:08:15	2020-04-23	12	[{"id_menu":3,"count":1}]	21323	pick-up	0	12
53677	2020-04-23 23:11:40	2020-04-23	9	[{"id_menu":7,"count":1}]	17913	delivery	5	14
53678	2020-04-23 23:15:26	2020-04-23	12	[{"id_menu":1,"count":1}]	6555	pick-up	0	12
53679	2020-04-23 23:17:37	2020-04-23	17	[{"id_menu":4,"count":2}]	7024	delivery	5	22
53680	2020-04-23 23:20:50	2020-04-23	17	[{"id_menu":4,"count":1}]	21316	delivery	5	22
53681	2020-04-23 23:23:07	2020-04-23	12	[{"id_menu":1,"count":1}]	21251	delivery	5	17
53682	2020-04-23 23:23:10	2020-04-23	9	[{"id_menu":7,"count":1}]	12248	pick-up	0	9
53683	2020-04-23 23:23:20	2020-04-23	14	[{"id_menu":2,"count":1}]	18479	delivery	5	19
53684	2020-04-23 23:24:22	2020-04-23	9	[{"id_menu":6,"count":1}]	2023	pick-up	0	9
53685	2020-04-23 23:26:03	2020-04-23	8	[{"id_menu":5,"count":1}]	16440	delivery	5	13
53686	2020-04-23 23:35:00	2020-04-23	17	[{"id_menu":4,"count":1}]	21314	delivery	5	22
53687	2020-04-23 23:37:11	2020-04-23	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15437	delivery	5	35
53688	2020-04-23 23:37:23	2020-04-23	14	[{"id_menu":2,"count":1}]	7182	pick-up	0	14
53689	2020-04-23 23:46:37	2020-04-23	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	17869	delivery	5	26
53690	2020-04-23 23:49:19	2020-04-23	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5574	delivery	5	31
53691	2020-04-23 23:55:27	2020-04-23	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1810	delivery	5	34
53692	2020-04-23 23:58:11	2020-04-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	21290	delivery	5	31
53693	2020-04-24 00:03:17	2020-04-24	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8683	delivery	5	40
53694	2020-04-24 00:06:13	2020-04-24	14	[{"id_menu":2,"count":1}]	429	pick-up	0	14
53695	2020-04-24 00:09:09	2020-04-24	9	[{"id_menu":6,"count":1}]	10709	delivery	5	14
53696	2020-04-24 00:14:13	2020-04-24	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	9960	pick-up	0	30
53697	2020-04-24 00:16:47	2020-04-24	12	[{"id_menu":1,"count":1}]	7871	delivery	5	17
53698	2020-04-24 00:20:28	2020-04-24	14	[{"id_menu":2,"count":2}]	2656	pick-up	0	14
53699	2020-04-24 00:20:47	2020-04-24	14	[{"id_menu":2,"count":1}]	3537	delivery	5	19
53700	2020-04-24 00:21:08	2020-04-24	14	[{"id_menu":2,"count":1}]	3180	pick-up	0	14
53701	2020-04-24 00:21:28	2020-04-24	9	[{"id_menu":7,"count":1}]	21496	delivery	5	14
53702	2020-04-24 00:25:32	2020-04-24	9	[{"id_menu":6,"count":1}]	9141	delivery	5	14
53703	2020-04-24 00:28:01	2020-04-24	8	[{"id_menu":5,"count":1}]	21453	delivery	5	13
53704	2020-04-24 00:42:12	2020-04-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	21508	pick-up	0	23
53705	2020-04-24 00:56:04	2020-04-24	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21353	delivery	5	49
53706	2020-04-24 01:10:00	2020-04-24	12	[{"id_menu":1,"count":1}]	16915	delivery	5	17
53707	2020-04-24 01:15:14	2020-04-24	14	[{"id_menu":2,"count":1}]	12882	delivery	5	19
53708	2020-04-24 01:17:17	2020-04-24	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	21410	delivery	5	27
53709	2020-04-24 01:27:22	2020-04-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10896	delivery	5	22
53710	2020-04-24 01:34:10	2020-04-24	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21448	pick-up	0	34
53711	2020-04-24 01:36:24	2020-04-24	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	12610	delivery	5	45
53712	2020-04-24 01:37:48	2020-04-24	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	21355	delivery	5	26
53713	2020-04-24 01:40:17	2020-04-24	17	[{"id_menu":4,"count":1}]	21490	delivery	5	22
53714	2020-04-24 01:46:16	2020-04-24	8	[{"id_menu":5,"count":2}]	16423	delivery	5	13
53715	2020-04-24 01:46:25	2020-04-24	9	[{"id_menu":7,"count":1}]	3567	delivery	5	14
53716	2020-04-24 01:52:08	2020-04-24	9	[{"id_menu":6,"count":1}]	21523	delivery	5	14
53717	2020-04-24 02:02:37	2020-04-24	9	[{"id_menu":6,"count":1}]	21349	delivery	5	14
53718	2020-04-24 02:03:22	2020-04-24	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	21457	delivery	5	22
53719	2020-04-24 02:03:37	2020-04-24	12	[{"id_menu":1,"count":1}]	14506	delivery	5	17
53720	2020-04-24 02:04:19	2020-04-24	17	[{"id_menu":4,"count":1}]	16238	delivery	5	22
53721	2020-04-24 02:06:54	2020-04-24	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21493	delivery	5	45
53722	2020-04-24 02:07:33	2020-04-24	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	21374	delivery	5	31
53723	2020-04-24 02:10:48	2020-04-24	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	21398	delivery	5	26
53724	2020-04-24 02:14:12	2020-04-24	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	21367	delivery	5	39
53725	2020-04-24 02:14:13	2020-04-24	17	[{"id_menu":4,"count":1}]	18737	delivery	5	22
53726	2020-04-24 02:17:55	2020-04-24	17	[{"id_menu":4,"count":1}]	21375	delivery	5	22
53727	2020-04-24 02:22:15	2020-04-24	14	[{"id_menu":2,"count":1}]	10796	delivery	5	19
53728	2020-04-24 02:25:52	2020-04-24	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	21449	delivery	5	38
53729	2020-04-24 02:31:42	2020-04-24	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5433	delivery	5	51
53730	2020-04-24 02:31:58	2020-04-24	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	8928	pick-up	0	26
53731	2020-04-24 02:34:51	2020-04-24	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1317	pick-up	0	40
53732	2020-04-24 02:35:03	2020-04-24	8	[{"id_menu":5,"count":1}]	3963	delivery	5	13
53733	2020-04-24 02:41:03	2020-04-24	12	[{"id_menu":1,"count":1}]	13634	delivery	5	17
53734	2020-04-24 02:42:29	2020-04-24	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	3560	pick-up	0	31
53735	2020-04-24 02:58:21	2020-04-24	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	21437	delivery	5	27
53736	2020-04-24 02:59:49	2020-04-24	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21483	pick-up	0	31
53737	2020-04-24 03:06:06	2020-04-24	9	[{"id_menu":6,"count":1}]	21319	delivery	5	14
53738	2020-04-24 03:06:46	2020-04-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	21392	delivery	5	28
53739	2020-04-24 03:24:20	2020-04-24	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	21469	delivery	5	34
53740	2020-04-24 03:31:21	2020-04-24	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	13940	delivery	5	26
53741	2020-04-24 03:36:05	2020-04-24	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17657	delivery	5	39
53742	2020-04-24 03:46:58	2020-04-24	8	[{"id_menu":5,"count":1}]	21409	delivery	5	13
53743	2020-04-24 03:50:10	2020-04-24	12	[{"id_menu":3,"count":1}]	21479	delivery	5	17
53744	2020-04-24 03:51:06	2020-04-24	12	[{"id_menu":3,"count":1}]	9562	delivery	5	17
53745	2020-04-24 03:53:38	2020-04-24	9	[{"id_menu":7,"count":1}]	21463	delivery	5	14
53746	2020-04-24 03:53:50	2020-04-24	9	[{"id_menu":6,"count":1}]	16308	pick-up	0	9
53747	2020-04-24 03:55:11	2020-04-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	21433	delivery	5	28
53748	2020-04-24 03:58:31	2020-04-24	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	12476	delivery	5	27
53749	2020-04-24 04:02:32	2020-04-24	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20573	delivery	5	34
53750	2020-04-24 04:03:29	2020-04-24	9	[{"id_menu":7,"count":1}]	21414	delivery	5	14
53751	2020-04-24 04:10:36	2020-04-24	14	[{"id_menu":2,"count":1}]	21389	pick-up	0	14
53752	2020-04-24 04:12:44	2020-04-24	9	[{"id_menu":6,"count":1}]	21530	delivery	5	14
53753	2020-04-24 04:19:39	2020-04-24	17	[{"id_menu":4,"count":1}]	21415	delivery	5	22
53754	2020-04-24 04:22:09	2020-04-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13020	delivery	5	22
53755	2020-04-24 04:47:42	2020-04-24	9	[{"id_menu":7,"count":1}]	9169	delivery	5	14
53756	2020-04-24 04:48:12	2020-04-24	8	[{"id_menu":5,"count":1}]	16610	delivery	5	13
53757	2020-04-24 04:48:42	2020-04-24	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12070	pick-up	0	35
53758	2020-04-24 04:53:00	2020-04-24	12	[{"id_menu":3,"count":1}]	11624	delivery	5	17
53759	2020-04-24 04:53:34	2020-04-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	21366	delivery	5	28
53760	2020-04-24 04:54:46	2020-04-24	9	[{"id_menu":7,"count":1}]	21489	delivery	5	14
53761	2020-04-24 05:14:26	2020-04-24	9	[{"id_menu":6,"count":1}]	21371	delivery	5	14
53762	2020-04-24 05:15:17	2020-04-24	8	[{"id_menu":5,"count":1}]	11378	delivery	5	13
53763	2020-04-24 05:20:53	2020-04-24	14	[{"id_menu":2,"count":1}]	21350	pick-up	0	14
53764	2020-04-24 05:29:41	2020-04-24	12	[{"id_menu":3,"count":1}]	3730	pick-up	0	12
53765	2020-04-24 05:45:38	2020-04-24	9	[{"id_menu":6,"count":1}]	10638	delivery	5	14
53766	2020-04-24 05:45:42	2020-04-24	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	1163	delivery	5	43
53767	2020-04-24 05:47:00	2020-04-24	8	[{"id_menu":5,"count":1}]	10488	delivery	5	13
53768	2020-04-24 05:49:58	2020-04-24	9	[{"id_menu":7,"count":1}]	15681	delivery	5	14
53769	2020-04-24 05:51:49	2020-04-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":3}]	17198	delivery	5	28
53770	2020-04-24 05:52:45	2020-04-24	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	21510	pick-up	0	20
53771	2020-04-24 06:12:31	2020-04-24	9	[{"id_menu":7,"count":1}]	21502	delivery	5	14
53772	2020-04-24 06:15:32	2020-04-24	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	17131	delivery	5	29
53773	2020-04-24 06:20:53	2020-04-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	21462	delivery	5	31
53774	2020-04-24 06:22:34	2020-04-24	8	[{"id_menu":5,"count":1}]	4141	delivery	5	13
53775	2020-04-24 06:24:41	2020-04-24	14	[{"id_menu":2,"count":1}]	5094	pick-up	0	14
53776	2020-04-24 06:30:48	2020-04-24	8	[{"id_menu":5,"count":1}]	21359	delivery	5	13
53777	2020-04-24 06:32:02	2020-04-24	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	21394	delivery	5	26
53778	2020-04-24 06:36:57	2020-04-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	21399	delivery	5	31
53779	2020-04-24 06:38:21	2020-04-24	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	21445	delivery	5	39
53780	2020-04-24 06:38:46	2020-04-24	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	21430	delivery	5	40
53781	2020-04-24 06:40:30	2020-04-24	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	21503	pick-up	0	29
53782	2020-04-24 06:44:47	2020-04-24	12	[{"id_menu":3,"count":1}]	12240	delivery	5	17
53783	2020-04-24 06:50:52	2020-04-24	8	[{"id_menu":5,"count":2}]	1898	pick-up	0	8
53784	2020-04-24 06:52:15	2020-04-24	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	21470	delivery	5	26
53785	2020-04-24 06:52:28	2020-04-24	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	5234	pick-up	0	21
53786	2020-04-24 06:55:14	2020-04-24	12	[{"id_menu":3,"count":1}]	19218	pick-up	0	12
53787	2020-04-24 07:00:32	2020-04-24	17	[{"id_menu":4,"count":1}]	21455	pick-up	0	17
53788	2020-04-24 07:12:24	2020-04-24	9	[{"id_menu":7,"count":1}]	21484	delivery	5	14
53789	2020-04-24 07:22:19	2020-04-24	12	[{"id_menu":3,"count":1}]	519	pick-up	0	12
53790	2020-04-24 07:22:31	2020-04-24	14	[{"id_menu":2,"count":1}]	21497	delivery	5	19
53791	2020-04-24 07:25:11	2020-04-24	9	[{"id_menu":7,"count":1}]	15982	delivery	5	14
53792	2020-04-24 07:34:31	2020-04-24	9	[{"id_menu":6,"count":1}]	11187	delivery	5	14
53793	2020-04-24 07:53:03	2020-04-24	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	9450	delivery	5	48
53794	2020-04-24 07:54:17	2020-04-24	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	21405	delivery	5	56
53795	2020-04-24 07:55:59	2020-04-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	15777	delivery	5	23
53796	2020-04-24 08:00:34	2020-04-24	17	[{"id_menu":4,"count":1}]	13370	pick-up	0	17
53797	2020-04-24 08:08:17	2020-04-24	9	[{"id_menu":6,"count":1}]	20289	delivery	5	14
53798	2020-04-24 08:11:51	2020-04-24	9	[{"id_menu":7,"count":1}]	1836	pick-up	0	9
53799	2020-04-24 08:15:45	2020-04-24	9	[{"id_menu":7,"count":1}]	21519	pick-up	0	9
53800	2020-04-24 08:23:28	2020-04-24	9	[{"id_menu":6,"count":1}]	15241	delivery	5	14
53801	2020-04-24 08:33:11	2020-04-24	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	169	pick-up	0	35
53802	2020-04-24 08:34:08	2020-04-24	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	256	pick-up	0	47
53803	2020-04-24 08:36:41	2020-04-24	12	[{"id_menu":1,"count":1}]	2156	delivery	5	17
53804	2020-04-24 08:41:38	2020-04-24	14	[{"id_menu":2,"count":1}]	8420	pick-up	0	14
53805	2020-04-24 08:42:19	2020-04-24	8	[{"id_menu":5,"count":1}]	1106	pick-up	0	8
53806	2020-04-24 08:43:11	2020-04-24	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	21404	delivery	5	36
53807	2020-04-24 08:43:43	2020-04-24	9	[{"id_menu":6,"count":1}]	21377	delivery	5	14
53808	2020-04-24 08:43:58	2020-04-24	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	21395	delivery	5	27
53809	2020-04-24 08:45:10	2020-04-24	12	[{"id_menu":1,"count":1}]	21441	delivery	5	17
53810	2020-04-24 08:51:28	2020-04-24	17	[{"id_menu":4,"count":1}]	6901	pick-up	0	17
53811	2020-04-24 09:03:31	2020-04-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	801	delivery	5	22
53812	2020-04-24 09:03:53	2020-04-24	12	[{"id_menu":1,"count":1}]	3838	delivery	5	17
53813	2020-04-24 09:06:14	2020-04-24	14	[{"id_menu":2,"count":1}]	20668	pick-up	0	14
53814	2020-04-24 09:09:11	2020-04-24	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	3871	pick-up	0	38
53815	2020-04-24 09:09:35	2020-04-24	8	[{"id_menu":5,"count":1}]	21521	delivery	5	13
53816	2020-04-24 09:14:58	2020-04-24	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21473	delivery	5	22
53817	2020-04-24 09:20:31	2020-04-24	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21417	delivery	5	53
53818	2020-04-24 09:24:56	2020-04-24	9	[{"id_menu":7,"count":1}]	21050	delivery	5	14
53819	2020-04-24 09:26:40	2020-04-24	14	[{"id_menu":2,"count":2}]	7200	pick-up	0	14
53820	2020-04-24 09:46:47	2020-04-24	9	[{"id_menu":6,"count":1}]	21356	delivery	5	14
53821	2020-04-24 09:52:11	2020-04-24	17	[{"id_menu":4,"count":1}]	21443	delivery	5	22
53822	2020-04-24 09:55:13	2020-04-24	9	[{"id_menu":7,"count":1}]	3399	pick-up	0	9
53823	2020-04-24 09:59:23	2020-04-24	9	[{"id_menu":7,"count":2}]	1415	pick-up	0	9
53824	2020-04-24 10:00:13	2020-04-24	8	[{"id_menu":5,"count":1}]	21388	delivery	5	13
53825	2020-04-24 10:02:24	2020-04-24	12	[{"id_menu":1,"count":1}]	21347	delivery	5	17
53826	2020-04-24 10:04:23	2020-04-24	8	[{"id_menu":5,"count":1}]	3475	delivery	5	13
53827	2020-04-24 10:13:00	2020-04-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	21512	delivery	5	28
53828	2020-04-24 10:14:12	2020-04-24	9	[{"id_menu":7,"count":2}]	21361	delivery	5	14
53829	2020-04-24 10:19:25	2020-04-24	9	[{"id_menu":6,"count":1}]	21474	delivery	5	14
53830	2020-04-24 10:20:27	2020-04-24	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	16569	delivery	5	42
53831	2020-04-24 10:25:00	2020-04-24	12	[{"id_menu":3,"count":1}]	21362	delivery	5	17
53832	2020-04-24 10:31:39	2020-04-24	8	[{"id_menu":5,"count":1}]	4874	pick-up	0	8
53833	2020-04-24 10:31:54	2020-04-24	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	21514	delivery	5	26
53834	2020-04-24 10:34:53	2020-04-24	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	21500	delivery	5	40
53835	2020-04-24 10:41:00	2020-04-24	12	[{"id_menu":3,"count":1}]	21420	delivery	5	17
53836	2020-04-24 10:46:32	2020-04-24	17	[{"id_menu":4,"count":1}]	4995	delivery	5	22
53837	2020-04-24 10:48:23	2020-04-24	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	9949	delivery	5	46
53838	2020-04-24 10:48:36	2020-04-24	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	21464	delivery	5	43
53839	2020-04-24 10:54:26	2020-04-24	17	[{"id_menu":4,"count":1}]	6668	delivery	5	22
53840	2020-04-24 10:54:50	2020-04-24	14	[{"id_menu":2,"count":1}]	11973	delivery	5	19
53841	2020-04-24 10:55:32	2020-04-24	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21387	delivery	5	34
53842	2020-04-24 10:57:04	2020-04-24	17	[{"id_menu":4,"count":2}]	21522	delivery	5	22
53843	2020-04-24 10:58:16	2020-04-24	9	[{"id_menu":7,"count":1}]	2928	pick-up	0	9
53844	2020-04-24 11:07:03	2020-04-24	14	[{"id_menu":2,"count":1}]	13146	delivery	5	19
53845	2020-04-24 11:07:15	2020-04-24	8	[{"id_menu":5,"count":1}]	16239	delivery	5	13
53846	2020-04-24 11:08:54	2020-04-24	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	21518	delivery	5	40
53847	2020-04-24 11:11:58	2020-04-24	12	[{"id_menu":1,"count":1}]	6176	pick-up	0	12
53848	2020-04-24 11:12:34	2020-04-24	14	[{"id_menu":2,"count":1}]	1427	pick-up	0	14
53849	2020-04-24 11:17:21	2020-04-24	12	[{"id_menu":1,"count":1}]	21478	delivery	5	17
53850	2020-04-24 11:18:16	2020-04-24	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	21373	delivery	5	35
53851	2020-04-24 11:18:19	2020-04-24	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	17569	delivery	5	26
53852	2020-04-24 11:20:05	2020-04-24	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	18770	pick-up	0	38
53853	2020-04-24 11:20:29	2020-04-24	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	21513	delivery	5	25
53854	2020-04-24 11:22:56	2020-04-24	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4319	pick-up	0	32
53855	2020-04-24 11:30:25	2020-04-24	9	[{"id_menu":6,"count":1}]	11812	delivery	5	14
53856	2020-04-24 11:32:05	2020-04-24	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	122	delivery	5	29
53857	2020-04-24 11:32:18	2020-04-24	12	[{"id_menu":1,"count":1}]	15800	delivery	5	17
53858	2020-04-24 11:33:50	2020-04-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1979	pick-up	0	17
53859	2020-04-24 11:36:59	2020-04-24	17	[{"id_menu":4,"count":1}]	15013	delivery	5	22
53860	2020-04-24 11:39:41	2020-04-24	9	[{"id_menu":6,"count":1}]	17538	delivery	5	14
53861	2020-04-24 11:43:03	2020-04-24	12	[{"id_menu":1,"count":1}]	1351	pick-up	0	12
53862	2020-04-24 11:49:36	2020-04-24	9	[{"id_menu":7,"count":1}]	5107	delivery	5	14
53863	2020-04-24 11:53:50	2020-04-24	12	[{"id_menu":1,"count":1}]	10116	delivery	5	17
53864	2020-04-24 11:55:03	2020-04-24	9	[{"id_menu":7,"count":1}]	21408	delivery	5	14
53865	2020-04-24 11:58:08	2020-04-24	8	[{"id_menu":5,"count":1}]	10829	pick-up	0	8
53866	2020-04-24 11:58:11	2020-04-24	9	[{"id_menu":6,"count":1}]	21488	delivery	5	14
53867	2020-04-24 11:59:25	2020-04-24	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	21364	delivery	5	26
53868	2020-04-24 12:00:38	2020-04-24	9	[{"id_menu":7,"count":1}]	7588	delivery	5	14
53869	2020-04-24 12:05:35	2020-04-24	9	[{"id_menu":7,"count":1}]	4183	delivery	5	14
53870	2020-04-24 12:07:02	2020-04-24	14	[{"id_menu":2,"count":1}]	10309	delivery	5	19
53871	2020-04-24 12:08:50	2020-04-24	14	[{"id_menu":2,"count":1}]	3233	pick-up	0	14
53872	2020-04-24 12:08:58	2020-04-24	14	[{"id_menu":2,"count":1}]	7196	delivery	5	19
53873	2020-04-24 12:11:47	2020-04-24	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	3278	delivery	5	23
53874	2020-04-24 12:13:38	2020-04-24	8	[{"id_menu":5,"count":1}]	11189	pick-up	0	8
53875	2020-04-24 12:21:43	2020-04-24	9	[{"id_menu":6,"count":1}]	14331	delivery	5	14
53876	2020-04-24 12:24:00	2020-04-24	8	[{"id_menu":5,"count":1}]	3108	delivery	5	13
53877	2020-04-24 12:34:36	2020-04-24	12	[{"id_menu":1,"count":1}]	21480	delivery	5	17
53878	2020-04-24 12:37:34	2020-04-24	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	9194	delivery	5	34
53879	2020-04-24 12:38:44	2020-04-24	12	[{"id_menu":3,"count":1}]	21434	delivery	5	17
53880	2020-04-24 12:39:31	2020-04-24	8	[{"id_menu":5,"count":2}]	14693	delivery	5	13
53881	2020-04-24 12:39:44	2020-04-24	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	21384	delivery	5	26
53882	2020-04-24 12:44:49	2020-04-24	12	[{"id_menu":1,"count":1}]	4624	pick-up	0	12
53883	2020-04-24 12:45:06	2020-04-24	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21358	pick-up	0	17
53884	2020-04-24 12:48:56	2020-04-24	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	21511	delivery	5	40
53885	2020-04-24 12:57:57	2020-04-24	8	[{"id_menu":5,"count":1}]	16317	delivery	5	13
53886	2020-04-24 12:59:58	2020-04-24	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2474	pick-up	0	21
53887	2020-04-24 13:06:18	2020-04-24	9	[{"id_menu":6,"count":1}]	17416	delivery	5	14
53888	2020-04-24 13:08:40	2020-04-24	9	[{"id_menu":7,"count":1}]	5520	pick-up	0	9
53889	2020-04-24 13:09:43	2020-04-24	12	[{"id_menu":1,"count":1}]	18703	pick-up	0	12
53890	2020-04-24 13:14:28	2020-04-24	9	[{"id_menu":6,"count":1}]	15110	pick-up	0	9
53891	2020-04-24 13:16:35	2020-04-24	9	[{"id_menu":7,"count":1}]	8714	delivery	5	14
53892	2020-04-24 13:17:05	2020-04-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1676	delivery	5	28
53893	2020-04-24 13:20:20	2020-04-24	12	[{"id_menu":1,"count":1}]	1263	pick-up	0	12
53894	2020-04-24 13:21:02	2020-04-24	9	[{"id_menu":7,"count":1}]	21454	delivery	5	14
53895	2020-04-24 13:22:37	2020-04-24	17	[{"id_menu":4,"count":1}]	2641	pick-up	0	17
53896	2020-04-24 13:27:13	2020-04-24	12	[{"id_menu":1,"count":2}]	10923	delivery	5	17
53897	2020-04-24 13:28:04	2020-04-24	8	[{"id_menu":5,"count":2}]	21396	delivery	5	13
53898	2020-04-24 13:30:25	2020-04-24	17	[{"id_menu":4,"count":1}]	2119	delivery	5	22
53899	2020-04-24 13:35:38	2020-04-24	12	[{"id_menu":1,"count":3}]	21492	delivery	5	17
53900	2020-04-24 13:41:26	2020-04-24	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1722	pick-up	0	21
53901	2020-04-24 13:46:16	2020-04-24	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	9423	delivery	5	29
53902	2020-04-24 13:47:15	2020-04-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21527	delivery	5	23
53903	2020-04-24 13:48:52	2020-04-24	9	[{"id_menu":6,"count":1}]	21498	delivery	5	14
53904	2020-04-24 13:49:13	2020-04-24	9	[{"id_menu":7,"count":1}]	1250	pick-up	0	9
53905	2020-04-24 13:51:28	2020-04-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1804	delivery	5	31
53906	2020-04-24 13:54:23	2020-04-24	17	[{"id_menu":4,"count":1}]	21357	delivery	5	22
53907	2020-04-24 13:59:09	2020-04-24	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	7190	pick-up	0	29
53908	2020-04-24 13:59:12	2020-04-24	12	[{"id_menu":1,"count":1}]	235	delivery	5	17
53909	2020-04-24 14:01:23	2020-04-24	17	[{"id_menu":4,"count":1}]	14708	delivery	5	22
53910	2020-04-24 14:05:51	2020-04-24	8	[{"id_menu":5,"count":1}]	7022	delivery	5	13
53911	2020-04-24 14:07:46	2020-04-24	17	[{"id_menu":4,"count":1}]	18839	pick-up	0	17
53912	2020-04-24 14:09:48	2020-04-24	14	[{"id_menu":2,"count":1}]	3825	delivery	5	19
53913	2020-04-24 14:15:48	2020-04-24	14	[{"id_menu":2,"count":1}]	21487	delivery	5	19
53914	2020-04-24 14:23:12	2020-04-24	9	[{"id_menu":6,"count":1}]	16741	delivery	5	14
53915	2020-04-24 14:27:38	2020-04-24	9	[{"id_menu":7,"count":1}]	2932	pick-up	0	9
53916	2020-04-24 14:30:45	2020-04-24	8	[{"id_menu":5,"count":1}]	14290	pick-up	0	8
53917	2020-04-24 14:33:54	2020-04-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	13621	delivery	5	22
53918	2020-04-24 14:36:08	2020-04-24	9	[{"id_menu":7,"count":1}]	21411	delivery	5	14
53919	2020-04-24 14:40:47	2020-04-24	17	[{"id_menu":4,"count":1}]	16984	pick-up	0	17
53920	2020-04-24 14:41:24	2020-04-24	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	21326	delivery	5	31
53921	2020-04-24 14:43:34	2020-04-24	9	[{"id_menu":7,"count":1}]	10283	pick-up	0	9
53922	2020-04-24 15:12:16	2020-04-24	9	[{"id_menu":7,"count":1}]	21345	pick-up	0	9
53923	2020-04-24 15:13:35	2020-04-24	17	[{"id_menu":4,"count":1}]	11103	delivery	5	22
53924	2020-04-24 15:17:48	2020-04-24	12	[{"id_menu":1,"count":1}]	20338	pick-up	0	12
53925	2020-04-24 15:22:24	2020-04-24	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	13115	delivery	5	26
53926	2020-04-24 15:24:18	2020-04-24	9	[{"id_menu":6,"count":2}]	21466	delivery	5	14
53927	2020-04-24 15:25:48	2020-04-24	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	21465	delivery	5	38
53928	2020-04-24 15:35:09	2020-04-24	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6080	delivery	5	35
53929	2020-04-24 15:44:15	2020-04-24	12	[{"id_menu":3,"count":1}]	3155	pick-up	0	12
53930	2020-04-24 15:44:56	2020-04-24	12	[{"id_menu":3,"count":1}]	1176	pick-up	0	12
53931	2020-04-24 15:48:53	2020-04-24	9	[{"id_menu":6,"count":1}]	1233	pick-up	0	9
53932	2020-04-24 15:48:57	2020-04-24	12	[{"id_menu":3,"count":1}]	12290	delivery	5	17
53933	2020-04-24 15:49:30	2020-04-24	9	[{"id_menu":6,"count":2}]	3883	delivery	5	14
53934	2020-04-24 15:49:53	2020-04-24	9	[{"id_menu":6,"count":1}]	8282	pick-up	0	9
53935	2020-04-24 15:55:36	2020-04-24	14	[{"id_menu":2,"count":1}]	21461	delivery	5	19
53936	2020-04-24 15:56:33	2020-04-24	17	[{"id_menu":4,"count":1}]	17671	delivery	5	22
53937	2020-04-24 15:58:21	2020-04-24	12	[{"id_menu":1,"count":1}]	15716	delivery	5	17
53938	2020-04-24 16:00:34	2020-04-24	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	17197	pick-up	0	24
53939	2020-04-24 16:00:43	2020-04-24	14	[{"id_menu":2,"count":1}]	20711	delivery	5	19
53940	2020-04-24 16:00:49	2020-04-24	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":3}]	3481	delivery	5	34
53941	2020-04-24 16:00:58	2020-04-24	9	[{"id_menu":7,"count":1}]	887	delivery	5	14
53942	2020-04-24 16:03:33	2020-04-24	9	[{"id_menu":7,"count":1}]	13210	delivery	5	14
53943	2020-04-24 16:16:18	2020-04-24	8	[{"id_menu":5,"count":1}]	11181	delivery	5	13
53944	2020-04-24 16:20:36	2020-04-24	9	[{"id_menu":7,"count":1}]	14686	delivery	5	14
53945	2020-04-24 16:23:06	2020-04-24	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2360	delivery	5	37
53946	2020-04-24 16:24:51	2020-04-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21505	delivery	5	23
53947	2020-04-24 16:24:54	2020-04-24	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21529	delivery	5	31
53948	2020-04-24 16:27:10	2020-04-24	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	29	pick-up	0	25
53949	2020-04-24 16:36:01	2020-04-24	14	[{"id_menu":2,"count":1}]	21528	delivery	5	19
53950	2020-04-24 16:50:43	2020-04-24	8	[{"id_menu":5,"count":1}]	2404	pick-up	0	8
53951	2020-04-24 16:55:41	2020-04-24	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	11292	delivery	5	26
53952	2020-04-24 17:01:34	2020-04-24	8	[{"id_menu":5,"count":1}]	1152	pick-up	0	8
53953	2020-04-24 17:05:15	2020-04-24	14	[{"id_menu":2,"count":1}]	8397	delivery	5	19
53954	2020-04-24 17:11:44	2020-04-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21501	delivery	5	23
53955	2020-04-24 17:16:18	2020-04-24	14	[{"id_menu":2,"count":1}]	21452	delivery	5	19
53956	2020-04-24 17:20:17	2020-04-24	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	21446	delivery	5	26
53957	2020-04-24 17:28:43	2020-04-24	9	[{"id_menu":6,"count":1}]	1900	pick-up	0	9
53958	2020-04-24 17:30:50	2020-04-24	12	[{"id_menu":3,"count":1}]	19144	pick-up	0	12
53959	2020-04-24 17:31:11	2020-04-24	14	[{"id_menu":2,"count":1}]	10697	delivery	5	19
53960	2020-04-24 17:33:27	2020-04-24	9	[{"id_menu":6,"count":1}]	18947	delivery	5	14
53961	2020-04-24 17:34:12	2020-04-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	847	pick-up	0	26
53962	2020-04-24 17:36:08	2020-04-24	12	[{"id_menu":1,"count":1}]	18364	delivery	5	17
53963	2020-04-24 17:41:56	2020-04-24	9	[{"id_menu":7,"count":1}]	15028	pick-up	0	9
53964	2020-04-24 17:49:51	2020-04-24	14	[{"id_menu":2,"count":1}]	2726	pick-up	0	14
53965	2020-04-24 17:49:51	2020-04-24	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	21504	pick-up	0	20
53966	2020-04-24 17:50:43	2020-04-24	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7455	delivery	5	36
53967	2020-04-24 17:54:26	2020-04-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21499	delivery	5	23
53968	2020-04-24 17:56:16	2020-04-24	9	[{"id_menu":7,"count":1}]	20926	delivery	5	14
53969	2020-04-24 17:56:23	2020-04-24	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	11961	delivery	5	52
53970	2020-04-24 18:01:37	2020-04-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	21391	delivery	5	22
53971	2020-04-24 18:02:01	2020-04-24	8	[{"id_menu":5,"count":1}]	21170	delivery	5	13
53972	2020-04-24 18:02:38	2020-04-24	14	[{"id_menu":2,"count":1}]	21509	delivery	5	19
53973	2020-04-24 18:11:40	2020-04-24	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	21381	delivery	5	22
53974	2020-04-24 18:12:11	2020-04-24	14	[{"id_menu":2,"count":1}]	21401	delivery	5	19
53975	2020-04-24 18:29:30	2020-04-24	17	[{"id_menu":4,"count":1}]	14573	delivery	5	22
53976	2020-04-24 18:34:01	2020-04-24	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15661	delivery	5	43
53977	2020-04-24 18:38:16	2020-04-24	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11716	delivery	5	43
53978	2020-04-24 18:42:28	2020-04-24	12	[{"id_menu":3,"count":1}]	4726	pick-up	0	12
53979	2020-04-24 18:55:26	2020-04-24	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12737	delivery	5	39
53980	2020-04-24 18:55:36	2020-04-24	17	[{"id_menu":4,"count":1}]	1453	pick-up	0	17
53981	2020-04-24 18:56:22	2020-04-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21402	delivery	5	23
53982	2020-04-24 18:59:47	2020-04-24	9	[{"id_menu":6,"count":1}]	230	delivery	5	14
53983	2020-04-24 19:03:05	2020-04-24	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	20147	delivery	5	26
53984	2020-04-24 19:04:57	2020-04-24	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	21386	delivery	5	31
53985	2020-04-24 19:05:43	2020-04-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	21451	delivery	5	22
53986	2020-04-24 19:06:16	2020-04-24	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21354	delivery	5	22
53987	2020-04-24 19:07:09	2020-04-24	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21491	delivery	5	31
53988	2020-04-24 19:07:48	2020-04-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	5884	delivery	5	22
53989	2020-04-24 19:08:19	2020-04-24	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	15995	delivery	5	34
53990	2020-04-24 19:16:03	2020-04-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3403	delivery	5	28
53991	2020-04-24 19:18:44	2020-04-24	8	[{"id_menu":5,"count":1}]	3512	delivery	5	13
53992	2020-04-24 19:22:00	2020-04-24	9	[{"id_menu":6,"count":2}]	10273	pick-up	0	9
53993	2020-04-24 19:22:53	2020-04-24	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	21348	delivery	5	40
53994	2020-04-24 19:32:39	2020-04-24	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	21400	delivery	5	26
53995	2020-04-24 19:33:56	2020-04-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":3}]	21352	pick-up	0	26
53996	2020-04-24 19:46:55	2020-04-24	9	[{"id_menu":6,"count":1}]	21456	pick-up	0	9
53997	2020-04-24 19:47:34	2020-04-24	12	[{"id_menu":3,"count":1}]	19798	pick-up	0	12
53998	2020-04-24 19:48:03	2020-04-24	9	[{"id_menu":6,"count":1}]	4310	delivery	5	14
53999	2020-04-24 19:51:52	2020-04-24	9	[{"id_menu":6,"count":1}]	18804	delivery	5	14
54000	2020-04-24 19:59:26	2020-04-24	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	21477	delivery	5	26
54001	2020-04-24 20:00:48	2020-04-24	17	[{"id_menu":4,"count":1}]	76	pick-up	0	17
54002	2020-04-24 20:01:39	2020-04-24	9	[{"id_menu":7,"count":1}]	1774	pick-up	0	9
54003	2020-04-24 20:02:50	2020-04-24	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	21476	delivery	5	26
54004	2020-04-24 20:10:12	2020-04-24	12	[{"id_menu":3,"count":1}]	6328	pick-up	0	12
54005	2020-04-24 20:11:49	2020-04-24	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8372	pick-up	0	26
54006	2020-04-24 20:14:24	2020-04-24	9	[{"id_menu":7,"count":1}]	7306	pick-up	0	9
54007	2020-04-24 20:28:57	2020-04-24	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15108	delivery	5	31
54008	2020-04-24 20:35:04	2020-04-24	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	21516	delivery	5	25
54009	2020-04-24 20:35:56	2020-04-24	9	[{"id_menu":7,"count":1}]	21403	delivery	5	14
54010	2020-04-24 20:42:56	2020-04-24	8	[{"id_menu":5,"count":1}]	21351	delivery	5	13
54011	2020-04-24 20:46:51	2020-04-24	12	[{"id_menu":3,"count":1}]	21370	delivery	5	17
54012	2020-04-24 20:47:51	2020-04-24	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17610	delivery	5	39
54013	2020-04-24 20:50:15	2020-04-24	9	[{"id_menu":6,"count":1}]	21494	delivery	5	14
54014	2020-04-24 20:54:45	2020-04-24	17	[{"id_menu":4,"count":1}]	13498	delivery	5	22
54015	2020-04-24 20:55:59	2020-04-24	12	[{"id_menu":3,"count":1}]	18928	delivery	5	17
54016	2020-04-24 21:01:40	2020-04-24	14	[{"id_menu":2,"count":1}]	20565	delivery	5	19
54017	2020-04-24 21:05:19	2020-04-24	9	[{"id_menu":7,"count":1}]	7526	delivery	5	14
54018	2020-04-24 21:08:28	2020-04-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1674	delivery	5	31
54019	2020-04-24 21:11:06	2020-04-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	786	pick-up	0	26
54020	2020-04-24 21:16:35	2020-04-24	9	[{"id_menu":7,"count":1}]	1442	pick-up	0	9
54021	2020-04-24 21:24:21	2020-04-24	14	[{"id_menu":2,"count":1}]	21458	delivery	5	19
54022	2020-04-24 21:26:37	2020-04-24	9	[{"id_menu":6,"count":1}]	6022	delivery	5	14
54023	2020-04-24 21:32:17	2020-04-24	14	[{"id_menu":2,"count":1}]	2413	delivery	5	19
54024	2020-04-24 21:37:08	2020-04-24	14	[{"id_menu":2,"count":1}]	21440	delivery	5	19
54025	2020-04-24 21:41:11	2020-04-24	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	21485	pick-up	0	26
54026	2020-04-24 21:49:04	2020-04-24	14	[{"id_menu":2,"count":1}]	8456	delivery	5	19
54027	2020-04-24 21:49:51	2020-04-24	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7623	delivery	5	40
54028	2020-04-24 21:53:05	2020-04-24	12	[{"id_menu":3,"count":1}]	2947	pick-up	0	12
54029	2020-04-24 21:53:11	2020-04-24	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	21383	delivery	5	23
54030	2020-04-24 21:54:04	2020-04-24	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	7220	delivery	5	38
54031	2020-04-24 21:58:08	2020-04-24	8	[{"id_menu":5,"count":1}]	21447	delivery	5	13
54032	2020-04-24 22:00:10	2020-04-24	9	[{"id_menu":7,"count":1}]	21429	delivery	5	14
54033	2020-04-24 22:06:29	2020-04-24	9	[{"id_menu":6,"count":1}]	17353	pick-up	0	9
54034	2020-04-24 22:06:30	2020-04-24	14	[{"id_menu":2,"count":2}]	537	pick-up	0	14
54035	2020-04-24 22:13:57	2020-04-24	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	21425	delivery	5	42
54036	2020-04-24 22:25:08	2020-04-24	12	[{"id_menu":3,"count":1}]	13371	delivery	5	17
54037	2020-04-24 22:30:03	2020-04-24	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	21432	delivery	5	31
54038	2020-04-24 22:31:42	2020-04-24	17	[{"id_menu":4,"count":1}]	17664	delivery	5	22
54039	2020-04-24 22:42:12	2020-04-24	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	2821	pick-up	0	20
54040	2020-04-24 22:45:23	2020-04-24	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	21481	delivery	5	36
54041	2020-04-24 22:51:00	2020-04-24	8	[{"id_menu":5,"count":1}]	3372	pick-up	0	8
54042	2020-04-24 22:52:48	2020-04-24	14	[{"id_menu":2,"count":1}]	21369	delivery	5	19
54043	2020-04-24 22:58:38	2020-04-24	9	[{"id_menu":6,"count":1}]	4443	pick-up	0	9
54044	2020-04-24 22:58:39	2020-04-24	12	[{"id_menu":1,"count":1}]	21427	delivery	5	17
54045	2020-04-24 23:01:15	2020-04-24	9	[{"id_menu":7,"count":1}]	4100	delivery	5	14
54046	2020-04-24 23:05:58	2020-04-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10387	pick-up	0	26
54047	2020-04-24 23:06:29	2020-04-24	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13568	delivery	5	39
54048	2020-04-24 23:15:52	2020-04-24	17	[{"id_menu":4,"count":1}]	14969	delivery	5	22
54049	2020-04-24 23:17:02	2020-04-24	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	21343	delivery	5	27
54050	2020-04-24 23:19:10	2020-04-24	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	17596	delivery	5	31
54051	2020-04-24 23:20:37	2020-04-24	8	[{"id_menu":5,"count":1}]	13649	delivery	5	13
54052	2020-04-24 23:21:38	2020-04-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	636	delivery	5	22
54053	2020-04-24 23:38:28	2020-04-24	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	20606	delivery	5	26
54054	2020-04-24 23:40:31	2020-04-24	12	[{"id_menu":3,"count":1}]	8487	delivery	5	17
54055	2020-04-24 23:45:53	2020-04-24	8	[{"id_menu":5,"count":1}]	21424	delivery	5	13
54056	2020-04-24 23:46:28	2020-04-24	8	[{"id_menu":5,"count":1}]	21393	delivery	5	13
54057	2020-04-24 23:47:58	2020-04-24	9	[{"id_menu":7,"count":1}]	21379	pick-up	0	9
54058	2020-04-24 23:55:09	2020-04-24	9	[{"id_menu":6,"count":1}]	13269	delivery	5	14
54059	2020-04-25 00:04:01	2020-04-25	12	[{"id_menu":3,"count":2}]	3338	pick-up	0	12
54060	2020-04-25 00:04:08	2020-04-25	12	[{"id_menu":3,"count":1}]	21532	delivery	5	17
54061	2020-04-25 00:06:39	2020-04-25	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	21682	delivery	5	30
54062	2020-04-25 00:16:45	2020-04-25	17	[{"id_menu":4,"count":1}]	6409	delivery	5	22
54063	2020-04-25 00:19:23	2020-04-25	12	[{"id_menu":3,"count":2}]	1390	pick-up	0	12
54064	2020-04-25 00:19:53	2020-04-25	12	[{"id_menu":3,"count":1}]	1239	pick-up	0	12
54065	2020-04-25 00:21:43	2020-04-25	14	[{"id_menu":2,"count":1}]	9565	delivery	5	19
54066	2020-04-25 00:22:50	2020-04-25	12	[{"id_menu":3,"count":1}]	21587	delivery	5	17
54067	2020-04-25 00:24:14	2020-04-25	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21545	delivery	5	37
54068	2020-04-25 00:27:51	2020-04-25	9	[{"id_menu":6,"count":1}]	1910	pick-up	0	9
54069	2020-04-25 00:30:12	2020-04-25	12	[{"id_menu":3,"count":1}]	2320	delivery	5	17
54070	2020-04-25 00:31:42	2020-04-25	17	[{"id_menu":4,"count":1}]	586	pick-up	0	17
54071	2020-04-25 00:32:50	2020-04-25	9	[{"id_menu":7,"count":1}]	19037	delivery	5	14
54072	2020-04-25 00:35:50	2020-04-25	9	[{"id_menu":7,"count":1}]	4356	delivery	5	14
54073	2020-04-25 00:41:53	2020-04-25	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	16530	delivery	5	26
54074	2020-04-25 00:42:28	2020-04-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	559	delivery	5	23
54075	2020-04-25 00:45:43	2020-04-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14558	delivery	5	22
54076	2020-04-25 00:47:04	2020-04-25	12	[{"id_menu":3,"count":1}]	13120	pick-up	0	12
54077	2020-04-25 00:52:34	2020-04-25	17	[{"id_menu":4,"count":1}]	21700	delivery	5	22
54078	2020-04-25 00:54:45	2020-04-25	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3938	delivery	5	26
54079	2020-04-25 01:07:57	2020-04-25	9	[{"id_menu":6,"count":1}]	21572	delivery	5	14
54080	2020-04-25 01:13:57	2020-04-25	9	[{"id_menu":6,"count":1}]	21062	delivery	5	14
54081	2020-04-25 01:15:54	2020-04-25	14	[{"id_menu":2,"count":1}]	21597	delivery	5	19
54082	2020-04-25 01:16:15	2020-04-25	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	12367	pick-up	0	26
54083	2020-04-25 01:18:31	2020-04-25	14	[{"id_menu":2,"count":1}]	11156	delivery	5	19
54084	2020-04-25 01:19:07	2020-04-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14694	delivery	5	22
54085	2020-04-25 01:22:05	2020-04-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	21621	delivery	5	28
54086	2020-04-25 01:27:32	2020-04-25	9	[{"id_menu":6,"count":2}]	12889	delivery	5	14
54087	2020-04-25 01:28:29	2020-04-25	9	[{"id_menu":6,"count":1}]	9040	pick-up	0	9
54088	2020-04-25 01:29:11	2020-04-25	12	[{"id_menu":3,"count":1}]	17633	delivery	5	17
54089	2020-04-25 01:33:32	2020-04-25	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21703	delivery	5	34
54090	2020-04-25 01:35:25	2020-04-25	14	[{"id_menu":2,"count":1}]	13270	delivery	5	19
54091	2020-04-25 01:39:23	2020-04-25	14	[{"id_menu":2,"count":1}]	11191	delivery	5	19
54092	2020-04-25 01:39:43	2020-04-25	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5888	delivery	5	36
54093	2020-04-25 01:45:07	2020-04-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19529	delivery	5	23
54094	2020-04-25 01:46:48	2020-04-25	12	[{"id_menu":3,"count":1}]	3320	delivery	5	17
54095	2020-04-25 01:47:08	2020-04-25	9	[{"id_menu":7,"count":1}]	21605	delivery	5	14
54096	2020-04-25 01:51:38	2020-04-25	9	[{"id_menu":6,"count":1}]	8199	delivery	5	14
54097	2020-04-25 01:53:24	2020-04-25	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12265	pick-up	0	26
54098	2020-04-25 01:56:25	2020-04-25	9	[{"id_menu":7,"count":1}]	9696	delivery	5	14
54099	2020-04-25 02:04:06	2020-04-25	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	16627	delivery	5	38
54100	2020-04-25 02:15:21	2020-04-25	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	11793	pick-up	0	26
54101	2020-04-25 02:15:39	2020-04-25	9	[{"id_menu":6,"count":2}]	9420	pick-up	0	9
54102	2020-04-25 02:17:35	2020-04-25	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	21599	pick-up	0	20
54103	2020-04-25 02:23:27	2020-04-25	9	[{"id_menu":7,"count":1}]	9402	pick-up	0	9
54104	2020-04-25 02:26:22	2020-04-25	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7159	pick-up	0	37
54105	2020-04-25 02:29:02	2020-04-25	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	21640	delivery	5	34
54106	2020-04-25 02:30:12	2020-04-25	9	[{"id_menu":6,"count":1}]	3788	pick-up	0	9
54107	2020-04-25 02:36:02	2020-04-25	9	[{"id_menu":7,"count":1}]	21548	delivery	5	14
54108	2020-04-25 02:38:26	2020-04-25	8	[{"id_menu":5,"count":1}]	2191	delivery	5	13
54109	2020-04-25 02:41:27	2020-04-25	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":3}]	9296	delivery	5	26
54110	2020-04-25 02:41:34	2020-04-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16836	delivery	5	22
54111	2020-04-25 02:42:38	2020-04-25	9	[{"id_menu":6,"count":1}]	17657	delivery	5	14
54112	2020-04-25 02:43:48	2020-04-25	9	[{"id_menu":7,"count":1}]	21706	delivery	5	14
54113	2020-04-25 02:48:32	2020-04-25	12	[{"id_menu":1,"count":1}]	5141	pick-up	0	12
54114	2020-04-25 02:57:06	2020-04-25	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	21686	pick-up	0	40
54115	2020-04-25 02:59:10	2020-04-25	12	[{"id_menu":1,"count":1}]	4090	pick-up	0	12
54116	2020-04-25 03:00:36	2020-04-25	9	[{"id_menu":6,"count":1}]	18936	delivery	5	14
54117	2020-04-25 03:03:01	2020-04-25	14	[{"id_menu":2,"count":2}]	21257	delivery	5	19
54118	2020-04-25 03:03:52	2020-04-25	17	[{"id_menu":4,"count":1}]	15590	pick-up	0	17
54119	2020-04-25 03:04:13	2020-04-25	9	[{"id_menu":7,"count":1}]	7743	delivery	5	14
54120	2020-04-25 03:07:43	2020-04-25	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10494	delivery	5	30
54121	2020-04-25 03:12:15	2020-04-25	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	21606	pick-up	0	37
54122	2020-04-25 03:18:38	2020-04-25	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	10365	delivery	5	40
54123	2020-04-25 03:20:23	2020-04-25	8	[{"id_menu":5,"count":2}]	2041	pick-up	0	8
54124	2020-04-25 03:21:28	2020-04-25	12	[{"id_menu":3,"count":1}]	19889	delivery	5	17
54125	2020-04-25 03:25:58	2020-04-25	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	970	pick-up	0	26
54126	2020-04-25 03:26:22	2020-04-25	14	[{"id_menu":2,"count":2}]	21601	delivery	5	19
54127	2020-04-25 03:26:42	2020-04-25	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	11867	delivery	5	28
54128	2020-04-25 03:28:15	2020-04-25	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	10850	pick-up	0	22
54129	2020-04-25 03:28:39	2020-04-25	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5154	delivery	5	39
54130	2020-04-25 03:29:20	2020-04-25	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	21329	pick-up	0	29
54131	2020-04-25 03:29:27	2020-04-25	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	21669	delivery	5	34
54132	2020-04-25 03:29:45	2020-04-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10706	pick-up	0	26
54133	2020-04-25 03:30:11	2020-04-25	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	10027	delivery	5	26
54134	2020-04-25 03:32:33	2020-04-25	8	[{"id_menu":5,"count":1}]	15750	delivery	5	13
54135	2020-04-25 03:33:15	2020-04-25	9	[{"id_menu":6,"count":2}]	21547	delivery	5	14
54136	2020-04-25 03:37:08	2020-04-25	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7465	pick-up	0	31
54137	2020-04-25 03:42:43	2020-04-25	14	[{"id_menu":2,"count":1}]	21604	pick-up	0	14
54138	2020-04-25 03:49:13	2020-04-25	9	[{"id_menu":6,"count":1}]	7007	delivery	5	14
54139	2020-04-25 03:50:22	2020-04-25	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13411	delivery	5	35
54140	2020-04-25 03:57:54	2020-04-25	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	5060	pick-up	0	22
54141	2020-04-25 04:00:50	2020-04-25	12	[{"id_menu":1,"count":1}]	227	pick-up	0	12
54142	2020-04-25 04:05:36	2020-04-25	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	18419	delivery	5	38
54143	2020-04-25 04:06:03	2020-04-25	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13488	delivery	5	48
54144	2020-04-25 04:09:39	2020-04-25	8	[{"id_menu":5,"count":1}]	5250	delivery	5	13
54145	2020-04-25 04:10:46	2020-04-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3286	delivery	5	22
54146	2020-04-25 04:10:47	2020-04-25	14	[{"id_menu":2,"count":1}]	1148	delivery	5	19
54147	2020-04-25 04:11:37	2020-04-25	12	[{"id_menu":1,"count":1}]	1309	pick-up	0	12
54148	2020-04-25 04:12:43	2020-04-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	15888	delivery	5	28
54149	2020-04-25 04:16:57	2020-04-25	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	5642	delivery	5	31
54150	2020-04-25 04:17:25	2020-04-25	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21531	delivery	5	22
54151	2020-04-25 04:19:12	2020-04-25	12	[{"id_menu":3,"count":1}]	7866	pick-up	0	12
54152	2020-04-25 04:19:28	2020-04-25	9	[{"id_menu":7,"count":1}]	21610	delivery	5	14
54153	2020-04-25 04:24:26	2020-04-25	14	[{"id_menu":2,"count":1}]	4636	pick-up	0	14
54154	2020-04-25 04:34:27	2020-04-25	14	[{"id_menu":2,"count":1}]	8618	delivery	5	19
54155	2020-04-25 04:35:30	2020-04-25	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21580	delivery	5	34
54156	2020-04-25 04:35:55	2020-04-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	268	pick-up	0	23
54157	2020-04-25 04:50:45	2020-04-25	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	21537	delivery	5	26
54158	2020-04-25 04:51:19	2020-04-25	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13153	delivery	5	40
54159	2020-04-25 04:51:29	2020-04-25	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	21578	delivery	5	28
54160	2020-04-25 04:53:39	2020-04-25	9	[{"id_menu":6,"count":1}]	15026	pick-up	0	9
54161	2020-04-25 04:54:44	2020-04-25	17	[{"id_menu":4,"count":1}]	12602	delivery	5	22
54162	2020-04-25 04:57:01	2020-04-25	9	[{"id_menu":7,"count":1}]	21655	delivery	5	14
54163	2020-04-25 05:02:49	2020-04-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21677	delivery	5	22
54164	2020-04-25 05:04:37	2020-04-25	12	[{"id_menu":1,"count":1}]	21570	delivery	5	17
54165	2020-04-25 05:04:40	2020-04-25	9	[{"id_menu":6,"count":1}]	9941	delivery	5	14
54166	2020-04-25 05:06:16	2020-04-25	9	[{"id_menu":6,"count":1}]	21665	delivery	5	14
54167	2020-04-25 05:10:40	2020-04-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	10589	pick-up	0	23
54168	2020-04-25 05:16:26	2020-04-25	9	[{"id_menu":7,"count":1}]	21628	delivery	5	14
54169	2020-04-25 05:17:15	2020-04-25	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12780	delivery	5	34
54170	2020-04-25 05:18:11	2020-04-25	17	[{"id_menu":4,"count":1}]	12240	pick-up	0	17
54171	2020-04-25 05:22:02	2020-04-25	12	[{"id_menu":3,"count":1}]	13853	pick-up	0	12
54172	2020-04-25 05:22:07	2020-04-25	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":2}]	21666	delivery	5	26
54173	2020-04-25 05:26:51	2020-04-25	9	[{"id_menu":6,"count":1}]	8198	delivery	5	14
54174	2020-04-25 05:29:20	2020-04-25	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	7631	pick-up	0	29
54175	2020-04-25 05:29:40	2020-04-25	17	[{"id_menu":4,"count":1}]	12686	pick-up	0	17
54176	2020-04-25 05:31:22	2020-04-25	12	[{"id_menu":1,"count":1}]	20870	delivery	5	17
54177	2020-04-25 05:35:08	2020-04-25	8	[{"id_menu":5,"count":1}]	14362	delivery	5	13
54178	2020-04-25 05:37:39	2020-04-25	9	[{"id_menu":7,"count":1}]	5758	pick-up	0	9
54179	2020-04-25 05:40:29	2020-04-25	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	8379	delivery	5	28
54180	2020-04-25 05:41:41	2020-04-25	9	[{"id_menu":6,"count":1}]	4205	delivery	5	14
54181	2020-04-25 05:45:10	2020-04-25	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1507	pick-up	0	22
54182	2020-04-25 05:46:32	2020-04-25	17	[{"id_menu":4,"count":1}]	21693	delivery	5	22
54183	2020-04-25 05:47:31	2020-04-25	8	[{"id_menu":5,"count":1}]	21535	delivery	5	13
54184	2020-04-25 05:48:31	2020-04-25	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	21592	delivery	5	26
54185	2020-04-25 05:52:11	2020-04-25	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	21567	delivery	5	31
54186	2020-04-25 05:52:50	2020-04-25	14	[{"id_menu":2,"count":2}]	21539	delivery	5	19
54187	2020-04-25 05:53:34	2020-04-25	9	[{"id_menu":7,"count":1}]	18791	delivery	5	14
54188	2020-04-25 05:55:05	2020-04-25	14	[{"id_menu":2,"count":1}]	1203	delivery	5	19
54189	2020-04-25 05:55:38	2020-04-25	12	[{"id_menu":3,"count":1}]	9121	delivery	5	17
54190	2020-04-25 06:00:33	2020-04-25	9	[{"id_menu":7,"count":1}]	2670	delivery	5	14
54191	2020-04-25 06:06:34	2020-04-25	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	21634	pick-up	0	21
54192	2020-04-25 06:12:35	2020-04-25	9	[{"id_menu":6,"count":1}]	21645	delivery	5	14
54193	2020-04-25 06:16:16	2020-04-25	14	[{"id_menu":2,"count":1}]	21552	delivery	5	19
54194	2020-04-25 06:21:54	2020-04-25	14	[{"id_menu":2,"count":1}]	21668	delivery	5	19
54195	2020-04-25 06:23:02	2020-04-25	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	12827	delivery	5	26
54196	2020-04-25 06:23:43	2020-04-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	8184	delivery	5	28
54197	2020-04-25 06:26:05	2020-04-25	9	[{"id_menu":7,"count":1}]	17353	pick-up	0	9
54198	2020-04-25 06:37:21	2020-04-25	12	[{"id_menu":3,"count":1}]	18824	pick-up	0	12
54199	2020-04-25 06:40:19	2020-04-25	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	21623	delivery	5	30
54200	2020-04-25 06:44:30	2020-04-25	14	[{"id_menu":2,"count":3}]	21574	delivery	5	19
54201	2020-04-25 06:46:05	2020-04-25	12	[{"id_menu":3,"count":1}]	21577	delivery	5	17
54202	2020-04-25 06:46:39	2020-04-25	9	[{"id_menu":7,"count":1}]	15839	delivery	5	14
54203	2020-04-25 06:52:01	2020-04-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8775	pick-up	0	26
54204	2020-04-25 06:52:38	2020-04-25	9	[{"id_menu":6,"count":1}]	14165	delivery	5	14
54205	2020-04-25 06:53:32	2020-04-25	12	[{"id_menu":1,"count":1}]	10287	pick-up	0	12
54206	2020-04-25 06:53:38	2020-04-25	14	[{"id_menu":2,"count":2}]	13410	delivery	5	19
54207	2020-04-25 06:53:46	2020-04-25	12	[{"id_menu":3,"count":1}]	21653	delivery	5	17
54208	2020-04-25 06:53:47	2020-04-25	14	[{"id_menu":2,"count":1}]	4238	pick-up	0	14
54209	2020-04-25 06:55:38	2020-04-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	14222	delivery	5	28
54210	2020-04-25 06:56:15	2020-04-25	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	489	delivery	5	31
54211	2020-04-25 06:58:02	2020-04-25	14	[{"id_menu":2,"count":1}]	6599	delivery	5	19
54212	2020-04-25 07:01:51	2020-04-25	9	[{"id_menu":6,"count":1}]	21579	delivery	5	14
54213	2020-04-25 07:04:33	2020-04-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16239	delivery	5	23
54214	2020-04-25 07:05:21	2020-04-25	12	[{"id_menu":1,"count":1}]	19043	delivery	5	17
54215	2020-04-25 07:06:19	2020-04-25	17	[{"id_menu":4,"count":1}]	5794	delivery	5	22
54216	2020-04-25 07:07:36	2020-04-25	9	[{"id_menu":6,"count":1}]	21603	delivery	5	14
54217	2020-04-25 07:08:00	2020-04-25	8	[{"id_menu":5,"count":1}]	3557	delivery	5	13
54218	2020-04-25 07:08:30	2020-04-25	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16710	pick-up	0	38
54219	2020-04-25 07:11:33	2020-04-25	14	[{"id_menu":2,"count":2}]	21673	delivery	5	19
54220	2020-04-25 07:11:52	2020-04-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21613	delivery	5	23
54221	2020-04-25 07:13:23	2020-04-25	14	[{"id_menu":2,"count":1}]	21624	delivery	5	19
54222	2020-04-25 07:13:59	2020-04-25	9	[{"id_menu":7,"count":1}]	627	pick-up	0	9
54223	2020-04-25 07:22:34	2020-04-25	12	[{"id_menu":1,"count":1}]	21338	delivery	5	17
54224	2020-04-25 07:24:04	2020-04-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	21696	delivery	5	31
54225	2020-04-25 07:24:56	2020-04-25	9	[{"id_menu":6,"count":1}]	19124	delivery	5	14
54226	2020-04-25 07:30:36	2020-04-25	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	21685	delivery	5	30
54227	2020-04-25 07:32:37	2020-04-25	14	[{"id_menu":2,"count":1}]	21674	delivery	5	19
54228	2020-04-25 07:32:39	2020-04-25	14	[{"id_menu":2,"count":1}]	21699	delivery	5	19
54229	2020-04-25 07:32:50	2020-04-25	14	[{"id_menu":2,"count":2}]	21551	pick-up	0	14
54230	2020-04-25 07:33:02	2020-04-25	12	[{"id_menu":1,"count":1}]	9086	pick-up	0	12
54231	2020-04-25 07:35:09	2020-04-25	9	[{"id_menu":6,"count":1}]	14868	delivery	5	14
54232	2020-04-25 07:38:51	2020-04-25	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	21561	delivery	5	43
54233	2020-04-25 07:45:36	2020-04-25	8	[{"id_menu":5,"count":1}]	5775	delivery	5	13
54234	2020-04-25 07:46:58	2020-04-25	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	467	pick-up	0	29
54235	2020-04-25 07:48:32	2020-04-25	12	[{"id_menu":1,"count":1}]	12987	delivery	5	17
54236	2020-04-25 07:53:04	2020-04-25	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	21694	delivery	5	31
54237	2020-04-25 08:01:00	2020-04-25	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2025	pick-up	0	26
54238	2020-04-25 08:02:20	2020-04-25	8	[{"id_menu":5,"count":1}]	17357	delivery	5	13
54239	2020-04-25 08:02:32	2020-04-25	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21648	delivery	5	46
54240	2020-04-25 08:03:36	2020-04-25	14	[{"id_menu":2,"count":1}]	21616	delivery	5	19
54241	2020-04-25 08:09:29	2020-04-25	14	[{"id_menu":2,"count":1}]	16328	pick-up	0	14
54242	2020-04-25 08:11:43	2020-04-25	14	[{"id_menu":2,"count":1}]	21679	delivery	5	19
54243	2020-04-25 08:15:44	2020-04-25	12	[{"id_menu":3,"count":1}]	21625	delivery	5	17
54244	2020-04-25 08:24:43	2020-04-25	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	9852	pick-up	0	26
54245	2020-04-25 08:29:27	2020-04-25	9	[{"id_menu":7,"count":1}]	21573	delivery	5	14
54246	2020-04-25 08:31:19	2020-04-25	9	[{"id_menu":7,"count":1}]	19526	delivery	5	14
54247	2020-04-25 08:31:38	2020-04-25	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21626	delivery	5	31
54248	2020-04-25 08:31:52	2020-04-25	14	[{"id_menu":2,"count":1}]	7571	pick-up	0	14
54249	2020-04-25 08:33:50	2020-04-25	12	[{"id_menu":3,"count":1}]	11471	delivery	5	17
54250	2020-04-25 08:38:15	2020-04-25	14	[{"id_menu":2,"count":1}]	5071	delivery	5	19
54251	2020-04-25 08:38:23	2020-04-25	9	[{"id_menu":6,"count":1}]	14411	delivery	5	14
54252	2020-04-25 08:42:03	2020-04-25	9	[{"id_menu":7,"count":1}]	784	pick-up	0	9
54253	2020-04-25 08:42:53	2020-04-25	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	11412	delivery	5	22
54254	2020-04-25 08:43:36	2020-04-25	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	17145	delivery	5	34
54255	2020-04-25 08:47:39	2020-04-25	8	[{"id_menu":5,"count":1}]	17425	delivery	5	13
54256	2020-04-25 08:47:49	2020-04-25	14	[{"id_menu":2,"count":1}]	4818	delivery	5	19
54257	2020-04-25 08:52:28	2020-04-25	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4824	delivery	5	40
54258	2020-04-25 08:56:54	2020-04-25	14	[{"id_menu":2,"count":1}]	2799	delivery	5	19
54259	2020-04-25 09:05:08	2020-04-25	14	[{"id_menu":2,"count":1}]	21690	delivery	5	19
54260	2020-04-25 09:08:36	2020-04-25	9	[{"id_menu":6,"count":1}]	12184	pick-up	0	9
54261	2020-04-25 09:13:30	2020-04-25	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	21630	delivery	5	30
54262	2020-04-25 09:15:07	2020-04-25	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2897	pick-up	0	35
54263	2020-04-25 09:15:37	2020-04-25	8	[{"id_menu":5,"count":1}]	21622	delivery	5	13
54264	2020-04-25 09:15:45	2020-04-25	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	11768	pick-up	0	29
54265	2020-04-25 09:15:53	2020-04-25	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	7374	delivery	5	31
54266	2020-04-25 09:19:38	2020-04-25	12	[{"id_menu":1,"count":1}]	21585	delivery	5	17
54267	2020-04-25 09:22:00	2020-04-25	12	[{"id_menu":1,"count":1}]	21541	delivery	5	17
54268	2020-04-25 09:22:21	2020-04-25	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	2696	delivery	5	48
54269	2020-04-25 09:25:27	2020-04-25	17	[{"id_menu":4,"count":2}]	144	delivery	5	22
54270	2020-04-25 09:27:33	2020-04-25	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	21556	pick-up	0	26
54271	2020-04-25 09:29:32	2020-04-25	9	[{"id_menu":7,"count":1}]	21607	pick-up	0	9
54272	2020-04-25 09:30:16	2020-04-25	14	[{"id_menu":2,"count":1}]	11604	pick-up	0	14
54273	2020-04-25 09:32:09	2020-04-25	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6116	delivery	5	28
54274	2020-04-25 09:40:45	2020-04-25	9	[{"id_menu":6,"count":2}]	21678	pick-up	0	9
54275	2020-04-25 09:42:00	2020-04-25	17	[{"id_menu":4,"count":1}]	21591	delivery	5	22
54276	2020-04-25 09:45:44	2020-04-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17003	delivery	5	23
54277	2020-04-25 09:48:16	2020-04-25	12	[{"id_menu":3,"count":1}]	6171	delivery	5	17
54278	2020-04-25 09:48:26	2020-04-25	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	3868	pick-up	0	31
54279	2020-04-25 09:51:14	2020-04-25	12	[{"id_menu":3,"count":1}]	4960	pick-up	0	12
54280	2020-04-25 09:52:18	2020-04-25	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	5082	pick-up	0	21
54281	2020-04-25 09:56:34	2020-04-25	9	[{"id_menu":6,"count":1}]	21659	delivery	5	14
54282	2020-04-25 10:00:41	2020-04-25	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	17831	delivery	5	31
54283	2020-04-25 10:02:43	2020-04-25	8	[{"id_menu":5,"count":1}]	21681	delivery	5	13
54284	2020-04-25 10:03:27	2020-04-25	12	[{"id_menu":3,"count":1}]	5238	delivery	5	17
54285	2020-04-25 10:03:52	2020-04-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4532	delivery	5	22
54286	2020-04-25 10:04:19	2020-04-25	12	[{"id_menu":1,"count":1}]	2413	pick-up	0	12
54287	2020-04-25 10:06:30	2020-04-25	12	[{"id_menu":3,"count":1}]	5292	pick-up	0	12
54288	2020-04-25 10:07:24	2020-04-25	8	[{"id_menu":5,"count":1}]	15764	delivery	5	13
54289	2020-04-25 10:07:59	2020-04-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21702	delivery	5	23
54290	2020-04-25 10:09:23	2020-04-25	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	21550	delivery	5	31
54291	2020-04-25 10:09:25	2020-04-25	8	[{"id_menu":5,"count":1}]	12243	delivery	5	13
54292	2020-04-25 10:10:28	2020-04-25	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	21576	delivery	5	30
54293	2020-04-25 10:12:34	2020-04-25	9	[{"id_menu":7,"count":1}]	10244	pick-up	0	9
54294	2020-04-25 10:19:51	2020-04-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21536	delivery	5	22
54295	2020-04-25 10:21:53	2020-04-25	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	293	pick-up	0	21
54296	2020-04-25 10:23:24	2020-04-25	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2354	pick-up	0	20
54297	2020-04-25 10:28:09	2020-04-25	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	18658	delivery	5	30
54298	2020-04-25 10:28:41	2020-04-25	9	[{"id_menu":7,"count":1}]	21651	delivery	5	14
54299	2020-04-25 10:30:42	2020-04-25	9	[{"id_menu":7,"count":2}]	13613	delivery	5	14
54300	2020-04-25 10:31:50	2020-04-25	9	[{"id_menu":6,"count":1}]	10651	delivery	5	14
54301	2020-04-25 10:32:01	2020-04-25	12	[{"id_menu":3,"count":1}]	21652	pick-up	0	12
54302	2020-04-25 10:34:10	2020-04-25	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	11825	delivery	5	26
54303	2020-04-25 10:34:58	2020-04-25	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21684	delivery	5	34
54304	2020-04-25 10:35:47	2020-04-25	9	[{"id_menu":7,"count":1}]	20182	delivery	5	14
54305	2020-04-25 10:39:59	2020-04-25	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	14572	pick-up	0	24
54306	2020-04-25 10:44:34	2020-04-25	8	[{"id_menu":5,"count":1}]	15771	delivery	5	13
54307	2020-04-25 10:45:57	2020-04-25	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	21560	delivery	5	31
54308	2020-04-25 10:51:06	2020-04-25	14	[{"id_menu":2,"count":1}]	2599	pick-up	0	14
54309	2020-04-25 11:03:17	2020-04-25	9	[{"id_menu":6,"count":1}]	3198	delivery	5	14
54310	2020-04-25 11:14:25	2020-04-25	9	[{"id_menu":7,"count":1}]	21534	delivery	5	14
54311	2020-04-25 11:15:04	2020-04-25	14	[{"id_menu":2,"count":1}]	21565	pick-up	0	14
54312	2020-04-25 11:18:31	2020-04-25	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	21540	delivery	5	27
54313	2020-04-25 11:18:32	2020-04-25	8	[{"id_menu":5,"count":2}]	6331	pick-up	0	8
54314	2020-04-25 11:19:02	2020-04-25	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	21608	delivery	5	28
54315	2020-04-25 11:19:15	2020-04-25	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6519	delivery	5	36
54316	2020-04-25 11:21:22	2020-04-25	9	[{"id_menu":6,"count":1}]	14246	delivery	5	14
54317	2020-04-25 11:26:29	2020-04-25	8	[{"id_menu":5,"count":1}]	11971	delivery	5	13
54318	2020-04-25 11:30:25	2020-04-25	12	[{"id_menu":3,"count":1}]	2185	pick-up	0	12
54319	2020-04-25 11:31:35	2020-04-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9778	delivery	5	31
54320	2020-04-25 11:34:16	2020-04-25	14	[{"id_menu":2,"count":1}]	21600	pick-up	0	14
54321	2020-04-25 11:38:21	2020-04-25	14	[{"id_menu":2,"count":1}]	21571	delivery	5	19
54322	2020-04-25 11:39:59	2020-04-25	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	13649	delivery	5	40
54323	2020-04-25 11:40:43	2020-04-25	9	[{"id_menu":7,"count":1}]	21704	delivery	5	14
54324	2020-04-25 11:41:29	2020-04-25	17	[{"id_menu":4,"count":1}]	21642	pick-up	0	17
54325	2020-04-25 11:43:43	2020-04-25	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	21660	delivery	5	34
54326	2020-04-25 11:45:32	2020-04-25	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3684	delivery	5	36
54327	2020-04-25 11:46:15	2020-04-25	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1315	delivery	5	35
54328	2020-04-25 11:46:27	2020-04-25	9	[{"id_menu":6,"count":1}]	21584	delivery	5	14
54329	2020-04-25 11:47:46	2020-04-25	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	17511	delivery	5	30
54330	2020-04-25 11:48:33	2020-04-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	16829	pick-up	0	23
54331	2020-04-25 11:51:39	2020-04-25	12	[{"id_menu":1,"count":1}]	2251	pick-up	0	12
54332	2020-04-25 11:57:59	2020-04-25	12	[{"id_menu":1,"count":1}]	21569	pick-up	0	12
54333	2020-04-25 12:00:49	2020-04-25	14	[{"id_menu":2,"count":1}]	4193	delivery	5	19
54334	2020-04-25 12:03:45	2020-04-25	9	[{"id_menu":7,"count":1}]	21566	delivery	5	14
54335	2020-04-25 12:11:47	2020-04-25	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	11779	pick-up	0	18
54336	2020-04-25 12:14:21	2020-04-25	9	[{"id_menu":7,"count":1}]	11250	delivery	5	14
54337	2020-04-25 12:17:58	2020-04-25	9	[{"id_menu":7,"count":1}]	55	delivery	5	14
54338	2020-04-25 12:20:37	2020-04-25	9	[{"id_menu":6,"count":1}]	5928	delivery	5	14
54339	2020-04-25 12:22:35	2020-04-25	17	[{"id_menu":4,"count":1}]	3447	delivery	5	22
54340	2020-04-25 12:28:04	2020-04-25	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	14775	delivery	5	36
54341	2020-04-25 12:29:01	2020-04-25	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	12791	pick-up	0	29
54342	2020-04-25 12:35:43	2020-04-25	9	[{"id_menu":6,"count":1}]	21549	delivery	5	14
54343	2020-04-25 12:40:12	2020-04-25	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	21618	delivery	5	36
54344	2020-04-25 12:40:20	2020-04-25	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	6603	delivery	5	25
54345	2020-04-25 12:47:41	2020-04-25	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	995	delivery	5	44
54346	2020-04-25 12:47:59	2020-04-25	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	19212	pick-up	0	22
54347	2020-04-25 12:48:19	2020-04-25	8	[{"id_menu":5,"count":2}]	4365	pick-up	0	8
54348	2020-04-25 12:55:17	2020-04-25	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	7834	pick-up	0	26
54349	2020-04-25 12:56:18	2020-04-25	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	12094	delivery	5	28
54350	2020-04-25 13:00:56	2020-04-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	566	pick-up	0	23
54351	2020-04-25 13:01:56	2020-04-25	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	19892	delivery	5	34
54352	2020-04-25 13:02:20	2020-04-25	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	6104	delivery	5	34
54353	2020-04-25 13:03:25	2020-04-25	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	21594	delivery	5	40
54354	2020-04-25 13:08:28	2020-04-25	8	[{"id_menu":5,"count":1}]	2613	pick-up	0	8
54355	2020-04-25 13:08:32	2020-04-25	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":3}]	8757	pick-up	0	26
54356	2020-04-25 13:16:16	2020-04-25	9	[{"id_menu":7,"count":1}]	9426	delivery	5	14
54357	2020-04-25 13:19:24	2020-04-25	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1922	delivery	5	40
54358	2020-04-25 13:22:35	2020-04-25	14	[{"id_menu":2,"count":1}]	7553	delivery	5	19
54359	2020-04-25 13:26:48	2020-04-25	9	[{"id_menu":7,"count":1}]	21218	delivery	5	14
54360	2020-04-25 13:29:43	2020-04-25	8	[{"id_menu":5,"count":1}]	18460	delivery	5	13
54361	2020-04-25 13:30:00	2020-04-25	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	21562	delivery	5	31
54362	2020-04-25 13:40:59	2020-04-25	12	[{"id_menu":1,"count":1}]	8877	delivery	5	17
54363	2020-04-25 13:42:18	2020-04-25	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	10694	pick-up	0	20
54364	2020-04-25 13:44:13	2020-04-25	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4917	delivery	5	28
54365	2020-04-25 13:46:39	2020-04-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21664	delivery	5	22
54366	2020-04-25 13:50:02	2020-04-25	12	[{"id_menu":1,"count":1}]	19181	pick-up	0	12
54367	2020-04-25 13:50:14	2020-04-25	12	[{"id_menu":1,"count":1}]	19957	delivery	5	17
54368	2020-04-25 13:59:16	2020-04-25	9	[{"id_menu":7,"count":1}]	19857	delivery	5	14
54369	2020-04-25 14:02:50	2020-04-25	9	[{"id_menu":7,"count":2}]	2602	delivery	5	14
54370	2020-04-25 14:05:52	2020-04-25	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	9266	pick-up	0	26
54371	2020-04-25 14:07:25	2020-04-25	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	6799	delivery	5	26
54372	2020-04-25 14:07:35	2020-04-25	9	[{"id_menu":7,"count":1}]	833	pick-up	0	9
54373	2020-04-25 14:08:25	2020-04-25	9	[{"id_menu":7,"count":1}]	17287	delivery	5	14
54374	2020-04-25 14:12:41	2020-04-25	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	4757	delivery	5	26
54375	2020-04-25 14:14:21	2020-04-25	14	[{"id_menu":2,"count":1}]	7919	delivery	5	19
54376	2020-04-25 14:16:56	2020-04-25	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	21639	delivery	5	31
54377	2020-04-25 14:18:48	2020-04-25	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	9934	pick-up	0	21
54378	2020-04-25 14:24:28	2020-04-25	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	21638	delivery	5	31
54379	2020-04-25 14:25:43	2020-04-25	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	11777	delivery	5	25
54380	2020-04-25 14:26:59	2020-04-25	9	[{"id_menu":7,"count":2}]	962	delivery	5	14
54381	2020-04-25 14:27:48	2020-04-25	9	[{"id_menu":6,"count":1}]	3592	pick-up	0	9
54382	2020-04-25 14:40:05	2020-04-25	12	[{"id_menu":3,"count":1}]	7385	pick-up	0	12
54383	2020-04-25 14:40:07	2020-04-25	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	7501	pick-up	0	21
54384	2020-04-25 14:43:30	2020-04-25	14	[{"id_menu":2,"count":1}]	9640	pick-up	0	14
54385	2020-04-25 14:45:51	2020-04-25	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	16749	delivery	5	26
54386	2020-04-25 14:48:30	2020-04-25	9	[{"id_menu":7,"count":2}]	8397	delivery	5	14
54387	2020-04-25 14:50:38	2020-04-25	17	[{"id_menu":4,"count":1}]	17062	delivery	5	22
54388	2020-04-25 15:01:36	2020-04-25	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2477	pick-up	0	25
54389	2020-04-25 15:09:03	2020-04-25	8	[{"id_menu":5,"count":2}]	12690	pick-up	0	8
54390	2020-04-25 15:11:29	2020-04-25	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6117	delivery	5	37
54391	2020-04-25 15:23:54	2020-04-25	12	[{"id_menu":1,"count":1}]	21633	delivery	5	17
54392	2020-04-25 15:24:16	2020-04-25	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	756	pick-up	0	43
54393	2020-04-25 15:24:37	2020-04-25	12	[{"id_menu":3,"count":1}]	21563	delivery	5	17
54394	2020-04-25 15:25:04	2020-04-25	9	[{"id_menu":6,"count":1}]	3206	pick-up	0	9
54395	2020-04-25 15:25:26	2020-04-25	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	4495	delivery	5	44
54396	2020-04-25 15:26:15	2020-04-25	14	[{"id_menu":2,"count":1}]	11046	delivery	5	19
54397	2020-04-25 15:29:37	2020-04-25	9	[{"id_menu":6,"count":1}]	21598	delivery	5	14
54398	2020-04-25 15:30:36	2020-04-25	9	[{"id_menu":6,"count":1}]	21582	pick-up	0	9
54399	2020-04-25 15:40:33	2020-04-25	17	[{"id_menu":4,"count":1}]	9392	delivery	5	22
54400	2020-04-25 15:45:06	2020-04-25	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	21689	delivery	5	36
54401	2020-04-25 15:46:01	2020-04-25	9	[{"id_menu":6,"count":2}]	5766	delivery	5	14
54402	2020-04-25 15:47:43	2020-04-25	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	21589	delivery	5	43
54403	2020-04-25 15:50:26	2020-04-25	12	[{"id_menu":1,"count":1}]	5592	delivery	5	17
54404	2020-04-25 15:57:06	2020-04-25	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	21644	delivery	5	25
54405	2020-04-25 16:01:59	2020-04-25	14	[{"id_menu":2,"count":1}]	11028	pick-up	0	14
54406	2020-04-25 16:06:21	2020-04-25	41	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	21611	delivery	5	46
54407	2020-04-25 16:07:56	2020-04-25	8	[{"id_menu":5,"count":1}]	21205	delivery	5	13
54408	2020-04-25 16:09:09	2020-04-25	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10626	pick-up	0	30
54409	2020-04-25 16:16:37	2020-04-25	9	[{"id_menu":7,"count":1}]	6041	delivery	5	14
54410	2020-04-25 16:17:37	2020-04-25	12	[{"id_menu":1,"count":1}]	8949	pick-up	0	12
54411	2020-04-25 16:25:21	2020-04-25	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21675	delivery	5	22
54412	2020-04-25 16:28:41	2020-04-25	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4088	delivery	5	34
54413	2020-04-25 16:33:38	2020-04-25	9	[{"id_menu":6,"count":1}]	12019	pick-up	0	9
54414	2020-04-25 16:36:34	2020-04-25	12	[{"id_menu":1,"count":1}]	21533	delivery	5	17
54415	2020-04-25 16:38:46	2020-04-25	9	[{"id_menu":6,"count":1}]	5387	pick-up	0	9
54416	2020-04-25 16:41:12	2020-04-25	12	[{"id_menu":1,"count":2}]	5832	pick-up	0	12
54417	2020-04-25 16:41:59	2020-04-25	9	[{"id_menu":6,"count":1}]	21658	delivery	5	14
54418	2020-04-25 16:46:56	2020-04-25	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	171	delivery	5	36
54419	2020-04-25 16:48:48	2020-04-25	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	20573	delivery	5	45
54420	2020-04-25 16:51:31	2020-04-25	9	[{"id_menu":6,"count":1}]	21637	delivery	5	14
54421	2020-04-25 16:57:06	2020-04-25	12	[{"id_menu":1,"count":1}]	1014	pick-up	0	12
54422	2020-04-25 17:04:45	2020-04-25	8	[{"id_menu":5,"count":1}]	17095	delivery	5	13
54423	2020-04-25 17:11:50	2020-04-25	9	[{"id_menu":6,"count":1}]	19665	delivery	5	14
54424	2020-04-25 17:11:53	2020-04-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21609	delivery	5	23
54425	2020-04-25 17:16:11	2020-04-25	12	[{"id_menu":1,"count":1}]	21705	delivery	5	17
54426	2020-04-25 17:18:36	2020-04-25	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	9973	delivery	5	25
54427	2020-04-25 17:22:03	2020-04-25	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21646	delivery	5	36
54428	2020-04-25 17:24:08	2020-04-25	17	[{"id_menu":4,"count":1}]	21581	delivery	5	22
54429	2020-04-25 17:24:20	2020-04-25	17	[{"id_menu":4,"count":1}]	17686	delivery	5	22
54430	2020-04-25 17:24:55	2020-04-25	8	[{"id_menu":5,"count":1}]	21647	delivery	5	13
54431	2020-04-25 17:29:21	2020-04-25	8	[{"id_menu":5,"count":1}]	21635	delivery	5	13
54432	2020-04-25 17:35:05	2020-04-25	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21555	delivery	5	34
54433	2020-04-25 17:36:43	2020-04-25	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21543	delivery	5	40
54434	2020-04-25 17:41:11	2020-04-25	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16624	delivery	5	34
54435	2020-04-25 17:42:14	2020-04-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	19488	delivery	5	28
54436	2020-04-25 17:42:25	2020-04-25	17	[{"id_menu":4,"count":1}]	1742	pick-up	0	17
54437	2020-04-25 17:43:06	2020-04-25	14	[{"id_menu":2,"count":1}]	3940	pick-up	0	14
54438	2020-04-25 17:44:45	2020-04-25	9	[{"id_menu":6,"count":1}]	13081	delivery	5	14
54439	2020-04-25 17:47:14	2020-04-25	12	[{"id_menu":1,"count":1}]	3247	pick-up	0	12
54440	2020-04-25 17:50:12	2020-04-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21667	delivery	5	23
54441	2020-04-25 17:50:33	2020-04-25	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	21656	delivery	5	43
54442	2020-04-25 17:51:41	2020-04-25	9	[{"id_menu":7,"count":1}]	21641	delivery	5	14
54443	2020-04-25 17:52:21	2020-04-25	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	21564	delivery	5	36
54444	2020-04-25 17:53:05	2020-04-25	14	[{"id_menu":2,"count":1}]	1485	delivery	5	19
54445	2020-04-25 18:00:19	2020-04-25	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	16044	delivery	5	39
54446	2020-04-25 18:00:56	2020-04-25	9	[{"id_menu":7,"count":1}]	7705	delivery	5	14
54447	2020-04-25 18:00:57	2020-04-25	9	[{"id_menu":7,"count":1}]	21629	delivery	5	14
54448	2020-04-25 18:03:43	2020-04-25	14	[{"id_menu":2,"count":1}]	4007	pick-up	0	14
54449	2020-04-25 18:08:10	2020-04-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21558	pick-up	0	17
54450	2020-04-25 18:08:13	2020-04-25	9	[{"id_menu":7,"count":1}]	21595	pick-up	0	9
54451	2020-04-25 18:08:54	2020-04-25	14	[{"id_menu":2,"count":1}]	10525	pick-up	0	14
54452	2020-04-25 18:12:31	2020-04-25	9	[{"id_menu":7,"count":1}]	3773	delivery	5	14
54453	2020-04-25 18:19:52	2020-04-25	14	[{"id_menu":2,"count":1}]	7550	delivery	5	19
54454	2020-04-25 18:22:30	2020-04-25	9	[{"id_menu":7,"count":1}]	360	pick-up	0	9
54455	2020-04-25 18:24:50	2020-04-25	12	[{"id_menu":3,"count":1}]	1028	delivery	5	17
54456	2020-04-25 18:25:03	2020-04-25	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21649	delivery	5	48
54457	2020-04-25 18:27:54	2020-04-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3957	pick-up	0	17
54458	2020-04-25 18:32:29	2020-04-25	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	21657	delivery	5	23
54459	2020-04-25 18:41:57	2020-04-25	9	[{"id_menu":7,"count":1}]	877	pick-up	0	9
54460	2020-04-25 18:48:19	2020-04-25	9	[{"id_menu":6,"count":1}]	17804	delivery	5	14
54461	2020-04-25 18:49:48	2020-04-25	14	[{"id_menu":2,"count":1}]	21636	delivery	5	19
54462	2020-04-25 18:52:11	2020-04-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	21676	delivery	5	28
54463	2020-04-25 18:53:10	2020-04-25	17	[{"id_menu":4,"count":1}]	11593	pick-up	0	17
54464	2020-04-25 18:55:38	2020-04-25	9	[{"id_menu":6,"count":1}]	14252	delivery	5	14
54465	2020-04-25 18:58:08	2020-04-25	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	21701	delivery	5	37
54466	2020-04-25 19:00:01	2020-04-25	12	[{"id_menu":3,"count":1}]	3115	delivery	5	17
54467	2020-04-25 19:00:26	2020-04-25	9	[{"id_menu":6,"count":1}]	21671	delivery	5	14
54468	2020-04-25 19:00:40	2020-04-25	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	9057	pick-up	0	21
54469	2020-04-25 19:05:05	2020-04-25	9	[{"id_menu":7,"count":1}]	19011	pick-up	0	9
54470	2020-04-25 19:07:13	2020-04-25	12	[{"id_menu":3,"count":1}]	1158	delivery	5	17
54471	2020-04-25 19:14:34	2020-04-25	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	21672	pick-up	0	29
54472	2020-04-25 19:17:44	2020-04-25	8	[{"id_menu":5,"count":1}]	21650	delivery	5	13
54473	2020-04-25 19:19:12	2020-04-25	9	[{"id_menu":6,"count":1}]	18320	delivery	5	14
54474	2020-04-25 19:22:27	2020-04-25	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	21586	delivery	5	30
54475	2020-04-25 19:23:02	2020-04-25	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17803	delivery	5	43
54476	2020-04-25 19:23:35	2020-04-25	17	[{"id_menu":4,"count":1}]	13862	delivery	5	22
54477	2020-04-25 19:24:01	2020-04-25	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1088	pick-up	0	23
54478	2020-04-25 19:24:47	2020-04-25	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21538	delivery	5	22
54479	2020-04-25 19:28:37	2020-04-25	9	[{"id_menu":6,"count":1}]	10336	delivery	5	14
54480	2020-04-25 19:31:09	2020-04-25	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9957	delivery	5	49
54481	2020-04-25 19:31:32	2020-04-25	12	[{"id_menu":1,"count":1}]	21663	delivery	5	17
54482	2020-04-25 19:31:40	2020-04-25	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	12934	delivery	5	40
54483	2020-04-25 19:36:31	2020-04-25	9	[{"id_menu":7,"count":1}]	21575	pick-up	0	9
54484	2020-04-25 19:36:53	2020-04-25	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21698	delivery	5	37
54485	2020-04-25 19:39:16	2020-04-25	12	[{"id_menu":1,"count":1}]	21466	delivery	5	17
54486	2020-04-25 19:39:35	2020-04-25	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	21273	pick-up	0	21
54487	2020-04-25 19:41:17	2020-04-25	12	[{"id_menu":1,"count":1}]	16571	pick-up	0	12
54488	2020-04-25 19:41:49	2020-04-25	14	[{"id_menu":2,"count":1}]	4062	delivery	5	19
54489	2020-04-25 19:44:20	2020-04-25	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15429	delivery	5	22
54490	2020-04-25 19:51:57	2020-04-25	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	10980	delivery	5	48
54491	2020-04-25 19:53:43	2020-04-25	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	10852	pick-up	0	26
54492	2020-04-25 19:56:19	2020-04-25	9	[{"id_menu":7,"count":1}]	730	delivery	5	14
54493	2020-04-25 19:59:44	2020-04-25	9	[{"id_menu":6,"count":1}]	8852	delivery	5	14
54494	2020-04-25 20:00:52	2020-04-25	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	12164	delivery	5	31
54495	2020-04-25 20:00:59	2020-04-25	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	16152	delivery	5	30
54496	2020-04-25 20:01:04	2020-04-25	12	[{"id_menu":3,"count":1}]	4488	delivery	5	17
54497	2020-04-25 20:20:51	2020-04-25	17	[{"id_menu":4,"count":1}]	6848	delivery	5	22
54498	2020-04-25 20:21:10	2020-04-25	17	[{"id_menu":4,"count":1}]	21632	pick-up	0	17
54499	2020-04-25 20:21:23	2020-04-25	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	15101	delivery	5	40
54500	2020-04-25 20:21:28	2020-04-25	17	[{"id_menu":4,"count":1}]	746	pick-up	0	17
54501	2020-04-25 20:22:50	2020-04-25	9	[{"id_menu":6,"count":1}]	21588	delivery	5	14
54502	2020-04-25 20:24:41	2020-04-25	9	[{"id_menu":6,"count":1}]	21557	delivery	5	14
54503	2020-04-25 20:25:19	2020-04-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	14970	pick-up	0	23
54504	2020-04-25 20:26:20	2020-04-25	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	8090	pick-up	0	21
54505	2020-04-25 20:26:42	2020-04-25	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19122	delivery	5	22
54506	2020-04-25 20:27:37	2020-04-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	21670	delivery	5	23
54507	2020-04-25 20:28:02	2020-04-25	12	[{"id_menu":1,"count":1}]	11276	delivery	5	17
54508	2020-04-25 20:31:16	2020-04-25	14	[{"id_menu":2,"count":1}]	18344	pick-up	0	14
54509	2020-04-25 20:38:51	2020-04-25	14	[{"id_menu":2,"count":2}]	8180	delivery	5	19
54510	2020-04-25 20:41:12	2020-04-25	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	21426	delivery	5	25
54511	2020-04-25 20:46:42	2020-04-25	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	15437	delivery	5	34
54512	2020-04-25 20:49:28	2020-04-25	9	[{"id_menu":7,"count":1}]	19115	delivery	5	14
54513	2020-04-25 20:49:46	2020-04-25	14	[{"id_menu":2,"count":1}]	10598	pick-up	0	14
54514	2020-04-25 20:59:43	2020-04-25	9	[{"id_menu":6,"count":1}]	21662	delivery	5	14
54515	2020-04-25 20:59:43	2020-04-25	17	[{"id_menu":4,"count":1}]	9517	delivery	5	22
54516	2020-04-25 21:01:11	2020-04-25	9	[{"id_menu":6,"count":2}]	13303	delivery	5	14
54517	2020-04-25 21:01:43	2020-04-25	17	[{"id_menu":4,"count":2}]	21553	pick-up	0	17
54518	2020-04-25 21:07:51	2020-04-25	12	[{"id_menu":1,"count":1}]	13545	delivery	5	17
54519	2020-04-25 21:18:53	2020-04-25	12	[{"id_menu":1,"count":1}]	21615	delivery	5	17
54520	2020-04-25 21:18:59	2020-04-25	9	[{"id_menu":7,"count":1}]	10807	delivery	5	14
54521	2020-04-25 21:19:12	2020-04-25	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21654	delivery	5	45
54522	2020-04-25 21:19:20	2020-04-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	21596	pick-up	0	26
54523	2020-04-25 21:19:51	2020-04-25	14	[{"id_menu":2,"count":1}]	11083	delivery	5	19
54524	2020-04-25 21:22:22	2020-04-25	17	[{"id_menu":4,"count":1}]	21612	pick-up	0	17
54525	2020-04-25 21:23:21	2020-04-25	9	[{"id_menu":6,"count":1}]	18236	delivery	5	14
54526	2020-04-25 21:24:56	2020-04-25	8	[{"id_menu":5,"count":1}]	18763	delivery	5	13
54527	2020-04-25 21:25:06	2020-04-25	17	[{"id_menu":4,"count":1}]	7155	delivery	5	22
54528	2020-04-25 21:26:52	2020-04-25	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3997	delivery	5	39
54529	2020-04-25 21:31:19	2020-04-25	8	[{"id_menu":5,"count":1}]	16512	delivery	5	13
54530	2020-04-25 21:31:53	2020-04-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2784	delivery	5	28
54531	2020-04-25 21:34:32	2020-04-25	14	[{"id_menu":2,"count":1}]	10391	delivery	5	19
54532	2020-04-25 21:36:49	2020-04-25	8	[{"id_menu":5,"count":1}]	19971	delivery	5	13
54533	2020-04-25 21:39:03	2020-04-25	9	[{"id_menu":6,"count":1}]	21680	delivery	5	14
54534	2020-04-25 21:39:32	2020-04-25	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	21627	delivery	5	48
54535	2020-04-25 21:42:05	2020-04-25	9	[{"id_menu":6,"count":1}]	19781	delivery	5	14
54536	2020-04-25 21:46:10	2020-04-25	17	[{"id_menu":4,"count":1}]	12940	delivery	5	22
54537	2020-04-25 21:49:42	2020-04-25	9	[{"id_menu":6,"count":1}]	21614	delivery	5	14
54538	2020-04-25 21:50:54	2020-04-25	12	[{"id_menu":3,"count":1}]	7546	pick-up	0	12
54539	2020-04-25 21:53:00	2020-04-25	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3542	delivery	5	51
54540	2020-04-25 21:54:16	2020-04-25	12	[{"id_menu":1,"count":1}]	3431	delivery	5	17
54541	2020-04-25 21:55:02	2020-04-25	14	[{"id_menu":2,"count":2}]	389	delivery	5	19
54542	2020-04-25 21:56:16	2020-04-25	14	[{"id_menu":2,"count":1}]	17428	delivery	5	19
54543	2020-04-25 21:56:22	2020-04-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4651	delivery	5	23
54544	2020-04-25 21:57:32	2020-04-25	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	21619	delivery	5	28
54545	2020-04-25 21:59:19	2020-04-25	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	4141	delivery	5	26
54546	2020-04-25 22:01:52	2020-04-25	12	[{"id_menu":1,"count":1}]	18830	delivery	5	17
54547	2020-04-25 22:07:11	2020-04-25	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	4347	delivery	5	25
54548	2020-04-25 22:12:02	2020-04-25	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	6366	delivery	5	23
54549	2020-04-25 22:19:09	2020-04-25	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	546	delivery	5	26
54550	2020-04-25 22:21:17	2020-04-25	14	[{"id_menu":2,"count":1}]	18760	delivery	5	19
54551	2020-04-25 22:27:52	2020-04-25	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21590	delivery	5	46
54552	2020-04-25 22:30:27	2020-04-25	14	[{"id_menu":2,"count":1}]	21559	delivery	5	19
54553	2020-04-25 22:33:33	2020-04-25	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	15000	delivery	5	40
54554	2020-04-25 22:35:17	2020-04-25	9	[{"id_menu":7,"count":1}]	21692	delivery	5	14
54555	2020-04-25 22:35:59	2020-04-25	8	[{"id_menu":5,"count":1}]	21683	delivery	5	13
54556	2020-04-25 22:46:55	2020-04-25	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	21617	pick-up	0	26
54557	2020-04-25 22:50:59	2020-04-25	14	[{"id_menu":2,"count":1}]	7288	delivery	5	19
54558	2020-04-25 22:59:47	2020-04-25	14	[{"id_menu":2,"count":1}]	21568	delivery	5	19
54559	2020-04-25 23:00:32	2020-04-25	12	[{"id_menu":3,"count":1}]	8289	delivery	5	17
54560	2020-04-25 23:05:56	2020-04-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	21695	delivery	5	23
54561	2020-04-25 23:08:21	2020-04-25	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	21583	delivery	5	31
54562	2020-04-25 23:12:15	2020-04-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15749	delivery	5	23
54563	2020-04-25 23:14:55	2020-04-25	17	[{"id_menu":4,"count":1}]	21631	delivery	5	22
54564	2020-04-25 23:16:41	2020-04-25	9	[{"id_menu":6,"count":1}]	6172	pick-up	0	9
54565	2020-04-25 23:19:14	2020-04-25	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7526	delivery	5	36
54566	2020-04-25 23:21:57	2020-04-25	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6248	pick-up	0	23
54567	2020-04-25 23:27:11	2020-04-25	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	21620	delivery	5	39
54568	2020-04-25 23:30:07	2020-04-25	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	21602	delivery	5	26
54569	2020-04-25 23:32:31	2020-04-25	17	[{"id_menu":4,"count":1}]	21697	delivery	5	22
54570	2020-04-25 23:33:09	2020-04-25	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	644	pick-up	0	29
54571	2020-04-25 23:35:07	2020-04-25	9	[{"id_menu":6,"count":2}]	21542	delivery	5	14
54572	2020-04-25 23:36:39	2020-04-25	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	6477	delivery	5	31
54573	2020-04-25 23:40:05	2020-04-25	14	[{"id_menu":2,"count":1}]	3520	pick-up	0	14
54574	2020-04-25 23:41:01	2020-04-25	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	19107	delivery	5	26
54575	2020-04-25 23:41:40	2020-04-25	46	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	2420	pick-up	0	46
54576	2020-04-25 23:44:39	2020-04-25	9	[{"id_menu":6,"count":1}]	12387	pick-up	0	9
54577	2020-04-25 23:47:46	2020-04-25	9	[{"id_menu":6,"count":1}]	18206	delivery	5	14
54578	2020-04-25 23:48:31	2020-04-25	17	[{"id_menu":4,"count":1}]	21687	delivery	5	22
54579	2020-04-26 00:02:07	2020-04-26	9	[{"id_menu":7,"count":1}]	15426	delivery	5	14
54580	2020-04-26 00:04:06	2020-04-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6202	pick-up	0	17
54581	2020-04-26 00:04:44	2020-04-26	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	16503	delivery	5	30
54582	2020-04-26 00:04:53	2020-04-26	8	[{"id_menu":5,"count":1}]	7796	delivery	5	13
54583	2020-04-26 00:07:23	2020-04-26	12	[{"id_menu":3,"count":1}]	9934	pick-up	0	12
54584	2020-04-26 00:07:27	2020-04-26	14	[{"id_menu":2,"count":2}]	8597	delivery	5	19
54585	2020-04-26 00:10:27	2020-04-26	9	[{"id_menu":7,"count":1}]	15803	pick-up	0	9
54586	2020-04-26 00:11:14	2020-04-26	9	[{"id_menu":6,"count":1}]	8838	delivery	5	14
54587	2020-04-26 00:13:40	2020-04-26	9	[{"id_menu":7,"count":1}]	6596	delivery	5	14
54588	2020-04-26 00:14:20	2020-04-26	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	14972	pick-up	0	20
54589	2020-04-26 00:17:48	2020-04-26	12	[{"id_menu":3,"count":1}]	401	pick-up	0	12
54590	2020-04-26 00:19:05	2020-04-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13178	delivery	5	22
54591	2020-04-26 00:19:12	2020-04-26	12	[{"id_menu":3,"count":1}]	21723	pick-up	0	12
54592	2020-04-26 00:19:56	2020-04-26	9	[{"id_menu":6,"count":1}]	20756	delivery	5	14
54593	2020-04-26 00:27:51	2020-04-26	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7821	delivery	5	34
54594	2020-04-26 00:33:56	2020-04-26	9	[{"id_menu":6,"count":1}]	20941	delivery	5	14
54595	2020-04-26 00:37:48	2020-04-26	9	[{"id_menu":7,"count":1}]	2776	pick-up	0	9
54596	2020-04-26 00:38:37	2020-04-26	17	[{"id_menu":4,"count":1}]	9635	pick-up	0	17
54597	2020-04-26 00:41:29	2020-04-26	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	21713	delivery	5	27
54598	2020-04-26 00:42:02	2020-04-26	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12786	delivery	5	39
54599	2020-04-26 00:44:05	2020-04-26	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	18658	delivery	5	22
54600	2020-04-26 00:46:04	2020-04-26	9	[{"id_menu":7,"count":1}]	2845	delivery	5	14
54601	2020-04-26 00:48:17	2020-04-26	14	[{"id_menu":2,"count":1}]	21837	delivery	5	19
54602	2020-04-26 00:51:46	2020-04-26	8	[{"id_menu":5,"count":1}]	1130	pick-up	0	8
54603	2020-04-26 00:53:02	2020-04-26	9	[{"id_menu":6,"count":1}]	2536	delivery	5	14
54604	2020-04-26 00:54:24	2020-04-26	8	[{"id_menu":5,"count":1}]	21728	delivery	5	13
54605	2020-04-26 00:59:00	2020-04-26	9	[{"id_menu":6,"count":1}]	4512	pick-up	0	9
54606	2020-04-26 01:06:41	2020-04-26	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	18980	pick-up	0	20
54607	2020-04-26 01:07:11	2020-04-26	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	7387	delivery	5	23
54608	2020-04-26 01:07:28	2020-04-26	17	[{"id_menu":4,"count":1}]	4736	delivery	5	22
54609	2020-04-26 01:08:55	2020-04-26	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21808	delivery	5	34
54610	2020-04-26 01:09:48	2020-04-26	9	[{"id_menu":6,"count":1}]	21859	delivery	5	14
54611	2020-04-26 01:11:47	2020-04-26	9	[{"id_menu":6,"count":1}]	21838	delivery	5	14
54612	2020-04-26 01:13:34	2020-04-26	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	21849	delivery	5	30
54613	2020-04-26 01:14:40	2020-04-26	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21881	delivery	5	37
54614	2020-04-26 01:17:06	2020-04-26	14	[{"id_menu":2,"count":1}]	1545	pick-up	0	14
54615	2020-04-26 01:22:21	2020-04-26	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	18304	pick-up	0	23
54616	2020-04-26 01:22:22	2020-04-26	9	[{"id_menu":7,"count":2}]	13339	delivery	5	14
54617	2020-04-26 01:27:27	2020-04-26	12	[{"id_menu":3,"count":1}]	232	delivery	5	17
54618	2020-04-26 01:28:22	2020-04-26	9	[{"id_menu":7,"count":1}]	8050	delivery	5	14
54619	2020-04-26 01:33:31	2020-04-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	189	pick-up	0	17
54620	2020-04-26 01:35:46	2020-04-26	8	[{"id_menu":5,"count":1}]	18559	pick-up	0	8
54621	2020-04-26 01:36:04	2020-04-26	12	[{"id_menu":1,"count":1}]	10632	pick-up	0	12
54622	2020-04-26 01:36:24	2020-04-26	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1720	pick-up	0	44
54623	2020-04-26 01:36:50	2020-04-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11141	delivery	5	22
54624	2020-04-26 01:39:48	2020-04-26	8	[{"id_menu":5,"count":1}]	21827	delivery	5	13
54625	2020-04-26 01:42:11	2020-04-26	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14707	delivery	5	31
54626	2020-04-26 01:43:16	2020-04-26	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2182	delivery	5	34
54627	2020-04-26 01:48:58	2020-04-26	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	13634	delivery	5	26
54628	2020-04-26 01:49:16	2020-04-26	14	[{"id_menu":2,"count":1}]	456	delivery	5	19
54629	2020-04-26 01:52:24	2020-04-26	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21743	delivery	5	31
54630	2020-04-26 01:54:06	2020-04-26	8	[{"id_menu":5,"count":1}]	12107	delivery	5	13
54631	2020-04-26 01:59:31	2020-04-26	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8442	pick-up	0	34
54632	2020-04-26 02:00:04	2020-04-26	17	[{"id_menu":4,"count":1}]	17223	delivery	5	22
54633	2020-04-26 02:05:09	2020-04-26	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	13740	delivery	5	31
54634	2020-04-26 02:08:41	2020-04-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13540	delivery	5	23
54635	2020-04-26 02:10:43	2020-04-26	14	[{"id_menu":2,"count":1}]	15911	delivery	5	19
54636	2020-04-26 02:10:53	2020-04-26	14	[{"id_menu":2,"count":1}]	19720	delivery	5	19
54637	2020-04-26 02:11:46	2020-04-26	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	18751	delivery	5	25
54638	2020-04-26 02:14:39	2020-04-26	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	8295	delivery	5	26
54639	2020-04-26 02:16:27	2020-04-26	9	[{"id_menu":6,"count":3}]	19608	delivery	5	14
54640	2020-04-26 02:21:30	2020-04-26	14	[{"id_menu":2,"count":1}]	21760	delivery	5	19
54641	2020-04-26 02:23:24	2020-04-26	14	[{"id_menu":2,"count":1}]	3932	delivery	5	19
54642	2020-04-26 02:24:34	2020-04-26	14	[{"id_menu":2,"count":1}]	21758	delivery	5	19
54643	2020-04-26 02:30:12	2020-04-26	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	10073	pick-up	0	34
54644	2020-04-26 02:30:13	2020-04-26	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	5176	delivery	5	26
54645	2020-04-26 02:31:47	2020-04-26	17	[{"id_menu":4,"count":1}]	359	pick-up	0	17
54646	2020-04-26 02:32:34	2020-04-26	17	[{"id_menu":4,"count":2}]	14265	delivery	5	22
54647	2020-04-26 02:32:40	2020-04-26	9	[{"id_menu":6,"count":1}]	9440	delivery	5	14
54648	2020-04-26 02:37:51	2020-04-26	12	[{"id_menu":1,"count":1}]	20076	delivery	5	17
54649	2020-04-26 02:38:09	2020-04-26	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	7871	delivery	5	25
54650	2020-04-26 02:41:42	2020-04-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	5822	delivery	5	28
54651	2020-04-26 02:42:19	2020-04-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	18568	delivery	5	28
54652	2020-04-26 02:43:39	2020-04-26	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10362	delivery	5	39
54653	2020-04-26 02:43:44	2020-04-26	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":3}]	7627	pick-up	0	20
54654	2020-04-26 02:44:27	2020-04-26	12	[{"id_menu":3,"count":1}]	21823	delivery	5	17
54655	2020-04-26 02:45:44	2020-04-26	8	[{"id_menu":5,"count":1}]	20564	delivery	5	13
54656	2020-04-26 02:47:33	2020-04-26	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	661	delivery	5	31
54657	2020-04-26 02:56:16	2020-04-26	14	[{"id_menu":2,"count":1}]	21846	delivery	5	19
54658	2020-04-26 02:57:37	2020-04-26	9	[{"id_menu":7,"count":1}]	3755	pick-up	0	9
54659	2020-04-26 02:57:49	2020-04-26	8	[{"id_menu":5,"count":1}]	21817	delivery	5	13
54660	2020-04-26 02:58:55	2020-04-26	9	[{"id_menu":7,"count":1}]	21791	delivery	5	14
54661	2020-04-26 03:01:02	2020-04-26	8	[{"id_menu":5,"count":1}]	21778	pick-up	0	8
54662	2020-04-26 03:09:04	2020-04-26	9	[{"id_menu":6,"count":1}]	10893	pick-up	0	9
54663	2020-04-26 03:12:56	2020-04-26	8	[{"id_menu":5,"count":1}]	4946	delivery	5	13
54664	2020-04-26 03:23:15	2020-04-26	14	[{"id_menu":2,"count":1}]	21115	delivery	5	19
54665	2020-04-26 03:25:52	2020-04-26	12	[{"id_menu":3,"count":1}]	20196	delivery	5	17
54666	2020-04-26 03:28:33	2020-04-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1369	pick-up	0	17
54667	2020-04-26 03:28:45	2020-04-26	8	[{"id_menu":5,"count":2}]	21862	delivery	5	13
54668	2020-04-26 03:34:05	2020-04-26	9	[{"id_menu":6,"count":1}]	21732	pick-up	0	9
54669	2020-04-26 03:36:14	2020-04-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	21865	delivery	5	31
54670	2020-04-26 03:36:27	2020-04-26	8	[{"id_menu":5,"count":1}]	11921	delivery	5	13
54671	2020-04-26 03:42:58	2020-04-26	14	[{"id_menu":2,"count":1}]	8268	delivery	5	19
54672	2020-04-26 03:44:29	2020-04-26	8	[{"id_menu":5,"count":1}]	18445	delivery	5	13
54673	2020-04-26 03:47:39	2020-04-26	12	[{"id_menu":3,"count":1}]	14673	pick-up	0	12
54674	2020-04-26 03:50:11	2020-04-26	9	[{"id_menu":7,"count":1}]	602	delivery	5	14
54675	2020-04-26 03:52:11	2020-04-26	9	[{"id_menu":6,"count":1}]	13226	delivery	5	14
54676	2020-04-26 03:53:38	2020-04-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2905	delivery	5	28
54677	2020-04-26 04:02:05	2020-04-26	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	21822	delivery	5	43
54678	2020-04-26 04:02:18	2020-04-26	9	[{"id_menu":6,"count":1}]	21761	delivery	5	14
54679	2020-04-26 04:03:18	2020-04-26	14	[{"id_menu":2,"count":1}]	16844	delivery	5	19
54680	2020-04-26 04:04:18	2020-04-26	9	[{"id_menu":6,"count":1}]	2089	delivery	5	14
54681	2020-04-26 04:07:14	2020-04-26	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	21717	pick-up	0	24
54682	2020-04-26 04:12:45	2020-04-26	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	21867	pick-up	0	26
54683	2020-04-26 04:12:50	2020-04-26	14	[{"id_menu":2,"count":1}]	12889	pick-up	0	14
54684	2020-04-26 04:20:22	2020-04-26	9	[{"id_menu":7,"count":1}]	21768	delivery	5	14
54685	2020-04-26 04:21:02	2020-04-26	9	[{"id_menu":7,"count":1}]	9904	delivery	5	14
54686	2020-04-26 04:21:26	2020-04-26	12	[{"id_menu":3,"count":1}]	21831	delivery	5	17
54687	2020-04-26 04:25:21	2020-04-26	14	[{"id_menu":2,"count":1}]	21855	delivery	5	19
54688	2020-04-26 04:26:55	2020-04-26	9	[{"id_menu":7,"count":1}]	6469	pick-up	0	9
54689	2020-04-26 04:27:15	2020-04-26	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16952	delivery	5	43
54690	2020-04-26 04:30:48	2020-04-26	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	21774	delivery	5	30
54691	2020-04-26 04:34:11	2020-04-26	17	[{"id_menu":4,"count":1}]	21753	delivery	5	22
54692	2020-04-26 04:36:04	2020-04-26	8	[{"id_menu":5,"count":1}]	13877	delivery	5	13
54693	2020-04-26 04:36:31	2020-04-26	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	21726	delivery	5	36
54694	2020-04-26 04:37:37	2020-04-26	8	[{"id_menu":5,"count":1}]	12318	delivery	5	13
54695	2020-04-26 04:38:06	2020-04-26	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	9113	delivery	5	25
54696	2020-04-26 04:38:22	2020-04-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19840	delivery	5	22
54697	2020-04-26 04:43:00	2020-04-26	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8234	delivery	5	42
54698	2020-04-26 04:44:24	2020-04-26	8	[{"id_menu":5,"count":1}]	13843	delivery	5	13
54699	2020-04-26 04:48:55	2020-04-26	9	[{"id_menu":7,"count":2}]	21840	delivery	5	14
54700	2020-04-26 04:49:06	2020-04-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	865	pick-up	0	21
54701	2020-04-26 04:50:02	2020-04-26	12	[{"id_menu":3,"count":1}]	3056	delivery	5	17
54702	2020-04-26 04:53:23	2020-04-26	9	[{"id_menu":7,"count":1}]	21864	delivery	5	14
54703	2020-04-26 04:54:35	2020-04-26	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	8810	delivery	5	26
54704	2020-04-26 04:58:43	2020-04-26	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	21725	delivery	5	27
54705	2020-04-26 04:58:55	2020-04-26	8	[{"id_menu":5,"count":1}]	5466	delivery	5	13
54706	2020-04-26 04:59:13	2020-04-26	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	16985	delivery	5	26
54707	2020-04-26 05:12:40	2020-04-26	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	21352	pick-up	0	21
54708	2020-04-26 05:12:48	2020-04-26	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	17934	delivery	5	26
54709	2020-04-26 05:14:39	2020-04-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	21872	delivery	5	28
54710	2020-04-26 05:16:10	2020-04-26	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5708	delivery	5	43
54711	2020-04-26 05:17:34	2020-04-26	8	[{"id_menu":5,"count":1}]	128	pick-up	0	8
54712	2020-04-26 05:19:29	2020-04-26	9	[{"id_menu":7,"count":1}]	13368	delivery	5	14
54713	2020-04-26 05:21:50	2020-04-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20852	delivery	5	23
54714	2020-04-26 05:22:33	2020-04-26	9	[{"id_menu":6,"count":1}]	21032	delivery	5	14
54715	2020-04-26 05:30:52	2020-04-26	12	[{"id_menu":3,"count":1}]	21004	delivery	5	17
54716	2020-04-26 05:30:56	2020-04-26	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	10679	pick-up	0	29
54717	2020-04-26 05:34:55	2020-04-26	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	21856	delivery	5	26
54718	2020-04-26 05:35:40	2020-04-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15995	delivery	5	22
54719	2020-04-26 05:42:07	2020-04-26	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	10763	delivery	5	40
54720	2020-04-26 05:44:00	2020-04-26	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8344	delivery	5	35
54721	2020-04-26 05:45:42	2020-04-26	8	[{"id_menu":5,"count":1}]	9176	delivery	5	13
54722	2020-04-26 05:48:34	2020-04-26	9	[{"id_menu":7,"count":1}]	15977	delivery	5	14
54723	2020-04-26 05:54:11	2020-04-26	17	[{"id_menu":4,"count":1}]	11570	pick-up	0	17
54724	2020-04-26 05:55:01	2020-04-26	14	[{"id_menu":2,"count":1}]	21877	delivery	5	19
54725	2020-04-26 05:56:32	2020-04-26	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	482	delivery	5	43
54726	2020-04-26 05:56:43	2020-04-26	9	[{"id_menu":7,"count":1}]	21816	delivery	5	14
54727	2020-04-26 05:57:36	2020-04-26	17	[{"id_menu":4,"count":1}]	3314	pick-up	0	17
54728	2020-04-26 05:57:37	2020-04-26	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	9375	delivery	5	48
54729	2020-04-26 05:57:44	2020-04-26	9	[{"id_menu":6,"count":1}]	21759	delivery	5	14
54730	2020-04-26 05:58:03	2020-04-26	9	[{"id_menu":7,"count":1}]	21828	delivery	5	14
54731	2020-04-26 06:01:35	2020-04-26	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	21860	pick-up	0	21
54732	2020-04-26 06:02:00	2020-04-26	9	[{"id_menu":7,"count":1}]	21730	delivery	5	14
54733	2020-04-26 06:02:39	2020-04-26	9	[{"id_menu":6,"count":1}]	21878	delivery	5	14
54734	2020-04-26 06:04:29	2020-04-26	8	[{"id_menu":5,"count":1}]	10425	pick-up	0	8
54735	2020-04-26 06:05:28	2020-04-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	16253	delivery	5	26
54736	2020-04-26 06:06:34	2020-04-26	17	[{"id_menu":4,"count":1}]	19750	delivery	5	22
54737	2020-04-26 06:08:10	2020-04-26	9	[{"id_menu":6,"count":1}]	18755	delivery	5	14
54738	2020-04-26 06:14:12	2020-04-26	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	21536	delivery	5	31
54739	2020-04-26 06:14:23	2020-04-26	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	12387	pick-up	0	20
54740	2020-04-26 06:14:37	2020-04-26	9	[{"id_menu":7,"count":1}]	2597	delivery	5	14
54741	2020-04-26 06:16:27	2020-04-26	8	[{"id_menu":5,"count":1}]	21736	delivery	5	13
54742	2020-04-26 06:17:50	2020-04-26	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	21821	delivery	5	30
54743	2020-04-26 06:24:56	2020-04-26	8	[{"id_menu":5,"count":1}]	21709	delivery	5	13
54744	2020-04-26 06:27:53	2020-04-26	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	21873	delivery	5	44
54745	2020-04-26 06:27:56	2020-04-26	9	[{"id_menu":7,"count":1}]	6459	delivery	5	14
54746	2020-04-26 06:28:20	2020-04-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	7545	delivery	5	28
54747	2020-04-26 06:29:13	2020-04-26	9	[{"id_menu":6,"count":1}]	21847	delivery	5	14
54748	2020-04-26 06:33:28	2020-04-26	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11023	delivery	5	35
54749	2020-04-26 06:34:25	2020-04-26	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21854	delivery	5	34
54750	2020-04-26 06:35:41	2020-04-26	9	[{"id_menu":6,"count":1}]	11353	delivery	5	14
54751	2020-04-26 06:36:14	2020-04-26	8	[{"id_menu":5,"count":1}]	21870	delivery	5	13
54752	2020-04-26 06:41:37	2020-04-26	17	[{"id_menu":4,"count":1}]	17389	delivery	5	22
54753	2020-04-26 06:43:49	2020-04-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5310	delivery	5	31
54754	2020-04-26 06:45:50	2020-04-26	14	[{"id_menu":2,"count":1}]	2871	delivery	5	19
54755	2020-04-26 06:48:34	2020-04-26	9	[{"id_menu":6,"count":1}]	18332	delivery	5	14
54756	2020-04-26 06:53:14	2020-04-26	9	[{"id_menu":7,"count":1}]	16687	delivery	5	14
54757	2020-04-26 06:53:49	2020-04-26	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	21783	delivery	5	22
54758	2020-04-26 06:58:38	2020-04-26	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	21800	delivery	5	36
54759	2020-04-26 07:01:33	2020-04-26	12	[{"id_menu":1,"count":1}]	736	delivery	5	17
54760	2020-04-26 07:03:38	2020-04-26	17	[{"id_menu":4,"count":1}]	4798	pick-up	0	17
54761	2020-04-26 07:04:01	2020-04-26	14	[{"id_menu":2,"count":1}]	3373	pick-up	0	14
54762	2020-04-26 07:08:52	2020-04-26	14	[{"id_menu":2,"count":3}]	21775	delivery	5	19
54763	2020-04-26 07:11:55	2020-04-26	8	[{"id_menu":5,"count":1}]	13432	delivery	5	13
54764	2020-04-26 07:11:59	2020-04-26	14	[{"id_menu":2,"count":1}]	4356	delivery	5	19
54765	2020-04-26 07:12:18	2020-04-26	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	2079	pick-up	0	25
54766	2020-04-26 07:12:31	2020-04-26	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	21810	delivery	5	40
54767	2020-04-26 07:12:59	2020-04-26	14	[{"id_menu":2,"count":1}]	8543	pick-up	0	14
54768	2020-04-26 07:13:25	2020-04-26	12	[{"id_menu":3,"count":1}]	21807	delivery	5	17
54769	2020-04-26 07:15:10	2020-04-26	9	[{"id_menu":6,"count":1}]	9590	delivery	5	14
54770	2020-04-26 07:18:36	2020-04-26	14	[{"id_menu":2,"count":1}]	21711	pick-up	0	14
54771	2020-04-26 07:19:08	2020-04-26	9	[{"id_menu":7,"count":1}]	21788	pick-up	0	9
54772	2020-04-26 07:20:40	2020-04-26	9	[{"id_menu":6,"count":2}]	13111	delivery	5	14
54773	2020-04-26 07:22:02	2020-04-26	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	12629	delivery	5	26
54774	2020-04-26 07:26:13	2020-04-26	14	[{"id_menu":2,"count":1}]	10219	delivery	5	19
54775	2020-04-26 07:26:48	2020-04-26	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	21749	delivery	5	31
54776	2020-04-26 07:32:39	2020-04-26	14	[{"id_menu":2,"count":1}]	21239	pick-up	0	14
54777	2020-04-26 07:36:23	2020-04-26	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	21851	delivery	5	48
54778	2020-04-26 07:37:50	2020-04-26	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5075	pick-up	0	52
54779	2020-04-26 07:47:34	2020-04-26	12	[{"id_menu":1,"count":1}]	15843	delivery	5	17
54780	2020-04-26 07:52:27	2020-04-26	12	[{"id_menu":1,"count":1}]	13425	delivery	5	17
54781	2020-04-26 07:56:14	2020-04-26	9	[{"id_menu":6,"count":2}]	5376	delivery	5	14
54782	2020-04-26 07:57:46	2020-04-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13387	delivery	5	31
54783	2020-04-26 08:01:58	2020-04-26	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18412	delivery	5	31
54784	2020-04-26 08:04:46	2020-04-26	12	[{"id_menu":1,"count":1}]	13690	pick-up	0	12
54785	2020-04-26 08:06:54	2020-04-26	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3377	delivery	5	37
54786	2020-04-26 08:12:25	2020-04-26	17	[{"id_menu":4,"count":1}]	21781	delivery	5	22
54787	2020-04-26 08:21:26	2020-04-26	9	[{"id_menu":6,"count":1}]	21770	pick-up	0	9
54788	2020-04-26 08:23:12	2020-04-26	17	[{"id_menu":4,"count":1}]	8148	pick-up	0	17
54789	2020-04-26 08:23:39	2020-04-26	9	[{"id_menu":6,"count":1}]	19318	pick-up	0	9
54790	2020-04-26 08:25:31	2020-04-26	9	[{"id_menu":7,"count":1}]	4368	pick-up	0	9
54791	2020-04-26 08:26:06	2020-04-26	9	[{"id_menu":6,"count":1}]	21739	delivery	5	14
54792	2020-04-26 08:29:32	2020-04-26	9	[{"id_menu":7,"count":1}]	21735	delivery	5	14
54793	2020-04-26 08:29:38	2020-04-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	1858	pick-up	0	17
54794	2020-04-26 08:33:30	2020-04-26	14	[{"id_menu":2,"count":1}]	1700	pick-up	0	14
54795	2020-04-26 08:34:26	2020-04-26	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	6092	delivery	5	31
54796	2020-04-26 08:35:43	2020-04-26	17	[{"id_menu":4,"count":1}]	11602	delivery	5	22
54797	2020-04-26 08:36:04	2020-04-26	14	[{"id_menu":2,"count":1}]	9560	delivery	5	19
54798	2020-04-26 08:36:07	2020-04-26	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	21857	pick-up	0	26
54799	2020-04-26 08:36:18	2020-04-26	9	[{"id_menu":6,"count":1}]	365	delivery	5	14
54800	2020-04-26 08:38:14	2020-04-26	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	9141	delivery	5	36
54801	2020-04-26 08:40:08	2020-04-26	14	[{"id_menu":2,"count":2}]	15594	pick-up	0	14
54802	2020-04-26 08:41:43	2020-04-26	14	[{"id_menu":2,"count":1}]	7652	pick-up	0	14
54803	2020-04-26 08:43:29	2020-04-26	12	[{"id_menu":3,"count":1}]	15028	pick-up	0	12
54804	2020-04-26 08:43:34	2020-04-26	8	[{"id_menu":5,"count":1}]	7509	delivery	5	13
54805	2020-04-26 08:51:00	2020-04-26	14	[{"id_menu":2,"count":1}]	21833	delivery	5	19
54806	2020-04-26 08:52:30	2020-04-26	9	[{"id_menu":7,"count":1}]	2153	pick-up	0	9
54807	2020-04-26 08:53:04	2020-04-26	12	[{"id_menu":1,"count":1}]	21825	pick-up	0	12
54808	2020-04-26 08:55:55	2020-04-26	12	[{"id_menu":1,"count":1}]	21474	delivery	5	17
54809	2020-04-26 08:57:58	2020-04-26	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1352	pick-up	0	26
54810	2020-04-26 09:03:40	2020-04-26	9	[{"id_menu":7,"count":1}]	21727	pick-up	0	9
54811	2020-04-26 09:05:02	2020-04-26	9	[{"id_menu":7,"count":1}]	11493	pick-up	0	9
54812	2020-04-26 09:10:37	2020-04-26	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1505	pick-up	0	31
54813	2020-04-26 09:11:10	2020-04-26	9	[{"id_menu":6,"count":1}]	5226	delivery	5	14
54814	2020-04-26 09:19:56	2020-04-26	12	[{"id_menu":3,"count":1}]	21729	delivery	5	17
54815	2020-04-26 09:22:31	2020-04-26	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	10713	delivery	5	22
54816	2020-04-26 09:30:16	2020-04-26	9	[{"id_menu":6,"count":1}]	17719	delivery	5	14
54817	2020-04-26 09:36:23	2020-04-26	8	[{"id_menu":5,"count":1}]	21703	delivery	5	13
54818	2020-04-26 09:41:28	2020-04-26	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15105	delivery	5	31
54819	2020-04-26 09:44:21	2020-04-26	14	[{"id_menu":2,"count":1}]	21852	delivery	5	19
54820	2020-04-26 09:46:47	2020-04-26	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21871	delivery	5	31
54821	2020-04-26 09:50:09	2020-04-26	14	[{"id_menu":2,"count":2}]	20804	pick-up	0	14
54822	2020-04-26 09:52:00	2020-04-26	9	[{"id_menu":6,"count":1}]	21744	delivery	5	14
54823	2020-04-26 09:57:29	2020-04-26	12	[{"id_menu":1,"count":1}]	5047	pick-up	0	12
54824	2020-04-26 09:58:11	2020-04-26	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":2}]	3466	delivery	5	28
54825	2020-04-26 09:58:34	2020-04-26	14	[{"id_menu":2,"count":1}]	21722	delivery	5	19
54826	2020-04-26 09:59:07	2020-04-26	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	9559	delivery	5	40
54827	2020-04-26 10:00:06	2020-04-26	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2653	pick-up	0	29
54828	2020-04-26 10:00:19	2020-04-26	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	21724	delivery	5	34
54829	2020-04-26 10:04:21	2020-04-26	17	[{"id_menu":4,"count":1}]	3138	pick-up	0	17
54830	2020-04-26 10:05:12	2020-04-26	9	[{"id_menu":6,"count":2}]	21792	delivery	5	14
54831	2020-04-26 10:08:41	2020-04-26	12	[{"id_menu":1,"count":1}]	4021	pick-up	0	12
54832	2020-04-26 10:13:28	2020-04-26	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	17754	pick-up	0	21
54833	2020-04-26 10:15:52	2020-04-26	8	[{"id_menu":5,"count":1}]	6645	delivery	5	13
54834	2020-04-26 10:19:41	2020-04-26	9	[{"id_menu":7,"count":1}]	21777	delivery	5	14
54835	2020-04-26 10:27:09	2020-04-26	9	[{"id_menu":6,"count":1}]	16183	delivery	5	14
54836	2020-04-26 10:28:02	2020-04-26	9	[{"id_menu":7,"count":1}]	235	pick-up	0	9
54837	2020-04-26 10:28:22	2020-04-26	8	[{"id_menu":5,"count":1}]	5458	delivery	5	13
54838	2020-04-26 10:31:30	2020-04-26	12	[{"id_menu":3,"count":1}]	12384	delivery	5	17
54839	2020-04-26 10:36:22	2020-04-26	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	15099	delivery	5	30
54840	2020-04-26 10:36:56	2020-04-26	9	[{"id_menu":7,"count":1}]	11262	delivery	5	14
54841	2020-04-26 10:38:37	2020-04-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2158	pick-up	0	23
54842	2020-04-26 10:43:00	2020-04-26	9	[{"id_menu":6,"count":1}]	21866	delivery	5	14
54843	2020-04-26 10:47:59	2020-04-26	9	[{"id_menu":6,"count":1}]	21	delivery	5	14
54844	2020-04-26 10:48:58	2020-04-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14344	delivery	5	23
54845	2020-04-26 10:52:28	2020-04-26	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20942	delivery	5	53
54846	2020-04-26 10:54:44	2020-04-26	8	[{"id_menu":5,"count":1}]	44	pick-up	0	8
54847	2020-04-26 10:59:34	2020-04-26	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	15162	pick-up	0	25
54848	2020-04-26 11:01:42	2020-04-26	8	[{"id_menu":5,"count":1}]	19594	delivery	5	13
54849	2020-04-26 11:03:37	2020-04-26	17	[{"id_menu":4,"count":1}]	11183	pick-up	0	17
54850	2020-04-26 11:06:34	2020-04-26	12	[{"id_menu":1,"count":1}]	16647	delivery	5	17
54851	2020-04-26 11:09:27	2020-04-26	23	[{"id_menu":2,"count":3},{"id_menu":6,"count":1}]	3260	pick-up	0	23
54852	2020-04-26 11:10:26	2020-04-26	21	[{"id_menu":1,"count":3},{"id_menu":6,"count":1}]	18353	pick-up	0	21
54853	2020-04-26 11:11:43	2020-04-26	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3696	delivery	5	36
54854	2020-04-26 11:13:09	2020-04-26	12	[{"id_menu":3,"count":1}]	13656	pick-up	0	12
54855	2020-04-26 11:17:06	2020-04-26	9	[{"id_menu":6,"count":1}]	21764	delivery	5	14
54856	2020-04-26 11:19:46	2020-04-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15189	delivery	5	22
54857	2020-04-26 11:20:04	2020-04-26	14	[{"id_menu":2,"count":1}]	2590	pick-up	0	14
54858	2020-04-26 11:21:00	2020-04-26	9	[{"id_menu":7,"count":1}]	2492	pick-up	0	9
54859	2020-04-26 11:21:01	2020-04-26	17	[{"id_menu":4,"count":1}]	8779	delivery	5	22
54860	2020-04-26 11:21:10	2020-04-26	17	[{"id_menu":4,"count":1}]	14220	delivery	5	22
54861	2020-04-26 11:24:12	2020-04-26	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8250	delivery	5	52
54862	2020-04-26 11:24:32	2020-04-26	12	[{"id_menu":3,"count":1}]	6385	delivery	5	17
54863	2020-04-26 11:25:08	2020-04-26	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4009	pick-up	0	26
54864	2020-04-26 11:25:46	2020-04-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	13674	delivery	5	26
54865	2020-04-26 11:26:01	2020-04-26	8	[{"id_menu":5,"count":1}]	21885	delivery	5	13
54866	2020-04-26 11:26:28	2020-04-26	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	2190	pick-up	0	26
54867	2020-04-26 11:35:56	2020-04-26	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21769	delivery	5	36
54868	2020-04-26 11:36:58	2020-04-26	12	[{"id_menu":3,"count":1}]	5043	delivery	5	17
54869	2020-04-26 11:37:59	2020-04-26	8	[{"id_menu":5,"count":1}]	15664	delivery	5	13
54870	2020-04-26 11:49:28	2020-04-26	9	[{"id_menu":7,"count":1}]	21879	delivery	5	14
54871	2020-04-26 11:50:07	2020-04-26	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3509	pick-up	0	31
54872	2020-04-26 11:50:13	2020-04-26	12	[{"id_menu":1,"count":1}]	4139	pick-up	0	12
54873	2020-04-26 11:53:14	2020-04-26	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21875	delivery	5	34
54874	2020-04-26 11:53:56	2020-04-26	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	408	pick-up	0	29
54875	2020-04-26 11:54:50	2020-04-26	9	[{"id_menu":6,"count":1}]	21757	delivery	5	14
54876	2020-04-26 11:57:02	2020-04-26	8	[{"id_menu":5,"count":1}]	15962	delivery	5	13
54877	2020-04-26 11:57:28	2020-04-26	9	[{"id_menu":6,"count":2}]	21714	delivery	5	14
54878	2020-04-26 11:58:59	2020-04-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	21863	delivery	5	31
54879	2020-04-26 12:04:30	2020-04-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2031	pick-up	0	23
54880	2020-04-26 12:04:58	2020-04-26	9	[{"id_menu":6,"count":1}]	21869	delivery	5	14
54881	2020-04-26 12:10:15	2020-04-26	9	[{"id_menu":7,"count":1}]	16790	pick-up	0	9
54882	2020-04-26 12:12:59	2020-04-26	14	[{"id_menu":2,"count":1}]	1523	pick-up	0	14
54883	2020-04-26 12:13:42	2020-04-26	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17435	delivery	5	35
54884	2020-04-26 12:14:21	2020-04-26	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21737	pick-up	0	32
54885	2020-04-26 12:20:50	2020-04-26	9	[{"id_menu":7,"count":1}]	21814	delivery	5	14
54886	2020-04-26 12:20:52	2020-04-26	8	[{"id_menu":5,"count":1}]	6855	delivery	5	13
54887	2020-04-26 12:21:06	2020-04-26	14	[{"id_menu":2,"count":1}]	609	delivery	5	19
54888	2020-04-26 12:22:38	2020-04-26	17	[{"id_menu":4,"count":1}]	20477	delivery	5	22
54889	2020-04-26 12:24:15	2020-04-26	8	[{"id_menu":5,"count":1}]	21441	delivery	5	13
54890	2020-04-26 12:25:14	2020-04-26	9	[{"id_menu":7,"count":1}]	21779	delivery	5	14
54891	2020-04-26 12:25:40	2020-04-26	17	[{"id_menu":4,"count":1}]	21868	delivery	5	22
54892	2020-04-26 12:26:30	2020-04-26	12	[{"id_menu":1,"count":1}]	21805	delivery	5	17
54893	2020-04-26 12:28:22	2020-04-26	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	21845	pick-up	0	21
54894	2020-04-26 12:29:41	2020-04-26	12	[{"id_menu":3,"count":1}]	14800	delivery	5	17
54895	2020-04-26 12:30:18	2020-04-26	17	[{"id_menu":4,"count":1}]	7991	delivery	5	22
54896	2020-04-26 12:31:54	2020-04-26	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	16872	delivery	5	28
54897	2020-04-26 12:32:42	2020-04-26	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	21804	delivery	5	30
54898	2020-04-26 12:37:31	2020-04-26	8	[{"id_menu":5,"count":1}]	357	delivery	5	13
54899	2020-04-26 12:38:37	2020-04-26	12	[{"id_menu":1,"count":1}]	8181	delivery	5	17
54900	2020-04-26 12:47:41	2020-04-26	9	[{"id_menu":7,"count":1}]	21799	delivery	5	14
54901	2020-04-26 12:48:53	2020-04-26	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21734	delivery	5	36
54902	2020-04-26 12:50:15	2020-04-26	9	[{"id_menu":7,"count":1}]	21748	delivery	5	14
54903	2020-04-26 12:51:48	2020-04-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17152	delivery	5	22
54904	2020-04-26 12:51:52	2020-04-26	17	[{"id_menu":4,"count":1}]	21882	delivery	5	22
54905	2020-04-26 12:54:29	2020-04-26	9	[{"id_menu":6,"count":1}]	7595	pick-up	0	9
54906	2020-04-26 12:55:25	2020-04-26	9	[{"id_menu":7,"count":1}]	21884	delivery	5	14
54907	2020-04-26 12:57:46	2020-04-26	14	[{"id_menu":2,"count":1}]	17950	delivery	5	19
54908	2020-04-26 13:01:24	2020-04-26	12	[{"id_menu":1,"count":1}]	21787	delivery	5	17
54909	2020-04-26 13:04:52	2020-04-26	12	[{"id_menu":1,"count":1}]	21796	delivery	5	17
54910	2020-04-26 13:04:59	2020-04-26	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	259	delivery	5	45
54911	2020-04-26 13:05:41	2020-04-26	9	[{"id_menu":7,"count":1}]	16280	pick-up	0	9
54912	2020-04-26 13:05:53	2020-04-26	12	[{"id_menu":3,"count":1}]	21797	delivery	5	17
54913	2020-04-26 13:09:15	2020-04-26	12	[{"id_menu":1,"count":1}]	21746	delivery	5	17
54914	2020-04-26 13:11:24	2020-04-26	12	[{"id_menu":1,"count":1}]	15947	delivery	5	17
54915	2020-04-26 13:12:57	2020-04-26	9	[{"id_menu":6,"count":1}]	1744	delivery	5	14
54916	2020-04-26 13:14:39	2020-04-26	14	[{"id_menu":2,"count":1}]	11408	delivery	5	19
54917	2020-04-26 13:14:45	2020-04-26	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	19290	delivery	5	25
54918	2020-04-26 13:14:53	2020-04-26	12	[{"id_menu":1,"count":1}]	719	delivery	5	17
54919	2020-04-26 13:17:16	2020-04-26	14	[{"id_menu":2,"count":1}]	21826	delivery	5	19
54920	2020-04-26 13:24:42	2020-04-26	12	[{"id_menu":1,"count":1}]	21114	pick-up	0	12
54921	2020-04-26 13:31:44	2020-04-26	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1063	delivery	5	31
54922	2020-04-26 13:32:17	2020-04-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	21886	delivery	5	26
54923	2020-04-26 13:33:08	2020-04-26	8	[{"id_menu":5,"count":1}]	2945	delivery	5	13
54924	2020-04-26 13:35:38	2020-04-26	9	[{"id_menu":7,"count":1}]	21708	delivery	5	14
54925	2020-04-26 13:39:53	2020-04-26	12	[{"id_menu":3,"count":1}]	9802	pick-up	0	12
54926	2020-04-26 13:43:53	2020-04-26	14	[{"id_menu":2,"count":1}]	12380	delivery	5	19
54927	2020-04-26 13:44:09	2020-04-26	9	[{"id_menu":6,"count":1}]	21742	delivery	5	14
54928	2020-04-26 13:44:31	2020-04-26	8	[{"id_menu":5,"count":1}]	8880	delivery	5	13
54929	2020-04-26 13:45:47	2020-04-26	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2662	delivery	5	36
54930	2020-04-26 13:46:28	2020-04-26	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13621	delivery	5	31
54931	2020-04-26 13:47:13	2020-04-26	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	11515	delivery	5	36
54932	2020-04-26 13:49:32	2020-04-26	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	21721	delivery	5	26
54933	2020-04-26 13:49:43	2020-04-26	8	[{"id_menu":5,"count":2}]	21765	delivery	5	13
54934	2020-04-26 13:50:17	2020-04-26	9	[{"id_menu":7,"count":1}]	2579	delivery	5	14
54935	2020-04-26 13:50:20	2020-04-26	9	[{"id_menu":6,"count":1}]	19969	delivery	5	14
54936	2020-04-26 13:53:06	2020-04-26	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":3}]	21844	delivery	5	27
54937	2020-04-26 13:55:46	2020-04-26	12	[{"id_menu":3,"count":2}]	19686	delivery	5	17
54938	2020-04-26 13:55:56	2020-04-26	14	[{"id_menu":2,"count":1}]	3335	pick-up	0	14
54939	2020-04-26 13:57:07	2020-04-26	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	19506	pick-up	0	26
54940	2020-04-26 13:59:05	2020-04-26	9	[{"id_menu":6,"count":1}]	377	pick-up	0	9
54941	2020-04-26 13:59:41	2020-04-26	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21754	delivery	5	48
54942	2020-04-26 14:00:10	2020-04-26	12	[{"id_menu":1,"count":1}]	17501	pick-up	0	12
54943	2020-04-26 14:00:53	2020-04-26	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	21820	delivery	5	25
54944	2020-04-26 14:01:01	2020-04-26	12	[{"id_menu":1,"count":1}]	2339	pick-up	0	12
54945	2020-04-26 14:07:21	2020-04-26	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	14124	delivery	5	34
54946	2020-04-26 14:07:22	2020-04-26	8	[{"id_menu":5,"count":1}]	15728	delivery	5	13
54947	2020-04-26 14:14:37	2020-04-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13507	delivery	5	22
54948	2020-04-26 14:17:25	2020-04-26	8	[{"id_menu":5,"count":1}]	18879	delivery	5	13
54949	2020-04-26 14:19:51	2020-04-26	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21762	delivery	5	43
54950	2020-04-26 14:25:35	2020-04-26	12	[{"id_menu":3,"count":1}]	21809	delivery	5	17
54951	2020-04-26 14:25:40	2020-04-26	8	[{"id_menu":5,"count":1}]	21880	delivery	5	13
54952	2020-04-26 14:25:46	2020-04-26	9	[{"id_menu":6,"count":1}]	21841	pick-up	0	9
54953	2020-04-26 14:28:40	2020-04-26	17	[{"id_menu":4,"count":1}]	21801	delivery	5	22
54954	2020-04-26 14:30:35	2020-04-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2981	delivery	5	23
54955	2020-04-26 14:30:47	2020-04-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21842	delivery	5	23
54956	2020-04-26 14:32:28	2020-04-26	9	[{"id_menu":6,"count":1}]	3968	delivery	5	14
54957	2020-04-26 14:34:05	2020-04-26	9	[{"id_menu":7,"count":1}]	21835	delivery	5	14
54958	2020-04-26 14:35:01	2020-04-26	17	[{"id_menu":4,"count":1}]	10675	delivery	5	22
54959	2020-04-26 14:38:21	2020-04-26	14	[{"id_menu":2,"count":1}]	6600	delivery	5	19
54960	2020-04-26 14:51:37	2020-04-26	9	[{"id_menu":6,"count":1}]	1900	pick-up	0	9
54961	2020-04-26 14:53:03	2020-04-26	9	[{"id_menu":6,"count":1}]	6164	pick-up	0	9
54962	2020-04-26 14:54:07	2020-04-26	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	1239	pick-up	0	18
54963	2020-04-26 14:57:30	2020-04-26	9	[{"id_menu":7,"count":1}]	14256	delivery	5	14
54964	2020-04-26 15:01:19	2020-04-26	8	[{"id_menu":5,"count":2}]	21767	delivery	5	13
54965	2020-04-26 15:03:41	2020-04-26	17	[{"id_menu":4,"count":1}]	10598	pick-up	0	17
54966	2020-04-26 15:04:21	2020-04-26	9	[{"id_menu":7,"count":1}]	12704	delivery	5	14
54967	2020-04-26 15:04:30	2020-04-26	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	19981	delivery	5	40
54968	2020-04-26 15:04:37	2020-04-26	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	21718	delivery	5	26
54969	2020-04-26 15:04:44	2020-04-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2972	delivery	5	23
54970	2020-04-26 15:06:14	2020-04-26	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8298	pick-up	0	29
54971	2020-04-26 15:07:33	2020-04-26	9	[{"id_menu":7,"count":1}]	16755	delivery	5	14
54972	2020-04-26 15:08:30	2020-04-26	14	[{"id_menu":2,"count":1}]	2956	delivery	5	19
54973	2020-04-26 15:12:37	2020-04-26	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	9082	pick-up	0	21
54974	2020-04-26 15:19:15	2020-04-26	14	[{"id_menu":2,"count":1}]	10393	pick-up	0	14
54975	2020-04-26 15:32:02	2020-04-26	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21832	delivery	5	36
54976	2020-04-26 15:33:48	2020-04-26	12	[{"id_menu":3,"count":1}]	9520	delivery	5	17
54977	2020-04-26 15:40:58	2020-04-26	9	[{"id_menu":6,"count":1}]	21745	delivery	5	14
54978	2020-04-26 15:41:34	2020-04-26	9	[{"id_menu":7,"count":1}]	21733	pick-up	0	9
54979	2020-04-26 15:46:05	2020-04-26	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2971	pick-up	0	21
54980	2020-04-26 15:49:01	2020-04-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17428	delivery	5	23
54981	2020-04-26 15:52:17	2020-04-26	12	[{"id_menu":1,"count":1}]	19974	pick-up	0	12
54982	2020-04-26 15:54:52	2020-04-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	3940	delivery	5	26
54983	2020-04-26 15:55:12	2020-04-26	9	[{"id_menu":7,"count":1}]	21633	delivery	5	14
54984	2020-04-26 15:57:31	2020-04-26	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	21386	delivery	5	42
54985	2020-04-26 15:59:42	2020-04-26	14	[{"id_menu":2,"count":1}]	11130	delivery	5	19
54986	2020-04-26 16:02:18	2020-04-26	9	[{"id_menu":6,"count":1}]	21874	pick-up	0	9
54987	2020-04-26 16:04:12	2020-04-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	16289	delivery	5	26
54988	2020-04-26 16:04:17	2020-04-26	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19467	delivery	5	31
54989	2020-04-26 16:18:57	2020-04-26	9	[{"id_menu":7,"count":1}]	9281	delivery	5	14
54990	2020-04-26 16:19:00	2020-04-26	14	[{"id_menu":2,"count":1}]	21747	delivery	5	19
54991	2020-04-26 16:20:14	2020-04-26	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	457	delivery	5	31
54992	2020-04-26 16:22:17	2020-04-26	9	[{"id_menu":7,"count":1}]	2420	pick-up	0	9
54993	2020-04-26 16:23:18	2020-04-26	12	[{"id_menu":1,"count":1}]	11616	delivery	5	17
54994	2020-04-26 16:24:44	2020-04-26	8	[{"id_menu":5,"count":1}]	21771	delivery	5	13
54995	2020-04-26 16:25:10	2020-04-26	8	[{"id_menu":5,"count":1}]	1095	pick-up	0	8
54996	2020-04-26 16:32:35	2020-04-26	9	[{"id_menu":7,"count":1}]	6366	delivery	5	14
54997	2020-04-26 16:34:20	2020-04-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	4414	pick-up	0	21
54998	2020-04-26 16:35:30	2020-04-26	8	[{"id_menu":5,"count":1}]	21780	delivery	5	13
54999	2020-04-26 16:36:08	2020-04-26	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	21888	delivery	5	45
55000	2020-04-26 16:36:54	2020-04-26	12	[{"id_menu":1,"count":1}]	16239	delivery	5	17
55001	2020-04-26 16:37:52	2020-04-26	9	[{"id_menu":7,"count":2}]	4855	delivery	5	14
55002	2020-04-26 16:39:13	2020-04-26	9	[{"id_menu":7,"count":1}]	2415	pick-up	0	9
55003	2020-04-26 16:40:37	2020-04-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21719	delivery	5	22
55004	2020-04-26 16:42:01	2020-04-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":3}]	21819	delivery	5	22
55005	2020-04-26 16:52:42	2020-04-26	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	13639	delivery	5	25
55006	2020-04-26 16:55:26	2020-04-26	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1616	pick-up	0	22
55007	2020-04-26 16:57:41	2020-04-26	9	[{"id_menu":7,"count":1}]	15455	delivery	5	14
55008	2020-04-26 17:02:38	2020-04-26	14	[{"id_menu":2,"count":2}]	634	pick-up	0	14
55009	2020-04-26 17:03:45	2020-04-26	17	[{"id_menu":4,"count":1}]	18539	delivery	5	22
55010	2020-04-26 17:06:35	2020-04-26	17	[{"id_menu":4,"count":1}]	3155	pick-up	0	17
55011	2020-04-26 17:09:10	2020-04-26	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	21850	delivery	5	35
55012	2020-04-26 17:09:13	2020-04-26	14	[{"id_menu":2,"count":1}]	7872	delivery	5	19
55013	2020-04-26 17:10:24	2020-04-26	9	[{"id_menu":7,"count":1}]	12522	delivery	5	14
55014	2020-04-26 17:10:30	2020-04-26	12	[{"id_menu":1,"count":1}]	21716	delivery	5	17
55015	2020-04-26 17:11:53	2020-04-26	9	[{"id_menu":7,"count":1}]	21834	delivery	5	14
55016	2020-04-26 17:16:27	2020-04-26	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	15781	pick-up	0	25
55017	2020-04-26 17:19:08	2020-04-26	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	21509	pick-up	0	22
55018	2020-04-26 17:21:05	2020-04-26	9	[{"id_menu":6,"count":1}]	4313	delivery	5	14
55019	2020-04-26 17:23:16	2020-04-26	9	[{"id_menu":6,"count":1}]	21784	delivery	5	14
55020	2020-04-26 17:24:52	2020-04-26	12	[{"id_menu":3,"count":1}]	7053	pick-up	0	12
55021	2020-04-26 17:26:27	2020-04-26	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	21876	delivery	5	25
55022	2020-04-26 17:34:04	2020-04-26	9	[{"id_menu":7,"count":1}]	21756	delivery	5	14
55023	2020-04-26 17:35:55	2020-04-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	21751	delivery	5	28
55024	2020-04-26 17:38:27	2020-04-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1810	delivery	5	28
55025	2020-04-26 17:41:31	2020-04-26	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	13236	delivery	5	42
55026	2020-04-26 17:42:46	2020-04-26	14	[{"id_menu":2,"count":1}]	21772	delivery	5	19
55027	2020-04-26 17:42:57	2020-04-26	9	[{"id_menu":7,"count":1}]	19817	delivery	5	14
55028	2020-04-26 17:43:43	2020-04-26	8	[{"id_menu":5,"count":1}]	21710	delivery	5	13
55029	2020-04-26 17:44:09	2020-04-26	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	21773	delivery	5	31
55030	2020-04-26 17:51:27	2020-04-26	9	[{"id_menu":7,"count":2}]	10695	delivery	5	14
55031	2020-04-26 17:52:48	2020-04-26	12	[{"id_menu":1,"count":1}]	3871	pick-up	0	12
55032	2020-04-26 17:55:08	2020-04-26	12	[{"id_menu":3,"count":1}]	3604	delivery	5	17
55033	2020-04-26 17:55:45	2020-04-26	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	21752	delivery	5	26
55034	2020-04-26 17:56:11	2020-04-26	8	[{"id_menu":5,"count":1}]	21806	pick-up	0	8
55035	2020-04-26 17:58:24	2020-04-26	8	[{"id_menu":5,"count":1}]	9203	delivery	5	13
55036	2020-04-26 18:00:25	2020-04-26	8	[{"id_menu":5,"count":1}]	2309	pick-up	0	8
55037	2020-04-26 18:01:13	2020-04-26	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	21818	delivery	5	48
55038	2020-04-26 18:07:36	2020-04-26	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	18159	delivery	5	28
55039	2020-04-26 18:14:56	2020-04-26	14	[{"id_menu":2,"count":1}]	511	delivery	5	19
55040	2020-04-26 18:16:02	2020-04-26	14	[{"id_menu":2,"count":1}]	16578	delivery	5	19
55041	2020-04-26 18:16:47	2020-04-26	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	21890	delivery	5	43
55042	2020-04-26 18:16:50	2020-04-26	9	[{"id_menu":6,"count":1}]	21858	delivery	5	14
55043	2020-04-26 18:18:16	2020-04-26	17	[{"id_menu":4,"count":1}]	21891	delivery	5	22
55044	2020-04-26 18:28:58	2020-04-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21793	delivery	5	22
55045	2020-04-26 18:31:22	2020-04-26	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	21887	delivery	5	34
55046	2020-04-26 18:32:27	2020-04-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4710	delivery	5	22
55047	2020-04-26 18:34:46	2020-04-26	9	[{"id_menu":6,"count":1}]	4143	delivery	5	14
55048	2020-04-26 18:38:55	2020-04-26	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	18016	delivery	5	31
55049	2020-04-26 18:39:34	2020-04-26	8	[{"id_menu":5,"count":1}]	7086	pick-up	0	8
55050	2020-04-26 18:46:25	2020-04-26	9	[{"id_menu":7,"count":2}]	19502	delivery	5	14
55051	2020-04-26 18:49:40	2020-04-26	8	[{"id_menu":5,"count":1}]	5286	pick-up	0	8
55052	2020-04-26 18:51:29	2020-04-26	17	[{"id_menu":4,"count":1}]	7522	delivery	5	22
55053	2020-04-26 18:55:55	2020-04-26	17	[{"id_menu":4,"count":1}]	17814	pick-up	0	17
55054	2020-04-26 18:56:55	2020-04-26	14	[{"id_menu":2,"count":1}]	16428	delivery	5	19
55055	2020-04-26 18:57:17	2020-04-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8212	delivery	5	28
55056	2020-04-26 18:57:42	2020-04-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13596	delivery	5	31
55057	2020-04-26 18:59:41	2020-04-26	17	[{"id_menu":4,"count":1}]	17423	pick-up	0	17
55058	2020-04-26 19:07:13	2020-04-26	17	[{"id_menu":4,"count":1}]	1289	pick-up	0	17
55059	2020-04-26 19:09:49	2020-04-26	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21861	delivery	5	34
55060	2020-04-26 19:15:04	2020-04-26	14	[{"id_menu":2,"count":1}]	10921	delivery	5	19
55061	2020-04-26 19:20:39	2020-04-26	17	[{"id_menu":4,"count":1}]	9575	pick-up	0	17
55062	2020-04-26 19:20:53	2020-04-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	19011	pick-up	0	23
55063	2020-04-26 19:23:11	2020-04-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14411	delivery	5	22
55064	2020-04-26 19:23:45	2020-04-26	12	[{"id_menu":3,"count":1}]	21803	pick-up	0	12
55065	2020-04-26 19:25:57	2020-04-26	9	[{"id_menu":6,"count":1}]	9950	delivery	5	14
55066	2020-04-26 19:25:58	2020-04-26	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	593	pick-up	0	40
55067	2020-04-26 19:27:13	2020-04-26	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	9246	delivery	5	34
55068	2020-04-26 19:28:01	2020-04-26	8	[{"id_menu":5,"count":1}]	21824	delivery	5	13
55069	2020-04-26 19:30:21	2020-04-26	8	[{"id_menu":5,"count":1}]	10192	delivery	5	13
55070	2020-04-26 19:32:00	2020-04-26	17	[{"id_menu":4,"count":1}]	21853	delivery	5	22
55071	2020-04-26 19:35:54	2020-04-26	9	[{"id_menu":7,"count":1}]	21766	delivery	5	14
55072	2020-04-26 19:38:10	2020-04-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	21782	delivery	5	26
55073	2020-04-26 19:50:55	2020-04-26	17	[{"id_menu":4,"count":1}]	21795	pick-up	0	17
55074	2020-04-26 19:54:27	2020-04-26	12	[{"id_menu":3,"count":1}]	21811	delivery	5	17
55075	2020-04-26 20:00:00	2020-04-26	9	[{"id_menu":7,"count":1}]	18148	delivery	5	14
55076	2020-04-26 20:08:10	2020-04-26	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	15069	delivery	5	42
55077	2020-04-26 20:11:25	2020-04-26	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	2119	delivery	5	31
55078	2020-04-26 20:12:47	2020-04-26	8	[{"id_menu":5,"count":1}]	11198	pick-up	0	8
55079	2020-04-26 20:20:00	2020-04-26	14	[{"id_menu":2,"count":1}]	528	delivery	5	19
55080	2020-04-26 20:22:09	2020-04-26	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	15930	delivery	5	45
55081	2020-04-26 20:23:03	2020-04-26	20	[{"id_menu":3,"count":3},{"id_menu":5,"count":1}]	15180	delivery	5	25
55082	2020-04-26 20:23:11	2020-04-26	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19459	delivery	5	39
55083	2020-04-26 20:25:08	2020-04-26	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	21578	delivery	5	31
55084	2020-04-26 20:28:56	2020-04-26	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	8508	delivery	5	26
55085	2020-04-26 20:29:53	2020-04-26	9	[{"id_menu":6,"count":1}]	21786	pick-up	0	9
55086	2020-04-26 20:38:12	2020-04-26	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3863	delivery	5	36
55087	2020-04-26 20:40:26	2020-04-26	9	[{"id_menu":6,"count":1}]	5663	delivery	5	14
55088	2020-04-26 20:45:11	2020-04-26	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14662	pick-up	0	35
55089	2020-04-26 20:45:50	2020-04-26	12	[{"id_menu":1,"count":1}]	14395	delivery	5	17
55090	2020-04-26 20:47:35	2020-04-26	12	[{"id_menu":3,"count":1}]	21763	pick-up	0	12
55091	2020-04-26 20:50:02	2020-04-26	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21830	delivery	5	40
55092	2020-04-26 20:50:12	2020-04-26	9	[{"id_menu":6,"count":1}]	21738	delivery	5	14
55093	2020-04-26 20:52:37	2020-04-26	8	[{"id_menu":5,"count":1}]	21785	delivery	5	13
55094	2020-04-26 20:55:21	2020-04-26	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19229	delivery	5	35
55095	2020-04-26 21:01:31	2020-04-26	8	[{"id_menu":5,"count":1}]	14230	delivery	5	13
55096	2020-04-26 21:01:56	2020-04-26	8	[{"id_menu":5,"count":1}]	15161	delivery	5	13
55097	2020-04-26 21:03:13	2020-04-26	12	[{"id_menu":3,"count":1}]	2933	pick-up	0	12
55098	2020-04-26 21:05:22	2020-04-26	8	[{"id_menu":5,"count":2}]	21839	pick-up	0	8
55099	2020-04-26 21:06:53	2020-04-26	9	[{"id_menu":7,"count":1}]	5405	delivery	5	14
55100	2020-04-26 21:10:50	2020-04-26	9	[{"id_menu":7,"count":1}]	11417	delivery	5	14
55101	2020-04-26 21:13:49	2020-04-26	9	[{"id_menu":7,"count":1}]	21798	delivery	5	14
55102	2020-04-26 21:16:36	2020-04-26	14	[{"id_menu":2,"count":1}]	266	pick-up	0	14
55103	2020-04-26 21:20:07	2020-04-26	9	[{"id_menu":6,"count":1}]	9976	delivery	5	14
55104	2020-04-26 21:27:53	2020-04-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21802	delivery	5	23
55105	2020-04-26 21:28:46	2020-04-26	9	[{"id_menu":6,"count":1}]	11758	delivery	5	14
55106	2020-04-26 21:33:44	2020-04-26	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	8552	delivery	5	25
55107	2020-04-26 21:35:26	2020-04-26	9	[{"id_menu":6,"count":1}]	13485	delivery	5	14
55108	2020-04-26 21:35:36	2020-04-26	9	[{"id_menu":7,"count":1}]	6874	delivery	5	14
55109	2020-04-26 21:36:54	2020-04-26	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":2}]	19523	pick-up	0	20
55110	2020-04-26 21:39:29	2020-04-26	9	[{"id_menu":6,"count":1}]	14260	delivery	5	14
55111	2020-04-26 21:41:09	2020-04-26	17	[{"id_menu":4,"count":1}]	21435	delivery	5	22
55112	2020-04-26 21:41:25	2020-04-26	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	5850	delivery	5	26
55113	2020-04-26 21:45:43	2020-04-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	15194	pick-up	0	23
55114	2020-04-26 21:45:44	2020-04-26	17	[{"id_menu":4,"count":1}]	20628	pick-up	0	17
55115	2020-04-26 21:45:54	2020-04-26	17	[{"id_menu":4,"count":1}]	3241	pick-up	0	17
55116	2020-04-26 21:48:37	2020-04-26	8	[{"id_menu":5,"count":1}]	7046	pick-up	0	8
55117	2020-04-26 21:49:06	2020-04-26	14	[{"id_menu":2,"count":1}]	21485	pick-up	0	14
55118	2020-04-26 21:50:47	2020-04-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	18379	delivery	5	26
55119	2020-04-26 21:50:53	2020-04-26	12	[{"id_menu":1,"count":1}]	3271	pick-up	0	12
55120	2020-04-26 21:51:00	2020-04-26	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21720	delivery	5	52
55121	2020-04-26 21:51:02	2020-04-26	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	6819	delivery	5	25
55122	2020-04-26 21:51:28	2020-04-26	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	19857	delivery	5	34
55123	2020-04-26 21:53:56	2020-04-26	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	2277	pick-up	0	26
55124	2020-04-26 21:57:41	2020-04-26	9	[{"id_menu":6,"count":1}]	21836	delivery	5	14
55125	2020-04-26 22:04:39	2020-04-26	9	[{"id_menu":6,"count":1}]	19270	delivery	5	14
55126	2020-04-26 22:04:58	2020-04-26	12	[{"id_menu":1,"count":1}]	21790	delivery	5	17
55127	2020-04-26 22:06:08	2020-04-26	9	[{"id_menu":7,"count":1}]	4770	pick-up	0	9
55128	2020-04-26 22:07:24	2020-04-26	17	[{"id_menu":4,"count":1}]	21883	pick-up	0	17
55129	2020-04-26 22:07:47	2020-04-26	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	14237	delivery	5	25
55130	2020-04-26 22:15:25	2020-04-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	21712	delivery	5	26
55131	2020-04-26 22:17:16	2020-04-26	14	[{"id_menu":2,"count":1}]	21889	delivery	5	19
55132	2020-04-26 22:23:33	2020-04-26	9	[{"id_menu":7,"count":1}]	7306	delivery	5	14
55133	2020-04-26 22:24:05	2020-04-26	14	[{"id_menu":2,"count":1}]	4097	pick-up	0	14
55134	2020-04-26 22:25:32	2020-04-26	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	21715	delivery	5	39
55135	2020-04-26 22:29:28	2020-04-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	12532	pick-up	0	21
55136	2020-04-26 22:32:10	2020-04-26	8	[{"id_menu":5,"count":1}]	6140	delivery	5	13
55137	2020-04-26 22:38:09	2020-04-26	17	[{"id_menu":4,"count":2}]	21740	delivery	5	22
55138	2020-04-26 22:39:16	2020-04-26	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2298	delivery	5	51
55139	2020-04-26 22:39:27	2020-04-26	9	[{"id_menu":7,"count":1}]	21794	delivery	5	14
55140	2020-04-26 22:45:51	2020-04-26	14	[{"id_menu":2,"count":1}]	21755	delivery	5	19
55141	2020-04-26 22:46:48	2020-04-26	9	[{"id_menu":7,"count":1}]	3578	pick-up	0	9
55142	2020-04-26 22:47:22	2020-04-26	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	8406	delivery	5	27
55143	2020-04-26 22:50:08	2020-04-26	9	[{"id_menu":6,"count":1}]	21741	delivery	5	14
55144	2020-04-26 22:53:42	2020-04-26	12	[{"id_menu":1,"count":1}]	16301	pick-up	0	12
55145	2020-04-26 22:53:47	2020-04-26	17	[{"id_menu":4,"count":1}]	12474	delivery	5	22
55146	2020-04-26 22:55:01	2020-04-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	21843	delivery	5	28
55147	2020-04-26 22:55:30	2020-04-26	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	18475	delivery	5	26
55148	2020-04-26 23:02:53	2020-04-26	9	[{"id_menu":7,"count":1}]	21789	delivery	5	14
55149	2020-04-26 23:04:03	2020-04-26	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	20144	delivery	5	31
55150	2020-04-26 23:05:31	2020-04-26	12	[{"id_menu":1,"count":1}]	21731	delivery	5	17
55151	2020-04-26 23:05:38	2020-04-26	9	[{"id_menu":6,"count":1}]	18459	delivery	5	14
55152	2020-04-26 23:06:24	2020-04-26	17	[{"id_menu":4,"count":1}]	191	pick-up	0	17
55153	2020-04-26 23:10:33	2020-04-26	8	[{"id_menu":5,"count":3}]	18066	delivery	5	13
55154	2020-04-26 23:13:02	2020-04-26	14	[{"id_menu":2,"count":1}]	21750	delivery	5	19
55155	2020-04-26 23:14:11	2020-04-26	17	[{"id_menu":4,"count":1}]	1021	pick-up	0	17
55156	2020-04-26 23:14:22	2020-04-26	9	[{"id_menu":7,"count":1}]	891	pick-up	0	9
55157	2020-04-26 23:14:48	2020-04-26	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21848	delivery	5	43
55158	2020-04-26 23:15:12	2020-04-26	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2231	pick-up	0	43
55159	2020-04-26 23:16:37	2020-04-26	9	[{"id_menu":6,"count":1}]	21813	delivery	5	14
55160	2020-04-26 23:22:55	2020-04-26	14	[{"id_menu":2,"count":1}]	21707	delivery	5	19
55161	2020-04-26 23:28:11	2020-04-26	12	[{"id_menu":1,"count":1}]	1375	pick-up	0	12
55162	2020-04-26 23:29:06	2020-04-26	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18348	pick-up	0	35
55163	2020-04-26 23:30:04	2020-04-26	8	[{"id_menu":5,"count":1}]	12692	delivery	5	13
55164	2020-04-26 23:30:32	2020-04-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	21776	delivery	5	28
55165	2020-04-26 23:31:43	2020-04-26	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	14660	delivery	5	56
55166	2020-04-26 23:31:56	2020-04-26	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	13958	delivery	5	34
55167	2020-04-26 23:45:34	2020-04-26	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	12168	delivery	5	40
55168	2020-04-26 23:46:41	2020-04-26	9	[{"id_menu":6,"count":1}]	5129	delivery	5	14
55169	2020-04-26 23:47:19	2020-04-26	17	[{"id_menu":4,"count":1}]	21815	delivery	5	22
55170	2020-04-26 23:49:11	2020-04-26	8	[{"id_menu":5,"count":1}]	11513	delivery	5	13
55171	2020-04-26 23:49:48	2020-04-26	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	14795	delivery	5	25
55172	2020-04-26 23:53:59	2020-04-26	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	14616	pick-up	0	31
55173	2020-04-26 23:56:27	2020-04-26	14	[{"id_menu":2,"count":1}]	21812	delivery	5	19
55174	2020-04-26 23:57:13	2020-04-26	14	[{"id_menu":2,"count":1}]	16309	pick-up	0	14
55175	2020-04-26 23:57:18	2020-04-26	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9344	delivery	5	35
55176	2020-04-26 23:58:26	2020-04-26	12	[{"id_menu":1,"count":1}]	2663	delivery	5	17
55177	2020-04-26 23:58:32	2020-04-26	17	[{"id_menu":4,"count":1}]	21829	delivery	5	22
55178	2020-04-27 00:00:47	2020-04-27	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5251	delivery	5	34
55179	2020-04-27 00:23:52	2020-04-27	9	[{"id_menu":6,"count":1}]	5544	delivery	5	14
55180	2020-04-27 00:24:32	2020-04-27	12	[{"id_menu":1,"count":1}]	12695	delivery	5	17
55181	2020-04-27 00:28:00	2020-04-27	9	[{"id_menu":6,"count":1}]	14146	pick-up	0	9
55182	2020-04-27 00:31:31	2020-04-27	9	[{"id_menu":7,"count":1}]	1219	delivery	5	14
55183	2020-04-27 00:33:15	2020-04-27	12	[{"id_menu":3,"count":1}]	16204	delivery	5	17
55184	2020-04-27 00:34:59	2020-04-27	12	[{"id_menu":1,"count":1}]	17582	delivery	5	17
55185	2020-04-27 00:36:04	2020-04-27	17	[{"id_menu":4,"count":1}]	21903	delivery	5	22
55186	2020-04-27 00:43:18	2020-04-27	9	[{"id_menu":6,"count":1}]	11379	delivery	5	14
55187	2020-04-27 01:04:30	2020-04-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6499	delivery	5	36
55188	2020-04-27 01:13:13	2020-04-27	14	[{"id_menu":2,"count":1}]	12503	delivery	5	19
55189	2020-04-27 01:14:19	2020-04-27	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11789	delivery	5	22
55190	2020-04-27 01:14:56	2020-04-27	17	[{"id_menu":4,"count":2}]	22021	pick-up	0	17
55191	2020-04-27 01:17:42	2020-04-27	8	[{"id_menu":5,"count":1}]	19921	delivery	5	13
55192	2020-04-27 01:21:57	2020-04-27	9	[{"id_menu":6,"count":1}]	21919	delivery	5	14
55193	2020-04-27 01:24:11	2020-04-27	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18948	delivery	5	34
55194	2020-04-27 01:25:28	2020-04-27	9	[{"id_menu":6,"count":2}]	21926	delivery	5	14
55195	2020-04-27 01:30:17	2020-04-27	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	8651	delivery	5	31
55196	2020-04-27 01:41:38	2020-04-27	14	[{"id_menu":2,"count":1}]	8339	delivery	5	19
55197	2020-04-27 01:52:26	2020-04-27	9	[{"id_menu":6,"count":1}]	16098	delivery	5	14
55198	2020-04-27 01:55:05	2020-04-27	14	[{"id_menu":2,"count":1}]	5935	delivery	5	19
55199	2020-04-27 02:02:44	2020-04-27	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	21952	delivery	5	35
55200	2020-04-27 02:21:39	2020-04-27	14	[{"id_menu":2,"count":1}]	21899	pick-up	0	14
55201	2020-04-27 02:32:36	2020-04-27	17	[{"id_menu":4,"count":1}]	3651	pick-up	0	17
55202	2020-04-27 02:38:16	2020-04-27	8	[{"id_menu":5,"count":1}]	2721	delivery	5	13
55203	2020-04-27 02:39:51	2020-04-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	21917	delivery	5	23
55204	2020-04-27 02:46:33	2020-04-27	14	[{"id_menu":2,"count":2}]	8298	pick-up	0	14
55205	2020-04-27 02:50:22	2020-04-27	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6347	delivery	5	48
55206	2020-04-27 02:55:28	2020-04-27	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3092	pick-up	0	26
55207	2020-04-27 02:56:23	2020-04-27	17	[{"id_menu":4,"count":1}]	15031	delivery	5	22
55208	2020-04-27 02:58:51	2020-04-27	9	[{"id_menu":6,"count":1}]	3010	pick-up	0	9
55209	2020-04-27 03:32:12	2020-04-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	14165	delivery	5	28
55210	2020-04-27 03:34:13	2020-04-27	14	[{"id_menu":2,"count":1}]	12380	delivery	5	19
55211	2020-04-27 03:36:25	2020-04-27	14	[{"id_menu":2,"count":1}]	9523	pick-up	0	14
55212	2020-04-27 03:41:37	2020-04-27	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	11241	delivery	5	27
55213	2020-04-27 03:41:42	2020-04-27	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	16272	delivery	5	34
55214	2020-04-27 03:42:16	2020-04-27	9	[{"id_menu":6,"count":1}]	8300	pick-up	0	9
55215	2020-04-27 03:44:34	2020-04-27	12	[{"id_menu":3,"count":1}]	6627	delivery	5	17
55216	2020-04-27 03:50:01	2020-04-27	12	[{"id_menu":3,"count":1}]	22005	delivery	5	17
55217	2020-04-27 03:53:09	2020-04-27	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	7952	delivery	5	48
55218	2020-04-27 03:56:59	2020-04-27	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	19820	delivery	5	25
55219	2020-04-27 04:06:36	2020-04-27	12	[{"id_menu":3,"count":1}]	21958	delivery	5	17
55220	2020-04-27 04:25:53	2020-04-27	14	[{"id_menu":2,"count":2}]	15388	pick-up	0	14
55221	2020-04-27 04:26:29	2020-04-27	9	[{"id_menu":6,"count":1}]	21907	delivery	5	14
55222	2020-04-27 04:26:53	2020-04-27	12	[{"id_menu":3,"count":1}]	1929	delivery	5	17
55223	2020-04-27 04:28:02	2020-04-27	9	[{"id_menu":7,"count":1}]	19701	delivery	5	14
55224	2020-04-27 04:28:36	2020-04-27	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	16678	pick-up	0	22
55225	2020-04-27 04:31:46	2020-04-27	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	10983	pick-up	0	26
55226	2020-04-27 04:33:13	2020-04-27	17	[{"id_menu":4,"count":1}]	8350	pick-up	0	17
55227	2020-04-27 04:43:47	2020-04-27	12	[{"id_menu":3,"count":1}]	2237	pick-up	0	12
55228	2020-04-27 04:48:30	2020-04-27	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	19566	delivery	5	37
55229	2020-04-27 04:49:19	2020-04-27	8	[{"id_menu":5,"count":1}]	21263	pick-up	0	8
55230	2020-04-27 05:09:21	2020-04-27	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	8589	delivery	5	48
55231	2020-04-27 05:16:34	2020-04-27	12	[{"id_menu":3,"count":1}]	22018	delivery	5	17
55232	2020-04-27 05:24:37	2020-04-27	9	[{"id_menu":7,"count":1}]	9714	pick-up	0	9
55233	2020-04-27 05:33:07	2020-04-27	14	[{"id_menu":2,"count":1}]	21895	delivery	5	19
55234	2020-04-27 05:33:09	2020-04-27	17	[{"id_menu":4,"count":1}]	7383	pick-up	0	17
55235	2020-04-27 05:39:35	2020-04-27	9	[{"id_menu":7,"count":1}]	1562	delivery	5	14
55236	2020-04-27 05:45:06	2020-04-27	12	[{"id_menu":3,"count":1}]	2190	delivery	5	17
55237	2020-04-27 05:45:36	2020-04-27	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	20528	delivery	5	23
55238	2020-04-27 05:51:16	2020-04-27	12	[{"id_menu":3,"count":1}]	1689	pick-up	0	12
55239	2020-04-27 05:53:41	2020-04-27	12	[{"id_menu":3,"count":2}]	12855	delivery	5	17
55240	2020-04-27 05:54:12	2020-04-27	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	203	pick-up	0	21
55241	2020-04-27 05:56:15	2020-04-27	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	8834	delivery	5	31
55242	2020-04-27 06:08:50	2020-04-27	9	[{"id_menu":6,"count":1}]	3595	pick-up	0	9
55243	2020-04-27 06:09:03	2020-04-27	9	[{"id_menu":7,"count":1}]	21947	pick-up	0	9
55244	2020-04-27 06:20:12	2020-04-27	8	[{"id_menu":5,"count":1}]	21580	delivery	5	13
55245	2020-04-27 06:23:34	2020-04-27	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":2}]	9449	delivery	5	36
55246	2020-04-27 06:29:23	2020-04-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	17910	delivery	5	28
55247	2020-04-27 06:40:31	2020-04-27	12	[{"id_menu":3,"count":1}]	2715	delivery	5	17
55248	2020-04-27 06:42:12	2020-04-27	14	[{"id_menu":2,"count":2}]	5773	delivery	5	19
55249	2020-04-27 06:43:42	2020-04-27	9	[{"id_menu":7,"count":1}]	11832	delivery	5	14
55250	2020-04-27 06:46:11	2020-04-27	12	[{"id_menu":1,"count":1}]	22002	delivery	5	17
55251	2020-04-27 06:49:07	2020-04-27	9	[{"id_menu":7,"count":1}]	4892	delivery	5	14
55252	2020-04-27 07:00:27	2020-04-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	22028	delivery	5	28
55253	2020-04-27 07:05:22	2020-04-27	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8382	delivery	5	39
55254	2020-04-27 07:09:09	2020-04-27	9	[{"id_menu":6,"count":1}]	12396	delivery	5	14
55255	2020-04-27 07:10:51	2020-04-27	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	20215	delivery	5	31
55256	2020-04-27 07:13:38	2020-04-27	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15032	delivery	5	37
55257	2020-04-27 07:13:57	2020-04-27	8	[{"id_menu":5,"count":1}]	21932	delivery	5	13
55258	2020-04-27 07:17:59	2020-04-27	8	[{"id_menu":5,"count":1}]	10122	delivery	5	13
55259	2020-04-27 07:20:36	2020-04-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	21897	delivery	5	36
55260	2020-04-27 07:24:21	2020-04-27	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	21930	delivery	5	26
55261	2020-04-27 07:24:45	2020-04-27	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	7440	delivery	5	23
55262	2020-04-27 07:34:39	2020-04-27	9	[{"id_menu":7,"count":2}]	8145	pick-up	0	9
55263	2020-04-27 07:37:41	2020-04-27	17	[{"id_menu":4,"count":1}]	3976	pick-up	0	17
55264	2020-04-27 07:42:18	2020-04-27	14	[{"id_menu":2,"count":1}]	22008	delivery	5	19
55265	2020-04-27 07:47:16	2020-04-27	14	[{"id_menu":2,"count":1}]	21894	delivery	5	19
55266	2020-04-27 07:51:37	2020-04-27	12	[{"id_menu":3,"count":1}]	11390	delivery	5	17
55267	2020-04-27 07:57:41	2020-04-27	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21990	delivery	5	31
55268	2020-04-27 07:58:09	2020-04-27	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	12907	delivery	5	28
55269	2020-04-27 08:03:50	2020-04-27	9	[{"id_menu":6,"count":1}]	21980	delivery	5	14
55270	2020-04-27 08:05:29	2020-04-27	17	[{"id_menu":4,"count":2}]	1088	delivery	5	22
55271	2020-04-27 08:07:12	2020-04-27	14	[{"id_menu":2,"count":1}]	21928	delivery	5	19
55272	2020-04-27 08:11:40	2020-04-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	21977	delivery	5	28
55273	2020-04-27 08:11:46	2020-04-27	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	21943	delivery	5	37
55274	2020-04-27 08:20:06	2020-04-27	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	21987	delivery	5	28
55275	2020-04-27 08:22:11	2020-04-27	8	[{"id_menu":5,"count":1}]	1681	pick-up	0	8
55276	2020-04-27 08:27:25	2020-04-27	14	[{"id_menu":2,"count":1}]	4741	delivery	5	19
55277	2020-04-27 08:31:33	2020-04-27	17	[{"id_menu":4,"count":1}]	4248	delivery	5	22
55278	2020-04-27 08:36:37	2020-04-27	14	[{"id_menu":2,"count":1}]	21986	delivery	5	19
55279	2020-04-27 08:43:32	2020-04-27	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":2}]	22023	delivery	5	34
55280	2020-04-27 08:45:11	2020-04-27	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6707	delivery	5	40
55281	2020-04-27 08:53:45	2020-04-27	14	[{"id_menu":2,"count":1}]	3948	delivery	5	19
55282	2020-04-27 08:55:52	2020-04-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21898	pick-up	0	18
55283	2020-04-27 08:59:16	2020-04-27	8	[{"id_menu":5,"count":1}]	19827	pick-up	0	8
55284	2020-04-27 09:01:57	2020-04-27	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	19160	delivery	5	40
55285	2020-04-27 09:07:04	2020-04-27	14	[{"id_menu":2,"count":1}]	10526	pick-up	0	14
55286	2020-04-27 09:11:15	2020-04-27	12	[{"id_menu":1,"count":1}]	19036	delivery	5	17
55287	2020-04-27 09:15:06	2020-04-27	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	21934	delivery	5	28
55288	2020-04-27 09:22:40	2020-04-27	17	[{"id_menu":4,"count":1}]	5099	delivery	5	22
55289	2020-04-27 09:24:21	2020-04-27	12	[{"id_menu":1,"count":1}]	21920	pick-up	0	12
55290	2020-04-27 09:27:33	2020-04-27	14	[{"id_menu":2,"count":1}]	4250	pick-up	0	14
55291	2020-04-27 09:27:43	2020-04-27	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	21262	delivery	5	29
55292	2020-04-27 09:27:44	2020-04-27	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7586	delivery	5	43
55293	2020-04-27 09:35:20	2020-04-27	17	[{"id_menu":4,"count":1}]	1914	pick-up	0	17
55294	2020-04-27 09:40:24	2020-04-27	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21086	delivery	5	47
55295	2020-04-27 09:58:15	2020-04-27	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3459	pick-up	0	23
55296	2020-04-27 10:04:04	2020-04-27	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	21984	delivery	5	27
55297	2020-04-27 10:07:08	2020-04-27	9	[{"id_menu":6,"count":1}]	21416	delivery	5	14
55298	2020-04-27 10:08:56	2020-04-27	9	[{"id_menu":6,"count":1}]	19071	pick-up	0	9
55299	2020-04-27 10:11:11	2020-04-27	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	10594	delivery	5	27
55300	2020-04-27 10:13:04	2020-04-27	17	[{"id_menu":4,"count":1}]	7888	delivery	5	22
55301	2020-04-27 10:13:22	2020-04-27	17	[{"id_menu":4,"count":1}]	9135	delivery	5	22
55302	2020-04-27 10:22:55	2020-04-27	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7244	delivery	5	52
55303	2020-04-27 10:32:11	2020-04-27	9	[{"id_menu":6,"count":1}]	4652	pick-up	0	9
55304	2020-04-27 10:37:24	2020-04-27	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	21953	pick-up	0	26
55305	2020-04-27 10:39:05	2020-04-27	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	20250	delivery	5	37
55306	2020-04-27 10:39:37	2020-04-27	8	[{"id_menu":5,"count":1}]	16695	delivery	5	13
55307	2020-04-27 10:43:59	2020-04-27	9	[{"id_menu":7,"count":1}]	5047	pick-up	0	9
55308	2020-04-27 10:45:56	2020-04-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	21968	delivery	5	36
55309	2020-04-27 10:47:03	2020-04-27	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	3509	pick-up	0	24
55310	2020-04-27 10:57:10	2020-04-27	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	22006	delivery	5	34
55311	2020-04-27 10:58:11	2020-04-27	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	5707	delivery	5	22
55312	2020-04-27 11:00:19	2020-04-27	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	21957	delivery	5	28
55313	2020-04-27 11:02:48	2020-04-27	12	[{"id_menu":3,"count":1}]	9303	pick-up	0	12
55314	2020-04-27 11:04:38	2020-04-27	9	[{"id_menu":7,"count":1}]	21949	delivery	5	14
55315	2020-04-27 11:17:32	2020-04-27	8	[{"id_menu":5,"count":1}]	2527	delivery	5	13
55316	2020-04-27 11:25:22	2020-04-27	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	22003	delivery	5	26
55317	2020-04-27 11:42:05	2020-04-27	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14900	delivery	5	45
55318	2020-04-27 11:50:05	2020-04-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21955	delivery	5	23
55319	2020-04-27 11:50:48	2020-04-27	12	[{"id_menu":1,"count":1}]	21967	delivery	5	17
55320	2020-04-27 11:56:07	2020-04-27	12	[{"id_menu":1,"count":1}]	376	pick-up	0	12
55321	2020-04-27 12:00:21	2020-04-27	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	13704	pick-up	0	21
55322	2020-04-27 12:05:12	2020-04-27	14	[{"id_menu":2,"count":1}]	20327	delivery	5	19
55323	2020-04-27 12:15:10	2020-04-27	12	[{"id_menu":1,"count":1}]	21999	pick-up	0	12
55324	2020-04-27 12:15:35	2020-04-27	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	18685	delivery	5	34
55325	2020-04-27 12:18:39	2020-04-27	17	[{"id_menu":4,"count":1}]	6950	delivery	5	22
55326	2020-04-27 12:44:43	2020-04-27	17	[{"id_menu":4,"count":1}]	20907	delivery	5	22
55327	2020-04-27 12:56:10	2020-04-27	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	6104	delivery	5	26
55328	2020-04-27 12:57:16	2020-04-27	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15015	delivery	5	37
55329	2020-04-27 13:09:15	2020-04-27	8	[{"id_menu":5,"count":1}]	18327	delivery	5	13
55330	2020-04-27 13:11:51	2020-04-27	14	[{"id_menu":2,"count":1}]	7559	delivery	5	19
55331	2020-04-27 13:13:19	2020-04-27	12	[{"id_menu":1,"count":1}]	14516	delivery	5	17
55332	2020-04-27 13:20:46	2020-04-27	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	6959	delivery	5	27
55333	2020-04-27 13:32:44	2020-04-27	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	15944	delivery	5	31
55334	2020-04-27 13:33:38	2020-04-27	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	14775	delivery	5	31
55335	2020-04-27 13:35:40	2020-04-27	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	17541	delivery	5	39
55336	2020-04-27 13:43:44	2020-04-27	12	[{"id_menu":1,"count":1}]	1993	pick-up	0	12
55337	2020-04-27 13:56:01	2020-04-27	9	[{"id_menu":6,"count":1}]	7596	delivery	5	14
55338	2020-04-27 14:05:14	2020-04-27	14	[{"id_menu":2,"count":1}]	21923	delivery	5	19
55339	2020-04-27 14:08:44	2020-04-27	12	[{"id_menu":1,"count":1}]	17421	delivery	5	17
55340	2020-04-27 14:12:08	2020-04-27	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8666	delivery	5	34
55341	2020-04-27 14:14:43	2020-04-27	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	19504	pick-up	0	22
55342	2020-04-27 14:17:50	2020-04-27	12	[{"id_menu":3,"count":1}]	3869	pick-up	0	12
55343	2020-04-27 14:22:05	2020-04-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	189	pick-up	0	23
55344	2020-04-27 14:22:32	2020-04-27	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15669	delivery	5	36
55345	2020-04-27 14:24:18	2020-04-27	14	[{"id_menu":2,"count":1}]	21960	delivery	5	19
55346	2020-04-27 14:26:49	2020-04-27	12	[{"id_menu":1,"count":1}]	9331	pick-up	0	12
55347	2020-04-27 14:30:50	2020-04-27	14	[{"id_menu":2,"count":1}]	6539	pick-up	0	14
55348	2020-04-27 14:37:53	2020-04-27	9	[{"id_menu":7,"count":1}]	7485	delivery	5	14
55349	2020-04-27 14:41:05	2020-04-27	17	[{"id_menu":4,"count":1}]	21985	delivery	5	22
55350	2020-04-27 14:44:58	2020-04-27	9	[{"id_menu":6,"count":1}]	9950	delivery	5	14
55351	2020-04-27 14:51:30	2020-04-27	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	16216	delivery	5	40
55352	2020-04-27 14:54:50	2020-04-27	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	120	delivery	5	30
55353	2020-04-27 14:55:41	2020-04-27	9	[{"id_menu":7,"count":1}]	18755	delivery	5	14
55354	2020-04-27 14:57:26	2020-04-27	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22004	delivery	5	45
55355	2020-04-27 15:00:48	2020-04-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17669	delivery	5	22
55356	2020-04-27 15:04:58	2020-04-27	14	[{"id_menu":2,"count":1}]	22030	delivery	5	19
55357	2020-04-27 15:11:19	2020-04-27	9	[{"id_menu":6,"count":1}]	7963	delivery	5	14
55358	2020-04-27 15:12:37	2020-04-27	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	21935	delivery	5	35
55359	2020-04-27 15:16:03	2020-04-27	9	[{"id_menu":6,"count":1}]	6561	pick-up	0	9
55360	2020-04-27 15:28:59	2020-04-27	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	22026	delivery	5	40
55361	2020-04-27 15:39:32	2020-04-27	14	[{"id_menu":2,"count":2}]	12675	pick-up	0	14
55362	2020-04-27 15:40:39	2020-04-27	9	[{"id_menu":6,"count":1}]	285	delivery	5	14
55363	2020-04-27 15:41:55	2020-04-27	12	[{"id_menu":1,"count":1}]	7741	pick-up	0	12
55364	2020-04-27 15:49:13	2020-04-27	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	21991	delivery	5	31
55365	2020-04-27 15:56:21	2020-04-27	9	[{"id_menu":7,"count":1}]	21896	delivery	5	14
55366	2020-04-27 16:15:32	2020-04-27	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16135	delivery	5	45
55367	2020-04-27 16:17:11	2020-04-27	9	[{"id_menu":7,"count":1}]	21998	delivery	5	14
55368	2020-04-27 16:19:29	2020-04-27	12	[{"id_menu":1,"count":1}]	14411	delivery	5	17
55369	2020-04-27 16:28:22	2020-04-27	55	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	8320	delivery	5	60
55370	2020-04-27 16:33:09	2020-04-27	17	[{"id_menu":4,"count":1}]	3048	delivery	5	22
55371	2020-04-27 16:40:47	2020-04-27	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	21969	delivery	5	31
55372	2020-04-27 16:41:07	2020-04-27	9	[{"id_menu":6,"count":1}]	21906	delivery	5	14
55373	2020-04-27 16:47:28	2020-04-27	12	[{"id_menu":1,"count":1}]	17038	delivery	5	17
55374	2020-04-27 16:54:58	2020-04-27	9	[{"id_menu":7,"count":1}]	21993	pick-up	0	9
55375	2020-04-27 16:55:55	2020-04-27	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	22012	delivery	5	31
55376	2020-04-27 16:57:28	2020-04-27	14	[{"id_menu":2,"count":1}]	10807	pick-up	0	14
55377	2020-04-27 16:57:39	2020-04-27	9	[{"id_menu":7,"count":1}]	21868	delivery	5	14
55378	2020-04-27 16:59:33	2020-04-27	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	21983	delivery	5	22
55379	2020-04-27 17:00:36	2020-04-27	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	21975	pick-up	0	25
55380	2020-04-27 17:00:59	2020-04-27	12	[{"id_menu":3,"count":1}]	18407	delivery	5	17
55381	2020-04-27 17:03:19	2020-04-27	12	[{"id_menu":3,"count":1}]	4053	pick-up	0	12
55382	2020-04-27 17:04:54	2020-04-27	14	[{"id_menu":2,"count":1}]	21118	delivery	5	19
55383	2020-04-27 17:05:45	2020-04-27	9	[{"id_menu":6,"count":1}]	18518	delivery	5	14
55384	2020-04-27 17:12:35	2020-04-27	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20852	delivery	5	43
55385	2020-04-27 17:14:26	2020-04-27	17	[{"id_menu":4,"count":1}]	12254	pick-up	0	17
55386	2020-04-27 17:58:09	2020-04-27	17	[{"id_menu":4,"count":1}]	6864	delivery	5	22
55387	2020-04-27 17:59:58	2020-04-27	12	[{"id_menu":3,"count":1}]	7941	pick-up	0	12
55388	2020-04-27 18:01:42	2020-04-27	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	17256	delivery	5	31
55389	2020-04-27 18:05:41	2020-04-27	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	21945	delivery	5	52
55390	2020-04-27 18:13:14	2020-04-27	14	[{"id_menu":2,"count":1}]	2011	delivery	5	19
55391	2020-04-27 18:19:18	2020-04-27	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	22001	delivery	5	26
55392	2020-04-27 18:21:54	2020-04-27	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	21901	pick-up	0	35
55393	2020-04-27 18:22:05	2020-04-27	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	19817	delivery	5	25
55394	2020-04-27 18:22:07	2020-04-27	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7691	pick-up	0	23
55395	2020-04-27 18:29:58	2020-04-27	8	[{"id_menu":5,"count":1}]	10790	delivery	5	13
55396	2020-04-27 18:38:04	2020-04-27	12	[{"id_menu":3,"count":1}]	4058	delivery	5	17
55397	2020-04-27 18:38:23	2020-04-27	12	[{"id_menu":1,"count":2}]	16466	pick-up	0	12
55398	2020-04-27 18:50:15	2020-04-27	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	12876	delivery	5	34
55399	2020-04-27 18:51:57	2020-04-27	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7217	delivery	5	34
55400	2020-04-27 18:55:27	2020-04-27	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":2}]	21854	delivery	5	22
55401	2020-04-27 18:59:46	2020-04-27	9	[{"id_menu":6,"count":1}]	13568	delivery	5	14
55402	2020-04-27 19:00:54	2020-04-27	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9199	delivery	5	30
55403	2020-04-27 19:12:47	2020-04-27	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8548	delivery	5	30
55404	2020-04-27 19:16:40	2020-04-27	9	[{"id_menu":7,"count":1}]	21995	delivery	5	14
55405	2020-04-27 19:31:26	2020-04-27	9	[{"id_menu":6,"count":2}]	22019	delivery	5	14
55406	2020-04-27 19:32:13	2020-04-27	12	[{"id_menu":1,"count":1}]	21913	delivery	5	17
55407	2020-04-27 19:33:04	2020-04-27	17	[{"id_menu":4,"count":1}]	2868	delivery	5	22
55408	2020-04-27 19:37:05	2020-04-27	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	6699	delivery	5	40
55409	2020-04-27 19:45:27	2020-04-27	8	[{"id_menu":5,"count":1}]	21948	pick-up	0	8
55410	2020-04-27 20:21:17	2020-04-27	9	[{"id_menu":7,"count":1}]	22025	delivery	5	14
55411	2020-04-27 20:28:45	2020-04-27	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	11624	delivery	5	25
55412	2020-04-27 20:29:03	2020-04-27	8	[{"id_menu":5,"count":1}]	5215	pick-up	0	8
55413	2020-04-27 20:37:22	2020-04-27	14	[{"id_menu":2,"count":1}]	1289	delivery	5	19
55414	2020-04-27 20:41:33	2020-04-27	14	[{"id_menu":2,"count":1}]	21925	delivery	5	19
55415	2020-04-27 20:43:05	2020-04-27	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	5028	delivery	5	25
55416	2020-04-27 20:49:45	2020-04-27	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21976	delivery	5	40
55417	2020-04-27 21:09:10	2020-04-27	12	[{"id_menu":3,"count":1}]	17695	delivery	5	17
55418	2020-04-27 21:11:09	2020-04-27	8	[{"id_menu":5,"count":1}]	10534	delivery	5	13
55419	2020-04-27 21:15:38	2020-04-27	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2000	pick-up	0	35
55420	2020-04-27 21:25:54	2020-04-27	9	[{"id_menu":6,"count":2}]	12074	delivery	5	14
55421	2020-04-27 21:31:04	2020-04-27	9	[{"id_menu":6,"count":1}]	15845	delivery	5	14
55422	2020-04-27 21:39:24	2020-04-27	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	18353	pick-up	0	26
55423	2020-04-27 21:40:53	2020-04-27	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	15929	pick-up	0	22
55424	2020-04-27 21:42:13	2020-04-27	8	[{"id_menu":5,"count":1}]	2358	pick-up	0	8
55425	2020-04-27 21:46:35	2020-04-27	9	[{"id_menu":6,"count":1}]	12572	delivery	5	14
55426	2020-04-27 21:55:13	2020-04-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8866	delivery	5	23
55427	2020-04-27 21:55:30	2020-04-27	8	[{"id_menu":5,"count":1}]	21989	delivery	5	13
55428	2020-04-27 22:00:57	2020-04-27	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	15603	delivery	5	30
55429	2020-04-27 22:01:39	2020-04-27	9	[{"id_menu":7,"count":1}]	20431	delivery	5	14
55430	2020-04-27 22:04:09	2020-04-27	9	[{"id_menu":6,"count":1}]	21937	delivery	5	14
55431	2020-04-27 22:06:45	2020-04-27	9	[{"id_menu":7,"count":1}]	11964	delivery	5	14
55432	2020-04-27 22:11:12	2020-04-27	9	[{"id_menu":7,"count":1}]	1282	pick-up	0	9
55433	2020-04-27 22:23:15	2020-04-27	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1100	delivery	5	37
55434	2020-04-27 22:30:58	2020-04-27	8	[{"id_menu":5,"count":1}]	3603	pick-up	0	8
55435	2020-04-27 22:34:01	2020-04-27	8	[{"id_menu":5,"count":1}]	7250	pick-up	0	8
55436	2020-04-27 22:41:17	2020-04-27	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	16565	delivery	5	23
55437	2020-04-27 22:45:24	2020-04-27	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	21938	delivery	5	30
55438	2020-04-27 22:45:24	2020-04-27	12	[{"id_menu":3,"count":1}]	21954	pick-up	0	12
55439	2020-04-27 22:46:48	2020-04-27	14	[{"id_menu":2,"count":1}]	14666	pick-up	0	14
55440	2020-04-27 22:55:50	2020-04-27	14	[{"id_menu":2,"count":1}]	2123	pick-up	0	14
55441	2020-04-27 23:00:02	2020-04-27	12	[{"id_menu":3,"count":1}]	21982	delivery	5	17
55442	2020-04-27 23:06:04	2020-04-27	9	[{"id_menu":7,"count":1}]	2351	pick-up	0	9
55443	2020-04-27 23:12:14	2020-04-27	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2961	pick-up	0	38
55444	2020-04-27 23:12:32	2020-04-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21944	delivery	5	22
55445	2020-04-27 23:13:16	2020-04-27	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4901	pick-up	0	25
55446	2020-04-27 23:13:45	2020-04-27	8	[{"id_menu":5,"count":1}]	12410	delivery	5	13
55447	2020-04-27 23:19:39	2020-04-27	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6366	delivery	5	47
55448	2020-04-27 23:21:54	2020-04-27	8	[{"id_menu":5,"count":1}]	15653	pick-up	0	8
55449	2020-04-27 23:22:31	2020-04-27	9	[{"id_menu":7,"count":1}]	22014	delivery	5	14
55450	2020-04-27 23:29:46	2020-04-27	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	6813	delivery	5	25
55451	2020-04-27 23:46:39	2020-04-27	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21910	pick-up	0	30
55452	2020-04-27 23:46:40	2020-04-27	12	[{"id_menu":3,"count":1}]	9749	pick-up	0	12
55453	2020-04-27 23:51:51	2020-04-27	9	[{"id_menu":6,"count":1}]	2272	delivery	5	14
55454	2020-04-27 23:53:27	2020-04-27	9	[{"id_menu":7,"count":1}]	19965	delivery	5	14
55455	2020-04-27 23:54:44	2020-04-27	9	[{"id_menu":6,"count":1}]	21950	delivery	5	14
55456	2020-04-28 00:01:59	2020-04-28	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	14344	delivery	5	29
55457	2020-04-28 00:11:17	2020-04-28	14	[{"id_menu":2,"count":2}]	22176	delivery	5	19
55458	2020-04-28 00:13:55	2020-04-28	12	[{"id_menu":1,"count":1}]	2000	delivery	5	17
55459	2020-04-28 00:16:07	2020-04-28	17	[{"id_menu":4,"count":1}]	10205	delivery	5	22
55460	2020-04-28 00:16:26	2020-04-28	9	[{"id_menu":6,"count":1}]	10048	pick-up	0	9
55461	2020-04-28 00:20:44	2020-04-28	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	22076	delivery	5	45
55462	2020-04-28 00:26:11	2020-04-28	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	16834	delivery	5	30
55463	2020-04-28 00:37:12	2020-04-28	12	[{"id_menu":3,"count":1}]	14165	delivery	5	17
55464	2020-04-28 00:40:38	2020-04-28	14	[{"id_menu":2,"count":1}]	17460	delivery	5	19
55465	2020-04-28 00:48:08	2020-04-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	22154	delivery	5	22
55466	2020-04-28 00:48:34	2020-04-28	8	[{"id_menu":5,"count":1}]	22136	delivery	5	13
55467	2020-04-28 01:10:56	2020-04-28	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4362	delivery	5	45
55468	2020-04-28 01:12:49	2020-04-28	17	[{"id_menu":4,"count":1}]	19387	delivery	5	22
55469	2020-04-28 01:14:31	2020-04-28	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	22042	delivery	5	37
55470	2020-04-28 01:15:08	2020-04-28	9	[{"id_menu":6,"count":1}]	964	delivery	5	14
55471	2020-04-28 01:22:30	2020-04-28	14	[{"id_menu":2,"count":1}]	1924	pick-up	0	14
55472	2020-04-28 01:23:28	2020-04-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17435	delivery	5	23
55473	2020-04-28 01:24:48	2020-04-28	12	[{"id_menu":1,"count":1}]	1914	pick-up	0	12
55474	2020-04-28 01:32:43	2020-04-28	9	[{"id_menu":7,"count":1}]	22100	delivery	5	14
55475	2020-04-28 01:32:47	2020-04-28	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	11377	delivery	5	31
55476	2020-04-28 01:34:02	2020-04-28	12	[{"id_menu":1,"count":1}]	15360	delivery	5	17
55477	2020-04-28 01:34:23	2020-04-28	17	[{"id_menu":4,"count":1}]	22206	delivery	5	22
55478	2020-04-28 01:38:12	2020-04-28	12	[{"id_menu":3,"count":2}]	21782	delivery	5	17
55479	2020-04-28 01:38:42	2020-04-28	14	[{"id_menu":2,"count":1}]	22084	delivery	5	19
55480	2020-04-28 01:41:56	2020-04-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	22115	delivery	5	31
55481	2020-04-28 01:42:01	2020-04-28	9	[{"id_menu":7,"count":1}]	15368	delivery	5	14
55482	2020-04-28 01:54:39	2020-04-28	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9859	pick-up	0	29
55483	2020-04-28 02:06:15	2020-04-28	17	[{"id_menu":4,"count":1}]	16100	delivery	5	22
55484	2020-04-28 02:07:17	2020-04-28	17	[{"id_menu":4,"count":1}]	2551	delivery	5	22
55485	2020-04-28 02:08:11	2020-04-28	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	11041	delivery	5	28
55486	2020-04-28 02:09:00	2020-04-28	9	[{"id_menu":6,"count":1}]	22095	delivery	5	14
55487	2020-04-28 02:14:54	2020-04-28	9	[{"id_menu":7,"count":1}]	20000	delivery	5	14
55488	2020-04-28 02:19:26	2020-04-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	21368	delivery	5	31
55489	2020-04-28 02:19:58	2020-04-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4281	delivery	5	22
55490	2020-04-28 02:20:35	2020-04-28	14	[{"id_menu":2,"count":1}]	18248	delivery	5	19
55491	2020-04-28 02:22:35	2020-04-28	17	[{"id_menu":4,"count":1}]	22096	delivery	5	22
55492	2020-04-28 02:25:07	2020-04-28	17	[{"id_menu":4,"count":1}]	22088	delivery	5	22
55493	2020-04-28 02:36:52	2020-04-28	9	[{"id_menu":7,"count":1}]	10679	pick-up	0	9
55494	2020-04-28 02:37:04	2020-04-28	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	12054	pick-up	0	26
55495	2020-04-28 02:37:57	2020-04-28	9	[{"id_menu":6,"count":1}]	10147	delivery	5	14
55496	2020-04-28 02:43:28	2020-04-28	9	[{"id_menu":6,"count":1}]	22079	delivery	5	14
55497	2020-04-28 02:46:58	2020-04-28	9	[{"id_menu":6,"count":1}]	20749	delivery	5	14
55498	2020-04-28 02:51:44	2020-04-28	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	20911	delivery	5	27
55499	2020-04-28 02:54:18	2020-04-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22039	delivery	5	22
55500	2020-04-28 02:56:13	2020-04-28	14	[{"id_menu":2,"count":1}]	20238	pick-up	0	14
55501	2020-04-28 02:58:06	2020-04-28	9	[{"id_menu":6,"count":1}]	12815	delivery	5	14
55502	2020-04-28 03:05:54	2020-04-28	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	19093	delivery	5	27
55503	2020-04-28 03:06:49	2020-04-28	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	120	delivery	5	26
55504	2020-04-28 03:09:13	2020-04-28	12	[{"id_menu":3,"count":1}]	22137	delivery	5	17
55505	2020-04-28 03:15:34	2020-04-28	9	[{"id_menu":7,"count":1}]	20825	delivery	5	14
55506	2020-04-28 03:18:46	2020-04-28	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12883	delivery	5	39
55507	2020-04-28 03:20:42	2020-04-28	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2980	pick-up	0	26
55508	2020-04-28 03:26:55	2020-04-28	12	[{"id_menu":1,"count":1}]	22205	pick-up	0	12
55509	2020-04-28 03:27:27	2020-04-28	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22131	pick-up	0	46
55510	2020-04-28 03:29:09	2020-04-28	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18938	delivery	5	36
55511	2020-04-28 03:29:24	2020-04-28	9	[{"id_menu":6,"count":2}]	17354	delivery	5	14
55512	2020-04-28 03:35:12	2020-04-28	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	5581	pick-up	0	31
55513	2020-04-28 03:35:27	2020-04-28	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	22184	delivery	5	40
55514	2020-04-28 03:42:19	2020-04-28	12	[{"id_menu":1,"count":1}]	2857	pick-up	0	12
55515	2020-04-28 04:01:49	2020-04-28	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	22045	delivery	5	31
55516	2020-04-28 04:06:42	2020-04-28	8	[{"id_menu":5,"count":1}]	9295	delivery	5	13
55517	2020-04-28 04:13:53	2020-04-28	9	[{"id_menu":6,"count":1}]	15138	delivery	5	14
55518	2020-04-28 04:18:17	2020-04-28	14	[{"id_menu":2,"count":1}]	3526	delivery	5	19
55519	2020-04-28 04:20:02	2020-04-28	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	9139	delivery	5	25
55520	2020-04-28 04:23:25	2020-04-28	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	5460	pick-up	0	29
55521	2020-04-28 04:32:26	2020-04-28	12	[{"id_menu":1,"count":1}]	8363	pick-up	0	12
55522	2020-04-28 04:39:33	2020-04-28	8	[{"id_menu":5,"count":1}]	22204	delivery	5	13
55523	2020-04-28 04:40:22	2020-04-28	14	[{"id_menu":2,"count":1}]	11281	pick-up	0	14
55524	2020-04-28 04:50:19	2020-04-28	12	[{"id_menu":1,"count":1}]	16330	delivery	5	17
55525	2020-04-28 04:51:40	2020-04-28	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	9312	delivery	5	34
55526	2020-04-28 04:54:09	2020-04-28	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8692	delivery	5	57
55527	2020-04-28 05:01:04	2020-04-28	8	[{"id_menu":5,"count":1}]	3319	pick-up	0	8
55528	2020-04-28 05:03:30	2020-04-28	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	22168	delivery	5	36
55529	2020-04-28 05:03:49	2020-04-28	12	[{"id_menu":1,"count":1}]	1684	delivery	5	17
55530	2020-04-28 05:07:26	2020-04-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	22117	delivery	5	31
55531	2020-04-28 05:13:33	2020-04-28	9	[{"id_menu":6,"count":1}]	22073	delivery	5	14
55532	2020-04-28 05:16:55	2020-04-28	12	[{"id_menu":3,"count":1}]	22123	delivery	5	17
55533	2020-04-28 05:19:18	2020-04-28	12	[{"id_menu":1,"count":1}]	22108	delivery	5	17
55534	2020-04-28 05:20:12	2020-04-28	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	22085	delivery	5	26
55535	2020-04-28 05:24:19	2020-04-28	9	[{"id_menu":7,"count":1}]	3823	delivery	5	14
55536	2020-04-28 05:24:24	2020-04-28	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22164	delivery	5	39
55537	2020-04-28 05:26:53	2020-04-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3640	delivery	5	31
55538	2020-04-28 05:30:07	2020-04-28	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	4376	delivery	5	43
55539	2020-04-28 05:35:37	2020-04-28	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	22072	delivery	5	25
55540	2020-04-28 05:40:46	2020-04-28	8	[{"id_menu":5,"count":1}]	22167	delivery	5	13
55541	2020-04-28 05:48:52	2020-04-28	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	11685	delivery	5	43
55542	2020-04-28 05:52:07	2020-04-28	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	193	pick-up	0	29
55543	2020-04-28 05:56:43	2020-04-28	9	[{"id_menu":6,"count":1}]	20288	delivery	5	14
55544	2020-04-28 05:58:15	2020-04-28	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1992	delivery	5	26
55545	2020-04-28 05:59:17	2020-04-28	9	[{"id_menu":6,"count":1}]	14984	delivery	5	14
55546	2020-04-28 06:00:16	2020-04-28	9	[{"id_menu":7,"count":1}]	18329	delivery	5	14
55547	2020-04-28 06:01:41	2020-04-28	12	[{"id_menu":3,"count":1}]	2072	pick-up	0	12
55548	2020-04-28 06:04:21	2020-04-28	9	[{"id_menu":6,"count":1}]	22055	delivery	5	14
55549	2020-04-28 06:20:38	2020-04-28	9	[{"id_menu":6,"count":1}]	729	pick-up	0	9
55550	2020-04-28 06:24:20	2020-04-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	22064	delivery	5	22
55551	2020-04-28 06:26:34	2020-04-28	9	[{"id_menu":7,"count":1}]	4102	pick-up	0	9
55552	2020-04-28 06:27:15	2020-04-28	8	[{"id_menu":5,"count":2}]	22069	pick-up	0	8
55553	2020-04-28 06:33:08	2020-04-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	22087	delivery	5	31
55554	2020-04-28 06:44:07	2020-04-28	17	[{"id_menu":4,"count":1}]	22129	delivery	5	22
55555	2020-04-28 06:47:39	2020-04-28	12	[{"id_menu":1,"count":1}]	16250	delivery	5	17
55556	2020-04-28 06:47:50	2020-04-28	9	[{"id_menu":6,"count":1}]	17511	delivery	5	14
55557	2020-04-28 06:57:00	2020-04-28	9	[{"id_menu":7,"count":1}]	22182	delivery	5	14
55558	2020-04-28 07:04:47	2020-04-28	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	6015	delivery	5	27
55559	2020-04-28 07:05:54	2020-04-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11507	delivery	5	31
55560	2020-04-28 07:12:10	2020-04-28	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2590	pick-up	0	21
55561	2020-04-28 07:22:16	2020-04-28	14	[{"id_menu":2,"count":2}]	1934	pick-up	0	14
55562	2020-04-28 07:24:12	2020-04-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5835	delivery	5	31
55563	2020-04-28 07:24:42	2020-04-28	9	[{"id_menu":7,"count":1}]	9130	delivery	5	14
55564	2020-04-28 07:27:41	2020-04-28	17	[{"id_menu":4,"count":1}]	783	pick-up	0	17
55565	2020-04-28 07:31:55	2020-04-28	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	18928	pick-up	0	26
55566	2020-04-28 07:35:39	2020-04-28	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19978	delivery	5	54
55567	2020-04-28 07:37:34	2020-04-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16270	pick-up	0	26
55568	2020-04-28 07:44:12	2020-04-28	12	[{"id_menu":3,"count":1}]	22103	delivery	5	17
55569	2020-04-28 07:46:20	2020-04-28	8	[{"id_menu":5,"count":1}]	22102	delivery	5	13
55570	2020-04-28 07:51:39	2020-04-28	12	[{"id_menu":3,"count":1}]	638	pick-up	0	12
55571	2020-04-28 07:52:45	2020-04-28	33	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4644	delivery	5	38
55572	2020-04-28 08:05:01	2020-04-28	9	[{"id_menu":7,"count":1}]	22152	delivery	5	14
55573	2020-04-28 08:05:58	2020-04-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	22197	delivery	5	31
55574	2020-04-28 08:11:04	2020-04-28	9	[{"id_menu":7,"count":1}]	22089	delivery	5	14
55575	2020-04-28 08:15:14	2020-04-28	8	[{"id_menu":5,"count":1}]	11098	delivery	5	13
55576	2020-04-28 08:16:13	2020-04-28	9	[{"id_menu":7,"count":1}]	22132	delivery	5	14
55577	2020-04-28 08:29:17	2020-04-28	12	[{"id_menu":1,"count":1}]	5393	delivery	5	17
55578	2020-04-28 08:42:21	2020-04-28	8	[{"id_menu":5,"count":1}]	22148	pick-up	0	8
55579	2020-04-28 08:43:47	2020-04-28	14	[{"id_menu":2,"count":1}]	6248	pick-up	0	14
55580	2020-04-28 08:46:54	2020-04-28	14	[{"id_menu":2,"count":1}]	18717	delivery	5	19
55581	2020-04-28 08:53:43	2020-04-28	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	9898	pick-up	0	31
55582	2020-04-28 08:54:05	2020-04-28	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	14743	delivery	5	26
55583	2020-04-28 08:57:32	2020-04-28	14	[{"id_menu":2,"count":1}]	12781	delivery	5	19
55584	2020-04-28 09:08:06	2020-04-28	14	[{"id_menu":2,"count":1}]	2426	pick-up	0	14
55585	2020-04-28 09:15:49	2020-04-28	17	[{"id_menu":4,"count":1}]	22134	delivery	5	22
55586	2020-04-28 09:17:09	2020-04-28	9	[{"id_menu":7,"count":1}]	6678	delivery	5	14
55587	2020-04-28 09:24:16	2020-04-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	21386	pick-up	0	23
55588	2020-04-28 09:24:36	2020-04-28	17	[{"id_menu":4,"count":1}]	7387	delivery	5	22
55589	2020-04-28 09:24:44	2020-04-28	8	[{"id_menu":5,"count":1}]	22057	delivery	5	13
55590	2020-04-28 09:31:10	2020-04-28	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3992	delivery	5	43
55591	2020-04-28 09:35:18	2020-04-28	8	[{"id_menu":5,"count":1}]	10937	delivery	5	13
55592	2020-04-28 09:38:23	2020-04-28	17	[{"id_menu":4,"count":1}]	8655	delivery	5	22
55593	2020-04-28 09:41:55	2020-04-28	9	[{"id_menu":6,"count":1}]	4825	delivery	5	14
55594	2020-04-28 09:47:21	2020-04-28	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	22106	pick-up	0	20
55595	2020-04-28 09:50:12	2020-04-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17995	pick-up	0	17
55596	2020-04-28 09:54:07	2020-04-28	12	[{"id_menu":3,"count":1}]	22181	delivery	5	17
55597	2020-04-28 09:57:57	2020-04-28	17	[{"id_menu":4,"count":1}]	4478	delivery	5	22
55598	2020-04-28 09:59:07	2020-04-28	12	[{"id_menu":3,"count":1}]	19233	delivery	5	17
55599	2020-04-28 10:02:29	2020-04-28	9	[{"id_menu":7,"count":1}]	942	pick-up	0	9
55600	2020-04-28 10:08:22	2020-04-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20443	delivery	5	22
55601	2020-04-28 10:11:26	2020-04-28	17	[{"id_menu":4,"count":1}]	12445	pick-up	0	17
55602	2020-04-28 10:11:34	2020-04-28	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9103	delivery	5	30
55603	2020-04-28 10:16:14	2020-04-28	8	[{"id_menu":5,"count":1}]	2660	delivery	5	13
55604	2020-04-28 10:16:39	2020-04-28	12	[{"id_menu":1,"count":1}]	5359	delivery	5	17
55605	2020-04-28 10:17:23	2020-04-28	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6201	delivery	5	30
55606	2020-04-28 10:21:51	2020-04-28	9	[{"id_menu":6,"count":1}]	16009	delivery	5	14
55607	2020-04-28 10:22:13	2020-04-28	9	[{"id_menu":7,"count":1}]	11298	delivery	5	14
55608	2020-04-28 10:27:38	2020-04-28	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	3626	delivery	5	31
55609	2020-04-28 10:30:52	2020-04-28	8	[{"id_menu":5,"count":1}]	4636	pick-up	0	8
55610	2020-04-28 10:40:27	2020-04-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	22043	pick-up	0	26
55611	2020-04-28 10:43:19	2020-04-28	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	15110	pick-up	0	26
55612	2020-04-28 10:47:46	2020-04-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	20092	delivery	5	31
55613	2020-04-28 10:47:52	2020-04-28	12	[{"id_menu":1,"count":1}]	22191	delivery	5	17
55614	2020-04-28 10:50:28	2020-04-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14495	delivery	5	22
55615	2020-04-28 10:55:24	2020-04-28	12	[{"id_menu":3,"count":1}]	20438	delivery	5	17
55616	2020-04-28 11:05:07	2020-04-28	9	[{"id_menu":7,"count":1}]	6535	delivery	5	14
55617	2020-04-28 11:09:46	2020-04-28	9	[{"id_menu":6,"count":1}]	10597	delivery	5	14
55618	2020-04-28 11:10:10	2020-04-28	14	[{"id_menu":2,"count":1}]	18286	delivery	5	19
55619	2020-04-28 11:10:47	2020-04-28	12	[{"id_menu":3,"count":1}]	22056	delivery	5	17
55620	2020-04-28 11:21:05	2020-04-28	8	[{"id_menu":5,"count":1}]	10948	pick-up	0	8
55621	2020-04-28 11:23:19	2020-04-28	29	[{"id_menu":3,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22063	delivery	5	34
55622	2020-04-28 11:25:00	2020-04-28	17	[{"id_menu":4,"count":1}]	6848	pick-up	0	17
55623	2020-04-28 11:26:56	2020-04-28	9	[{"id_menu":7,"count":1}]	22104	delivery	5	14
55624	2020-04-28 11:34:36	2020-04-28	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5857	delivery	5	35
55625	2020-04-28 11:43:32	2020-04-28	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	20524	delivery	5	40
55626	2020-04-28 11:44:12	2020-04-28	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	16516	delivery	5	28
55627	2020-04-28 11:48:22	2020-04-28	9	[{"id_menu":7,"count":1}]	22116	delivery	5	14
55628	2020-04-28 11:57:19	2020-04-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	22070	delivery	5	28
55629	2020-04-28 11:59:20	2020-04-28	9	[{"id_menu":6,"count":1}]	16141	delivery	5	14
55630	2020-04-28 12:03:12	2020-04-28	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	4033	pick-up	0	20
55631	2020-04-28 12:08:13	2020-04-28	14	[{"id_menu":2,"count":1}]	7449	delivery	5	19
55632	2020-04-28 12:12:22	2020-04-28	9	[{"id_menu":7,"count":1}]	5942	delivery	5	14
55633	2020-04-28 12:14:06	2020-04-28	9	[{"id_menu":7,"count":1}]	22121	delivery	5	14
55634	2020-04-28 12:19:52	2020-04-28	8	[{"id_menu":5,"count":1}]	18222	pick-up	0	8
55635	2020-04-28 12:37:48	2020-04-28	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22163	delivery	5	40
55636	2020-04-28 12:48:16	2020-04-28	14	[{"id_menu":2,"count":1}]	107	pick-up	0	14
55637	2020-04-28 12:49:58	2020-04-28	9	[{"id_menu":7,"count":1}]	22051	delivery	5	14
55638	2020-04-28 12:56:39	2020-04-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1537	pick-up	0	26
55639	2020-04-28 12:57:31	2020-04-28	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	5181	delivery	5	36
55640	2020-04-28 12:58:53	2020-04-28	14	[{"id_menu":2,"count":1}]	9060	delivery	5	19
55641	2020-04-28 13:05:21	2020-04-28	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7208	delivery	5	31
55642	2020-04-28 13:07:21	2020-04-28	9	[{"id_menu":6,"count":1}]	22034	delivery	5	14
55643	2020-04-28 13:08:58	2020-04-28	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	15265	pick-up	0	26
55644	2020-04-28 13:13:32	2020-04-28	9	[{"id_menu":6,"count":1}]	8910	delivery	5	14
55645	2020-04-28 13:17:52	2020-04-28	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	8954	delivery	5	40
55646	2020-04-28 13:17:53	2020-04-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":3}]	22145	delivery	5	31
55647	2020-04-28 13:27:44	2020-04-28	9	[{"id_menu":6,"count":1}]	6865	delivery	5	14
55648	2020-04-28 13:27:46	2020-04-28	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12224	pick-up	0	29
55649	2020-04-28 13:29:31	2020-04-28	14	[{"id_menu":2,"count":1}]	22187	delivery	5	19
55650	2020-04-28 13:31:19	2020-04-28	12	[{"id_menu":1,"count":1}]	22114	delivery	5	17
55651	2020-04-28 13:31:57	2020-04-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	14068	delivery	5	31
55652	2020-04-28 13:36:05	2020-04-28	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	16831	delivery	5	48
55653	2020-04-28 13:36:21	2020-04-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	10499	delivery	5	28
55654	2020-04-28 13:36:46	2020-04-28	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	6480	delivery	5	35
55655	2020-04-28 13:37:43	2020-04-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	16084	delivery	5	28
55656	2020-04-28 13:37:48	2020-04-28	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	22074	delivery	5	34
55657	2020-04-28 13:42:00	2020-04-28	14	[{"id_menu":2,"count":1}]	8306	delivery	5	19
55658	2020-04-28 13:49:33	2020-04-28	9	[{"id_menu":6,"count":1}]	3519	delivery	5	14
55659	2020-04-28 13:53:47	2020-04-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	741	pick-up	0	26
55660	2020-04-28 14:00:56	2020-04-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20271	delivery	5	23
55661	2020-04-28 14:03:42	2020-04-28	14	[{"id_menu":2,"count":1}]	15113	delivery	5	19
55662	2020-04-28 14:07:50	2020-04-28	9	[{"id_menu":6,"count":1}]	18050	delivery	5	14
55663	2020-04-28 14:15:32	2020-04-28	17	[{"id_menu":4,"count":1}]	19341	delivery	5	22
55664	2020-04-28 14:20:37	2020-04-28	12	[{"id_menu":3,"count":1}]	12464	delivery	5	17
55665	2020-04-28 14:20:59	2020-04-28	9	[{"id_menu":6,"count":1}]	4923	delivery	5	14
55666	2020-04-28 14:28:25	2020-04-28	14	[{"id_menu":2,"count":1}]	22093	delivery	5	19
55667	2020-04-28 14:29:28	2020-04-28	9	[{"id_menu":6,"count":1}]	8157	delivery	5	14
55668	2020-04-28 14:30:44	2020-04-28	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	21945	delivery	5	40
55669	2020-04-28 14:55:43	2020-04-28	9	[{"id_menu":7,"count":1}]	9423	delivery	5	14
55670	2020-04-28 14:55:47	2020-04-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	22078	delivery	5	22
55671	2020-04-28 14:55:54	2020-04-28	9	[{"id_menu":6,"count":1}]	22127	delivery	5	14
55672	2020-04-28 14:57:30	2020-04-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	511	pick-up	0	26
55673	2020-04-28 15:01:16	2020-04-28	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	22190	delivery	5	40
55674	2020-04-28 15:08:00	2020-04-28	9	[{"id_menu":7,"count":1}]	19840	delivery	5	14
55675	2020-04-28 15:08:09	2020-04-28	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	22066	delivery	5	44
55676	2020-04-28 15:15:31	2020-04-28	12	[{"id_menu":3,"count":1}]	9065	pick-up	0	12
55677	2020-04-28 15:23:20	2020-04-28	14	[{"id_menu":2,"count":1}]	11156	delivery	5	19
55678	2020-04-28 15:26:28	2020-04-28	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	22139	delivery	5	26
55679	2020-04-28 15:41:30	2020-04-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	22200	delivery	5	23
55680	2020-04-28 15:48:19	2020-04-28	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18392	pick-up	0	32
55681	2020-04-28 15:49:01	2020-04-28	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	22208	delivery	5	26
55682	2020-04-28 15:49:21	2020-04-28	14	[{"id_menu":2,"count":1}]	22192	delivery	5	19
55683	2020-04-28 15:57:16	2020-04-28	8	[{"id_menu":5,"count":3}]	4381	delivery	5	13
55684	2020-04-28 15:58:47	2020-04-28	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	11266	delivery	5	25
55685	2020-04-28 15:59:58	2020-04-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6950	delivery	5	28
55686	2020-04-28 16:01:07	2020-04-28	14	[{"id_menu":2,"count":1}]	17092	delivery	5	19
55687	2020-04-28 16:02:56	2020-04-28	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	993	pick-up	0	29
55688	2020-04-28 16:07:40	2020-04-28	8	[{"id_menu":5,"count":1}]	22158	delivery	5	13
55689	2020-04-28 16:15:43	2020-04-28	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	21431	delivery	5	38
55690	2020-04-28 16:17:19	2020-04-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":3}]	22165	delivery	5	31
55691	2020-04-28 16:18:09	2020-04-28	9	[{"id_menu":6,"count":1}]	691	pick-up	0	9
55692	2020-04-28 16:22:12	2020-04-28	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16001	delivery	5	52
55693	2020-04-28 16:23:59	2020-04-28	12	[{"id_menu":3,"count":1}]	22189	pick-up	0	12
55694	2020-04-28 16:25:32	2020-04-28	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	22186	delivery	5	43
55695	2020-04-28 16:25:39	2020-04-28	17	[{"id_menu":4,"count":1}]	21391	delivery	5	22
55696	2020-04-28 16:29:23	2020-04-28	8	[{"id_menu":5,"count":1}]	3993	delivery	5	13
55697	2020-04-28 16:30:51	2020-04-28	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17950	delivery	5	52
55698	2020-04-28 16:31:07	2020-04-28	9	[{"id_menu":7,"count":1}]	22171	delivery	5	14
55699	2020-04-28 16:39:37	2020-04-28	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22133	delivery	5	36
55700	2020-04-28 16:48:07	2020-04-28	12	[{"id_menu":1,"count":1}]	18612	delivery	5	17
55701	2020-04-28 16:57:19	2020-04-28	8	[{"id_menu":5,"count":1}]	22149	delivery	5	13
55702	2020-04-28 17:01:02	2020-04-28	9	[{"id_menu":7,"count":1}]	11223	delivery	5	14
55703	2020-04-28 17:07:48	2020-04-28	9	[{"id_menu":6,"count":1}]	22091	delivery	5	14
55704	2020-04-28 17:10:30	2020-04-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	22125	delivery	5	31
55705	2020-04-28 17:16:25	2020-04-28	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	22112	delivery	5	27
55706	2020-04-28 17:16:34	2020-04-28	17	[{"id_menu":4,"count":1}]	7719	delivery	5	22
55707	2020-04-28 17:18:17	2020-04-28	12	[{"id_menu":1,"count":1}]	17341	delivery	5	17
55708	2020-04-28 17:23:31	2020-04-28	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	17550	delivery	5	40
55709	2020-04-28 17:25:07	2020-04-28	9	[{"id_menu":6,"count":1}]	17371	delivery	5	14
55710	2020-04-28 17:28:38	2020-04-28	14	[{"id_menu":2,"count":2}]	22041	delivery	5	19
55711	2020-04-28 17:31:25	2020-04-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	18133	delivery	5	28
55712	2020-04-28 17:37:57	2020-04-28	8	[{"id_menu":5,"count":1}]	22111	delivery	5	13
55713	2020-04-28 17:39:38	2020-04-28	14	[{"id_menu":2,"count":1}]	13875	delivery	5	19
55714	2020-04-28 17:50:04	2020-04-28	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	22193	delivery	5	53
55715	2020-04-28 17:55:54	2020-04-28	12	[{"id_menu":1,"count":1}]	22174	delivery	5	17
55716	2020-04-28 17:58:20	2020-04-28	17	[{"id_menu":4,"count":1}]	22067	delivery	5	22
55717	2020-04-28 18:00:55	2020-04-28	9	[{"id_menu":6,"count":2}]	22035	delivery	5	14
55718	2020-04-28 18:03:43	2020-04-28	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	4232	delivery	5	25
55719	2020-04-28 18:09:00	2020-04-28	9	[{"id_menu":7,"count":1}]	7530	delivery	5	14
55720	2020-04-28 18:11:54	2020-04-28	12	[{"id_menu":1,"count":1}]	16303	delivery	5	17
55721	2020-04-28 18:13:56	2020-04-28	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	19375	delivery	5	42
55722	2020-04-28 18:14:11	2020-04-28	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	22135	delivery	5	39
55723	2020-04-28 18:14:55	2020-04-28	12	[{"id_menu":3,"count":1}]	285	pick-up	0	12
55724	2020-04-28 18:17:02	2020-04-28	9	[{"id_menu":6,"count":3}]	17855	delivery	5	14
55725	2020-04-28 18:21:53	2020-04-28	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2050	pick-up	0	31
55726	2020-04-28 18:25:09	2020-04-28	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	22119	pick-up	0	21
55727	2020-04-28 18:27:59	2020-04-28	12	[{"id_menu":1,"count":1}]	11196	delivery	5	17
55728	2020-04-28 18:28:45	2020-04-28	14	[{"id_menu":2,"count":1}]	22183	delivery	5	19
55729	2020-04-28 18:41:13	2020-04-28	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22082	delivery	5	39
55730	2020-04-28 18:42:54	2020-04-28	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	16771	pick-up	0	21
55731	2020-04-28 18:44:36	2020-04-28	17	[{"id_menu":4,"count":1}]	22195	delivery	5	22
55732	2020-04-28 18:47:25	2020-04-28	9	[{"id_menu":6,"count":1}]	21848	delivery	5	14
55733	2020-04-28 18:48:55	2020-04-28	14	[{"id_menu":2,"count":1}]	8755	pick-up	0	14
55734	2020-04-28 19:09:18	2020-04-28	8	[{"id_menu":5,"count":2}]	17671	delivery	5	13
55735	2020-04-28 19:14:54	2020-04-28	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	22185	delivery	5	31
55736	2020-04-28 19:14:55	2020-04-28	8	[{"id_menu":5,"count":1}]	13497	pick-up	0	8
55737	2020-04-28 19:16:54	2020-04-28	8	[{"id_menu":5,"count":2}]	4836	delivery	5	13
55738	2020-04-28 19:38:47	2020-04-28	8	[{"id_menu":5,"count":1}]	22054	delivery	5	13
55739	2020-04-28 19:45:15	2020-04-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16307	delivery	5	23
55740	2020-04-28 19:47:04	2020-04-28	8	[{"id_menu":5,"count":1}]	22036	delivery	5	13
55741	2020-04-28 19:49:23	2020-04-28	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	12228	delivery	5	31
55742	2020-04-28 19:55:19	2020-04-28	9	[{"id_menu":7,"count":1}]	66	delivery	5	14
55743	2020-04-28 20:00:48	2020-04-28	12	[{"id_menu":3,"count":1}]	22040	delivery	5	17
55744	2020-04-28 20:09:47	2020-04-28	12	[{"id_menu":1,"count":1}]	19804	delivery	5	17
55745	2020-04-28 20:26:14	2020-04-28	12	[{"id_menu":1,"count":1}]	10648	pick-up	0	12
55746	2020-04-28 20:26:39	2020-04-28	8	[{"id_menu":5,"count":1}]	10495	delivery	5	13
55747	2020-04-28 20:30:31	2020-04-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	22180	delivery	5	31
55748	2020-04-28 20:30:57	2020-04-28	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	11283	delivery	5	40
55749	2020-04-28 20:40:55	2020-04-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20413	pick-up	0	18
55750	2020-04-28 20:43:12	2020-04-28	12	[{"id_menu":1,"count":1}]	22196	delivery	5	17
55751	2020-04-28 20:45:37	2020-04-28	8	[{"id_menu":5,"count":1}]	16688	delivery	5	13
55752	2020-04-28 20:45:57	2020-04-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11403	delivery	5	22
55753	2020-04-28 20:49:13	2020-04-28	9	[{"id_menu":7,"count":2}]	22166	delivery	5	14
55754	2020-04-28 20:50:29	2020-04-28	12	[{"id_menu":1,"count":1}]	22155	delivery	5	17
55755	2020-04-28 21:00:59	2020-04-28	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	22101	delivery	5	40
55756	2020-04-28 21:02:43	2020-04-28	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10567	delivery	5	37
55757	2020-04-28 21:03:16	2020-04-28	8	[{"id_menu":5,"count":1}]	4514	delivery	5	13
55758	2020-04-28 21:09:07	2020-04-28	9	[{"id_menu":6,"count":2}]	4990	delivery	5	14
55759	2020-04-28 21:13:42	2020-04-28	14	[{"id_menu":2,"count":2}]	3174	delivery	5	19
55760	2020-04-28 21:15:35	2020-04-28	9	[{"id_menu":6,"count":1}]	20805	pick-up	0	9
55761	2020-04-28 21:16:05	2020-04-28	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8705	delivery	5	45
55762	2020-04-28 21:18:22	2020-04-28	34	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	22124	delivery	5	39
55763	2020-04-28 21:18:48	2020-04-28	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	5792	delivery	5	31
55764	2020-04-28 21:19:34	2020-04-28	23	[{"id_menu":2,"count":3},{"id_menu":6,"count":1}]	22080	delivery	5	28
55765	2020-04-28 21:26:31	2020-04-28	9	[{"id_menu":7,"count":1}]	686	delivery	5	14
55766	2020-04-28 21:27:05	2020-04-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2838	pick-up	0	17
55767	2020-04-28 21:30:24	2020-04-28	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	10541	pick-up	0	29
55768	2020-04-28 21:34:22	2020-04-28	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20803	delivery	5	43
55769	2020-04-28 21:36:05	2020-04-28	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	22202	delivery	5	26
55770	2020-04-28 21:48:54	2020-04-28	9	[{"id_menu":6,"count":1}]	20569	delivery	5	14
55771	2020-04-28 21:50:44	2020-04-28	17	[{"id_menu":4,"count":1}]	22075	delivery	5	22
55772	2020-04-28 21:53:38	2020-04-28	9	[{"id_menu":7,"count":1}]	17467	delivery	5	14
55773	2020-04-28 21:56:07	2020-04-28	17	[{"id_menu":4,"count":1}]	21649	delivery	5	22
55774	2020-04-28 22:00:15	2020-04-28	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	1765	delivery	5	26
55775	2020-04-28 22:04:45	2020-04-28	9	[{"id_menu":7,"count":1}]	801	pick-up	0	9
55776	2020-04-28 22:10:11	2020-04-28	12	[{"id_menu":3,"count":1}]	10505	delivery	5	17
55777	2020-04-28 22:27:48	2020-04-28	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	287	pick-up	0	20
55778	2020-04-28 22:34:53	2020-04-28	9	[{"id_menu":6,"count":1}]	20457	delivery	5	14
55779	2020-04-28 22:36:52	2020-04-28	9	[{"id_menu":7,"count":1}]	7158	delivery	5	14
55780	2020-04-28 22:37:15	2020-04-28	9	[{"id_menu":7,"count":2}]	22061	delivery	5	14
55781	2020-04-28 22:39:14	2020-04-28	14	[{"id_menu":2,"count":1}]	13461	delivery	5	19
55782	2020-04-28 22:41:35	2020-04-28	9	[{"id_menu":6,"count":1}]	22179	delivery	5	14
55783	2020-04-28 22:43:52	2020-04-28	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2185	delivery	5	26
55784	2020-04-28 22:47:02	2020-04-28	9	[{"id_menu":6,"count":1}]	10321	delivery	5	14
55785	2020-04-28 22:48:34	2020-04-28	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	13307	pick-up	0	22
55786	2020-04-28 22:51:30	2020-04-28	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	586	pick-up	0	24
55787	2020-04-28 22:51:48	2020-04-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	12701	delivery	5	22
55788	2020-04-28 22:55:13	2020-04-28	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":2}]	16632	pick-up	0	21
55789	2020-04-28 22:56:41	2020-04-28	9	[{"id_menu":6,"count":1}]	22065	delivery	5	14
55790	2020-04-28 22:58:49	2020-04-28	14	[{"id_menu":2,"count":2}]	3667	delivery	5	19
55791	2020-04-28 23:03:11	2020-04-28	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15902	delivery	5	36
55792	2020-04-28 23:16:26	2020-04-28	12	[{"id_menu":3,"count":1}]	22201	delivery	5	17
55793	2020-04-28 23:20:22	2020-04-28	9	[{"id_menu":7,"count":1}]	1170	pick-up	0	9
55794	2020-04-28 23:22:40	2020-04-28	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	22071	pick-up	0	23
55795	2020-04-28 23:26:20	2020-04-28	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1288	pick-up	0	26
55796	2020-04-28 23:30:34	2020-04-28	9	[{"id_menu":6,"count":2}]	22081	delivery	5	14
55797	2020-04-28 23:32:16	2020-04-28	14	[{"id_menu":2,"count":1}]	16546	pick-up	0	14
55798	2020-04-28 23:33:37	2020-04-28	17	[{"id_menu":4,"count":1}]	6990	delivery	5	22
55799	2020-04-28 23:35:53	2020-04-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	10729	delivery	5	22
55800	2020-04-28 23:36:53	2020-04-28	9	[{"id_menu":6,"count":1}]	22047	delivery	5	14
55801	2020-04-28 23:37:41	2020-04-28	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22037	delivery	5	39
55802	2020-04-28 23:40:39	2020-04-28	17	[{"id_menu":4,"count":1}]	9848	delivery	5	22
55803	2020-04-28 23:40:39	2020-04-28	12	[{"id_menu":1,"count":1}]	22029	delivery	5	17
55804	2020-04-28 23:43:42	2020-04-28	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9851	delivery	5	37
55805	2020-04-28 23:53:59	2020-04-28	8	[{"id_menu":5,"count":1}]	2392	pick-up	0	8
55806	2020-04-28 23:56:54	2020-04-28	9	[{"id_menu":6,"count":1}]	13350	delivery	5	14
55807	2020-04-29 00:03:04	2020-04-29	9	[{"id_menu":6,"count":1}]	1862	delivery	5	14
55808	2020-04-29 00:09:20	2020-04-29	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	22214	delivery	5	34
55809	2020-04-29 00:11:03	2020-04-29	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	22308	delivery	5	34
55810	2020-04-29 00:12:26	2020-04-29	17	[{"id_menu":4,"count":1}]	13026	pick-up	0	17
55811	2020-04-29 00:13:45	2020-04-29	8	[{"id_menu":5,"count":2}]	3153	pick-up	0	8
55812	2020-04-29 00:15:59	2020-04-29	12	[{"id_menu":3,"count":1}]	2850	pick-up	0	12
55813	2020-04-29 00:17:57	2020-04-29	14	[{"id_menu":2,"count":1}]	18861	delivery	5	19
55814	2020-04-29 00:33:50	2020-04-29	17	[{"id_menu":4,"count":1}]	7835	delivery	5	22
55815	2020-04-29 00:41:21	2020-04-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	5339	delivery	5	36
55816	2020-04-29 00:47:32	2020-04-29	12	[{"id_menu":1,"count":1}]	22243	delivery	5	17
55817	2020-04-29 00:47:48	2020-04-29	12	[{"id_menu":1,"count":1}]	22237	delivery	5	17
55818	2020-04-29 00:49:22	2020-04-29	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	7261	delivery	5	23
55819	2020-04-29 00:50:34	2020-04-29	8	[{"id_menu":5,"count":1}]	1296	pick-up	0	8
55820	2020-04-29 00:52:12	2020-04-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13881	delivery	5	36
55821	2020-04-29 01:00:06	2020-04-29	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	14357	delivery	5	23
55822	2020-04-29 01:00:28	2020-04-29	9	[{"id_menu":6,"count":1}]	19411	delivery	5	14
55823	2020-04-29 01:01:50	2020-04-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3511	pick-up	0	17
55824	2020-04-29 01:08:39	2020-04-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	22349	delivery	5	31
55825	2020-04-29 01:09:04	2020-04-29	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6154	delivery	5	43
55826	2020-04-29 01:12:39	2020-04-29	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22378	delivery	5	31
55827	2020-04-29 01:17:24	2020-04-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	22313	pick-up	0	26
55828	2020-04-29 01:21:02	2020-04-29	37	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	11190	pick-up	0	37
55829	2020-04-29 01:26:02	2020-04-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1808	delivery	5	28
55830	2020-04-29 01:27:46	2020-04-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	22377	delivery	5	23
55831	2020-04-29 01:31:31	2020-04-29	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	22350	delivery	5	39
55832	2020-04-29 01:36:22	2020-04-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	502	delivery	5	22
55833	2020-04-29 01:38:09	2020-04-29	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	22260	delivery	5	26
55834	2020-04-29 01:38:57	2020-04-29	14	[{"id_menu":2,"count":1}]	22326	delivery	5	19
55835	2020-04-29 01:39:10	2020-04-29	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6591	pick-up	0	25
55836	2020-04-29 01:40:26	2020-04-29	14	[{"id_menu":2,"count":1}]	6341	delivery	5	19
55837	2020-04-29 01:41:26	2020-04-29	8	[{"id_menu":5,"count":1}]	8584	delivery	5	13
55838	2020-04-29 01:41:38	2020-04-29	12	[{"id_menu":1,"count":1}]	9191	pick-up	0	12
55839	2020-04-29 01:47:21	2020-04-29	12	[{"id_menu":3,"count":1}]	22240	delivery	5	17
55840	2020-04-29 01:50:33	2020-04-29	9	[{"id_menu":6,"count":1}]	22246	delivery	5	14
55841	2020-04-29 01:50:51	2020-04-29	12	[{"id_menu":1,"count":1}]	22121	delivery	5	17
55842	2020-04-29 01:55:30	2020-04-29	12	[{"id_menu":3,"count":1}]	1662	delivery	5	17
55843	2020-04-29 01:55:48	2020-04-29	9	[{"id_menu":7,"count":2}]	15614	delivery	5	14
55844	2020-04-29 01:59:31	2020-04-29	9	[{"id_menu":6,"count":1}]	1203	pick-up	0	9
55845	2020-04-29 01:59:36	2020-04-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2366	pick-up	0	26
55846	2020-04-29 02:04:17	2020-04-29	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22226	pick-up	0	46
55847	2020-04-29 02:05:00	2020-04-29	12	[{"id_menu":1,"count":1}]	3711	pick-up	0	12
55848	2020-04-29 02:08:07	2020-04-29	9	[{"id_menu":7,"count":1}]	22232	delivery	5	14
55849	2020-04-29 02:21:35	2020-04-29	8	[{"id_menu":5,"count":1}]	6765	delivery	5	13
55850	2020-04-29 02:23:14	2020-04-29	12	[{"id_menu":1,"count":1}]	11046	delivery	5	17
55851	2020-04-29 02:26:06	2020-04-29	17	[{"id_menu":4,"count":1}]	18063	pick-up	0	17
55852	2020-04-29 02:26:51	2020-04-29	14	[{"id_menu":2,"count":1}]	6499	delivery	5	19
55853	2020-04-29 02:30:52	2020-04-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	22280	delivery	5	28
55854	2020-04-29 02:35:38	2020-04-29	12	[{"id_menu":3,"count":1}]	19905	delivery	5	17
55855	2020-04-29 02:44:57	2020-04-29	14	[{"id_menu":2,"count":1}]	6741	delivery	5	19
55856	2020-04-29 02:49:52	2020-04-29	9	[{"id_menu":7,"count":1}]	1627	pick-up	0	9
55857	2020-04-29 02:51:02	2020-04-29	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	16152	delivery	5	31
55858	2020-04-29 02:53:47	2020-04-29	14	[{"id_menu":2,"count":1}]	1291	pick-up	0	14
55859	2020-04-29 02:54:05	2020-04-29	17	[{"id_menu":4,"count":1}]	20144	delivery	5	22
55860	2020-04-29 02:55:09	2020-04-29	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	10264	pick-up	0	34
55861	2020-04-29 02:56:21	2020-04-29	12	[{"id_menu":3,"count":1}]	22257	delivery	5	17
55862	2020-04-29 02:59:08	2020-04-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22279	delivery	5	36
55863	2020-04-29 03:03:20	2020-04-29	8	[{"id_menu":5,"count":1}]	22307	delivery	5	13
55864	2020-04-29 03:05:00	2020-04-29	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	22329	delivery	5	25
55865	2020-04-29 03:10:06	2020-04-29	12	[{"id_menu":1,"count":3}]	11988	delivery	5	17
55866	2020-04-29 03:21:45	2020-04-29	17	[{"id_menu":4,"count":1}]	16753	pick-up	0	17
55867	2020-04-29 03:23:58	2020-04-29	12	[{"id_menu":3,"count":1}]	18034	delivery	5	17
55868	2020-04-29 03:26:01	2020-04-29	17	[{"id_menu":4,"count":1}]	5244	delivery	5	22
55869	2020-04-29 03:27:23	2020-04-29	14	[{"id_menu":2,"count":1}]	13196	delivery	5	19
55870	2020-04-29 03:28:10	2020-04-29	12	[{"id_menu":1,"count":1}]	22318	delivery	5	17
55871	2020-04-29 03:32:03	2020-04-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	22228	delivery	5	23
55872	2020-04-29 03:32:22	2020-04-29	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9892	delivery	5	43
55873	2020-04-29 03:32:39	2020-04-29	12	[{"id_menu":3,"count":1}]	16238	delivery	5	17
55874	2020-04-29 03:36:03	2020-04-29	9	[{"id_menu":7,"count":1}]	18330	delivery	5	14
55875	2020-04-29 03:39:46	2020-04-29	8	[{"id_menu":5,"count":1}]	3350	delivery	5	13
55876	2020-04-29 03:41:10	2020-04-29	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22217	delivery	5	35
55877	2020-04-29 03:52:30	2020-04-29	9	[{"id_menu":7,"count":1}]	13111	delivery	5	14
55878	2020-04-29 03:52:51	2020-04-29	9	[{"id_menu":6,"count":1}]	22258	delivery	5	14
55879	2020-04-29 03:53:01	2020-04-29	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	5526	delivery	5	31
55880	2020-04-29 04:00:23	2020-04-29	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	9313	delivery	5	35
55881	2020-04-29 04:03:52	2020-04-29	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	22259	delivery	5	40
55882	2020-04-29 04:13:32	2020-04-29	9	[{"id_menu":7,"count":1}]	22379	delivery	5	14
55883	2020-04-29 04:17:59	2020-04-29	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1055	delivery	5	45
55884	2020-04-29 04:27:37	2020-04-29	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22364	delivery	5	39
55885	2020-04-29 04:34:42	2020-04-29	14	[{"id_menu":2,"count":2}]	4431	pick-up	0	14
55886	2020-04-29 04:38:28	2020-04-29	12	[{"id_menu":3,"count":1}]	22319	delivery	5	17
55887	2020-04-29 04:40:07	2020-04-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	20832	delivery	5	28
55888	2020-04-29 04:40:44	2020-04-29	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13188	delivery	5	31
55889	2020-04-29 04:45:20	2020-04-29	12	[{"id_menu":1,"count":1}]	22327	delivery	5	17
55890	2020-04-29 04:46:02	2020-04-29	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	22309	pick-up	0	29
55891	2020-04-29 04:47:12	2020-04-29	9	[{"id_menu":7,"count":1}]	9820	pick-up	0	9
55892	2020-04-29 04:48:55	2020-04-29	9	[{"id_menu":6,"count":1}]	11792	delivery	5	14
55893	2020-04-29 04:53:40	2020-04-29	14	[{"id_menu":2,"count":2}]	1179	delivery	5	19
55894	2020-04-29 04:53:40	2020-04-29	12	[{"id_menu":3,"count":1}]	6242	pick-up	0	12
55895	2020-04-29 04:56:22	2020-04-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":3}]	22367	delivery	5	31
55896	2020-04-29 04:56:32	2020-04-29	12	[{"id_menu":3,"count":1}]	4690	delivery	5	17
55897	2020-04-29 04:58:11	2020-04-29	9	[{"id_menu":6,"count":1}]	22224	delivery	5	14
55898	2020-04-29 04:59:25	2020-04-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16444	delivery	5	31
55899	2020-04-29 05:10:19	2020-04-29	12	[{"id_menu":1,"count":1}]	22235	delivery	5	17
55900	2020-04-29 05:18:26	2020-04-29	17	[{"id_menu":4,"count":1}]	6164	pick-up	0	17
55901	2020-04-29 05:21:09	2020-04-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	11550	delivery	5	28
55902	2020-04-29 05:26:36	2020-04-29	38	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7706	pick-up	0	38
55903	2020-04-29 05:28:33	2020-04-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4577	pick-up	0	26
55904	2020-04-29 05:31:08	2020-04-29	8	[{"id_menu":5,"count":1}]	21888	delivery	5	13
55905	2020-04-29 05:32:20	2020-04-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3111	pick-up	0	21
55906	2020-04-29 05:38:09	2020-04-29	8	[{"id_menu":5,"count":1}]	22227	delivery	5	13
55907	2020-04-29 05:38:27	2020-04-29	17	[{"id_menu":4,"count":3}]	21748	delivery	5	22
55908	2020-04-29 05:40:31	2020-04-29	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	18035	delivery	5	38
55909	2020-04-29 05:44:38	2020-04-29	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5791	delivery	5	34
55910	2020-04-29 05:48:05	2020-04-29	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	22271	pick-up	0	21
55911	2020-04-29 05:49:10	2020-04-29	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	22236	delivery	5	31
55912	2020-04-29 05:49:36	2020-04-29	12	[{"id_menu":1,"count":1}]	9602	pick-up	0	12
55913	2020-04-29 05:59:46	2020-04-29	14	[{"id_menu":2,"count":1}]	14819	delivery	5	19
55914	2020-04-29 06:04:03	2020-04-29	9	[{"id_menu":6,"count":1}]	22375	delivery	5	14
55915	2020-04-29 06:11:20	2020-04-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22305	delivery	5	36
55916	2020-04-29 06:13:13	2020-04-29	8	[{"id_menu":5,"count":1}]	22274	delivery	5	13
55917	2020-04-29 06:14:15	2020-04-29	14	[{"id_menu":2,"count":1}]	2210	delivery	5	19
55918	2020-04-29 06:17:08	2020-04-29	9	[{"id_menu":6,"count":1}]	13829	delivery	5	14
55919	2020-04-29 06:26:30	2020-04-29	14	[{"id_menu":2,"count":1}]	12112	delivery	5	19
55920	2020-04-29 06:35:46	2020-04-29	17	[{"id_menu":4,"count":1}]	3226	pick-up	0	17
55921	2020-04-29 06:41:05	2020-04-29	8	[{"id_menu":5,"count":1}]	22328	delivery	5	13
55922	2020-04-29 06:43:53	2020-04-29	14	[{"id_menu":2,"count":1}]	17711	delivery	5	19
55923	2020-04-29 06:51:24	2020-04-29	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22357	delivery	5	39
55924	2020-04-29 06:57:43	2020-04-29	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	21304	pick-up	0	20
55925	2020-04-29 06:57:59	2020-04-29	17	[{"id_menu":4,"count":1}]	22220	delivery	5	22
55926	2020-04-29 07:04:36	2020-04-29	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	8521	pick-up	0	35
55927	2020-04-29 07:11:35	2020-04-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1306	delivery	5	22
55928	2020-04-29 07:13:50	2020-04-29	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	22353	delivery	5	34
55929	2020-04-29 07:14:08	2020-04-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22317	delivery	5	22
55930	2020-04-29 07:22:41	2020-04-29	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	21826	delivery	5	31
55931	2020-04-29 07:23:22	2020-04-29	12	[{"id_menu":3,"count":1}]	22264	delivery	5	17
55932	2020-04-29 07:24:50	2020-04-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19857	delivery	5	36
55933	2020-04-29 07:31:05	2020-04-29	9	[{"id_menu":6,"count":1}]	22288	delivery	5	14
55934	2020-04-29 07:32:56	2020-04-29	8	[{"id_menu":5,"count":1}]	61	pick-up	0	8
55935	2020-04-29 07:34:27	2020-04-29	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	22306	delivery	5	39
55936	2020-04-29 07:36:09	2020-04-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	20820	pick-up	0	26
55937	2020-04-29 07:38:38	2020-04-29	12	[{"id_menu":3,"count":1}]	22347	pick-up	0	12
55938	2020-04-29 07:44:32	2020-04-29	12	[{"id_menu":1,"count":1}]	9834	delivery	5	17
55939	2020-04-29 07:45:16	2020-04-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	22358	delivery	5	31
55940	2020-04-29 07:51:04	2020-04-29	17	[{"id_menu":4,"count":1}]	20229	delivery	5	22
55941	2020-04-29 07:53:54	2020-04-29	9	[{"id_menu":7,"count":1}]	2561	pick-up	0	9
55942	2020-04-29 07:55:33	2020-04-29	9	[{"id_menu":7,"count":1}]	2824	pick-up	0	9
55943	2020-04-29 07:59:51	2020-04-29	17	[{"id_menu":4,"count":1}]	5005	delivery	5	22
55944	2020-04-29 08:02:51	2020-04-29	8	[{"id_menu":5,"count":1}]	3382	pick-up	0	8
55945	2020-04-29 08:05:17	2020-04-29	9	[{"id_menu":7,"count":1}]	8595	pick-up	0	9
55946	2020-04-29 08:14:10	2020-04-29	9	[{"id_menu":7,"count":1}]	22321	delivery	5	14
55947	2020-04-29 08:14:17	2020-04-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	22213	delivery	5	26
55948	2020-04-29 08:14:24	2020-04-29	9	[{"id_menu":6,"count":1}]	11587	delivery	5	14
55949	2020-04-29 08:18:22	2020-04-29	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	808	pick-up	0	29
55950	2020-04-29 08:18:54	2020-04-29	9	[{"id_menu":7,"count":1}]	1982	pick-up	0	9
55951	2020-04-29 08:21:19	2020-04-29	12	[{"id_menu":1,"count":1}]	19747	pick-up	0	12
55952	2020-04-29 08:25:39	2020-04-29	9	[{"id_menu":6,"count":1}]	12461	delivery	5	14
55953	2020-04-29 08:25:50	2020-04-29	17	[{"id_menu":4,"count":1}]	11028	pick-up	0	17
55954	2020-04-29 08:41:31	2020-04-29	17	[{"id_menu":4,"count":1}]	2891	pick-up	0	17
55955	2020-04-29 08:44:06	2020-04-29	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	9312	delivery	5	44
55956	2020-04-29 08:46:36	2020-04-29	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	22247	delivery	5	26
55957	2020-04-29 08:47:59	2020-04-29	9	[{"id_menu":6,"count":1}]	21752	delivery	5	14
55958	2020-04-29 08:49:54	2020-04-29	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	6941	pick-up	0	26
55959	2020-04-29 09:01:01	2020-04-29	9	[{"id_menu":7,"count":2}]	5138	pick-up	0	9
55960	2020-04-29 09:08:08	2020-04-29	12	[{"id_menu":1,"count":2}]	22352	delivery	5	17
55961	2020-04-29 09:09:14	2020-04-29	14	[{"id_menu":2,"count":1}]	22334	delivery	5	19
55962	2020-04-29 09:10:09	2020-04-29	14	[{"id_menu":2,"count":1}]	853	pick-up	0	14
55963	2020-04-29 09:19:00	2020-04-29	9	[{"id_menu":6,"count":2}]	22234	delivery	5	14
55964	2020-04-29 09:23:27	2020-04-29	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3447	delivery	5	34
55965	2020-04-29 09:32:47	2020-04-29	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	29	delivery	5	36
55966	2020-04-29 09:34:51	2020-04-29	9	[{"id_menu":7,"count":1}]	11069	delivery	5	14
55967	2020-04-29 09:35:15	2020-04-29	9	[{"id_menu":6,"count":1}]	22267	delivery	5	14
55968	2020-04-29 09:38:01	2020-04-29	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	5267	pick-up	0	29
55969	2020-04-29 09:39:36	2020-04-29	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	22253	delivery	5	36
55970	2020-04-29 09:41:56	2020-04-29	12	[{"id_menu":1,"count":1}]	22303	delivery	5	17
55971	2020-04-29 09:42:32	2020-04-29	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	22362	delivery	5	43
55972	2020-04-29 09:46:03	2020-04-29	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11277	delivery	5	39
55973	2020-04-29 09:47:00	2020-04-29	12	[{"id_menu":3,"count":1}]	9304	pick-up	0	12
55974	2020-04-29 09:49:04	2020-04-29	14	[{"id_menu":2,"count":1}]	19828	pick-up	0	14
55975	2020-04-29 09:50:39	2020-04-29	9	[{"id_menu":6,"count":1}]	18490	delivery	5	14
55976	2020-04-29 09:51:49	2020-04-29	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2806	delivery	5	45
55977	2020-04-29 09:51:50	2020-04-29	12	[{"id_menu":1,"count":1}]	22365	delivery	5	17
55978	2020-04-29 09:52:15	2020-04-29	9	[{"id_menu":6,"count":1}]	1905	pick-up	0	9
55979	2020-04-29 09:54:03	2020-04-29	9	[{"id_menu":7,"count":1}]	12068	delivery	5	14
55980	2020-04-29 09:54:46	2020-04-29	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	22276	delivery	5	25
55981	2020-04-29 09:55:51	2020-04-29	12	[{"id_menu":1,"count":1}]	21386	pick-up	0	12
55982	2020-04-29 09:56:12	2020-04-29	17	[{"id_menu":4,"count":1}]	22297	delivery	5	22
55983	2020-04-29 09:58:04	2020-04-29	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2954	pick-up	0	20
55984	2020-04-29 10:04:00	2020-04-29	8	[{"id_menu":5,"count":1}]	20035	delivery	5	13
55985	2020-04-29 10:08:22	2020-04-29	12	[{"id_menu":1,"count":1}]	22272	delivery	5	17
55986	2020-04-29 10:09:24	2020-04-29	8	[{"id_menu":5,"count":1}]	20503	pick-up	0	8
55987	2020-04-29 10:10:49	2020-04-29	14	[{"id_menu":2,"count":1}]	17732	delivery	5	19
55988	2020-04-29 10:11:12	2020-04-29	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	15565	pick-up	0	20
55989	2020-04-29 10:11:51	2020-04-29	9	[{"id_menu":6,"count":1}]	7572	pick-up	0	9
55990	2020-04-29 10:11:58	2020-04-29	8	[{"id_menu":5,"count":1}]	22244	delivery	5	13
55991	2020-04-29 10:12:55	2020-04-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	10968	pick-up	0	21
55992	2020-04-29 10:14:26	2020-04-29	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	22348	delivery	5	34
55993	2020-04-29 10:17:12	2020-04-29	17	[{"id_menu":4,"count":1}]	8146	delivery	5	22
55994	2020-04-29 10:20:36	2020-04-29	9	[{"id_menu":6,"count":1}]	5040	delivery	5	14
55995	2020-04-29 10:20:41	2020-04-29	17	[{"id_menu":4,"count":1}]	22338	pick-up	0	17
55996	2020-04-29 10:28:38	2020-04-29	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	13303	delivery	5	40
55997	2020-04-29 10:32:24	2020-04-29	9	[{"id_menu":7,"count":1}]	22242	delivery	5	14
55998	2020-04-29 10:33:07	2020-04-29	14	[{"id_menu":2,"count":1}]	11208	delivery	5	19
55999	2020-04-29 10:34:50	2020-04-29	8	[{"id_menu":5,"count":1}]	8873	pick-up	0	8
56000	2020-04-29 10:35:11	2020-04-29	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22285	delivery	5	45
56001	2020-04-29 10:38:19	2020-04-29	9	[{"id_menu":6,"count":1}]	16406	pick-up	0	9
56002	2020-04-29 10:40:13	2020-04-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	22369	delivery	5	31
56003	2020-04-29 10:46:05	2020-04-29	9	[{"id_menu":6,"count":1}]	11969	pick-up	0	9
56004	2020-04-29 10:54:55	2020-04-29	14	[{"id_menu":2,"count":1}]	22322	delivery	5	19
56005	2020-04-29 10:58:03	2020-04-29	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	18119	pick-up	0	34
56006	2020-04-29 10:58:25	2020-04-29	12	[{"id_menu":1,"count":1}]	17366	delivery	5	17
56007	2020-04-29 11:00:44	2020-04-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10444	delivery	5	22
56008	2020-04-29 11:01:54	2020-04-29	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	18980	pick-up	0	20
56009	2020-04-29 11:02:25	2020-04-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":3}]	22316	delivery	5	26
56010	2020-04-29 11:03:12	2020-04-29	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":2}]	21133	delivery	5	27
56011	2020-04-29 11:06:17	2020-04-29	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	4560	delivery	5	26
56012	2020-04-29 11:06:58	2020-04-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7179	delivery	5	31
56013	2020-04-29 11:07:09	2020-04-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6232	pick-up	0	23
56014	2020-04-29 11:10:57	2020-04-29	12	[{"id_menu":3,"count":1}]	2470	pick-up	0	12
56015	2020-04-29 11:16:49	2020-04-29	14	[{"id_menu":2,"count":1}]	21940	delivery	5	19
56016	2020-04-29 11:22:14	2020-04-29	9	[{"id_menu":7,"count":1}]	18005	pick-up	0	9
56017	2020-04-29 11:25:50	2020-04-29	9	[{"id_menu":7,"count":1}]	22265	delivery	5	14
56018	2020-04-29 11:32:37	2020-04-29	9	[{"id_menu":6,"count":1}]	20595	pick-up	0	9
56019	2020-04-29 11:36:08	2020-04-29	14	[{"id_menu":2,"count":1}]	10151	delivery	5	19
56020	2020-04-29 11:40:18	2020-04-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14002	delivery	5	22
56021	2020-04-29 11:40:54	2020-04-29	14	[{"id_menu":2,"count":2}]	12302	delivery	5	19
56022	2020-04-29 11:47:58	2020-04-29	12	[{"id_menu":3,"count":1}]	22287	pick-up	0	12
56023	2020-04-29 11:57:45	2020-04-29	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	18520	delivery	5	31
56024	2020-04-29 12:07:12	2020-04-29	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	18815	delivery	5	35
56025	2020-04-29 12:07:49	2020-04-29	12	[{"id_menu":1,"count":1}]	43	pick-up	0	12
56026	2020-04-29 12:13:22	2020-04-29	12	[{"id_menu":1,"count":1}]	3528	delivery	5	17
56027	2020-04-29 12:14:29	2020-04-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12231	delivery	5	22
56028	2020-04-29 12:23:22	2020-04-29	9	[{"id_menu":7,"count":1}]	22248	pick-up	0	9
56029	2020-04-29 12:24:16	2020-04-29	14	[{"id_menu":2,"count":1}]	2426	delivery	5	19
56030	2020-04-29 12:24:28	2020-04-29	12	[{"id_menu":3,"count":1}]	11083	delivery	5	17
56031	2020-04-29 12:24:52	2020-04-29	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	12853	delivery	5	42
56032	2020-04-29 12:25:09	2020-04-29	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2252	pick-up	0	35
56033	2020-04-29 12:25:27	2020-04-29	14	[{"id_menu":2,"count":1}]	9562	delivery	5	19
56034	2020-04-29 12:25:58	2020-04-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	9086	pick-up	0	23
56035	2020-04-29 12:27:45	2020-04-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2543	pick-up	0	17
56036	2020-04-29 12:37:01	2020-04-29	9	[{"id_menu":6,"count":1}]	2450	delivery	5	14
56037	2020-04-29 12:37:39	2020-04-29	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	4837	delivery	5	45
56038	2020-04-29 12:41:45	2020-04-29	17	[{"id_menu":4,"count":1}]	527	pick-up	0	17
56039	2020-04-29 12:44:48	2020-04-29	9	[{"id_menu":7,"count":1}]	16333	pick-up	0	9
56040	2020-04-29 12:44:57	2020-04-29	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	9103	delivery	5	39
56041	2020-04-29 12:46:44	2020-04-29	9	[{"id_menu":7,"count":1}]	22315	delivery	5	14
56042	2020-04-29 12:50:11	2020-04-29	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	22351	delivery	5	43
56043	2020-04-29 12:56:31	2020-04-29	9	[{"id_menu":7,"count":1}]	3963	delivery	5	14
56044	2020-04-29 13:04:31	2020-04-29	17	[{"id_menu":4,"count":1}]	10859	delivery	5	22
56045	2020-04-29 13:05:02	2020-04-29	9	[{"id_menu":7,"count":2}]	14285	delivery	5	14
56046	2020-04-29 13:06:00	2020-04-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	22211	delivery	5	31
56047	2020-04-29 13:07:25	2020-04-29	8	[{"id_menu":5,"count":1}]	1118	delivery	5	13
56048	2020-04-29 13:11:17	2020-04-29	9	[{"id_menu":6,"count":1}]	22254	delivery	5	14
56049	2020-04-29 13:15:43	2020-04-29	9	[{"id_menu":6,"count":1}]	2118	pick-up	0	9
56050	2020-04-29 13:18:39	2020-04-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3888	delivery	5	27
56051	2020-04-29 13:20:14	2020-04-29	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	17306	pick-up	0	29
56052	2020-04-29 13:21:30	2020-04-29	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	809	delivery	5	43
56053	2020-04-29 13:23:21	2020-04-29	14	[{"id_menu":2,"count":1}]	5467	delivery	5	19
56054	2020-04-29 13:24:19	2020-04-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9166	delivery	5	36
56055	2020-04-29 13:26:07	2020-04-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11267	delivery	5	22
56056	2020-04-29 13:28:08	2020-04-29	9	[{"id_menu":6,"count":1}]	16033	delivery	5	14
56057	2020-04-29 13:30:30	2020-04-29	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15679	delivery	5	52
56058	2020-04-29 13:32:32	2020-04-29	12	[{"id_menu":1,"count":1}]	14339	pick-up	0	12
56059	2020-04-29 13:34:00	2020-04-29	9	[{"id_menu":6,"count":1}]	22261	delivery	5	14
56060	2020-04-29 13:39:00	2020-04-29	9	[{"id_menu":6,"count":1}]	16803	pick-up	0	9
56061	2020-04-29 13:42:18	2020-04-29	14	[{"id_menu":2,"count":1}]	1136	pick-up	0	14
56062	2020-04-29 13:43:40	2020-04-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2731	pick-up	0	22
56063	2020-04-29 13:47:46	2020-04-29	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	22346	delivery	5	34
56064	2020-04-29 13:48:56	2020-04-29	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	22122	delivery	5	34
56065	2020-04-29 13:50:28	2020-04-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11070	delivery	5	31
56066	2020-04-29 13:52:12	2020-04-29	9	[{"id_menu":7,"count":1}]	18881	delivery	5	14
56067	2020-04-29 13:54:20	2020-04-29	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	18171	delivery	5	30
56068	2020-04-29 13:55:34	2020-04-29	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	15314	delivery	5	34
56069	2020-04-29 13:57:11	2020-04-29	12	[{"id_menu":3,"count":1}]	19311	delivery	5	17
56070	2020-04-29 13:59:24	2020-04-29	14	[{"id_menu":2,"count":1}]	9404	pick-up	0	14
56071	2020-04-29 14:07:37	2020-04-29	9	[{"id_menu":7,"count":1}]	22249	delivery	5	14
56072	2020-04-29 14:07:38	2020-04-29	17	[{"id_menu":4,"count":1}]	22310	delivery	5	22
56073	2020-04-29 14:07:42	2020-04-29	9	[{"id_menu":7,"count":1}]	4702	delivery	5	14
56074	2020-04-29 14:09:18	2020-04-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19372	delivery	5	22
56075	2020-04-29 14:15:41	2020-04-29	9	[{"id_menu":6,"count":1}]	12552	pick-up	0	9
56076	2020-04-29 14:16:32	2020-04-29	17	[{"id_menu":4,"count":1}]	21038	delivery	5	22
56077	2020-04-29 14:20:10	2020-04-29	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	22361	delivery	5	23
56078	2020-04-29 14:22:40	2020-04-29	17	[{"id_menu":4,"count":1}]	458	delivery	5	22
56079	2020-04-29 14:22:59	2020-04-29	17	[{"id_menu":4,"count":1}]	22229	delivery	5	22
56080	2020-04-29 14:23:28	2020-04-29	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	19434	delivery	5	31
56081	2020-04-29 14:25:48	2020-04-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	14529	delivery	5	23
56082	2020-04-29 14:30:40	2020-04-29	9	[{"id_menu":7,"count":1}]	15022	delivery	5	14
56083	2020-04-29 14:32:37	2020-04-29	17	[{"id_menu":4,"count":2}]	22233	delivery	5	22
56084	2020-04-29 14:32:55	2020-04-29	9	[{"id_menu":7,"count":1}]	18705	delivery	5	14
56085	2020-04-29 14:34:11	2020-04-29	8	[{"id_menu":5,"count":1}]	2085	pick-up	0	8
56086	2020-04-29 14:36:39	2020-04-29	14	[{"id_menu":2,"count":1}]	3493	delivery	5	19
56087	2020-04-29 14:40:19	2020-04-29	9	[{"id_menu":6,"count":1}]	19607	delivery	5	14
56088	2020-04-29 14:43:00	2020-04-29	9	[{"id_menu":7,"count":1}]	9791	delivery	5	14
56089	2020-04-29 14:49:57	2020-04-29	9	[{"id_menu":7,"count":1}]	22344	delivery	5	14
56090	2020-04-29 14:54:36	2020-04-29	9	[{"id_menu":7,"count":1}]	9095	delivery	5	14
56091	2020-04-29 15:01:06	2020-04-29	9	[{"id_menu":7,"count":1}]	5293	pick-up	0	9
56092	2020-04-29 15:01:21	2020-04-29	8	[{"id_menu":5,"count":1}]	22219	delivery	5	13
56093	2020-04-29 15:01:21	2020-04-29	12	[{"id_menu":3,"count":1}]	16598	delivery	5	17
56094	2020-04-29 15:06:16	2020-04-29	9	[{"id_menu":6,"count":1}]	11035	pick-up	0	9
56095	2020-04-29 15:10:52	2020-04-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3333	delivery	5	22
56096	2020-04-29 15:12:17	2020-04-29	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	5655	delivery	5	27
56097	2020-04-29 15:15:29	2020-04-29	9	[{"id_menu":6,"count":1}]	22376	pick-up	0	9
56098	2020-04-29 15:15:34	2020-04-29	9	[{"id_menu":7,"count":1}]	10442	delivery	5	14
56099	2020-04-29 15:19:15	2020-04-29	14	[{"id_menu":2,"count":1}]	22332	delivery	5	19
56100	2020-04-29 15:22:23	2020-04-29	14	[{"id_menu":2,"count":1}]	13371	delivery	5	19
56101	2020-04-29 15:30:32	2020-04-29	9	[{"id_menu":6,"count":1}]	11367	delivery	5	14
56102	2020-04-29 15:31:04	2020-04-29	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	19729	delivery	5	38
56103	2020-04-29 15:35:55	2020-04-29	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	22335	delivery	5	34
56104	2020-04-29 15:42:54	2020-04-29	9	[{"id_menu":7,"count":1}]	22345	delivery	5	14
56105	2020-04-29 15:44:44	2020-04-29	14	[{"id_menu":2,"count":1}]	7539	delivery	5	19
56106	2020-04-29 15:47:00	2020-04-29	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	22291	delivery	5	34
56107	2020-04-29 15:47:55	2020-04-29	14	[{"id_menu":2,"count":1}]	22330	delivery	5	19
56108	2020-04-29 15:48:51	2020-04-29	12	[{"id_menu":3,"count":1}]	22255	delivery	5	17
56109	2020-04-29 15:49:30	2020-04-29	9	[{"id_menu":6,"count":1}]	22314	delivery	5	14
56110	2020-04-29 15:56:41	2020-04-29	17	[{"id_menu":4,"count":1}]	22340	delivery	5	22
56111	2020-04-29 15:59:53	2020-04-29	14	[{"id_menu":2,"count":1}]	21595	pick-up	0	14
56112	2020-04-29 16:00:45	2020-04-29	8	[{"id_menu":5,"count":1}]	5361	pick-up	0	8
56113	2020-04-29 16:00:52	2020-04-29	8	[{"id_menu":5,"count":1}]	22283	delivery	5	13
56114	2020-04-29 16:04:24	2020-04-29	12	[{"id_menu":3,"count":2}]	22360	delivery	5	17
56115	2020-04-29 16:04:57	2020-04-29	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	12019	pick-up	0	21
56116	2020-04-29 16:06:41	2020-04-29	14	[{"id_menu":2,"count":1}]	17999	delivery	5	19
56117	2020-04-29 16:07:09	2020-04-29	9	[{"id_menu":6,"count":1}]	18366	delivery	5	14
56118	2020-04-29 16:10:55	2020-04-29	9	[{"id_menu":7,"count":1}]	21246	delivery	5	14
56119	2020-04-29 16:28:24	2020-04-29	12	[{"id_menu":1,"count":1}]	2803	pick-up	0	12
56120	2020-04-29 16:31:41	2020-04-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14924	delivery	5	23
56121	2020-04-29 16:32:27	2020-04-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	22252	delivery	5	36
56122	2020-04-29 16:47:55	2020-04-29	14	[{"id_menu":2,"count":1}]	22372	delivery	5	19
56123	2020-04-29 16:50:00	2020-04-29	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	6519	delivery	5	35
56124	2020-04-29 16:51:44	2020-04-29	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":2}]	18951	delivery	5	22
56125	2020-04-29 16:53:55	2020-04-29	9	[{"id_menu":6,"count":1}]	13006	delivery	5	14
56126	2020-04-29 16:56:04	2020-04-29	12	[{"id_menu":1,"count":1}]	4467	pick-up	0	12
56127	2020-04-29 17:04:30	2020-04-29	9	[{"id_menu":6,"count":1}]	20680	delivery	5	14
56128	2020-04-29 17:07:00	2020-04-29	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7200	delivery	5	34
56129	2020-04-29 17:12:16	2020-04-29	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1715	delivery	5	25
56130	2020-04-29 17:12:29	2020-04-29	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	7888	delivery	5	37
56131	2020-04-29 17:13:25	2020-04-29	9	[{"id_menu":6,"count":1}]	20507	delivery	5	14
56132	2020-04-29 17:27:38	2020-04-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	22231	delivery	5	26
56133	2020-04-29 17:27:50	2020-04-29	8	[{"id_menu":5,"count":1}]	19132	delivery	5	13
56134	2020-04-29 17:30:04	2020-04-29	12	[{"id_menu":1,"count":1}]	1806	delivery	5	17
56135	2020-04-29 17:32:34	2020-04-29	9	[{"id_menu":6,"count":1}]	36	pick-up	0	9
56136	2020-04-29 17:34:41	2020-04-29	9	[{"id_menu":6,"count":1}]	21978	pick-up	0	9
56137	2020-04-29 17:35:22	2020-04-29	9	[{"id_menu":6,"count":1}]	940	delivery	5	14
56138	2020-04-29 17:43:46	2020-04-29	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	22333	delivery	5	26
56139	2020-04-29 17:57:26	2020-04-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12467	delivery	5	23
56140	2020-04-29 17:58:35	2020-04-29	12	[{"id_menu":1,"count":1}]	22221	delivery	5	17
56141	2020-04-29 18:00:39	2020-04-29	9	[{"id_menu":6,"count":1}]	22284	pick-up	0	9
56142	2020-04-29 18:06:20	2020-04-29	12	[{"id_menu":1,"count":1}]	3678	delivery	5	17
56143	2020-04-29 18:09:22	2020-04-29	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	22225	delivery	5	44
56144	2020-04-29 18:11:09	2020-04-29	9	[{"id_menu":6,"count":1}]	22209	pick-up	0	9
56145	2020-04-29 18:11:15	2020-04-29	9	[{"id_menu":7,"count":1}]	21811	delivery	5	14
56146	2020-04-29 18:11:25	2020-04-29	17	[{"id_menu":4,"count":1}]	13837	pick-up	0	17
56147	2020-04-29 18:14:37	2020-04-29	14	[{"id_menu":2,"count":2}]	22374	delivery	5	19
56148	2020-04-29 18:22:37	2020-04-29	8	[{"id_menu":5,"count":1}]	2836	pick-up	0	8
56149	2020-04-29 18:26:53	2020-04-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22250	delivery	5	23
56150	2020-04-29 18:28:03	2020-04-29	12	[{"id_menu":1,"count":1}]	7293	delivery	5	17
56151	2020-04-29 18:35:46	2020-04-29	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22355	delivery	5	31
56152	2020-04-29 18:42:26	2020-04-29	12	[{"id_menu":3,"count":1}]	8050	delivery	5	17
56153	2020-04-29 18:43:24	2020-04-29	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	22222	delivery	5	30
56154	2020-04-29 18:43:36	2020-04-29	14	[{"id_menu":2,"count":1}]	21322	pick-up	0	14
56155	2020-04-29 18:47:07	2020-04-29	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	20154	delivery	5	40
56156	2020-04-29 18:47:40	2020-04-29	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	22293	delivery	5	39
56157	2020-04-29 18:49:27	2020-04-29	8	[{"id_menu":5,"count":1}]	11589	delivery	5	13
56158	2020-04-29 18:50:26	2020-04-29	14	[{"id_menu":2,"count":1}]	17197	pick-up	0	14
56159	2020-04-29 18:52:24	2020-04-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	22312	delivery	5	26
56160	2020-04-29 18:53:36	2020-04-29	14	[{"id_menu":2,"count":1}]	6245	delivery	5	19
56161	2020-04-29 18:54:46	2020-04-29	12	[{"id_menu":1,"count":1}]	13927	delivery	5	17
56162	2020-04-29 18:57:54	2020-04-29	17	[{"id_menu":4,"count":1}]	22341	delivery	5	22
56163	2020-04-29 19:02:40	2020-04-29	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	22371	delivery	5	45
56164	2020-04-29 19:09:52	2020-04-29	14	[{"id_menu":2,"count":1}]	1563	delivery	5	19
56165	2020-04-29 19:10:26	2020-04-29	9	[{"id_menu":6,"count":1}]	11695	delivery	5	14
56166	2020-04-29 19:18:39	2020-04-29	14	[{"id_menu":2,"count":1}]	16222	pick-up	0	14
56167	2020-04-29 19:19:54	2020-04-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	17190	delivery	5	27
56168	2020-04-29 19:22:01	2020-04-29	9	[{"id_menu":6,"count":1}]	3972	delivery	5	14
56169	2020-04-29 19:23:14	2020-04-29	9	[{"id_menu":6,"count":1}]	22216	delivery	5	14
56170	2020-04-29 19:27:18	2020-04-29	9	[{"id_menu":7,"count":1}]	1139	delivery	5	14
56171	2020-04-29 19:30:37	2020-04-29	9	[{"id_menu":6,"count":1}]	22337	pick-up	0	9
56172	2020-04-29 19:36:47	2020-04-29	9	[{"id_menu":6,"count":2}]	22342	delivery	5	14
56173	2020-04-29 19:41:55	2020-04-29	8	[{"id_menu":5,"count":1}]	9193	pick-up	0	8
56174	2020-04-29 19:49:30	2020-04-29	9	[{"id_menu":7,"count":1}]	22324	delivery	5	14
56175	2020-04-29 19:51:37	2020-04-29	9	[{"id_menu":7,"count":1}]	5963	pick-up	0	9
56176	2020-04-29 19:58:28	2020-04-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	22218	delivery	5	28
56177	2020-04-29 20:01:15	2020-04-29	17	[{"id_menu":4,"count":1}]	906	pick-up	0	17
56178	2020-04-29 20:03:18	2020-04-29	17	[{"id_menu":4,"count":1}]	22331	delivery	5	22
56179	2020-04-29 20:12:25	2020-04-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	22299	delivery	5	31
56180	2020-04-29 20:20:07	2020-04-29	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	16844	delivery	5	40
56181	2020-04-29 20:24:17	2020-04-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	10507	delivery	5	26
56182	2020-04-29 20:31:55	2020-04-29	9	[{"id_menu":7,"count":1}]	22339	delivery	5	14
56183	2020-04-29 20:38:54	2020-04-29	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13713	delivery	5	43
56184	2020-04-29 20:57:04	2020-04-29	12	[{"id_menu":3,"count":1}]	22278	delivery	5	17
56185	2020-04-29 21:02:27	2020-04-29	12	[{"id_menu":1,"count":1}]	22373	delivery	5	17
56186	2020-04-29 21:06:19	2020-04-29	8	[{"id_menu":5,"count":1}]	172	delivery	5	13
56187	2020-04-29 21:09:54	2020-04-29	9	[{"id_menu":7,"count":1}]	22359	delivery	5	14
56188	2020-04-29 21:16:25	2020-04-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	22270	delivery	5	31
56189	2020-04-29 21:18:54	2020-04-29	9	[{"id_menu":6,"count":1}]	16544	delivery	5	14
56190	2020-04-29 21:22:55	2020-04-29	9	[{"id_menu":6,"count":2}]	17153	delivery	5	14
56191	2020-04-29 21:27:32	2020-04-29	9	[{"id_menu":7,"count":1}]	22251	delivery	5	14
56192	2020-04-29 21:30:15	2020-04-29	9	[{"id_menu":7,"count":1}]	11961	delivery	5	14
56193	2020-04-29 21:30:58	2020-04-29	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	21502	pick-up	0	21
56194	2020-04-29 21:37:37	2020-04-29	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	11922	delivery	5	40
56195	2020-04-29 21:41:07	2020-04-29	9	[{"id_menu":6,"count":1}]	22368	delivery	5	14
56196	2020-04-29 21:55:33	2020-04-29	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11543	delivery	5	35
56197	2020-04-29 21:59:02	2020-04-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10279	pick-up	0	26
56198	2020-04-29 21:59:16	2020-04-29	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	3835	delivery	5	22
56199	2020-04-29 22:13:51	2020-04-29	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	20029	delivery	5	26
56200	2020-04-29 22:17:50	2020-04-29	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	22289	delivery	5	46
56201	2020-04-29 22:33:21	2020-04-29	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	22212	delivery	5	55
56202	2020-04-29 22:40:53	2020-04-29	9	[{"id_menu":7,"count":1}]	22292	delivery	5	14
56203	2020-04-29 22:48:31	2020-04-29	8	[{"id_menu":5,"count":1}]	22263	delivery	5	13
56204	2020-04-29 22:53:56	2020-04-29	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	13452	delivery	5	31
56205	2020-04-29 22:55:30	2020-04-29	14	[{"id_menu":2,"count":1}]	22296	pick-up	0	14
56206	2020-04-29 22:59:37	2020-04-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	20993	delivery	5	31
56207	2020-04-29 23:03:06	2020-04-29	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21177	delivery	5	40
56208	2020-04-29 23:06:46	2020-04-29	9	[{"id_menu":6,"count":1}]	22363	delivery	5	14
56209	2020-04-29 23:09:58	2020-04-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	22273	delivery	5	28
56210	2020-04-29 23:21:01	2020-04-29	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	22354	delivery	5	22
56211	2020-04-29 23:21:53	2020-04-29	12	[{"id_menu":3,"count":1}]	15292	delivery	5	17
56212	2020-04-29 23:26:29	2020-04-29	9	[{"id_menu":6,"count":1}]	17667	delivery	5	14
56213	2020-04-29 23:28:00	2020-04-29	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	22311	delivery	5	29
56214	2020-04-29 23:35:42	2020-04-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	22300	pick-up	0	23
56215	2020-04-29 23:35:43	2020-04-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8612	delivery	5	31
56216	2020-04-29 23:44:27	2020-04-29	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	14032	delivery	5	26
56217	2020-04-29 23:47:49	2020-04-29	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	20844	delivery	5	43
56218	2020-04-29 23:48:53	2020-04-29	9	[{"id_menu":6,"count":2}]	10820	delivery	5	14
56219	2020-04-29 23:49:12	2020-04-29	17	[{"id_menu":4,"count":2}]	8057	delivery	5	22
56220	2020-04-29 23:51:04	2020-04-29	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6786	delivery	5	31
56221	2020-04-29 23:52:08	2020-04-29	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	21078	delivery	5	44
56222	2020-04-29 23:55:14	2020-04-29	8	[{"id_menu":5,"count":1}]	5074	delivery	5	13
56223	2020-04-29 23:59:37	2020-04-29	9	[{"id_menu":7,"count":1}]	22262	delivery	5	14
56224	2020-04-30 00:00:33	2020-04-30	12	[{"id_menu":1,"count":1}]	5332	pick-up	0	12
56225	2020-04-30 00:02:47	2020-04-30	12	[{"id_menu":1,"count":1}]	22381	pick-up	0	12
56226	2020-04-30 00:05:51	2020-04-30	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	22474	delivery	5	26
56227	2020-04-30 00:07:49	2020-04-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	18124	delivery	5	31
56228	2020-04-30 00:09:53	2020-04-30	12	[{"id_menu":1,"count":1}]	3441	delivery	5	17
56229	2020-04-30 00:10:15	2020-04-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	6957	pick-up	0	21
56230	2020-04-30 00:16:00	2020-04-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	22128	delivery	5	31
56231	2020-04-30 00:30:13	2020-04-30	9	[{"id_menu":7,"count":1}]	19126	delivery	5	14
56232	2020-04-30 00:33:37	2020-04-30	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	22400	delivery	5	38
56233	2020-04-30 00:37:46	2020-04-30	9	[{"id_menu":6,"count":1}]	22443	delivery	5	14
56234	2020-04-30 00:38:28	2020-04-30	17	[{"id_menu":4,"count":1}]	8341	delivery	5	22
56235	2020-04-30 00:40:20	2020-04-30	17	[{"id_menu":4,"count":1}]	13536	delivery	5	22
56236	2020-04-30 00:41:10	2020-04-30	12	[{"id_menu":1,"count":1}]	22512	delivery	5	17
56237	2020-04-30 00:41:33	2020-04-30	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	20946	delivery	5	34
56238	2020-04-30 00:44:55	2020-04-30	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20840	delivery	5	34
56239	2020-04-30 00:45:49	2020-04-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	22504	delivery	5	23
56240	2020-04-30 00:46:26	2020-04-30	9	[{"id_menu":6,"count":1}]	22411	delivery	5	14
56241	2020-04-30 00:47:13	2020-04-30	9	[{"id_menu":7,"count":2}]	10935	pick-up	0	9
56242	2020-04-30 00:47:54	2020-04-30	14	[{"id_menu":2,"count":1}]	5503	pick-up	0	14
56243	2020-04-30 00:53:25	2020-04-30	12	[{"id_menu":1,"count":1}]	22502	delivery	5	17
56244	2020-04-30 00:57:54	2020-04-30	12	[{"id_menu":3,"count":1}]	856	delivery	5	17
56245	2020-04-30 01:05:13	2020-04-30	8	[{"id_menu":5,"count":1}]	9127	delivery	5	13
56246	2020-04-30 01:05:41	2020-04-30	8	[{"id_menu":5,"count":1}]	18458	delivery	5	13
56247	2020-04-30 01:08:43	2020-04-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	16193	delivery	5	23
56248	2020-04-30 01:14:27	2020-04-30	12	[{"id_menu":1,"count":1}]	1170	pick-up	0	12
56249	2020-04-30 01:15:44	2020-04-30	9	[{"id_menu":6,"count":1}]	13613	pick-up	0	9
56250	2020-04-30 01:19:54	2020-04-30	14	[{"id_menu":2,"count":3}]	6044	delivery	5	19
56251	2020-04-30 01:23:23	2020-04-30	12	[{"id_menu":3,"count":1}]	338	delivery	5	17
56252	2020-04-30 01:24:51	2020-04-30	9	[{"id_menu":6,"count":1}]	22419	pick-up	0	9
56253	2020-04-30 01:26:51	2020-04-30	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	17701	delivery	5	31
56254	2020-04-30 01:29:10	2020-04-30	9	[{"id_menu":7,"count":1}]	12393	pick-up	0	9
56255	2020-04-30 01:33:06	2020-04-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	4689	delivery	5	23
56256	2020-04-30 01:33:07	2020-04-30	9	[{"id_menu":6,"count":1}]	22437	delivery	5	14
56257	2020-04-30 01:37:10	2020-04-30	8	[{"id_menu":5,"count":1}]	22389	delivery	5	13
56258	2020-04-30 01:40:17	2020-04-30	8	[{"id_menu":5,"count":1}]	22425	delivery	5	13
56259	2020-04-30 01:40:58	2020-04-30	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22418	pick-up	0	35
56260	2020-04-30 01:42:55	2020-04-30	9	[{"id_menu":6,"count":2}]	15020	delivery	5	14
56261	2020-04-30 01:46:30	2020-04-30	14	[{"id_menu":2,"count":1}]	22441	delivery	5	19
56262	2020-04-30 01:46:33	2020-04-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4841	pick-up	0	17
56263	2020-04-30 01:46:50	2020-04-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6752	delivery	5	23
56264	2020-04-30 01:55:06	2020-04-30	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	4939	delivery	5	23
56265	2020-04-30 01:55:44	2020-04-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3289	pick-up	0	23
56266	2020-04-30 01:59:51	2020-04-30	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	14907	delivery	5	23
56267	2020-04-30 02:04:58	2020-04-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17986	delivery	5	22
56268	2020-04-30 02:18:22	2020-04-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8980	delivery	5	31
56269	2020-04-30 02:18:30	2020-04-30	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1854	pick-up	0	20
56270	2020-04-30 02:21:29	2020-04-30	9	[{"id_menu":7,"count":1}]	4838	pick-up	0	9
56271	2020-04-30 02:21:36	2020-04-30	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	22401	delivery	5	43
56272	2020-04-30 02:25:17	2020-04-30	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	806	pick-up	0	32
56273	2020-04-30 02:44:58	2020-04-30	9	[{"id_menu":7,"count":1}]	22426	delivery	5	14
56274	2020-04-30 02:51:20	2020-04-30	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	22414	delivery	5	36
56275	2020-04-30 02:52:11	2020-04-30	8	[{"id_menu":5,"count":1}]	16794	pick-up	0	8
56276	2020-04-30 02:53:09	2020-04-30	9	[{"id_menu":6,"count":1}]	1685	pick-up	0	9
56277	2020-04-30 02:54:24	2020-04-30	9	[{"id_menu":6,"count":1}]	1080	pick-up	0	9
56278	2020-04-30 02:56:57	2020-04-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	22431	delivery	5	22
56279	2020-04-30 02:58:33	2020-04-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21806	delivery	5	22
56280	2020-04-30 02:59:03	2020-04-30	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	8538	delivery	5	26
56281	2020-04-30 03:17:34	2020-04-30	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22384	delivery	5	36
56282	2020-04-30 03:17:57	2020-04-30	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	18680	delivery	5	30
56283	2020-04-30 03:18:08	2020-04-30	8	[{"id_menu":5,"count":1}]	22413	delivery	5	13
56284	2020-04-30 03:22:17	2020-04-30	9	[{"id_menu":6,"count":2}]	22417	delivery	5	14
56285	2020-04-30 03:39:02	2020-04-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7476	delivery	5	31
56286	2020-04-30 03:47:30	2020-04-30	17	[{"id_menu":4,"count":1}]	381	pick-up	0	17
56287	2020-04-30 03:52:30	2020-04-30	12	[{"id_menu":3,"count":1}]	6156	pick-up	0	12
56288	2020-04-30 03:52:46	2020-04-30	14	[{"id_menu":2,"count":1}]	22447	delivery	5	19
56289	2020-04-30 03:53:13	2020-04-30	14	[{"id_menu":2,"count":1}]	12012	pick-up	0	14
56290	2020-04-30 03:53:55	2020-04-30	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14081	pick-up	0	38
56291	2020-04-30 03:54:14	2020-04-30	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4671	delivery	5	37
56292	2020-04-30 03:56:42	2020-04-30	12	[{"id_menu":3,"count":1}]	8748	delivery	5	17
56293	2020-04-30 03:59:16	2020-04-30	14	[{"id_menu":2,"count":1}]	13466	delivery	5	19
56294	2020-04-30 03:59:57	2020-04-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	585	delivery	5	28
56295	2020-04-30 04:07:14	2020-04-30	9	[{"id_menu":7,"count":1}]	21849	delivery	5	14
56296	2020-04-30 04:13:01	2020-04-30	9	[{"id_menu":6,"count":1}]	22507	delivery	5	14
56297	2020-04-30 04:13:15	2020-04-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	7119	pick-up	0	22
56298	2020-04-30 04:18:10	2020-04-30	14	[{"id_menu":2,"count":2}]	22445	pick-up	0	14
56299	2020-04-30 04:18:21	2020-04-30	12	[{"id_menu":1,"count":1}]	17397	delivery	5	17
56300	2020-04-30 04:26:15	2020-04-30	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	6164	pick-up	0	26
56301	2020-04-30 04:27:04	2020-04-30	12	[{"id_menu":1,"count":1}]	1860	pick-up	0	12
56302	2020-04-30 04:29:15	2020-04-30	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11367	delivery	5	35
56303	2020-04-30 04:30:24	2020-04-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11312	delivery	5	23
56304	2020-04-30 04:32:28	2020-04-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2547	pick-up	0	17
56305	2020-04-30 04:33:15	2020-04-30	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6885	delivery	5	36
56306	2020-04-30 04:33:26	2020-04-30	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13694	delivery	5	34
56307	2020-04-30 04:36:39	2020-04-30	9	[{"id_menu":6,"count":1}]	22380	delivery	5	14
56308	2020-04-30 04:38:26	2020-04-30	8	[{"id_menu":5,"count":1}]	15604	delivery	5	13
56309	2020-04-30 04:39:01	2020-04-30	14	[{"id_menu":2,"count":1}]	22435	delivery	5	19
56310	2020-04-30 04:40:50	2020-04-30	14	[{"id_menu":2,"count":1}]	15524	delivery	5	19
56311	2020-04-30 04:42:31	2020-04-30	9	[{"id_menu":6,"count":1}]	10411	delivery	5	14
56312	2020-04-30 04:44:12	2020-04-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	22487	delivery	5	23
56313	2020-04-30 04:44:39	2020-04-30	34	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	16952	delivery	5	39
56314	2020-04-30 04:46:02	2020-04-30	9	[{"id_menu":6,"count":1}]	19418	delivery	5	14
56315	2020-04-30 04:48:05	2020-04-30	12	[{"id_menu":3,"count":1}]	22511	delivery	5	17
56316	2020-04-30 04:57:30	2020-04-30	9	[{"id_menu":6,"count":1}]	20965	delivery	5	14
56317	2020-04-30 05:01:33	2020-04-30	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	12078	delivery	5	29
56318	2020-04-30 05:05:18	2020-04-30	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18593	delivery	5	36
56319	2020-04-30 05:06:01	2020-04-30	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	7731	delivery	5	26
56320	2020-04-30 05:07:45	2020-04-30	8	[{"id_menu":5,"count":1}]	22460	delivery	5	13
56321	2020-04-30 05:10:20	2020-04-30	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	12615	delivery	5	38
56322	2020-04-30 05:16:50	2020-04-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	22440	delivery	5	31
56323	2020-04-30 05:21:29	2020-04-30	14	[{"id_menu":2,"count":2}]	1138	pick-up	0	14
56324	2020-04-30 05:24:51	2020-04-30	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	22421	pick-up	0	21
56325	2020-04-30 05:27:07	2020-04-30	9	[{"id_menu":7,"count":1}]	19294	delivery	5	14
56326	2020-04-30 05:28:26	2020-04-30	9	[{"id_menu":7,"count":1}]	22394	delivery	5	14
56327	2020-04-30 05:31:24	2020-04-30	12	[{"id_menu":1,"count":1}]	22508	pick-up	0	12
56328	2020-04-30 05:34:11	2020-04-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	10328	delivery	5	23
56329	2020-04-30 05:38:31	2020-04-30	14	[{"id_menu":2,"count":1}]	153	delivery	5	19
56330	2020-04-30 05:40:26	2020-04-30	12	[{"id_menu":1,"count":1}]	22482	delivery	5	17
56331	2020-04-30 05:49:57	2020-04-30	9	[{"id_menu":6,"count":1}]	22393	delivery	5	14
56332	2020-04-30 05:51:31	2020-04-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	6168	delivery	5	27
56333	2020-04-30 05:54:39	2020-04-30	17	[{"id_menu":4,"count":1}]	16280	delivery	5	22
56334	2020-04-30 06:00:16	2020-04-30	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	8176	delivery	5	34
56335	2020-04-30 06:08:03	2020-04-30	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16912	delivery	5	43
56336	2020-04-30 06:08:40	2020-04-30	8	[{"id_menu":5,"count":1}]	2440	delivery	5	13
56337	2020-04-30 06:08:58	2020-04-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1945	pick-up	0	18
56338	2020-04-30 06:09:42	2020-04-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	5710	delivery	5	28
56339	2020-04-30 06:10:17	2020-04-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	22494	delivery	5	27
56340	2020-04-30 06:18:34	2020-04-30	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	16999	delivery	5	34
56341	2020-04-30 06:18:54	2020-04-30	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	22466	pick-up	0	26
56342	2020-04-30 06:20:19	2020-04-30	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22399	delivery	5	43
56343	2020-04-30 06:22:26	2020-04-30	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8897	delivery	5	31
56344	2020-04-30 06:23:12	2020-04-30	8	[{"id_menu":5,"count":1}]	8789	pick-up	0	8
56345	2020-04-30 06:26:10	2020-04-30	12	[{"id_menu":1,"count":1}]	22463	delivery	5	17
56346	2020-04-30 06:26:58	2020-04-30	8	[{"id_menu":5,"count":1}]	3040	delivery	5	13
56347	2020-04-30 06:29:01	2020-04-30	9	[{"id_menu":7,"count":1}]	22402	delivery	5	14
56348	2020-04-30 06:29:30	2020-04-30	9	[{"id_menu":6,"count":1}]	22449	pick-up	0	9
56349	2020-04-30 06:31:10	2020-04-30	8	[{"id_menu":5,"count":1}]	22464	pick-up	0	8
56350	2020-04-30 06:32:18	2020-04-30	9	[{"id_menu":7,"count":1}]	13133	pick-up	0	9
56351	2020-04-30 06:35:58	2020-04-30	9	[{"id_menu":7,"count":1}]	527	delivery	5	14
56352	2020-04-30 06:36:01	2020-04-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5954	delivery	5	23
56353	2020-04-30 06:36:04	2020-04-30	14	[{"id_menu":2,"count":2}]	8954	delivery	5	19
56354	2020-04-30 06:40:10	2020-04-30	8	[{"id_menu":5,"count":2}]	330	pick-up	0	8
56355	2020-04-30 06:43:59	2020-04-30	12	[{"id_menu":3,"count":1}]	17568	delivery	5	17
56356	2020-04-30 06:48:06	2020-04-30	8	[{"id_menu":5,"count":1}]	5176	delivery	5	13
56357	2020-04-30 06:48:48	2020-04-30	8	[{"id_menu":5,"count":1}]	9539	delivery	5	13
56358	2020-04-30 06:54:45	2020-04-30	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	20413	pick-up	0	31
56359	2020-04-30 06:57:15	2020-04-30	14	[{"id_menu":2,"count":1}]	21917	delivery	5	19
56360	2020-04-30 07:06:53	2020-04-30	12	[{"id_menu":3,"count":1}]	11406	delivery	5	17
56361	2020-04-30 07:12:27	2020-04-30	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	8014	delivery	5	36
56362	2020-04-30 07:23:10	2020-04-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10416	pick-up	0	26
56363	2020-04-30 07:24:08	2020-04-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	8109	pick-up	0	22
56364	2020-04-30 07:27:34	2020-04-30	9	[{"id_menu":7,"count":1}]	4981	delivery	5	14
56365	2020-04-30 07:28:40	2020-04-30	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	22438	delivery	5	40
56366	2020-04-30 07:32:04	2020-04-30	9	[{"id_menu":6,"count":1}]	9304	pick-up	0	9
56367	2020-04-30 07:38:14	2020-04-30	8	[{"id_menu":5,"count":1}]	3122	delivery	5	13
56368	2020-04-30 07:41:47	2020-04-30	12	[{"id_menu":1,"count":1}]	3596	pick-up	0	12
56369	2020-04-30 07:42:25	2020-04-30	9	[{"id_menu":7,"count":1}]	10380	delivery	5	14
56370	2020-04-30 07:43:18	2020-04-30	12	[{"id_menu":3,"count":1}]	9107	delivery	5	17
56371	2020-04-30 07:45:11	2020-04-30	14	[{"id_menu":2,"count":1}]	9106	pick-up	0	14
56372	2020-04-30 07:50:03	2020-04-30	9	[{"id_menu":7,"count":1}]	18758	pick-up	0	9
56373	2020-04-30 07:53:22	2020-04-30	12	[{"id_menu":3,"count":1}]	22407	delivery	5	17
56374	2020-04-30 07:54:18	2020-04-30	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	22428	delivery	5	34
56375	2020-04-30 08:04:57	2020-04-30	9	[{"id_menu":7,"count":1}]	9846	delivery	5	14
56376	2020-04-30 08:06:13	2020-04-30	17	[{"id_menu":4,"count":1}]	19232	delivery	5	22
56377	2020-04-30 08:09:16	2020-04-30	14	[{"id_menu":2,"count":1}]	5869	pick-up	0	14
56378	2020-04-30 08:10:01	2020-04-30	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	22499	pick-up	0	29
56379	2020-04-30 08:12:12	2020-04-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22422	delivery	5	23
56380	2020-04-30 08:25:04	2020-04-30	9	[{"id_menu":7,"count":1}]	19838	delivery	5	14
56381	2020-04-30 08:25:40	2020-04-30	12	[{"id_menu":1,"count":1}]	22500	delivery	5	17
56382	2020-04-30 08:27:01	2020-04-30	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	13272	delivery	5	39
56383	2020-04-30 08:30:59	2020-04-30	8	[{"id_menu":5,"count":1}]	19861	delivery	5	13
56384	2020-04-30 08:31:06	2020-04-30	9	[{"id_menu":6,"count":1}]	11779	pick-up	0	9
56385	2020-04-30 08:31:08	2020-04-30	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	11789	delivery	5	30
56386	2020-04-30 08:33:32	2020-04-30	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	22457	delivery	5	57
56387	2020-04-30 08:40:29	2020-04-30	17	[{"id_menu":4,"count":1}]	4979	delivery	5	22
56388	2020-04-30 08:42:31	2020-04-30	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1748	pick-up	0	21
56389	2020-04-30 08:53:28	2020-04-30	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	10496	delivery	5	26
56390	2020-04-30 08:54:07	2020-04-30	12	[{"id_menu":1,"count":1}]	22484	delivery	5	17
56391	2020-04-30 08:56:28	2020-04-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22420	delivery	5	23
56392	2020-04-30 08:59:40	2020-04-30	8	[{"id_menu":5,"count":1}]	22475	delivery	5	13
56393	2020-04-30 09:01:19	2020-04-30	14	[{"id_menu":2,"count":1}]	1979	delivery	5	19
56394	2020-04-30 09:04:43	2020-04-30	9	[{"id_menu":6,"count":2}]	10706	pick-up	0	9
56395	2020-04-30 09:07:35	2020-04-30	8	[{"id_menu":5,"count":1}]	16545	delivery	5	13
56396	2020-04-30 09:10:50	2020-04-30	8	[{"id_menu":5,"count":1}]	19481	delivery	5	13
56397	2020-04-30 09:12:51	2020-04-30	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	15496	delivery	5	37
56398	2020-04-30 09:13:21	2020-04-30	9	[{"id_menu":6,"count":1}]	13199	pick-up	0	9
56399	2020-04-30 09:13:36	2020-04-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	7176	delivery	5	28
56400	2020-04-30 09:16:55	2020-04-30	9	[{"id_menu":7,"count":1}]	22461	delivery	5	14
56401	2020-04-30 09:34:28	2020-04-30	12	[{"id_menu":1,"count":1}]	17614	pick-up	0	12
56402	2020-04-30 09:44:24	2020-04-30	17	[{"id_menu":4,"count":1}]	12108	pick-up	0	17
56403	2020-04-30 09:46:45	2020-04-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	21142	delivery	5	26
56404	2020-04-30 09:50:49	2020-04-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":3}]	8585	delivery	5	31
56405	2020-04-30 09:51:00	2020-04-30	8	[{"id_menu":5,"count":1}]	7870	delivery	5	13
56406	2020-04-30 09:56:17	2020-04-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19493	delivery	5	22
56407	2020-04-30 09:57:15	2020-04-30	8	[{"id_menu":5,"count":1}]	18198	delivery	5	13
56408	2020-04-30 09:58:58	2020-04-30	17	[{"id_menu":4,"count":1}]	8371	pick-up	0	17
56409	2020-04-30 10:01:12	2020-04-30	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	22465	delivery	5	31
56410	2020-04-30 10:01:59	2020-04-30	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	22410	delivery	5	48
56411	2020-04-30 10:02:22	2020-04-30	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10999	delivery	5	22
56412	2020-04-30 10:03:34	2020-04-30	14	[{"id_menu":2,"count":1}]	22510	delivery	5	19
56413	2020-04-30 10:05:53	2020-04-30	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	22444	pick-up	0	38
56414	2020-04-30 10:06:01	2020-04-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8791	pick-up	0	26
56415	2020-04-30 10:06:54	2020-04-30	12	[{"id_menu":3,"count":1}]	19212	pick-up	0	12
56416	2020-04-30 10:09:53	2020-04-30	14	[{"id_menu":2,"count":1}]	13987	delivery	5	19
56417	2020-04-30 10:10:28	2020-04-30	12	[{"id_menu":3,"count":1}]	822	delivery	5	17
56418	2020-04-30 10:23:16	2020-04-30	17	[{"id_menu":4,"count":1}]	16891	pick-up	0	17
56419	2020-04-30 10:24:34	2020-04-30	9	[{"id_menu":7,"count":1}]	19705	delivery	5	14
56420	2020-04-30 10:34:27	2020-04-30	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3324	pick-up	0	52
56421	2020-04-30 10:35:16	2020-04-30	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	4782	pick-up	0	26
56422	2020-04-30 10:40:04	2020-04-30	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	21438	delivery	5	25
56423	2020-04-30 10:42:32	2020-04-30	9	[{"id_menu":7,"count":1}]	20352	delivery	5	14
56424	2020-04-30 10:44:22	2020-04-30	9	[{"id_menu":6,"count":1}]	1112	delivery	5	14
56425	2020-04-30 10:51:36	2020-04-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	22483	delivery	5	22
56426	2020-04-30 10:54:42	2020-04-30	8	[{"id_menu":5,"count":1}]	2176	pick-up	0	8
56427	2020-04-30 11:00:24	2020-04-30	12	[{"id_menu":1,"count":1}]	20313	delivery	5	17
56428	2020-04-30 11:03:10	2020-04-30	9	[{"id_menu":6,"count":1}]	11005	delivery	5	14
56429	2020-04-30 11:04:07	2020-04-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1627	pick-up	0	23
56430	2020-04-30 11:04:51	2020-04-30	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	18627	delivery	5	25
56431	2020-04-30 11:12:38	2020-04-30	17	[{"id_menu":4,"count":1}]	22485	delivery	5	22
56432	2020-04-30 11:19:07	2020-04-30	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	6026	delivery	5	25
56433	2020-04-30 11:24:04	2020-04-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6113	delivery	5	22
56434	2020-04-30 11:24:52	2020-04-30	8	[{"id_menu":5,"count":1}]	3125	delivery	5	13
56435	2020-04-30 11:25:01	2020-04-30	12	[{"id_menu":1,"count":1}]	12552	pick-up	0	12
56436	2020-04-30 11:27:00	2020-04-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	22486	delivery	5	22
56437	2020-04-30 11:27:18	2020-04-30	12	[{"id_menu":3,"count":1}]	2443	pick-up	0	12
56438	2020-04-30 11:32:29	2020-04-30	9	[{"id_menu":7,"count":1}]	22403	delivery	5	14
56439	2020-04-30 11:33:15	2020-04-30	8	[{"id_menu":5,"count":1}]	22387	delivery	5	13
56440	2020-04-30 11:35:12	2020-04-30	12	[{"id_menu":1,"count":2}]	9385	delivery	5	17
56441	2020-04-30 11:44:05	2020-04-30	12	[{"id_menu":3,"count":1}]	20579	delivery	5	17
56442	2020-04-30 11:49:52	2020-04-30	12	[{"id_menu":3,"count":1}]	10544	delivery	5	17
56443	2020-04-30 11:56:14	2020-04-30	9	[{"id_menu":7,"count":2}]	780	delivery	5	14
56444	2020-04-30 12:00:37	2020-04-30	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	22396	delivery	5	45
56445	2020-04-30 12:09:22	2020-04-30	14	[{"id_menu":2,"count":1}]	439	pick-up	0	14
56446	2020-04-30 12:10:07	2020-04-30	12	[{"id_menu":3,"count":1}]	20792	delivery	5	17
56447	2020-04-30 12:17:07	2020-04-30	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	17190	delivery	5	26
56448	2020-04-30 12:19:44	2020-04-30	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	11454	pick-up	0	26
56449	2020-04-30 12:20:34	2020-04-30	8	[{"id_menu":5,"count":1}]	22514	delivery	5	13
56450	2020-04-30 12:33:56	2020-04-30	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11961	delivery	5	40
56451	2020-04-30 12:34:18	2020-04-30	9	[{"id_menu":6,"count":1}]	21054	delivery	5	14
56452	2020-04-30 12:36:54	2020-04-30	29	[{"id_menu":3,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	22398	delivery	5	34
56453	2020-04-30 12:39:03	2020-04-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	19030	delivery	5	28
56454	2020-04-30 12:41:03	2020-04-30	9	[{"id_menu":6,"count":1}]	5799	pick-up	0	9
56455	2020-04-30 12:43:30	2020-04-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	16042	pick-up	0	23
56456	2020-04-30 12:44:15	2020-04-30	9	[{"id_menu":7,"count":1}]	14666	pick-up	0	9
56457	2020-04-30 12:48:39	2020-04-30	17	[{"id_menu":4,"count":1}]	10273	pick-up	0	17
56458	2020-04-30 13:00:27	2020-04-30	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	22473	pick-up	0	26
56459	2020-04-30 13:03:10	2020-04-30	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2591	pick-up	0	25
56460	2020-04-30 13:04:09	2020-04-30	9	[{"id_menu":6,"count":1}]	22044	delivery	5	14
56461	2020-04-30 13:04:39	2020-04-30	14	[{"id_menu":2,"count":1}]	15368	delivery	5	19
56462	2020-04-30 13:08:07	2020-04-30	9	[{"id_menu":7,"count":1}]	19477	delivery	5	14
56463	2020-04-30 13:11:50	2020-04-30	9	[{"id_menu":7,"count":1}]	4206	pick-up	0	9
56464	2020-04-30 13:12:21	2020-04-30	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1068	pick-up	0	38
56465	2020-04-30 13:13:37	2020-04-30	9	[{"id_menu":7,"count":1}]	22391	delivery	5	14
56466	2020-04-30 13:14:07	2020-04-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	22392	delivery	5	26
56467	2020-04-30 13:16:40	2020-04-30	12	[{"id_menu":3,"count":1}]	4271	delivery	5	17
56468	2020-04-30 13:18:26	2020-04-30	9	[{"id_menu":7,"count":1}]	586	pick-up	0	9
56469	2020-04-30 13:20:42	2020-04-30	12	[{"id_menu":3,"count":1}]	22513	pick-up	0	12
56470	2020-04-30 13:23:46	2020-04-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	13426	delivery	5	28
56471	2020-04-30 13:31:46	2020-04-30	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	4828	delivery	5	26
56472	2020-04-30 13:35:19	2020-04-30	9	[{"id_menu":7,"count":1}]	11717	delivery	5	14
56473	2020-04-30 13:36:03	2020-04-30	14	[{"id_menu":2,"count":2}]	2564	pick-up	0	14
56474	2020-04-30 13:36:16	2020-04-30	12	[{"id_menu":3,"count":1}]	16328	pick-up	0	12
56475	2020-04-30 13:40:23	2020-04-30	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	22478	pick-up	0	29
56476	2020-04-30 13:47:28	2020-04-30	12	[{"id_menu":1,"count":1}]	5886	delivery	5	17
56477	2020-04-30 13:49:51	2020-04-30	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1700	pick-up	0	31
56478	2020-04-30 13:50:20	2020-04-30	12	[{"id_menu":3,"count":1}]	14194	delivery	5	17
56479	2020-04-30 13:50:35	2020-04-30	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	22497	delivery	5	26
56480	2020-04-30 13:51:40	2020-04-30	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	14842	delivery	5	22
56481	2020-04-30 13:57:36	2020-04-30	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22382	delivery	5	53
56482	2020-04-30 14:03:48	2020-04-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22388	delivery	5	23
56483	2020-04-30 14:07:19	2020-04-30	17	[{"id_menu":4,"count":1}]	13266	delivery	5	22
56484	2020-04-30 14:08:03	2020-04-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19198	delivery	5	22
56485	2020-04-30 14:12:58	2020-04-30	9	[{"id_menu":6,"count":1}]	22412	delivery	5	14
56486	2020-04-30 14:13:36	2020-04-30	14	[{"id_menu":2,"count":1}]	15829	pick-up	0	14
56487	2020-04-30 14:22:11	2020-04-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7319	delivery	5	31
56488	2020-04-30 14:26:32	2020-04-30	8	[{"id_menu":5,"count":1}]	22430	delivery	5	13
56489	2020-04-30 14:36:08	2020-04-30	12	[{"id_menu":3,"count":1}]	9565	delivery	5	17
56490	2020-04-30 14:39:03	2020-04-30	14	[{"id_menu":2,"count":1}]	22481	delivery	5	19
56491	2020-04-30 14:39:10	2020-04-30	12	[{"id_menu":1,"count":1}]	9793	pick-up	0	12
56492	2020-04-30 14:45:38	2020-04-30	12	[{"id_menu":1,"count":1}]	22423	pick-up	0	12
56493	2020-04-30 14:49:12	2020-04-30	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	19647	delivery	5	43
56494	2020-04-30 14:49:32	2020-04-30	17	[{"id_menu":4,"count":1}]	5400	delivery	5	22
56495	2020-04-30 14:55:07	2020-04-30	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	14662	pick-up	0	20
56496	2020-04-30 14:58:56	2020-04-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	456	pick-up	0	26
56497	2020-04-30 15:00:20	2020-04-30	8	[{"id_menu":5,"count":1}]	13246	delivery	5	13
56498	2020-04-30 15:01:52	2020-04-30	17	[{"id_menu":4,"count":1}]	5041	pick-up	0	17
56499	2020-04-30 15:04:37	2020-04-30	9	[{"id_menu":6,"count":1}]	16094	delivery	5	14
56500	2020-04-30 15:07:59	2020-04-30	12	[{"id_menu":1,"count":1}]	11760	delivery	5	17
56501	2020-04-30 15:15:48	2020-04-30	9	[{"id_menu":7,"count":1}]	6840	delivery	5	14
56502	2020-04-30 15:27:46	2020-04-30	12	[{"id_menu":3,"count":1}]	7705	delivery	5	17
56503	2020-04-30 15:28:15	2020-04-30	9	[{"id_menu":7,"count":1}]	7186	pick-up	0	9
56504	2020-04-30 15:34:49	2020-04-30	8	[{"id_menu":5,"count":1}]	274	pick-up	0	8
56505	2020-04-30 15:38:59	2020-04-30	17	[{"id_menu":4,"count":1}]	10986	delivery	5	22
56506	2020-04-30 15:44:53	2020-04-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	21703	delivery	5	31
56507	2020-04-30 15:45:00	2020-04-30	12	[{"id_menu":1,"count":1}]	22477	pick-up	0	12
56508	2020-04-30 15:46:58	2020-04-30	12	[{"id_menu":3,"count":1}]	19860	delivery	5	17
56509	2020-04-30 15:49:03	2020-04-30	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	12490	delivery	5	30
56510	2020-04-30 15:52:42	2020-04-30	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22467	delivery	5	35
56511	2020-04-30 15:54:12	2020-04-30	9	[{"id_menu":7,"count":1}]	12194	delivery	5	14
56512	2020-04-30 15:55:25	2020-04-30	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	19679	delivery	5	26
56513	2020-04-30 16:00:19	2020-04-30	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	16323	delivery	5	37
56514	2020-04-30 16:00:23	2020-04-30	9	[{"id_menu":6,"count":1}]	5911	delivery	5	14
56515	2020-04-30 16:04:19	2020-04-30	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	9682	pick-up	0	43
56516	2020-04-30 16:16:11	2020-04-30	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	17610	delivery	5	36
56517	2020-04-30 16:17:04	2020-04-30	9	[{"id_menu":7,"count":1}]	22432	delivery	5	14
56518	2020-04-30 16:24:07	2020-04-30	14	[{"id_menu":2,"count":1}]	22207	pick-up	0	14
56519	2020-04-30 16:26:52	2020-04-30	9	[{"id_menu":7,"count":1}]	22448	delivery	5	14
56520	2020-04-30 16:27:19	2020-04-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	22433	delivery	5	28
56521	2020-04-30 16:32:53	2020-04-30	8	[{"id_menu":5,"count":1}]	7733	delivery	5	13
56522	2020-04-30 16:41:45	2020-04-30	9	[{"id_menu":7,"count":1}]	21417	delivery	5	14
56523	2020-04-30 16:47:46	2020-04-30	17	[{"id_menu":4,"count":1}]	41	pick-up	0	17
56524	2020-04-30 16:52:15	2020-04-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7293	delivery	5	28
56525	2020-04-30 16:53:59	2020-04-30	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2478	delivery	5	34
56526	2020-04-30 16:57:18	2020-04-30	17	[{"id_menu":4,"count":1}]	5354	pick-up	0	17
56527	2020-04-30 16:58:09	2020-04-30	8	[{"id_menu":5,"count":1}]	1495	delivery	5	13
56528	2020-04-30 16:59:04	2020-04-30	12	[{"id_menu":3,"count":1}]	7043	pick-up	0	12
56529	2020-04-30 17:08:06	2020-04-30	14	[{"id_menu":2,"count":1}]	16082	delivery	5	19
56530	2020-04-30 17:12:23	2020-04-30	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	22472	delivery	5	48
56531	2020-04-30 17:16:58	2020-04-30	9	[{"id_menu":7,"count":1}]	22221	delivery	5	14
56532	2020-04-30 17:17:53	2020-04-30	9	[{"id_menu":6,"count":2}]	17852	delivery	5	14
56533	2020-04-30 17:22:56	2020-04-30	9	[{"id_menu":6,"count":1}]	1343	pick-up	0	9
56534	2020-04-30 17:24:12	2020-04-30	12	[{"id_menu":3,"count":1}]	21074	delivery	5	17
56535	2020-04-30 17:24:18	2020-04-30	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4287	delivery	5	26
56536	2020-04-30 17:27:16	2020-04-30	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	19172	delivery	5	26
56537	2020-04-30 17:27:57	2020-04-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	22404	delivery	5	28
56538	2020-04-30 17:36:01	2020-04-30	9	[{"id_menu":7,"count":1}]	5744	delivery	5	14
56539	2020-04-30 17:37:55	2020-04-30	9	[{"id_menu":7,"count":1}]	20968	delivery	5	14
56540	2020-04-30 17:39:34	2020-04-30	8	[{"id_menu":5,"count":1}]	18645	delivery	5	13
56541	2020-04-30 17:41:58	2020-04-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	14475	delivery	5	28
56542	2020-04-30 17:42:50	2020-04-30	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17485	delivery	5	40
56543	2020-04-30 17:42:53	2020-04-30	14	[{"id_menu":2,"count":1}]	10495	delivery	5	19
56544	2020-04-30 17:46:10	2020-04-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	21143	delivery	5	28
56545	2020-04-30 17:46:29	2020-04-30	9	[{"id_menu":6,"count":1}]	16679	delivery	5	14
56546	2020-04-30 17:46:48	2020-04-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7776	pick-up	0	26
56547	2020-04-30 18:01:02	2020-04-30	12	[{"id_menu":1,"count":1}]	8163	pick-up	0	12
56548	2020-04-30 18:01:29	2020-04-30	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1541	delivery	5	26
56549	2020-04-30 18:01:55	2020-04-30	17	[{"id_menu":4,"count":1}]	22397	delivery	5	22
56550	2020-04-30 18:02:46	2020-04-30	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	19008	delivery	5	30
56551	2020-04-30 18:04:08	2020-04-30	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	22492	delivery	5	31
56552	2020-04-30 18:13:56	2020-04-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22406	delivery	5	23
56553	2020-04-30 18:19:28	2020-04-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5225	delivery	5	23
56554	2020-04-30 18:27:12	2020-04-30	12	[{"id_menu":1,"count":1}]	7953	delivery	5	17
56555	2020-04-30 18:32:31	2020-04-30	9	[{"id_menu":7,"count":1}]	21684	delivery	5	14
56556	2020-04-30 18:32:42	2020-04-30	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16156	delivery	5	43
56557	2020-04-30 18:34:55	2020-04-30	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	21847	delivery	5	40
56558	2020-04-30 18:36:21	2020-04-30	9	[{"id_menu":6,"count":1}]	2000	pick-up	0	9
56559	2020-04-30 18:37:38	2020-04-30	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15728	delivery	5	39
56560	2020-04-30 18:45:39	2020-04-30	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	22385	delivery	5	31
56561	2020-04-30 18:48:18	2020-04-30	9	[{"id_menu":7,"count":1}]	19633	pick-up	0	9
56562	2020-04-30 18:48:20	2020-04-30	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2674	delivery	5	26
56563	2020-04-30 18:48:48	2020-04-30	9	[{"id_menu":7,"count":1}]	18780	delivery	5	14
56564	2020-04-30 18:52:05	2020-04-30	12	[{"id_menu":1,"count":1}]	22505	delivery	5	17
56565	2020-04-30 18:59:47	2020-04-30	8	[{"id_menu":5,"count":1}]	22462	delivery	5	13
56566	2020-04-30 19:01:08	2020-04-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	22409	delivery	5	28
56567	2020-04-30 19:13:59	2020-04-30	14	[{"id_menu":2,"count":1}]	12351	delivery	5	19
56568	2020-04-30 19:14:44	2020-04-30	9	[{"id_menu":6,"count":1}]	13235	delivery	5	14
56569	2020-04-30 19:17:39	2020-04-30	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3490	delivery	5	30
56570	2020-04-30 19:18:28	2020-04-30	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	22450	delivery	5	26
56571	2020-04-30 19:19:04	2020-04-30	12	[{"id_menu":3,"count":1}]	22490	pick-up	0	12
56572	2020-04-30 19:23:17	2020-04-30	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	8644	delivery	5	35
56573	2020-04-30 19:23:44	2020-04-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19535	delivery	5	22
56574	2020-04-30 19:23:55	2020-04-30	9	[{"id_menu":6,"count":1}]	22424	delivery	5	14
56575	2020-04-30 19:24:21	2020-04-30	9	[{"id_menu":6,"count":1}]	22459	pick-up	0	9
56576	2020-04-30 19:29:04	2020-04-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	22480	delivery	5	31
56577	2020-04-30 19:30:01	2020-04-30	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22470	delivery	5	54
56578	2020-04-30 19:30:06	2020-04-30	9	[{"id_menu":6,"count":1}]	6476	delivery	5	14
56579	2020-04-30 19:30:35	2020-04-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3851	delivery	5	31
56580	2020-04-30 19:36:52	2020-04-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	3332	delivery	5	26
56581	2020-04-30 19:37:32	2020-04-30	12	[{"id_menu":1,"count":1}]	20663	delivery	5	17
56582	2020-04-30 19:38:33	2020-04-30	8	[{"id_menu":5,"count":1}]	19893	delivery	5	13
56583	2020-04-30 19:38:38	2020-04-30	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	22506	delivery	5	34
56584	2020-04-30 19:39:33	2020-04-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16571	pick-up	0	26
56585	2020-04-30 19:46:24	2020-04-30	14	[{"id_menu":2,"count":1}]	7667	delivery	5	19
56586	2020-04-30 19:50:23	2020-04-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6326	delivery	5	22
56587	2020-04-30 19:51:54	2020-04-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	12894	delivery	5	26
56588	2020-04-30 19:53:20	2020-04-30	9	[{"id_menu":7,"count":1}]	18302	delivery	5	14
56589	2020-04-30 19:57:54	2020-04-30	9	[{"id_menu":7,"count":1}]	1729	pick-up	0	9
56590	2020-04-30 20:06:26	2020-04-30	17	[{"id_menu":4,"count":1}]	22493	delivery	5	22
56591	2020-04-30 20:10:56	2020-04-30	8	[{"id_menu":5,"count":1}]	1130	pick-up	0	8
56592	2020-04-30 20:11:47	2020-04-30	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	22436	delivery	5	23
56593	2020-04-30 20:13:42	2020-04-30	12	[{"id_menu":1,"count":1}]	9627	pick-up	0	12
56594	2020-04-30 20:14:56	2020-04-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	22498	delivery	5	31
56595	2020-04-30 20:15:29	2020-04-30	9	[{"id_menu":6,"count":1}]	3688	delivery	5	14
56596	2020-04-30 20:22:22	2020-04-30	9	[{"id_menu":7,"count":1}]	440	delivery	5	14
56597	2020-04-30 20:22:45	2020-04-30	8	[{"id_menu":5,"count":2}]	1079	delivery	5	13
56598	2020-04-30 20:34:39	2020-04-30	12	[{"id_menu":3,"count":1}]	22453	delivery	5	17
56599	2020-04-30 20:36:35	2020-04-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	22489	delivery	5	26
56600	2020-04-30 20:42:39	2020-04-30	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	22383	pick-up	0	43
56601	2020-04-30 20:47:27	2020-04-30	8	[{"id_menu":5,"count":1}]	5891	delivery	5	13
56602	2020-04-30 20:56:46	2020-04-30	9	[{"id_menu":6,"count":1}]	1592	delivery	5	14
56603	2020-04-30 20:57:40	2020-04-30	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3689	delivery	5	37
56604	2020-04-30 21:00:04	2020-04-30	9	[{"id_menu":7,"count":1}]	2973	pick-up	0	9
56605	2020-04-30 21:00:50	2020-04-30	9	[{"id_menu":6,"count":1}]	2071	pick-up	0	9
56606	2020-04-30 21:03:05	2020-04-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	14555	delivery	5	22
56607	2020-04-30 21:06:27	2020-04-30	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	10662	delivery	5	31
56608	2020-04-30 21:09:59	2020-04-30	12	[{"id_menu":1,"count":1}]	22476	pick-up	0	12
56609	2020-04-30 21:10:58	2020-04-30	14	[{"id_menu":2,"count":1}]	5311	pick-up	0	14
56610	2020-04-30 21:19:00	2020-04-30	12	[{"id_menu":3,"count":1}]	22456	delivery	5	17
56611	2020-04-30 21:25:54	2020-04-30	12	[{"id_menu":3,"count":1}]	8029	delivery	5	17
56612	2020-04-30 21:26:58	2020-04-30	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	18683	delivery	5	23
56613	2020-04-30 21:31:58	2020-04-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	3661	delivery	5	23
56614	2020-04-30 21:34:28	2020-04-30	17	[{"id_menu":4,"count":1}]	18283	delivery	5	22
56615	2020-04-30 21:39:12	2020-04-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	20883	delivery	5	28
56616	2020-04-30 21:39:51	2020-04-30	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4938	delivery	5	26
56617	2020-04-30 21:43:32	2020-04-30	8	[{"id_menu":5,"count":1}]	13545	delivery	5	13
56618	2020-04-30 21:46:56	2020-04-30	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15356	delivery	5	45
56619	2020-04-30 21:53:26	2020-04-30	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	22451	delivery	5	38
56620	2020-04-30 21:57:17	2020-04-30	8	[{"id_menu":5,"count":1}]	22346	delivery	5	13
56621	2020-04-30 22:07:57	2020-04-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16839	delivery	5	31
56622	2020-04-30 22:08:04	2020-04-30	14	[{"id_menu":2,"count":2}]	13855	delivery	5	19
56623	2020-04-30 22:11:18	2020-04-30	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	932	delivery	5	36
56624	2020-04-30 22:15:20	2020-04-30	9	[{"id_menu":6,"count":1}]	12285	pick-up	0	9
56625	2020-04-30 22:16:52	2020-04-30	14	[{"id_menu":2,"count":1}]	7289	delivery	5	19
56626	2020-04-30 22:19:20	2020-04-30	9	[{"id_menu":7,"count":2}]	6327	delivery	5	14
56627	2020-04-30 22:21:34	2020-04-30	9	[{"id_menu":7,"count":1}]	22446	delivery	5	14
56628	2020-04-30 22:26:47	2020-04-30	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	19490	pick-up	0	25
56629	2020-04-30 22:29:59	2020-04-30	9	[{"id_menu":6,"count":1}]	22455	delivery	5	14
56630	2020-04-30 22:37:46	2020-04-30	9	[{"id_menu":6,"count":1}]	22495	delivery	5	14
56631	2020-04-30 22:39:18	2020-04-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	13521	delivery	5	26
56632	2020-04-30 22:40:53	2020-04-30	17	[{"id_menu":4,"count":1}]	22405	delivery	5	22
56633	2020-04-30 22:43:05	2020-04-30	9	[{"id_menu":7,"count":1}]	2037	pick-up	0	9
56634	2020-04-30 22:52:00	2020-04-30	9	[{"id_menu":7,"count":1}]	18100	delivery	5	14
56635	2020-04-30 22:52:14	2020-04-30	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	19372	delivery	5	40
56636	2020-04-30 22:52:52	2020-04-30	9	[{"id_menu":6,"count":1}]	18896	delivery	5	14
56637	2020-04-30 22:53:35	2020-04-30	12	[{"id_menu":1,"count":1}]	22429	delivery	5	17
56638	2020-04-30 22:54:44	2020-04-30	9	[{"id_menu":7,"count":1}]	16167	delivery	5	14
56639	2020-04-30 23:13:57	2020-04-30	14	[{"id_menu":2,"count":1}]	6635	delivery	5	19
56640	2020-04-30 23:18:34	2020-04-30	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	913	delivery	5	30
56641	2020-04-30 23:26:09	2020-04-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":3}]	9530	delivery	5	23
56642	2020-04-30 23:30:50	2020-04-30	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	234	pick-up	0	30
56643	2020-04-30 23:32:08	2020-04-30	9	[{"id_menu":6,"count":1}]	22454	delivery	5	14
56644	2020-04-30 23:33:24	2020-04-30	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	12872	delivery	5	34
56645	2020-04-30 23:34:58	2020-04-30	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	19243	delivery	5	36
56646	2020-04-30 23:34:59	2020-04-30	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22434	delivery	5	37
56647	2020-04-30 23:45:07	2020-04-30	17	[{"id_menu":4,"count":1}]	22468	delivery	5	22
56648	2020-04-30 23:48:13	2020-04-30	9	[{"id_menu":7,"count":1}]	1332	pick-up	0	9
56649	2020-04-30 23:49:17	2020-04-30	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	20771	delivery	5	34
56650	2020-04-30 23:49:44	2020-04-30	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	11493	pick-up	0	20
56651	2020-04-30 23:50:11	2020-04-30	14	[{"id_menu":2,"count":1}]	7094	delivery	5	19
56652	2020-04-30 23:56:18	2020-04-30	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2178	pick-up	0	21
56653	2020-05-01 00:00:09	2020-05-01	12	[{"id_menu":1,"count":1}]	18980	pick-up	0	12
56654	2020-05-01 00:00:14	2020-05-01	14	[{"id_menu":2,"count":1}]	12080	delivery	5	19
56655	2020-05-01 00:09:05	2020-05-01	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	20000	delivery	5	36
56656	2020-05-01 00:09:14	2020-05-01	17	[{"id_menu":4,"count":1}]	18253	pick-up	0	17
56657	2020-05-01 00:10:24	2020-05-01	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	13437	delivery	5	28
56658	2020-05-01 00:12:47	2020-05-01	14	[{"id_menu":2,"count":2}]	22588	delivery	5	19
56659	2020-05-01 00:14:26	2020-05-01	9	[{"id_menu":6,"count":1}]	22597	delivery	5	14
56660	2020-05-01 00:19:48	2020-05-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4307	delivery	5	36
56661	2020-05-01 00:22:39	2020-05-01	9	[{"id_menu":7,"count":1}]	3536	pick-up	0	9
56662	2020-05-01 00:23:35	2020-05-01	17	[{"id_menu":4,"count":1}]	22618	delivery	5	22
56663	2020-05-01 00:27:09	2020-05-01	17	[{"id_menu":4,"count":1}]	14813	delivery	5	22
56664	2020-05-01 00:28:21	2020-05-01	9	[{"id_menu":6,"count":2}]	22628	delivery	5	14
56665	2020-05-01 00:28:41	2020-05-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2908	delivery	5	22
56666	2020-05-01 00:29:02	2020-05-01	17	[{"id_menu":4,"count":1}]	22661	delivery	5	22
56667	2020-05-01 00:29:32	2020-05-01	9	[{"id_menu":6,"count":1}]	20329	delivery	5	14
56668	2020-05-01 00:31:19	2020-05-01	9	[{"id_menu":6,"count":1}]	10968	delivery	5	14
56669	2020-05-01 00:32:34	2020-05-01	14	[{"id_menu":2,"count":1}]	22698	delivery	5	19
56670	2020-05-01 00:39:12	2020-05-01	12	[{"id_menu":3,"count":1}]	22668	delivery	5	17
56671	2020-05-01 00:40:21	2020-05-01	14	[{"id_menu":2,"count":1}]	573	delivery	5	19
56672	2020-05-01 00:43:30	2020-05-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":3}]	22557	delivery	5	22
56673	2020-05-01 00:46:52	2020-05-01	12	[{"id_menu":1,"count":1}]	6097	pick-up	0	12
56674	2020-05-01 00:46:57	2020-05-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17331	delivery	5	31
56675	2020-05-01 00:55:12	2020-05-01	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22656	delivery	5	40
56676	2020-05-01 01:05:03	2020-05-01	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	10421	delivery	5	26
56677	2020-05-01 01:09:50	2020-05-01	9	[{"id_menu":7,"count":1}]	22598	pick-up	0	9
56678	2020-05-01 01:10:41	2020-05-01	9	[{"id_menu":6,"count":1}]	22257	delivery	5	14
56679	2020-05-01 01:16:05	2020-05-01	14	[{"id_menu":2,"count":1}]	16111	delivery	5	19
56680	2020-05-01 01:21:55	2020-05-01	9	[{"id_menu":6,"count":1}]	22636	delivery	5	14
56681	2020-05-01 01:26:33	2020-05-01	8	[{"id_menu":5,"count":1}]	8123	pick-up	0	8
56682	2020-05-01 01:31:56	2020-05-01	9	[{"id_menu":7,"count":1}]	5743	delivery	5	14
56683	2020-05-01 01:34:14	2020-05-01	14	[{"id_menu":2,"count":1}]	8418	pick-up	0	14
56684	2020-05-01 01:39:35	2020-05-01	12	[{"id_menu":3,"count":1}]	4071	delivery	5	17
56685	2020-05-01 01:47:25	2020-05-01	9	[{"id_menu":6,"count":1}]	12252	delivery	5	14
56686	2020-05-01 01:47:55	2020-05-01	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2428	delivery	5	36
56687	2020-05-01 01:48:54	2020-05-01	12	[{"id_menu":3,"count":1}]	22657	delivery	5	17
56688	2020-05-01 01:50:52	2020-05-01	9	[{"id_menu":6,"count":1}]	8436	delivery	5	14
56689	2020-05-01 02:03:42	2020-05-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":3}]	22577	delivery	5	23
56690	2020-05-01 02:08:28	2020-05-01	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14984	delivery	5	31
56691	2020-05-01 02:12:15	2020-05-01	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3518	delivery	5	34
56692	2020-05-01 02:18:42	2020-05-01	12	[{"id_menu":3,"count":1}]	11615	delivery	5	17
56693	2020-05-01 02:21:33	2020-05-01	17	[{"id_menu":4,"count":1}]	5737	delivery	5	22
56694	2020-05-01 02:26:20	2020-05-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	22555	delivery	5	28
56695	2020-05-01 02:26:49	2020-05-01	14	[{"id_menu":2,"count":1}]	12321	delivery	5	19
56696	2020-05-01 02:34:32	2020-05-01	12	[{"id_menu":3,"count":1}]	16081	pick-up	0	12
56697	2020-05-01 02:35:50	2020-05-01	17	[{"id_menu":4,"count":2}]	22693	delivery	5	22
56698	2020-05-01 02:36:56	2020-05-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12982	pick-up	0	18
56699	2020-05-01 02:37:09	2020-05-01	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	12364	delivery	5	31
56700	2020-05-01 02:41:10	2020-05-01	9	[{"id_menu":6,"count":1}]	2585	pick-up	0	9
56701	2020-05-01 02:43:56	2020-05-01	12	[{"id_menu":3,"count":1}]	10518	delivery	5	17
56702	2020-05-01 02:44:00	2020-05-01	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	22525	delivery	5	48
56703	2020-05-01 02:44:17	2020-05-01	9	[{"id_menu":7,"count":1}]	19353	delivery	5	14
56704	2020-05-01 02:44:51	2020-05-01	14	[{"id_menu":2,"count":1}]	18283	delivery	5	19
56705	2020-05-01 02:48:14	2020-05-01	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5148	delivery	5	35
56706	2020-05-01 02:52:04	2020-05-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22567	delivery	5	22
56707	2020-05-01 02:57:52	2020-05-01	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22612	delivery	5	36
56708	2020-05-01 02:58:41	2020-05-01	12	[{"id_menu":1,"count":1}]	10194	pick-up	0	12
56709	2020-05-01 03:00:31	2020-05-01	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	9167	delivery	5	34
56710	2020-05-01 03:04:40	2020-05-01	9	[{"id_menu":7,"count":1}]	7944	delivery	5	14
56711	2020-05-01 03:05:54	2020-05-01	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18376	delivery	5	39
56712	2020-05-01 03:06:04	2020-05-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	22625	delivery	5	31
56713	2020-05-01 03:17:44	2020-05-01	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	10039	pick-up	0	29
56714	2020-05-01 03:21:36	2020-05-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	291	pick-up	0	17
56715	2020-05-01 03:27:25	2020-05-01	14	[{"id_menu":2,"count":1}]	20865	delivery	5	19
56716	2020-05-01 03:28:05	2020-05-01	14	[{"id_menu":2,"count":1}]	9304	pick-up	0	14
56717	2020-05-01 03:28:54	2020-05-01	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	274	pick-up	0	50
56718	2020-05-01 03:30:01	2020-05-01	9	[{"id_menu":7,"count":1}]	22600	delivery	5	14
56719	2020-05-01 03:32:01	2020-05-01	9	[{"id_menu":6,"count":1}]	17723	delivery	5	14
56720	2020-05-01 03:43:10	2020-05-01	17	[{"id_menu":4,"count":1}]	1882	delivery	5	22
56721	2020-05-01 03:47:55	2020-05-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	22655	delivery	5	28
56722	2020-05-01 03:50:36	2020-05-01	9	[{"id_menu":6,"count":1}]	7922	pick-up	0	9
56723	2020-05-01 03:52:53	2020-05-01	9	[{"id_menu":6,"count":1}]	12611	delivery	5	14
56724	2020-05-01 03:52:56	2020-05-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22229	delivery	5	23
56725	2020-05-01 03:55:29	2020-05-01	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	9097	pick-up	0	33
56726	2020-05-01 03:58:20	2020-05-01	12	[{"id_menu":3,"count":1}]	4714	pick-up	0	12
56727	2020-05-01 04:01:13	2020-05-01	14	[{"id_menu":2,"count":1}]	22574	delivery	5	19
56728	2020-05-01 04:06:13	2020-05-01	17	[{"id_menu":4,"count":1}]	2149	pick-up	0	17
56729	2020-05-01 04:14:36	2020-05-01	12	[{"id_menu":3,"count":1}]	8180	pick-up	0	12
56730	2020-05-01 04:20:36	2020-05-01	8	[{"id_menu":5,"count":1}]	13495	pick-up	0	8
56731	2020-05-01 04:22:20	2020-05-01	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	22601	delivery	5	34
56732	2020-05-01 04:29:28	2020-05-01	8	[{"id_menu":5,"count":1}]	2119	delivery	5	13
56733	2020-05-01 04:32:58	2020-05-01	9	[{"id_menu":6,"count":1}]	18870	delivery	5	14
56734	2020-05-01 04:39:13	2020-05-01	14	[{"id_menu":2,"count":1}]	20140	pick-up	0	14
56735	2020-05-01 04:48:45	2020-05-01	9	[{"id_menu":7,"count":1}]	17522	delivery	5	14
56736	2020-05-01 04:58:46	2020-05-01	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	19774	delivery	5	45
56737	2020-05-01 04:59:54	2020-05-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	22591	delivery	5	36
56738	2020-05-01 05:01:19	2020-05-01	17	[{"id_menu":4,"count":1}]	22542	delivery	5	22
56739	2020-05-01 05:03:53	2020-05-01	9	[{"id_menu":6,"count":1}]	13530	delivery	5	14
56740	2020-05-01 05:04:23	2020-05-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	10933	delivery	5	22
56741	2020-05-01 05:06:04	2020-05-01	8	[{"id_menu":5,"count":1}]	19935	delivery	5	13
56742	2020-05-01 05:14:34	2020-05-01	12	[{"id_menu":3,"count":1}]	826	pick-up	0	12
56743	2020-05-01 05:15:59	2020-05-01	14	[{"id_menu":2,"count":1}]	10252	delivery	5	19
56744	2020-05-01 05:17:32	2020-05-01	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	7734	delivery	5	27
56745	2020-05-01 05:17:36	2020-05-01	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	22654	delivery	5	29
56746	2020-05-01 05:24:49	2020-05-01	17	[{"id_menu":4,"count":1}]	13613	delivery	5	22
56747	2020-05-01 05:25:30	2020-05-01	17	[{"id_menu":4,"count":1}]	2850	pick-up	0	17
56748	2020-05-01 05:28:53	2020-05-01	17	[{"id_menu":4,"count":1}]	22569	delivery	5	22
56749	2020-05-01 05:34:18	2020-05-01	12	[{"id_menu":3,"count":1}]	22537	delivery	5	17
56750	2020-05-01 05:35:52	2020-05-01	12	[{"id_menu":3,"count":1}]	20922	pick-up	0	12
56751	2020-05-01 05:37:33	2020-05-01	14	[{"id_menu":2,"count":1}]	19360	delivery	5	19
56752	2020-05-01 05:40:55	2020-05-01	8	[{"id_menu":5,"count":1}]	1293	delivery	5	13
56753	2020-05-01 05:42:43	2020-05-01	8	[{"id_menu":5,"count":1}]	10843	delivery	5	13
56754	2020-05-01 05:47:48	2020-05-01	9	[{"id_menu":6,"count":1}]	22560	delivery	5	14
56755	2020-05-01 05:52:10	2020-05-01	8	[{"id_menu":5,"count":1}]	6869	delivery	5	13
56756	2020-05-01 05:57:47	2020-05-01	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14775	delivery	5	45
56757	2020-05-01 05:58:01	2020-05-01	12	[{"id_menu":1,"count":1}]	19857	delivery	5	17
56758	2020-05-01 06:00:17	2020-05-01	12	[{"id_menu":3,"count":1}]	2579	delivery	5	17
56759	2020-05-01 06:01:37	2020-05-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19663	delivery	5	22
56760	2020-05-01 06:11:37	2020-05-01	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	16634	delivery	5	27
56761	2020-05-01 06:14:39	2020-05-01	9	[{"id_menu":7,"count":1}]	22590	delivery	5	14
56762	2020-05-01 06:15:18	2020-05-01	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	9728	pick-up	0	22
56763	2020-05-01 06:19:38	2020-05-01	17	[{"id_menu":4,"count":1}]	1259	pick-up	0	17
56764	2020-05-01 06:21:25	2020-05-01	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11016	delivery	5	57
56765	2020-05-01 06:22:42	2020-05-01	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	14520	delivery	5	57
56766	2020-05-01 06:22:59	2020-05-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	22607	delivery	5	26
56767	2020-05-01 06:23:46	2020-05-01	12	[{"id_menu":3,"count":1}]	22518	delivery	5	17
56768	2020-05-01 06:24:02	2020-05-01	8	[{"id_menu":5,"count":1}]	6311	delivery	5	13
56769	2020-05-01 06:42:20	2020-05-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5248	pick-up	0	18
56770	2020-05-01 06:44:03	2020-05-01	9	[{"id_menu":7,"count":2}]	22650	delivery	5	14
56771	2020-05-01 06:54:39	2020-05-01	8	[{"id_menu":5,"count":1}]	236	pick-up	0	8
56772	2020-05-01 07:03:39	2020-05-01	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	13907	delivery	5	25
56773	2020-05-01 07:07:40	2020-05-01	14	[{"id_menu":2,"count":1}]	8240	pick-up	0	14
56774	2020-05-01 07:09:03	2020-05-01	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	22554	delivery	5	43
56775	2020-05-01 07:09:44	2020-05-01	8	[{"id_menu":5,"count":1}]	5790	pick-up	0	8
56776	2020-05-01 07:11:52	2020-05-01	17	[{"id_menu":4,"count":1}]	12938	delivery	5	22
56777	2020-05-01 07:23:21	2020-05-01	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8385	delivery	5	31
56778	2020-05-01 07:25:59	2020-05-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	22551	delivery	5	28
56779	2020-05-01 07:37:07	2020-05-01	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	22634	delivery	5	46
56780	2020-05-01 07:40:06	2020-05-01	17	[{"id_menu":4,"count":1}]	12698	delivery	5	22
56781	2020-05-01 07:44:31	2020-05-01	8	[{"id_menu":5,"count":1}]	22017	delivery	5	13
56782	2020-05-01 07:45:36	2020-05-01	17	[{"id_menu":4,"count":1}]	4793	delivery	5	22
56783	2020-05-01 07:47:31	2020-05-01	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22622	delivery	5	35
56784	2020-05-01 07:51:47	2020-05-01	8	[{"id_menu":5,"count":1}]	2845	delivery	5	13
56785	2020-05-01 08:10:59	2020-05-01	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	22648	delivery	5	38
56786	2020-05-01 08:18:01	2020-05-01	8	[{"id_menu":5,"count":1}]	10178	delivery	5	13
56787	2020-05-01 08:19:52	2020-05-01	12	[{"id_menu":3,"count":1}]	14624	pick-up	0	12
56788	2020-05-01 08:21:09	2020-05-01	8	[{"id_menu":5,"count":1}]	22619	delivery	5	13
56789	2020-05-01 08:21:37	2020-05-01	14	[{"id_menu":2,"count":1}]	22517	delivery	5	19
56790	2020-05-01 08:23:05	2020-05-01	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	20951	delivery	5	34
56791	2020-05-01 08:29:15	2020-05-01	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1442	delivery	5	26
56792	2020-05-01 08:31:25	2020-05-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	12581	delivery	5	28
56793	2020-05-01 08:32:32	2020-05-01	9	[{"id_menu":6,"count":1}]	22664	delivery	5	14
56794	2020-05-01 08:34:33	2020-05-01	9	[{"id_menu":7,"count":1}]	13442	pick-up	0	9
56795	2020-05-01 08:35:01	2020-05-01	12	[{"id_menu":1,"count":1}]	7204	delivery	5	17
56796	2020-05-01 08:36:34	2020-05-01	8	[{"id_menu":5,"count":1}]	22608	delivery	5	13
56797	2020-05-01 08:37:09	2020-05-01	9	[{"id_menu":6,"count":1}]	2200	pick-up	0	9
56798	2020-05-01 08:37:57	2020-05-01	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	22592	delivery	5	27
56799	2020-05-01 08:39:21	2020-05-01	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	7706	delivery	5	27
56800	2020-05-01 08:41:29	2020-05-01	12	[{"id_menu":3,"count":1}]	8389	delivery	5	17
56801	2020-05-01 08:45:05	2020-05-01	9	[{"id_menu":6,"count":1}]	17194	delivery	5	14
56802	2020-05-01 08:48:26	2020-05-01	12	[{"id_menu":1,"count":1}]	15187	pick-up	0	12
56803	2020-05-01 08:49:26	2020-05-01	12	[{"id_menu":1,"count":1}]	13054	delivery	5	17
56804	2020-05-01 08:54:07	2020-05-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	20785	delivery	5	23
56805	2020-05-01 08:54:17	2020-05-01	14	[{"id_menu":2,"count":1}]	1562	delivery	5	19
56806	2020-05-01 08:54:54	2020-05-01	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	22602	delivery	5	38
56807	2020-05-01 08:57:08	2020-05-01	9	[{"id_menu":6,"count":1}]	15159	delivery	5	14
56808	2020-05-01 08:57:15	2020-05-01	9	[{"id_menu":7,"count":1}]	22596	delivery	5	14
56809	2020-05-01 09:03:20	2020-05-01	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	22553	delivery	5	40
56810	2020-05-01 09:11:38	2020-05-01	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	22580	delivery	5	30
56811	2020-05-01 09:14:12	2020-05-01	12	[{"id_menu":3,"count":1}]	22575	pick-up	0	12
56812	2020-05-01 09:16:37	2020-05-01	12	[{"id_menu":1,"count":1}]	21	delivery	5	17
56813	2020-05-01 09:17:01	2020-05-01	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	13287	delivery	5	25
56814	2020-05-01 09:19:15	2020-05-01	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	15629	delivery	5	39
56815	2020-05-01 09:25:30	2020-05-01	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	22677	delivery	5	31
56816	2020-05-01 09:26:23	2020-05-01	8	[{"id_menu":5,"count":1}]	17581	delivery	5	13
56817	2020-05-01 09:29:01	2020-05-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16622	delivery	5	31
56818	2020-05-01 09:37:04	2020-05-01	14	[{"id_menu":2,"count":1}]	13795	delivery	5	19
56819	2020-05-01 09:40:58	2020-05-01	8	[{"id_menu":5,"count":1}]	7704	delivery	5	13
56820	2020-05-01 09:44:45	2020-05-01	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	22700	delivery	5	38
56821	2020-05-01 09:45:05	2020-05-01	9	[{"id_menu":6,"count":1}]	1040	delivery	5	14
56822	2020-05-01 09:47:47	2020-05-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21257	delivery	5	22
56823	2020-05-01 09:48:01	2020-05-01	14	[{"id_menu":2,"count":1}]	22644	delivery	5	19
56824	2020-05-01 09:52:53	2020-05-01	9	[{"id_menu":6,"count":1}]	22627	delivery	5	14
56825	2020-05-01 09:55:11	2020-05-01	8	[{"id_menu":5,"count":1}]	22683	delivery	5	13
56826	2020-05-01 09:55:26	2020-05-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	22675	delivery	5	26
56827	2020-05-01 09:55:39	2020-05-01	17	[{"id_menu":4,"count":1}]	12089	delivery	5	22
56828	2020-05-01 10:02:24	2020-05-01	8	[{"id_menu":5,"count":1}]	22609	delivery	5	13
56829	2020-05-01 10:04:39	2020-05-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22697	pick-up	0	17
56830	2020-05-01 10:05:01	2020-05-01	8	[{"id_menu":5,"count":1}]	6746	delivery	5	13
56831	2020-05-01 10:06:34	2020-05-01	17	[{"id_menu":4,"count":1}]	11390	delivery	5	22
56832	2020-05-01 10:08:36	2020-05-01	9	[{"id_menu":7,"count":1}]	22613	delivery	5	14
56833	2020-05-01 10:10:35	2020-05-01	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	22561	delivery	5	26
56834	2020-05-01 10:12:31	2020-05-01	12	[{"id_menu":1,"count":1}]	21072	delivery	5	17
56835	2020-05-01 10:14:03	2020-05-01	9	[{"id_menu":7,"count":1}]	3180	pick-up	0	9
56836	2020-05-01 10:15:19	2020-05-01	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	4825	pick-up	0	34
56837	2020-05-01 10:16:04	2020-05-01	9	[{"id_menu":7,"count":1}]	62	delivery	5	14
56838	2020-05-01 10:16:06	2020-05-01	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	18903	delivery	5	39
56839	2020-05-01 10:16:52	2020-05-01	8	[{"id_menu":5,"count":1}]	10750	delivery	5	13
56840	2020-05-01 10:17:54	2020-05-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6379	delivery	5	23
56841	2020-05-01 10:17:57	2020-05-01	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	10603	delivery	5	39
56842	2020-05-01 10:20:23	2020-05-01	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22562	delivery	5	31
56843	2020-05-01 10:29:41	2020-05-01	12	[{"id_menu":1,"count":1}]	11946	pick-up	0	12
56844	2020-05-01 10:30:37	2020-05-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4424	delivery	5	23
56845	2020-05-01 10:36:25	2020-05-01	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22369	delivery	5	36
56846	2020-05-01 10:37:31	2020-05-01	9	[{"id_menu":6,"count":1}]	3457	pick-up	0	9
56847	2020-05-01 10:39:14	2020-05-01	14	[{"id_menu":2,"count":1}]	22539	delivery	5	19
56848	2020-05-01 10:43:26	2020-05-01	8	[{"id_menu":5,"count":2}]	8501	pick-up	0	8
56849	2020-05-01 10:45:41	2020-05-01	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	4674	delivery	5	26
56850	2020-05-01 10:45:41	2020-05-01	9	[{"id_menu":7,"count":1}]	22570	delivery	5	14
56851	2020-05-01 10:46:04	2020-05-01	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	17460	delivery	5	31
56852	2020-05-01 10:47:16	2020-05-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	22573	delivery	5	28
56853	2020-05-01 10:51:29	2020-05-01	12	[{"id_menu":3,"count":1}]	22520	delivery	5	17
56854	2020-05-01 10:53:52	2020-05-01	9	[{"id_menu":6,"count":1}]	22572	delivery	5	14
56855	2020-05-01 10:56:00	2020-05-01	9	[{"id_menu":6,"count":1}]	22638	delivery	5	14
56856	2020-05-01 10:59:21	2020-05-01	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	18596	delivery	5	43
56857	2020-05-01 11:04:56	2020-05-01	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	4265	delivery	5	34
56858	2020-05-01 11:09:26	2020-05-01	14	[{"id_menu":2,"count":1}]	6484	delivery	5	19
56859	2020-05-01 11:10:11	2020-05-01	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	22603	pick-up	0	29
56860	2020-05-01 11:11:11	2020-05-01	14	[{"id_menu":2,"count":1}]	11093	delivery	5	19
56861	2020-05-01 11:17:21	2020-05-01	9	[{"id_menu":7,"count":1}]	12384	delivery	5	14
56862	2020-05-01 11:18:56	2020-05-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2341	pick-up	0	17
56863	2020-05-01 11:20:57	2020-05-01	9	[{"id_menu":7,"count":2}]	20916	delivery	5	14
56864	2020-05-01 11:28:19	2020-05-01	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15179	delivery	5	45
56865	2020-05-01 11:34:01	2020-05-01	9	[{"id_menu":7,"count":1}]	22578	delivery	5	14
56866	2020-05-01 11:36:00	2020-05-01	9	[{"id_menu":7,"count":3}]	11279	delivery	5	14
56867	2020-05-01 11:42:53	2020-05-01	8	[{"id_menu":5,"count":1}]	22690	delivery	5	13
56868	2020-05-01 11:44:56	2020-05-01	12	[{"id_menu":3,"count":1}]	8719	pick-up	0	12
56869	2020-05-01 11:45:13	2020-05-01	12	[{"id_menu":1,"count":1}]	22643	pick-up	0	12
56870	2020-05-01 11:54:09	2020-05-01	8	[{"id_menu":5,"count":1}]	22629	delivery	5	13
56871	2020-05-01 11:58:42	2020-05-01	9	[{"id_menu":6,"count":1}]	22532	delivery	5	14
56872	2020-05-01 12:05:42	2020-05-01	17	[{"id_menu":4,"count":1}]	21766	delivery	5	22
56873	2020-05-01 12:16:31	2020-05-01	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	13320	pick-up	0	26
56874	2020-05-01 12:17:34	2020-05-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	8813	delivery	5	28
56875	2020-05-01 12:19:06	2020-05-01	9	[{"id_menu":6,"count":1}]	19845	pick-up	0	9
56876	2020-05-01 12:23:19	2020-05-01	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	9633	delivery	5	25
56877	2020-05-01 12:29:41	2020-05-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4559	delivery	5	22
56878	2020-05-01 12:35:41	2020-05-01	8	[{"id_menu":5,"count":1}]	17725	delivery	5	13
56879	2020-05-01 12:38:12	2020-05-01	12	[{"id_menu":3,"count":1}]	2615	pick-up	0	12
56880	2020-05-01 12:41:01	2020-05-01	17	[{"id_menu":4,"count":1}]	14584	delivery	5	22
56881	2020-05-01 12:42:17	2020-05-01	12	[{"id_menu":3,"count":1}]	11756	delivery	5	17
56882	2020-05-01 12:42:38	2020-05-01	8	[{"id_menu":5,"count":1}]	15520	delivery	5	13
56883	2020-05-01 12:44:24	2020-05-01	9	[{"id_menu":7,"count":1}]	15079	delivery	5	14
56884	2020-05-01 12:46:49	2020-05-01	14	[{"id_menu":2,"count":1}]	3126	pick-up	0	14
56885	2020-05-01 12:47:05	2020-05-01	8	[{"id_menu":5,"count":2}]	4705	pick-up	0	8
56886	2020-05-01 12:48:45	2020-05-01	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2894	delivery	5	26
56887	2020-05-01 12:50:34	2020-05-01	9	[{"id_menu":7,"count":1}]	14124	delivery	5	14
56888	2020-05-01 12:52:02	2020-05-01	12	[{"id_menu":1,"count":1}]	7054	delivery	5	17
56889	2020-05-01 12:52:45	2020-05-01	12	[{"id_menu":3,"count":1}]	19340	delivery	5	17
56890	2020-05-01 12:57:40	2020-05-01	8	[{"id_menu":5,"count":1}]	20772	delivery	5	13
56891	2020-05-01 12:59:36	2020-05-01	12	[{"id_menu":1,"count":1}]	22530	delivery	5	17
56892	2020-05-01 13:01:44	2020-05-01	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	22663	delivery	5	34
56893	2020-05-01 13:20:22	2020-05-01	8	[{"id_menu":5,"count":1}]	22593	delivery	5	13
56894	2020-05-01 13:22:19	2020-05-01	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	7444	delivery	5	38
56895	2020-05-01 13:23:00	2020-05-01	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	22584	delivery	5	39
56896	2020-05-01 13:23:42	2020-05-01	12	[{"id_menu":1,"count":1}]	906	pick-up	0	12
56897	2020-05-01 13:25:11	2020-05-01	12	[{"id_menu":3,"count":1}]	19551	pick-up	0	12
56898	2020-05-01 13:29:25	2020-05-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	639	pick-up	0	23
56899	2020-05-01 13:30:06	2020-05-01	12	[{"id_menu":1,"count":1}]	20696	pick-up	0	12
56900	2020-05-01 13:33:41	2020-05-01	8	[{"id_menu":5,"count":1}]	12184	delivery	5	13
56901	2020-05-01 13:38:21	2020-05-01	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	22670	pick-up	0	25
56902	2020-05-01 13:39:45	2020-05-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	22671	delivery	5	31
56903	2020-05-01 13:40:49	2020-05-01	17	[{"id_menu":4,"count":1}]	20729	delivery	5	22
56904	2020-05-01 13:44:58	2020-05-01	9	[{"id_menu":6,"count":1}]	22143	delivery	5	14
56905	2020-05-01 13:55:06	2020-05-01	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	22559	delivery	5	31
56906	2020-05-01 14:00:48	2020-05-01	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22546	delivery	5	34
56907	2020-05-01 14:06:17	2020-05-01	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	11983	delivery	5	27
56908	2020-05-01 14:09:00	2020-05-01	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17006	delivery	5	53
56909	2020-05-01 14:09:53	2020-05-01	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2275	delivery	5	25
56910	2020-05-01 14:11:18	2020-05-01	14	[{"id_menu":2,"count":1}]	22548	delivery	5	19
56911	2020-05-01 14:19:59	2020-05-01	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	22524	delivery	5	56
56912	2020-05-01 14:21:58	2020-05-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2443	pick-up	0	26
56913	2020-05-01 14:23:46	2020-05-01	12	[{"id_menu":3,"count":1}]	3130	pick-up	0	12
56914	2020-05-01 14:29:56	2020-05-01	12	[{"id_menu":3,"count":1}]	22614	pick-up	0	12
56915	2020-05-01 14:35:20	2020-05-01	9	[{"id_menu":7,"count":1}]	22615	delivery	5	14
56916	2020-05-01 14:35:50	2020-05-01	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	21518	delivery	5	34
56917	2020-05-01 14:39:25	2020-05-01	14	[{"id_menu":2,"count":1}]	17503	delivery	5	19
56918	2020-05-01 14:43:36	2020-05-01	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9238	delivery	5	43
56919	2020-05-01 14:47:22	2020-05-01	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22633	delivery	5	35
56920	2020-05-01 14:53:56	2020-05-01	17	[{"id_menu":4,"count":2}]	22585	delivery	5	22
56921	2020-05-01 14:54:28	2020-05-01	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16987	delivery	5	39
56922	2020-05-01 14:55:38	2020-05-01	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12934	delivery	5	53
56923	2020-05-01 14:57:24	2020-05-01	8	[{"id_menu":5,"count":1}]	22599	delivery	5	13
56924	2020-05-01 14:58:06	2020-05-01	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	6637	delivery	5	31
56925	2020-05-01 15:01:08	2020-05-01	9	[{"id_menu":6,"count":1}]	22649	delivery	5	14
56926	2020-05-01 15:04:25	2020-05-01	9	[{"id_menu":6,"count":1}]	21897	delivery	5	14
56927	2020-05-01 15:10:18	2020-05-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	22564	delivery	5	22
56928	2020-05-01 15:23:15	2020-05-01	9	[{"id_menu":6,"count":1}]	8400	delivery	5	14
56929	2020-05-01 15:29:13	2020-05-01	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	22535	delivery	5	23
56930	2020-05-01 15:29:29	2020-05-01	29	[{"id_menu":1,"count":3},{"id_menu":4,"count":1}]	22568	pick-up	0	29
56931	2020-05-01 15:34:30	2020-05-01	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16434	delivery	5	48
56932	2020-05-01 15:34:50	2020-05-01	14	[{"id_menu":2,"count":1}]	18206	delivery	5	19
56933	2020-05-01 15:36:17	2020-05-01	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7007	delivery	5	52
56934	2020-05-01 15:43:54	2020-05-01	9	[{"id_menu":6,"count":1}]	22523	delivery	5	14
56935	2020-05-01 15:44:30	2020-05-01	8	[{"id_menu":5,"count":1}]	7690	pick-up	0	8
56936	2020-05-01 15:48:15	2020-05-01	14	[{"id_menu":2,"count":1}]	21357	delivery	5	19
56937	2020-05-01 15:53:57	2020-05-01	17	[{"id_menu":4,"count":1}]	2282	pick-up	0	17
56938	2020-05-01 15:54:44	2020-05-01	17	[{"id_menu":4,"count":1}]	2980	pick-up	0	17
56939	2020-05-01 15:56:23	2020-05-01	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	12057	delivery	5	39
56940	2020-05-01 15:59:27	2020-05-01	17	[{"id_menu":4,"count":1}]	743	pick-up	0	17
56941	2020-05-01 16:06:23	2020-05-01	9	[{"id_menu":6,"count":1}]	9011	delivery	5	14
56942	2020-05-01 16:16:59	2020-05-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20262	delivery	5	23
56943	2020-05-01 16:25:22	2020-05-01	12	[{"id_menu":3,"count":1}]	22642	delivery	5	17
56944	2020-05-01 16:34:17	2020-05-01	17	[{"id_menu":4,"count":1}]	9347	delivery	5	22
56945	2020-05-01 16:40:17	2020-05-01	9	[{"id_menu":6,"count":1}]	4834	delivery	5	14
56946	2020-05-01 16:41:12	2020-05-01	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	22556	delivery	5	34
56947	2020-05-01 16:42:35	2020-05-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4767	pick-up	0	23
56948	2020-05-01 16:48:50	2020-05-01	12	[{"id_menu":1,"count":1}]	11012	delivery	5	17
56949	2020-05-01 16:54:46	2020-05-01	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	22620	delivery	5	34
56950	2020-05-01 16:58:31	2020-05-01	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	17391	delivery	5	30
56951	2020-05-01 17:00:29	2020-05-01	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6104	delivery	5	47
56952	2020-05-01 17:11:26	2020-05-01	12	[{"id_menu":3,"count":1}]	16956	delivery	5	17
56953	2020-05-01 17:13:49	2020-05-01	8	[{"id_menu":5,"count":1}]	21535	delivery	5	13
56954	2020-05-01 17:18:09	2020-05-01	9	[{"id_menu":7,"count":2}]	21083	pick-up	0	9
56955	2020-05-01 17:24:05	2020-05-01	9	[{"id_menu":7,"count":1}]	16170	delivery	5	14
56956	2020-05-01 17:24:17	2020-05-01	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	22563	delivery	5	35
56957	2020-05-01 17:24:54	2020-05-01	9	[{"id_menu":6,"count":1}]	17470	delivery	5	14
56958	2020-05-01 17:26:51	2020-05-01	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	10159	delivery	5	28
56959	2020-05-01 17:29:14	2020-05-01	9	[{"id_menu":7,"count":1}]	458	delivery	5	14
56960	2020-05-01 17:30:16	2020-05-01	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	22630	delivery	5	46
56961	2020-05-01 17:34:20	2020-05-01	9	[{"id_menu":6,"count":1}]	601	pick-up	0	9
56962	2020-05-01 17:37:47	2020-05-01	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	5201	pick-up	0	26
56963	2020-05-01 17:46:46	2020-05-01	9	[{"id_menu":7,"count":1}]	8863	pick-up	0	9
56964	2020-05-01 17:48:28	2020-05-01	9	[{"id_menu":7,"count":1}]	22637	pick-up	0	9
56965	2020-05-01 17:55:05	2020-05-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22516	pick-up	0	17
56966	2020-05-01 17:59:01	2020-05-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	22534	delivery	5	36
56967	2020-05-01 18:01:54	2020-05-01	12	[{"id_menu":1,"count":1}]	18030	delivery	5	17
56968	2020-05-01 18:02:29	2020-05-01	12	[{"id_menu":1,"count":1}]	14411	delivery	5	17
56969	2020-05-01 18:02:50	2020-05-01	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	546	delivery	5	36
56970	2020-05-01 18:02:50	2020-05-01	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	22686	delivery	5	57
56971	2020-05-01 18:05:30	2020-05-01	8	[{"id_menu":5,"count":1}]	22531	delivery	5	13
56972	2020-05-01 18:07:54	2020-05-01	9	[{"id_menu":6,"count":1}]	22680	delivery	5	14
56973	2020-05-01 18:14:36	2020-05-01	12	[{"id_menu":1,"count":1}]	22610	pick-up	0	12
56974	2020-05-01 18:15:45	2020-05-01	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19894	pick-up	0	31
56975	2020-05-01 18:30:28	2020-05-01	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	22646	delivery	5	34
56976	2020-05-01 18:32:09	2020-05-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	22552	delivery	5	28
56977	2020-05-01 18:32:36	2020-05-01	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	19506	pick-up	0	21
56978	2020-05-01 18:33:34	2020-05-01	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	22528	delivery	5	31
56979	2020-05-01 18:38:58	2020-05-01	9	[{"id_menu":6,"count":1}]	22565	pick-up	0	9
56980	2020-05-01 18:54:21	2020-05-01	14	[{"id_menu":2,"count":1}]	22658	delivery	5	19
56981	2020-05-01 18:55:24	2020-05-01	14	[{"id_menu":2,"count":1}]	22571	delivery	5	19
56982	2020-05-01 18:57:29	2020-05-01	12	[{"id_menu":1,"count":1}]	2320	pick-up	0	12
56983	2020-05-01 19:00:34	2020-05-01	12	[{"id_menu":3,"count":1}]	15137	delivery	5	17
56984	2020-05-01 19:03:48	2020-05-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22595	delivery	5	23
56985	2020-05-01 19:05:14	2020-05-01	17	[{"id_menu":4,"count":1}]	6092	pick-up	0	17
56986	2020-05-01 19:05:19	2020-05-01	12	[{"id_menu":1,"count":2}]	91	pick-up	0	12
56987	2020-05-01 19:08:01	2020-05-01	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	20024	pick-up	0	20
56988	2020-05-01 19:09:51	2020-05-01	9	[{"id_menu":6,"count":1}]	13477	pick-up	0	9
56989	2020-05-01 19:13:25	2020-05-01	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	17372	pick-up	0	20
56990	2020-05-01 19:17:25	2020-05-01	12	[{"id_menu":3,"count":1}]	17610	delivery	5	17
56991	2020-05-01 19:32:37	2020-05-01	9	[{"id_menu":6,"count":1}]	22605	pick-up	0	9
56992	2020-05-01 19:34:13	2020-05-01	9	[{"id_menu":6,"count":1}]	5886	delivery	5	14
56993	2020-05-01 19:34:21	2020-05-01	9	[{"id_menu":6,"count":1}]	2891	pick-up	0	9
56994	2020-05-01 19:37:59	2020-05-01	9	[{"id_menu":6,"count":1}]	22549	delivery	5	14
56995	2020-05-01 19:41:10	2020-05-01	9	[{"id_menu":6,"count":1}]	22581	delivery	5	14
56996	2020-05-01 19:46:25	2020-05-01	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4905	delivery	5	45
56997	2020-05-01 19:48:32	2020-05-01	17	[{"id_menu":4,"count":1}]	17456	delivery	5	22
56998	2020-05-01 19:50:27	2020-05-01	8	[{"id_menu":5,"count":1}]	22113	delivery	5	13
56999	2020-05-01 19:51:23	2020-05-01	14	[{"id_menu":2,"count":1}]	13028	pick-up	0	14
57000	2020-05-01 19:52:33	2020-05-01	9	[{"id_menu":6,"count":1}]	21281	delivery	5	14
57001	2020-05-01 20:03:09	2020-05-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6848	pick-up	0	31
57002	2020-05-01 20:04:07	2020-05-01	9	[{"id_menu":6,"count":2}]	7713	delivery	5	14
57003	2020-05-01 20:19:43	2020-05-01	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	19434	pick-up	0	22
57004	2020-05-01 20:24:22	2020-05-01	14	[{"id_menu":2,"count":1}]	11637	delivery	5	19
57005	2020-05-01 20:29:11	2020-05-01	12	[{"id_menu":1,"count":1}]	22623	pick-up	0	12
57006	2020-05-01 20:33:55	2020-05-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	22541	delivery	5	22
57007	2020-05-01 20:35:36	2020-05-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	22611	delivery	5	28
57008	2020-05-01 20:36:58	2020-05-01	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	586	pick-up	0	43
57009	2020-05-01 20:42:12	2020-05-01	14	[{"id_menu":2,"count":1}]	14127	delivery	5	19
57010	2020-05-01 20:44:38	2020-05-01	12	[{"id_menu":1,"count":1}]	14794	delivery	5	17
57011	2020-05-01 20:48:50	2020-05-01	9	[{"id_menu":6,"count":1}]	20670	delivery	5	14
57012	2020-05-01 20:51:09	2020-05-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22533	delivery	5	22
57013	2020-05-01 20:51:25	2020-05-01	12	[{"id_menu":3,"count":1}]	13062	pick-up	0	12
57014	2020-05-01 20:57:26	2020-05-01	9	[{"id_menu":6,"count":1}]	22699	delivery	5	14
57015	2020-05-01 21:03:39	2020-05-01	14	[{"id_menu":2,"count":1}]	12483	delivery	5	19
57016	2020-05-01 21:12:55	2020-05-01	9	[{"id_menu":7,"count":1}]	22547	delivery	5	14
57017	2020-05-01 21:27:05	2020-05-01	9	[{"id_menu":7,"count":1}]	16361	delivery	5	14
57018	2020-05-01 21:29:03	2020-05-01	14	[{"id_menu":2,"count":1}]	22651	delivery	5	19
57019	2020-05-01 21:41:09	2020-05-01	14	[{"id_menu":2,"count":1}]	22681	delivery	5	19
57020	2020-05-01 21:41:43	2020-05-01	12	[{"id_menu":3,"count":1}]	11452	pick-up	0	12
57021	2020-05-01 21:44:52	2020-05-01	12	[{"id_menu":1,"count":1}]	10283	pick-up	0	12
57022	2020-05-01 21:49:00	2020-05-01	9	[{"id_menu":6,"count":1}]	2164	delivery	5	14
57023	2020-05-01 21:49:52	2020-05-01	14	[{"id_menu":2,"count":1}]	18770	pick-up	0	14
57024	2020-05-01 21:57:27	2020-05-01	12	[{"id_menu":1,"count":1}]	22521	delivery	5	17
57025	2020-05-01 21:57:33	2020-05-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	22662	delivery	5	22
57026	2020-05-01 21:57:48	2020-05-01	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1670	pick-up	0	34
57027	2020-05-01 22:00:23	2020-05-01	9	[{"id_menu":7,"count":1}]	22526	delivery	5	14
57028	2020-05-01 22:02:38	2020-05-01	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	475	delivery	5	29
57029	2020-05-01 22:06:32	2020-05-01	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	13758	delivery	5	37
57030	2020-05-01 22:08:34	2020-05-01	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3812	delivery	5	31
57031	2020-05-01 22:13:52	2020-05-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	21263	pick-up	0	23
57032	2020-05-01 22:25:52	2020-05-01	12	[{"id_menu":1,"count":1}]	22586	delivery	5	17
57033	2020-05-01 22:28:20	2020-05-01	12	[{"id_menu":3,"count":1}]	22594	delivery	5	17
57034	2020-05-01 22:31:36	2020-05-01	17	[{"id_menu":4,"count":1}]	1432	pick-up	0	17
57035	2020-05-01 22:33:15	2020-05-01	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2071	pick-up	0	21
57036	2020-05-01 22:36:30	2020-05-01	17	[{"id_menu":4,"count":1}]	9048	delivery	5	22
57037	2020-05-01 22:41:06	2020-05-01	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4191	pick-up	0	26
57038	2020-05-01 22:46:18	2020-05-01	8	[{"id_menu":5,"count":1}]	13677	pick-up	0	8
57039	2020-05-01 22:50:15	2020-05-01	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	8705	delivery	5	25
57040	2020-05-01 23:00:16	2020-05-01	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3618	delivery	5	27
57041	2020-05-01 23:00:34	2020-05-01	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22606	delivery	5	31
57042	2020-05-01 23:04:14	2020-05-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	22694	delivery	5	22
57043	2020-05-01 23:05:58	2020-05-01	14	[{"id_menu":2,"count":2}]	12318	delivery	5	19
57044	2020-05-01 23:06:29	2020-05-01	8	[{"id_menu":5,"count":1}]	8506	delivery	5	13
57045	2020-05-01 23:13:26	2020-05-01	12	[{"id_menu":3,"count":1}]	22624	delivery	5	17
57046	2020-05-01 23:16:01	2020-05-01	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22645	delivery	5	40
57047	2020-05-01 23:21:16	2020-05-01	8	[{"id_menu":5,"count":1}]	7689	pick-up	0	8
57048	2020-05-01 23:27:16	2020-05-01	12	[{"id_menu":3,"count":1}]	3016	delivery	5	17
57049	2020-05-01 23:28:46	2020-05-01	9	[{"id_menu":6,"count":1}]	799	delivery	5	14
57050	2020-05-01 23:29:51	2020-05-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22621	pick-up	0	17
57051	2020-05-01 23:31:20	2020-05-01	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	15218	delivery	5	27
57052	2020-05-01 23:32:50	2020-05-01	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3989	delivery	5	45
57053	2020-05-01 23:40:57	2020-05-01	8	[{"id_menu":5,"count":1}]	4190	delivery	5	13
57054	2020-05-01 23:42:41	2020-05-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8189	delivery	5	22
57055	2020-05-01 23:43:16	2020-05-01	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	22519	pick-up	0	24
57056	2020-05-01 23:50:57	2020-05-01	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8349	delivery	5	34
57057	2020-05-01 23:54:05	2020-05-01	9	[{"id_menu":6,"count":1}]	22684	delivery	5	14
57058	2020-05-02 00:00:38	2020-05-02	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	17083	pick-up	0	20
57059	2020-05-02 00:01:21	2020-05-02	9	[{"id_menu":6,"count":1}]	18148	delivery	5	14
57060	2020-05-02 00:03:16	2020-05-02	17	[{"id_menu":4,"count":1}]	22878	delivery	5	22
57061	2020-05-02 00:03:41	2020-05-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3989	delivery	5	22
57062	2020-05-02 00:03:43	2020-05-02	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	22713	delivery	5	25
57063	2020-05-02 00:04:01	2020-05-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	19793	delivery	5	23
57064	2020-05-02 00:08:53	2020-05-02	9	[{"id_menu":7,"count":1}]	4953	delivery	5	14
57065	2020-05-02 00:12:17	2020-05-02	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	5886	delivery	5	26
57066	2020-05-02 00:12:26	2020-05-02	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	22835	pick-up	0	26
57067	2020-05-02 00:16:51	2020-05-02	14	[{"id_menu":2,"count":1}]	22859	delivery	5	19
57068	2020-05-02 00:25:53	2020-05-02	12	[{"id_menu":3,"count":1}]	22774	delivery	5	17
57069	2020-05-02 00:26:00	2020-05-02	17	[{"id_menu":4,"count":1}]	6113	delivery	5	22
57070	2020-05-02 00:33:33	2020-05-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7190	pick-up	0	23
57071	2020-05-02 00:34:13	2020-05-02	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	22716	delivery	5	39
57072	2020-05-02 00:35:04	2020-05-02	17	[{"id_menu":4,"count":1}]	3452	delivery	5	22
57073	2020-05-02 00:37:55	2020-05-02	12	[{"id_menu":1,"count":1}]	22792	delivery	5	17
57074	2020-05-02 00:38:37	2020-05-02	9	[{"id_menu":6,"count":1}]	2858	delivery	5	14
57075	2020-05-02 00:40:43	2020-05-02	14	[{"id_menu":2,"count":1}]	22704	delivery	5	19
57076	2020-05-02 00:57:54	2020-05-02	17	[{"id_menu":4,"count":1}]	3113	delivery	5	22
57077	2020-05-02 01:05:49	2020-05-02	9	[{"id_menu":6,"count":2}]	21962	delivery	5	14
57078	2020-05-02 01:09:49	2020-05-02	9	[{"id_menu":7,"count":1}]	22875	pick-up	0	9
57079	2020-05-02 01:10:33	2020-05-02	9	[{"id_menu":7,"count":2}]	15221	delivery	5	14
57080	2020-05-02 01:14:25	2020-05-02	17	[{"id_menu":4,"count":1}]	19783	delivery	5	22
57081	2020-05-02 01:18:58	2020-05-02	8	[{"id_menu":5,"count":1}]	1527	pick-up	0	8
57082	2020-05-02 01:20:07	2020-05-02	12	[{"id_menu":3,"count":1}]	22732	pick-up	0	12
57083	2020-05-02 01:23:26	2020-05-02	14	[{"id_menu":2,"count":1}]	22819	delivery	5	19
57084	2020-05-02 01:24:37	2020-05-02	14	[{"id_menu":2,"count":1}]	22741	delivery	5	19
57085	2020-05-02 01:28:15	2020-05-02	9	[{"id_menu":6,"count":1}]	22760	delivery	5	14
57086	2020-05-02 01:36:22	2020-05-02	9	[{"id_menu":7,"count":1}]	10337	delivery	5	14
57087	2020-05-02 01:40:33	2020-05-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16350	delivery	5	31
57088	2020-05-02 01:42:09	2020-05-02	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	22747	delivery	5	31
57089	2020-05-02 01:43:02	2020-05-02	9	[{"id_menu":7,"count":1}]	22880	delivery	5	14
57090	2020-05-02 01:50:39	2020-05-02	12	[{"id_menu":1,"count":1}]	15082	pick-up	0	12
57091	2020-05-02 01:55:00	2020-05-02	17	[{"id_menu":4,"count":1}]	17494	delivery	5	22
57092	2020-05-02 02:03:29	2020-05-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	22778	delivery	5	28
57093	2020-05-02 02:08:07	2020-05-02	9	[{"id_menu":7,"count":1}]	5574	delivery	5	14
57094	2020-05-02 02:08:35	2020-05-02	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22787	delivery	5	34
57095	2020-05-02 02:12:10	2020-05-02	9	[{"id_menu":6,"count":1}]	12775	delivery	5	14
57096	2020-05-02 02:19:11	2020-05-02	8	[{"id_menu":5,"count":1}]	22842	delivery	5	13
57097	2020-05-02 02:19:49	2020-05-02	12	[{"id_menu":1,"count":1}]	22807	pick-up	0	12
57098	2020-05-02 02:20:32	2020-05-02	8	[{"id_menu":5,"count":1}]	13924	delivery	5	13
57099	2020-05-02 02:21:43	2020-05-02	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	15027	delivery	5	22
57100	2020-05-02 02:23:09	2020-05-02	9	[{"id_menu":7,"count":1}]	22738	delivery	5	14
57101	2020-05-02 02:25:05	2020-05-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	22802	delivery	5	22
57102	2020-05-02 02:28:30	2020-05-02	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22826	delivery	5	53
57103	2020-05-02 02:28:40	2020-05-02	9	[{"id_menu":7,"count":1}]	22820	delivery	5	14
57104	2020-05-02 02:28:45	2020-05-02	8	[{"id_menu":5,"count":1}]	8224	pick-up	0	8
57105	2020-05-02 02:30:32	2020-05-02	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	5093	delivery	5	34
57106	2020-05-02 02:39:17	2020-05-02	8	[{"id_menu":5,"count":1}]	3934	delivery	5	13
57107	2020-05-02 02:43:20	2020-05-02	12	[{"id_menu":3,"count":1}]	22768	delivery	5	17
57108	2020-05-02 02:49:17	2020-05-02	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	11648	pick-up	0	21
57109	2020-05-02 02:49:56	2020-05-02	9	[{"id_menu":6,"count":1}]	20542	delivery	5	14
57110	2020-05-02 02:50:19	2020-05-02	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	18468	delivery	5	29
57111	2020-05-02 02:50:57	2020-05-02	9	[{"id_menu":6,"count":1}]	20304	delivery	5	14
57112	2020-05-02 02:53:39	2020-05-02	12	[{"id_menu":1,"count":1}]	20967	delivery	5	17
57113	2020-05-02 02:56:24	2020-05-02	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22744	delivery	5	54
57114	2020-05-02 03:05:55	2020-05-02	12	[{"id_menu":3,"count":1}]	5861	delivery	5	17
57115	2020-05-02 03:08:16	2020-05-02	9	[{"id_menu":7,"count":1}]	13465	delivery	5	14
57116	2020-05-02 03:14:27	2020-05-02	8	[{"id_menu":5,"count":1}]	3471	delivery	5	13
57117	2020-05-02 03:15:28	2020-05-02	17	[{"id_menu":4,"count":1}]	22708	delivery	5	22
57118	2020-05-02 03:27:22	2020-05-02	43	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2785	delivery	5	48
57119	2020-05-02 03:32:21	2020-05-02	14	[{"id_menu":2,"count":1}]	12224	pick-up	0	14
57120	2020-05-02 03:32:21	2020-05-02	12	[{"id_menu":1,"count":1}]	19423	delivery	5	17
57121	2020-05-02 03:42:02	2020-05-02	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20746	delivery	5	40
57122	2020-05-02 03:43:28	2020-05-02	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22785	delivery	5	52
57123	2020-05-02 03:45:29	2020-05-02	12	[{"id_menu":1,"count":2}]	19840	delivery	5	17
57124	2020-05-02 03:46:29	2020-05-02	17	[{"id_menu":4,"count":2}]	22856	delivery	5	22
57125	2020-05-02 03:50:00	2020-05-02	9	[{"id_menu":7,"count":1}]	1314	pick-up	0	9
57126	2020-05-02 03:50:47	2020-05-02	9	[{"id_menu":7,"count":1}]	1403	pick-up	0	9
57127	2020-05-02 03:53:48	2020-05-02	17	[{"id_menu":4,"count":1}]	3788	pick-up	0	17
57128	2020-05-02 03:56:10	2020-05-02	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	20008	delivery	5	31
57129	2020-05-02 03:56:34	2020-05-02	9	[{"id_menu":6,"count":1}]	3249	pick-up	0	9
57130	2020-05-02 03:57:03	2020-05-02	9	[{"id_menu":6,"count":1}]	17011	delivery	5	14
57131	2020-05-02 03:57:37	2020-05-02	12	[{"id_menu":1,"count":1}]	14054	pick-up	0	12
57132	2020-05-02 04:01:10	2020-05-02	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	17286	delivery	5	38
57133	2020-05-02 04:05:55	2020-05-02	9	[{"id_menu":7,"count":1}]	69	pick-up	0	9
57134	2020-05-02 04:07:36	2020-05-02	14	[{"id_menu":2,"count":1}]	22824	pick-up	0	14
57135	2020-05-02 04:08:15	2020-05-02	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	22776	delivery	5	39
57136	2020-05-02 04:14:55	2020-05-02	12	[{"id_menu":1,"count":1}]	22784	pick-up	0	12
57137	2020-05-02 04:16:05	2020-05-02	9	[{"id_menu":7,"count":1}]	13345	delivery	5	14
57138	2020-05-02 04:28:53	2020-05-02	17	[{"id_menu":4,"count":1}]	274	pick-up	0	17
57139	2020-05-02 04:32:45	2020-05-02	9	[{"id_menu":6,"count":1}]	22777	delivery	5	14
57140	2020-05-02 04:34:02	2020-05-02	9	[{"id_menu":7,"count":1}]	14384	delivery	5	14
57141	2020-05-02 04:34:40	2020-05-02	9	[{"id_menu":7,"count":1}]	18635	delivery	5	14
57142	2020-05-02 04:37:15	2020-05-02	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	22847	delivery	5	56
57143	2020-05-02 04:38:16	2020-05-02	9	[{"id_menu":7,"count":1}]	5329	delivery	5	14
57144	2020-05-02 04:42:02	2020-05-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	18263	delivery	5	28
57145	2020-05-02 04:43:18	2020-05-02	9	[{"id_menu":6,"count":1}]	10903	delivery	5	14
57146	2020-05-02 04:45:22	2020-05-02	12	[{"id_menu":1,"count":1}]	22689	delivery	5	17
57147	2020-05-02 04:45:53	2020-05-02	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	22836	delivery	5	34
57148	2020-05-02 04:50:09	2020-05-02	9	[{"id_menu":6,"count":1}]	22707	delivery	5	14
57149	2020-05-02 04:55:34	2020-05-02	17	[{"id_menu":4,"count":1}]	15428	delivery	5	22
57150	2020-05-02 04:56:31	2020-05-02	9	[{"id_menu":6,"count":1}]	22848	delivery	5	14
57151	2020-05-02 05:02:17	2020-05-02	9	[{"id_menu":6,"count":1}]	9113	delivery	5	14
57152	2020-05-02 05:04:45	2020-05-02	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	22866	delivery	5	34
57153	2020-05-02 05:05:24	2020-05-02	8	[{"id_menu":5,"count":1}]	22709	delivery	5	13
57154	2020-05-02 05:09:17	2020-05-02	12	[{"id_menu":3,"count":1}]	11795	pick-up	0	12
57155	2020-05-02 05:13:42	2020-05-02	12	[{"id_menu":1,"count":1}]	22862	delivery	5	17
57156	2020-05-02 05:15:53	2020-05-02	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3408	delivery	5	31
57157	2020-05-02 05:16:38	2020-05-02	9	[{"id_menu":7,"count":1}]	22710	delivery	5	14
57158	2020-05-02 05:19:53	2020-05-02	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1432	pick-up	0	29
57159	2020-05-02 05:20:36	2020-05-02	9	[{"id_menu":7,"count":1}]	17664	delivery	5	14
57160	2020-05-02 05:22:46	2020-05-02	9	[{"id_menu":7,"count":2}]	22818	delivery	5	14
57161	2020-05-02 05:22:56	2020-05-02	9	[{"id_menu":6,"count":1}]	5053	delivery	5	14
57162	2020-05-02 05:23:31	2020-05-02	9	[{"id_menu":7,"count":1}]	22817	delivery	5	14
57163	2020-05-02 05:26:11	2020-05-02	9	[{"id_menu":7,"count":1}]	22816	delivery	5	14
57164	2020-05-02 05:27:40	2020-05-02	8	[{"id_menu":5,"count":1}]	10755	pick-up	0	8
57165	2020-05-02 05:30:33	2020-05-02	12	[{"id_menu":1,"count":1}]	14730	delivery	5	17
57166	2020-05-02 05:31:02	2020-05-02	9	[{"id_menu":6,"count":1}]	10449	delivery	5	14
57167	2020-05-02 05:32:05	2020-05-02	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	22750	pick-up	0	20
57168	2020-05-02 05:41:48	2020-05-02	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1722	pick-up	0	26
57169	2020-05-02 05:49:17	2020-05-02	9	[{"id_menu":6,"count":1}]	3847	pick-up	0	9
57170	2020-05-02 05:49:17	2020-05-02	12	[{"id_menu":3,"count":1}]	12949	delivery	5	17
57171	2020-05-02 05:50:14	2020-05-02	12	[{"id_menu":1,"count":1}]	22753	delivery	5	17
57172	2020-05-02 05:50:56	2020-05-02	9	[{"id_menu":6,"count":1}]	22851	delivery	5	14
57173	2020-05-02 05:56:51	2020-05-02	12	[{"id_menu":1,"count":1}]	5041	pick-up	0	12
57174	2020-05-02 05:57:38	2020-05-02	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	22850	delivery	5	36
57175	2020-05-02 06:00:16	2020-05-02	14	[{"id_menu":2,"count":1}]	22626	pick-up	0	14
57176	2020-05-02 06:05:57	2020-05-02	8	[{"id_menu":5,"count":1}]	545	pick-up	0	8
57177	2020-05-02 06:11:53	2020-05-02	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	22755	delivery	5	37
57178	2020-05-02 06:14:11	2020-05-02	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	19916	delivery	5	31
57179	2020-05-02 06:14:23	2020-05-02	9	[{"id_menu":7,"count":1}]	22783	pick-up	0	9
57180	2020-05-02 06:16:18	2020-05-02	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	22791	pick-up	0	40
57181	2020-05-02 06:16:41	2020-05-02	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	3119	delivery	5	34
57182	2020-05-02 06:33:15	2020-05-02	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22767	delivery	5	37
57183	2020-05-02 06:36:27	2020-05-02	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16072	delivery	5	40
57184	2020-05-02 06:37:57	2020-05-02	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	13262	delivery	5	45
57185	2020-05-02 06:39:43	2020-05-02	9	[{"id_menu":6,"count":1}]	4747	pick-up	0	9
57186	2020-05-02 06:44:55	2020-05-02	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18420	delivery	5	35
57187	2020-05-02 06:50:33	2020-05-02	17	[{"id_menu":4,"count":1}]	18259	pick-up	0	17
57188	2020-05-02 06:50:56	2020-05-02	17	[{"id_menu":4,"count":1}]	22752	delivery	5	22
57189	2020-05-02 06:52:55	2020-05-02	17	[{"id_menu":4,"count":2}]	7912	delivery	5	22
57190	2020-05-02 06:56:39	2020-05-02	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	22786	delivery	5	34
57191	2020-05-02 06:58:08	2020-05-02	14	[{"id_menu":2,"count":1}]	22730	delivery	5	19
57192	2020-05-02 07:00:20	2020-05-02	9	[{"id_menu":6,"count":1}]	19971	delivery	5	14
57193	2020-05-02 07:04:05	2020-05-02	17	[{"id_menu":4,"count":1}]	10415	pick-up	0	17
57194	2020-05-02 07:06:31	2020-05-02	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	22861	delivery	5	25
57195	2020-05-02 07:09:10	2020-05-02	8	[{"id_menu":5,"count":1}]	16321	pick-up	0	8
57196	2020-05-02 07:10:41	2020-05-02	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	22443	delivery	5	40
57197	2020-05-02 07:14:04	2020-05-02	8	[{"id_menu":5,"count":1}]	10324	delivery	5	13
57198	2020-05-02 07:14:18	2020-05-02	12	[{"id_menu":1,"count":1}]	3909	pick-up	0	12
57199	2020-05-02 07:15:49	2020-05-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8022	delivery	5	31
57200	2020-05-02 07:27:26	2020-05-02	12	[{"id_menu":3,"count":1}]	22728	delivery	5	17
57201	2020-05-02 07:37:46	2020-05-02	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	14286	delivery	5	31
57202	2020-05-02 07:39:48	2020-05-02	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	8830	delivery	5	43
57203	2020-05-02 07:41:15	2020-05-02	17	[{"id_menu":4,"count":1}]	22745	delivery	5	22
57204	2020-05-02 07:45:23	2020-05-02	12	[{"id_menu":1,"count":1}]	22737	delivery	5	17
57205	2020-05-02 07:53:10	2020-05-02	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16614	delivery	5	43
57206	2020-05-02 07:59:04	2020-05-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15123	delivery	5	22
57207	2020-05-02 08:00:54	2020-05-02	12	[{"id_menu":3,"count":1}]	22297	delivery	5	17
57208	2020-05-02 08:05:08	2020-05-02	9	[{"id_menu":7,"count":1}]	10714	delivery	5	14
57209	2020-05-02 08:05:21	2020-05-02	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	10336	delivery	5	22
57210	2020-05-02 08:08:05	2020-05-02	9	[{"id_menu":7,"count":1}]	6322	delivery	5	14
57211	2020-05-02 08:14:27	2020-05-02	8	[{"id_menu":5,"count":1}]	14924	delivery	5	13
57212	2020-05-02 08:22:54	2020-05-02	9	[{"id_menu":7,"count":1}]	15461	delivery	5	14
57213	2020-05-02 08:23:41	2020-05-02	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	800	delivery	5	37
57214	2020-05-02 08:26:23	2020-05-02	17	[{"id_menu":4,"count":1}]	20712	delivery	5	22
57215	2020-05-02 08:26:43	2020-05-02	14	[{"id_menu":2,"count":1}]	13256	pick-up	0	14
57216	2020-05-02 08:28:41	2020-05-02	14	[{"id_menu":2,"count":1}]	22863	delivery	5	19
57217	2020-05-02 08:34:44	2020-05-02	9	[{"id_menu":6,"count":1}]	371	delivery	5	14
57218	2020-05-02 08:36:14	2020-05-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	22706	delivery	5	22
57219	2020-05-02 08:36:27	2020-05-02	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	22865	delivery	5	26
57220	2020-05-02 08:40:36	2020-05-02	9	[{"id_menu":7,"count":1}]	13922	delivery	5	14
57221	2020-05-02 08:44:39	2020-05-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	22718	delivery	5	31
57222	2020-05-02 08:48:22	2020-05-02	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22871	delivery	5	22
57223	2020-05-02 08:48:38	2020-05-02	8	[{"id_menu":5,"count":1}]	2594	pick-up	0	8
57224	2020-05-02 08:49:05	2020-05-02	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	22766	delivery	5	36
57225	2020-05-02 08:52:07	2020-05-02	17	[{"id_menu":4,"count":1}]	381	pick-up	0	17
57226	2020-05-02 08:59:20	2020-05-02	8	[{"id_menu":5,"count":1}]	22796	delivery	5	13
57227	2020-05-02 09:00:41	2020-05-02	9	[{"id_menu":7,"count":2}]	22806	delivery	5	14
57228	2020-05-02 09:01:00	2020-05-02	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	6116	delivery	5	23
57229	2020-05-02 09:01:45	2020-05-02	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	10266	delivery	5	22
57230	2020-05-02 09:02:09	2020-05-02	12	[{"id_menu":3,"count":1}]	18418	delivery	5	17
57231	2020-05-02 09:03:33	2020-05-02	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16182	delivery	5	51
57232	2020-05-02 09:04:11	2020-05-02	14	[{"id_menu":2,"count":1}]	12479	delivery	5	19
57233	2020-05-02 09:06:02	2020-05-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	19602	pick-up	0	23
57234	2020-05-02 09:07:40	2020-05-02	17	[{"id_menu":4,"count":1}]	22793	delivery	5	22
57235	2020-05-02 09:10:00	2020-05-02	9	[{"id_menu":6,"count":1}]	11983	delivery	5	14
57236	2020-05-02 09:11:23	2020-05-02	17	[{"id_menu":4,"count":1}]	5160	delivery	5	22
57237	2020-05-02 09:13:02	2020-05-02	12	[{"id_menu":3,"count":1}]	22719	delivery	5	17
57238	2020-05-02 09:19:58	2020-05-02	8	[{"id_menu":5,"count":1}]	15629	delivery	5	13
57239	2020-05-02 09:20:35	2020-05-02	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	22720	pick-up	0	31
57240	2020-05-02 09:22:18	2020-05-02	9	[{"id_menu":6,"count":1}]	22858	delivery	5	14
57241	2020-05-02 09:23:34	2020-05-02	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	22857	delivery	5	34
57242	2020-05-02 09:23:43	2020-05-02	17	[{"id_menu":4,"count":1}]	13473	pick-up	0	17
57243	2020-05-02 09:25:40	2020-05-02	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	22860	delivery	5	26
57244	2020-05-02 09:26:02	2020-05-02	8	[{"id_menu":5,"count":1}]	22855	delivery	5	13
57245	2020-05-02 09:28:14	2020-05-02	9	[{"id_menu":7,"count":1}]	4628	pick-up	0	9
57246	2020-05-02 09:28:41	2020-05-02	14	[{"id_menu":2,"count":1}]	4644	pick-up	0	14
57247	2020-05-02 09:45:42	2020-05-02	8	[{"id_menu":5,"count":1}]	19412	delivery	5	13
57248	2020-05-02 09:46:06	2020-05-02	14	[{"id_menu":2,"count":1}]	16124	delivery	5	19
57249	2020-05-02 09:49:35	2020-05-02	12	[{"id_menu":1,"count":1}]	5901	pick-up	0	12
57250	2020-05-02 09:59:52	2020-05-02	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	9290	delivery	5	31
57251	2020-05-02 10:00:27	2020-05-02	17	[{"id_menu":4,"count":1}]	701	delivery	5	22
57252	2020-05-02 10:04:51	2020-05-02	12	[{"id_menu":3,"count":1}]	14146	pick-up	0	12
57253	2020-05-02 10:06:25	2020-05-02	9	[{"id_menu":7,"count":1}]	22846	pick-up	0	9
57254	2020-05-02 10:09:24	2020-05-02	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	22727	delivery	5	26
57255	2020-05-02 10:13:02	2020-05-02	9	[{"id_menu":7,"count":1}]	12060	delivery	5	14
57256	2020-05-02 10:15:44	2020-05-02	14	[{"id_menu":2,"count":1}]	22643	pick-up	0	14
57257	2020-05-02 10:15:57	2020-05-02	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	9110	delivery	5	43
57258	2020-05-02 10:16:01	2020-05-02	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11245	delivery	5	31
57259	2020-05-02 10:16:15	2020-05-02	9	[{"id_menu":6,"count":1}]	8334	delivery	5	14
57260	2020-05-02 10:16:55	2020-05-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":3}]	22830	delivery	5	22
57261	2020-05-02 10:18:25	2020-05-02	12	[{"id_menu":3,"count":2}]	22828	delivery	5	17
57262	2020-05-02 10:19:58	2020-05-02	9	[{"id_menu":7,"count":1}]	6600	pick-up	0	9
57263	2020-05-02 10:21:31	2020-05-02	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	22736	delivery	5	26
57264	2020-05-02 10:28:02	2020-05-02	9	[{"id_menu":6,"count":1}]	17933	delivery	5	14
57332	2020-05-02 13:40:51	2020-05-02	12	[{"id_menu":3,"count":1}]	22801	delivery	5	17
57265	2020-05-02 10:29:46	2020-05-02	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	22109	delivery	5	40
57266	2020-05-02 10:30:44	2020-05-02	12	[{"id_menu":3,"count":1}]	204	delivery	5	17
57267	2020-05-02 10:30:50	2020-05-02	9	[{"id_menu":6,"count":1}]	2557	delivery	5	14
57268	2020-05-02 10:30:58	2020-05-02	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	22790	delivery	5	36
57269	2020-05-02 10:33:37	2020-05-02	12	[{"id_menu":3,"count":1}]	3511	pick-up	0	12
57270	2020-05-02 10:35:47	2020-05-02	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	22726	delivery	5	26
57271	2020-05-02 10:41:55	2020-05-02	17	[{"id_menu":4,"count":2}]	12933	delivery	5	22
57272	2020-05-02 10:43:16	2020-05-02	17	[{"id_menu":4,"count":2}]	13657	delivery	5	22
57273	2020-05-02 10:45:54	2020-05-02	8	[{"id_menu":5,"count":1}]	13758	delivery	5	13
57274	2020-05-02 10:46:45	2020-05-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2516	pick-up	0	23
57275	2020-05-02 10:48:07	2020-05-02	14	[{"id_menu":2,"count":2}]	802	pick-up	0	14
57276	2020-05-02 10:49:17	2020-05-02	9	[{"id_menu":7,"count":1}]	529	pick-up	0	9
57277	2020-05-02 10:49:31	2020-05-02	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12454	pick-up	0	17
57278	2020-05-02 10:50:13	2020-05-02	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	15443	delivery	5	26
57279	2020-05-02 10:51:02	2020-05-02	9	[{"id_menu":6,"count":1}]	22721	delivery	5	14
57280	2020-05-02 10:53:28	2020-05-02	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	18244	delivery	5	31
57281	2020-05-02 10:54:35	2020-05-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11806	delivery	5	31
57282	2020-05-02 10:54:37	2020-05-02	8	[{"id_menu":5,"count":1}]	10717	delivery	5	13
57283	2020-05-02 10:57:13	2020-05-02	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4841	delivery	5	44
57284	2020-05-02 11:00:45	2020-05-02	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	22853	delivery	5	28
57285	2020-05-02 11:05:38	2020-05-02	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3819	delivery	5	48
57286	2020-05-02 11:06:05	2020-05-02	17	[{"id_menu":4,"count":1}]	22734	delivery	5	22
57287	2020-05-02 11:10:14	2020-05-02	8	[{"id_menu":5,"count":1}]	22814	delivery	5	13
57288	2020-05-02 11:13:11	2020-05-02	9	[{"id_menu":7,"count":1}]	2805	delivery	5	14
57289	2020-05-02 11:15:41	2020-05-02	8	[{"id_menu":5,"count":1}]	18629	delivery	5	13
57290	2020-05-02 11:18:32	2020-05-02	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	22789	delivery	5	36
57291	2020-05-02 11:22:15	2020-05-02	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	7813	delivery	5	31
57292	2020-05-02 11:24:36	2020-05-02	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	7097	pick-up	0	20
57293	2020-05-02 11:30:27	2020-05-02	9	[{"id_menu":6,"count":1}]	20302	delivery	5	14
57294	2020-05-02 11:34:17	2020-05-02	9	[{"id_menu":6,"count":1}]	621	pick-up	0	9
57295	2020-05-02 11:34:47	2020-05-02	14	[{"id_menu":2,"count":1}]	20667	pick-up	0	14
57296	2020-05-02 11:36:28	2020-05-02	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	22812	delivery	5	57
57297	2020-05-02 11:36:53	2020-05-02	9	[{"id_menu":6,"count":1}]	12095	pick-up	0	9
57298	2020-05-02 11:37:15	2020-05-02	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22831	delivery	5	35
57299	2020-05-02 11:38:42	2020-05-02	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	22799	delivery	5	34
57300	2020-05-02 11:39:16	2020-05-02	9	[{"id_menu":6,"count":2}]	3572	delivery	5	14
57301	2020-05-02 11:46:02	2020-05-02	8	[{"id_menu":5,"count":1}]	22876	delivery	5	13
57302	2020-05-02 11:51:02	2020-05-02	8	[{"id_menu":5,"count":1}]	22781	delivery	5	13
57303	2020-05-02 11:58:44	2020-05-02	9	[{"id_menu":6,"count":1}]	2954	delivery	5	14
57304	2020-05-02 12:03:20	2020-05-02	9	[{"id_menu":7,"count":1}]	5257	pick-up	0	9
57305	2020-05-02 12:06:18	2020-05-02	17	[{"id_menu":4,"count":1}]	9267	delivery	5	22
57306	2020-05-02 12:06:19	2020-05-02	14	[{"id_menu":2,"count":1}]	12905	pick-up	0	14
57307	2020-05-02 12:07:55	2020-05-02	9	[{"id_menu":6,"count":1}]	22703	delivery	5	14
57308	2020-05-02 12:15:13	2020-05-02	12	[{"id_menu":3,"count":1}]	22822	pick-up	0	12
57309	2020-05-02 12:23:34	2020-05-02	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	94	delivery	5	25
57310	2020-05-02 12:24:21	2020-05-02	8	[{"id_menu":5,"count":1}]	2136	delivery	5	13
57311	2020-05-02 12:24:42	2020-05-02	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14015	delivery	5	36
57312	2020-05-02 12:27:05	2020-05-02	9	[{"id_menu":6,"count":1}]	6493	delivery	5	14
57313	2020-05-02 12:29:32	2020-05-02	9	[{"id_menu":7,"count":1}]	22838	delivery	5	14
57314	2020-05-02 12:29:56	2020-05-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	22873	delivery	5	31
57315	2020-05-02 12:34:07	2020-05-02	17	[{"id_menu":4,"count":1}]	8951	delivery	5	22
57316	2020-05-02 12:38:24	2020-05-02	8	[{"id_menu":5,"count":1}]	3865	delivery	5	13
57317	2020-05-02 12:42:52	2020-05-02	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	22782	delivery	5	26
57318	2020-05-02 12:46:26	2020-05-02	12	[{"id_menu":1,"count":1}]	22779	delivery	5	17
57319	2020-05-02 12:49:56	2020-05-02	8	[{"id_menu":5,"count":1}]	22788	delivery	5	13
57320	2020-05-02 12:52:43	2020-05-02	14	[{"id_menu":2,"count":1}]	18928	pick-up	0	14
57321	2020-05-02 12:55:27	2020-05-02	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7782	delivery	5	48
57322	2020-05-02 12:56:48	2020-05-02	12	[{"id_menu":1,"count":1}]	223	pick-up	0	12
57323	2020-05-02 12:59:31	2020-05-02	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	22158	pick-up	0	22
57324	2020-05-02 13:04:17	2020-05-02	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	22723	delivery	5	30
57325	2020-05-02 13:08:11	2020-05-02	12	[{"id_menu":1,"count":1}]	8522	delivery	5	17
57326	2020-05-02 13:14:39	2020-05-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	15120	pick-up	0	23
57327	2020-05-02 13:18:32	2020-05-02	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	22759	delivery	5	40
57328	2020-05-02 13:19:31	2020-05-02	9	[{"id_menu":7,"count":1}]	22763	delivery	5	14
57329	2020-05-02 13:23:34	2020-05-02	9	[{"id_menu":7,"count":1}]	12670	delivery	5	14
57330	2020-05-02 13:36:45	2020-05-02	17	[{"id_menu":4,"count":1}]	12198	delivery	5	22
57331	2020-05-02 13:37:01	2020-05-02	12	[{"id_menu":1,"count":1}]	19062	delivery	5	17
57333	2020-05-02 13:41:52	2020-05-02	12	[{"id_menu":3,"count":1}]	511	pick-up	0	12
57334	2020-05-02 13:42:02	2020-05-02	9	[{"id_menu":6,"count":1}]	22348	delivery	5	14
57335	2020-05-02 13:44:49	2020-05-02	17	[{"id_menu":4,"count":3}]	22761	delivery	5	22
57336	2020-05-02 13:45:00	2020-05-02	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	10834	delivery	5	40
57337	2020-05-02 13:53:19	2020-05-02	9	[{"id_menu":7,"count":1}]	6440	pick-up	0	9
57338	2020-05-02 13:53:23	2020-05-02	9	[{"id_menu":6,"count":1}]	22849	delivery	5	14
57339	2020-05-02 13:53:42	2020-05-02	9	[{"id_menu":6,"count":1}]	19256	delivery	5	14
57340	2020-05-02 13:54:45	2020-05-02	9	[{"id_menu":6,"count":1}]	12189	pick-up	0	9
57341	2020-05-02 13:56:26	2020-05-02	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	3458	pick-up	0	24
57342	2020-05-02 14:02:54	2020-05-02	8	[{"id_menu":5,"count":1}]	10139	delivery	5	13
57343	2020-05-02 14:04:23	2020-05-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	20187	delivery	5	28
57344	2020-05-02 14:10:47	2020-05-02	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22811	delivery	5	45
57345	2020-05-02 14:11:32	2020-05-02	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	22764	delivery	5	31
57346	2020-05-02 14:13:30	2020-05-02	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	1509	delivery	5	28
57347	2020-05-02 14:14:58	2020-05-02	12	[{"id_menu":1,"count":1}]	20888	delivery	5	17
57348	2020-05-02 14:16:16	2020-05-02	9	[{"id_menu":6,"count":1}]	1622	pick-up	0	9
57349	2020-05-02 14:16:54	2020-05-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	18162	delivery	5	23
57350	2020-05-02 14:18:13	2020-05-02	9	[{"id_menu":6,"count":1}]	13552	delivery	5	14
57351	2020-05-02 14:18:56	2020-05-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	22722	delivery	5	31
57352	2020-05-02 14:21:02	2020-05-02	14	[{"id_menu":2,"count":1}]	8298	pick-up	0	14
57353	2020-05-02 14:21:38	2020-05-02	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1040	delivery	5	31
57354	2020-05-02 14:24:43	2020-05-02	14	[{"id_menu":2,"count":1}]	12089	delivery	5	19
57355	2020-05-02 14:24:49	2020-05-02	9	[{"id_menu":7,"count":1}]	2520	pick-up	0	9
57356	2020-05-02 14:24:58	2020-05-02	17	[{"id_menu":4,"count":1}]	1089	pick-up	0	17
57357	2020-05-02 14:25:27	2020-05-02	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2140	pick-up	0	35
57358	2020-05-02 14:25:34	2020-05-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	8708	delivery	5	28
57359	2020-05-02 14:25:47	2020-05-02	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14169	delivery	5	34
57360	2020-05-02 14:25:55	2020-05-02	12	[{"id_menu":1,"count":1}]	22724	pick-up	0	12
57361	2020-05-02 14:30:49	2020-05-02	17	[{"id_menu":4,"count":1}]	22808	delivery	5	22
57362	2020-05-02 14:31:35	2020-05-02	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	20711	delivery	5	39
57363	2020-05-02 14:32:34	2020-05-02	12	[{"id_menu":1,"count":1}]	22825	delivery	5	17
57364	2020-05-02 14:38:19	2020-05-02	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	22771	delivery	5	55
57365	2020-05-02 14:39:09	2020-05-02	17	[{"id_menu":4,"count":1}]	3982	delivery	5	22
57366	2020-05-02 14:46:24	2020-05-02	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3509	delivery	5	31
57367	2020-05-02 14:49:56	2020-05-02	9	[{"id_menu":7,"count":1}]	6594	delivery	5	14
57368	2020-05-02 14:54:03	2020-05-02	9	[{"id_menu":6,"count":1}]	20408	pick-up	0	9
57369	2020-05-02 14:57:20	2020-05-02	14	[{"id_menu":2,"count":1}]	20815	delivery	5	19
57370	2020-05-02 15:00:43	2020-05-02	9	[{"id_menu":6,"count":1}]	379	pick-up	0	9
57371	2020-05-02 15:02:12	2020-05-02	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	5503	pick-up	0	21
57372	2020-05-02 15:02:41	2020-05-02	17	[{"id_menu":4,"count":1}]	11390	pick-up	0	17
57373	2020-05-02 15:06:13	2020-05-02	9	[{"id_menu":6,"count":1}]	22827	delivery	5	14
57374	2020-05-02 15:07:04	2020-05-02	9	[{"id_menu":7,"count":1}]	12285	pick-up	0	9
57375	2020-05-02 15:07:09	2020-05-02	9	[{"id_menu":7,"count":1}]	1559	pick-up	0	9
57376	2020-05-02 15:08:26	2020-05-02	8	[{"id_menu":5,"count":1}]	22701	delivery	5	13
57377	2020-05-02 15:11:26	2020-05-02	8	[{"id_menu":5,"count":1}]	8269	delivery	5	13
57378	2020-05-02 15:13:28	2020-05-02	17	[{"id_menu":4,"count":1}]	20723	delivery	5	22
57379	2020-05-02 15:27:19	2020-05-02	9	[{"id_menu":6,"count":1}]	22832	delivery	5	14
57380	2020-05-02 15:32:25	2020-05-02	37	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	22868	delivery	5	42
57381	2020-05-02 15:34:13	2020-05-02	8	[{"id_menu":5,"count":1}]	3684	delivery	5	13
57382	2020-05-02 15:36:35	2020-05-02	8	[{"id_menu":5,"count":1}]	9106	delivery	5	13
57383	2020-05-02 15:39:44	2020-05-02	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	22833	delivery	5	57
57384	2020-05-02 15:39:59	2020-05-02	14	[{"id_menu":2,"count":1}]	15365	delivery	5	19
57385	2020-05-02 15:41:41	2020-05-02	9	[{"id_menu":6,"count":1}]	14752	delivery	5	14
57386	2020-05-02 15:42:07	2020-05-02	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	22729	delivery	5	31
57387	2020-05-02 15:42:42	2020-05-02	9	[{"id_menu":6,"count":1}]	22714	delivery	5	14
57388	2020-05-02 15:42:53	2020-05-02	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	1118	delivery	5	34
57389	2020-05-02 15:47:34	2020-05-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22874	delivery	5	23
57390	2020-05-02 15:47:37	2020-05-02	17	[{"id_menu":4,"count":1}]	22794	delivery	5	22
57391	2020-05-02 15:51:22	2020-05-02	17	[{"id_menu":4,"count":1}]	22740	delivery	5	22
57392	2020-05-02 15:53:40	2020-05-02	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2065	pick-up	0	21
57393	2020-05-02 15:58:06	2020-05-02	9	[{"id_menu":7,"count":1}]	4294	delivery	5	14
57394	2020-05-02 16:03:52	2020-05-02	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21490	delivery	5	22
57395	2020-05-02 16:04:53	2020-05-02	17	[{"id_menu":4,"count":2}]	17700	pick-up	0	17
57396	2020-05-02 16:05:23	2020-05-02	17	[{"id_menu":4,"count":1}]	1215	delivery	5	22
57397	2020-05-02 16:05:24	2020-05-02	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	1335	pick-up	0	30
57398	2020-05-02 16:08:02	2020-05-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14280	delivery	5	22
57399	2020-05-02 16:12:37	2020-05-02	8	[{"id_menu":5,"count":1}]	14106	delivery	5	13
57400	2020-05-02 16:17:02	2020-05-02	29	[{"id_menu":3,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14542	delivery	5	34
57401	2020-05-02 16:17:43	2020-05-02	9	[{"id_menu":7,"count":1}]	6489	pick-up	0	9
57402	2020-05-02 16:18:15	2020-05-02	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	22867	delivery	5	34
57403	2020-05-02 16:19:39	2020-05-02	12	[{"id_menu":1,"count":2}]	2416	pick-up	0	12
57404	2020-05-02 16:24:58	2020-05-02	17	[{"id_menu":4,"count":1}]	18847	delivery	5	22
57405	2020-05-02 16:27:27	2020-05-02	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	10461	delivery	5	39
57406	2020-05-02 16:28:12	2020-05-02	9	[{"id_menu":6,"count":1}]	4453	pick-up	0	9
57407	2020-05-02 16:30:02	2020-05-02	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17738	delivery	5	48
57408	2020-05-02 16:37:59	2020-05-02	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7811	delivery	5	51
57409	2020-05-02 16:38:47	2020-05-02	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	5761	delivery	5	27
57410	2020-05-02 16:39:00	2020-05-02	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	15187	pick-up	0	25
57411	2020-05-02 16:39:32	2020-05-02	17	[{"id_menu":4,"count":1}]	18119	pick-up	0	17
57412	2020-05-02 16:40:06	2020-05-02	12	[{"id_menu":1,"count":1}]	524	delivery	5	17
57413	2020-05-02 16:42:07	2020-05-02	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22815	delivery	5	37
57414	2020-05-02 16:42:10	2020-05-02	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	22809	delivery	5	39
57415	2020-05-02 16:45:40	2020-05-02	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	6204	pick-up	0	29
57416	2020-05-02 16:50:06	2020-05-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15873	delivery	5	31
57417	2020-05-02 16:50:31	2020-05-02	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	22754	delivery	5	44
57418	2020-05-02 16:53:26	2020-05-02	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22780	delivery	5	34
57419	2020-05-02 16:54:27	2020-05-02	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	22748	delivery	5	30
57420	2020-05-02 16:55:29	2020-05-02	9	[{"id_menu":6,"count":1}]	18843	delivery	5	14
57421	2020-05-02 16:56:03	2020-05-02	14	[{"id_menu":2,"count":1}]	3940	delivery	5	19
57422	2020-05-02 16:56:28	2020-05-02	12	[{"id_menu":3,"count":1}]	22852	delivery	5	17
57423	2020-05-02 16:57:20	2020-05-02	9	[{"id_menu":6,"count":1}]	11181	delivery	5	14
57424	2020-05-02 17:04:35	2020-05-02	9	[{"id_menu":6,"count":1}]	22804	delivery	5	14
57425	2020-05-02 17:05:51	2020-05-02	12	[{"id_menu":3,"count":1}]	22743	delivery	5	17
57426	2020-05-02 17:08:58	2020-05-02	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	22711	delivery	5	31
57427	2020-05-02 17:11:55	2020-05-02	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	8456	delivery	5	48
57428	2020-05-02 17:12:25	2020-05-02	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2252	pick-up	0	29
57429	2020-05-02 17:13:03	2020-05-02	17	[{"id_menu":4,"count":1}]	22705	delivery	5	22
57430	2020-05-02 17:13:17	2020-05-02	12	[{"id_menu":1,"count":1}]	20835	pick-up	0	12
57431	2020-05-02 17:15:11	2020-05-02	14	[{"id_menu":2,"count":1}]	940	pick-up	0	14
57432	2020-05-02 17:17:21	2020-05-02	9	[{"id_menu":6,"count":1}]	10582	delivery	5	14
57433	2020-05-02 17:20:19	2020-05-02	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	22854	delivery	5	23
57434	2020-05-02 17:20:32	2020-05-02	8	[{"id_menu":5,"count":1}]	11570	pick-up	0	8
57435	2020-05-02 17:23:37	2020-05-02	17	[{"id_menu":4,"count":1}]	2798	delivery	5	22
57436	2020-05-02 17:28:05	2020-05-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	8553	delivery	5	28
57437	2020-05-02 17:29:04	2020-05-02	8	[{"id_menu":5,"count":1}]	22717	delivery	5	13
57438	2020-05-02 17:32:26	2020-05-02	9	[{"id_menu":7,"count":1}]	22795	delivery	5	14
57439	2020-05-02 17:33:55	2020-05-02	9	[{"id_menu":6,"count":1}]	9684	delivery	5	14
57440	2020-05-02 17:39:24	2020-05-02	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22810	delivery	5	39
57441	2020-05-02 17:42:20	2020-05-02	9	[{"id_menu":7,"count":1}]	22841	delivery	5	14
57442	2020-05-02 17:43:24	2020-05-02	9	[{"id_menu":6,"count":1}]	19808	delivery	5	14
57443	2020-05-02 17:49:15	2020-05-02	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3421	pick-up	0	31
57444	2020-05-02 17:53:55	2020-05-02	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	22762	delivery	5	34
57445	2020-05-02 18:00:06	2020-05-02	12	[{"id_menu":1,"count":1}]	3968	pick-up	0	12
57446	2020-05-02 18:03:30	2020-05-02	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	3010	delivery	5	31
57447	2020-05-02 18:04:41	2020-05-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	20068	delivery	5	31
57448	2020-05-02 18:08:11	2020-05-02	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2110	delivery	5	28
57449	2020-05-02 18:11:24	2020-05-02	9	[{"id_menu":6,"count":1}]	16599	delivery	5	14
57450	2020-05-02 18:11:42	2020-05-02	17	[{"id_menu":4,"count":1}]	22770	delivery	5	22
57451	2020-05-02 18:14:02	2020-05-02	8	[{"id_menu":5,"count":1}]	22765	pick-up	0	8
57452	2020-05-02 18:15:52	2020-05-02	9	[{"id_menu":6,"count":2}]	1223	delivery	5	14
57453	2020-05-02 18:15:52	2020-05-02	12	[{"id_menu":3,"count":1}]	6152	delivery	5	17
57454	2020-05-02 18:16:01	2020-05-02	9	[{"id_menu":6,"count":1}]	1424	pick-up	0	9
57455	2020-05-02 18:16:36	2020-05-02	9	[{"id_menu":6,"count":1}]	22797	delivery	5	14
57456	2020-05-02 18:24:37	2020-05-02	9	[{"id_menu":7,"count":1}]	22872	delivery	5	14
57457	2020-05-02 18:24:38	2020-05-02	17	[{"id_menu":4,"count":1}]	22715	delivery	5	22
57458	2020-05-02 18:25:03	2020-05-02	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	22845	delivery	5	45
57459	2020-05-02 18:28:26	2020-05-02	14	[{"id_menu":2,"count":1}]	22733	delivery	5	19
57460	2020-05-02 18:31:17	2020-05-02	8	[{"id_menu":5,"count":1}]	7141	delivery	5	13
57461	2020-05-02 18:35:27	2020-05-02	9	[{"id_menu":7,"count":1}]	4350	pick-up	0	9
57462	2020-05-02 18:37:38	2020-05-02	12	[{"id_menu":3,"count":1}]	6645	delivery	5	17
57463	2020-05-02 18:38:48	2020-05-02	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	6270	delivery	5	27
57464	2020-05-02 18:48:41	2020-05-02	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	19277	delivery	5	34
57465	2020-05-02 18:49:34	2020-05-02	9	[{"id_menu":6,"count":1}]	20879	pick-up	0	9
57466	2020-05-02 18:50:03	2020-05-02	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	22869	delivery	5	30
57467	2020-05-02 18:50:05	2020-05-02	12	[{"id_menu":3,"count":1}]	1239	delivery	5	17
57468	2020-05-02 18:51:23	2020-05-02	12	[{"id_menu":1,"count":1}]	15578	delivery	5	17
57469	2020-05-02 18:57:01	2020-05-02	9	[{"id_menu":7,"count":2}]	21454	delivery	5	14
57470	2020-05-02 19:04:39	2020-05-02	9	[{"id_menu":7,"count":1}]	22735	delivery	5	14
57471	2020-05-02 19:08:21	2020-05-02	17	[{"id_menu":4,"count":1}]	15513	delivery	5	22
57472	2020-05-02 19:10:05	2020-05-02	12	[{"id_menu":3,"count":1}]	21100	delivery	5	17
57473	2020-05-02 19:13:08	2020-05-02	17	[{"id_menu":4,"count":1}]	12210	pick-up	0	17
57474	2020-05-02 19:13:12	2020-05-02	14	[{"id_menu":2,"count":1}]	22758	pick-up	0	14
57475	2020-05-02 19:14:26	2020-05-02	14	[{"id_menu":2,"count":1}]	20214	delivery	5	19
57476	2020-05-02 19:16:38	2020-05-02	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	7757	delivery	5	34
57477	2020-05-02 19:16:54	2020-05-02	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	10802	delivery	5	36
57478	2020-05-02 19:21:21	2020-05-02	17	[{"id_menu":4,"count":1}]	21485	pick-up	0	17
57479	2020-05-02 19:21:34	2020-05-02	9	[{"id_menu":7,"count":2}]	22844	pick-up	0	9
57480	2020-05-02 19:30:04	2020-05-02	12	[{"id_menu":3,"count":1}]	11146	pick-up	0	12
57481	2020-05-02 19:30:39	2020-05-02	9	[{"id_menu":6,"count":1}]	11673	delivery	5	14
57482	2020-05-02 19:36:05	2020-05-02	9	[{"id_menu":7,"count":1}]	3148	delivery	5	14
57483	2020-05-02 19:38:11	2020-05-02	9	[{"id_menu":7,"count":1}]	22870	pick-up	0	9
57484	2020-05-02 19:39:56	2020-05-02	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	13238	delivery	5	34
57485	2020-05-02 19:43:25	2020-05-02	9	[{"id_menu":6,"count":1}]	1684	delivery	5	14
57486	2020-05-02 19:46:15	2020-05-02	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	17556	delivery	5	40
57487	2020-05-02 19:51:09	2020-05-02	9	[{"id_menu":7,"count":1}]	22746	delivery	5	14
57488	2020-05-02 19:51:34	2020-05-02	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22739	delivery	5	34
57489	2020-05-02 19:51:40	2020-05-02	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	622	delivery	5	38
57490	2020-05-02 19:54:24	2020-05-02	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	22749	delivery	5	45
57491	2020-05-02 19:55:59	2020-05-02	9	[{"id_menu":6,"count":1}]	14726	delivery	5	14
57492	2020-05-02 19:57:04	2020-05-02	12	[{"id_menu":1,"count":1}]	10232	pick-up	0	12
57493	2020-05-02 19:58:37	2020-05-02	9	[{"id_menu":7,"count":1}]	453	delivery	5	14
57494	2020-05-02 20:00:46	2020-05-02	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	554	delivery	5	44
57495	2020-05-02 20:01:21	2020-05-02	12	[{"id_menu":1,"count":1}]	13621	delivery	5	17
57496	2020-05-02 20:02:27	2020-05-02	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	19693	delivery	5	39
57497	2020-05-02 20:03:22	2020-05-02	9	[{"id_menu":7,"count":1}]	482	delivery	5	14
57498	2020-05-02 20:09:33	2020-05-02	9	[{"id_menu":7,"count":1}]	11969	pick-up	0	9
57499	2020-05-02 20:11:31	2020-05-02	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	22877	delivery	5	22
57500	2020-05-02 20:15:35	2020-05-02	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	22769	delivery	5	26
57501	2020-05-02 20:16:48	2020-05-02	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22805	delivery	5	37
57502	2020-05-02 20:23:17	2020-05-02	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1145	pick-up	0	21
57503	2020-05-02 20:26:30	2020-05-02	9	[{"id_menu":7,"count":1}]	22800	delivery	5	14
57504	2020-05-02 20:31:51	2020-05-02	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	13656	delivery	5	36
57505	2020-05-02 20:33:42	2020-05-02	9	[{"id_menu":6,"count":1}]	18758	pick-up	0	9
57506	2020-05-02 20:41:24	2020-05-02	8	[{"id_menu":5,"count":1}]	19486	delivery	5	13
57507	2020-05-02 20:44:51	2020-05-02	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	22840	delivery	5	22
57508	2020-05-02 20:45:42	2020-05-02	9	[{"id_menu":7,"count":1}]	22813	delivery	5	14
57509	2020-05-02 20:47:12	2020-05-02	14	[{"id_menu":2,"count":1}]	11839	delivery	5	19
57510	2020-05-02 20:55:15	2020-05-02	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11172	delivery	5	22
57511	2020-05-02 20:55:22	2020-05-02	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	22228	pick-up	0	31
57512	2020-05-02 20:57:49	2020-05-02	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	22332	delivery	5	40
57513	2020-05-02 21:04:29	2020-05-02	12	[{"id_menu":1,"count":1}]	2352	pick-up	0	12
57514	2020-05-02 21:09:10	2020-05-02	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":2}]	1387	delivery	5	31
57515	2020-05-02 21:10:58	2020-05-02	12	[{"id_menu":1,"count":1}]	20413	pick-up	0	12
57516	2020-05-02 21:14:08	2020-05-02	9	[{"id_menu":7,"count":1}]	2275	pick-up	0	9
57517	2020-05-02 21:14:53	2020-05-02	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	13091	delivery	5	26
57518	2020-05-02 21:14:57	2020-05-02	17	[{"id_menu":4,"count":1}]	12248	delivery	5	22
57519	2020-05-02 21:15:29	2020-05-02	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	14979	delivery	5	35
57520	2020-05-02 21:16:27	2020-05-02	9	[{"id_menu":7,"count":1}]	3131	delivery	5	14
57521	2020-05-02 21:16:36	2020-05-02	9	[{"id_menu":7,"count":1}]	22798	delivery	5	14
57522	2020-05-02 21:19:23	2020-05-02	9	[{"id_menu":6,"count":1}]	7888	delivery	5	14
57523	2020-05-02 21:20:15	2020-05-02	17	[{"id_menu":4,"count":1}]	2946	delivery	5	22
57524	2020-05-02 21:21:14	2020-05-02	8	[{"id_menu":5,"count":1}]	15961	delivery	5	13
57525	2020-05-02 21:25:36	2020-05-02	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	22757	delivery	5	48
57526	2020-05-02 21:29:00	2020-05-02	9	[{"id_menu":6,"count":1}]	19628	delivery	5	14
57527	2020-05-02 21:32:41	2020-05-02	9	[{"id_menu":6,"count":1}]	18407	delivery	5	14
57528	2020-05-02 21:41:03	2020-05-02	17	[{"id_menu":4,"count":1}]	22751	delivery	5	22
57529	2020-05-02 21:42:01	2020-05-02	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	1453	pick-up	0	34
57530	2020-05-02 21:48:37	2020-05-02	9	[{"id_menu":6,"count":1}]	22691	pick-up	0	9
57531	2020-05-02 21:49:48	2020-05-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	8598	pick-up	0	17
57532	2020-05-02 21:52:56	2020-05-02	14	[{"id_menu":2,"count":1}]	2066	pick-up	0	14
57533	2020-05-02 21:55:00	2020-05-02	12	[{"id_menu":3,"count":1}]	22843	delivery	5	17
57534	2020-05-02 22:01:50	2020-05-02	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17366	delivery	5	43
57535	2020-05-02 22:05:17	2020-05-02	12	[{"id_menu":1,"count":1}]	19844	delivery	5	17
57536	2020-05-02 22:06:09	2020-05-02	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22712	delivery	5	34
57537	2020-05-02 22:08:06	2020-05-02	8	[{"id_menu":5,"count":1}]	359	pick-up	0	8
57538	2020-05-02 22:08:15	2020-05-02	14	[{"id_menu":2,"count":1}]	3102	delivery	5	19
57539	2020-05-02 22:16:50	2020-05-02	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	22829	delivery	5	36
57540	2020-05-02 22:28:39	2020-05-02	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	8420	pick-up	0	38
57541	2020-05-02 22:31:09	2020-05-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7533	delivery	5	23
57542	2020-05-02 22:32:08	2020-05-02	49	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	22725	delivery	5	54
57543	2020-05-02 22:40:06	2020-05-02	12	[{"id_menu":3,"count":1}]	202	pick-up	0	12
57544	2020-05-02 22:48:48	2020-05-02	14	[{"id_menu":2,"count":1}]	22823	pick-up	0	14
57545	2020-05-02 22:49:12	2020-05-02	9	[{"id_menu":6,"count":1}]	122	pick-up	0	9
57546	2020-05-02 22:55:25	2020-05-02	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1597	delivery	5	26
57547	2020-05-02 22:56:25	2020-05-02	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	136	delivery	5	27
57548	2020-05-02 23:00:08	2020-05-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":3}]	22839	delivery	5	22
57549	2020-05-02 23:04:52	2020-05-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11491	pick-up	0	18
57550	2020-05-02 23:05:04	2020-05-02	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7028	delivery	5	45
57551	2020-05-02 23:09:17	2020-05-02	9	[{"id_menu":7,"count":1}]	22742	delivery	5	14
57552	2020-05-02 23:13:09	2020-05-02	9	[{"id_menu":6,"count":1}]	22837	delivery	5	14
57553	2020-05-02 23:14:44	2020-05-02	17	[{"id_menu":4,"count":1}]	13483	delivery	5	22
57554	2020-05-02 23:15:18	2020-05-02	12	[{"id_menu":3,"count":1}]	6364	delivery	5	17
57555	2020-05-02 23:18:34	2020-05-02	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3115	delivery	5	36
57556	2020-05-02 23:18:56	2020-05-02	9	[{"id_menu":7,"count":1}]	22821	delivery	5	14
57557	2020-05-02 23:19:45	2020-05-02	8	[{"id_menu":5,"count":1}]	22089	delivery	5	13
57558	2020-05-02 23:20:26	2020-05-02	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3197	delivery	5	28
57559	2020-05-02 23:24:07	2020-05-02	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	22702	delivery	5	31
57560	2020-05-02 23:26:45	2020-05-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17503	delivery	5	23
57561	2020-05-02 23:29:08	2020-05-02	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	22756	delivery	5	38
57562	2020-05-02 23:34:54	2020-05-02	9	[{"id_menu":7,"count":1}]	19207	delivery	5	14
57563	2020-05-02 23:36:58	2020-05-02	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	22320	pick-up	0	26
57564	2020-05-02 23:38:07	2020-05-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19641	delivery	5	22
57565	2020-05-02 23:38:32	2020-05-02	12	[{"id_menu":3,"count":1}]	22773	pick-up	0	12
57566	2020-05-02 23:42:37	2020-05-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	22803	delivery	5	22
57567	2020-05-02 23:43:03	2020-05-02	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7905	pick-up	0	35
57568	2020-05-02 23:43:25	2020-05-02	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	5167	pick-up	0	22
57569	2020-05-02 23:52:46	2020-05-02	9	[{"id_menu":6,"count":2}]	22731	delivery	5	14
57570	2020-05-03 00:00:11	2020-05-03	8	[{"id_menu":5,"count":2}]	16644	delivery	5	13
57571	2020-05-03 00:00:28	2020-05-03	17	[{"id_menu":4,"count":1}]	23038	delivery	5	22
57572	2020-05-03 00:02:35	2020-05-03	14	[{"id_menu":2,"count":1}]	23024	delivery	5	19
57573	2020-05-03 00:02:37	2020-05-03	12	[{"id_menu":1,"count":1}]	22961	delivery	5	17
57574	2020-05-03 00:06:10	2020-05-03	17	[{"id_menu":4,"count":1}]	23022	delivery	5	22
57575	2020-05-03 00:08:55	2020-05-03	8	[{"id_menu":5,"count":1}]	9032	pick-up	0	8
57576	2020-05-03 00:11:30	2020-05-03	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	15136	delivery	5	40
57577	2020-05-03 00:13:52	2020-05-03	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	4695	delivery	5	31
57578	2020-05-03 00:14:46	2020-05-03	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4393	pick-up	0	31
57579	2020-05-03 00:14:52	2020-05-03	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	22947	delivery	5	43
57580	2020-05-03 00:15:33	2020-05-03	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	13842	delivery	5	26
57581	2020-05-03 00:16:54	2020-05-03	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	22957	delivery	5	40
57582	2020-05-03 00:21:54	2020-05-03	17	[{"id_menu":4,"count":1}]	2322	pick-up	0	17
57583	2020-05-03 00:23:37	2020-05-03	9	[{"id_menu":7,"count":1}]	3604	pick-up	0	9
57584	2020-05-03 00:30:38	2020-05-03	9	[{"id_menu":6,"count":1}]	470	delivery	5	14
57585	2020-05-03 00:31:54	2020-05-03	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22929	delivery	5	35
57586	2020-05-03 00:33:57	2020-05-03	12	[{"id_menu":1,"count":1}]	17700	pick-up	0	12
57587	2020-05-03 00:40:20	2020-05-03	9	[{"id_menu":7,"count":1}]	8482	delivery	5	14
57588	2020-05-03 00:41:23	2020-05-03	12	[{"id_menu":1,"count":1}]	1700	pick-up	0	12
57589	2020-05-03 00:42:32	2020-05-03	9	[{"id_menu":6,"count":3}]	4003	delivery	5	14
57590	2020-05-03 00:46:03	2020-05-03	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	23017	delivery	5	22
57591	2020-05-03 00:54:41	2020-05-03	12	[{"id_menu":3,"count":1}]	2367	pick-up	0	12
57592	2020-05-03 00:55:30	2020-05-03	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	10996	delivery	5	28
57593	2020-05-03 00:56:38	2020-05-03	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16413	delivery	5	45
57594	2020-05-03 00:58:07	2020-05-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	23049	delivery	5	28
57595	2020-05-03 00:58:51	2020-05-03	12	[{"id_menu":1,"count":1}]	3000	pick-up	0	12
57596	2020-05-03 01:01:55	2020-05-03	14	[{"id_menu":2,"count":1}]	21606	delivery	5	19
57597	2020-05-03 01:05:51	2020-05-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	2601	pick-up	0	23
57598	2020-05-03 01:08:03	2020-05-03	8	[{"id_menu":5,"count":1}]	6869	delivery	5	13
57599	2020-05-03 01:09:09	2020-05-03	9	[{"id_menu":7,"count":2}]	19966	delivery	5	14
57600	2020-05-03 01:12:40	2020-05-03	9	[{"id_menu":7,"count":2}]	5328	delivery	5	14
57601	2020-05-03 01:17:02	2020-05-03	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21887	delivery	5	34
57602	2020-05-03 01:23:16	2020-05-03	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	22988	delivery	5	25
57603	2020-05-03 01:26:56	2020-05-03	9	[{"id_menu":6,"count":1}]	9798	delivery	5	14
57604	2020-05-03 01:31:36	2020-05-03	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	20558	delivery	5	22
57605	2020-05-03 01:32:07	2020-05-03	12	[{"id_menu":1,"count":1}]	16042	pick-up	0	12
57606	2020-05-03 01:35:12	2020-05-03	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	23001	delivery	5	26
57607	2020-05-03 01:35:44	2020-05-03	9	[{"id_menu":7,"count":1}]	22926	delivery	5	14
57608	2020-05-03 01:37:30	2020-05-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5427	pick-up	0	23
57609	2020-05-03 01:40:53	2020-05-03	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	22928	delivery	5	23
57610	2020-05-03 01:42:59	2020-05-03	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7906	delivery	5	52
57611	2020-05-03 01:44:09	2020-05-03	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	22973	delivery	5	43
57612	2020-05-03 01:44:38	2020-05-03	14	[{"id_menu":2,"count":1}]	15721	delivery	5	19
57613	2020-05-03 01:46:39	2020-05-03	9	[{"id_menu":7,"count":1}]	22882	delivery	5	14
57614	2020-05-03 01:46:54	2020-05-03	8	[{"id_menu":5,"count":1}]	2311	pick-up	0	8
57615	2020-05-03 01:50:09	2020-05-03	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21672	pick-up	0	17
57616	2020-05-03 01:56:08	2020-05-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	22951	delivery	5	28
57617	2020-05-03 01:57:34	2020-05-03	12	[{"id_menu":1,"count":1}]	3173	delivery	5	17
57618	2020-05-03 01:58:36	2020-05-03	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	23079	delivery	5	40
57619	2020-05-03 02:00:51	2020-05-03	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18375	delivery	5	52
57620	2020-05-03 02:01:52	2020-05-03	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	15110	pick-up	0	23
57621	2020-05-03 02:16:30	2020-05-03	17	[{"id_menu":4,"count":1}]	1834	delivery	5	22
57622	2020-05-03 02:20:27	2020-05-03	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17503	delivery	5	23
57623	2020-05-03 02:31:07	2020-05-03	12	[{"id_menu":3,"count":1}]	23056	delivery	5	17
57624	2020-05-03 02:35:34	2020-05-03	9	[{"id_menu":6,"count":1}]	17055	delivery	5	14
57625	2020-05-03 02:35:48	2020-05-03	14	[{"id_menu":2,"count":2}]	23035	delivery	5	19
57626	2020-05-03 02:37:04	2020-05-03	12	[{"id_menu":3,"count":1}]	1640	delivery	5	17
57627	2020-05-03 02:43:36	2020-05-03	14	[{"id_menu":2,"count":1}]	14031	delivery	5	19
57628	2020-05-03 02:44:23	2020-05-03	9	[{"id_menu":6,"count":1}]	23033	delivery	5	14
57629	2020-05-03 02:45:46	2020-05-03	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	14086	pick-up	0	29
57630	2020-05-03 02:46:19	2020-05-03	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	23061	delivery	5	34
57631	2020-05-03 02:49:27	2020-05-03	14	[{"id_menu":2,"count":1}]	22909	delivery	5	19
57632	2020-05-03 02:50:06	2020-05-03	12	[{"id_menu":1,"count":1}]	23014	delivery	5	17
57633	2020-05-03 02:57:57	2020-05-03	17	[{"id_menu":4,"count":1}]	22916	delivery	5	22
57634	2020-05-03 02:58:07	2020-05-03	17	[{"id_menu":4,"count":1}]	1654	pick-up	0	17
57635	2020-05-03 03:04:54	2020-05-03	9	[{"id_menu":6,"count":1}]	19321	delivery	5	14
57636	2020-05-03 03:06:55	2020-05-03	17	[{"id_menu":4,"count":1}]	22705	delivery	5	22
57637	2020-05-03 03:10:34	2020-05-03	8	[{"id_menu":5,"count":1}]	23083	delivery	5	13
57638	2020-05-03 03:10:35	2020-05-03	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22910	delivery	5	47
57639	2020-05-03 03:12:14	2020-05-03	9	[{"id_menu":7,"count":1}]	1317	pick-up	0	9
57640	2020-05-03 03:13:26	2020-05-03	12	[{"id_menu":3,"count":1}]	1489	pick-up	0	12
57641	2020-05-03 03:13:30	2020-05-03	9	[{"id_menu":7,"count":1}]	12020	delivery	5	14
57642	2020-05-03 03:16:19	2020-05-03	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	9230	delivery	5	26
57643	2020-05-03 03:17:30	2020-05-03	8	[{"id_menu":5,"count":1}]	14845	delivery	5	13
57644	2020-05-03 03:18:03	2020-05-03	12	[{"id_menu":3,"count":1}]	1374	pick-up	0	12
57645	2020-05-03 03:20:33	2020-05-03	8	[{"id_menu":5,"count":1}]	22999	delivery	5	13
57646	2020-05-03 03:23:02	2020-05-03	9	[{"id_menu":6,"count":1}]	21532	delivery	5	14
57647	2020-05-03 03:23:23	2020-05-03	8	[{"id_menu":5,"count":1}]	17363	delivery	5	13
57648	2020-05-03 03:24:31	2020-05-03	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23057	delivery	5	23
57649	2020-05-03 03:25:12	2020-05-03	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	12914	delivery	5	23
57650	2020-05-03 03:27:16	2020-05-03	9	[{"id_menu":6,"count":1}]	21345	pick-up	0	9
57651	2020-05-03 03:28:44	2020-05-03	12	[{"id_menu":3,"count":1}]	21276	delivery	5	17
57652	2020-05-03 03:28:54	2020-05-03	12	[{"id_menu":3,"count":1}]	8758	pick-up	0	12
57653	2020-05-03 03:28:55	2020-05-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	22970	delivery	5	31
57654	2020-05-03 03:28:57	2020-05-03	9	[{"id_menu":6,"count":1}]	3098	delivery	5	14
57655	2020-05-03 03:29:21	2020-05-03	9	[{"id_menu":6,"count":1}]	22899	delivery	5	14
57656	2020-05-03 03:32:39	2020-05-03	8	[{"id_menu":5,"count":1}]	22549	delivery	5	13
57657	2020-05-03 03:34:22	2020-05-03	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	22889	delivery	5	40
57658	2020-05-03 03:34:49	2020-05-03	9	[{"id_menu":6,"count":1}]	23009	delivery	5	14
57659	2020-05-03 03:37:19	2020-05-03	8	[{"id_menu":5,"count":1}]	22913	delivery	5	13
57660	2020-05-03 03:40:18	2020-05-03	12	[{"id_menu":1,"count":1}]	22900	pick-up	0	12
57661	2020-05-03 03:40:46	2020-05-03	12	[{"id_menu":3,"count":1}]	15326	pick-up	0	12
57662	2020-05-03 03:42:19	2020-05-03	9	[{"id_menu":6,"count":1}]	20657	delivery	5	14
57663	2020-05-03 03:43:05	2020-05-03	12	[{"id_menu":1,"count":1}]	4116	delivery	5	17
57664	2020-05-03 03:43:17	2020-05-03	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	22950	delivery	5	25
57665	2020-05-03 03:45:11	2020-05-03	12	[{"id_menu":1,"count":1}]	7193	pick-up	0	12
57666	2020-05-03 03:46:02	2020-05-03	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	6148	delivery	5	38
57667	2020-05-03 03:48:12	2020-05-03	14	[{"id_menu":2,"count":1}]	13708	delivery	5	19
57668	2020-05-03 03:49:03	2020-05-03	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23016	delivery	5	31
57669	2020-05-03 03:49:06	2020-05-03	9	[{"id_menu":6,"count":2}]	16411	delivery	5	14
57670	2020-05-03 03:51:07	2020-05-03	12	[{"id_menu":1,"count":1}]	23040	delivery	5	17
57671	2020-05-03 04:02:41	2020-05-03	14	[{"id_menu":2,"count":1}]	22955	delivery	5	19
57672	2020-05-03 04:04:14	2020-05-03	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	19875	delivery	5	43
57673	2020-05-03 04:08:10	2020-05-03	14	[{"id_menu":2,"count":1}]	22924	delivery	5	19
57674	2020-05-03 04:08:52	2020-05-03	9	[{"id_menu":7,"count":1}]	22984	delivery	5	14
57675	2020-05-03 04:10:02	2020-05-03	12	[{"id_menu":1,"count":1}]	22538	pick-up	0	12
57676	2020-05-03 04:11:47	2020-05-03	12	[{"id_menu":3,"count":1}]	18294	pick-up	0	12
57677	2020-05-03 04:12:56	2020-05-03	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23026	delivery	5	36
57678	2020-05-03 04:14:12	2020-05-03	17	[{"id_menu":4,"count":1}]	378	pick-up	0	17
57679	2020-05-03 04:17:17	2020-05-03	17	[{"id_menu":4,"count":1}]	19810	pick-up	0	17
57680	2020-05-03 04:18:38	2020-05-03	9	[{"id_menu":7,"count":1}]	19700	delivery	5	14
57681	2020-05-03 04:19:11	2020-05-03	8	[{"id_menu":5,"count":1}]	23004	delivery	5	13
57682	2020-05-03 04:20:30	2020-05-03	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	22898	delivery	5	23
57683	2020-05-03 04:25:44	2020-05-03	14	[{"id_menu":2,"count":1}]	822	pick-up	0	14
57684	2020-05-03 04:26:35	2020-05-03	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23071	delivery	5	36
57685	2020-05-03 04:32:16	2020-05-03	17	[{"id_menu":4,"count":1}]	22904	delivery	5	22
57686	2020-05-03 04:32:49	2020-05-03	12	[{"id_menu":1,"count":1}]	1597	pick-up	0	12
57687	2020-05-03 04:35:29	2020-05-03	14	[{"id_menu":2,"count":1}]	10008	pick-up	0	14
57688	2020-05-03 04:35:37	2020-05-03	9	[{"id_menu":7,"count":1}]	11095	delivery	5	14
57689	2020-05-03 04:38:12	2020-05-03	17	[{"id_menu":4,"count":1}]	20007	delivery	5	22
57690	2020-05-03 04:42:04	2020-05-03	12	[{"id_menu":3,"count":1}]	5247	delivery	5	17
57691	2020-05-03 04:44:44	2020-05-03	14	[{"id_menu":2,"count":1}]	21195	delivery	5	19
57692	2020-05-03 04:45:00	2020-05-03	9	[{"id_menu":7,"count":1}]	22939	delivery	5	14
57693	2020-05-03 04:46:07	2020-05-03	9	[{"id_menu":6,"count":1}]	23080	delivery	5	14
57694	2020-05-03 04:51:06	2020-05-03	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	13110	pick-up	0	26
57695	2020-05-03 04:52:57	2020-05-03	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	12598	delivery	5	46
57696	2020-05-03 04:57:09	2020-05-03	8	[{"id_menu":5,"count":1}]	4072	pick-up	0	8
57697	2020-05-03 05:03:05	2020-05-03	17	[{"id_menu":4,"count":1}]	1676	pick-up	0	17
57698	2020-05-03 05:05:59	2020-05-03	14	[{"id_menu":2,"count":1}]	3389	pick-up	0	14
57699	2020-05-03 05:06:04	2020-05-03	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20413	delivery	5	53
57700	2020-05-03 05:06:35	2020-05-03	9	[{"id_menu":7,"count":1}]	22977	delivery	5	14
57701	2020-05-03 05:07:10	2020-05-03	12	[{"id_menu":1,"count":1}]	1508	pick-up	0	12
57702	2020-05-03 05:10:56	2020-05-03	9	[{"id_menu":7,"count":1}]	22907	delivery	5	14
57703	2020-05-03 05:12:30	2020-05-03	17	[{"id_menu":4,"count":1}]	10022	delivery	5	22
57704	2020-05-03 05:12:55	2020-05-03	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1155	pick-up	0	18
57705	2020-05-03 05:16:22	2020-05-03	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11878	pick-up	0	29
57706	2020-05-03 05:21:01	2020-05-03	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	15381	pick-up	0	29
57707	2020-05-03 05:22:50	2020-05-03	9	[{"id_menu":6,"count":1}]	12039	delivery	5	14
57708	2020-05-03 05:23:06	2020-05-03	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16921	delivery	5	39
57709	2020-05-03 05:23:56	2020-05-03	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	17470	pick-up	0	21
57710	2020-05-03 05:26:29	2020-05-03	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	769	delivery	5	34
57711	2020-05-03 05:34:50	2020-05-03	14	[{"id_menu":2,"count":1}]	11612	delivery	5	19
57712	2020-05-03 05:40:42	2020-05-03	12	[{"id_menu":1,"count":1}]	8178	delivery	5	17
57713	2020-05-03 05:41:36	2020-05-03	9	[{"id_menu":7,"count":1}]	2962	delivery	5	14
57714	2020-05-03 05:46:14	2020-05-03	12	[{"id_menu":3,"count":1}]	9923	delivery	5	17
57715	2020-05-03 05:48:10	2020-05-03	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	11575	delivery	5	42
57716	2020-05-03 05:48:54	2020-05-03	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1771	delivery	5	26
57717	2020-05-03 05:51:52	2020-05-03	9	[{"id_menu":7,"count":1}]	22906	delivery	5	14
57718	2020-05-03 05:54:14	2020-05-03	17	[{"id_menu":4,"count":1}]	2071	pick-up	0	17
57719	2020-05-03 05:56:24	2020-05-03	9	[{"id_menu":6,"count":1}]	13256	pick-up	0	9
57720	2020-05-03 05:57:29	2020-05-03	17	[{"id_menu":4,"count":1}]	3701	pick-up	0	17
57721	2020-05-03 05:58:24	2020-05-03	17	[{"id_menu":4,"count":1}]	6345	delivery	5	22
57722	2020-05-03 05:59:23	2020-05-03	9	[{"id_menu":6,"count":1}]	23076	delivery	5	14
57723	2020-05-03 06:03:44	2020-05-03	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	11806	delivery	5	40
57724	2020-05-03 06:08:46	2020-05-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	22974	delivery	5	28
57725	2020-05-03 06:16:25	2020-05-03	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	11260	delivery	5	31
57726	2020-05-03 06:17:08	2020-05-03	14	[{"id_menu":2,"count":1}]	11531	pick-up	0	14
57727	2020-05-03 06:17:41	2020-05-03	17	[{"id_menu":4,"count":1}]	16477	delivery	5	22
57728	2020-05-03 06:19:32	2020-05-03	9	[{"id_menu":6,"count":1}]	9093	delivery	5	14
57729	2020-05-03 06:20:19	2020-05-03	14	[{"id_menu":2,"count":1}]	23042	delivery	5	19
57730	2020-05-03 06:26:43	2020-05-03	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	278	pick-up	0	20
57731	2020-05-03 06:27:39	2020-05-03	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	17174	pick-up	0	21
57732	2020-05-03 06:29:09	2020-05-03	9	[{"id_menu":7,"count":1}]	285	delivery	5	14
57733	2020-05-03 06:29:33	2020-05-03	9	[{"id_menu":7,"count":1}]	22964	delivery	5	14
57734	2020-05-03 06:30:23	2020-05-03	9	[{"id_menu":6,"count":1}]	22892	delivery	5	14
57735	2020-05-03 06:34:28	2020-05-03	9	[{"id_menu":7,"count":1}]	660	pick-up	0	9
57736	2020-05-03 06:34:49	2020-05-03	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22948	delivery	5	37
57737	2020-05-03 06:37:18	2020-05-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	19865	delivery	5	31
57738	2020-05-03 06:43:51	2020-05-03	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8091	delivery	5	22
57739	2020-05-03 06:47:59	2020-05-03	9	[{"id_menu":6,"count":1}]	9783	delivery	5	14
57740	2020-05-03 06:52:28	2020-05-03	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	22905	delivery	5	52
57741	2020-05-03 06:52:31	2020-05-03	12	[{"id_menu":1,"count":1}]	5601	delivery	5	17
57742	2020-05-03 06:53:16	2020-05-03	12	[{"id_menu":3,"count":1}]	23074	delivery	5	17
57743	2020-05-03 06:54:11	2020-05-03	8	[{"id_menu":5,"count":1}]	14025	delivery	5	13
57744	2020-05-03 06:56:29	2020-05-03	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22971	delivery	5	40
57745	2020-05-03 06:57:50	2020-05-03	14	[{"id_menu":2,"count":1}]	4285	pick-up	0	14
57746	2020-05-03 07:01:59	2020-05-03	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	23075	delivery	5	26
57747	2020-05-03 07:06:58	2020-05-03	9	[{"id_menu":7,"count":1}]	11204	delivery	5	14
57748	2020-05-03 07:08:38	2020-05-03	17	[{"id_menu":4,"count":1}]	1914	delivery	5	22
57749	2020-05-03 07:10:12	2020-05-03	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	17799	delivery	5	31
57750	2020-05-03 07:10:29	2020-05-03	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	23018	delivery	5	22
57751	2020-05-03 07:10:52	2020-05-03	14	[{"id_menu":2,"count":1}]	19770	delivery	5	19
57752	2020-05-03 07:12:30	2020-05-03	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	752	delivery	5	22
57753	2020-05-03 07:12:45	2020-05-03	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2874	pick-up	0	38
57754	2020-05-03 07:16:15	2020-05-03	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14638	delivery	5	40
57755	2020-05-03 07:19:02	2020-05-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5899	delivery	5	31
57756	2020-05-03 07:19:22	2020-05-03	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1649	pick-up	0	38
57757	2020-05-03 07:21:14	2020-05-03	9	[{"id_menu":7,"count":1}]	12527	pick-up	0	9
57758	2020-05-03 07:25:20	2020-05-03	12	[{"id_menu":1,"count":1}]	8080	delivery	5	17
57759	2020-05-03 07:26:23	2020-05-03	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	22966	delivery	5	35
57760	2020-05-03 07:26:23	2020-05-03	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	491	pick-up	0	22
57761	2020-05-03 07:26:24	2020-05-03	17	[{"id_menu":4,"count":1}]	18417	delivery	5	22
57762	2020-05-03 07:28:45	2020-05-03	9	[{"id_menu":6,"count":2}]	22960	pick-up	0	9
57763	2020-05-03 07:36:12	2020-05-03	9	[{"id_menu":7,"count":1}]	21628	delivery	5	14
57764	2020-05-03 07:37:02	2020-05-03	12	[{"id_menu":1,"count":1}]	5573	delivery	5	17
57765	2020-05-03 07:40:30	2020-05-03	8	[{"id_menu":5,"count":1}]	10007	delivery	5	13
57766	2020-05-03 07:47:51	2020-05-03	17	[{"id_menu":4,"count":1}]	22896	pick-up	0	17
57767	2020-05-03 07:49:24	2020-05-03	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	14411	delivery	5	36
57768	2020-05-03 07:50:42	2020-05-03	12	[{"id_menu":3,"count":1}]	274	delivery	5	17
57769	2020-05-03 07:53:10	2020-05-03	17	[{"id_menu":4,"count":1}]	11600	delivery	5	22
57770	2020-05-03 07:55:23	2020-05-03	8	[{"id_menu":5,"count":1}]	6664	delivery	5	13
57771	2020-05-03 07:56:35	2020-05-03	8	[{"id_menu":5,"count":1}]	16322	delivery	5	13
57772	2020-05-03 07:57:01	2020-05-03	9	[{"id_menu":6,"count":1}]	23081	delivery	5	14
57773	2020-05-03 08:02:25	2020-05-03	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	19500	delivery	5	31
57774	2020-05-03 08:10:54	2020-05-03	9	[{"id_menu":7,"count":1}]	409	delivery	5	14
57775	2020-05-03 08:12:39	2020-05-03	17	[{"id_menu":4,"count":1}]	2602	delivery	5	22
57776	2020-05-03 08:13:39	2020-05-03	9	[{"id_menu":7,"count":1}]	18593	delivery	5	14
57777	2020-05-03 08:13:53	2020-05-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	22884	delivery	5	28
57778	2020-05-03 08:14:55	2020-05-03	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7205	pick-up	0	25
57779	2020-05-03 08:16:22	2020-05-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	18818	delivery	5	31
57780	2020-05-03 08:19:40	2020-05-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	4436	pick-up	0	26
57781	2020-05-03 08:20:27	2020-05-03	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	22995	delivery	5	29
57782	2020-05-03 08:21:02	2020-05-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	18976	delivery	5	28
57783	2020-05-03 08:28:50	2020-05-03	17	[{"id_menu":4,"count":1}]	23054	delivery	5	22
57784	2020-05-03 08:30:53	2020-05-03	9	[{"id_menu":7,"count":1}]	23062	delivery	5	14
57785	2020-05-03 08:32:55	2020-05-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	8537	delivery	5	28
57786	2020-05-03 08:34:06	2020-05-03	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	371	delivery	5	28
57787	2020-05-03 08:34:25	2020-05-03	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	5461	delivery	5	31
57788	2020-05-03 08:38:44	2020-05-03	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	22946	delivery	5	26
57789	2020-05-03 08:41:26	2020-05-03	9	[{"id_menu":6,"count":1}]	22903	delivery	5	14
57790	2020-05-03 08:47:46	2020-05-03	12	[{"id_menu":1,"count":1}]	2420	pick-up	0	12
57791	2020-05-03 08:49:31	2020-05-03	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	22888	delivery	5	23
57792	2020-05-03 08:55:30	2020-05-03	12	[{"id_menu":1,"count":1}]	1507	pick-up	0	12
57793	2020-05-03 08:57:43	2020-05-03	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10776	delivery	5	22
57794	2020-05-03 08:59:03	2020-05-03	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	23013	delivery	5	34
57795	2020-05-03 08:59:45	2020-05-03	17	[{"id_menu":4,"count":1}]	5122	delivery	5	22
57796	2020-05-03 09:01:09	2020-05-03	9	[{"id_menu":6,"count":1}]	6787	delivery	5	14
57797	2020-05-03 09:02:38	2020-05-03	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	19905	delivery	5	27
57798	2020-05-03 09:02:53	2020-05-03	17	[{"id_menu":4,"count":1}]	22912	pick-up	0	17
57799	2020-05-03 09:03:08	2020-05-03	12	[{"id_menu":3,"count":1}]	7411	delivery	5	17
57800	2020-05-03 09:05:13	2020-05-03	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	11754	delivery	5	36
57801	2020-05-03 09:06:50	2020-05-03	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21178	delivery	5	35
57802	2020-05-03 09:08:04	2020-05-03	14	[{"id_menu":2,"count":2}]	3158	pick-up	0	14
57803	2020-05-03 09:08:57	2020-05-03	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	18958	pick-up	0	29
57804	2020-05-03 09:13:03	2020-05-03	14	[{"id_menu":2,"count":1}]	23072	delivery	5	19
57805	2020-05-03 09:13:32	2020-05-03	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	23066	delivery	5	40
57806	2020-05-03 09:15:41	2020-05-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	21352	pick-up	0	26
57807	2020-05-03 09:16:18	2020-05-03	9	[{"id_menu":6,"count":1}]	19205	delivery	5	14
57808	2020-05-03 09:17:52	2020-05-03	9	[{"id_menu":7,"count":1}]	21634	delivery	5	14
57809	2020-05-03 09:19:29	2020-05-03	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18102	delivery	5	43
57810	2020-05-03 09:19:42	2020-05-03	17	[{"id_menu":4,"count":1}]	8521	delivery	5	22
57811	2020-05-03 09:24:23	2020-05-03	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	22969	pick-up	0	26
57812	2020-05-03 09:25:28	2020-05-03	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3293	delivery	5	40
57813	2020-05-03 09:26:57	2020-05-03	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	12548	delivery	5	22
57814	2020-05-03 09:27:48	2020-05-03	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23043	delivery	5	52
57815	2020-05-03 09:30:14	2020-05-03	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17533	delivery	5	36
57816	2020-05-03 09:31:42	2020-05-03	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18567	delivery	5	36
57817	2020-05-03 09:31:45	2020-05-03	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	22363	delivery	5	26
57818	2020-05-03 09:32:37	2020-05-03	12	[{"id_menu":1,"count":1}]	21420	delivery	5	17
57819	2020-05-03 09:32:54	2020-05-03	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	23046	pick-up	0	34
57820	2020-05-03 09:34:54	2020-05-03	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	22979	pick-up	0	48
57821	2020-05-03 09:39:11	2020-05-03	9	[{"id_menu":6,"count":1}]	22998	delivery	5	14
57822	2020-05-03 09:39:34	2020-05-03	14	[{"id_menu":2,"count":1}]	22975	delivery	5	19
57823	2020-05-03 09:43:50	2020-05-03	12	[{"id_menu":1,"count":1}]	19873	delivery	5	17
57824	2020-05-03 09:47:01	2020-05-03	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	22989	delivery	5	25
57825	2020-05-03 09:48:38	2020-05-03	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	18810	delivery	5	38
57826	2020-05-03 09:52:15	2020-05-03	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	13823	delivery	5	38
57827	2020-05-03 09:53:04	2020-05-03	9	[{"id_menu":6,"count":1}]	16372	delivery	5	14
57828	2020-05-03 10:00:17	2020-05-03	9	[{"id_menu":6,"count":1}]	10882	pick-up	0	9
57829	2020-05-03 10:01:16	2020-05-03	8	[{"id_menu":5,"count":1}]	23050	delivery	5	13
57830	2020-05-03 10:02:20	2020-05-03	17	[{"id_menu":4,"count":1}]	22962	delivery	5	22
57831	2020-05-03 10:03:26	2020-05-03	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8230	delivery	5	39
57832	2020-05-03 10:08:09	2020-05-03	12	[{"id_menu":3,"count":1}]	1623	pick-up	0	12
57833	2020-05-03 10:10:19	2020-05-03	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22956	delivery	5	22
57834	2020-05-03 10:10:41	2020-05-03	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	23044	delivery	5	26
57835	2020-05-03 10:16:34	2020-05-03	12	[{"id_menu":3,"count":1}]	23068	delivery	5	17
57836	2020-05-03 10:17:19	2020-05-03	9	[{"id_menu":6,"count":1}]	19337	delivery	5	14
57837	2020-05-03 10:17:20	2020-05-03	8	[{"id_menu":5,"count":1}]	17516	delivery	5	13
57838	2020-05-03 10:31:24	2020-05-03	14	[{"id_menu":2,"count":1}]	22775	delivery	5	19
57839	2020-05-03 10:31:32	2020-05-03	17	[{"id_menu":4,"count":1}]	20647	delivery	5	22
57840	2020-05-03 10:33:20	2020-05-03	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15876	delivery	5	22
57841	2020-05-03 10:35:32	2020-05-03	12	[{"id_menu":3,"count":1}]	19488	delivery	5	17
57842	2020-05-03 10:36:42	2020-05-03	12	[{"id_menu":1,"count":1}]	4147	pick-up	0	12
57843	2020-05-03 10:41:22	2020-05-03	14	[{"id_menu":2,"count":1}]	22890	delivery	5	19
57844	2020-05-03 10:41:28	2020-05-03	14	[{"id_menu":2,"count":1}]	23032	delivery	5	19
57845	2020-05-03 10:42:04	2020-05-03	9	[{"id_menu":6,"count":1}]	1490	pick-up	0	9
57846	2020-05-03 10:46:49	2020-05-03	9	[{"id_menu":7,"count":1}]	16085	delivery	5	14
57847	2020-05-03 10:51:25	2020-05-03	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	9014	delivery	5	26
57848	2020-05-03 10:57:29	2020-05-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	23025	delivery	5	31
57849	2020-05-03 10:58:51	2020-05-03	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5174	delivery	5	31
57850	2020-05-03 11:05:35	2020-05-03	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	22893	delivery	5	30
57851	2020-05-03 11:08:32	2020-05-03	14	[{"id_menu":2,"count":1}]	14395	delivery	5	19
57852	2020-05-03 11:08:54	2020-05-03	9	[{"id_menu":6,"count":1}]	4084	delivery	5	14
57853	2020-05-03 11:10:53	2020-05-03	12	[{"id_menu":1,"count":1}]	22944	delivery	5	17
57854	2020-05-03 11:13:09	2020-05-03	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	22456	delivery	5	31
57855	2020-05-03 11:19:23	2020-05-03	9	[{"id_menu":7,"count":1}]	6151	delivery	5	14
57856	2020-05-03 11:21:37	2020-05-03	17	[{"id_menu":4,"count":1}]	12505	delivery	5	22
57857	2020-05-03 11:21:45	2020-05-03	8	[{"id_menu":5,"count":1}]	3589	delivery	5	13
57858	2020-05-03 11:22:18	2020-05-03	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	8233	delivery	5	26
57859	2020-05-03 11:32:05	2020-05-03	9	[{"id_menu":6,"count":1}]	4750	pick-up	0	9
57860	2020-05-03 11:32:14	2020-05-03	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	23003	delivery	5	25
57861	2020-05-03 11:33:34	2020-05-03	9	[{"id_menu":6,"count":1}]	3224	pick-up	0	9
57862	2020-05-03 11:35:13	2020-05-03	9	[{"id_menu":6,"count":1}]	10820	delivery	5	14
57863	2020-05-03 11:37:46	2020-05-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	23084	delivery	5	31
57864	2020-05-03 11:38:28	2020-05-03	17	[{"id_menu":4,"count":1}]	2552	pick-up	0	17
57865	2020-05-03 11:39:31	2020-05-03	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	7528	delivery	5	29
57866	2020-05-03 11:45:12	2020-05-03	8	[{"id_menu":5,"count":1}]	8598	pick-up	0	8
57867	2020-05-03 11:45:23	2020-05-03	9	[{"id_menu":7,"count":1}]	14920	delivery	5	14
57868	2020-05-03 11:45:42	2020-05-03	9	[{"id_menu":6,"count":1}]	22881	delivery	5	14
57869	2020-05-03 11:46:30	2020-05-03	17	[{"id_menu":4,"count":1}]	13313	delivery	5	22
57870	2020-05-03 11:46:59	2020-05-03	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	13176	delivery	5	27
57871	2020-05-03 11:47:08	2020-05-03	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	14027	pick-up	0	21
57872	2020-05-03 11:51:30	2020-05-03	9	[{"id_menu":6,"count":1}]	10153	pick-up	0	9
57873	2020-05-03 11:51:41	2020-05-03	9	[{"id_menu":7,"count":1}]	22938	pick-up	0	9
57874	2020-05-03 11:52:23	2020-05-03	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23027	delivery	5	22
57875	2020-05-03 11:56:06	2020-05-03	12	[{"id_menu":3,"count":1}]	22994	delivery	5	17
57876	2020-05-03 11:58:02	2020-05-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5508	pick-up	0	23
57877	2020-05-03 12:02:47	2020-05-03	8	[{"id_menu":5,"count":1}]	8212	delivery	5	13
57878	2020-05-03 12:04:19	2020-05-03	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	22943	delivery	5	36
57879	2020-05-03 12:04:52	2020-05-03	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	11528	delivery	5	26
57880	2020-05-03 12:08:45	2020-05-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	19955	delivery	5	28
57881	2020-05-03 12:09:10	2020-05-03	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23000	delivery	5	37
57882	2020-05-03 12:11:30	2020-05-03	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	22895	delivery	5	51
57883	2020-05-03 12:16:20	2020-05-03	9	[{"id_menu":6,"count":1}]	2187	delivery	5	14
57884	2020-05-03 12:17:41	2020-05-03	14	[{"id_menu":2,"count":1}]	17502	pick-up	0	14
57885	2020-05-03 12:18:37	2020-05-03	12	[{"id_menu":1,"count":1}]	153	delivery	5	17
57886	2020-05-03 12:19:28	2020-05-03	14	[{"id_menu":2,"count":1}]	14748	delivery	5	19
57887	2020-05-03 12:23:19	2020-05-03	12	[{"id_menu":1,"count":1}]	7741	pick-up	0	12
57888	2020-05-03 12:24:33	2020-05-03	14	[{"id_menu":2,"count":1}]	22891	delivery	5	19
57889	2020-05-03 12:24:57	2020-05-03	12	[{"id_menu":1,"count":1}]	22985	pick-up	0	12
57890	2020-05-03 12:25:25	2020-05-03	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	6243	pick-up	0	21
57891	2020-05-03 12:30:50	2020-05-03	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22338	pick-up	0	30
57892	2020-05-03 12:32:05	2020-05-03	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16247	delivery	5	31
57893	2020-05-03 12:34:53	2020-05-03	14	[{"id_menu":2,"count":2}]	6977	pick-up	0	14
57894	2020-05-03 12:35:56	2020-05-03	8	[{"id_menu":5,"count":1}]	15350	delivery	5	13
57895	2020-05-03 12:37:29	2020-05-03	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9597	delivery	5	22
57896	2020-05-03 12:41:18	2020-05-03	14	[{"id_menu":2,"count":1}]	4959	pick-up	0	14
57897	2020-05-03 12:43:15	2020-05-03	9	[{"id_menu":6,"count":1}]	13097	delivery	5	14
57898	2020-05-03 12:50:36	2020-05-03	12	[{"id_menu":3,"count":1}]	23011	delivery	5	17
57899	2020-05-03 12:55:19	2020-05-03	9	[{"id_menu":7,"count":1}]	22942	delivery	5	14
57900	2020-05-03 12:55:30	2020-05-03	9	[{"id_menu":6,"count":1}]	14666	pick-up	0	9
57901	2020-05-03 12:57:49	2020-05-03	14	[{"id_menu":2,"count":2}]	23030	delivery	5	19
57902	2020-05-03 12:58:02	2020-05-03	9	[{"id_menu":7,"count":1}]	23063	pick-up	0	9
57903	2020-05-03 13:01:26	2020-05-03	9	[{"id_menu":7,"count":1}]	445	delivery	5	14
57904	2020-05-03 13:02:19	2020-05-03	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	14894	delivery	5	22
57905	2020-05-03 13:03:21	2020-05-03	8	[{"id_menu":5,"count":1}]	22908	delivery	5	13
57906	2020-05-03 13:06:15	2020-05-03	9	[{"id_menu":6,"count":1}]	4192	delivery	5	14
57907	2020-05-03 13:09:51	2020-05-03	12	[{"id_menu":1,"count":1}]	2351	pick-up	0	12
57908	2020-05-03 13:13:31	2020-05-03	9	[{"id_menu":7,"count":1}]	4326	pick-up	0	9
57909	2020-05-03 13:16:14	2020-05-03	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8629	delivery	5	23
57910	2020-05-03 13:16:21	2020-05-03	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12604	delivery	5	34
57911	2020-05-03 13:20:15	2020-05-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8057	delivery	5	31
57912	2020-05-03 13:20:17	2020-05-03	12	[{"id_menu":3,"count":1}]	13565	delivery	5	17
57913	2020-05-03 13:22:16	2020-05-03	9	[{"id_menu":7,"count":1}]	10194	delivery	5	14
57914	2020-05-03 13:28:24	2020-05-03	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	22740	delivery	5	22
57915	2020-05-03 13:30:02	2020-05-03	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11849	delivery	5	31
57916	2020-05-03 13:34:07	2020-05-03	12	[{"id_menu":1,"count":1}]	9377	delivery	5	17
57917	2020-05-03 13:35:11	2020-05-03	8	[{"id_menu":5,"count":1}]	20327	pick-up	0	8
57918	2020-05-03 13:36:29	2020-05-03	17	[{"id_menu":4,"count":1}]	7782	pick-up	0	17
57919	2020-05-03 13:36:42	2020-05-03	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23002	delivery	5	22
57920	2020-05-03 13:37:03	2020-05-03	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	17558	delivery	5	43
57921	2020-05-03 13:40:46	2020-05-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":3}]	23028	delivery	5	31
57922	2020-05-03 13:43:41	2020-05-03	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	22952	pick-up	0	39
57923	2020-05-03 13:46:09	2020-05-03	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	22993	delivery	5	45
57924	2020-05-03 13:51:27	2020-05-03	17	[{"id_menu":4,"count":1}]	3754	delivery	5	22
57925	2020-05-03 13:54:06	2020-05-03	8	[{"id_menu":5,"count":1}]	22883	delivery	5	13
57926	2020-05-03 13:56:12	2020-05-03	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	23005	delivery	5	57
57927	2020-05-03 13:59:14	2020-05-03	8	[{"id_menu":5,"count":1}]	3298	delivery	5	13
57928	2020-05-03 13:59:18	2020-05-03	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	34	pick-up	0	21
57929	2020-05-03 14:03:04	2020-05-03	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17800	delivery	5	35
57930	2020-05-03 14:03:46	2020-05-03	12	[{"id_menu":1,"count":2}]	2827	pick-up	0	12
57931	2020-05-03 14:04:57	2020-05-03	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	20803	delivery	5	39
57932	2020-05-03 14:05:52	2020-05-03	9	[{"id_menu":7,"count":1}]	10929	delivery	5	14
57933	2020-05-03 14:07:23	2020-05-03	9	[{"id_menu":7,"count":1}]	5808	pick-up	0	9
57934	2020-05-03 14:11:22	2020-05-03	9	[{"id_menu":6,"count":1}]	7375	delivery	5	14
57935	2020-05-03 14:14:04	2020-05-03	9	[{"id_menu":7,"count":1}]	397	delivery	5	14
57936	2020-05-03 14:15:12	2020-05-03	17	[{"id_menu":4,"count":1}]	8028	pick-up	0	17
57937	2020-05-03 14:17:06	2020-05-03	17	[{"id_menu":4,"count":1}]	226	pick-up	0	17
57938	2020-05-03 14:20:34	2020-05-03	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	23020	delivery	5	55
57939	2020-05-03 14:21:48	2020-05-03	9	[{"id_menu":7,"count":1}]	23023	delivery	5	14
57940	2020-05-03 14:24:01	2020-05-03	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11744	delivery	5	35
57941	2020-05-03 14:24:09	2020-05-03	14	[{"id_menu":2,"count":2}]	21412	delivery	5	19
57942	2020-05-03 14:29:46	2020-05-03	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	22919	delivery	5	27
57943	2020-05-03 14:31:03	2020-05-03	14	[{"id_menu":2,"count":2}]	8329	delivery	5	19
57944	2020-05-03 14:32:36	2020-05-03	14	[{"id_menu":2,"count":1}]	22887	delivery	5	19
57945	2020-05-03 14:33:41	2020-05-03	17	[{"id_menu":4,"count":1}]	12936	delivery	5	22
57946	2020-05-03 14:34:52	2020-05-03	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	19893	pick-up	0	31
57947	2020-05-03 14:36:37	2020-05-03	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12097	delivery	5	23
57948	2020-05-03 14:40:24	2020-05-03	17	[{"id_menu":4,"count":1}]	20216	pick-up	0	17
57949	2020-05-03 14:40:45	2020-05-03	17	[{"id_menu":4,"count":1}]	3862	pick-up	0	17
57950	2020-05-03 14:41:42	2020-05-03	8	[{"id_menu":5,"count":1}]	22963	delivery	5	13
57951	2020-05-03 14:42:22	2020-05-03	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23021	delivery	5	22
57952	2020-05-03 14:43:43	2020-05-03	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	18666	delivery	5	26
57953	2020-05-03 14:45:27	2020-05-03	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	22980	delivery	5	34
57954	2020-05-03 14:45:57	2020-05-03	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2470	delivery	5	22
57955	2020-05-03 14:48:15	2020-05-03	17	[{"id_menu":4,"count":1}]	76	delivery	5	22
57956	2020-05-03 14:53:16	2020-05-03	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2995	delivery	5	31
57957	2020-05-03 14:54:01	2020-05-03	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	23052	delivery	5	28
57958	2020-05-03 15:19:15	2020-05-03	9	[{"id_menu":7,"count":1}]	16872	delivery	5	14
57959	2020-05-03 15:23:09	2020-05-03	12	[{"id_menu":1,"count":1}]	14424	delivery	5	17
57960	2020-05-03 15:26:35	2020-05-03	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23078	delivery	5	48
57961	2020-05-03 15:28:06	2020-05-03	14	[{"id_menu":2,"count":1}]	4179	pick-up	0	14
57962	2020-05-03 15:29:47	2020-05-03	12	[{"id_menu":1,"count":1}]	7073	delivery	5	17
57963	2020-05-03 15:32:58	2020-05-03	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	1736	delivery	5	23
57964	2020-05-03 15:33:23	2020-05-03	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20374	delivery	5	36
57965	2020-05-03 15:36:15	2020-05-03	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	23064	delivery	5	26
57966	2020-05-03 15:38:35	2020-05-03	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	14754	delivery	5	44
57967	2020-05-03 15:40:36	2020-05-03	14	[{"id_menu":2,"count":1}]	13537	pick-up	0	14
57968	2020-05-03 15:41:51	2020-05-03	8	[{"id_menu":5,"count":1}]	14877	pick-up	0	8
57969	2020-05-03 15:42:06	2020-05-03	9	[{"id_menu":7,"count":1}]	17743	delivery	5	14
57970	2020-05-03 15:42:20	2020-05-03	14	[{"id_menu":2,"count":2}]	22940	delivery	5	19
57971	2020-05-03 15:43:53	2020-05-03	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	22983	delivery	5	28
57972	2020-05-03 15:43:59	2020-05-03	9	[{"id_menu":7,"count":1}]	9683	delivery	5	14
57973	2020-05-03 15:45:18	2020-05-03	9	[{"id_menu":6,"count":1}]	22885	delivery	5	14
57974	2020-05-03 15:47:04	2020-05-03	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	22934	delivery	5	40
57975	2020-05-03 15:49:38	2020-05-03	9	[{"id_menu":6,"count":1}]	3048	pick-up	0	9
57976	2020-05-03 15:52:35	2020-05-03	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2922	pick-up	0	23
57977	2020-05-03 15:54:40	2020-05-03	12	[{"id_menu":1,"count":1}]	12949	delivery	5	17
57978	2020-05-03 15:54:43	2020-05-03	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	17790	pick-up	0	26
57979	2020-05-03 15:57:20	2020-05-03	8	[{"id_menu":5,"count":1}]	21426	delivery	5	13
57980	2020-05-03 15:58:24	2020-05-03	14	[{"id_menu":2,"count":1}]	10254	delivery	5	19
57981	2020-05-03 15:59:57	2020-05-03	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	16186	delivery	5	28
57982	2020-05-03 16:03:10	2020-05-03	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6150	delivery	5	44
57983	2020-05-03 16:05:03	2020-05-03	9	[{"id_menu":6,"count":1}]	22150	delivery	5	14
57984	2020-05-03 16:05:16	2020-05-03	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	21273	pick-up	0	38
57985	2020-05-03 16:15:00	2020-05-03	9	[{"id_menu":7,"count":1}]	22949	delivery	5	14
57986	2020-05-03 16:15:53	2020-05-03	12	[{"id_menu":1,"count":1}]	8995	pick-up	0	12
57987	2020-05-03 16:16:42	2020-05-03	9	[{"id_menu":7,"count":1}]	1988	delivery	5	14
57988	2020-05-03 16:18:29	2020-05-03	12	[{"id_menu":3,"count":1}]	22922	delivery	5	17
57989	2020-05-03 16:18:42	2020-05-03	8	[{"id_menu":5,"count":1}]	22954	delivery	5	13
57990	2020-05-03 16:19:10	2020-05-03	17	[{"id_menu":4,"count":1}]	23065	delivery	5	22
57991	2020-05-03 16:19:12	2020-05-03	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	22901	delivery	5	37
57992	2020-05-03 16:21:00	2020-05-03	9	[{"id_menu":6,"count":1}]	23051	delivery	5	14
57993	2020-05-03 16:22:30	2020-05-03	12	[{"id_menu":1,"count":1}]	23059	delivery	5	17
57994	2020-05-03 16:23:13	2020-05-03	17	[{"id_menu":4,"count":1}]	23029	delivery	5	22
57995	2020-05-03 16:26:02	2020-05-03	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2908	delivery	5	23
57996	2020-05-03 16:27:08	2020-05-03	9	[{"id_menu":7,"count":1}]	133	delivery	5	14
57997	2020-05-03 16:27:30	2020-05-03	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6947	delivery	5	28
57998	2020-05-03 16:31:23	2020-05-03	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22918	delivery	5	34
57999	2020-05-03 16:33:12	2020-05-03	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21502	delivery	5	23
58000	2020-05-03 16:34:14	2020-05-03	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2889	pick-up	0	31
58001	2020-05-03 16:34:44	2020-05-03	14	[{"id_menu":2,"count":2}]	991	pick-up	0	14
58002	2020-05-03 16:35:40	2020-05-03	9	[{"id_menu":6,"count":1}]	11541	delivery	5	14
58003	2020-05-03 16:35:59	2020-05-03	9	[{"id_menu":7,"count":2}]	18148	delivery	5	14
58004	2020-05-03 16:39:52	2020-05-03	9	[{"id_menu":7,"count":1}]	3099	delivery	5	14
58005	2020-05-03 16:43:12	2020-05-03	8	[{"id_menu":5,"count":1}]	11146	pick-up	0	8
58006	2020-05-03 16:44:15	2020-05-03	9	[{"id_menu":7,"count":1}]	8595	delivery	5	14
58007	2020-05-03 16:47:29	2020-05-03	8	[{"id_menu":5,"count":1}]	19313	pick-up	0	8
58008	2020-05-03 16:48:23	2020-05-03	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	841	pick-up	0	31
58009	2020-05-03 16:50:18	2020-05-03	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	22987	pick-up	0	31
58010	2020-05-03 16:50:18	2020-05-03	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15903	delivery	5	22
58011	2020-05-03 16:51:19	2020-05-03	17	[{"id_menu":4,"count":1}]	5783	delivery	5	22
58012	2020-05-03 16:51:43	2020-05-03	9	[{"id_menu":7,"count":1}]	22959	delivery	5	14
58013	2020-05-03 16:54:12	2020-05-03	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	23039	delivery	5	26
58014	2020-05-03 16:54:55	2020-05-03	17	[{"id_menu":4,"count":1}]	20668	pick-up	0	17
58015	2020-05-03 16:59:16	2020-05-03	17	[{"id_menu":4,"count":1}]	743	pick-up	0	17
58016	2020-05-03 17:00:00	2020-05-03	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	12012	pick-up	0	29
58017	2020-05-03 17:02:04	2020-05-03	9	[{"id_menu":6,"count":2}]	16068	delivery	5	14
58018	2020-05-03 17:03:05	2020-05-03	14	[{"id_menu":2,"count":1}]	3033	pick-up	0	14
58019	2020-05-03 17:03:52	2020-05-03	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	22933	pick-up	0	29
58020	2020-05-03 17:03:56	2020-05-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	22958	delivery	5	28
58021	2020-05-03 17:05:04	2020-05-03	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15741	delivery	5	51
58022	2020-05-03 17:09:41	2020-05-03	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	22914	delivery	5	45
58023	2020-05-03 17:11:18	2020-05-03	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	22945	pick-up	0	26
58024	2020-05-03 17:12:31	2020-05-03	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	22953	delivery	5	26
58025	2020-05-03 17:14:58	2020-05-03	9	[{"id_menu":7,"count":1}]	23073	delivery	5	14
58026	2020-05-03 17:17:03	2020-05-03	8	[{"id_menu":5,"count":1}]	18309	pick-up	0	8
58027	2020-05-03 17:17:41	2020-05-03	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	8145	pick-up	0	29
58028	2020-05-03 17:17:42	2020-05-03	17	[{"id_menu":4,"count":1}]	15294	delivery	5	22
58029	2020-05-03 17:20:11	2020-05-03	8	[{"id_menu":5,"count":1}]	21849	delivery	5	13
58030	2020-05-03 17:21:06	2020-05-03	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	22991	delivery	5	22
58031	2020-05-03 17:25:13	2020-05-03	9	[{"id_menu":6,"count":1}]	1545	pick-up	0	9
58032	2020-05-03 17:27:05	2020-05-03	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	19162	delivery	5	31
58033	2020-05-03 17:36:29	2020-05-03	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	13528	pick-up	0	25
58034	2020-05-03 17:38:31	2020-05-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	20595	pick-up	0	23
58035	2020-05-03 17:39:19	2020-05-03	17	[{"id_menu":4,"count":1}]	138	delivery	5	22
58036	2020-05-03 17:40:07	2020-05-03	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20843	delivery	5	22
58037	2020-05-03 17:41:07	2020-05-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	20338	delivery	5	31
58038	2020-05-03 17:42:41	2020-05-03	8	[{"id_menu":5,"count":1}]	19092	pick-up	0	8
58039	2020-05-03 17:45:38	2020-05-03	9	[{"id_menu":6,"count":1}]	22927	delivery	5	14
58040	2020-05-03 17:48:04	2020-05-03	8	[{"id_menu":5,"count":1}]	16181	delivery	5	13
58041	2020-05-03 17:51:09	2020-05-03	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	12686	delivery	5	26
58042	2020-05-03 17:51:31	2020-05-03	9	[{"id_menu":7,"count":1}]	19104	delivery	5	14
58043	2020-05-03 17:53:27	2020-05-03	9	[{"id_menu":7,"count":1}]	16636	delivery	5	14
58044	2020-05-03 17:55:04	2020-05-03	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23019	delivery	5	48
58045	2020-05-03 17:56:18	2020-05-03	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23058	delivery	5	39
58046	2020-05-03 17:58:54	2020-05-03	9	[{"id_menu":7,"count":1}]	5315	delivery	5	14
58047	2020-05-03 17:59:54	2020-05-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	22976	pick-up	0	26
58048	2020-05-03 18:01:12	2020-05-03	12	[{"id_menu":3,"count":1}]	8123	delivery	5	17
58049	2020-05-03 18:01:19	2020-05-03	9	[{"id_menu":6,"count":1}]	14867	delivery	5	14
58050	2020-05-03 18:02:39	2020-05-03	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3385	delivery	5	28
58051	2020-05-03 18:04:19	2020-05-03	9	[{"id_menu":6,"count":1}]	14233	delivery	5	14
58052	2020-05-03 18:04:31	2020-05-03	12	[{"id_menu":1,"count":1}]	6948	delivery	5	17
58053	2020-05-03 18:05:34	2020-05-03	9	[{"id_menu":7,"count":2}]	3281	delivery	5	14
58054	2020-05-03 18:07:57	2020-05-03	8	[{"id_menu":5,"count":1}]	22581	delivery	5	13
58055	2020-05-03 18:13:51	2020-05-03	12	[{"id_menu":3,"count":1}]	5473	pick-up	0	12
58056	2020-05-03 18:14:17	2020-05-03	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	5747	delivery	5	30
58057	2020-05-03 18:15:20	2020-05-03	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	22311	delivery	5	43
58058	2020-05-03 18:17:22	2020-05-03	14	[{"id_menu":2,"count":1}]	7571	pick-up	0	14
58059	2020-05-03 18:22:15	2020-05-03	9	[{"id_menu":7,"count":1}]	4411	pick-up	0	9
58060	2020-05-03 18:25:13	2020-05-03	12	[{"id_menu":3,"count":1}]	22968	delivery	5	17
58061	2020-05-03 18:27:49	2020-05-03	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	15600	delivery	5	28
58062	2020-05-03 18:29:52	2020-05-03	9	[{"id_menu":7,"count":1}]	23006	delivery	5	14
58063	2020-05-03 18:38:36	2020-05-03	17	[{"id_menu":4,"count":1}]	12532	pick-up	0	17
58064	2020-05-03 18:39:12	2020-05-03	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1754	delivery	5	55
58065	2020-05-03 18:39:26	2020-05-03	17	[{"id_menu":4,"count":1}]	17664	delivery	5	22
58066	2020-05-03 18:39:41	2020-05-03	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	21262	delivery	5	26
58067	2020-05-03 18:42:55	2020-05-03	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	12489	delivery	5	26
58068	2020-05-03 18:45:22	2020-05-03	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	14151	delivery	5	40
58069	2020-05-03 18:54:25	2020-05-03	9	[{"id_menu":7,"count":1}]	23048	delivery	5	14
58070	2020-05-03 18:55:29	2020-05-03	9	[{"id_menu":7,"count":1}]	11609	delivery	5	14
58071	2020-05-03 18:55:38	2020-05-03	12	[{"id_menu":1,"count":1}]	22982	pick-up	0	12
58072	2020-05-03 18:56:55	2020-05-03	8	[{"id_menu":5,"count":1}]	22936	delivery	5	13
58073	2020-05-03 19:03:52	2020-05-03	8	[{"id_menu":5,"count":3}]	18476	delivery	5	13
58074	2020-05-03 19:05:09	2020-05-03	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	9055	pick-up	0	35
58075	2020-05-03 19:06:26	2020-05-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8210	delivery	5	31
58076	2020-05-03 19:06:38	2020-05-03	14	[{"id_menu":2,"count":1}]	16337	delivery	5	19
58077	2020-05-03 19:13:17	2020-05-03	9	[{"id_menu":7,"count":1}]	16252	delivery	5	14
58078	2020-05-03 19:13:29	2020-05-03	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	12650	delivery	5	22
58079	2020-05-03 19:15:57	2020-05-03	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	456	pick-up	0	29
58080	2020-05-03 19:18:12	2020-05-03	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	22902	delivery	5	34
58081	2020-05-03 19:18:33	2020-05-03	9	[{"id_menu":7,"count":1}]	5318	pick-up	0	9
58082	2020-05-03 19:18:36	2020-05-03	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	22920	delivery	5	44
58083	2020-05-03 19:18:40	2020-05-03	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	23082	delivery	5	22
58084	2020-05-03 19:23:06	2020-05-03	9	[{"id_menu":6,"count":1}]	22894	delivery	5	14
58085	2020-05-03 19:26:22	2020-05-03	12	[{"id_menu":1,"count":1}]	4344	delivery	5	17
58086	2020-05-03 19:29:33	2020-05-03	14	[{"id_menu":2,"count":1}]	18776	delivery	5	19
58087	2020-05-03 19:31:00	2020-05-03	9	[{"id_menu":6,"count":1}]	4851	delivery	5	14
58088	2020-05-03 19:32:43	2020-05-03	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1674	pick-up	0	33
58089	2020-05-03 19:36:38	2020-05-03	14	[{"id_menu":2,"count":1}]	22997	pick-up	0	14
58090	2020-05-03 19:37:50	2020-05-03	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23015	delivery	5	37
58091	2020-05-03 19:40:59	2020-05-03	12	[{"id_menu":1,"count":1}]	5144	delivery	5	17
58092	2020-05-03 19:41:41	2020-05-03	12	[{"id_menu":3,"count":1}]	17874	pick-up	0	12
58093	2020-05-03 19:41:53	2020-05-03	12	[{"id_menu":3,"count":1}]	16127	delivery	5	17
58094	2020-05-03 19:42:55	2020-05-03	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22937	delivery	5	23
58095	2020-05-03 19:44:05	2020-05-03	9	[{"id_menu":6,"count":1}]	23067	delivery	5	14
58096	2020-05-03 19:45:39	2020-05-03	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	22931	delivery	5	43
58097	2020-05-03 19:48:12	2020-05-03	12	[{"id_menu":3,"count":1}]	5201	delivery	5	17
58098	2020-05-03 19:50:27	2020-05-03	8	[{"id_menu":5,"count":1}]	22917	delivery	5	13
58099	2020-05-03 19:51:38	2020-05-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15456	pick-up	0	26
58100	2020-05-03 19:54:40	2020-05-03	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	16916	delivery	5	31
58101	2020-05-03 19:55:28	2020-05-03	9	[{"id_menu":6,"count":1}]	13028	pick-up	0	9
58102	2020-05-03 19:55:34	2020-05-03	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	13198	delivery	5	31
58103	2020-05-03 19:56:49	2020-05-03	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	22990	pick-up	0	31
58104	2020-05-03 19:59:14	2020-05-03	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5883	delivery	5	31
58105	2020-05-03 19:59:53	2020-05-03	9	[{"id_menu":7,"count":1}]	13543	delivery	5	14
58106	2020-05-03 20:00:27	2020-05-03	9	[{"id_menu":7,"count":1}]	23047	delivery	5	14
58107	2020-05-03 20:01:06	2020-05-03	9	[{"id_menu":6,"count":2}]	22978	delivery	5	14
58108	2020-05-03 20:03:35	2020-05-03	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	23012	delivery	5	40
58109	2020-05-03 20:03:36	2020-05-03	9	[{"id_menu":7,"count":1}]	11969	pick-up	0	9
58110	2020-05-03 20:07:05	2020-05-03	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20792	delivery	5	40
58111	2020-05-03 20:18:54	2020-05-03	8	[{"id_menu":5,"count":1}]	22911	delivery	5	13
58112	2020-05-03 20:20:18	2020-05-03	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22996	delivery	5	35
58113	2020-05-03 20:20:58	2020-05-03	17	[{"id_menu":4,"count":1}]	8004	delivery	5	22
58114	2020-05-03 20:21:01	2020-05-03	14	[{"id_menu":2,"count":1}]	7410	delivery	5	19
58115	2020-05-03 20:23:02	2020-05-03	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	2359	pick-up	0	21
58116	2020-05-03 20:29:50	2020-05-03	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7891	pick-up	0	25
58117	2020-05-03 20:29:56	2020-05-03	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	3082	pick-up	0	21
58118	2020-05-03 20:30:23	2020-05-03	9	[{"id_menu":6,"count":1}]	22897	delivery	5	14
58119	2020-05-03 20:30:44	2020-05-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17353	pick-up	0	26
58120	2020-05-03 20:35:41	2020-05-03	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	13309	delivery	5	26
58121	2020-05-03 20:40:03	2020-05-03	8	[{"id_menu":5,"count":1}]	12159	delivery	5	13
58122	2020-05-03 20:40:18	2020-05-03	8	[{"id_menu":5,"count":1}]	766	delivery	5	13
58123	2020-05-03 20:40:48	2020-05-03	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	23070	delivery	5	26
58124	2020-05-03 20:42:42	2020-05-03	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	23077	delivery	5	43
58125	2020-05-03 20:43:54	2020-05-03	9	[{"id_menu":6,"count":1}]	10710	delivery	5	14
58126	2020-05-03 20:44:10	2020-05-03	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8496	delivery	5	40
58127	2020-05-03 20:45:08	2020-05-03	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	22915	delivery	5	34
58128	2020-05-03 20:47:22	2020-05-03	14	[{"id_menu":2,"count":1}]	13662	pick-up	0	14
58129	2020-05-03 20:48:52	2020-05-03	17	[{"id_menu":4,"count":1}]	8952	delivery	5	22
58130	2020-05-03 20:51:10	2020-05-03	9	[{"id_menu":7,"count":1}]	21167	delivery	5	14
58131	2020-05-03 20:53:41	2020-05-03	9	[{"id_menu":6,"count":1}]	18519	delivery	5	14
58132	2020-05-03 20:55:36	2020-05-03	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22967	delivery	5	45
58133	2020-05-03 21:01:36	2020-05-03	9	[{"id_menu":7,"count":1}]	22886	delivery	5	14
58134	2020-05-03 21:05:06	2020-05-03	9	[{"id_menu":6,"count":1}]	22981	delivery	5	14
58135	2020-05-03 21:06:09	2020-05-03	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	19252	delivery	5	25
58136	2020-05-03 21:06:21	2020-05-03	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	21170	delivery	5	31
58137	2020-05-03 21:07:05	2020-05-03	12	[{"id_menu":1,"count":1}]	22716	delivery	5	17
58138	2020-05-03 21:10:05	2020-05-03	12	[{"id_menu":1,"count":1}]	5764	pick-up	0	12
58139	2020-05-03 21:11:32	2020-05-03	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	23045	delivery	5	26
58140	2020-05-03 21:12:20	2020-05-03	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	12384	delivery	5	25
58141	2020-05-03 21:14:03	2020-05-03	8	[{"id_menu":5,"count":1}]	23007	pick-up	0	8
58142	2020-05-03 21:15:01	2020-05-03	12	[{"id_menu":3,"count":1}]	2955	delivery	5	17
58143	2020-05-03 21:16:15	2020-05-03	8	[{"id_menu":5,"count":1}]	22167	delivery	5	13
58144	2020-05-03 21:19:03	2020-05-03	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	14795	delivery	5	25
58145	2020-05-03 21:21:09	2020-05-03	9	[{"id_menu":7,"count":1}]	23041	delivery	5	14
58146	2020-05-03 21:21:30	2020-05-03	9	[{"id_menu":7,"count":1}]	16559	delivery	5	14
58147	2020-05-03 21:24:05	2020-05-03	9	[{"id_menu":7,"count":1}]	3332	delivery	5	14
58148	2020-05-03 21:25:55	2020-05-03	14	[{"id_menu":2,"count":1}]	23037	delivery	5	19
58149	2020-05-03 21:26:47	2020-05-03	9	[{"id_menu":6,"count":1}]	18509	delivery	5	14
58150	2020-05-03 21:27:01	2020-05-03	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	23055	delivery	5	40
58151	2020-05-03 21:32:23	2020-05-03	12	[{"id_menu":3,"count":1}]	2517	pick-up	0	12
58152	2020-05-03 21:33:31	2020-05-03	17	[{"id_menu":4,"count":1}]	7465	pick-up	0	17
58153	2020-05-03 21:37:24	2020-05-03	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	23053	delivery	5	28
58154	2020-05-03 21:43:55	2020-05-03	12	[{"id_menu":1,"count":1}]	9528	pick-up	0	12
58155	2020-05-03 21:48:13	2020-05-03	32	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	906	pick-up	0	32
58156	2020-05-03 21:49:40	2020-05-03	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	23069	delivery	5	45
58157	2020-05-03 21:51:40	2020-05-03	9	[{"id_menu":7,"count":1}]	23060	delivery	5	14
58158	2020-05-03 21:53:06	2020-05-03	12	[{"id_menu":1,"count":1}]	5019	pick-up	0	12
58159	2020-05-03 21:56:48	2020-05-03	12	[{"id_menu":3,"count":1}]	22941	delivery	5	17
58160	2020-05-03 21:58:34	2020-05-03	14	[{"id_menu":2,"count":2}]	19637	pick-up	0	14
58161	2020-05-03 22:03:47	2020-05-03	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3820	pick-up	0	18
58162	2020-05-03 22:04:21	2020-05-03	12	[{"id_menu":1,"count":1}]	2312	pick-up	0	12
58163	2020-05-03 22:05:01	2020-05-03	12	[{"id_menu":3,"count":1}]	22972	pick-up	0	12
58164	2020-05-03 22:05:07	2020-05-03	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	3119	delivery	5	26
58165	2020-05-03 22:08:00	2020-05-03	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2627	delivery	5	31
58166	2020-05-03 22:09:13	2020-05-03	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2538	pick-up	0	22
58167	2020-05-03 22:10:07	2020-05-03	12	[{"id_menu":3,"count":1}]	23010	delivery	5	17
58168	2020-05-03 22:14:40	2020-05-03	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	22986	pick-up	0	23
58169	2020-05-03 22:15:29	2020-05-03	14	[{"id_menu":2,"count":1}]	4172	pick-up	0	14
58170	2020-05-03 22:17:21	2020-05-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	22930	delivery	5	31
58171	2020-05-03 22:18:59	2020-05-03	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	22925	delivery	5	29
58172	2020-05-03 22:22:10	2020-05-03	9	[{"id_menu":7,"count":1}]	8424	delivery	5	14
58173	2020-05-03 22:22:49	2020-05-03	9	[{"id_menu":7,"count":1}]	23036	delivery	5	14
58174	2020-05-03 22:27:21	2020-05-03	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	23034	delivery	5	42
58175	2020-05-03 22:27:33	2020-05-03	8	[{"id_menu":5,"count":1}]	17654	delivery	5	13
58176	2020-05-03 22:27:42	2020-05-03	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	22932	delivery	5	37
58177	2020-05-03 22:35:15	2020-05-03	9	[{"id_menu":6,"count":1}]	17555	delivery	5	14
58178	2020-05-03 22:35:56	2020-05-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	15549	delivery	5	28
58179	2020-05-03 22:38:33	2020-05-03	12	[{"id_menu":3,"count":1}]	1720	pick-up	0	12
58180	2020-05-03 22:42:38	2020-05-03	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	22845	delivery	5	26
58181	2020-05-03 22:44:21	2020-05-03	8	[{"id_menu":5,"count":1}]	11382	delivery	5	13
58182	2020-05-03 22:45:28	2020-05-03	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	15679	delivery	5	26
58183	2020-05-03 22:45:32	2020-05-03	9	[{"id_menu":6,"count":1}]	22921	delivery	5	14
58184	2020-05-03 22:46:31	2020-05-03	9	[{"id_menu":7,"count":1}]	18064	delivery	5	14
58185	2020-05-03 22:48:40	2020-05-03	9	[{"id_menu":6,"count":1}]	140	delivery	5	14
58186	2020-05-03 22:51:31	2020-05-03	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10488	delivery	5	40
58187	2020-05-03 22:51:42	2020-05-03	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	17020	delivery	5	34
58188	2020-05-03 22:53:05	2020-05-03	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":2}]	6800	delivery	5	22
58189	2020-05-03 22:53:15	2020-05-03	8	[{"id_menu":5,"count":1}]	13122	delivery	5	13
58190	2020-05-03 22:53:20	2020-05-03	9	[{"id_menu":7,"count":1}]	7983	pick-up	0	9
58191	2020-05-03 22:53:23	2020-05-03	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	2927	delivery	5	25
58192	2020-05-03 22:56:35	2020-05-03	14	[{"id_menu":2,"count":1}]	14562	pick-up	0	14
58260	2020-05-04 02:29:26	2020-05-04	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10808	delivery	5	35
58193	2020-05-03 22:57:00	2020-05-03	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	92	delivery	5	48
58194	2020-05-03 22:59:49	2020-05-03	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	8628	delivery	5	26
58195	2020-05-03 23:00:05	2020-05-03	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	18161	delivery	5	52
58196	2020-05-03 23:08:25	2020-05-03	12	[{"id_menu":1,"count":1}]	1780	pick-up	0	12
58197	2020-05-03 23:08:45	2020-05-03	9	[{"id_menu":7,"count":1}]	13064	delivery	5	14
58198	2020-05-03 23:09:41	2020-05-03	14	[{"id_menu":2,"count":1}]	18344	pick-up	0	14
58199	2020-05-03 23:10:54	2020-05-03	14	[{"id_menu":2,"count":1}]	23008	delivery	5	19
58200	2020-05-03 23:11:37	2020-05-03	12	[{"id_menu":1,"count":1}]	21895	delivery	5	17
58201	2020-05-03 23:12:09	2020-05-03	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	8234	delivery	5	26
58202	2020-05-03 23:13:38	2020-05-03	17	[{"id_menu":4,"count":1}]	2332	delivery	5	22
58203	2020-05-03 23:15:18	2020-05-03	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7533	delivery	5	34
58204	2020-05-03 23:16:38	2020-05-03	17	[{"id_menu":4,"count":1}]	22965	pick-up	0	17
58205	2020-05-03 23:18:50	2020-05-03	9	[{"id_menu":6,"count":1}]	11793	pick-up	0	9
58206	2020-05-03 23:22:08	2020-05-03	12	[{"id_menu":1,"count":1}]	13308	delivery	5	17
58207	2020-05-03 23:24:40	2020-05-03	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12228	delivery	5	55
58208	2020-05-03 23:27:34	2020-05-03	8	[{"id_menu":5,"count":1}]	8471	delivery	5	13
58209	2020-05-03 23:28:39	2020-05-03	12	[{"id_menu":3,"count":1}]	13824	delivery	5	17
58210	2020-05-03 23:33:10	2020-05-03	8	[{"id_menu":5,"count":1}]	23031	delivery	5	13
58211	2020-05-03 23:43:17	2020-05-03	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	10304	delivery	5	31
58212	2020-05-03 23:44:07	2020-05-03	9	[{"id_menu":7,"count":1}]	22935	delivery	5	14
58213	2020-05-03 23:44:17	2020-05-03	14	[{"id_menu":2,"count":1}]	224	delivery	5	19
58214	2020-05-03 23:47:27	2020-05-03	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	3022	delivery	5	28
58215	2020-05-03 23:49:25	2020-05-03	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	13561	delivery	5	26
58216	2020-05-03 23:51:36	2020-05-03	12	[{"id_menu":3,"count":1}]	9509	pick-up	0	12
58217	2020-05-03 23:51:38	2020-05-03	14	[{"id_menu":2,"count":1}]	4710	pick-up	0	14
58218	2020-05-03 23:52:14	2020-05-03	9	[{"id_menu":7,"count":1}]	15044	delivery	5	14
58219	2020-05-03 23:53:19	2020-05-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	4281	delivery	5	28
58220	2020-05-03 23:53:57	2020-05-03	14	[{"id_menu":2,"count":1}]	14519	pick-up	0	14
58221	2020-05-03 23:54:32	2020-05-03	17	[{"id_menu":4,"count":1}]	5419	delivery	5	22
58222	2020-05-03 23:55:18	2020-05-03	9	[{"id_menu":6,"count":1}]	2122	delivery	5	14
58223	2020-05-03 23:58:02	2020-05-03	8	[{"id_menu":5,"count":1}]	22923	delivery	5	13
58224	2020-05-03 23:58:37	2020-05-03	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	22992	delivery	5	25
58225	2020-05-04 00:07:00	2020-05-04	12	[{"id_menu":3,"count":1}]	6926	delivery	5	17
58226	2020-05-04 00:23:25	2020-05-04	9	[{"id_menu":6,"count":1}]	17964	delivery	5	14
58227	2020-05-04 00:36:32	2020-05-04	12	[{"id_menu":1,"count":1}]	8494	delivery	5	17
58228	2020-05-04 00:36:42	2020-05-04	12	[{"id_menu":1,"count":1}]	16841	pick-up	0	12
58229	2020-05-04 00:43:15	2020-05-04	17	[{"id_menu":4,"count":1}]	8269	delivery	5	22
58230	2020-05-04 00:43:51	2020-05-04	8	[{"id_menu":5,"count":1}]	23241	pick-up	0	8
58231	2020-05-04 00:46:04	2020-05-04	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16346	delivery	5	45
58232	2020-05-04 00:51:07	2020-05-04	12	[{"id_menu":1,"count":1}]	13370	pick-up	0	12
58233	2020-05-04 00:52:48	2020-05-04	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	9963	delivery	5	26
58234	2020-05-04 00:57:12	2020-05-04	9	[{"id_menu":7,"count":1}]	7752	delivery	5	14
58235	2020-05-04 00:57:23	2020-05-04	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1844	pick-up	0	17
58236	2020-05-04 00:57:44	2020-05-04	9	[{"id_menu":7,"count":1}]	1367	pick-up	0	9
58237	2020-05-04 01:03:22	2020-05-04	17	[{"id_menu":4,"count":1}]	3233	pick-up	0	17
58238	2020-05-04 01:13:13	2020-05-04	9	[{"id_menu":7,"count":3}]	6559	delivery	5	14
58239	2020-05-04 01:14:21	2020-05-04	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	16335	pick-up	0	23
58240	2020-05-04 01:16:47	2020-05-04	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22718	pick-up	0	17
58241	2020-05-04 01:19:05	2020-05-04	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	23113	delivery	5	30
58242	2020-05-04 01:25:59	2020-05-04	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	23096	delivery	5	26
58243	2020-05-04 01:28:16	2020-05-04	12	[{"id_menu":3,"count":1}]	5191	delivery	5	17
58244	2020-05-04 01:31:29	2020-05-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	23135	pick-up	0	23
58245	2020-05-04 01:35:00	2020-05-04	12	[{"id_menu":3,"count":1}]	18936	delivery	5	17
58246	2020-05-04 01:37:56	2020-05-04	9	[{"id_menu":6,"count":1}]	23119	delivery	5	14
58247	2020-05-04 01:42:08	2020-05-04	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	23228	pick-up	0	29
58248	2020-05-04 01:45:07	2020-05-04	17	[{"id_menu":4,"count":1}]	23165	delivery	5	22
58249	2020-05-04 01:50:56	2020-05-04	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	15557	delivery	5	22
58250	2020-05-04 01:51:17	2020-05-04	17	[{"id_menu":4,"count":1}]	5972	pick-up	0	17
58251	2020-05-04 01:53:03	2020-05-04	8	[{"id_menu":5,"count":1}]	21072	delivery	5	13
58252	2020-05-04 01:59:11	2020-05-04	9	[{"id_menu":6,"count":1}]	15742	delivery	5	14
58253	2020-05-04 02:04:02	2020-05-04	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6157	pick-up	0	18
58254	2020-05-04 02:12:09	2020-05-04	9	[{"id_menu":7,"count":1}]	21671	delivery	5	14
58255	2020-05-04 02:22:35	2020-05-04	8	[{"id_menu":5,"count":1}]	14144	delivery	5	13
58256	2020-05-04 02:23:55	2020-05-04	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23146	delivery	5	51
58257	2020-05-04 02:24:02	2020-05-04	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	23175	delivery	5	35
58258	2020-05-04 02:25:17	2020-05-04	9	[{"id_menu":7,"count":1}]	23171	delivery	5	14
58259	2020-05-04 02:28:36	2020-05-04	17	[{"id_menu":4,"count":1}]	23186	delivery	5	22
58261	2020-05-04 02:30:53	2020-05-04	12	[{"id_menu":1,"count":1}]	18418	delivery	5	17
58262	2020-05-04 02:32:32	2020-05-04	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	3378	delivery	5	27
58263	2020-05-04 02:36:34	2020-05-04	8	[{"id_menu":5,"count":1}]	10964	delivery	5	13
58264	2020-05-04 02:37:25	2020-05-04	9	[{"id_menu":7,"count":1}]	1141	pick-up	0	9
58265	2020-05-04 02:55:52	2020-05-04	17	[{"id_menu":4,"count":1}]	2149	delivery	5	22
58266	2020-05-04 03:02:24	2020-05-04	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	13753	delivery	5	26
58267	2020-05-04 03:05:11	2020-05-04	14	[{"id_menu":2,"count":1}]	23162	delivery	5	19
58268	2020-05-04 03:20:23	2020-05-04	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	22685	delivery	5	36
58269	2020-05-04 03:23:28	2020-05-04	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	23116	delivery	5	26
58270	2020-05-04 03:40:37	2020-05-04	8	[{"id_menu":5,"count":1}]	23230	delivery	5	13
58271	2020-05-04 03:52:20	2020-05-04	9	[{"id_menu":6,"count":1}]	12911	delivery	5	14
58272	2020-05-04 03:57:45	2020-05-04	9	[{"id_menu":7,"count":1}]	22831	delivery	5	14
58273	2020-05-04 04:01:04	2020-05-04	12	[{"id_menu":3,"count":1}]	23121	delivery	5	17
58274	2020-05-04 04:03:43	2020-05-04	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	23180	delivery	5	43
58275	2020-05-04 04:06:00	2020-05-04	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19720	delivery	5	22
58276	2020-05-04 04:07:40	2020-05-04	14	[{"id_menu":2,"count":2}]	23136	delivery	5	19
58277	2020-05-04 04:11:10	2020-05-04	12	[{"id_menu":3,"count":2}]	1629	pick-up	0	12
58278	2020-05-04 04:19:44	2020-05-04	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	171	delivery	5	36
58279	2020-05-04 04:21:02	2020-05-04	9	[{"id_menu":7,"count":1}]	8640	pick-up	0	9
58280	2020-05-04 04:24:13	2020-05-04	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20868	delivery	5	23
58281	2020-05-04 04:30:12	2020-05-04	17	[{"id_menu":4,"count":1}]	17320	delivery	5	22
58282	2020-05-04 04:33:50	2020-05-04	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	22900	delivery	5	31
58283	2020-05-04 04:33:54	2020-05-04	17	[{"id_menu":5,"count":3},{"id_menu":7,"count":1}]	15006	delivery	5	22
58284	2020-05-04 04:34:44	2020-05-04	8	[{"id_menu":5,"count":1}]	17342	delivery	5	13
58285	2020-05-04 04:35:47	2020-05-04	14	[{"id_menu":2,"count":1}]	1820	pick-up	0	14
58286	2020-05-04 04:43:10	2020-05-04	12	[{"id_menu":1,"count":1}]	1373	pick-up	0	12
58287	2020-05-04 04:43:42	2020-05-04	12	[{"id_menu":3,"count":1}]	2332	delivery	5	17
58288	2020-05-04 04:46:16	2020-05-04	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5875	pick-up	0	26
58289	2020-05-04 04:49:57	2020-05-04	9	[{"id_menu":6,"count":1}]	2055	pick-up	0	9
58290	2020-05-04 04:52:30	2020-05-04	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	6802	delivery	5	26
58291	2020-05-04 04:52:41	2020-05-04	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6328	delivery	5	36
58292	2020-05-04 04:58:16	2020-05-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2562	pick-up	0	23
58293	2020-05-04 05:00:58	2020-05-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	15757	delivery	5	28
58294	2020-05-04 05:02:06	2020-05-04	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	23140	delivery	5	40
58295	2020-05-04 05:02:15	2020-05-04	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	9466	delivery	5	25
58296	2020-05-04 05:02:42	2020-05-04	8	[{"id_menu":5,"count":2}]	23088	delivery	5	13
58297	2020-05-04 05:06:01	2020-05-04	8	[{"id_menu":5,"count":1}]	23138	delivery	5	13
58298	2020-05-04 05:08:04	2020-05-04	9	[{"id_menu":7,"count":1}]	11760	delivery	5	14
58299	2020-05-04 05:08:26	2020-05-04	12	[{"id_menu":3,"count":1}]	10958	pick-up	0	12
58300	2020-05-04 05:11:32	2020-05-04	12	[{"id_menu":1,"count":1}]	22363	delivery	5	17
58301	2020-05-04 05:27:28	2020-05-04	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	19931	pick-up	0	21
58302	2020-05-04 05:27:51	2020-05-04	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11192	delivery	5	23
58303	2020-05-04 05:27:53	2020-05-04	17	[{"id_menu":4,"count":2}]	9266	pick-up	0	17
58304	2020-05-04 05:28:35	2020-05-04	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5931	delivery	5	39
58305	2020-05-04 05:38:08	2020-05-04	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	18102	delivery	5	26
58306	2020-05-04 05:39:12	2020-05-04	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15644	delivery	5	43
58307	2020-05-04 05:44:24	2020-05-04	14	[{"id_menu":2,"count":1}]	19478	delivery	5	19
58308	2020-05-04 05:48:53	2020-05-04	9	[{"id_menu":6,"count":1}]	23213	delivery	5	14
58309	2020-05-04 05:56:28	2020-05-04	14	[{"id_menu":2,"count":1}]	207	pick-up	0	14
58310	2020-05-04 05:59:28	2020-05-04	14	[{"id_menu":2,"count":1}]	20905	pick-up	0	14
58311	2020-05-04 06:00:31	2020-05-04	8	[{"id_menu":5,"count":1}]	932	delivery	5	13
58312	2020-05-04 06:02:23	2020-05-04	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10143	delivery	5	30
58313	2020-05-04 06:14:52	2020-05-04	8	[{"id_menu":5,"count":1}]	9833	delivery	5	13
58314	2020-05-04 06:18:27	2020-05-04	8	[{"id_menu":5,"count":1}]	13697	pick-up	0	8
58315	2020-05-04 06:18:31	2020-05-04	12	[{"id_menu":3,"count":1}]	12393	pick-up	0	12
58316	2020-05-04 06:20:21	2020-05-04	14	[{"id_menu":2,"count":1}]	7554	pick-up	0	14
58317	2020-05-04 06:20:26	2020-05-04	9	[{"id_menu":6,"count":1}]	23222	delivery	5	14
58318	2020-05-04 06:23:46	2020-05-04	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	23163	delivery	5	43
58319	2020-05-04 06:24:22	2020-05-04	9	[{"id_menu":6,"count":1}]	345	pick-up	0	9
58320	2020-05-04 06:27:11	2020-05-04	14	[{"id_menu":2,"count":1}]	7731	delivery	5	19
58321	2020-05-04 06:27:48	2020-05-04	17	[{"id_menu":4,"count":1}]	2935	pick-up	0	17
58322	2020-05-04 06:33:33	2020-05-04	9	[{"id_menu":6,"count":1}]	13038	delivery	5	14
58323	2020-05-04 06:46:50	2020-05-04	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	7179	pick-up	0	21
58324	2020-05-04 06:48:40	2020-05-04	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	10895	delivery	5	31
58325	2020-05-04 06:51:04	2020-05-04	12	[{"id_menu":3,"count":1}]	19490	pick-up	0	12
58326	2020-05-04 07:16:55	2020-05-04	12	[{"id_menu":3,"count":1}]	8098	pick-up	0	12
58327	2020-05-04 07:18:53	2020-05-04	14	[{"id_menu":2,"count":1}]	23225	delivery	5	19
58328	2020-05-04 07:33:31	2020-05-04	9	[{"id_menu":6,"count":1}]	20006	delivery	5	14
58329	2020-05-04 07:53:13	2020-05-04	12	[{"id_menu":3,"count":1}]	7084	pick-up	0	12
58330	2020-05-04 07:58:45	2020-05-04	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	23231	delivery	5	45
58331	2020-05-04 08:01:49	2020-05-04	9	[{"id_menu":6,"count":1}]	6248	delivery	5	14
58332	2020-05-04 08:02:04	2020-05-04	9	[{"id_menu":7,"count":1}]	12095	pick-up	0	9
58333	2020-05-04 08:05:12	2020-05-04	9	[{"id_menu":7,"count":1}]	21368	delivery	5	14
58334	2020-05-04 08:05:50	2020-05-04	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	18445	pick-up	0	26
58335	2020-05-04 08:07:17	2020-05-04	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23152	delivery	5	48
58336	2020-05-04 08:11:58	2020-05-04	8	[{"id_menu":5,"count":1}]	23176	delivery	5	13
58337	2020-05-04 08:19:32	2020-05-04	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	23236	delivery	5	44
58338	2020-05-04 08:30:02	2020-05-04	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	7975	pick-up	0	26
58339	2020-05-04 08:31:12	2020-05-04	9	[{"id_menu":7,"count":1}]	20137	delivery	5	14
58340	2020-05-04 08:38:48	2020-05-04	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6818	delivery	5	51
58341	2020-05-04 08:44:18	2020-05-04	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	23205	delivery	5	31
58342	2020-05-04 08:53:33	2020-05-04	12	[{"id_menu":1,"count":1}]	23090	delivery	5	17
58343	2020-05-04 08:56:15	2020-05-04	9	[{"id_menu":7,"count":1}]	21698	delivery	5	14
58344	2020-05-04 09:02:58	2020-05-04	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	8536	delivery	5	25
58345	2020-05-04 09:07:01	2020-05-04	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13922	delivery	5	23
58346	2020-05-04 09:10:25	2020-05-04	12	[{"id_menu":1,"count":1}]	23155	delivery	5	17
58347	2020-05-04 09:11:49	2020-05-04	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	17067	delivery	5	37
58348	2020-05-04 09:12:42	2020-05-04	12	[{"id_menu":1,"count":1}]	11896	pick-up	0	12
58349	2020-05-04 09:14:19	2020-05-04	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	17917	delivery	5	26
58350	2020-05-04 09:32:05	2020-05-04	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	23232	delivery	5	27
58351	2020-05-04 09:33:18	2020-05-04	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	17707	delivery	5	27
58352	2020-05-04 09:34:21	2020-05-04	9	[{"id_menu":6,"count":1}]	12835	delivery	5	14
58353	2020-05-04 09:37:23	2020-05-04	9	[{"id_menu":6,"count":1}]	23220	delivery	5	14
58354	2020-05-04 09:41:39	2020-05-04	8	[{"id_menu":5,"count":1}]	23160	delivery	5	13
58355	2020-05-04 09:50:33	2020-05-04	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	7341	delivery	5	35
58356	2020-05-04 09:51:01	2020-05-04	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	23105	delivery	5	26
58357	2020-05-04 09:59:44	2020-05-04	9	[{"id_menu":7,"count":1}]	21049	delivery	5	14
58358	2020-05-04 10:01:00	2020-05-04	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23198	delivery	5	23
58359	2020-05-04 10:01:57	2020-05-04	12	[{"id_menu":1,"count":1}]	491	pick-up	0	12
58360	2020-05-04 10:02:14	2020-05-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	981	pick-up	0	23
58361	2020-05-04 10:03:17	2020-05-04	9	[{"id_menu":7,"count":1}]	20312	delivery	5	14
58362	2020-05-04 10:04:08	2020-05-04	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	19909	delivery	5	43
58363	2020-05-04 10:12:15	2020-05-04	14	[{"id_menu":2,"count":1}]	12299	delivery	5	19
58364	2020-05-04 10:13:30	2020-05-04	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	21076	pick-up	0	23
58365	2020-05-04 10:15:34	2020-05-04	9	[{"id_menu":7,"count":1}]	10671	delivery	5	14
58366	2020-05-04 10:25:03	2020-05-04	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	5699	delivery	5	38
58367	2020-05-04 10:38:18	2020-05-04	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23168	delivery	5	40
58368	2020-05-04 10:38:43	2020-05-04	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	10770	delivery	5	26
58369	2020-05-04 10:38:55	2020-05-04	8	[{"id_menu":5,"count":1}]	23166	delivery	5	13
58370	2020-05-04 10:39:44	2020-05-04	14	[{"id_menu":2,"count":1}]	6277	pick-up	0	14
58371	2020-05-04 10:46:41	2020-05-04	14	[{"id_menu":2,"count":1}]	993	pick-up	0	14
58372	2020-05-04 10:48:40	2020-05-04	17	[{"id_menu":4,"count":1}]	397	delivery	5	22
58373	2020-05-04 10:53:11	2020-05-04	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	6450	delivery	5	30
58374	2020-05-04 10:56:47	2020-05-04	12	[{"id_menu":1,"count":1}]	8726	delivery	5	17
58375	2020-05-04 10:57:38	2020-05-04	14	[{"id_menu":2,"count":1}]	7177	pick-up	0	14
58376	2020-05-04 11:04:04	2020-05-04	8	[{"id_menu":5,"count":1}]	23158	delivery	5	13
58377	2020-05-04 11:06:45	2020-05-04	12	[{"id_menu":1,"count":1}]	23195	delivery	5	17
58378	2020-05-04 11:18:58	2020-05-04	12	[{"id_menu":1,"count":1}]	256	pick-up	0	12
58379	2020-05-04 11:27:46	2020-05-04	12	[{"id_menu":1,"count":1}]	23178	delivery	5	17
58380	2020-05-04 11:37:13	2020-05-04	9	[{"id_menu":6,"count":1}]	23237	pick-up	0	9
58381	2020-05-04 11:43:38	2020-05-04	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":2}]	23114	delivery	5	36
58382	2020-05-04 11:43:59	2020-05-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2922	pick-up	0	23
58383	2020-05-04 11:46:44	2020-05-04	9	[{"id_menu":7,"count":1}]	10872	delivery	5	14
58384	2020-05-04 11:47:43	2020-05-04	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23252	delivery	5	22
58385	2020-05-04 11:52:25	2020-05-04	9	[{"id_menu":7,"count":2}]	5398	delivery	5	14
58386	2020-05-04 11:57:31	2020-05-04	12	[{"id_menu":1,"count":1}]	4287	delivery	5	17
58387	2020-05-04 12:00:08	2020-05-04	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	23257	delivery	5	26
58388	2020-05-04 12:00:58	2020-05-04	9	[{"id_menu":7,"count":1}]	3283	pick-up	0	9
58389	2020-05-04 12:04:35	2020-05-04	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	20487	delivery	5	22
58390	2020-05-04 12:07:46	2020-05-04	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	23259	delivery	5	26
58391	2020-05-04 12:10:17	2020-05-04	17	[{"id_menu":4,"count":1}]	3647	pick-up	0	17
58392	2020-05-04 12:19:13	2020-05-04	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7644	delivery	5	22
58393	2020-05-04 12:24:52	2020-05-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	12954	delivery	5	28
58459	2020-05-04 16:56:27	2020-05-04	17	[{"id_menu":4,"count":1}]	3198	pick-up	0	17
58394	2020-05-04 12:26:05	2020-05-04	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	17091	delivery	5	43
58395	2020-05-04 12:31:04	2020-05-04	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	23243	delivery	5	39
58396	2020-05-04 12:32:29	2020-05-04	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	5932	delivery	5	22
58397	2020-05-04 12:45:45	2020-05-04	9	[{"id_menu":7,"count":1}]	23206	delivery	5	14
58398	2020-05-04 12:46:19	2020-05-04	8	[{"id_menu":5,"count":1}]	7960	pick-up	0	8
58399	2020-05-04 12:56:44	2020-05-04	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	16592	pick-up	0	29
58400	2020-05-04 12:56:58	2020-05-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	23097	delivery	5	28
58401	2020-05-04 12:58:30	2020-05-04	9	[{"id_menu":6,"count":1}]	23141	delivery	5	14
58402	2020-05-04 12:58:57	2020-05-04	9	[{"id_menu":6,"count":1}]	23250	delivery	5	14
58403	2020-05-04 13:01:26	2020-05-04	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23234	delivery	5	40
58404	2020-05-04 13:07:23	2020-05-04	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	17900	delivery	5	25
58405	2020-05-04 13:09:31	2020-05-04	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	23131	pick-up	0	25
58406	2020-05-04 13:20:05	2020-05-04	17	[{"id_menu":4,"count":1}]	23177	delivery	5	22
58407	2020-05-04 13:20:14	2020-05-04	14	[{"id_menu":2,"count":1}]	2271	pick-up	0	14
58408	2020-05-04 13:21:14	2020-05-04	9	[{"id_menu":7,"count":1}]	6204	delivery	5	14
58409	2020-05-04 13:22:27	2020-05-04	9	[{"id_menu":7,"count":2}]	23156	delivery	5	14
58410	2020-05-04 13:27:57	2020-05-04	14	[{"id_menu":2,"count":1}]	3986	pick-up	0	14
58411	2020-05-04 13:39:05	2020-05-04	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	23124	delivery	5	28
58412	2020-05-04 14:02:39	2020-05-04	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16488	delivery	5	39
58413	2020-05-04 14:03:03	2020-05-04	17	[{"id_menu":4,"count":1}]	12918	pick-up	0	17
58414	2020-05-04 14:12:10	2020-05-04	14	[{"id_menu":2,"count":1}]	16443	delivery	5	19
58415	2020-05-04 14:13:32	2020-05-04	9	[{"id_menu":6,"count":1}]	23095	delivery	5	14
58416	2020-05-04 14:13:54	2020-05-04	12	[{"id_menu":3,"count":1}]	23224	delivery	5	17
58417	2020-05-04 14:14:22	2020-05-04	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	2827	pick-up	0	32
58418	2020-05-04 14:14:48	2020-05-04	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18512	delivery	5	39
58419	2020-05-04 14:14:53	2020-05-04	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	14411	delivery	5	23
58420	2020-05-04 14:21:05	2020-05-04	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	10381	delivery	5	31
58421	2020-05-04 14:21:14	2020-05-04	8	[{"id_menu":5,"count":1}]	2608	delivery	5	13
58422	2020-05-04 14:48:00	2020-05-04	14	[{"id_menu":2,"count":1}]	4090	pick-up	0	14
58423	2020-05-04 14:48:45	2020-05-04	12	[{"id_menu":1,"count":1}]	13497	pick-up	0	12
58424	2020-05-04 14:56:47	2020-05-04	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23187	delivery	5	36
58425	2020-05-04 15:06:58	2020-05-04	9	[{"id_menu":7,"count":1}]	23132	delivery	5	14
58426	2020-05-04 15:11:19	2020-05-04	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	16000	delivery	5	25
58427	2020-05-04 15:16:27	2020-05-04	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2585	delivery	5	57
58428	2020-05-04 15:37:43	2020-05-04	12	[{"id_menu":1,"count":1}]	19172	delivery	5	17
58429	2020-05-04 15:38:38	2020-05-04	9	[{"id_menu":7,"count":1}]	23189	delivery	5	14
58430	2020-05-04 15:46:55	2020-05-04	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	23161	delivery	5	30
58431	2020-05-04 15:47:46	2020-05-04	12	[{"id_menu":3,"count":1}]	18845	delivery	5	17
58432	2020-05-04 15:57:49	2020-05-04	17	[{"id_menu":4,"count":1}]	1143	pick-up	0	17
58433	2020-05-04 15:59:07	2020-05-04	9	[{"id_menu":6,"count":1}]	19166	delivery	5	14
58434	2020-05-04 16:01:05	2020-05-04	34	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	23086	delivery	5	39
58435	2020-05-04 16:05:28	2020-05-04	8	[{"id_menu":5,"count":1}]	6364	pick-up	0	8
58436	2020-05-04 16:06:30	2020-05-04	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20512	delivery	5	35
58437	2020-05-04 16:09:02	2020-05-04	9	[{"id_menu":7,"count":1}]	23199	delivery	5	14
58438	2020-05-04 16:10:16	2020-05-04	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	23212	delivery	5	34
58439	2020-05-04 16:11:11	2020-05-04	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	23227	delivery	5	38
58440	2020-05-04 16:12:39	2020-05-04	9	[{"id_menu":7,"count":1}]	23091	delivery	5	14
58441	2020-05-04 16:13:49	2020-05-04	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9214	delivery	5	35
58442	2020-05-04 16:16:15	2020-05-04	17	[{"id_menu":4,"count":1}]	12132	delivery	5	22
58443	2020-05-04 16:17:24	2020-05-04	9	[{"id_menu":6,"count":1}]	23137	pick-up	0	9
58444	2020-05-04 16:19:04	2020-05-04	14	[{"id_menu":2,"count":1}]	23115	delivery	5	19
58445	2020-05-04 16:21:46	2020-05-04	12	[{"id_menu":3,"count":1}]	16997	delivery	5	17
58446	2020-05-04 16:23:35	2020-05-04	12	[{"id_menu":1,"count":1}]	8772	delivery	5	17
58447	2020-05-04 16:27:13	2020-05-04	9	[{"id_menu":6,"count":1}]	15012	delivery	5	14
58448	2020-05-04 16:30:16	2020-05-04	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	23254	delivery	5	36
58449	2020-05-04 16:31:44	2020-05-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	23245	delivery	5	28
58450	2020-05-04 16:33:55	2020-05-04	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22311	delivery	5	31
58451	2020-05-04 16:40:20	2020-05-04	9	[{"id_menu":6,"count":1}]	23248	delivery	5	14
58452	2020-05-04 16:45:45	2020-05-04	8	[{"id_menu":5,"count":1}]	23129	delivery	5	13
58453	2020-05-04 16:48:46	2020-05-04	12	[{"id_menu":1,"count":1}]	10499	delivery	5	17
58454	2020-05-04 16:48:56	2020-05-04	14	[{"id_menu":2,"count":1}]	23247	pick-up	0	14
58455	2020-05-04 16:49:54	2020-05-04	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	23109	delivery	5	27
58456	2020-05-04 16:51:15	2020-05-04	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	23253	pick-up	0	21
58457	2020-05-04 16:52:33	2020-05-04	17	[{"id_menu":4,"count":1}]	4652	delivery	5	22
58458	2020-05-04 16:54:22	2020-05-04	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23242	delivery	5	35
58460	2020-05-04 16:57:25	2020-05-04	12	[{"id_menu":1,"count":1}]	10576	delivery	5	17
58461	2020-05-04 17:01:42	2020-05-04	14	[{"id_menu":2,"count":1}]	4620	delivery	5	19
58462	2020-05-04 17:02:30	2020-05-04	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	18302	delivery	5	39
58463	2020-05-04 17:10:03	2020-05-04	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	23170	delivery	5	36
58464	2020-05-04 17:10:21	2020-05-04	9	[{"id_menu":6,"count":1}]	7585	delivery	5	14
58465	2020-05-04 17:19:35	2020-05-04	17	[{"id_menu":4,"count":1}]	23123	delivery	5	22
58466	2020-05-04 17:23:34	2020-05-04	12	[{"id_menu":1,"count":1}]	23201	delivery	5	17
58467	2020-05-04 17:26:34	2020-05-04	8	[{"id_menu":5,"count":1}]	10598	delivery	5	13
58468	2020-05-04 17:35:52	2020-05-04	9	[{"id_menu":7,"count":1}]	15723	delivery	5	14
58469	2020-05-04 17:39:15	2020-05-04	12	[{"id_menu":3,"count":1}]	20885	delivery	5	17
58470	2020-05-04 17:46:32	2020-05-04	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9081	delivery	5	40
58471	2020-05-04 17:54:49	2020-05-04	9	[{"id_menu":6,"count":1}]	338	pick-up	0	9
58472	2020-05-04 18:03:08	2020-05-04	12	[{"id_menu":1,"count":1}]	23188	delivery	5	17
58473	2020-05-04 18:08:30	2020-05-04	9	[{"id_menu":6,"count":1}]	5736	pick-up	0	9
58474	2020-05-04 18:09:48	2020-05-04	14	[{"id_menu":2,"count":2}]	14831	delivery	5	19
58475	2020-05-04 18:17:31	2020-05-04	12	[{"id_menu":3,"count":1}]	6413	delivery	5	17
58476	2020-05-04 18:24:08	2020-05-04	9	[{"id_menu":7,"count":1}]	23108	delivery	5	14
58477	2020-05-04 18:27:44	2020-05-04	9	[{"id_menu":7,"count":1}]	1337	delivery	5	14
58478	2020-05-04 18:38:24	2020-05-04	12	[{"id_menu":1,"count":1}]	17571	delivery	5	17
58479	2020-05-04 18:38:39	2020-05-04	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23159	delivery	5	23
58480	2020-05-04 18:48:24	2020-05-04	12	[{"id_menu":3,"count":1}]	22722	delivery	5	17
58481	2020-05-04 18:50:50	2020-05-04	9	[{"id_menu":6,"count":1}]	23184	delivery	5	14
58482	2020-05-04 18:52:55	2020-05-04	12	[{"id_menu":1,"count":1}]	6823	delivery	5	17
58483	2020-05-04 18:53:55	2020-05-04	9	[{"id_menu":7,"count":1}]	23120	pick-up	0	9
58484	2020-05-04 18:58:55	2020-05-04	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	8564	delivery	5	25
58485	2020-05-04 18:59:24	2020-05-04	9	[{"id_menu":7,"count":1}]	4470	pick-up	0	9
58486	2020-05-04 19:08:26	2020-05-04	12	[{"id_menu":3,"count":1}]	21785	pick-up	0	12
58487	2020-05-04 19:18:06	2020-05-04	14	[{"id_menu":2,"count":1}]	17727	pick-up	0	14
58488	2020-05-04 19:18:48	2020-05-04	8	[{"id_menu":5,"count":1}]	23172	delivery	5	13
58489	2020-05-04 19:26:52	2020-05-04	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	23145	delivery	5	31
58490	2020-05-04 19:28:16	2020-05-04	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	23193	delivery	5	26
58491	2020-05-04 19:30:59	2020-05-04	8	[{"id_menu":5,"count":1}]	4585	pick-up	0	8
58492	2020-05-04 19:32:25	2020-05-04	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9352	delivery	5	35
58493	2020-05-04 19:36:33	2020-05-04	12	[{"id_menu":1,"count":1}]	10676	delivery	5	17
58494	2020-05-04 19:53:40	2020-05-04	8	[{"id_menu":5,"count":1}]	23235	delivery	5	13
58495	2020-05-04 19:54:00	2020-05-04	8	[{"id_menu":5,"count":1}]	2765	delivery	5	13
58496	2020-05-04 19:58:01	2020-05-04	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	23111	pick-up	0	20
58497	2020-05-04 19:58:30	2020-05-04	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	623	pick-up	0	31
58498	2020-05-04 19:59:48	2020-05-04	8	[{"id_menu":5,"count":1}]	4539	delivery	5	13
58499	2020-05-04 20:02:25	2020-05-04	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	6907	delivery	5	34
58500	2020-05-04 20:07:51	2020-05-04	8	[{"id_menu":5,"count":1}]	13174	delivery	5	13
58501	2020-05-04 20:12:47	2020-05-04	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	18864	delivery	5	34
58502	2020-05-04 20:21:19	2020-05-04	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	12642	delivery	5	22
58503	2020-05-04 20:29:50	2020-05-04	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23251	delivery	5	22
58504	2020-05-04 20:32:22	2020-05-04	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11513	delivery	5	43
58505	2020-05-04 20:34:59	2020-05-04	17	[{"id_menu":4,"count":1}]	20587	delivery	5	22
58506	2020-05-04 20:36:38	2020-05-04	12	[{"id_menu":3,"count":1}]	3909	pick-up	0	12
58507	2020-05-04 20:38:32	2020-05-04	14	[{"id_menu":2,"count":3}]	8867	delivery	5	19
58508	2020-05-04 20:44:33	2020-05-04	17	[{"id_menu":4,"count":1}]	20485	delivery	5	22
58509	2020-05-04 20:49:21	2020-05-04	9	[{"id_menu":6,"count":1}]	23240	delivery	5	14
58510	2020-05-04 20:53:14	2020-05-04	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20959	delivery	5	45
58511	2020-05-04 20:56:49	2020-05-04	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	23183	delivery	5	31
58512	2020-05-04 21:00:49	2020-05-04	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	998	pick-up	0	26
58513	2020-05-04 21:01:53	2020-05-04	9	[{"id_menu":6,"count":1}]	3007	pick-up	0	9
58514	2020-05-04 21:05:20	2020-05-04	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	11367	delivery	5	38
58515	2020-05-04 21:09:42	2020-05-04	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21358	pick-up	0	26
58516	2020-05-04 21:11:22	2020-05-04	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	13930	pick-up	0	26
58517	2020-05-04 21:11:35	2020-05-04	12	[{"id_menu":3,"count":1}]	23133	pick-up	0	12
58518	2020-05-04 21:14:43	2020-05-04	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23174	delivery	5	22
58519	2020-05-04 21:18:36	2020-05-04	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	7506	delivery	5	31
58520	2020-05-04 21:32:50	2020-05-04	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23130	delivery	5	22
58521	2020-05-04 21:35:12	2020-05-04	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	13136	pick-up	0	23
58522	2020-05-04 21:53:50	2020-05-04	9	[{"id_menu":6,"count":1}]	8866	delivery	5	14
58523	2020-05-04 21:57:54	2020-05-04	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	19281	delivery	5	26
58524	2020-05-04 21:58:30	2020-05-04	12	[{"id_menu":3,"count":1}]	8110	delivery	5	17
58525	2020-05-04 22:04:01	2020-05-04	8	[{"id_menu":5,"count":1}]	15686	pick-up	0	8
58526	2020-05-04 22:06:25	2020-05-04	9	[{"id_menu":6,"count":1}]	23221	pick-up	0	9
58527	2020-05-04 22:07:12	2020-05-04	17	[{"id_menu":4,"count":2}]	8579	pick-up	0	17
58528	2020-05-04 22:09:41	2020-05-04	9	[{"id_menu":6,"count":1}]	304	pick-up	0	9
58529	2020-05-04 22:12:44	2020-05-04	9	[{"id_menu":7,"count":1}]	21022	delivery	5	14
58530	2020-05-04 22:20:59	2020-05-04	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	23238	delivery	5	25
58531	2020-05-04 22:22:49	2020-05-04	12	[{"id_menu":3,"count":1}]	527	delivery	5	17
58532	2020-05-04 22:23:58	2020-05-04	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	23233	delivery	5	36
58533	2020-05-04 22:24:44	2020-05-04	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23210	delivery	5	43
58534	2020-05-04 22:35:31	2020-05-04	17	[{"id_menu":4,"count":1}]	13507	delivery	5	22
58535	2020-05-04 22:39:27	2020-05-04	9	[{"id_menu":6,"count":1}]	3745	delivery	5	14
58536	2020-05-04 22:41:00	2020-05-04	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23261	delivery	5	36
58537	2020-05-04 22:42:21	2020-05-04	9	[{"id_menu":6,"count":1}]	19599	delivery	5	14
58538	2020-05-04 22:47:40	2020-05-04	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	7182	pick-up	0	29
58539	2020-05-04 22:52:20	2020-05-04	12	[{"id_menu":1,"count":1}]	188	delivery	5	17
58540	2020-05-04 23:00:39	2020-05-04	12	[{"id_menu":3,"count":1}]	4986	pick-up	0	12
58541	2020-05-04 23:08:21	2020-05-04	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	13288	pick-up	0	23
58542	2020-05-04 23:16:07	2020-05-04	17	[{"id_menu":4,"count":1}]	16627	pick-up	0	17
58543	2020-05-04 23:34:49	2020-05-04	12	[{"id_menu":3,"count":1}]	21793	delivery	5	17
58544	2020-05-04 23:36:56	2020-05-04	12	[{"id_menu":1,"count":1}]	20931	delivery	5	17
58545	2020-05-04 23:44:51	2020-05-04	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18650	delivery	5	34
58546	2020-05-04 23:45:38	2020-05-04	9	[{"id_menu":6,"count":1}]	1719	pick-up	0	9
58547	2020-05-04 23:46:51	2020-05-04	12	[{"id_menu":1,"count":1}]	2523	pick-up	0	12
58548	2020-05-04 23:48:59	2020-05-04	12	[{"id_menu":3,"count":1}]	2026	pick-up	0	12
58549	2020-05-04 23:49:48	2020-05-04	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	5341	delivery	5	45
58550	2020-05-04 23:49:52	2020-05-04	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	23169	delivery	5	31
58551	2020-05-04 23:57:11	2020-05-04	9	[{"id_menu":7,"count":1}]	14038	delivery	5	14
58552	2020-05-05 00:03:54	2020-05-05	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	13371	delivery	5	40
58553	2020-05-05 00:08:15	2020-05-05	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	12184	delivery	5	34
58554	2020-05-05 00:08:15	2020-05-05	17	[{"id_menu":4,"count":1}]	9151	delivery	5	22
58555	2020-05-05 00:08:29	2020-05-05	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10238	delivery	5	39
58556	2020-05-05 00:09:09	2020-05-05	12	[{"id_menu":3,"count":1}]	23395	delivery	5	17
58557	2020-05-05 00:11:05	2020-05-05	14	[{"id_menu":2,"count":1}]	23426	delivery	5	19
58558	2020-05-05 00:12:12	2020-05-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13082	delivery	5	22
58559	2020-05-05 00:21:15	2020-05-05	9	[{"id_menu":7,"count":1}]	22557	delivery	5	14
58560	2020-05-05 00:36:39	2020-05-05	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	9914	delivery	5	26
58561	2020-05-05 00:44:53	2020-05-05	9	[{"id_menu":7,"count":1}]	7891	pick-up	0	9
58562	2020-05-05 00:47:47	2020-05-05	26	[{"id_menu":2,"count":3},{"id_menu":3,"count":1}]	23338	delivery	5	31
58563	2020-05-05 00:51:40	2020-05-05	17	[{"id_menu":4,"count":1}]	8240	pick-up	0	17
58564	2020-05-05 00:57:14	2020-05-05	17	[{"id_menu":4,"count":1}]	23400	pick-up	0	17
58565	2020-05-05 00:59:14	2020-05-05	9	[{"id_menu":7,"count":1}]	23418	delivery	5	14
58566	2020-05-05 01:09:48	2020-05-05	12	[{"id_menu":3,"count":1}]	23364	delivery	5	17
58567	2020-05-05 01:09:56	2020-05-05	17	[{"id_menu":4,"count":1}]	19131	delivery	5	22
58568	2020-05-05 01:14:36	2020-05-05	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	23378	delivery	5	45
58569	2020-05-05 01:16:45	2020-05-05	9	[{"id_menu":6,"count":1}]	13370	pick-up	0	9
58570	2020-05-05 01:24:59	2020-05-05	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	23374	delivery	5	27
58571	2020-05-05 01:30:48	2020-05-05	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16436	delivery	5	36
58572	2020-05-05 01:33:18	2020-05-05	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	23392	delivery	5	35
58573	2020-05-05 01:36:58	2020-05-05	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	23370	delivery	5	26
58574	2020-05-05 01:37:44	2020-05-05	12	[{"id_menu":1,"count":1}]	20962	delivery	5	17
58575	2020-05-05 01:39:20	2020-05-05	9	[{"id_menu":6,"count":1}]	23335	delivery	5	14
58576	2020-05-05 01:44:00	2020-05-05	12	[{"id_menu":1,"count":1}]	1012	delivery	5	17
58577	2020-05-05 01:45:24	2020-05-05	12	[{"id_menu":3,"count":1}]	22429	delivery	5	17
58578	2020-05-05 01:52:51	2020-05-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	22873	delivery	5	28
58579	2020-05-05 01:55:51	2020-05-05	9	[{"id_menu":6,"count":1}]	23285	pick-up	0	9
58580	2020-05-05 02:00:47	2020-05-05	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	10254	delivery	5	22
58581	2020-05-05 02:00:57	2020-05-05	14	[{"id_menu":2,"count":1}]	23321	delivery	5	19
58582	2020-05-05 02:01:01	2020-05-05	12	[{"id_menu":1,"count":1}]	86	pick-up	0	12
58583	2020-05-05 02:01:35	2020-05-05	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	17852	delivery	5	26
58584	2020-05-05 02:06:59	2020-05-05	8	[{"id_menu":5,"count":1}]	6483	delivery	5	13
58585	2020-05-05 02:10:37	2020-05-05	8	[{"id_menu":5,"count":1}]	1095	pick-up	0	8
58586	2020-05-05 02:17:29	2020-05-05	9	[{"id_menu":6,"count":1}]	16988	delivery	5	14
58587	2020-05-05 02:20:17	2020-05-05	9	[{"id_menu":6,"count":1}]	14239	pick-up	0	9
58588	2020-05-05 02:20:49	2020-05-05	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18195	delivery	5	34
58589	2020-05-05 02:21:21	2020-05-05	8	[{"id_menu":5,"count":1}]	23268	delivery	5	13
58590	2020-05-05 02:23:58	2020-05-05	17	[{"id_menu":4,"count":1}]	23333	delivery	5	22
58591	2020-05-05 02:25:07	2020-05-05	14	[{"id_menu":2,"count":1}]	21481	pick-up	0	14
58592	2020-05-05 02:36:12	2020-05-05	12	[{"id_menu":1,"count":1}]	5050	pick-up	0	12
58593	2020-05-05 02:40:12	2020-05-05	9	[{"id_menu":7,"count":1}]	23276	delivery	5	14
58594	2020-05-05 02:50:19	2020-05-05	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2875	pick-up	0	35
58595	2020-05-05 02:52:41	2020-05-05	12	[{"id_menu":1,"count":1}]	13656	pick-up	0	12
58596	2020-05-05 03:00:34	2020-05-05	8	[{"id_menu":5,"count":1}]	17676	delivery	5	13
58597	2020-05-05 03:02:39	2020-05-05	9	[{"id_menu":7,"count":1}]	14585	pick-up	0	9
58598	2020-05-05 03:05:39	2020-05-05	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	23368	delivery	5	34
58599	2020-05-05 03:21:23	2020-05-05	9	[{"id_menu":6,"count":1}]	5183	delivery	5	14
58600	2020-05-05 03:21:46	2020-05-05	14	[{"id_menu":2,"count":1}]	23319	delivery	5	19
58601	2020-05-05 03:28:40	2020-05-05	17	[{"id_menu":4,"count":1}]	23325	delivery	5	22
58602	2020-05-05 03:32:57	2020-05-05	12	[{"id_menu":1,"count":1}]	1093	pick-up	0	12
58603	2020-05-05 03:36:38	2020-05-05	12	[{"id_menu":3,"count":1}]	23288	delivery	5	17
58604	2020-05-05 03:37:56	2020-05-05	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	9142	delivery	5	40
58605	2020-05-05 03:40:07	2020-05-05	17	[{"id_menu":4,"count":1}]	21723	pick-up	0	17
58606	2020-05-05 03:49:28	2020-05-05	12	[{"id_menu":3,"count":1}]	23306	delivery	5	17
58607	2020-05-05 04:02:19	2020-05-05	8	[{"id_menu":5,"count":2}]	13732	pick-up	0	8
58608	2020-05-05 04:07:06	2020-05-05	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23414	delivery	5	48
58609	2020-05-05 04:07:29	2020-05-05	12	[{"id_menu":1,"count":1}]	1956	delivery	5	17
58610	2020-05-05 04:13:10	2020-05-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	23267	delivery	5	28
58611	2020-05-05 04:20:43	2020-05-05	17	[{"id_menu":4,"count":1}]	23300	pick-up	0	17
58612	2020-05-05 04:22:21	2020-05-05	12	[{"id_menu":1,"count":1}]	1457	delivery	5	17
58613	2020-05-05 04:23:21	2020-05-05	14	[{"id_menu":2,"count":1}]	17530	delivery	5	19
58614	2020-05-05 04:31:24	2020-05-05	8	[{"id_menu":5,"count":1}]	17321	pick-up	0	8
58615	2020-05-05 04:32:11	2020-05-05	9	[{"id_menu":7,"count":1}]	23366	delivery	5	14
58616	2020-05-05 04:37:18	2020-05-05	9	[{"id_menu":7,"count":1}]	23318	delivery	5	14
58617	2020-05-05 04:42:54	2020-05-05	12	[{"id_menu":3,"count":1}]	6184	delivery	5	17
58618	2020-05-05 04:44:13	2020-05-05	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	13245	delivery	5	29
58619	2020-05-05 04:47:51	2020-05-05	14	[{"id_menu":2,"count":1}]	23377	delivery	5	19
58620	2020-05-05 04:49:08	2020-05-05	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23315	delivery	5	52
58621	2020-05-05 04:55:09	2020-05-05	12	[{"id_menu":1,"count":1}]	18980	pick-up	0	12
58622	2020-05-05 04:59:42	2020-05-05	17	[{"id_menu":4,"count":1}]	1015	pick-up	0	17
58623	2020-05-05 05:03:45	2020-05-05	9	[{"id_menu":7,"count":1}]	12841	delivery	5	14
58624	2020-05-05 05:05:33	2020-05-05	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23342	delivery	5	31
58625	2020-05-05 05:08:46	2020-05-05	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	17569	pick-up	0	26
58626	2020-05-05 05:13:04	2020-05-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	23380	delivery	5	31
58627	2020-05-05 05:18:12	2020-05-05	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23270	delivery	5	36
58628	2020-05-05 05:25:55	2020-05-05	14	[{"id_menu":2,"count":1}]	19256	pick-up	0	14
58629	2020-05-05 05:28:13	2020-05-05	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23292	delivery	5	22
58630	2020-05-05 05:29:11	2020-05-05	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17511	delivery	5	31
58631	2020-05-05 05:36:08	2020-05-05	9	[{"id_menu":7,"count":1}]	23412	delivery	5	14
58632	2020-05-05 05:36:33	2020-05-05	12	[{"id_menu":1,"count":1}]	20711	delivery	5	17
58633	2020-05-05 05:37:56	2020-05-05	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	13033	pick-up	0	26
58634	2020-05-05 05:39:48	2020-05-05	8	[{"id_menu":5,"count":1}]	5400	delivery	5	13
58635	2020-05-05 05:40:28	2020-05-05	9	[{"id_menu":6,"count":1}]	23281	delivery	5	14
58636	2020-05-05 05:48:14	2020-05-05	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":3}]	2750	pick-up	0	26
58637	2020-05-05 05:49:32	2020-05-05	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9258	delivery	5	22
58638	2020-05-05 06:01:39	2020-05-05	9	[{"id_menu":7,"count":1}]	825	delivery	5	14
58639	2020-05-05 06:04:20	2020-05-05	12	[{"id_menu":3,"count":1}]	11773	delivery	5	17
58640	2020-05-05 06:04:43	2020-05-05	8	[{"id_menu":5,"count":1}]	2580	pick-up	0	8
58641	2020-05-05 06:13:06	2020-05-05	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	4347	delivery	5	26
58642	2020-05-05 06:13:44	2020-05-05	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6326	delivery	5	43
58643	2020-05-05 06:30:27	2020-05-05	12	[{"id_menu":3,"count":1}]	6116	delivery	5	17
58644	2020-05-05 06:42:53	2020-05-05	9	[{"id_menu":7,"count":1}]	13747	delivery	5	14
58645	2020-05-05 06:45:21	2020-05-05	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21373	delivery	5	52
58646	2020-05-05 06:47:10	2020-05-05	9	[{"id_menu":7,"count":1}]	423	pick-up	0	9
58647	2020-05-05 06:47:49	2020-05-05	9	[{"id_menu":6,"count":1}]	3705	delivery	5	14
58648	2020-05-05 06:53:03	2020-05-05	12	[{"id_menu":3,"count":1}]	18533	pick-up	0	12
58649	2020-05-05 06:56:10	2020-05-05	17	[{"id_menu":4,"count":2}]	23322	delivery	5	22
58650	2020-05-05 07:00:08	2020-05-05	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2632	delivery	5	39
58651	2020-05-05 07:00:50	2020-05-05	17	[{"id_menu":4,"count":1}]	17517	delivery	5	22
58652	2020-05-05 07:07:06	2020-05-05	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	23279	delivery	5	26
58653	2020-05-05 07:15:56	2020-05-05	8	[{"id_menu":5,"count":1}]	17582	pick-up	0	8
58654	2020-05-05 07:18:21	2020-05-05	9	[{"id_menu":6,"count":1}]	23308	delivery	5	14
58655	2020-05-05 07:18:29	2020-05-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2788	pick-up	0	23
58656	2020-05-05 07:26:46	2020-05-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23420	delivery	5	23
58657	2020-05-05 07:35:01	2020-05-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6195	pick-up	0	26
58658	2020-05-05 07:40:34	2020-05-05	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1992	pick-up	0	21
58659	2020-05-05 07:40:37	2020-05-05	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	23273	delivery	5	43
58660	2020-05-05 07:45:40	2020-05-05	14	[{"id_menu":2,"count":1}]	17046	pick-up	0	14
58661	2020-05-05 07:47:25	2020-05-05	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23361	delivery	5	45
58662	2020-05-05 07:48:57	2020-05-05	12	[{"id_menu":3,"count":1}]	16860	delivery	5	17
58663	2020-05-05 07:58:21	2020-05-05	9	[{"id_menu":7,"count":1}]	7073	delivery	5	14
58664	2020-05-05 07:59:35	2020-05-05	9	[{"id_menu":7,"count":2}]	7711	delivery	5	14
58665	2020-05-05 08:00:53	2020-05-05	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	14759	delivery	5	35
58666	2020-05-05 08:03:46	2020-05-05	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	23430	delivery	5	43
58667	2020-05-05 08:15:07	2020-05-05	14	[{"id_menu":2,"count":1}]	5987	delivery	5	19
58668	2020-05-05 08:21:33	2020-05-05	12	[{"id_menu":1,"count":1}]	1176	pick-up	0	12
58669	2020-05-05 08:26:32	2020-05-05	14	[{"id_menu":2,"count":1}]	23427	delivery	5	19
58670	2020-05-05 08:28:03	2020-05-05	14	[{"id_menu":2,"count":1}]	19442	pick-up	0	14
58671	2020-05-05 08:34:26	2020-05-05	9	[{"id_menu":7,"count":1}]	8564	delivery	5	14
58672	2020-05-05 08:49:11	2020-05-05	8	[{"id_menu":5,"count":1}]	23424	pick-up	0	8
58673	2020-05-05 08:51:41	2020-05-05	12	[{"id_menu":1,"count":1}]	23350	pick-up	0	12
58674	2020-05-05 09:04:03	2020-05-05	8	[{"id_menu":5,"count":1}]	23346	delivery	5	13
58675	2020-05-05 09:05:31	2020-05-05	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	14475	delivery	5	28
58676	2020-05-05 09:14:12	2020-05-05	12	[{"id_menu":1,"count":1}]	23351	delivery	5	17
58677	2020-05-05 09:24:17	2020-05-05	8	[{"id_menu":5,"count":1}]	23348	delivery	5	13
58678	2020-05-05 09:25:26	2020-05-05	14	[{"id_menu":2,"count":1}]	7775	delivery	5	19
58679	2020-05-05 09:38:28	2020-05-05	9	[{"id_menu":7,"count":1}]	11286	delivery	5	14
58680	2020-05-05 09:39:28	2020-05-05	8	[{"id_menu":5,"count":1}]	18048	delivery	5	13
58681	2020-05-05 09:46:34	2020-05-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	13790	delivery	5	31
58682	2020-05-05 09:50:03	2020-05-05	8	[{"id_menu":5,"count":1}]	23286	delivery	5	13
58683	2020-05-05 10:01:28	2020-05-05	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	23337	delivery	5	26
58684	2020-05-05 10:03:48	2020-05-05	9	[{"id_menu":6,"count":3}]	16102	delivery	5	14
58685	2020-05-05 10:04:45	2020-05-05	8	[{"id_menu":5,"count":1}]	19348	delivery	5	13
58686	2020-05-05 10:08:49	2020-05-05	14	[{"id_menu":2,"count":1}]	22969	delivery	5	19
58687	2020-05-05 10:10:09	2020-05-05	9	[{"id_menu":6,"count":1}]	23334	delivery	5	14
58688	2020-05-05 10:15:54	2020-05-05	12	[{"id_menu":1,"count":1}]	4411	delivery	5	17
58689	2020-05-05 10:16:18	2020-05-05	8	[{"id_menu":5,"count":1}]	6797	delivery	5	13
58690	2020-05-05 10:19:43	2020-05-05	17	[{"id_menu":4,"count":1}]	8229	pick-up	0	17
58691	2020-05-05 10:20:26	2020-05-05	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	23372	pick-up	0	30
58692	2020-05-05 10:21:44	2020-05-05	17	[{"id_menu":4,"count":1}]	18374	pick-up	0	17
58693	2020-05-05 10:22:49	2020-05-05	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	12656	delivery	5	39
58694	2020-05-05 10:26:45	2020-05-05	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":2}]	15727	delivery	5	22
58695	2020-05-05 10:28:23	2020-05-05	9	[{"id_menu":7,"count":2}]	3780	pick-up	0	9
58696	2020-05-05 10:30:14	2020-05-05	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21102	delivery	5	35
58697	2020-05-05 10:32:14	2020-05-05	12	[{"id_menu":3,"count":1}]	23278	delivery	5	17
58698	2020-05-05 10:34:08	2020-05-05	9	[{"id_menu":7,"count":1}]	23347	delivery	5	14
58699	2020-05-05 10:38:10	2020-05-05	9	[{"id_menu":6,"count":1}]	16992	delivery	5	14
58700	2020-05-05 10:41:33	2020-05-05	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	23411	delivery	5	28
58701	2020-05-05 10:41:38	2020-05-05	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	3616	delivery	5	34
58702	2020-05-05 10:41:42	2020-05-05	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1569	pick-up	0	29
58703	2020-05-05 10:45:04	2020-05-05	14	[{"id_menu":2,"count":1}]	931	pick-up	0	14
58704	2020-05-05 10:51:34	2020-05-05	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	23274	delivery	5	31
58705	2020-05-05 10:54:13	2020-05-05	12	[{"id_menu":3,"count":1}]	23280	delivery	5	17
58706	2020-05-05 10:59:49	2020-05-05	17	[{"id_menu":4,"count":1}]	23381	delivery	5	22
58707	2020-05-05 11:04:05	2020-05-05	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2526	delivery	5	34
58708	2020-05-05 11:08:04	2020-05-05	9	[{"id_menu":6,"count":1}]	11383	pick-up	0	9
58709	2020-05-05 11:09:09	2020-05-05	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23428	delivery	5	54
58710	2020-05-05 11:15:02	2020-05-05	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19746	delivery	5	39
58711	2020-05-05 11:16:55	2020-05-05	9	[{"id_menu":6,"count":1}]	23282	delivery	5	14
58712	2020-05-05 11:19:14	2020-05-05	9	[{"id_menu":7,"count":1}]	23327	delivery	5	14
58713	2020-05-05 11:21:12	2020-05-05	33	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	23344	delivery	5	38
58714	2020-05-05 11:22:35	2020-05-05	8	[{"id_menu":5,"count":1}]	23388	delivery	5	13
58715	2020-05-05 11:25:23	2020-05-05	8	[{"id_menu":5,"count":1}]	5565	delivery	5	13
58716	2020-05-05 11:27:43	2020-05-05	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	23309	delivery	5	25
58717	2020-05-05 11:36:13	2020-05-05	8	[{"id_menu":5,"count":1}]	8358	pick-up	0	8
58718	2020-05-05 11:36:59	2020-05-05	9	[{"id_menu":7,"count":2}]	2615	pick-up	0	9
58719	2020-05-05 11:39:53	2020-05-05	12	[{"id_menu":1,"count":1}]	13662	delivery	5	17
58720	2020-05-05 11:43:43	2020-05-05	12	[{"id_menu":1,"count":1}]	23341	delivery	5	17
58721	2020-05-05 11:55:04	2020-05-05	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	23419	delivery	5	29
58722	2020-05-05 11:55:44	2020-05-05	8	[{"id_menu":5,"count":1}]	23394	delivery	5	13
58723	2020-05-05 11:56:11	2020-05-05	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	23248	delivery	5	30
58724	2020-05-05 12:01:22	2020-05-05	9	[{"id_menu":7,"count":1}]	5702	delivery	5	14
58725	2020-05-05 12:03:36	2020-05-05	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	23385	delivery	5	44
58726	2020-05-05 12:12:07	2020-05-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	23422	delivery	5	22
58727	2020-05-05 12:14:10	2020-05-05	9	[{"id_menu":6,"count":1}]	13155	pick-up	0	9
58728	2020-05-05 12:23:34	2020-05-05	17	[{"id_menu":4,"count":1}]	23390	delivery	5	22
58729	2020-05-05 12:24:16	2020-05-05	9	[{"id_menu":7,"count":1}]	13068	pick-up	0	9
58730	2020-05-05 12:26:18	2020-05-05	9	[{"id_menu":7,"count":1}]	23283	delivery	5	14
58731	2020-05-05 12:26:38	2020-05-05	14	[{"id_menu":2,"count":1}]	11795	delivery	5	19
58732	2020-05-05 12:26:41	2020-05-05	9	[{"id_menu":6,"count":1}]	3597	delivery	5	14
58733	2020-05-05 12:28:01	2020-05-05	12	[{"id_menu":1,"count":1}]	23336	delivery	5	17
58734	2020-05-05 12:28:45	2020-05-05	9	[{"id_menu":7,"count":1}]	20753	delivery	5	14
58735	2020-05-05 12:42:58	2020-05-05	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1002	pick-up	0	21
58736	2020-05-05 12:43:54	2020-05-05	14	[{"id_menu":2,"count":1}]	22708	pick-up	0	14
58737	2020-05-05 12:44:05	2020-05-05	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	23403	delivery	5	31
58738	2020-05-05 12:51:16	2020-05-05	9	[{"id_menu":7,"count":1}]	7932	delivery	5	14
58739	2020-05-05 13:06:10	2020-05-05	9	[{"id_menu":7,"count":1}]	23303	delivery	5	14
58740	2020-05-05 13:14:11	2020-05-05	9	[{"id_menu":7,"count":1}]	23317	delivery	5	14
58741	2020-05-05 13:16:07	2020-05-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11139	delivery	5	31
58742	2020-05-05 13:20:13	2020-05-05	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12944	delivery	5	35
58743	2020-05-05 13:26:34	2020-05-05	17	[{"id_menu":4,"count":1}]	14211	delivery	5	22
58744	2020-05-05 13:36:11	2020-05-05	14	[{"id_menu":2,"count":2}]	3524	delivery	5	19
58745	2020-05-05 13:38:32	2020-05-05	8	[{"id_menu":5,"count":1}]	8733	delivery	5	13
58746	2020-05-05 13:39:32	2020-05-05	9	[{"id_menu":7,"count":1}]	23375	delivery	5	14
58747	2020-05-05 13:39:53	2020-05-05	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3382	pick-up	0	29
58748	2020-05-05 13:43:06	2020-05-05	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	23296	delivery	5	39
58749	2020-05-05 13:45:27	2020-05-05	17	[{"id_menu":4,"count":1}]	3511	pick-up	0	17
58750	2020-05-05 14:01:10	2020-05-05	14	[{"id_menu":2,"count":1}]	22345	delivery	5	19
58751	2020-05-05 14:03:54	2020-05-05	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	12249	delivery	5	26
58752	2020-05-05 14:13:18	2020-05-05	12	[{"id_menu":3,"count":1}]	2973	pick-up	0	12
58753	2020-05-05 14:15:31	2020-05-05	8	[{"id_menu":5,"count":1}]	19741	delivery	5	13
58754	2020-05-05 14:17:44	2020-05-05	12	[{"id_menu":3,"count":1}]	22090	delivery	5	17
58755	2020-05-05 14:19:20	2020-05-05	14	[{"id_menu":2,"count":1}]	20628	pick-up	0	14
58756	2020-05-05 14:22:17	2020-05-05	9	[{"id_menu":6,"count":1}]	7432	pick-up	0	9
58757	2020-05-05 14:24:09	2020-05-05	9	[{"id_menu":6,"count":1}]	15907	delivery	5	14
58758	2020-05-05 14:28:27	2020-05-05	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	23314	delivery	5	31
58759	2020-05-05 14:28:49	2020-05-05	12	[{"id_menu":1,"count":1}]	23003	delivery	5	17
58760	2020-05-05 14:29:11	2020-05-05	14	[{"id_menu":2,"count":1}]	2560	pick-up	0	14
58761	2020-05-05 14:41:23	2020-05-05	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	112	delivery	5	25
58762	2020-05-05 14:46:11	2020-05-05	9	[{"id_menu":6,"count":1}]	23297	delivery	5	14
58763	2020-05-05 14:51:50	2020-05-05	9	[{"id_menu":6,"count":1}]	3198	pick-up	0	9
58764	2020-05-05 15:01:08	2020-05-05	9	[{"id_menu":6,"count":1}]	1929	pick-up	0	9
58765	2020-05-05 15:03:14	2020-05-05	9	[{"id_menu":7,"count":1}]	23404	delivery	5	14
58766	2020-05-05 15:07:37	2020-05-05	14	[{"id_menu":2,"count":1}]	19660	delivery	5	19
58767	2020-05-05 15:09:49	2020-05-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14202	delivery	5	31
58768	2020-05-05 15:09:56	2020-05-05	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	12847	delivery	5	42
58769	2020-05-05 15:21:35	2020-05-05	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16610	delivery	5	22
58770	2020-05-05 15:25:12	2020-05-05	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	11893	delivery	5	31
58771	2020-05-05 15:27:58	2020-05-05	12	[{"id_menu":3,"count":1}]	14531	pick-up	0	12
58772	2020-05-05 15:34:48	2020-05-05	9	[{"id_menu":7,"count":1}]	11174	delivery	5	14
58773	2020-05-05 15:36:12	2020-05-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	23340	delivery	5	31
58774	2020-05-05 15:39:05	2020-05-05	12	[{"id_menu":1,"count":1}]	23349	pick-up	0	12
58775	2020-05-05 15:45:07	2020-05-05	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19220	delivery	5	39
58776	2020-05-05 15:47:50	2020-05-05	17	[{"id_menu":4,"count":1}]	1631	delivery	5	22
58777	2020-05-05 15:47:51	2020-05-05	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	14204	delivery	5	36
58778	2020-05-05 15:52:30	2020-05-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19132	delivery	5	22
58779	2020-05-05 15:55:39	2020-05-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	16367	delivery	5	28
58780	2020-05-05 16:08:50	2020-05-05	14	[{"id_menu":2,"count":1}]	16186	pick-up	0	14
58781	2020-05-05 16:11:46	2020-05-05	9	[{"id_menu":7,"count":1}]	9066	delivery	5	14
58782	2020-05-05 16:11:59	2020-05-05	9	[{"id_menu":6,"count":1}]	19554	delivery	5	14
58783	2020-05-05 16:17:10	2020-05-05	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	12416	delivery	5	26
58784	2020-05-05 16:18:44	2020-05-05	12	[{"id_menu":3,"count":1}]	23352	pick-up	0	12
58785	2020-05-05 16:19:07	2020-05-05	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21865	delivery	5	31
58786	2020-05-05 16:25:22	2020-05-05	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15269	delivery	5	34
58787	2020-05-05 16:26:14	2020-05-05	9	[{"id_menu":6,"count":1}]	23302	delivery	5	14
58788	2020-05-05 16:32:43	2020-05-05	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10957	delivery	5	31
58789	2020-05-05 16:40:20	2020-05-05	17	[{"id_menu":4,"count":1}]	15109	pick-up	0	17
58790	2020-05-05 17:05:52	2020-05-05	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	17056	pick-up	0	26
58791	2020-05-05 17:21:07	2020-05-05	14	[{"id_menu":2,"count":1}]	19212	pick-up	0	14
58792	2020-05-05 17:25:32	2020-05-05	9	[{"id_menu":7,"count":1}]	22861	delivery	5	14
58793	2020-05-05 17:28:13	2020-05-05	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	23324	delivery	5	42
58794	2020-05-05 17:36:26	2020-05-05	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12634	delivery	5	39
58795	2020-05-05 17:42:25	2020-05-05	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23353	delivery	5	22
58796	2020-05-05 17:44:44	2020-05-05	9	[{"id_menu":7,"count":1}]	20854	delivery	5	14
58797	2020-05-05 17:46:17	2020-05-05	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	21426	delivery	5	22
58798	2020-05-05 17:47:41	2020-05-05	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3820	pick-up	0	29
58799	2020-05-05 17:48:29	2020-05-05	9	[{"id_menu":6,"count":1}]	18816	delivery	5	14
58800	2020-05-05 17:53:17	2020-05-05	12	[{"id_menu":3,"count":1}]	3985	delivery	5	17
58801	2020-05-05 17:57:11	2020-05-05	8	[{"id_menu":5,"count":2}]	20511	delivery	5	13
58802	2020-05-05 18:01:10	2020-05-05	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	19623	delivery	5	43
58803	2020-05-05 18:02:24	2020-05-05	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	23401	delivery	5	31
58804	2020-05-05 18:10:17	2020-05-05	9	[{"id_menu":7,"count":1}]	13178	delivery	5	14
58805	2020-05-05 18:11:07	2020-05-05	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	22208	delivery	5	29
58806	2020-05-05 18:16:29	2020-05-05	38	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10551	pick-up	0	38
58807	2020-05-05 18:25:16	2020-05-05	12	[{"id_menu":1,"count":1}]	23365	delivery	5	17
58808	2020-05-05 18:30:59	2020-05-05	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	23358	delivery	5	45
58809	2020-05-05 18:35:47	2020-05-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23371	delivery	5	22
58810	2020-05-05 18:39:05	2020-05-05	9	[{"id_menu":7,"count":1}]	23295	delivery	5	14
58811	2020-05-05 18:39:20	2020-05-05	9	[{"id_menu":7,"count":1}]	23290	delivery	5	14
58812	2020-05-05 18:41:25	2020-05-05	9	[{"id_menu":7,"count":1}]	3578	pick-up	0	9
58813	2020-05-05 18:42:31	2020-05-05	9	[{"id_menu":7,"count":1}]	23329	delivery	5	14
58814	2020-05-05 18:45:55	2020-05-05	12	[{"id_menu":1,"count":1}]	23331	delivery	5	17
58815	2020-05-05 18:48:04	2020-05-05	9	[{"id_menu":7,"count":1}]	7129	delivery	5	14
58816	2020-05-05 18:51:42	2020-05-05	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	11050	pick-up	0	20
58817	2020-05-05 18:58:19	2020-05-05	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23326	delivery	5	39
58818	2020-05-05 19:01:50	2020-05-05	17	[{"id_menu":4,"count":1}]	81	pick-up	0	17
58819	2020-05-05 19:03:03	2020-05-05	8	[{"id_menu":5,"count":1}]	23305	delivery	5	13
58820	2020-05-05 19:03:21	2020-05-05	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	23360	pick-up	0	33
58821	2020-05-05 19:04:06	2020-05-05	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	6696	delivery	5	26
58822	2020-05-05 19:08:34	2020-05-05	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	23408	pick-up	0	31
58823	2020-05-05 19:13:27	2020-05-05	17	[{"id_menu":4,"count":1}]	9793	delivery	5	22
58824	2020-05-05 19:16:05	2020-05-05	9	[{"id_menu":6,"count":1}]	10908	delivery	5	14
58825	2020-05-05 19:22:47	2020-05-05	12	[{"id_menu":1,"count":1}]	21230	delivery	5	17
58826	2020-05-05 19:25:32	2020-05-05	17	[{"id_menu":4,"count":1}]	5736	pick-up	0	17
58827	2020-05-05 19:29:52	2020-05-05	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4321	delivery	5	44
58828	2020-05-05 19:31:37	2020-05-05	8	[{"id_menu":5,"count":1}]	23409	delivery	5	13
58829	2020-05-05 19:47:47	2020-05-05	12	[{"id_menu":3,"count":1}]	12205	pick-up	0	12
58830	2020-05-05 19:59:32	2020-05-05	17	[{"id_menu":4,"count":1}]	5931	delivery	5	22
58831	2020-05-05 19:59:55	2020-05-05	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10642	delivery	5	42
58832	2020-05-05 20:03:21	2020-05-05	14	[{"id_menu":2,"count":1}]	3241	delivery	5	19
58833	2020-05-05 20:12:49	2020-05-05	9	[{"id_menu":6,"count":1}]	2916	pick-up	0	9
58834	2020-05-05 20:16:53	2020-05-05	9	[{"id_menu":6,"count":1}]	23284	delivery	5	14
58835	2020-05-05 20:17:46	2020-05-05	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":2}]	12475	delivery	5	31
58836	2020-05-05 20:18:50	2020-05-05	9	[{"id_menu":6,"count":1}]	21762	delivery	5	14
58837	2020-05-05 20:19:53	2020-05-05	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	23307	delivery	5	36
58838	2020-05-05 20:20:57	2020-05-05	17	[{"id_menu":4,"count":1}]	17743	delivery	5	22
58839	2020-05-05 20:26:49	2020-05-05	12	[{"id_menu":1,"count":1}]	13529	pick-up	0	12
58840	2020-05-05 20:31:29	2020-05-05	8	[{"id_menu":5,"count":1}]	23312	pick-up	0	8
58841	2020-05-05 20:40:02	2020-05-05	14	[{"id_menu":2,"count":1}]	23396	delivery	5	19
58842	2020-05-05 20:41:43	2020-05-05	9	[{"id_menu":6,"count":1}]	23397	delivery	5	14
58843	2020-05-05 20:54:37	2020-05-05	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	23405	delivery	5	30
58844	2020-05-05 21:02:37	2020-05-05	14	[{"id_menu":2,"count":1}]	21666	delivery	5	19
58845	2020-05-05 21:04:06	2020-05-05	14	[{"id_menu":2,"count":1}]	13758	delivery	5	19
58846	2020-05-05 21:06:51	2020-05-05	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11985	delivery	5	35
58847	2020-05-05 21:24:20	2020-05-05	9	[{"id_menu":7,"count":1}]	3603	delivery	5	14
58848	2020-05-05 21:26:40	2020-05-05	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3324	delivery	5	31
58849	2020-05-05 21:27:28	2020-05-05	9	[{"id_menu":6,"count":1}]	23277	delivery	5	14
58850	2020-05-05 21:30:54	2020-05-05	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	23363	delivery	5	42
58851	2020-05-05 21:31:18	2020-05-05	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	6842	pick-up	0	21
58852	2020-05-05 21:34:03	2020-05-05	9	[{"id_menu":6,"count":1}]	9272	delivery	5	14
58853	2020-05-05 21:47:49	2020-05-05	8	[{"id_menu":5,"count":2}]	21331	delivery	5	13
58854	2020-05-05 21:53:54	2020-05-05	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	20407	delivery	5	28
58855	2020-05-05 21:54:15	2020-05-05	9	[{"id_menu":6,"count":1}]	18936	delivery	5	14
58856	2020-05-05 21:56:36	2020-05-05	9	[{"id_menu":7,"count":1}]	22949	delivery	5	14
58857	2020-05-05 21:59:32	2020-05-05	12	[{"id_menu":1,"count":1}]	10330	delivery	5	17
58858	2020-05-05 22:01:50	2020-05-05	14	[{"id_menu":2,"count":1}]	563	pick-up	0	14
58859	2020-05-05 22:01:53	2020-05-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11822	delivery	5	23
58860	2020-05-05 22:04:21	2020-05-05	12	[{"id_menu":1,"count":1}]	1000	delivery	5	17
58861	2020-05-05 22:05:15	2020-05-05	8	[{"id_menu":5,"count":2}]	23304	delivery	5	13
58862	2020-05-05 22:18:16	2020-05-05	8	[{"id_menu":5,"count":1}]	23429	delivery	5	13
58863	2020-05-05 22:21:17	2020-05-05	12	[{"id_menu":1,"count":1}]	23393	delivery	5	17
58864	2020-05-05 22:23:53	2020-05-05	9	[{"id_menu":6,"count":1}]	23399	pick-up	0	9
58865	2020-05-05 22:26:35	2020-05-05	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	10820	delivery	5	27
58866	2020-05-05 22:30:30	2020-05-05	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	18201	delivery	5	26
58867	2020-05-05 22:35:00	2020-05-05	9	[{"id_menu":6,"count":1}]	23359	delivery	5	14
58868	2020-05-05 22:44:58	2020-05-05	9	[{"id_menu":6,"count":1}]	7835	delivery	5	14
58869	2020-05-05 22:47:35	2020-05-05	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	15507	delivery	5	31
58870	2020-05-05 22:47:47	2020-05-05	9	[{"id_menu":6,"count":1}]	6129	delivery	5	14
58871	2020-05-05 22:52:52	2020-05-05	12	[{"id_menu":1,"count":1}]	1263	pick-up	0	12
58872	2020-05-05 22:55:30	2020-05-05	12	[{"id_menu":1,"count":1}]	2587	pick-up	0	12
58873	2020-05-05 23:06:43	2020-05-05	12	[{"id_menu":3,"count":1}]	22863	delivery	5	17
58874	2020-05-05 23:10:05	2020-05-05	38	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	21562	delivery	5	43
58875	2020-05-05 23:14:10	2020-05-05	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	7772	pick-up	0	22
58876	2020-05-05 23:23:20	2020-05-05	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	23311	delivery	5	36
58877	2020-05-05 23:24:23	2020-05-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4775	delivery	5	22
58878	2020-05-05 23:24:36	2020-05-05	17	[{"id_menu":4,"count":1}]	3180	delivery	5	22
58879	2020-05-05 23:30:24	2020-05-05	8	[{"id_menu":5,"count":1}]	23271	delivery	5	13
58880	2020-05-05 23:34:52	2020-05-05	12	[{"id_menu":1,"count":1}]	23362	delivery	5	17
58881	2020-05-05 23:42:15	2020-05-05	12	[{"id_menu":3,"count":1}]	2834	pick-up	0	12
58882	2020-05-05 23:49:30	2020-05-05	9	[{"id_menu":7,"count":1}]	13062	pick-up	0	9
58883	2020-05-05 23:50:51	2020-05-05	9	[{"id_menu":6,"count":2}]	16271	delivery	5	14
58884	2020-05-05 23:50:59	2020-05-05	9	[{"id_menu":7,"count":1}]	23266	pick-up	0	9
58885	2020-05-05 23:58:06	2020-05-05	9	[{"id_menu":7,"count":1}]	5973	delivery	5	14
58886	2020-05-05 23:59:48	2020-05-05	9	[{"id_menu":7,"count":1}]	22597	delivery	5	14
58887	2020-05-06 00:01:59	2020-05-06	17	[{"id_menu":4,"count":1}]	23511	delivery	5	22
58888	2020-05-06 00:03:22	2020-05-06	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	22511	delivery	5	23
58889	2020-05-06 00:06:01	2020-05-06	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	23533	delivery	5	26
58890	2020-05-06 00:13:16	2020-05-06	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23465	delivery	5	22
58891	2020-05-06 00:13:48	2020-05-06	14	[{"id_menu":2,"count":2}]	16591	delivery	5	19
58892	2020-05-06 00:15:02	2020-05-06	9	[{"id_menu":6,"count":1}]	23460	delivery	5	14
58893	2020-05-06 00:20:55	2020-05-06	9	[{"id_menu":6,"count":1}]	13673	delivery	5	14
58894	2020-05-06 00:23:00	2020-05-06	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	23036	delivery	5	26
58895	2020-05-06 00:23:03	2020-05-06	8	[{"id_menu":5,"count":1}]	9714	pick-up	0	8
58896	2020-05-06 00:27:25	2020-05-06	9	[{"id_menu":7,"count":1}]	2675	delivery	5	14
58897	2020-05-06 00:27:40	2020-05-06	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	23461	pick-up	0	22
58898	2020-05-06 00:28:57	2020-05-06	14	[{"id_menu":2,"count":1}]	23564	delivery	5	19
58899	2020-05-06 00:30:46	2020-05-06	14	[{"id_menu":2,"count":1}]	1387	pick-up	0	14
58900	2020-05-06 00:31:46	2020-05-06	9	[{"id_menu":7,"count":2}]	15606	delivery	5	14
58901	2020-05-06 00:35:54	2020-05-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4624	pick-up	0	23
58902	2020-05-06 00:40:02	2020-05-06	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	755	pick-up	0	18
58903	2020-05-06 00:40:27	2020-05-06	14	[{"id_menu":2,"count":3}]	23537	delivery	5	19
58904	2020-05-06 00:40:42	2020-05-06	9	[{"id_menu":7,"count":1}]	23508	delivery	5	14
58905	2020-05-06 00:46:39	2020-05-06	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2429	delivery	5	23
58906	2020-05-06 00:50:13	2020-05-06	9	[{"id_menu":6,"count":1}]	23432	pick-up	0	9
58907	2020-05-06 00:50:25	2020-05-06	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	23482	delivery	5	28
58908	2020-05-06 00:58:57	2020-05-06	12	[{"id_menu":1,"count":1}]	328	delivery	5	17
58909	2020-05-06 00:59:58	2020-05-06	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23560	delivery	5	46
58910	2020-05-06 01:01:00	2020-05-06	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3330	pick-up	0	25
58911	2020-05-06 01:09:47	2020-05-06	9	[{"id_menu":6,"count":1}]	17628	delivery	5	14
58912	2020-05-06 01:14:35	2020-05-06	9	[{"id_menu":7,"count":1}]	23507	delivery	5	14
58913	2020-05-06 01:17:00	2020-05-06	9	[{"id_menu":7,"count":1}]	7025	delivery	5	14
58914	2020-05-06 01:17:08	2020-05-06	8	[{"id_menu":5,"count":1}]	23559	delivery	5	13
58915	2020-05-06 01:21:26	2020-05-06	9	[{"id_menu":7,"count":1}]	22369	delivery	5	14
58916	2020-05-06 01:22:02	2020-05-06	9	[{"id_menu":6,"count":1}]	23583	delivery	5	14
58917	2020-05-06 01:22:48	2020-05-06	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	23452	delivery	5	28
58918	2020-05-06 01:23:45	2020-05-06	14	[{"id_menu":2,"count":1}]	931	pick-up	0	14
58919	2020-05-06 01:31:25	2020-05-06	8	[{"id_menu":5,"count":1}]	11480	delivery	5	13
58920	2020-05-06 01:31:29	2020-05-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	23438	delivery	5	28
58921	2020-05-06 01:39:12	2020-05-06	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	484	pick-up	0	26
58922	2020-05-06 01:45:10	2020-05-06	17	[{"id_menu":4,"count":1}]	5822	delivery	5	22
58923	2020-05-06 01:48:43	2020-05-06	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12476	delivery	5	43
58924	2020-05-06 01:52:46	2020-05-06	12	[{"id_menu":3,"count":1}]	23531	pick-up	0	12
58925	2020-05-06 01:57:46	2020-05-06	12	[{"id_menu":3,"count":1}]	23505	delivery	5	17
58926	2020-05-06 02:01:20	2020-05-06	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	23487	delivery	5	28
58927	2020-05-06 02:02:10	2020-05-06	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23573	delivery	5	37
58928	2020-05-06 02:06:19	2020-05-06	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23441	delivery	5	52
58929	2020-05-06 02:12:31	2020-05-06	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	21183	delivery	5	22
58930	2020-05-06 02:13:55	2020-05-06	12	[{"id_menu":3,"count":1}]	23434	delivery	5	17
58931	2020-05-06 02:24:21	2020-05-06	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	23574	delivery	5	48
58932	2020-05-06 02:26:19	2020-05-06	12	[{"id_menu":1,"count":1}]	19256	pick-up	0	12
58933	2020-05-06 02:29:44	2020-05-06	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5866	pick-up	0	17
58934	2020-05-06 02:29:46	2020-05-06	17	[{"id_menu":4,"count":1}]	9356	delivery	5	22
58935	2020-05-06 02:37:33	2020-05-06	9	[{"id_menu":7,"count":1}]	23459	delivery	5	14
58936	2020-05-06 02:45:28	2020-05-06	8	[{"id_menu":5,"count":1}]	5508	delivery	5	13
58937	2020-05-06 02:51:00	2020-05-06	14	[{"id_menu":2,"count":1}]	1785	pick-up	0	14
58938	2020-05-06 02:51:42	2020-05-06	17	[{"id_menu":4,"count":1}]	22758	pick-up	0	17
58939	2020-05-06 02:53:51	2020-05-06	8	[{"id_menu":5,"count":1}]	10389	pick-up	0	8
58940	2020-05-06 02:53:55	2020-05-06	9	[{"id_menu":6,"count":1}]	17196	delivery	5	14
58941	2020-05-06 02:58:11	2020-05-06	12	[{"id_menu":3,"count":1}]	522	pick-up	0	12
58942	2020-05-06 03:05:27	2020-05-06	14	[{"id_menu":2,"count":2}]	23581	pick-up	0	14
58943	2020-05-06 03:08:17	2020-05-06	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	23578	delivery	5	26
58944	2020-05-06 03:08:43	2020-05-06	9	[{"id_menu":6,"count":1}]	3812	pick-up	0	9
58945	2020-05-06 03:16:14	2020-05-06	12	[{"id_menu":1,"count":1}]	3848	pick-up	0	12
58946	2020-05-06 03:19:39	2020-05-06	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	23431	delivery	5	31
58947	2020-05-06 03:21:15	2020-05-06	14	[{"id_menu":2,"count":1}]	9644	delivery	5	19
58948	2020-05-06 03:27:41	2020-05-06	17	[{"id_menu":4,"count":1}]	8632	delivery	5	22
58949	2020-05-06 03:35:00	2020-05-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	23457	delivery	5	28
58950	2020-05-06 03:35:56	2020-05-06	8	[{"id_menu":5,"count":1}]	23476	pick-up	0	8
58951	2020-05-06 03:37:55	2020-05-06	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	17038	delivery	5	26
58952	2020-05-06 03:43:35	2020-05-06	12	[{"id_menu":3,"count":1}]	23483	delivery	5	17
58953	2020-05-06 03:45:49	2020-05-06	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13422	delivery	5	31
58954	2020-05-06 03:46:23	2020-05-06	17	[{"id_menu":4,"count":1}]	8305	delivery	5	22
58955	2020-05-06 03:50:06	2020-05-06	12	[{"id_menu":1,"count":1}]	15390	delivery	5	17
58956	2020-05-06 03:54:48	2020-05-06	17	[{"id_menu":4,"count":1}]	23455	delivery	5	22
58957	2020-05-06 04:01:24	2020-05-06	8	[{"id_menu":5,"count":1}]	23502	delivery	5	13
58958	2020-05-06 04:04:15	2020-05-06	9	[{"id_menu":6,"count":2}]	14484	delivery	5	14
58959	2020-05-06 04:16:30	2020-05-06	17	[{"id_menu":4,"count":1}]	71	delivery	5	22
58960	2020-05-06 04:21:26	2020-05-06	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	6326	delivery	5	26
58961	2020-05-06 04:24:48	2020-05-06	12	[{"id_menu":3,"count":1}]	1627	pick-up	0	12
58962	2020-05-06 04:32:26	2020-05-06	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	23446	delivery	5	26
58963	2020-05-06 04:34:35	2020-05-06	9	[{"id_menu":7,"count":1}]	8149	delivery	5	14
58964	2020-05-06 04:36:43	2020-05-06	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17504	delivery	5	23
58965	2020-05-06 04:43:22	2020-05-06	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	3224	pick-up	0	21
58966	2020-05-06 04:46:45	2020-05-06	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	563	pick-up	0	24
58967	2020-05-06 04:48:29	2020-05-06	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	14672	delivery	5	28
58968	2020-05-06 04:57:52	2020-05-06	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16652	delivery	5	31
58969	2020-05-06 04:58:40	2020-05-06	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8298	pick-up	0	18
58970	2020-05-06 05:00:33	2020-05-06	9	[{"id_menu":7,"count":1}]	7923	delivery	5	14
58971	2020-05-06 05:00:51	2020-05-06	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	15502	delivery	5	26
58972	2020-05-06 05:09:38	2020-05-06	14	[{"id_menu":2,"count":1}]	13634	delivery	5	19
58973	2020-05-06 05:10:11	2020-05-06	9	[{"id_menu":6,"count":1}]	81	pick-up	0	9
58974	2020-05-06 05:15:16	2020-05-06	12	[{"id_menu":3,"count":1}]	4411	pick-up	0	12
58975	2020-05-06 05:17:32	2020-05-06	8	[{"id_menu":5,"count":1}]	15309	pick-up	0	8
58976	2020-05-06 05:19:24	2020-05-06	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	16405	delivery	5	34
58977	2020-05-06 05:21:05	2020-05-06	12	[{"id_menu":3,"count":1}]	8629	pick-up	0	12
58978	2020-05-06 05:30:57	2020-05-06	12	[{"id_menu":1,"count":1}]	9420	pick-up	0	12
58979	2020-05-06 05:34:28	2020-05-06	8	[{"id_menu":5,"count":1}]	5608	pick-up	0	8
58980	2020-05-06 05:39:05	2020-05-06	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	6894	delivery	5	26
58981	2020-05-06 05:40:48	2020-05-06	17	[{"id_menu":4,"count":1}]	23494	delivery	5	22
58982	2020-05-06 05:41:03	2020-05-06	9	[{"id_menu":7,"count":2}]	3294	delivery	5	14
58983	2020-05-06 05:41:11	2020-05-06	14	[{"id_menu":2,"count":1}]	1879	pick-up	0	14
58984	2020-05-06 05:42:28	2020-05-06	12	[{"id_menu":3,"count":1}]	16755	delivery	5	17
58985	2020-05-06 05:51:27	2020-05-06	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17600	delivery	5	39
58986	2020-05-06 05:51:53	2020-05-06	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1140	pick-up	0	17
58987	2020-05-06 05:53:29	2020-05-06	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	21390	pick-up	0	35
58988	2020-05-06 05:53:40	2020-05-06	9	[{"id_menu":6,"count":1}]	20956	delivery	5	14
58989	2020-05-06 06:02:25	2020-05-06	14	[{"id_menu":2,"count":1}]	1684	pick-up	0	14
58990	2020-05-06 06:06:30	2020-05-06	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	23481	delivery	5	22
58991	2020-05-06 06:06:51	2020-05-06	9	[{"id_menu":7,"count":1}]	8265	delivery	5	14
58992	2020-05-06 06:09:28	2020-05-06	14	[{"id_menu":2,"count":1}]	14198	delivery	5	19
58993	2020-05-06 06:15:29	2020-05-06	12	[{"id_menu":3,"count":1}]	23540	delivery	5	17
58994	2020-05-06 06:32:32	2020-05-06	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	23498	delivery	5	28
58995	2020-05-06 06:40:34	2020-05-06	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13758	delivery	5	22
58996	2020-05-06 06:42:12	2020-05-06	12	[{"id_menu":3,"count":1}]	8251	delivery	5	17
58997	2020-05-06 06:45:01	2020-05-06	12	[{"id_menu":1,"count":1}]	7638	delivery	5	17
58998	2020-05-06 06:48:29	2020-05-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4303	pick-up	0	23
58999	2020-05-06 06:48:43	2020-05-06	9	[{"id_menu":7,"count":1}]	23462	delivery	5	14
59000	2020-05-06 06:57:51	2020-05-06	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1770	delivery	5	35
59001	2020-05-06 06:57:52	2020-05-06	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5478	pick-up	0	52
59002	2020-05-06 07:12:04	2020-05-06	12	[{"id_menu":3,"count":1}]	16686	delivery	5	17
59003	2020-05-06 07:12:36	2020-05-06	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23493	delivery	5	43
59004	2020-05-06 07:13:00	2020-05-06	9	[{"id_menu":7,"count":1}]	8282	delivery	5	14
59005	2020-05-06 07:13:09	2020-05-06	9	[{"id_menu":6,"count":2}]	7269	delivery	5	14
59006	2020-05-06 07:13:10	2020-05-06	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12132	delivery	5	22
59007	2020-05-06 07:18:05	2020-05-06	14	[{"id_menu":2,"count":1}]	23526	delivery	5	19
59008	2020-05-06 07:27:27	2020-05-06	12	[{"id_menu":3,"count":1}]	16603	delivery	5	17
59009	2020-05-06 07:27:31	2020-05-06	9	[{"id_menu":7,"count":1}]	23445	delivery	5	14
59010	2020-05-06 07:28:55	2020-05-06	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5619	delivery	5	45
59011	2020-05-06 07:30:44	2020-05-06	14	[{"id_menu":2,"count":1}]	4131	delivery	5	19
59012	2020-05-06 07:31:11	2020-05-06	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	23467	delivery	5	27
59013	2020-05-06 07:33:59	2020-05-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	23557	delivery	5	28
59014	2020-05-06 07:35:11	2020-05-06	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1457	delivery	5	28
59015	2020-05-06 07:40:13	2020-05-06	9	[{"id_menu":7,"count":1}]	1104	pick-up	0	9
59016	2020-05-06 07:40:22	2020-05-06	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23552	delivery	5	36
59017	2020-05-06 07:44:56	2020-05-06	8	[{"id_menu":5,"count":1}]	23532	pick-up	0	8
59018	2020-05-06 07:53:40	2020-05-06	8	[{"id_menu":5,"count":1}]	8401	delivery	5	13
59019	2020-05-06 08:15:23	2020-05-06	17	[{"id_menu":4,"count":1}]	23550	delivery	5	22
59020	2020-05-06 08:18:43	2020-05-06	12	[{"id_menu":1,"count":1}]	13010	delivery	5	17
59021	2020-05-06 08:19:32	2020-05-06	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	6664	delivery	5	31
59022	2020-05-06 08:24:35	2020-05-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	8008	delivery	5	28
59023	2020-05-06 08:25:19	2020-05-06	17	[{"id_menu":4,"count":1}]	23569	delivery	5	22
59024	2020-05-06 08:25:43	2020-05-06	9	[{"id_menu":6,"count":1}]	19147	delivery	5	14
59025	2020-05-06 08:28:16	2020-05-06	17	[{"id_menu":4,"count":1}]	11630	delivery	5	22
59026	2020-05-06 08:31:29	2020-05-06	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	10479	pick-up	0	22
59027	2020-05-06 08:39:16	2020-05-06	14	[{"id_menu":2,"count":1}]	4414	pick-up	0	14
59028	2020-05-06 08:40:40	2020-05-06	9	[{"id_menu":6,"count":1}]	23518	delivery	5	14
59029	2020-05-06 08:41:19	2020-05-06	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15776	delivery	5	34
59030	2020-05-06 08:43:59	2020-05-06	12	[{"id_menu":1,"count":1}]	22982	delivery	5	17
59031	2020-05-06 08:44:08	2020-05-06	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	16359	delivery	5	25
59032	2020-05-06 08:46:21	2020-05-06	9	[{"id_menu":6,"count":1}]	10696	delivery	5	14
59033	2020-05-06 08:50:15	2020-05-06	9	[{"id_menu":6,"count":1}]	23512	delivery	5	14
59034	2020-05-06 08:56:22	2020-05-06	9	[{"id_menu":6,"count":1}]	691	pick-up	0	9
59035	2020-05-06 08:57:01	2020-05-06	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	23466	delivery	5	28
59036	2020-05-06 08:59:20	2020-05-06	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	2498	delivery	5	28
59037	2020-05-06 09:00:09	2020-05-06	9	[{"id_menu":6,"count":2}]	9258	delivery	5	14
59038	2020-05-06 09:00:53	2020-05-06	17	[{"id_menu":4,"count":1}]	23473	delivery	5	22
59039	2020-05-06 09:01:53	2020-05-06	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2590	delivery	5	31
59040	2020-05-06 09:08:13	2020-05-06	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19157	delivery	5	34
59041	2020-05-06 09:09:20	2020-05-06	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	10474	delivery	5	26
59042	2020-05-06 09:11:35	2020-05-06	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2715	pick-up	0	22
59043	2020-05-06 09:14:18	2020-05-06	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2482	pick-up	0	18
59044	2020-05-06 09:14:52	2020-05-06	9	[{"id_menu":7,"count":1}]	21961	pick-up	0	9
59045	2020-05-06 09:25:08	2020-05-06	49	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10757	delivery	5	54
59046	2020-05-06 09:32:22	2020-05-06	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21338	delivery	5	43
59047	2020-05-06 09:32:43	2020-05-06	17	[{"id_menu":4,"count":1}]	8088	delivery	5	22
59048	2020-05-06 09:44:46	2020-05-06	14	[{"id_menu":2,"count":1}]	23522	delivery	5	19
59049	2020-05-06 09:47:10	2020-05-06	9	[{"id_menu":7,"count":1}]	10393	delivery	5	14
59050	2020-05-06 09:49:06	2020-05-06	12	[{"id_menu":3,"count":1}]	7247	pick-up	0	12
59051	2020-05-06 09:50:39	2020-05-06	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6451	pick-up	0	29
59052	2020-05-06 09:56:39	2020-05-06	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5811	delivery	5	30
59053	2020-05-06 10:01:42	2020-05-06	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19313	pick-up	0	18
59054	2020-05-06 10:07:02	2020-05-06	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	21747	delivery	5	26
59055	2020-05-06 10:16:42	2020-05-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	23451	delivery	5	28
59056	2020-05-06 10:18:19	2020-05-06	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	23470	delivery	5	38
59057	2020-05-06 10:18:24	2020-05-06	9	[{"id_menu":7,"count":1}]	10234	delivery	5	14
59058	2020-05-06 10:25:41	2020-05-06	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	23544	delivery	5	48
59059	2020-05-06 10:30:43	2020-05-06	9	[{"id_menu":7,"count":1}]	9164	delivery	5	14
59060	2020-05-06 10:38:56	2020-05-06	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	3478	pick-up	0	20
59061	2020-05-06 10:46:14	2020-05-06	9	[{"id_menu":7,"count":1}]	12990	pick-up	0	9
59062	2020-05-06 10:46:22	2020-05-06	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8421	delivery	5	28
59063	2020-05-06 10:46:57	2020-05-06	8	[{"id_menu":5,"count":1}]	16188	delivery	5	13
59064	2020-05-06 10:48:24	2020-05-06	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	23443	delivery	5	45
59065	2020-05-06 10:49:48	2020-05-06	9	[{"id_menu":6,"count":2}]	18623	delivery	5	14
59066	2020-05-06 10:55:21	2020-05-06	9	[{"id_menu":6,"count":1}]	21925	delivery	5	14
59067	2020-05-06 10:57:59	2020-05-06	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	14715	delivery	5	40
59068	2020-05-06 11:02:01	2020-05-06	9	[{"id_menu":7,"count":1}]	8473	delivery	5	14
59069	2020-05-06 11:03:55	2020-05-06	14	[{"id_menu":2,"count":1}]	5056	delivery	5	19
59070	2020-05-06 11:06:25	2020-05-06	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	12418	delivery	5	46
59071	2020-05-06 11:10:05	2020-05-06	12	[{"id_menu":1,"count":1}]	23514	delivery	5	17
59072	2020-05-06 11:14:44	2020-05-06	9	[{"id_menu":6,"count":1}]	9192	delivery	5	14
59073	2020-05-06 11:15:22	2020-05-06	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23497	delivery	5	23
59074	2020-05-06 11:16:42	2020-05-06	9	[{"id_menu":7,"count":1}]	9766	delivery	5	14
59075	2020-05-06 11:22:20	2020-05-06	8	[{"id_menu":5,"count":1}]	4342	delivery	5	13
59076	2020-05-06 11:22:47	2020-05-06	17	[{"id_menu":4,"count":1}]	14427	delivery	5	22
59077	2020-05-06 11:26:13	2020-05-06	14	[{"id_menu":2,"count":1}]	1657	delivery	5	19
59078	2020-05-06 11:29:50	2020-05-06	17	[{"id_menu":4,"count":1}]	23551	delivery	5	22
59079	2020-05-06 11:40:26	2020-05-06	9	[{"id_menu":7,"count":1}]	3098	pick-up	0	9
59080	2020-05-06 11:40:41	2020-05-06	9	[{"id_menu":7,"count":1}]	19178	delivery	5	14
59081	2020-05-06 11:43:48	2020-05-06	8	[{"id_menu":5,"count":1}]	3518	delivery	5	13
59082	2020-05-06 11:45:07	2020-05-06	12	[{"id_menu":3,"count":1}]	3173	delivery	5	17
59083	2020-05-06 11:46:05	2020-05-06	17	[{"id_menu":4,"count":1}]	23545	delivery	5	22
59084	2020-05-06 11:47:37	2020-05-06	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	19448	delivery	5	28
59085	2020-05-06 11:51:50	2020-05-06	14	[{"id_menu":2,"count":1}]	4874	delivery	5	19
59086	2020-05-06 11:52:47	2020-05-06	12	[{"id_menu":3,"count":1}]	23563	delivery	5	17
59087	2020-05-06 11:52:54	2020-05-06	9	[{"id_menu":6,"count":1}]	23576	delivery	5	14
59088	2020-05-06 11:53:31	2020-05-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	11667	delivery	5	28
59089	2020-05-06 11:54:57	2020-05-06	9	[{"id_menu":6,"count":1}]	7361	pick-up	0	9
59090	2020-05-06 11:57:22	2020-05-06	9	[{"id_menu":6,"count":1}]	23548	delivery	5	14
59091	2020-05-06 11:57:32	2020-05-06	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9986	delivery	5	43
59092	2020-05-06 12:01:50	2020-05-06	9	[{"id_menu":7,"count":1}]	23437	delivery	5	14
59093	2020-05-06 12:03:23	2020-05-06	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	23503	delivery	5	44
59094	2020-05-06 12:04:15	2020-05-06	12	[{"id_menu":1,"count":2}]	17148	delivery	5	17
59095	2020-05-06 12:04:58	2020-05-06	12	[{"id_menu":3,"count":1}]	1720	pick-up	0	12
59096	2020-05-06 12:08:59	2020-05-06	12	[{"id_menu":1,"count":1}]	3666	delivery	5	17
59097	2020-05-06 12:11:10	2020-05-06	9	[{"id_menu":7,"count":1}]	21184	delivery	5	14
59098	2020-05-06 12:14:34	2020-05-06	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	7593	delivery	5	31
59099	2020-05-06 12:14:52	2020-05-06	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3940	pick-up	0	38
59100	2020-05-06 12:15:04	2020-05-06	9	[{"id_menu":6,"count":1}]	23579	delivery	5	14
59101	2020-05-06 12:22:56	2020-05-06	14	[{"id_menu":2,"count":1}]	15796	delivery	5	19
59102	2020-05-06 12:25:01	2020-05-06	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	170	pick-up	0	40
59103	2020-05-06 12:26:30	2020-05-06	14	[{"id_menu":2,"count":1}]	21034	pick-up	0	14
59104	2020-05-06 12:27:58	2020-05-06	17	[{"id_menu":4,"count":1}]	878	pick-up	0	17
59105	2020-05-06 12:31:30	2020-05-06	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	5720	delivery	5	38
59106	2020-05-06 12:36:05	2020-05-06	9	[{"id_menu":6,"count":1}]	6413	delivery	5	14
59107	2020-05-06 12:37:19	2020-05-06	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	18468	delivery	5	31
59108	2020-05-06 12:43:18	2020-05-06	14	[{"id_menu":2,"count":1}]	17569	delivery	5	19
59109	2020-05-06 12:45:11	2020-05-06	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	14740	delivery	5	31
59110	2020-05-06 12:45:30	2020-05-06	9	[{"id_menu":7,"count":2}]	23521	pick-up	0	9
59111	2020-05-06 12:47:40	2020-05-06	14	[{"id_menu":2,"count":1}]	9585	delivery	5	19
59112	2020-05-06 12:48:48	2020-05-06	17	[{"id_menu":4,"count":1}]	23523	delivery	5	22
59113	2020-05-06 12:51:05	2020-05-06	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	10664	delivery	5	34
59114	2020-05-06 12:56:00	2020-05-06	12	[{"id_menu":3,"count":1}]	17380	delivery	5	17
59115	2020-05-06 12:57:31	2020-05-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	23525	delivery	5	28
59116	2020-05-06 12:58:01	2020-05-06	17	[{"id_menu":4,"count":1}]	23440	pick-up	0	17
59117	2020-05-06 13:01:00	2020-05-06	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	11756	delivery	5	27
59118	2020-05-06 13:04:06	2020-05-06	12	[{"id_menu":1,"count":2}]	14027	pick-up	0	12
59119	2020-05-06 13:07:34	2020-05-06	9	[{"id_menu":6,"count":1}]	2787	delivery	5	14
59120	2020-05-06 13:11:48	2020-05-06	9	[{"id_menu":6,"count":1}]	10539	delivery	5	14
59121	2020-05-06 13:17:38	2020-05-06	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	23536	delivery	5	31
59122	2020-05-06 13:18:35	2020-05-06	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	14559	delivery	5	36
59123	2020-05-06 13:29:02	2020-05-06	9	[{"id_menu":7,"count":1}]	13636	delivery	5	14
59124	2020-05-06 13:30:04	2020-05-06	8	[{"id_menu":5,"count":1}]	23454	delivery	5	13
59125	2020-05-06 13:32:55	2020-05-06	17	[{"id_menu":4,"count":1}]	19181	delivery	5	22
59126	2020-05-06 13:33:10	2020-05-06	14	[{"id_menu":2,"count":1}]	372	pick-up	0	14
59127	2020-05-06 13:41:11	2020-05-06	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	23571	pick-up	0	21
59128	2020-05-06 13:55:08	2020-05-06	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10314	delivery	5	44
59129	2020-05-06 14:01:48	2020-05-06	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	12078	delivery	5	27
59130	2020-05-06 14:03:04	2020-05-06	17	[{"id_menu":4,"count":1}]	11840	delivery	5	22
59131	2020-05-06 14:03:54	2020-05-06	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	14433	delivery	5	22
59132	2020-05-06 14:13:12	2020-05-06	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	23524	delivery	5	25
59133	2020-05-06 14:22:52	2020-05-06	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21675	delivery	5	39
59134	2020-05-06 14:25:21	2020-05-06	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	23334	delivery	5	27
59135	2020-05-06 14:26:31	2020-05-06	12	[{"id_menu":3,"count":1}]	1489	delivery	5	17
59136	2020-05-06 14:28:17	2020-05-06	8	[{"id_menu":5,"count":1}]	6037	pick-up	0	8
59137	2020-05-06 14:31:47	2020-05-06	9	[{"id_menu":7,"count":2}]	23535	delivery	5	14
59138	2020-05-06 14:36:55	2020-05-06	9	[{"id_menu":6,"count":2}]	23471	delivery	5	14
59139	2020-05-06 14:38:35	2020-05-06	9	[{"id_menu":6,"count":1}]	2443	pick-up	0	9
59140	2020-05-06 14:40:37	2020-05-06	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	23554	delivery	5	31
59141	2020-05-06 14:41:42	2020-05-06	17	[{"id_menu":4,"count":1}]	6659	delivery	5	22
59142	2020-05-06 14:43:30	2020-05-06	12	[{"id_menu":1,"count":1}]	14139	pick-up	0	12
59143	2020-05-06 14:50:13	2020-05-06	17	[{"id_menu":4,"count":1}]	23585	pick-up	0	17
59144	2020-05-06 14:54:39	2020-05-06	14	[{"id_menu":2,"count":1}]	23469	delivery	5	19
59145	2020-05-06 14:56:46	2020-05-06	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5184	delivery	5	36
59146	2020-05-06 14:57:14	2020-05-06	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12946	delivery	5	31
59147	2020-05-06 15:00:13	2020-05-06	9	[{"id_menu":6,"count":1}]	23499	delivery	5	14
59148	2020-05-06 15:04:29	2020-05-06	9	[{"id_menu":6,"count":1}]	23447	delivery	5	14
59149	2020-05-06 15:07:13	2020-05-06	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	23539	delivery	5	31
59150	2020-05-06 15:10:33	2020-05-06	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	22429	delivery	5	40
59151	2020-05-06 15:12:38	2020-05-06	20	[{"id_menu":1,"count":3},{"id_menu":5,"count":1}]	23530	delivery	5	25
59152	2020-05-06 15:17:53	2020-05-06	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23510	delivery	5	23
59153	2020-05-06 15:31:42	2020-05-06	8	[{"id_menu":5,"count":1}]	12942	delivery	5	13
59154	2020-05-06 15:35:13	2020-05-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2470	pick-up	0	23
59155	2020-05-06 15:36:22	2020-05-06	12	[{"id_menu":3,"count":1}]	13068	pick-up	0	12
59156	2020-05-06 15:42:34	2020-05-06	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	23496	delivery	5	44
59157	2020-05-06 15:42:55	2020-05-06	12	[{"id_menu":1,"count":1}]	23561	pick-up	0	12
59158	2020-05-06 15:44:24	2020-05-06	14	[{"id_menu":2,"count":1}]	23449	delivery	5	19
59159	2020-05-06 15:55:41	2020-05-06	14	[{"id_menu":2,"count":1}]	23527	delivery	5	19
59160	2020-05-06 15:56:30	2020-05-06	17	[{"id_menu":4,"count":1}]	23516	pick-up	0	17
59161	2020-05-06 16:00:02	2020-05-06	8	[{"id_menu":5,"count":1}]	23504	delivery	5	13
59162	2020-05-06 16:00:04	2020-05-06	9	[{"id_menu":7,"count":1}]	17152	delivery	5	14
59163	2020-05-06 16:00:40	2020-05-06	12	[{"id_menu":1,"count":1}]	23556	delivery	5	17
59164	2020-05-06 16:03:28	2020-05-06	14	[{"id_menu":2,"count":1}]	11431	delivery	5	19
59165	2020-05-06 16:06:34	2020-05-06	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	23580	delivery	5	34
59166	2020-05-06 16:07:20	2020-05-06	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21631	delivery	5	39
59167	2020-05-06 16:28:17	2020-05-06	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	13114	delivery	5	34
59168	2020-05-06 16:28:19	2020-05-06	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	5491	pick-up	0	21
59169	2020-05-06 16:46:32	2020-05-06	9	[{"id_menu":6,"count":1}]	23570	delivery	5	14
59170	2020-05-06 16:50:08	2020-05-06	9	[{"id_menu":6,"count":1}]	12263	delivery	5	14
59171	2020-05-06 16:50:51	2020-05-06	14	[{"id_menu":2,"count":1}]	21682	delivery	5	19
59172	2020-05-06 16:52:12	2020-05-06	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2849	pick-up	0	26
59173	2020-05-06 16:55:19	2020-05-06	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	15481	delivery	5	44
59174	2020-05-06 16:55:50	2020-05-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":3}]	13827	delivery	5	28
59175	2020-05-06 16:59:31	2020-05-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	23501	delivery	5	28
59176	2020-05-06 16:59:36	2020-05-06	9	[{"id_menu":7,"count":1}]	15961	pick-up	0	9
59177	2020-05-06 17:00:44	2020-05-06	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5180	delivery	5	56
59178	2020-05-06 17:01:38	2020-05-06	17	[{"id_menu":4,"count":1}]	7190	pick-up	0	17
59179	2020-05-06 17:08:32	2020-05-06	9	[{"id_menu":7,"count":1}]	9021	delivery	5	14
59180	2020-05-06 17:09:09	2020-05-06	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	946	pick-up	0	24
59181	2020-05-06 17:21:19	2020-05-06	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23464	delivery	5	39
59182	2020-05-06 17:24:52	2020-05-06	14	[{"id_menu":2,"count":1}]	18312	delivery	5	19
59183	2020-05-06 17:27:11	2020-05-06	12	[{"id_menu":3,"count":1}]	853	pick-up	0	12
59184	2020-05-06 17:27:25	2020-05-06	8	[{"id_menu":5,"count":1}]	23568	delivery	5	13
59185	2020-05-06 17:28:04	2020-05-06	9	[{"id_menu":7,"count":1}]	19602	delivery	5	14
59186	2020-05-06 17:31:42	2020-05-06	9	[{"id_menu":7,"count":1}]	10209	pick-up	0	9
59187	2020-05-06 17:33:23	2020-05-06	8	[{"id_menu":5,"count":1}]	6491	delivery	5	13
59188	2020-05-06 17:34:32	2020-05-06	9	[{"id_menu":6,"count":1}]	23439	delivery	5	14
59189	2020-05-06 17:43:33	2020-05-06	9	[{"id_menu":6,"count":1}]	23562	delivery	5	14
59190	2020-05-06 17:45:17	2020-05-06	12	[{"id_menu":3,"count":1}]	7924	delivery	5	17
59191	2020-05-06 17:48:23	2020-05-06	9	[{"id_menu":6,"count":1}]	23513	delivery	5	14
59192	2020-05-06 17:52:17	2020-05-06	9	[{"id_menu":6,"count":1}]	23492	delivery	5	14
59193	2020-05-06 18:00:24	2020-05-06	14	[{"id_menu":2,"count":1}]	7316	delivery	5	19
59194	2020-05-06 18:01:25	2020-05-06	12	[{"id_menu":3,"count":1}]	13762	pick-up	0	12
59195	2020-05-06 18:02:19	2020-05-06	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	15732	pick-up	0	34
59196	2020-05-06 18:14:27	2020-05-06	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14088	delivery	5	39
59197	2020-05-06 18:18:37	2020-05-06	9	[{"id_menu":7,"count":1}]	10369	delivery	5	14
59198	2020-05-06 18:19:28	2020-05-06	9	[{"id_menu":6,"count":1}]	15659	delivery	5	14
59199	2020-05-06 18:27:46	2020-05-06	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2770	delivery	5	26
59200	2020-05-06 18:32:16	2020-05-06	9	[{"id_menu":6,"count":1}]	5945	pick-up	0	9
59201	2020-05-06 18:35:27	2020-05-06	9	[{"id_menu":6,"count":1}]	19459	delivery	5	14
59202	2020-05-06 18:35:32	2020-05-06	14	[{"id_menu":2,"count":1}]	22417	delivery	5	19
59203	2020-05-06 18:38:32	2020-05-06	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	4211	delivery	5	37
59204	2020-05-06 18:43:09	2020-05-06	12	[{"id_menu":3,"count":2}]	11635	delivery	5	17
59205	2020-05-06 18:44:18	2020-05-06	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	23488	delivery	5	26
59206	2020-05-06 18:44:43	2020-05-06	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	23549	delivery	5	31
59207	2020-05-06 18:45:52	2020-05-06	9	[{"id_menu":7,"count":1}]	23542	delivery	5	14
59208	2020-05-06 18:50:40	2020-05-06	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	14454	delivery	5	56
59209	2020-05-06 18:55:15	2020-05-06	17	[{"id_menu":4,"count":1}]	23566	delivery	5	22
59210	2020-05-06 18:58:29	2020-05-06	14	[{"id_menu":2,"count":1}]	19994	delivery	5	19
59211	2020-05-06 19:05:49	2020-05-06	12	[{"id_menu":1,"count":1}]	14688	pick-up	0	12
59212	2020-05-06 19:13:45	2020-05-06	9	[{"id_menu":7,"count":1}]	7679	delivery	5	14
59213	2020-05-06 19:15:20	2020-05-06	17	[{"id_menu":4,"count":1}]	14025	pick-up	0	17
59214	2020-05-06 19:19:38	2020-05-06	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3689	delivery	5	23
59215	2020-05-06 19:19:38	2020-05-06	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	18873	delivery	5	28
59216	2020-05-06 19:21:11	2020-05-06	9	[{"id_menu":7,"count":1}]	14490	delivery	5	14
59217	2020-05-06 19:22:23	2020-05-06	8	[{"id_menu":5,"count":1}]	10755	pick-up	0	8
59218	2020-05-06 19:28:59	2020-05-06	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23546	delivery	5	37
59219	2020-05-06 19:32:25	2020-05-06	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	5050	pick-up	0	26
59220	2020-05-06 19:32:47	2020-05-06	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	15032	delivery	5	48
59221	2020-05-06 19:33:15	2020-05-06	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	16167	delivery	5	22
59222	2020-05-06 19:40:31	2020-05-06	14	[{"id_menu":2,"count":1}]	23567	pick-up	0	14
59223	2020-05-06 19:43:08	2020-05-06	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":2}]	23520	delivery	5	22
59224	2020-05-06 19:43:54	2020-05-06	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23528	pick-up	0	17
59225	2020-05-06 19:50:03	2020-05-06	12	[{"id_menu":1,"count":1}]	3863	pick-up	0	12
59226	2020-05-06 19:59:03	2020-05-06	9	[{"id_menu":6,"count":1}]	11077	delivery	5	14
59227	2020-05-06 19:59:47	2020-05-06	9	[{"id_menu":6,"count":1}]	18519	delivery	5	14
59228	2020-05-06 20:00:29	2020-05-06	8	[{"id_menu":5,"count":1}]	5902	delivery	5	13
59229	2020-05-06 20:06:32	2020-05-06	9	[{"id_menu":7,"count":1}]	11127	pick-up	0	9
59230	2020-05-06 20:10:59	2020-05-06	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	23486	delivery	5	34
59231	2020-05-06 20:15:16	2020-05-06	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	996	pick-up	0	34
59232	2020-05-06 20:26:34	2020-05-06	17	[{"id_menu":4,"count":1}]	623	pick-up	0	17
59233	2020-05-06 20:26:36	2020-05-06	8	[{"id_menu":5,"count":1}]	23490	delivery	5	13
59234	2020-05-06 20:27:36	2020-05-06	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23547	delivery	5	48
59235	2020-05-06 20:30:23	2020-05-06	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	23298	delivery	5	43
59236	2020-05-06 20:32:52	2020-05-06	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	23538	delivery	5	23
59237	2020-05-06 20:38:32	2020-05-06	17	[{"id_menu":4,"count":1}]	23555	pick-up	0	17
59238	2020-05-06 20:41:22	2020-05-06	8	[{"id_menu":5,"count":1}]	21443	delivery	5	13
59239	2020-05-06 20:44:18	2020-05-06	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	18348	pick-up	0	26
59240	2020-05-06 20:46:23	2020-05-06	29	[{"id_menu":3,"count":3},{"id_menu":4,"count":1}]	16784	delivery	5	34
59241	2020-05-06 20:47:53	2020-05-06	17	[{"id_menu":4,"count":1}]	23500	pick-up	0	17
59242	2020-05-06 20:51:50	2020-05-06	12	[{"id_menu":1,"count":1}]	20479	delivery	5	17
59243	2020-05-06 21:07:20	2020-05-06	8	[{"id_menu":5,"count":1}]	3093	delivery	5	13
59244	2020-05-06 21:11:54	2020-05-06	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	23543	delivery	5	22
59245	2020-05-06 21:12:16	2020-05-06	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	883	pick-up	0	26
59246	2020-05-06 21:14:59	2020-05-06	12	[{"id_menu":3,"count":1}]	4492	delivery	5	17
59247	2020-05-06 21:26:22	2020-05-06	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	10005	delivery	5	34
59248	2020-05-06 21:30:48	2020-05-06	14	[{"id_menu":2,"count":2}]	20938	delivery	5	19
59249	2020-05-06 21:34:31	2020-05-06	8	[{"id_menu":5,"count":1}]	3106	delivery	5	13
59250	2020-05-06 21:35:03	2020-05-06	8	[{"id_menu":5,"count":1}]	1513	pick-up	0	8
59251	2020-05-06 21:35:29	2020-05-06	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	7979	delivery	5	27
59252	2020-05-06 21:37:38	2020-05-06	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6689	pick-up	0	52
59253	2020-05-06 21:37:40	2020-05-06	17	[{"id_menu":4,"count":2}]	21275	pick-up	0	17
59254	2020-05-06 21:48:08	2020-05-06	14	[{"id_menu":2,"count":1}]	23584	delivery	5	19
59255	2020-05-06 21:48:29	2020-05-06	14	[{"id_menu":2,"count":2}]	2551	delivery	5	19
59256	2020-05-06 21:49:34	2020-05-06	9	[{"id_menu":7,"count":1}]	14457	pick-up	0	9
59257	2020-05-06 21:51:11	2020-05-06	9	[{"id_menu":7,"count":1}]	20811	delivery	5	14
59258	2020-05-06 22:00:22	2020-05-06	9	[{"id_menu":6,"count":1}]	16466	delivery	5	14
59259	2020-05-06 22:07:37	2020-05-06	9	[{"id_menu":6,"count":1}]	8775	pick-up	0	9
59260	2020-05-06 22:10:44	2020-05-06	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20495	delivery	5	22
59261	2020-05-06 22:12:41	2020-05-06	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	23506	delivery	5	27
59262	2020-05-06 22:13:07	2020-05-06	12	[{"id_menu":3,"count":1}]	42	pick-up	0	12
59263	2020-05-06 22:16:05	2020-05-06	9	[{"id_menu":6,"count":1}]	23575	delivery	5	14
59264	2020-05-06 22:17:26	2020-05-06	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7437	delivery	5	43
59265	2020-05-06 22:23:37	2020-05-06	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	9254	delivery	5	25
59266	2020-05-06 22:25:18	2020-05-06	12	[{"id_menu":3,"count":1}]	6152	pick-up	0	12
59267	2020-05-06 22:30:34	2020-05-06	14	[{"id_menu":2,"count":2}]	1468	pick-up	0	14
59268	2020-05-06 22:30:47	2020-05-06	9	[{"id_menu":6,"count":1}]	13062	pick-up	0	9
59269	2020-05-06 22:30:50	2020-05-06	9	[{"id_menu":7,"count":1}]	1413	delivery	5	14
59270	2020-05-06 22:34:48	2020-05-06	9	[{"id_menu":6,"count":1}]	7699	delivery	5	14
59271	2020-05-06 22:39:55	2020-05-06	8	[{"id_menu":5,"count":1}]	23435	delivery	5	13
59272	2020-05-06 22:44:15	2020-05-06	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	13435	delivery	5	40
59273	2020-05-06 22:48:00	2020-05-06	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	5725	delivery	5	23
59274	2020-05-06 22:50:35	2020-05-06	8	[{"id_menu":5,"count":1}]	22693	delivery	5	13
59275	2020-05-06 22:50:42	2020-05-06	9	[{"id_menu":6,"count":1}]	23519	delivery	5	14
59276	2020-05-06 22:51:25	2020-05-06	17	[{"id_menu":4,"count":1}]	23477	delivery	5	22
59277	2020-05-06 22:53:19	2020-05-06	12	[{"id_menu":3,"count":1}]	23453	delivery	5	17
59278	2020-05-06 22:56:18	2020-05-06	9	[{"id_menu":7,"count":1}]	1592	delivery	5	14
59279	2020-05-06 22:58:58	2020-05-06	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	23489	delivery	5	30
59280	2020-05-06 23:00:51	2020-05-06	8	[{"id_menu":5,"count":1}]	12934	delivery	5	13
59281	2020-05-06 23:03:36	2020-05-06	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	16747	delivery	5	26
59282	2020-05-06 23:03:57	2020-05-06	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	23515	delivery	5	25
59283	2020-05-06 23:04:01	2020-05-06	9	[{"id_menu":6,"count":4}]	23448	delivery	5	14
59284	2020-05-06 23:06:59	2020-05-06	17	[{"id_menu":4,"count":1}]	23450	delivery	5	22
59285	2020-05-06 23:07:10	2020-05-06	9	[{"id_menu":7,"count":1}]	19768	pick-up	0	9
59286	2020-05-06 23:11:33	2020-05-06	17	[{"id_menu":4,"count":1}]	23484	delivery	5	22
59287	2020-05-06 23:14:04	2020-05-06	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	12924	delivery	5	22
59288	2020-05-06 23:14:27	2020-05-06	17	[{"id_menu":4,"count":1}]	847	pick-up	0	17
59289	2020-05-06 23:16:55	2020-05-06	8	[{"id_menu":5,"count":1}]	23475	delivery	5	13
59290	2020-05-06 23:18:42	2020-05-06	14	[{"id_menu":2,"count":2}]	7081	pick-up	0	14
59291	2020-05-06 23:18:53	2020-05-06	9	[{"id_menu":6,"count":1}]	19971	delivery	5	14
59292	2020-05-06 23:22:22	2020-05-06	14	[{"id_menu":2,"count":1}]	1163	delivery	5	19
59293	2020-05-06 23:23:43	2020-05-06	9	[{"id_menu":7,"count":1}]	16295	pick-up	0	9
59294	2020-05-06 23:25:38	2020-05-06	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10951	delivery	5	44
59295	2020-05-06 23:30:45	2020-05-06	12	[{"id_menu":1,"count":1}]	2570	pick-up	0	12
59296	2020-05-06 23:34:53	2020-05-06	14	[{"id_menu":2,"count":1}]	6784	delivery	5	19
59297	2020-05-06 23:40:45	2020-05-06	12	[{"id_menu":1,"count":1}]	13325	pick-up	0	12
59298	2020-05-06 23:42:35	2020-05-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	23480	delivery	5	28
59299	2020-05-06 23:42:50	2020-05-06	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6816	delivery	5	22
59300	2020-05-06 23:44:04	2020-05-06	8	[{"id_menu":5,"count":1}]	22981	delivery	5	13
59301	2020-05-06 23:54:21	2020-05-06	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	10245	delivery	5	37
59302	2020-05-06 23:54:49	2020-05-06	14	[{"id_menu":2,"count":1}]	2275	delivery	5	19
59303	2020-05-06 23:57:54	2020-05-06	12	[{"id_menu":1,"count":1}]	13123	delivery	5	17
59304	2020-05-07 00:10:11	2020-05-07	9	[{"id_menu":7,"count":1}]	4248	pick-up	0	9
59305	2020-05-07 00:18:04	2020-05-07	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	482	delivery	5	57
59306	2020-05-07 00:22:53	2020-05-07	12	[{"id_menu":1,"count":1}]	5902	delivery	5	17
59307	2020-05-07 00:41:06	2020-05-07	9	[{"id_menu":7,"count":1}]	23666	delivery	5	14
59308	2020-05-07 00:42:40	2020-05-07	17	[{"id_menu":4,"count":1}]	351	delivery	5	22
59309	2020-05-07 00:43:02	2020-05-07	17	[{"id_menu":4,"count":1}]	14616	pick-up	0	17
59310	2020-05-07 00:57:09	2020-05-07	8	[{"id_menu":5,"count":1}]	1457	delivery	5	13
59311	2020-05-07 01:00:27	2020-05-07	8	[{"id_menu":5,"count":1}]	8945	delivery	5	13
59312	2020-05-07 01:05:26	2020-05-07	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	18180	delivery	5	36
59313	2020-05-07 01:10:35	2020-05-07	46	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	7786	delivery	5	51
59314	2020-05-07 01:20:41	2020-05-07	8	[{"id_menu":5,"count":1}]	7835	pick-up	0	8
59315	2020-05-07 01:26:22	2020-05-07	8	[{"id_menu":5,"count":2}]	23655	delivery	5	13
59316	2020-05-07 01:26:51	2020-05-07	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	10152	pick-up	0	21
59317	2020-05-07 01:27:48	2020-05-07	9	[{"id_menu":6,"count":2}]	23625	delivery	5	14
59318	2020-05-07 01:29:03	2020-05-07	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23640	delivery	5	37
59319	2020-05-07 01:35:10	2020-05-07	9	[{"id_menu":7,"count":1}]	22578	delivery	5	14
59320	2020-05-07 01:39:22	2020-05-07	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	8290	delivery	5	26
59321	2020-05-07 01:40:47	2020-05-07	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4622	delivery	5	22
59322	2020-05-07 01:47:00	2020-05-07	12	[{"id_menu":1,"count":1}]	22598	delivery	5	17
59323	2020-05-07 01:47:54	2020-05-07	9	[{"id_menu":6,"count":1}]	23593	delivery	5	14
59324	2020-05-07 01:49:51	2020-05-07	14	[{"id_menu":2,"count":1}]	6202	pick-up	0	14
59325	2020-05-07 01:51:53	2020-05-07	12	[{"id_menu":3,"count":1}]	5478	pick-up	0	12
59326	2020-05-07 01:53:04	2020-05-07	9	[{"id_menu":6,"count":1}]	23644	delivery	5	14
59327	2020-05-07 01:54:40	2020-05-07	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	23607	pick-up	0	20
59328	2020-05-07 01:55:59	2020-05-07	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18201	delivery	5	49
59329	2020-05-07 01:56:23	2020-05-07	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	7925	delivery	5	40
59330	2020-05-07 02:06:42	2020-05-07	9	[{"id_menu":6,"count":1}]	23675	delivery	5	14
59331	2020-05-07 02:08:16	2020-05-07	9	[{"id_menu":6,"count":1}]	20338	pick-up	0	9
59332	2020-05-07 02:19:21	2020-05-07	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1681	pick-up	0	26
59333	2020-05-07 02:25:45	2020-05-07	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":2}]	3227	pick-up	0	23
59334	2020-05-07 02:26:00	2020-05-07	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23705	delivery	5	22
59335	2020-05-07 02:27:07	2020-05-07	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	11046	delivery	5	23
59336	2020-05-07 02:33:06	2020-05-07	9	[{"id_menu":6,"count":1}]	22707	delivery	5	14
59337	2020-05-07 02:37:22	2020-05-07	12	[{"id_menu":3,"count":1}]	23654	delivery	5	17
59338	2020-05-07 02:40:55	2020-05-07	9	[{"id_menu":6,"count":1}]	23680	delivery	5	14
59339	2020-05-07 02:48:36	2020-05-07	12	[{"id_menu":1,"count":1}]	23696	pick-up	0	12
59340	2020-05-07 02:55:30	2020-05-07	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	18390	delivery	5	45
59341	2020-05-07 02:57:35	2020-05-07	9	[{"id_menu":7,"count":2}]	10507	delivery	5	14
59342	2020-05-07 03:01:38	2020-05-07	8	[{"id_menu":5,"count":1}]	10833	delivery	5	13
59343	2020-05-07 03:05:26	2020-05-07	12	[{"id_menu":1,"count":1}]	352	pick-up	0	12
59344	2020-05-07 03:10:44	2020-05-07	9	[{"id_menu":7,"count":1}]	3228	pick-up	0	9
59345	2020-05-07 03:11:47	2020-05-07	14	[{"id_menu":2,"count":1}]	11789	delivery	5	19
59346	2020-05-07 03:13:35	2020-05-07	8	[{"id_menu":5,"count":1}]	19219	delivery	5	13
59347	2020-05-07 03:15:51	2020-05-07	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	11788	pick-up	0	21
59348	2020-05-07 03:16:38	2020-05-07	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23662	delivery	5	37
59349	2020-05-07 03:17:59	2020-05-07	12	[{"id_menu":3,"count":1}]	3851	pick-up	0	12
59350	2020-05-07 03:24:23	2020-05-07	9	[{"id_menu":6,"count":1}]	1537	pick-up	0	9
59351	2020-05-07 03:24:48	2020-05-07	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17790	delivery	5	53
59352	2020-05-07 03:27:23	2020-05-07	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	23590	delivery	5	36
59353	2020-05-07 03:27:44	2020-05-07	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	15829	pick-up	0	21
59354	2020-05-07 03:35:57	2020-05-07	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5213	delivery	5	31
59355	2020-05-07 03:37:07	2020-05-07	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8116	pick-up	0	38
59356	2020-05-07 03:37:46	2020-05-07	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23701	delivery	5	36
59357	2020-05-07 03:37:47	2020-05-07	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	12832	delivery	5	34
59358	2020-05-07 03:40:56	2020-05-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2569	pick-up	0	23
59359	2020-05-07 03:42:34	2020-05-07	17	[{"id_menu":4,"count":1}]	16857	delivery	5	22
59360	2020-05-07 03:43:22	2020-05-07	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	547	delivery	5	25
59361	2020-05-07 03:44:26	2020-05-07	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	23686	delivery	5	23
59362	2020-05-07 03:44:53	2020-05-07	12	[{"id_menu":1,"count":1}]	21820	delivery	5	17
59363	2020-05-07 03:47:50	2020-05-07	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2193	pick-up	0	22
59364	2020-05-07 03:57:12	2020-05-07	12	[{"id_menu":1,"count":1}]	14764	pick-up	0	12
59365	2020-05-07 04:00:57	2020-05-07	9	[{"id_menu":6,"count":1}]	7433	pick-up	0	9
59366	2020-05-07 04:04:46	2020-05-07	12	[{"id_menu":3,"count":1}]	23727	delivery	5	17
59367	2020-05-07 04:05:53	2020-05-07	12	[{"id_menu":3,"count":1}]	6990	pick-up	0	12
59368	2020-05-07 04:10:07	2020-05-07	9	[{"id_menu":7,"count":1}]	23681	delivery	5	14
59369	2020-05-07 04:14:28	2020-05-07	9	[{"id_menu":7,"count":1}]	23597	delivery	5	14
59370	2020-05-07 04:15:24	2020-05-07	9	[{"id_menu":6,"count":1}]	23592	pick-up	0	9
59371	2020-05-07 04:21:47	2020-05-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22787	delivery	5	23
59372	2020-05-07 04:21:49	2020-05-07	9	[{"id_menu":6,"count":1}]	15832	delivery	5	14
59373	2020-05-07 04:23:20	2020-05-07	12	[{"id_menu":1,"count":1}]	18900	delivery	5	17
59374	2020-05-07 04:24:05	2020-05-07	12	[{"id_menu":3,"count":1}]	19333	delivery	5	17
59375	2020-05-07 04:25:56	2020-05-07	17	[{"id_menu":4,"count":1}]	15120	pick-up	0	17
59376	2020-05-07 04:26:21	2020-05-07	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	23587	delivery	5	26
59377	2020-05-07 04:28:58	2020-05-07	14	[{"id_menu":2,"count":1}]	23706	delivery	5	19
59378	2020-05-07 04:31:16	2020-05-07	9	[{"id_menu":6,"count":1}]	2056	pick-up	0	9
59379	2020-05-07 04:33:11	2020-05-07	12	[{"id_menu":1,"count":1}]	21816	delivery	5	17
59380	2020-05-07 04:33:51	2020-05-07	17	[{"id_menu":4,"count":1}]	23629	delivery	5	22
59381	2020-05-07 04:35:22	2020-05-07	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	23731	delivery	5	25
59382	2020-05-07 04:36:09	2020-05-07	14	[{"id_menu":2,"count":1}]	10019	pick-up	0	14
59383	2020-05-07 04:40:38	2020-05-07	9	[{"id_menu":7,"count":1}]	14145	delivery	5	14
59384	2020-05-07 04:41:35	2020-05-07	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	23638	delivery	5	26
59385	2020-05-07 04:44:54	2020-05-07	12	[{"id_menu":1,"count":1}]	314	delivery	5	17
59386	2020-05-07 04:47:16	2020-05-07	17	[{"id_menu":4,"count":1}]	14767	pick-up	0	17
59387	2020-05-07 04:49:21	2020-05-07	12	[{"id_menu":1,"count":1}]	15973	delivery	5	17
59388	2020-05-07 04:49:56	2020-05-07	12	[{"id_menu":3,"count":1}]	2228	delivery	5	17
59389	2020-05-07 04:56:38	2020-05-07	12	[{"id_menu":1,"count":1}]	4072	pick-up	0	12
59390	2020-05-07 04:57:38	2020-05-07	12	[{"id_menu":3,"count":1}]	23693	delivery	5	17
59391	2020-05-07 05:12:15	2020-05-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	22568	pick-up	0	23
59392	2020-05-07 05:14:35	2020-05-07	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	23659	pick-up	0	35
59393	2020-05-07 05:20:44	2020-05-07	17	[{"id_menu":4,"count":1}]	21653	delivery	5	22
59394	2020-05-07 05:26:49	2020-05-07	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	23649	delivery	5	25
59395	2020-05-07 05:27:23	2020-05-07	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14034	pick-up	0	17
59396	2020-05-07 05:30:54	2020-05-07	9	[{"id_menu":6,"count":1}]	19572	delivery	5	14
59397	2020-05-07 05:35:14	2020-05-07	12	[{"id_menu":1,"count":1}]	2916	pick-up	0	12
59398	2020-05-07 05:37:44	2020-05-07	17	[{"id_menu":4,"count":1}]	23602	pick-up	0	17
59399	2020-05-07 05:41:30	2020-05-07	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	23665	delivery	5	37
59400	2020-05-07 05:47:04	2020-05-07	14	[{"id_menu":2,"count":1}]	596	pick-up	0	14
59401	2020-05-07 05:50:24	2020-05-07	17	[{"id_menu":4,"count":1}]	14090	delivery	5	22
59402	2020-05-07 05:52:05	2020-05-07	14	[{"id_menu":2,"count":1}]	8989	delivery	5	19
59403	2020-05-07 05:52:52	2020-05-07	9	[{"id_menu":7,"count":1}]	12954	delivery	5	14
59404	2020-05-07 05:53:44	2020-05-07	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23613	delivery	5	34
59405	2020-05-07 06:01:13	2020-05-07	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11464	delivery	5	31
59406	2020-05-07 06:05:49	2020-05-07	12	[{"id_menu":1,"count":1}]	23147	delivery	5	17
59407	2020-05-07 06:06:40	2020-05-07	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":2}]	5286	pick-up	0	31
59408	2020-05-07 06:06:59	2020-05-07	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	23687	delivery	5	25
59409	2020-05-07 06:09:22	2020-05-07	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	10771	delivery	5	37
59410	2020-05-07 06:10:23	2020-05-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":3}]	18102	delivery	5	23
59411	2020-05-07 06:11:51	2020-05-07	9	[{"id_menu":7,"count":1}]	23628	delivery	5	14
59412	2020-05-07 06:13:24	2020-05-07	17	[{"id_menu":4,"count":1}]	7934	pick-up	0	17
59413	2020-05-07 06:18:50	2020-05-07	9	[{"id_menu":7,"count":1}]	20965	delivery	5	14
59414	2020-05-07 06:20:06	2020-05-07	17	[{"id_menu":4,"count":1}]	2373	pick-up	0	17
59415	2020-05-07 06:38:53	2020-05-07	9	[{"id_menu":7,"count":1}]	1574	pick-up	0	9
59416	2020-05-07 06:45:23	2020-05-07	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10389	pick-up	0	30
59417	2020-05-07 06:47:08	2020-05-07	12	[{"id_menu":1,"count":1}]	6855	delivery	5	17
59418	2020-05-07 06:49:14	2020-05-07	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15769	pick-up	0	30
59419	2020-05-07 06:52:37	2020-05-07	9	[{"id_menu":6,"count":1}]	23714	delivery	5	14
59420	2020-05-07 06:52:53	2020-05-07	9	[{"id_menu":7,"count":1}]	23273	delivery	5	14
59421	2020-05-07 06:54:34	2020-05-07	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11297	delivery	5	43
59422	2020-05-07 06:55:16	2020-05-07	8	[{"id_menu":5,"count":1}]	23733	delivery	5	13
59423	2020-05-07 06:56:18	2020-05-07	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5632	delivery	5	40
59424	2020-05-07 06:59:58	2020-05-07	17	[{"id_menu":4,"count":1}]	23635	delivery	5	22
59425	2020-05-07 07:01:52	2020-05-07	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23630	delivery	5	22
59426	2020-05-07 07:03:32	2020-05-07	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	23673	delivery	5	25
59427	2020-05-07 07:09:42	2020-05-07	9	[{"id_menu":7,"count":1}]	19727	delivery	5	14
59428	2020-05-07 07:17:07	2020-05-07	12	[{"id_menu":3,"count":1}]	23730	delivery	5	17
59429	2020-05-07 07:19:09	2020-05-07	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11531	delivery	5	31
59430	2020-05-07 07:19:24	2020-05-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	15124	delivery	5	28
59431	2020-05-07 07:22:42	2020-05-07	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23615	delivery	5	43
59432	2020-05-07 07:23:24	2020-05-07	8	[{"id_menu":5,"count":1}]	15100	delivery	5	13
59433	2020-05-07 07:26:10	2020-05-07	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	12297	delivery	5	27
59434	2020-05-07 07:36:01	2020-05-07	8	[{"id_menu":5,"count":1}]	4192	delivery	5	13
59435	2020-05-07 07:45:41	2020-05-07	9	[{"id_menu":7,"count":1}]	9457	delivery	5	14
59436	2020-05-07 07:51:07	2020-05-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	21649	delivery	5	28
59437	2020-05-07 07:52:32	2020-05-07	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20209	delivery	5	36
59438	2020-05-07 07:59:32	2020-05-07	14	[{"id_menu":2,"count":1}]	2401	pick-up	0	14
59439	2020-05-07 08:06:44	2020-05-07	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	6648	delivery	5	26
59440	2020-05-07 08:07:12	2020-05-07	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	17641	pick-up	0	26
59441	2020-05-07 08:08:35	2020-05-07	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	7123	delivery	5	23
59442	2020-05-07 08:08:36	2020-05-07	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	23716	delivery	5	36
59443	2020-05-07 08:13:15	2020-05-07	9	[{"id_menu":7,"count":1}]	1075	delivery	5	14
59444	2020-05-07 08:13:52	2020-05-07	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	4436	pick-up	0	33
59445	2020-05-07 08:15:12	2020-05-07	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	231	delivery	5	46
59446	2020-05-07 08:20:02	2020-05-07	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	12912	pick-up	0	24
59447	2020-05-07 08:23:45	2020-05-07	17	[{"id_menu":4,"count":1}]	16301	pick-up	0	17
59448	2020-05-07 08:24:27	2020-05-07	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1581	pick-up	0	20
59449	2020-05-07 08:30:29	2020-05-07	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6489	delivery	5	39
59450	2020-05-07 08:34:31	2020-05-07	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	23599	delivery	5	39
59451	2020-05-07 08:38:33	2020-05-07	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6701	delivery	5	35
59452	2020-05-07 08:38:48	2020-05-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	7761	delivery	5	26
59453	2020-05-07 08:42:57	2020-05-07	12	[{"id_menu":1,"count":1}]	9915	delivery	5	17
59454	2020-05-07 08:45:58	2020-05-07	14	[{"id_menu":2,"count":3}]	2965	delivery	5	19
59455	2020-05-07 08:51:50	2020-05-07	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	23689	delivery	5	25
59456	2020-05-07 08:52:16	2020-05-07	12	[{"id_menu":3,"count":1}]	15048	pick-up	0	12
59457	2020-05-07 08:52:25	2020-05-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	23608	pick-up	0	21
59458	2020-05-07 08:55:48	2020-05-07	12	[{"id_menu":3,"count":1}]	1860	pick-up	0	12
59459	2020-05-07 08:56:58	2020-05-07	17	[{"id_menu":4,"count":1}]	4554	delivery	5	22
59460	2020-05-07 08:59:54	2020-05-07	34	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	23728	delivery	5	39
59461	2020-05-07 08:59:59	2020-05-07	17	[{"id_menu":4,"count":1}]	23695	pick-up	0	17
59462	2020-05-07 09:02:16	2020-05-07	9	[{"id_menu":7,"count":1}]	8468	delivery	5	14
59463	2020-05-07 09:03:52	2020-05-07	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6296	delivery	5	45
59464	2020-05-07 09:05:44	2020-05-07	9	[{"id_menu":6,"count":1}]	6090	pick-up	0	9
59465	2020-05-07 09:08:50	2020-05-07	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	23694	delivery	5	25
59466	2020-05-07 09:10:11	2020-05-07	14	[{"id_menu":2,"count":1}]	23688	delivery	5	19
59467	2020-05-07 09:16:46	2020-05-07	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":2}]	23588	pick-up	0	25
59468	2020-05-07 09:22:34	2020-05-07	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22550	delivery	5	34
59469	2020-05-07 09:23:09	2020-05-07	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2947	pick-up	0	26
59470	2020-05-07 09:26:10	2020-05-07	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8724	delivery	5	49
59471	2020-05-07 09:27:12	2020-05-07	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	15243	pick-up	0	31
59472	2020-05-07 09:31:00	2020-05-07	9	[{"id_menu":6,"count":1}]	23620	delivery	5	14
59473	2020-05-07 09:37:39	2020-05-07	9	[{"id_menu":7,"count":1}]	14027	pick-up	0	9
59474	2020-05-07 09:38:23	2020-05-07	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11208	delivery	5	36
59475	2020-05-07 09:40:49	2020-05-07	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	23668	delivery	5	31
59476	2020-05-07 09:42:40	2020-05-07	14	[{"id_menu":2,"count":1}]	23661	pick-up	0	14
59477	2020-05-07 09:46:00	2020-05-07	9	[{"id_menu":6,"count":1}]	6962	pick-up	0	9
59478	2020-05-07 09:50:56	2020-05-07	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	18652	pick-up	0	34
59479	2020-05-07 09:54:02	2020-05-07	12	[{"id_menu":3,"count":1}]	23278	delivery	5	17
59480	2020-05-07 10:03:54	2020-05-07	8	[{"id_menu":5,"count":1}]	7834	pick-up	0	8
59481	2020-05-07 10:04:43	2020-05-07	9	[{"id_menu":7,"count":1}]	19316	delivery	5	14
59482	2020-05-07 10:09:15	2020-05-07	12	[{"id_menu":3,"count":1}]	7213	delivery	5	17
59483	2020-05-07 10:09:30	2020-05-07	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3061	delivery	5	31
59484	2020-05-07 10:09:57	2020-05-07	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23697	delivery	5	40
59485	2020-05-07 10:13:30	2020-05-07	12	[{"id_menu":1,"count":1}]	22503	delivery	5	17
59486	2020-05-07 10:29:07	2020-05-07	12	[{"id_menu":1,"count":1}]	5506	pick-up	0	12
59487	2020-05-07 10:36:39	2020-05-07	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2055	pick-up	0	31
59488	2020-05-07 10:37:33	2020-05-07	9	[{"id_menu":6,"count":1}]	23598	delivery	5	14
59489	2020-05-07 10:38:56	2020-05-07	9	[{"id_menu":7,"count":1}]	7428	delivery	5	14
59490	2020-05-07 10:40:37	2020-05-07	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7130	delivery	5	40
59491	2020-05-07 10:44:57	2020-05-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23606	delivery	5	23
59492	2020-05-07 10:45:09	2020-05-07	17	[{"id_menu":4,"count":1}]	6152	pick-up	0	17
59493	2020-05-07 10:48:30	2020-05-07	8	[{"id_menu":5,"count":1}]	414	delivery	5	13
59494	2020-05-07 10:50:18	2020-05-07	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	8461	delivery	5	27
59495	2020-05-07 10:51:00	2020-05-07	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3153	pick-up	0	29
59496	2020-05-07 10:55:12	2020-05-07	12	[{"id_menu":1,"count":1}]	19092	pick-up	0	12
59497	2020-05-07 10:55:53	2020-05-07	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	5570	delivery	5	48
59498	2020-05-07 10:56:56	2020-05-07	9	[{"id_menu":6,"count":1}]	5817	delivery	5	14
59499	2020-05-07 11:11:25	2020-05-07	8	[{"id_menu":5,"count":1}]	12070	pick-up	0	8
59500	2020-05-07 11:17:43	2020-05-07	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	10228	delivery	5	31
59501	2020-05-07 11:18:32	2020-05-07	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	22208	delivery	5	36
59502	2020-05-07 11:27:16	2020-05-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6335	delivery	5	23
59503	2020-05-07 11:31:44	2020-05-07	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":2}]	21961	pick-up	0	31
59504	2020-05-07 11:35:48	2020-05-07	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14413	delivery	5	36
59505	2020-05-07 11:38:26	2020-05-07	9	[{"id_menu":6,"count":1}]	5639	pick-up	0	9
59506	2020-05-07 11:43:54	2020-05-07	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23648	delivery	5	40
59507	2020-05-07 11:44:50	2020-05-07	12	[{"id_menu":1,"count":1}]	399	delivery	5	17
59508	2020-05-07 11:52:33	2020-05-07	34	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	23699	delivery	5	39
59509	2020-05-07 11:55:31	2020-05-07	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20196	delivery	5	36
59510	2020-05-07 11:56:05	2020-05-07	9	[{"id_menu":7,"count":1}]	23678	delivery	5	14
59511	2020-05-07 11:56:34	2020-05-07	9	[{"id_menu":7,"count":1}]	23726	delivery	5	14
59512	2020-05-07 11:58:44	2020-05-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4368	delivery	5	28
59513	2020-05-07 11:58:46	2020-05-07	12	[{"id_menu":1,"count":1}]	6213	delivery	5	17
59514	2020-05-07 12:01:01	2020-05-07	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19480	delivery	5	39
59515	2020-05-07 12:01:06	2020-05-07	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":3}]	4624	delivery	5	22
59516	2020-05-07 12:04:27	2020-05-07	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	6257	delivery	5	34
59517	2020-05-07 12:09:59	2020-05-07	9	[{"id_menu":7,"count":1}]	23721	delivery	5	14
59518	2020-05-07 12:12:48	2020-05-07	17	[{"id_menu":4,"count":1}]	458	delivery	5	22
59519	2020-05-07 12:14:52	2020-05-07	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	7651	pick-up	0	21
59520	2020-05-07 12:15:27	2020-05-07	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	23679	pick-up	0	26
59521	2020-05-07 12:16:07	2020-05-07	49	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	23691	delivery	5	54
59522	2020-05-07 12:19:11	2020-05-07	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	23414	delivery	5	26
59523	2020-05-07 12:21:44	2020-05-07	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	19250	delivery	5	25
59524	2020-05-07 12:25:57	2020-05-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2766	delivery	5	26
59525	2020-05-07 12:30:54	2020-05-07	9	[{"id_menu":7,"count":1}]	23619	delivery	5	14
59526	2020-05-07 12:33:54	2020-05-07	8	[{"id_menu":5,"count":1}]	765	delivery	5	13
59527	2020-05-07 12:33:55	2020-05-07	9	[{"id_menu":6,"count":1}]	15948	delivery	5	14
59528	2020-05-07 12:36:07	2020-05-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5426	delivery	5	28
59529	2020-05-07 12:41:52	2020-05-07	8	[{"id_menu":5,"count":1}]	11570	pick-up	0	8
59530	2020-05-07 12:45:11	2020-05-07	9	[{"id_menu":6,"count":1}]	19386	delivery	5	14
59531	2020-05-07 12:48:14	2020-05-07	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	19177	pick-up	0	43
59532	2020-05-07 12:58:31	2020-05-07	12	[{"id_menu":3,"count":1}]	20913	pick-up	0	12
59533	2020-05-07 12:59:28	2020-05-07	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	20136	pick-up	0	43
59534	2020-05-07 13:05:57	2020-05-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14207	delivery	5	22
59535	2020-05-07 13:07:37	2020-05-07	17	[{"id_menu":4,"count":1}]	20815	delivery	5	22
59536	2020-05-07 13:08:44	2020-05-07	14	[{"id_menu":2,"count":1}]	5264	delivery	5	19
59537	2020-05-07 13:10:26	2020-05-07	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	23722	delivery	5	40
59538	2020-05-07 13:10:28	2020-05-07	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7998	delivery	5	37
59539	2020-05-07 13:13:30	2020-05-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	22647	delivery	5	23
59540	2020-05-07 13:16:44	2020-05-07	9	[{"id_menu":6,"count":1}]	13951	pick-up	0	9
59541	2020-05-07 13:17:53	2020-05-07	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23603	delivery	5	22
59542	2020-05-07 13:19:57	2020-05-07	8	[{"id_menu":5,"count":1}]	2434	pick-up	0	8
59543	2020-05-07 13:20:40	2020-05-07	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	661	pick-up	0	43
59544	2020-05-07 13:20:47	2020-05-07	17	[{"id_menu":4,"count":1}]	22684	delivery	5	22
59545	2020-05-07 13:27:58	2020-05-07	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	12849	delivery	5	39
59546	2020-05-07 13:29:34	2020-05-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	655	pick-up	0	23
59547	2020-05-07 13:33:57	2020-05-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	12527	pick-up	0	23
59548	2020-05-07 13:36:08	2020-05-07	9	[{"id_menu":7,"count":1}]	8311	delivery	5	14
59549	2020-05-07 13:36:11	2020-05-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23719	delivery	5	23
59550	2020-05-07 13:40:22	2020-05-07	12	[{"id_menu":1,"count":1}]	14735	pick-up	0	12
59551	2020-05-07 13:46:33	2020-05-07	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	16447	delivery	5	44
59552	2020-05-07 13:52:46	2020-05-07	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2612	delivery	5	34
59553	2020-05-07 13:54:59	2020-05-07	9	[{"id_menu":6,"count":1}]	14482	delivery	5	14
59554	2020-05-07 13:59:57	2020-05-07	12	[{"id_menu":1,"count":1}]	19808	delivery	5	17
59555	2020-05-07 14:01:25	2020-05-07	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4580	delivery	5	44
59556	2020-05-07 14:07:03	2020-05-07	9	[{"id_menu":7,"count":1}]	15361	pick-up	0	9
59557	2020-05-07 14:10:37	2020-05-07	17	[{"id_menu":4,"count":1}]	13548	delivery	5	22
59558	2020-05-07 14:11:20	2020-05-07	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	23729	pick-up	0	26
59559	2020-05-07 14:15:08	2020-05-07	8	[{"id_menu":5,"count":1}]	22214	delivery	5	13
59560	2020-05-07 14:15:47	2020-05-07	9	[{"id_menu":7,"count":1}]	18870	delivery	5	14
59561	2020-05-07 14:18:53	2020-05-07	9	[{"id_menu":6,"count":1}]	22775	delivery	5	14
59562	2020-05-07 14:21:41	2020-05-07	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23303	delivery	5	22
59563	2020-05-07 14:22:45	2020-05-07	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	23591	delivery	5	22
59564	2020-05-07 14:24:04	2020-05-07	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23631	delivery	5	51
59565	2020-05-07 14:33:31	2020-05-07	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19783	delivery	5	40
59566	2020-05-07 14:37:08	2020-05-07	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3232	delivery	5	22
59567	2020-05-07 14:37:16	2020-05-07	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	23637	delivery	5	31
59568	2020-05-07 14:39:14	2020-05-07	17	[{"id_menu":4,"count":1}]	18067	delivery	5	22
59569	2020-05-07 14:46:49	2020-05-07	8	[{"id_menu":5,"count":1}]	7190	delivery	5	13
59570	2020-05-07 14:51:21	2020-05-07	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	5790	pick-up	0	23
59571	2020-05-07 14:56:51	2020-05-07	12	[{"id_menu":3,"count":1}]	2283	pick-up	0	12
59572	2020-05-07 14:58:27	2020-05-07	12	[{"id_menu":3,"count":1}]	8973	delivery	5	17
59573	2020-05-07 14:59:19	2020-05-07	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	23676	delivery	5	31
59574	2020-05-07 15:13:36	2020-05-07	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18620	delivery	5	37
59575	2020-05-07 15:14:26	2020-05-07	12	[{"id_menu":1,"count":1}]	17270	delivery	5	17
59576	2020-05-07 15:22:28	2020-05-07	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23626	delivery	5	43
59577	2020-05-07 15:25:11	2020-05-07	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	5803	delivery	5	25
59578	2020-05-07 15:27:37	2020-05-07	12	[{"id_menu":1,"count":1}]	23621	delivery	5	17
59579	2020-05-07 15:28:25	2020-05-07	12	[{"id_menu":3,"count":1}]	23643	delivery	5	17
59580	2020-05-07 15:30:31	2020-05-07	9	[{"id_menu":7,"count":1}]	4905	delivery	5	14
59581	2020-05-07 15:33:56	2020-05-07	17	[{"id_menu":4,"count":1}]	143	delivery	5	22
59582	2020-05-07 15:34:45	2020-05-07	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	23641	delivery	5	40
59583	2020-05-07 15:35:33	2020-05-07	12	[{"id_menu":3,"count":1}]	9304	pick-up	0	12
59584	2020-05-07 15:36:04	2020-05-07	8	[{"id_menu":5,"count":1}]	17011	delivery	5	13
59585	2020-05-07 15:37:00	2020-05-07	9	[{"id_menu":7,"count":2}]	14931	delivery	5	14
59586	2020-05-07 15:38:10	2020-05-07	8	[{"id_menu":5,"count":1}]	23703	delivery	5	13
59587	2020-05-07 15:41:26	2020-05-07	17	[{"id_menu":4,"count":1}]	4223	pick-up	0	17
59588	2020-05-07 15:49:14	2020-05-07	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7623	delivery	5	39
59589	2020-05-07 15:50:27	2020-05-07	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	12753	delivery	5	27
59590	2020-05-07 15:58:24	2020-05-07	12	[{"id_menu":1,"count":1}]	23614	delivery	5	17
59591	2020-05-07 15:58:58	2020-05-07	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3534	delivery	5	31
59592	2020-05-07 16:00:02	2020-05-07	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17257	delivery	5	43
59593	2020-05-07 16:01:06	2020-05-07	8	[{"id_menu":5,"count":1}]	23718	delivery	5	13
59594	2020-05-07 16:02:38	2020-05-07	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3023	delivery	5	31
59595	2020-05-07 16:05:57	2020-05-07	8	[{"id_menu":5,"count":1}]	18430	delivery	5	13
59596	2020-05-07 16:08:29	2020-05-07	9	[{"id_menu":6,"count":1}]	2513	pick-up	0	9
59597	2020-05-07 16:09:48	2020-05-07	8	[{"id_menu":5,"count":1}]	3133	delivery	5	13
59598	2020-05-07 16:13:16	2020-05-07	9	[{"id_menu":7,"count":1}]	20328	pick-up	0	9
59599	2020-05-07 16:16:03	2020-05-07	9	[{"id_menu":7,"count":1}]	16373	delivery	5	14
59600	2020-05-07 16:16:17	2020-05-07	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14161	delivery	5	36
59601	2020-05-07 16:17:20	2020-05-07	12	[{"id_menu":1,"count":1}]	23612	delivery	5	17
59602	2020-05-07 16:19:22	2020-05-07	9	[{"id_menu":7,"count":1}]	6641	pick-up	0	9
59603	2020-05-07 16:23:02	2020-05-07	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	13987	delivery	5	26
59604	2020-05-07 16:34:46	2020-05-07	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	3870	pick-up	0	21
59605	2020-05-07 16:34:53	2020-05-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	23720	delivery	5	28
59606	2020-05-07 16:38:08	2020-05-07	9	[{"id_menu":6,"count":2}]	22066	delivery	5	14
59607	2020-05-07 16:39:23	2020-05-07	14	[{"id_menu":2,"count":1}]	23601	delivery	5	19
59608	2020-05-07 16:39:28	2020-05-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	17068	delivery	5	22
59609	2020-05-07 16:42:05	2020-05-07	17	[{"id_menu":4,"count":1}]	980	delivery	5	22
59610	2020-05-07 16:48:32	2020-05-07	9	[{"id_menu":7,"count":1}]	14444	delivery	5	14
59611	2020-05-07 16:49:00	2020-05-07	9	[{"id_menu":6,"count":1}]	13131	delivery	5	14
59612	2020-05-07 16:49:40	2020-05-07	17	[{"id_menu":4,"count":3}]	12126	delivery	5	22
59613	2020-05-07 16:51:35	2020-05-07	8	[{"id_menu":5,"count":1}]	11863	delivery	5	13
59614	2020-05-07 17:04:45	2020-05-07	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	73	pick-up	0	26
59615	2020-05-07 17:05:41	2020-05-07	12	[{"id_menu":3,"count":1}]	9337	pick-up	0	12
59616	2020-05-07 17:09:50	2020-05-07	8	[{"id_menu":5,"count":1}]	12019	pick-up	0	8
59617	2020-05-07 17:10:32	2020-05-07	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	22925	delivery	5	25
59618	2020-05-07 17:11:37	2020-05-07	14	[{"id_menu":2,"count":1}]	1638	delivery	5	19
59619	2020-05-07 17:13:03	2020-05-07	9	[{"id_menu":6,"count":2}]	23634	pick-up	0	9
59620	2020-05-07 17:20:33	2020-05-07	14	[{"id_menu":2,"count":1}]	11337	delivery	5	19
59621	2020-05-07 17:29:20	2020-05-07	12	[{"id_menu":3,"count":1}]	6470	pick-up	0	12
59622	2020-05-07 17:31:03	2020-05-07	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23684	delivery	5	39
59623	2020-05-07 17:41:24	2020-05-07	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	23663	delivery	5	43
59624	2020-05-07 17:42:32	2020-05-07	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19699	delivery	5	39
59625	2020-05-07 17:46:16	2020-05-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5280	delivery	5	28
59626	2020-05-07 17:52:47	2020-05-07	12	[{"id_menu":3,"count":1}]	23610	delivery	5	17
59627	2020-05-07 17:53:36	2020-05-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	23632	delivery	5	28
59628	2020-05-07 17:56:28	2020-05-07	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2715	pick-up	0	26
59629	2020-05-07 18:01:16	2020-05-07	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	23623	delivery	5	25
59630	2020-05-07 18:07:36	2020-05-07	9	[{"id_menu":7,"count":1}]	21553	delivery	5	14
59631	2020-05-07 18:13:15	2020-05-07	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11686	delivery	5	22
59632	2020-05-07 18:14:46	2020-05-07	12	[{"id_menu":1,"count":1}]	8684	delivery	5	17
59633	2020-05-07 18:14:56	2020-05-07	17	[{"id_menu":4,"count":1}]	23617	delivery	5	22
59634	2020-05-07 18:15:09	2020-05-07	14	[{"id_menu":2,"count":2}]	2616	delivery	5	19
59635	2020-05-07 18:30:13	2020-05-07	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1677	delivery	5	22
59636	2020-05-07 18:31:22	2020-05-07	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	23709	pick-up	0	20
59637	2020-05-07 18:33:28	2020-05-07	14	[{"id_menu":2,"count":2}]	23585	pick-up	0	14
59638	2020-05-07 18:34:44	2020-05-07	8	[{"id_menu":5,"count":1}]	19957	pick-up	0	8
59639	2020-05-07 18:35:04	2020-05-07	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23669	delivery	5	39
59640	2020-05-07 18:41:03	2020-05-07	9	[{"id_menu":6,"count":1}]	23715	delivery	5	14
59641	2020-05-07 18:43:05	2020-05-07	12	[{"id_menu":3,"count":1}]	2956	pick-up	0	12
59642	2020-05-07 18:44:40	2020-05-07	8	[{"id_menu":5,"count":2}]	5538	pick-up	0	8
59643	2020-05-07 18:45:30	2020-05-07	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	18959	delivery	5	40
59644	2020-05-07 18:48:01	2020-05-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	23618	delivery	5	28
59645	2020-05-07 18:51:26	2020-05-07	8	[{"id_menu":5,"count":1}]	6876	delivery	5	13
59646	2020-05-07 18:52:31	2020-05-07	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	23702	delivery	5	31
59647	2020-05-07 18:56:48	2020-05-07	12	[{"id_menu":3,"count":1}]	23636	delivery	5	17
59648	2020-05-07 18:57:13	2020-05-07	9	[{"id_menu":7,"count":1}]	10935	pick-up	0	9
59649	2020-05-07 18:58:54	2020-05-07	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	23605	delivery	5	43
59650	2020-05-07 19:01:44	2020-05-07	14	[{"id_menu":2,"count":1}]	1152	delivery	5	19
59651	2020-05-07 19:03:49	2020-05-07	8	[{"id_menu":5,"count":1}]	19005	pick-up	0	8
59652	2020-05-07 19:22:01	2020-05-07	8	[{"id_menu":5,"count":1}]	23708	pick-up	0	8
59653	2020-05-07 19:22:49	2020-05-07	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	19248	delivery	5	43
59654	2020-05-07 19:33:29	2020-05-07	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	8448	pick-up	0	38
59655	2020-05-07 19:35:31	2020-05-07	12	[{"id_menu":3,"count":1}]	12049	delivery	5	17
59656	2020-05-07 19:38:31	2020-05-07	17	[{"id_menu":4,"count":1}]	19995	delivery	5	22
59657	2020-05-07 19:40:54	2020-05-07	17	[{"id_menu":4,"count":1}]	22557	delivery	5	22
59658	2020-05-07 19:43:50	2020-05-07	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	5935	delivery	5	28
59659	2020-05-07 19:47:09	2020-05-07	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	22116	pick-up	0	21
59660	2020-05-07 19:51:04	2020-05-07	9	[{"id_menu":6,"count":1}]	23657	delivery	5	14
59661	2020-05-07 19:52:49	2020-05-07	14	[{"id_menu":2,"count":1}]	4892	delivery	5	19
59662	2020-05-07 19:53:44	2020-05-07	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2517	pick-up	0	25
59663	2020-05-07 20:02:17	2020-05-07	17	[{"id_menu":4,"count":1}]	5958	delivery	5	22
59664	2020-05-07 20:02:34	2020-05-07	12	[{"id_menu":3,"count":1}]	4034	delivery	5	17
59665	2020-05-07 20:05:23	2020-05-07	17	[{"id_menu":4,"count":1}]	23683	pick-up	0	17
59666	2020-05-07 20:11:58	2020-05-07	9	[{"id_menu":6,"count":2}]	3380	pick-up	0	9
59667	2020-05-07 20:17:22	2020-05-07	12	[{"id_menu":1,"count":1}]	13874	delivery	5	17
59668	2020-05-07 20:19:46	2020-05-07	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22832	delivery	5	36
59669	2020-05-07 20:33:56	2020-05-07	9	[{"id_menu":7,"count":1}]	660	pick-up	0	9
59670	2020-05-07 20:41:28	2020-05-07	8	[{"id_menu":5,"count":1}]	23713	pick-up	0	8
59671	2020-05-07 20:48:15	2020-05-07	9	[{"id_menu":6,"count":1}]	20934	delivery	5	14
59672	2020-05-07 20:51:13	2020-05-07	14	[{"id_menu":2,"count":1}]	23652	delivery	5	19
59673	2020-05-07 20:51:25	2020-05-07	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	23633	delivery	5	29
59674	2020-05-07 20:56:02	2020-05-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	23724	pick-up	0	23
59675	2020-05-07 20:56:28	2020-05-07	14	[{"id_menu":2,"count":1}]	23596	delivery	5	19
59676	2020-05-07 20:58:01	2020-05-07	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23653	delivery	5	45
59677	2020-05-07 20:59:30	2020-05-07	8	[{"id_menu":5,"count":1}]	23594	delivery	5	13
59678	2020-05-07 21:01:47	2020-05-07	12	[{"id_menu":3,"count":1}]	8380	delivery	5	17
59679	2020-05-07 21:05:06	2020-05-07	9	[{"id_menu":7,"count":1}]	13257	delivery	5	14
59680	2020-05-07 21:07:14	2020-05-07	14	[{"id_menu":2,"count":1}]	22626	pick-up	0	14
59681	2020-05-07 21:13:46	2020-05-07	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3463	pick-up	0	26
59682	2020-05-07 21:18:50	2020-05-07	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2172	pick-up	0	21
59683	2020-05-07 21:29:29	2020-05-07	12	[{"id_menu":3,"count":1}]	23685	delivery	5	17
59684	2020-05-07 21:36:36	2020-05-07	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7399	delivery	5	39
59685	2020-05-07 21:36:51	2020-05-07	12	[{"id_menu":1,"count":1}]	489	pick-up	0	12
59686	2020-05-07 21:41:32	2020-05-07	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2067	delivery	5	43
59687	2020-05-07 21:44:41	2020-05-07	12	[{"id_menu":3,"count":1}]	23704	delivery	5	17
59688	2020-05-07 21:49:00	2020-05-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19121	pick-up	0	18
59689	2020-05-07 21:58:33	2020-05-07	9	[{"id_menu":7,"count":1}]	13236	delivery	5	14
59690	2020-05-07 22:00:40	2020-05-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	17286	delivery	5	26
59691	2020-05-07 22:03:10	2020-05-07	12	[{"id_menu":3,"count":1}]	22088	delivery	5	17
59692	2020-05-07 22:11:24	2020-05-07	17	[{"id_menu":4,"count":1}]	23611	delivery	5	22
59693	2020-05-07 22:11:26	2020-05-07	12	[{"id_menu":1,"count":2}]	7678	pick-up	0	12
59694	2020-05-07 22:16:51	2020-05-07	12	[{"id_menu":3,"count":1}]	23710	delivery	5	17
59695	2020-05-07 22:19:13	2020-05-07	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	21461	delivery	5	31
59696	2020-05-07 22:22:15	2020-05-07	14	[{"id_menu":2,"count":1}]	6469	pick-up	0	14
59697	2020-05-07 22:23:43	2020-05-07	9	[{"id_menu":6,"count":1}]	8141	pick-up	0	9
59698	2020-05-07 22:27:03	2020-05-07	9	[{"id_menu":7,"count":1}]	17562	delivery	5	14
59699	2020-05-07 22:37:34	2020-05-07	17	[{"id_menu":4,"count":1}]	6982	pick-up	0	17
59700	2020-05-07 22:37:36	2020-05-07	12	[{"id_menu":1,"count":1}]	17397	pick-up	0	12
59701	2020-05-07 22:38:51	2020-05-07	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2843	delivery	5	26
59702	2020-05-07 22:44:26	2020-05-07	9	[{"id_menu":7,"count":2}]	23647	delivery	5	14
59703	2020-05-07 22:53:42	2020-05-07	14	[{"id_menu":2,"count":1}]	22380	delivery	5	19
59704	2020-05-07 22:59:22	2020-05-07	8	[{"id_menu":5,"count":2}]	9522	pick-up	0	8
59705	2020-05-07 23:00:35	2020-05-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2280	delivery	5	28
59706	2020-05-07 23:04:48	2020-05-07	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	23671	delivery	5	26
59707	2020-05-07 23:04:50	2020-05-07	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	6589	pick-up	0	20
59708	2020-05-07 23:07:21	2020-05-07	12	[{"id_menu":1,"count":1}]	23670	delivery	5	17
59709	2020-05-07 23:09:10	2020-05-07	9	[{"id_menu":7,"count":1}]	6369	pick-up	0	9
59710	2020-05-07 23:14:20	2020-05-07	12	[{"id_menu":3,"count":1}]	23651	delivery	5	17
59711	2020-05-07 23:14:26	2020-05-07	8	[{"id_menu":5,"count":1}]	5675	delivery	5	13
59712	2020-05-07 23:15:29	2020-05-07	9	[{"id_menu":7,"count":1}]	23627	delivery	5	14
59713	2020-05-07 23:17:02	2020-05-07	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	23682	delivery	5	35
59714	2020-05-07 23:18:09	2020-05-07	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	3205	pick-up	0	26
59715	2020-05-07 23:19:02	2020-05-07	8	[{"id_menu":5,"count":2}]	23700	delivery	5	13
59716	2020-05-07 23:19:11	2020-05-07	9	[{"id_menu":7,"count":1}]	21867	pick-up	0	9
59717	2020-05-07 23:20:48	2020-05-07	9	[{"id_menu":7,"count":1}]	285	delivery	5	14
59718	2020-05-07 23:24:27	2020-05-07	12	[{"id_menu":3,"count":1}]	8065	pick-up	0	12
59719	2020-05-07 23:25:10	2020-05-07	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	18299	delivery	5	34
59720	2020-05-07 23:26:14	2020-05-07	17	[{"id_menu":4,"count":1}]	3841	pick-up	0	17
59721	2020-05-07 23:27:37	2020-05-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	20239	delivery	5	28
59722	2020-05-07 23:29:25	2020-05-07	9	[{"id_menu":6,"count":1}]	23604	delivery	5	14
59723	2020-05-07 23:29:44	2020-05-07	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20027	delivery	5	48
59724	2020-05-07 23:29:58	2020-05-07	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	4395	pick-up	0	24
59725	2020-05-07 23:30:01	2020-05-07	9	[{"id_menu":6,"count":1}]	15908	delivery	5	14
59726	2020-05-07 23:45:22	2020-05-07	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14824	pick-up	0	26
59727	2020-05-07 23:50:42	2020-05-07	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	22969	pick-up	0	31
59728	2020-05-07 23:53:27	2020-05-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1138	delivery	5	28
59729	2020-05-07 23:53:41	2020-05-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6097	pick-up	0	23
59730	2020-05-07 23:54:37	2020-05-07	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	16737	delivery	5	34
59731	2020-05-07 23:56:46	2020-05-07	17	[{"id_menu":4,"count":1}]	23690	delivery	5	22
59732	2020-05-07 23:56:51	2020-05-07	9	[{"id_menu":6,"count":1}]	10518	delivery	5	14
59733	2020-05-08 00:00:47	2020-05-08	14	[{"id_menu":2,"count":1}]	18230	delivery	5	19
59734	2020-05-08 00:17:36	2020-05-08	17	[{"id_menu":4,"count":1}]	9095	delivery	5	22
59735	2020-05-08 00:23:25	2020-05-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1104	delivery	5	28
59736	2020-05-08 00:26:47	2020-05-08	14	[{"id_menu":2,"count":1}]	7151	pick-up	0	14
59737	2020-05-08 00:30:05	2020-05-08	12	[{"id_menu":3,"count":1}]	17048	delivery	5	17
59738	2020-05-08 00:32:00	2020-05-08	12	[{"id_menu":1,"count":1}]	10151	delivery	5	17
59739	2020-05-08 00:39:16	2020-05-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9439	delivery	5	28
59740	2020-05-08 00:47:38	2020-05-08	8	[{"id_menu":5,"count":2}]	20511	delivery	5	13
59741	2020-05-08 00:54:48	2020-05-08	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	18374	pick-up	0	21
59742	2020-05-08 00:59:24	2020-05-08	9	[{"id_menu":6,"count":1}]	23865	delivery	5	14
59743	2020-05-08 01:02:16	2020-05-08	8	[{"id_menu":5,"count":1}]	14783	delivery	5	13
59744	2020-05-08 01:02:24	2020-05-08	17	[{"id_menu":4,"count":1}]	6046	delivery	5	22
59745	2020-05-08 01:05:22	2020-05-08	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	23883	delivery	5	31
59746	2020-05-08 01:09:45	2020-05-08	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	23841	pick-up	0	26
59747	2020-05-08 01:11:08	2020-05-08	14	[{"id_menu":2,"count":1}]	6255	delivery	5	19
59748	2020-05-08 01:11:34	2020-05-08	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23786	delivery	5	31
59749	2020-05-08 01:14:41	2020-05-08	12	[{"id_menu":3,"count":1}]	23765	delivery	5	17
59750	2020-05-08 01:18:21	2020-05-08	9	[{"id_menu":6,"count":1}]	8424	delivery	5	14
59751	2020-05-08 01:22:59	2020-05-08	12	[{"id_menu":3,"count":1}]	17530	delivery	5	17
59752	2020-05-08 01:25:10	2020-05-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":3}]	12975	delivery	5	22
59753	2020-05-08 01:28:01	2020-05-08	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	16637	delivery	5	27
59754	2020-05-08 01:30:15	2020-05-08	8	[{"id_menu":5,"count":1}]	23755	delivery	5	13
59755	2020-05-08 01:32:20	2020-05-08	9	[{"id_menu":6,"count":1}]	23893	delivery	5	14
59756	2020-05-08 01:37:14	2020-05-08	12	[{"id_menu":1,"count":1}]	1676	delivery	5	17
59757	2020-05-08 01:44:14	2020-05-08	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23854	delivery	5	40
59758	2020-05-08 01:47:40	2020-05-08	9	[{"id_menu":6,"count":1}]	23773	delivery	5	14
59759	2020-05-08 01:48:28	2020-05-08	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15191	delivery	5	49
59760	2020-05-08 01:50:13	2020-05-08	12	[{"id_menu":3,"count":1}]	8267	delivery	5	17
59761	2020-05-08 01:53:34	2020-05-08	9	[{"id_menu":7,"count":1}]	3151	pick-up	0	9
59762	2020-05-08 02:05:34	2020-05-08	14	[{"id_menu":2,"count":1}]	23850	delivery	5	19
59763	2020-05-08 02:06:17	2020-05-08	12	[{"id_menu":1,"count":1}]	3971	pick-up	0	12
59764	2020-05-08 02:13:26	2020-05-08	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	12332	pick-up	0	21
59765	2020-05-08 02:20:28	2020-05-08	12	[{"id_menu":1,"count":1}]	23794	delivery	5	17
59766	2020-05-08 02:20:35	2020-05-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	23750	delivery	5	28
59767	2020-05-08 02:20:41	2020-05-08	9	[{"id_menu":6,"count":1}]	2392	delivery	5	14
59768	2020-05-08 02:22:06	2020-05-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	18847	delivery	5	23
59769	2020-05-08 02:23:05	2020-05-08	12	[{"id_menu":1,"count":1}]	23843	delivery	5	17
59770	2020-05-08 02:28:47	2020-05-08	9	[{"id_menu":6,"count":1}]	23831	pick-up	0	9
59771	2020-05-08 02:34:53	2020-05-08	9	[{"id_menu":6,"count":1}]	4495	delivery	5	14
59772	2020-05-08 02:46:39	2020-05-08	9	[{"id_menu":7,"count":1}]	23769	delivery	5	14
59773	2020-05-08 02:54:59	2020-05-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	399	delivery	5	28
59774	2020-05-08 02:57:06	2020-05-08	12	[{"id_menu":3,"count":1}]	13806	pick-up	0	12
59775	2020-05-08 02:58:15	2020-05-08	12	[{"id_menu":3,"count":1}]	23272	delivery	5	17
59776	2020-05-08 03:05:06	2020-05-08	12	[{"id_menu":3,"count":1}]	10598	delivery	5	17
59777	2020-05-08 03:08:02	2020-05-08	9	[{"id_menu":6,"count":1}]	5085	delivery	5	14
59778	2020-05-08 03:13:41	2020-05-08	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12876	delivery	5	43
59779	2020-05-08 03:15:41	2020-05-08	17	[{"id_menu":4,"count":1}]	23856	delivery	5	22
59780	2020-05-08 03:16:37	2020-05-08	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	23797	pick-up	0	26
59781	2020-05-08 03:16:46	2020-05-08	9	[{"id_menu":6,"count":1}]	23844	delivery	5	14
59782	2020-05-08 03:20:17	2020-05-08	14	[{"id_menu":2,"count":1}]	9913	pick-up	0	14
59783	2020-05-08 03:21:20	2020-05-08	9	[{"id_menu":6,"count":1}]	8104	delivery	5	14
59784	2020-05-08 03:28:14	2020-05-08	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2753	pick-up	0	21
59785	2020-05-08 03:31:44	2020-05-08	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6919	delivery	5	36
59786	2020-05-08 03:32:00	2020-05-08	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	23775	delivery	5	56
59787	2020-05-08 03:37:12	2020-05-08	9	[{"id_menu":7,"count":1}]	6363	delivery	5	14
59788	2020-05-08 03:41:43	2020-05-08	8	[{"id_menu":5,"count":1}]	6138	pick-up	0	8
59789	2020-05-08 03:41:56	2020-05-08	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23897	delivery	5	51
59790	2020-05-08 03:48:12	2020-05-08	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7572	pick-up	0	26
59791	2020-05-08 03:51:48	2020-05-08	14	[{"id_menu":2,"count":1}]	16857	delivery	5	19
59792	2020-05-08 03:54:50	2020-05-08	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	16091	delivery	5	31
59793	2020-05-08 04:04:01	2020-05-08	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	23729	delivery	5	31
59794	2020-05-08 04:04:32	2020-05-08	14	[{"id_menu":2,"count":1}]	11454	pick-up	0	14
59795	2020-05-08 04:16:14	2020-05-08	8	[{"id_menu":5,"count":1}]	7666	delivery	5	13
59796	2020-05-08 04:18:56	2020-05-08	12	[{"id_menu":3,"count":1}]	9809	delivery	5	17
59797	2020-05-08 04:20:25	2020-05-08	12	[{"id_menu":3,"count":2}]	3040	delivery	5	17
59798	2020-05-08 04:25:35	2020-05-08	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	18951	delivery	5	43
59799	2020-05-08 04:33:34	2020-05-08	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23882	delivery	5	36
59800	2020-05-08 04:35:24	2020-05-08	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	23909	delivery	5	30
59801	2020-05-08 04:38:39	2020-05-08	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1128	pick-up	0	41
59802	2020-05-08 04:50:35	2020-05-08	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	14882	delivery	5	26
59803	2020-05-08 04:55:31	2020-05-08	9	[{"id_menu":6,"count":1}]	12855	delivery	5	14
59804	2020-05-08 04:56:16	2020-05-08	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	8082	delivery	5	39
59805	2020-05-08 04:57:34	2020-05-08	14	[{"id_menu":2,"count":1}]	22394	delivery	5	19
59806	2020-05-08 04:58:10	2020-05-08	17	[{"id_menu":4,"count":1}]	10393	pick-up	0	17
59807	2020-05-08 04:58:50	2020-05-08	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	22948	delivery	5	31
59808	2020-05-08 04:59:34	2020-05-08	14	[{"id_menu":2,"count":1}]	16466	pick-up	0	14
59809	2020-05-08 05:05:28	2020-05-08	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	18347	pick-up	0	20
59810	2020-05-08 05:10:15	2020-05-08	14	[{"id_menu":2,"count":2}]	19383	delivery	5	19
59811	2020-05-08 05:11:12	2020-05-08	17	[{"id_menu":4,"count":1}]	23836	delivery	5	22
59812	2020-05-08 05:19:11	2020-05-08	9	[{"id_menu":6,"count":1}]	23842	delivery	5	14
59813	2020-05-08 05:27:27	2020-05-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4546	pick-up	0	23
59814	2020-05-08 05:27:56	2020-05-08	8	[{"id_menu":5,"count":1}]	23811	delivery	5	13
59815	2020-05-08 05:28:20	2020-05-08	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	23785	delivery	5	26
59816	2020-05-08 05:30:46	2020-05-08	12	[{"id_menu":3,"count":1}]	23847	delivery	5	17
59817	2020-05-08 05:38:52	2020-05-08	9	[{"id_menu":7,"count":2}]	17790	pick-up	0	9
59818	2020-05-08 05:50:29	2020-05-08	8	[{"id_menu":5,"count":1}]	2984	delivery	5	13
59819	2020-05-08 05:50:57	2020-05-08	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	9610	pick-up	0	38
59820	2020-05-08 05:54:57	2020-05-08	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	23736	delivery	5	43
59821	2020-05-08 05:57:35	2020-05-08	9	[{"id_menu":6,"count":1}]	23754	delivery	5	14
59822	2020-05-08 06:00:58	2020-05-08	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2572	pick-up	0	26
59823	2020-05-08 06:01:18	2020-05-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23862	delivery	5	23
59824	2020-05-08 06:02:28	2020-05-08	12	[{"id_menu":1,"count":1}]	20318	delivery	5	17
59825	2020-05-08 06:04:53	2020-05-08	12	[{"id_menu":3,"count":1}]	23787	delivery	5	17
59826	2020-05-08 06:05:38	2020-05-08	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	8238	delivery	5	25
59827	2020-05-08 06:06:45	2020-05-08	12	[{"id_menu":1,"count":1}]	4704	delivery	5	17
59828	2020-05-08 06:09:33	2020-05-08	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	23907	delivery	5	39
59829	2020-05-08 06:29:14	2020-05-08	12	[{"id_menu":1,"count":1}]	22603	pick-up	0	12
59830	2020-05-08 06:29:32	2020-05-08	9	[{"id_menu":7,"count":1}]	23838	delivery	5	14
59831	2020-05-08 06:32:30	2020-05-08	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	23759	delivery	5	23
59832	2020-05-08 06:36:35	2020-05-08	9	[{"id_menu":6,"count":1}]	6453	delivery	5	14
59833	2020-05-08 06:41:14	2020-05-08	8	[{"id_menu":5,"count":1}]	8827	pick-up	0	8
59834	2020-05-08 06:51:44	2020-05-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	23861	delivery	5	28
59835	2020-05-08 06:52:44	2020-05-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9728	pick-up	0	23
59836	2020-05-08 06:54:21	2020-05-08	9	[{"id_menu":7,"count":1}]	22751	delivery	5	14
59837	2020-05-08 06:58:09	2020-05-08	12	[{"id_menu":3,"count":1}]	23737	delivery	5	17
59838	2020-05-08 07:01:19	2020-05-08	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10354	delivery	5	30
59839	2020-05-08 07:02:38	2020-05-08	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23887	delivery	5	34
59840	2020-05-08 07:03:36	2020-05-08	12	[{"id_menu":3,"count":1}]	7847	delivery	5	17
59841	2020-05-08 07:05:15	2020-05-08	9	[{"id_menu":7,"count":1}]	23743	delivery	5	14
59842	2020-05-08 07:07:54	2020-05-08	14	[{"id_menu":2,"count":1}]	363	delivery	5	19
59843	2020-05-08 07:08:05	2020-05-08	12	[{"id_menu":1,"count":1}]	13371	delivery	5	17
59844	2020-05-08 07:09:02	2020-05-08	12	[{"id_menu":1,"count":1}]	23864	delivery	5	17
59845	2020-05-08 07:17:02	2020-05-08	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	5899	pick-up	0	26
59846	2020-05-08 07:17:16	2020-05-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5668	pick-up	0	23
59847	2020-05-08 07:24:16	2020-05-08	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4847	pick-up	0	21
59848	2020-05-08 07:29:59	2020-05-08	17	[{"id_menu":4,"count":1}]	10255	delivery	5	22
59849	2020-05-08 07:35:20	2020-05-08	9	[{"id_menu":6,"count":1}]	23822	delivery	5	14
59850	2020-05-08 07:38:08	2020-05-08	8	[{"id_menu":5,"count":1}]	23800	pick-up	0	8
59851	2020-05-08 07:41:58	2020-05-08	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	4479	pick-up	0	20
59852	2020-05-08 07:46:08	2020-05-08	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	23762	delivery	5	34
59853	2020-05-08 07:49:25	2020-05-08	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	9632	delivery	5	37
59854	2020-05-08 07:53:46	2020-05-08	14	[{"id_menu":2,"count":1}]	1415	delivery	5	19
59855	2020-05-08 07:55:52	2020-05-08	8	[{"id_menu":5,"count":1}]	23789	delivery	5	13
59856	2020-05-08 07:56:11	2020-05-08	12	[{"id_menu":3,"count":1}]	16480	delivery	5	17
59857	2020-05-08 08:00:53	2020-05-08	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23877	delivery	5	37
59858	2020-05-08 08:00:54	2020-05-08	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	440	delivery	5	31
59859	2020-05-08 08:01:46	2020-05-08	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3399	pick-up	0	25
59860	2020-05-08 08:03:33	2020-05-08	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	19507	delivery	5	31
59861	2020-05-08 08:03:41	2020-05-08	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	23829	delivery	5	23
59862	2020-05-08 08:07:38	2020-05-08	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	23891	delivery	5	22
59863	2020-05-08 08:08:30	2020-05-08	9	[{"id_menu":6,"count":1}]	19249	delivery	5	14
59864	2020-05-08 08:11:14	2020-05-08	14	[{"id_menu":2,"count":1}]	23776	delivery	5	19
59865	2020-05-08 08:12:24	2020-05-08	9	[{"id_menu":7,"count":1}]	23793	delivery	5	14
59866	2020-05-08 08:14:53	2020-05-08	14	[{"id_menu":2,"count":1}]	23915	delivery	5	19
59867	2020-05-08 08:27:19	2020-05-08	9	[{"id_menu":7,"count":2}]	23876	delivery	5	14
59868	2020-05-08 08:27:58	2020-05-08	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2266	pick-up	0	33
59869	2020-05-08 08:29:26	2020-05-08	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	12949	delivery	5	26
59870	2020-05-08 08:32:02	2020-05-08	14	[{"id_menu":2,"count":1}]	10244	pick-up	0	14
59871	2020-05-08 08:36:40	2020-05-08	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	19172	delivery	5	28
59872	2020-05-08 08:38:51	2020-05-08	8	[{"id_menu":5,"count":1}]	2806	delivery	5	13
59873	2020-05-08 08:39:11	2020-05-08	12	[{"id_menu":3,"count":1}]	18067	delivery	5	17
59874	2020-05-08 08:41:46	2020-05-08	17	[{"id_menu":4,"count":1}]	1582	pick-up	0	17
59875	2020-05-08 08:43:13	2020-05-08	9	[{"id_menu":7,"count":1}]	14432	pick-up	0	9
59876	2020-05-08 08:46:10	2020-05-08	9	[{"id_menu":7,"count":1}]	23782	pick-up	0	9
59877	2020-05-08 08:50:14	2020-05-08	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	15894	delivery	5	40
59878	2020-05-08 08:51:51	2020-05-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10452	pick-up	0	18
59879	2020-05-08 09:01:41	2020-05-08	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3063	delivery	5	31
59880	2020-05-08 09:02:05	2020-05-08	12	[{"id_menu":1,"count":1}]	9039	delivery	5	17
59881	2020-05-08 09:03:40	2020-05-08	8	[{"id_menu":5,"count":1}]	23802	delivery	5	13
59882	2020-05-08 09:05:13	2020-05-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19485	delivery	5	22
59883	2020-05-08 09:06:38	2020-05-08	17	[{"id_menu":4,"count":1}]	21066	delivery	5	22
59884	2020-05-08 09:11:13	2020-05-08	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23914	delivery	5	37
59885	2020-05-08 09:16:08	2020-05-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3996	delivery	5	28
59886	2020-05-08 09:19:48	2020-05-08	14	[{"id_menu":2,"count":2}]	20549	pick-up	0	14
59887	2020-05-08 09:26:15	2020-05-08	14	[{"id_menu":2,"count":1}]	20558	delivery	5	19
59888	2020-05-08 09:34:30	2020-05-08	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	22713	delivery	5	31
59889	2020-05-08 09:35:04	2020-05-08	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	5663	delivery	5	26
59890	2020-05-08 09:36:39	2020-05-08	9	[{"id_menu":7,"count":1}]	3860	delivery	5	14
59891	2020-05-08 09:36:42	2020-05-08	8	[{"id_menu":5,"count":1}]	17392	pick-up	0	8
59892	2020-05-08 09:36:52	2020-05-08	12	[{"id_menu":3,"count":1}]	1015	delivery	5	17
59893	2020-05-08 09:42:45	2020-05-08	12	[{"id_menu":3,"count":1}]	14480	pick-up	0	12
59894	2020-05-08 09:47:49	2020-05-08	14	[{"id_menu":2,"count":1}]	6037	pick-up	0	14
59895	2020-05-08 09:48:02	2020-05-08	12	[{"id_menu":3,"count":1}]	10267	delivery	5	17
59896	2020-05-08 09:49:17	2020-05-08	12	[{"id_menu":1,"count":1}]	7301	pick-up	0	12
59897	2020-05-08 09:50:40	2020-05-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	13713	delivery	5	23
59898	2020-05-08 09:58:11	2020-05-08	9	[{"id_menu":7,"count":1}]	23749	delivery	5	14
59899	2020-05-08 10:00:48	2020-05-08	8	[{"id_menu":5,"count":1}]	96	pick-up	0	8
59900	2020-05-08 10:12:06	2020-05-08	14	[{"id_menu":2,"count":2}]	7448	delivery	5	19
59901	2020-05-08 10:17:50	2020-05-08	12	[{"id_menu":1,"count":1}]	22606	delivery	5	17
59902	2020-05-08 10:27:18	2020-05-08	8	[{"id_menu":5,"count":1}]	9718	delivery	5	13
59903	2020-05-08 10:30:55	2020-05-08	12	[{"id_menu":3,"count":1}]	23801	delivery	5	17
59904	2020-05-08 10:32:08	2020-05-08	12	[{"id_menu":3,"count":1}]	15976	pick-up	0	12
59905	2020-05-08 10:38:07	2020-05-08	14	[{"id_menu":2,"count":1}]	6243	delivery	5	19
59906	2020-05-08 10:44:58	2020-05-08	9	[{"id_menu":6,"count":1}]	23846	delivery	5	14
59907	2020-05-08 10:46:43	2020-05-08	9	[{"id_menu":6,"count":2}]	1831	pick-up	0	9
59908	2020-05-08 10:50:53	2020-05-08	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	23299	delivery	5	26
59909	2020-05-08 10:51:51	2020-05-08	9	[{"id_menu":7,"count":1}]	2519	pick-up	0	9
59910	2020-05-08 10:54:09	2020-05-08	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15262	delivery	5	45
59911	2020-05-08 10:54:48	2020-05-08	14	[{"id_menu":2,"count":1}]	9093	delivery	5	19
59912	2020-05-08 11:01:53	2020-05-08	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	12132	delivery	5	38
59913	2020-05-08 11:03:05	2020-05-08	17	[{"id_menu":4,"count":1}]	23781	delivery	5	22
59914	2020-05-08 11:09:53	2020-05-08	17	[{"id_menu":4,"count":1}]	23895	delivery	5	22
59915	2020-05-08 11:12:30	2020-05-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	23834	delivery	5	28
59916	2020-05-08 11:18:45	2020-05-08	14	[{"id_menu":2,"count":1}]	5701	pick-up	0	14
59917	2020-05-08 11:20:17	2020-05-08	9	[{"id_menu":7,"count":1}]	19313	delivery	5	14
59918	2020-05-08 11:25:30	2020-05-08	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3289	pick-up	0	26
59919	2020-05-08 11:27:17	2020-05-08	9	[{"id_menu":6,"count":1}]	7803	delivery	5	14
59920	2020-05-08 11:33:37	2020-05-08	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	138	pick-up	0	29
59921	2020-05-08 11:50:11	2020-05-08	17	[{"id_menu":4,"count":2}]	8774	pick-up	0	17
59922	2020-05-08 11:52:16	2020-05-08	17	[{"id_menu":4,"count":1}]	29	pick-up	0	17
59923	2020-05-08 11:54:35	2020-05-08	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	23906	delivery	5	34
59924	2020-05-08 12:04:23	2020-05-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10245	delivery	5	23
59925	2020-05-08 12:08:20	2020-05-08	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	19867	pick-up	0	35
59926	2020-05-08 12:09:22	2020-05-08	9	[{"id_menu":6,"count":1}]	21143	delivery	5	14
59927	2020-05-08 12:10:40	2020-05-08	12	[{"id_menu":1,"count":1}]	7816	delivery	5	17
59928	2020-05-08 12:14:55	2020-05-08	8	[{"id_menu":5,"count":1}]	23779	delivery	5	13
59929	2020-05-08 12:15:11	2020-05-08	9	[{"id_menu":6,"count":1}]	8757	pick-up	0	9
59930	2020-05-08 12:17:58	2020-05-08	14	[{"id_menu":2,"count":1}]	21298	delivery	5	19
59931	2020-05-08 12:18:40	2020-05-08	14	[{"id_menu":2,"count":1}]	15361	delivery	5	19
59932	2020-05-08 12:21:08	2020-05-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19100	pick-up	0	18
59933	2020-05-08 12:22:07	2020-05-08	17	[{"id_menu":5,"count":3},{"id_menu":7,"count":1}]	13404	delivery	5	22
59934	2020-05-08 12:25:28	2020-05-08	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	2250	pick-up	0	26
59935	2020-05-08 12:30:30	2020-05-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	23904	delivery	5	28
59936	2020-05-08 12:34:45	2020-05-08	9	[{"id_menu":7,"count":1}]	9066	delivery	5	14
59937	2020-05-08 12:35:13	2020-05-08	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10690	delivery	5	31
59938	2020-05-08 12:39:24	2020-05-08	14	[{"id_menu":2,"count":1}]	21993	delivery	5	19
59939	2020-05-08 12:47:54	2020-05-08	9	[{"id_menu":6,"count":1}]	23911	delivery	5	14
59940	2020-05-08 12:52:16	2020-05-08	9	[{"id_menu":7,"count":1}]	2474	pick-up	0	9
59941	2020-05-08 12:52:44	2020-05-08	8	[{"id_menu":5,"count":1}]	4130	delivery	5	13
59942	2020-05-08 12:55:11	2020-05-08	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	3835	delivery	5	23
59943	2020-05-08 12:57:44	2020-05-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	5109	delivery	5	28
59944	2020-05-08 12:57:58	2020-05-08	17	[{"id_menu":4,"count":1}]	23857	delivery	5	22
59945	2020-05-08 13:01:25	2020-05-08	9	[{"id_menu":6,"count":1}]	23806	delivery	5	14
59946	2020-05-08 13:02:03	2020-05-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23892	delivery	5	23
59947	2020-05-08 13:10:00	2020-05-08	17	[{"id_menu":4,"count":1}]	17138	pick-up	0	17
59948	2020-05-08 13:10:50	2020-05-08	9	[{"id_menu":7,"count":1}]	19583	delivery	5	14
59949	2020-05-08 13:11:03	2020-05-08	12	[{"id_menu":3,"count":1}]	20203	delivery	5	17
59950	2020-05-08 13:24:11	2020-05-08	14	[{"id_menu":2,"count":1}]	7931	delivery	5	19
59951	2020-05-08 13:29:47	2020-05-08	9	[{"id_menu":7,"count":2}]	1893	pick-up	0	9
59952	2020-05-08 13:32:40	2020-05-08	9	[{"id_menu":6,"count":1}]	7740	delivery	5	14
59953	2020-05-08 13:42:31	2020-05-08	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	4136	delivery	5	26
59954	2020-05-08 13:45:21	2020-05-08	9	[{"id_menu":7,"count":1}]	7046	pick-up	0	9
59955	2020-05-08 13:47:03	2020-05-08	9	[{"id_menu":7,"count":1}]	23752	delivery	5	14
59956	2020-05-08 13:49:23	2020-05-08	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	23905	delivery	5	22
59957	2020-05-08 13:51:05	2020-05-08	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	23917	pick-up	0	26
59958	2020-05-08 13:53:09	2020-05-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2173	pick-up	0	17
59959	2020-05-08 13:55:35	2020-05-08	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":3}]	23878	delivery	5	26
59960	2020-05-08 13:56:40	2020-05-08	8	[{"id_menu":5,"count":1}]	23912	delivery	5	13
59961	2020-05-08 14:00:36	2020-05-08	17	[{"id_menu":4,"count":1}]	19490	pick-up	0	17
59962	2020-05-08 14:05:13	2020-05-08	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	17770	delivery	5	23
59963	2020-05-08 14:10:59	2020-05-08	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	15236	delivery	5	31
59964	2020-05-08 14:21:49	2020-05-08	9	[{"id_menu":7,"count":1}]	18612	delivery	5	14
59965	2020-05-08 14:24:02	2020-05-08	9	[{"id_menu":7,"count":1}]	12640	delivery	5	14
59966	2020-05-08 14:30:16	2020-05-08	12	[{"id_menu":1,"count":1}]	12072	delivery	5	17
59967	2020-05-08 14:32:04	2020-05-08	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	10862	pick-up	0	23
59968	2020-05-08 14:38:48	2020-05-08	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	22598	delivery	5	43
59969	2020-05-08 14:39:59	2020-05-08	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	11295	delivery	5	34
59970	2020-05-08 14:40:00	2020-05-08	14	[{"id_menu":2,"count":1}]	23886	pick-up	0	14
59971	2020-05-08 14:52:36	2020-05-08	8	[{"id_menu":5,"count":1}]	17769	delivery	5	13
59972	2020-05-08 15:04:18	2020-05-08	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	23742	delivery	5	28
59973	2020-05-08 15:05:24	2020-05-08	8	[{"id_menu":5,"count":1}]	23405	delivery	5	13
59974	2020-05-08 15:10:09	2020-05-08	9	[{"id_menu":6,"count":2}]	22639	delivery	5	14
59975	2020-05-08 15:13:14	2020-05-08	14	[{"id_menu":2,"count":1}]	17402	delivery	5	19
59976	2020-05-08 15:15:02	2020-05-08	12	[{"id_menu":3,"count":1}]	9562	pick-up	0	12
59977	2020-05-08 15:21:14	2020-05-08	9	[{"id_menu":6,"count":1}]	10362	delivery	5	14
59978	2020-05-08 15:23:05	2020-05-08	17	[{"id_menu":4,"count":1}]	23873	delivery	5	22
59979	2020-05-08 15:23:24	2020-05-08	8	[{"id_menu":5,"count":1}]	23872	delivery	5	13
59980	2020-05-08 15:30:19	2020-05-08	12	[{"id_menu":3,"count":1}]	19729	delivery	5	17
59981	2020-05-08 15:31:13	2020-05-08	9	[{"id_menu":6,"count":1}]	5802	pick-up	0	9
59982	2020-05-08 15:35:12	2020-05-08	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	23814	delivery	5	36
59983	2020-05-08 15:35:40	2020-05-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23745	delivery	5	22
59984	2020-05-08 15:36:30	2020-05-08	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23828	delivery	5	35
59985	2020-05-08 15:37:02	2020-05-08	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23792	delivery	5	36
59986	2020-05-08 15:54:04	2020-05-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2208	pick-up	0	18
59987	2020-05-08 16:01:40	2020-05-08	17	[{"id_menu":4,"count":1}]	17794	delivery	5	22
59988	2020-05-08 16:05:02	2020-05-08	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23795	delivery	5	40
59989	2020-05-08 16:05:04	2020-05-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	11667	delivery	5	28
59990	2020-05-08 16:09:04	2020-05-08	33	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	23756	delivery	5	38
59991	2020-05-08 16:13:03	2020-05-08	14	[{"id_menu":2,"count":1}]	7316	delivery	5	19
59992	2020-05-08 16:15:32	2020-05-08	8	[{"id_menu":5,"count":3}]	23817	delivery	5	13
59993	2020-05-08 16:22:26	2020-05-08	12	[{"id_menu":1,"count":1}]	3621	delivery	5	17
59994	2020-05-08 16:32:57	2020-05-08	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":2}]	23804	delivery	5	31
59995	2020-05-08 16:33:15	2020-05-08	9	[{"id_menu":6,"count":1}]	1738	pick-up	0	9
59996	2020-05-08 16:39:50	2020-05-08	12	[{"id_menu":3,"count":1}]	23845	delivery	5	17
59997	2020-05-08 16:43:37	2020-05-08	9	[{"id_menu":6,"count":1}]	23820	delivery	5	14
59998	2020-05-08 16:44:24	2020-05-08	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	19554	pick-up	0	29
59999	2020-05-08 16:47:35	2020-05-08	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":2}]	11543	delivery	5	22
60000	2020-05-08 16:54:14	2020-05-08	14	[{"id_menu":2,"count":1}]	21278	delivery	5	19
60001	2020-05-08 17:02:51	2020-05-08	17	[{"id_menu":4,"count":1}]	23766	delivery	5	22
60002	2020-05-08 17:04:52	2020-05-08	9	[{"id_menu":6,"count":1}]	927	delivery	5	14
60003	2020-05-08 17:05:55	2020-05-08	8	[{"id_menu":5,"count":1}]	4616	delivery	5	13
60004	2020-05-08 17:06:06	2020-05-08	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	23761	delivery	5	39
60005	2020-05-08 17:12:40	2020-05-08	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	11963	pick-up	0	31
60006	2020-05-08 17:15:15	2020-05-08	9	[{"id_menu":7,"count":1}]	10795	pick-up	0	9
60007	2020-05-08 17:15:40	2020-05-08	8	[{"id_menu":5,"count":1}]	23810	delivery	5	13
60008	2020-05-08 17:20:06	2020-05-08	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	5387	pick-up	0	26
60009	2020-05-08 17:33:17	2020-05-08	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":2}]	23739	delivery	5	31
60010	2020-05-08 17:37:11	2020-05-08	9	[{"id_menu":6,"count":1}]	23758	delivery	5	14
60011	2020-05-08 17:43:12	2020-05-08	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12905	pick-up	0	31
60012	2020-05-08 17:43:17	2020-05-08	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23784	delivery	5	52
60013	2020-05-08 17:43:54	2020-05-08	9	[{"id_menu":7,"count":1}]	9609	delivery	5	14
60014	2020-05-08 17:47:55	2020-05-08	17	[{"id_menu":4,"count":1}]	16282	delivery	5	22
60015	2020-05-08 17:49:30	2020-05-08	17	[{"id_menu":4,"count":1}]	12654	pick-up	0	17
60016	2020-05-08 17:50:03	2020-05-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8279	delivery	5	22
60017	2020-05-08 17:51:58	2020-05-08	9	[{"id_menu":6,"count":1}]	23902	delivery	5	14
60018	2020-05-08 17:57:54	2020-05-08	14	[{"id_menu":2,"count":1}]	23824	delivery	5	19
60019	2020-05-08 17:59:15	2020-05-08	12	[{"id_menu":1,"count":1}]	3318	pick-up	0	12
60020	2020-05-08 18:04:13	2020-05-08	9	[{"id_menu":7,"count":2}]	22730	delivery	5	14
60021	2020-05-08 18:10:08	2020-05-08	12	[{"id_menu":1,"count":1}]	23881	delivery	5	17
60022	2020-05-08 18:19:40	2020-05-08	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	8711	delivery	5	26
60023	2020-05-08 18:20:10	2020-05-08	17	[{"id_menu":4,"count":1}]	19001	delivery	5	22
60024	2020-05-08 18:20:35	2020-05-08	12	[{"id_menu":3,"count":1}]	23896	pick-up	0	12
60025	2020-05-08 18:23:12	2020-05-08	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	23798	delivery	5	31
60026	2020-05-08 18:27:55	2020-05-08	14	[{"id_menu":2,"count":1}]	23866	delivery	5	19
60027	2020-05-08 18:29:08	2020-05-08	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2082	pick-up	0	26
60028	2020-05-08 18:29:11	2020-05-08	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	19104	delivery	5	28
60029	2020-05-08 18:35:24	2020-05-08	8	[{"id_menu":5,"count":1}]	23848	delivery	5	13
60030	2020-05-08 18:38:33	2020-05-08	8	[{"id_menu":5,"count":1}]	23860	delivery	5	13
60031	2020-05-08 18:39:43	2020-05-08	9	[{"id_menu":7,"count":1}]	23890	pick-up	0	9
60032	2020-05-08 18:41:31	2020-05-08	9	[{"id_menu":7,"count":1}]	2627	delivery	5	14
60033	2020-05-08 18:45:05	2020-05-08	9	[{"id_menu":7,"count":1}]	23772	delivery	5	14
60034	2020-05-08 18:50:18	2020-05-08	17	[{"id_menu":4,"count":1}]	23808	delivery	5	22
60035	2020-05-08 18:50:59	2020-05-08	9	[{"id_menu":7,"count":1}]	22279	delivery	5	14
60036	2020-05-08 18:53:25	2020-05-08	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	22647	delivery	5	31
60037	2020-05-08 18:55:03	2020-05-08	14	[{"id_menu":2,"count":1}]	16280	delivery	5	19
60038	2020-05-08 18:57:49	2020-05-08	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17874	pick-up	0	44
60039	2020-05-08 19:01:31	2020-05-08	14	[{"id_menu":2,"count":1}]	20499	delivery	5	19
60040	2020-05-08 19:03:22	2020-05-08	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	934	pick-up	0	21
60041	2020-05-08 19:16:35	2020-05-08	12	[{"id_menu":1,"count":1}]	23898	delivery	5	17
60042	2020-05-08 19:20:48	2020-05-08	9	[{"id_menu":7,"count":1}]	23880	pick-up	0	9
60043	2020-05-08 19:26:14	2020-05-08	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	17784	pick-up	0	31
60044	2020-05-08 19:30:45	2020-05-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23757	delivery	5	22
60045	2020-05-08 19:33:57	2020-05-08	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	22115	delivery	5	57
60046	2020-05-08 19:34:20	2020-05-08	8	[{"id_menu":5,"count":1}]	1032	delivery	5	13
60047	2020-05-08 19:39:04	2020-05-08	9	[{"id_menu":7,"count":1}]	23774	delivery	5	14
60048	2020-05-08 19:39:50	2020-05-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	19985	pick-up	0	23
60049	2020-05-08 19:40:02	2020-05-08	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4042	delivery	5	43
60050	2020-05-08 19:40:17	2020-05-08	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	19957	pick-up	0	21
60051	2020-05-08 19:41:47	2020-05-08	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	11172	delivery	5	36
60052	2020-05-08 20:00:16	2020-05-08	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	23827	delivery	5	43
60053	2020-05-08 20:04:18	2020-05-08	9	[{"id_menu":6,"count":1}]	5303	delivery	5	14
60054	2020-05-08 20:06:15	2020-05-08	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11150	delivery	5	22
60055	2020-05-08 20:07:35	2020-05-08	9	[{"id_menu":7,"count":2}]	17582	pick-up	0	9
60056	2020-05-08 20:08:59	2020-05-08	14	[{"id_menu":2,"count":1}]	23790	delivery	5	19
60057	2020-05-08 20:10:18	2020-05-08	14	[{"id_menu":2,"count":1}]	3172	pick-up	0	14
60058	2020-05-08 20:13:33	2020-05-08	8	[{"id_menu":5,"count":1}]	2699	pick-up	0	8
60059	2020-05-08 20:14:26	2020-05-08	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18126	delivery	5	54
60060	2020-05-08 20:17:01	2020-05-08	8	[{"id_menu":5,"count":1}]	19892	delivery	5	13
60061	2020-05-08 20:18:35	2020-05-08	17	[{"id_menu":4,"count":1}]	1255	delivery	5	22
60062	2020-05-08 20:20:47	2020-05-08	14	[{"id_menu":2,"count":1}]	8030	pick-up	0	14
60063	2020-05-08 20:22:23	2020-05-08	9	[{"id_menu":7,"count":1}]	21426	delivery	5	14
60064	2020-05-08 20:27:38	2020-05-08	12	[{"id_menu":1,"count":1}]	23869	pick-up	0	12
60065	2020-05-08 20:28:03	2020-05-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4640	delivery	5	28
60066	2020-05-08 20:29:18	2020-05-08	8	[{"id_menu":5,"count":1}]	23777	delivery	5	13
60067	2020-05-08 20:32:17	2020-05-08	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	8444	delivery	5	25
60068	2020-05-08 20:36:27	2020-05-08	17	[{"id_menu":4,"count":1}]	18890	delivery	5	22
60069	2020-05-08 20:43:32	2020-05-08	9	[{"id_menu":6,"count":1}]	23805	delivery	5	14
60070	2020-05-08 20:49:48	2020-05-08	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23225	pick-up	0	48
60071	2020-05-08 20:49:55	2020-05-08	8	[{"id_menu":5,"count":1}]	21771	delivery	5	13
60072	2020-05-08 21:02:44	2020-05-08	9	[{"id_menu":7,"count":1}]	12641	delivery	5	14
60073	2020-05-08 21:11:44	2020-05-08	17	[{"id_menu":4,"count":1}]	23913	delivery	5	22
60074	2020-05-08 21:14:11	2020-05-08	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23799	delivery	5	35
60075	2020-05-08 21:14:30	2020-05-08	17	[{"id_menu":4,"count":1}]	19929	delivery	5	22
60076	2020-05-08 21:20:38	2020-05-08	9	[{"id_menu":6,"count":1}]	9961	delivery	5	14
60077	2020-05-08 21:21:53	2020-05-08	8	[{"id_menu":5,"count":1}]	23837	delivery	5	13
60078	2020-05-08 21:26:11	2020-05-08	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9914	delivery	5	22
60079	2020-05-08 21:27:01	2020-05-08	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	199	pick-up	0	31
60080	2020-05-08 21:28:40	2020-05-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21904	delivery	5	23
60081	2020-05-08 21:29:02	2020-05-08	12	[{"id_menu":1,"count":1}]	8286	pick-up	0	12
60082	2020-05-08 21:32:11	2020-05-08	9	[{"id_menu":7,"count":2}]	14984	delivery	5	14
60083	2020-05-08 21:34:36	2020-05-08	12	[{"id_menu":3,"count":1}]	19085	delivery	5	17
60084	2020-05-08 21:39:13	2020-05-08	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23899	delivery	5	22
60085	2020-05-08 21:40:26	2020-05-08	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	11200	delivery	5	40
60086	2020-05-08 21:41:18	2020-05-08	12	[{"id_menu":1,"count":1}]	23716	delivery	5	17
60087	2020-05-08 21:43:24	2020-05-08	9	[{"id_menu":7,"count":1}]	14177	delivery	5	14
60088	2020-05-08 21:49:36	2020-05-08	9	[{"id_menu":7,"count":1}]	23901	delivery	5	14
60089	2020-05-08 21:51:15	2020-05-08	9	[{"id_menu":7,"count":1}]	7051	delivery	5	14
60090	2020-05-08 21:52:21	2020-05-08	8	[{"id_menu":5,"count":1}]	10113	delivery	5	13
60091	2020-05-08 21:52:32	2020-05-08	12	[{"id_menu":3,"count":1}]	5325	delivery	5	17
60092	2020-05-08 21:54:01	2020-05-08	8	[{"id_menu":5,"count":1}]	6437	delivery	5	13
60093	2020-05-08 21:55:19	2020-05-08	9	[{"id_menu":6,"count":1}]	18633	delivery	5	14
60094	2020-05-08 21:55:35	2020-05-08	12	[{"id_menu":3,"count":1}]	4637	pick-up	0	12
60095	2020-05-08 21:57:32	2020-05-08	9	[{"id_menu":7,"count":1}]	23863	delivery	5	14
60096	2020-05-08 22:02:33	2020-05-08	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	23819	delivery	5	43
60097	2020-05-08 22:03:17	2020-05-08	17	[{"id_menu":4,"count":1}]	9631	pick-up	0	17
60098	2020-05-08 22:06:30	2020-05-08	9	[{"id_menu":7,"count":1}]	3905	pick-up	0	9
60099	2020-05-08 22:11:13	2020-05-08	14	[{"id_menu":2,"count":1}]	23894	delivery	5	19
60100	2020-05-08 22:15:20	2020-05-08	14	[{"id_menu":2,"count":1}]	19761	pick-up	0	14
60101	2020-05-08 22:22:55	2020-05-08	9	[{"id_menu":7,"count":1}]	23826	delivery	5	14
60102	2020-05-08 22:23:41	2020-05-08	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	3887	delivery	5	39
60103	2020-05-08 22:37:37	2020-05-08	9	[{"id_menu":7,"count":1}]	18159	delivery	5	14
60104	2020-05-08 22:39:40	2020-05-08	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	5677	delivery	5	34
60105	2020-05-08 22:41:29	2020-05-08	12	[{"id_menu":1,"count":1}]	22414	delivery	5	17
60106	2020-05-08 22:45:39	2020-05-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23451	delivery	5	22
60107	2020-05-08 22:47:42	2020-05-08	9	[{"id_menu":7,"count":1}]	8236	delivery	5	14
60108	2020-05-08 22:47:54	2020-05-08	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23835	delivery	5	48
60109	2020-05-08 22:52:18	2020-05-08	14	[{"id_menu":2,"count":1}]	3357	pick-up	0	14
60110	2020-05-08 22:56:36	2020-05-08	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	6458	pick-up	0	24
60111	2020-05-08 22:59:24	2020-05-08	12	[{"id_menu":3,"count":1}]	23870	delivery	5	17
60112	2020-05-08 23:01:57	2020-05-08	9	[{"id_menu":6,"count":1}]	3823	delivery	5	14
60113	2020-05-08 23:04:20	2020-05-08	9	[{"id_menu":6,"count":1}]	8947	delivery	5	14
60114	2020-05-08 23:13:40	2020-05-08	14	[{"id_menu":2,"count":1}]	13193	pick-up	0	14
60115	2020-05-08 23:18:36	2020-05-08	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6221	delivery	5	36
60116	2020-05-08 23:33:44	2020-05-08	12	[{"id_menu":1,"count":1}]	3111	pick-up	0	12
60117	2020-05-08 23:34:36	2020-05-08	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	13603	delivery	5	38
60118	2020-05-08 23:35:07	2020-05-08	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20671	delivery	5	53
60119	2020-05-08 23:35:38	2020-05-08	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11360	delivery	5	40
60120	2020-05-08 23:36:35	2020-05-08	12	[{"id_menu":3,"count":1}]	22369	delivery	5	17
60121	2020-05-08 23:36:46	2020-05-08	12	[{"id_menu":1,"count":1}]	8341	pick-up	0	12
60122	2020-05-08 23:48:58	2020-05-08	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11232	pick-up	0	35
60123	2020-05-08 23:49:16	2020-05-08	9	[{"id_menu":6,"count":1}]	15400	delivery	5	14
60124	2020-05-08 23:52:14	2020-05-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8101	delivery	5	22
60125	2020-05-08 23:56:31	2020-05-08	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	23067	delivery	5	31
60126	2020-05-09 00:02:04	2020-05-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	5778	delivery	5	28
60127	2020-05-09 00:04:15	2020-05-09	12	[{"id_menu":3,"count":1}]	3527	pick-up	0	12
60128	2020-05-09 00:10:02	2020-05-09	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	15398	delivery	5	31
60129	2020-05-09 00:14:14	2020-05-09	9	[{"id_menu":7,"count":1}]	16443	delivery	5	14
60130	2020-05-09 00:15:01	2020-05-09	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	14662	pick-up	0	31
60131	2020-05-09 00:15:27	2020-05-09	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23969	delivery	5	39
60132	2020-05-09 00:15:48	2020-05-09	9	[{"id_menu":6,"count":1}]	23950	delivery	5	14
60133	2020-05-09 00:18:06	2020-05-09	12	[{"id_menu":3,"count":1}]	541	pick-up	0	12
60134	2020-05-09 00:19:57	2020-05-09	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	20084	delivery	5	25
60135	2020-05-09 00:21:06	2020-05-09	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14894	delivery	5	34
60136	2020-05-09 00:25:04	2020-05-09	17	[{"id_menu":4,"count":1}]	24050	delivery	5	22
60137	2020-05-09 00:25:53	2020-05-09	12	[{"id_menu":1,"count":1}]	23002	delivery	5	17
60138	2020-05-09 00:27:59	2020-05-09	9	[{"id_menu":6,"count":1}]	3054	pick-up	0	9
60139	2020-05-09 00:31:58	2020-05-09	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23943	delivery	5	39
60140	2020-05-09 00:32:11	2020-05-09	9	[{"id_menu":7,"count":1}]	5490	delivery	5	14
60141	2020-05-09 00:32:59	2020-05-09	9	[{"id_menu":6,"count":1}]	2780	pick-up	0	9
60142	2020-05-09 00:35:27	2020-05-09	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24031	delivery	5	48
60143	2020-05-09 00:48:04	2020-05-09	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19708	delivery	5	22
60144	2020-05-09 00:48:37	2020-05-09	9	[{"id_menu":6,"count":1}]	23989	delivery	5	14
60145	2020-05-09 00:49:27	2020-05-09	12	[{"id_menu":3,"count":1}]	18652	pick-up	0	12
60146	2020-05-09 00:50:48	2020-05-09	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	10796	delivery	5	48
60147	2020-05-09 00:52:48	2020-05-09	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23920	delivery	5	31
60148	2020-05-09 00:53:22	2020-05-09	14	[{"id_menu":2,"count":1}]	23938	delivery	5	19
60149	2020-05-09 00:57:24	2020-05-09	8	[{"id_menu":5,"count":1}]	24064	delivery	5	13
60150	2020-05-09 00:57:43	2020-05-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23984	delivery	5	22
60151	2020-05-09 00:59:25	2020-05-09	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	14557	delivery	5	26
60152	2020-05-09 01:02:02	2020-05-09	9	[{"id_menu":7,"count":1}]	11574	pick-up	0	9
60153	2020-05-09 01:04:32	2020-05-09	12	[{"id_menu":3,"count":1}]	18577	delivery	5	17
60154	2020-05-09 01:13:30	2020-05-09	12	[{"id_menu":3,"count":1}]	21980	pick-up	0	12
60155	2020-05-09 01:14:53	2020-05-09	12	[{"id_menu":3,"count":1}]	3509	delivery	5	17
60156	2020-05-09 01:15:46	2020-05-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4052	delivery	5	28
60157	2020-05-09 01:17:18	2020-05-09	14	[{"id_menu":2,"count":1}]	162	pick-up	0	14
60158	2020-05-09 01:19:57	2020-05-09	9	[{"id_menu":6,"count":1}]	24009	delivery	5	14
60159	2020-05-09 01:20:29	2020-05-09	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24081	delivery	5	35
60160	2020-05-09 01:24:20	2020-05-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	24024	delivery	5	28
60161	2020-05-09 01:26:02	2020-05-09	12	[{"id_menu":1,"count":1}]	22174	delivery	5	17
60162	2020-05-09 01:26:23	2020-05-09	12	[{"id_menu":1,"count":1}]	4862	delivery	5	17
60163	2020-05-09 01:31:56	2020-05-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	23948	delivery	5	28
60164	2020-05-09 01:32:50	2020-05-09	9	[{"id_menu":6,"count":1}]	5966	pick-up	0	9
60165	2020-05-09 01:33:25	2020-05-09	9	[{"id_menu":7,"count":1}]	23967	pick-up	0	9
60166	2020-05-09 01:35:31	2020-05-09	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	24080	delivery	5	31
60167	2020-05-09 01:36:29	2020-05-09	8	[{"id_menu":5,"count":1}]	23977	delivery	5	13
60168	2020-05-09 01:37:49	2020-05-09	9	[{"id_menu":6,"count":1}]	21347	delivery	5	14
60169	2020-05-09 01:42:16	2020-05-09	12	[{"id_menu":1,"count":1}]	3246	delivery	5	17
60170	2020-05-09 01:46:18	2020-05-09	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3540	delivery	5	46
60171	2020-05-09 01:46:23	2020-05-09	9	[{"id_menu":6,"count":1}]	8311	delivery	5	14
60172	2020-05-09 01:48:25	2020-05-09	12	[{"id_menu":1,"count":1}]	5972	pick-up	0	12
60173	2020-05-09 01:52:48	2020-05-09	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	3940	pick-up	0	34
60174	2020-05-09 01:55:53	2020-05-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	972	delivery	5	28
60175	2020-05-09 01:57:03	2020-05-09	12	[{"id_menu":3,"count":1}]	4211	delivery	5	17
60176	2020-05-09 01:57:06	2020-05-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11709	delivery	5	23
60177	2020-05-09 02:03:31	2020-05-09	8	[{"id_menu":5,"count":1}]	10338	delivery	5	13
60178	2020-05-09 02:09:50	2020-05-09	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	6507	delivery	5	26
60179	2020-05-09 02:11:39	2020-05-09	9	[{"id_menu":6,"count":1}]	22603	delivery	5	14
60180	2020-05-09 02:14:11	2020-05-09	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	11177	delivery	5	25
60181	2020-05-09 02:16:27	2020-05-09	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	10051	delivery	5	39
60182	2020-05-09 02:16:58	2020-05-09	12	[{"id_menu":3,"count":1}]	9186	delivery	5	17
60183	2020-05-09 02:18:06	2020-05-09	12	[{"id_menu":3,"count":1}]	5782	delivery	5	17
60184	2020-05-09 02:19:03	2020-05-09	9	[{"id_menu":6,"count":2}]	24054	delivery	5	14
60185	2020-05-09 02:20:55	2020-05-09	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	24077	delivery	5	31
60186	2020-05-09 02:25:02	2020-05-09	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	17342	delivery	5	39
60187	2020-05-09 02:25:44	2020-05-09	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	24074	pick-up	0	26
60188	2020-05-09 02:29:21	2020-05-09	17	[{"id_menu":4,"count":1}]	23954	pick-up	0	17
60189	2020-05-09 02:29:36	2020-05-09	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24051	delivery	5	31
60190	2020-05-09 02:31:50	2020-05-09	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	24061	delivery	5	22
60191	2020-05-09 02:32:03	2020-05-09	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	14116	pick-up	0	21
60192	2020-05-09 02:33:13	2020-05-09	8	[{"id_menu":5,"count":1}]	21950	delivery	5	13
60193	2020-05-09 02:38:56	2020-05-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23925	delivery	5	23
60194	2020-05-09 02:40:32	2020-05-09	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	14550	delivery	5	28
60195	2020-05-09 02:42:20	2020-05-09	8	[{"id_menu":5,"count":1}]	22914	delivery	5	13
60196	2020-05-09 02:45:53	2020-05-09	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1832	pick-up	0	26
60197	2020-05-09 02:47:52	2020-05-09	12	[{"id_menu":1,"count":1}]	23718	delivery	5	17
60198	2020-05-09 02:49:09	2020-05-09	9	[{"id_menu":6,"count":1}]	15614	delivery	5	14
60199	2020-05-09 02:53:11	2020-05-09	17	[{"id_menu":4,"count":1}]	24030	pick-up	0	17
60200	2020-05-09 02:54:11	2020-05-09	14	[{"id_menu":2,"count":1}]	15334	delivery	5	19
60201	2020-05-09 03:00:09	2020-05-09	9	[{"id_menu":6,"count":1}]	23923	delivery	5	14
60202	2020-05-09 03:08:53	2020-05-09	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	23933	delivery	5	52
60203	2020-05-09 03:10:20	2020-05-09	14	[{"id_menu":2,"count":1}]	8058	delivery	5	19
60204	2020-05-09 03:18:53	2020-05-09	17	[{"id_menu":4,"count":1}]	6522	delivery	5	22
60205	2020-05-09 03:19:55	2020-05-09	14	[{"id_menu":2,"count":1}]	826	delivery	5	19
60206	2020-05-09 03:20:06	2020-05-09	9	[{"id_menu":6,"count":1}]	7780	delivery	5	14
60207	2020-05-09 03:22:36	2020-05-09	12	[{"id_menu":3,"count":1}]	4418	delivery	5	17
60208	2020-05-09 03:27:36	2020-05-09	14	[{"id_menu":2,"count":1}]	19686	delivery	5	19
60209	2020-05-09 03:30:19	2020-05-09	9	[{"id_menu":6,"count":1}]	23930	pick-up	0	9
60210	2020-05-09 03:31:35	2020-05-09	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	20492	delivery	5	27
60211	2020-05-09 03:34:31	2020-05-09	12	[{"id_menu":1,"count":1}]	9169	delivery	5	17
60212	2020-05-09 03:36:00	2020-05-09	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	13674	delivery	5	48
60213	2020-05-09 03:44:04	2020-05-09	14	[{"id_menu":2,"count":1}]	1935	delivery	5	19
60214	2020-05-09 03:45:09	2020-05-09	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23945	delivery	5	22
60215	2020-05-09 03:50:21	2020-05-09	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6168	delivery	5	48
60216	2020-05-09 03:51:38	2020-05-09	17	[{"id_menu":4,"count":1}]	8100	delivery	5	22
60217	2020-05-09 03:52:00	2020-05-09	55	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	23964	delivery	5	60
60218	2020-05-09 03:52:40	2020-05-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	24001	delivery	5	28
60219	2020-05-09 03:57:20	2020-05-09	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17098	pick-up	0	38
60220	2020-05-09 03:57:49	2020-05-09	9	[{"id_menu":6,"count":1}]	23695	pick-up	0	9
60221	2020-05-09 03:59:19	2020-05-09	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20803	delivery	5	37
60222	2020-05-09 04:00:07	2020-05-09	8	[{"id_menu":5,"count":1}]	3604	delivery	5	13
60223	2020-05-09 04:13:30	2020-05-09	14	[{"id_menu":2,"count":1}]	23962	delivery	5	19
60224	2020-05-09 04:13:57	2020-05-09	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24006	delivery	5	48
60225	2020-05-09 04:16:59	2020-05-09	14	[{"id_menu":2,"count":1}]	23935	delivery	5	19
60226	2020-05-09 04:18:47	2020-05-09	9	[{"id_menu":6,"count":1}]	9673	delivery	5	14
60227	2020-05-09 04:20:02	2020-05-09	9	[{"id_menu":7,"count":1}]	24028	pick-up	0	9
60228	2020-05-09 04:23:23	2020-05-09	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13635	delivery	5	47
60229	2020-05-09 04:26:12	2020-05-09	9	[{"id_menu":6,"count":1}]	5729	pick-up	0	9
60230	2020-05-09 04:29:45	2020-05-09	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	23997	delivery	5	29
60231	2020-05-09 04:32:49	2020-05-09	9	[{"id_menu":6,"count":1}]	3597	delivery	5	14
60232	2020-05-09 04:33:41	2020-05-09	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	24039	delivery	5	26
60233	2020-05-09 04:43:05	2020-05-09	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	5428	delivery	5	22
60234	2020-05-09 04:43:30	2020-05-09	9	[{"id_menu":6,"count":1}]	18080	delivery	5	14
60235	2020-05-09 04:44:36	2020-05-09	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1461	pick-up	0	21
60236	2020-05-09 04:47:36	2020-05-09	9	[{"id_menu":7,"count":1}]	19449	delivery	5	14
60237	2020-05-09 04:53:13	2020-05-09	9	[{"id_menu":6,"count":1}]	17937	delivery	5	14
60238	2020-05-09 04:53:23	2020-05-09	14	[{"id_menu":2,"count":1}]	9798	delivery	5	19
60239	2020-05-09 04:53:41	2020-05-09	12	[{"id_menu":1,"count":1}]	20944	delivery	5	17
60240	2020-05-09 04:54:24	2020-05-09	8	[{"id_menu":5,"count":1}]	24076	delivery	5	13
60241	2020-05-09 04:56:01	2020-05-09	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1358	pick-up	0	46
60242	2020-05-09 04:57:56	2020-05-09	9	[{"id_menu":6,"count":1}]	6748	delivery	5	14
60243	2020-05-09 05:02:06	2020-05-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	23975	delivery	5	28
60244	2020-05-09 05:03:32	2020-05-09	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	24012	delivery	5	40
60245	2020-05-09 05:07:58	2020-05-09	14	[{"id_menu":2,"count":1}]	1770	pick-up	0	14
60246	2020-05-09 05:10:09	2020-05-09	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23946	pick-up	0	46
60247	2020-05-09 05:14:57	2020-05-09	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	5109	delivery	5	39
60248	2020-05-09 05:23:19	2020-05-09	12	[{"id_menu":3,"count":1}]	13940	delivery	5	17
60249	2020-05-09 05:25:06	2020-05-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7766	pick-up	0	18
60250	2020-05-09 05:25:14	2020-05-09	12	[{"id_menu":3,"count":1}]	24053	delivery	5	17
60251	2020-05-09 05:25:37	2020-05-09	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	23285	pick-up	0	22
60252	2020-05-09 05:31:50	2020-05-09	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	19032	delivery	5	31
60253	2020-05-09 05:32:01	2020-05-09	17	[{"id_menu":4,"count":1}]	23939	pick-up	0	17
60254	2020-05-09 05:33:10	2020-05-09	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24007	delivery	5	22
60255	2020-05-09 05:38:40	2020-05-09	12	[{"id_menu":1,"count":1}]	4985	delivery	5	17
60256	2020-05-09 05:41:35	2020-05-09	9	[{"id_menu":7,"count":1}]	892	pick-up	0	9
60257	2020-05-09 05:41:41	2020-05-09	9	[{"id_menu":6,"count":1}]	9150	delivery	5	14
60258	2020-05-09 05:41:50	2020-05-09	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18646	pick-up	0	26
60259	2020-05-09 05:43:18	2020-05-09	17	[{"id_menu":4,"count":1}]	8256	delivery	5	22
60260	2020-05-09 05:44:15	2020-05-09	12	[{"id_menu":3,"count":1}]	23978	delivery	5	17
60261	2020-05-09 05:44:21	2020-05-09	14	[{"id_menu":2,"count":2}]	14020	delivery	5	19
60262	2020-05-09 05:50:06	2020-05-09	17	[{"id_menu":4,"count":1}]	22211	delivery	5	22
60263	2020-05-09 05:50:10	2020-05-09	9	[{"id_menu":7,"count":1}]	11766	pick-up	0	9
60264	2020-05-09 05:51:15	2020-05-09	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	13733	pick-up	0	31
60265	2020-05-09 05:53:54	2020-05-09	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	10159	delivery	5	27
60266	2020-05-09 05:53:56	2020-05-09	9	[{"id_menu":6,"count":1}]	10553	pick-up	0	9
60267	2020-05-09 05:54:21	2020-05-09	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7278	delivery	5	39
60268	2020-05-09 06:01:12	2020-05-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	24036	delivery	5	28
60269	2020-05-09 06:02:42	2020-05-09	14	[{"id_menu":2,"count":1}]	23924	delivery	5	19
60270	2020-05-09 06:04:46	2020-05-09	17	[{"id_menu":4,"count":1}]	24034	delivery	5	22
60271	2020-05-09 06:06:31	2020-05-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21426	delivery	5	23
60272	2020-05-09 06:08:51	2020-05-09	9	[{"id_menu":7,"count":1}]	15044	delivery	5	14
60273	2020-05-09 06:13:34	2020-05-09	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24035	delivery	5	45
60274	2020-05-09 06:18:40	2020-05-09	9	[{"id_menu":7,"count":1}]	24084	delivery	5	14
60275	2020-05-09 06:21:46	2020-05-09	8	[{"id_menu":5,"count":1}]	18396	pick-up	0	8
60276	2020-05-09 06:22:49	2020-05-09	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3164	pick-up	0	26
60277	2020-05-09 06:31:08	2020-05-09	17	[{"id_menu":4,"count":1}]	5321	delivery	5	22
60278	2020-05-09 06:33:42	2020-05-09	8	[{"id_menu":5,"count":1}]	1886	delivery	5	13
60279	2020-05-09 06:34:57	2020-05-09	8	[{"id_menu":5,"count":1}]	1280	pick-up	0	8
60280	2020-05-09 06:35:35	2020-05-09	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	21084	delivery	5	34
60281	2020-05-09 06:40:34	2020-05-09	8	[{"id_menu":5,"count":1}]	4896	delivery	5	13
60282	2020-05-09 06:41:39	2020-05-09	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	20903	delivery	5	26
60283	2020-05-09 06:42:43	2020-05-09	9	[{"id_menu":6,"count":1}]	19220	pick-up	0	9
60284	2020-05-09 06:46:26	2020-05-09	12	[{"id_menu":1,"count":1}]	17790	delivery	5	17
60285	2020-05-09 06:50:03	2020-05-09	9	[{"id_menu":6,"count":1}]	7475	delivery	5	14
60286	2020-05-09 06:50:17	2020-05-09	9	[{"id_menu":7,"count":2}]	24045	delivery	5	14
60287	2020-05-09 06:51:24	2020-05-09	14	[{"id_menu":2,"count":1}]	23966	delivery	5	19
60288	2020-05-09 06:56:55	2020-05-09	9	[{"id_menu":7,"count":1}]	2401	delivery	5	14
60289	2020-05-09 06:57:58	2020-05-09	17	[{"id_menu":4,"count":2}]	23991	pick-up	0	17
60290	2020-05-09 07:01:35	2020-05-09	9	[{"id_menu":7,"count":1}]	23957	delivery	5	14
60291	2020-05-09 07:05:12	2020-05-09	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	7144	delivery	5	30
60292	2020-05-09 07:10:34	2020-05-09	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1035	pick-up	0	21
60293	2020-05-09 07:12:51	2020-05-09	9	[{"id_menu":7,"count":1}]	24013	delivery	5	14
60294	2020-05-09 07:13:16	2020-05-09	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24021	delivery	5	36
60295	2020-05-09 07:17:45	2020-05-09	8	[{"id_menu":5,"count":1}]	19878	pick-up	0	8
60296	2020-05-09 07:17:59	2020-05-09	17	[{"id_menu":4,"count":1}]	19382	delivery	5	22
60297	2020-05-09 07:20:36	2020-05-09	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4841	delivery	5	36
60298	2020-05-09 07:22:02	2020-05-09	12	[{"id_menu":3,"count":1}]	19129	pick-up	0	12
60299	2020-05-09 07:22:22	2020-05-09	8	[{"id_menu":5,"count":1}]	15119	delivery	5	13
60300	2020-05-09 07:35:40	2020-05-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	23932	delivery	5	28
60301	2020-05-09 07:38:55	2020-05-09	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3328	delivery	5	44
60302	2020-05-09 07:42:02	2020-05-09	9	[{"id_menu":7,"count":2}]	11011	delivery	5	14
60303	2020-05-09 07:46:21	2020-05-09	17	[{"id_menu":4,"count":1}]	806	pick-up	0	17
60304	2020-05-09 07:52:19	2020-05-09	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	22876	delivery	5	34
60305	2020-05-09 07:55:38	2020-05-09	9	[{"id_menu":7,"count":2}]	2450	pick-up	0	9
60306	2020-05-09 08:04:28	2020-05-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	23996	delivery	5	28
60307	2020-05-09 08:05:52	2020-05-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	11992	pick-up	0	23
60308	2020-05-09 08:13:38	2020-05-09	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	12032	delivery	5	28
60309	2020-05-09 08:14:58	2020-05-09	9	[{"id_menu":7,"count":1}]	23927	delivery	5	14
60310	2020-05-09 08:15:40	2020-05-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1106	pick-up	0	23
60311	2020-05-09 08:17:24	2020-05-09	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23988	delivery	5	31
60312	2020-05-09 08:26:47	2020-05-09	12	[{"id_menu":3,"count":1}]	2292	delivery	5	17
60313	2020-05-09 08:27:28	2020-05-09	9	[{"id_menu":6,"count":1}]	4002	delivery	5	14
60314	2020-05-09 08:30:53	2020-05-09	12	[{"id_menu":3,"count":1}]	12540	pick-up	0	12
60315	2020-05-09 08:31:57	2020-05-09	8	[{"id_menu":5,"count":1}]	23928	delivery	5	13
60316	2020-05-09 08:32:12	2020-05-09	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	21599	pick-up	0	22
60317	2020-05-09 08:34:15	2020-05-09	17	[{"id_menu":4,"count":1}]	7687	pick-up	0	17
60318	2020-05-09 08:35:54	2020-05-09	9	[{"id_menu":7,"count":1}]	9420	pick-up	0	9
60319	2020-05-09 08:36:33	2020-05-09	17	[{"id_menu":4,"count":1}]	24043	delivery	5	22
60320	2020-05-09 08:47:59	2020-05-09	17	[{"id_menu":4,"count":1}]	7550	delivery	5	22
60321	2020-05-09 08:50:23	2020-05-09	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24066	delivery	5	34
60322	2020-05-09 08:51:33	2020-05-09	8	[{"id_menu":5,"count":1}]	1344	pick-up	0	8
60323	2020-05-09 08:52:36	2020-05-09	8	[{"id_menu":5,"count":1}]	3458	pick-up	0	8
60324	2020-05-09 08:52:41	2020-05-09	9	[{"id_menu":6,"count":1}]	3431	delivery	5	14
60325	2020-05-09 08:53:59	2020-05-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	500	delivery	5	22
60326	2020-05-09 08:58:21	2020-05-09	9	[{"id_menu":6,"count":1}]	23971	delivery	5	14
60327	2020-05-09 08:59:19	2020-05-09	14	[{"id_menu":2,"count":1}]	24091	delivery	5	19
60328	2020-05-09 09:00:25	2020-05-09	12	[{"id_menu":1,"count":1}]	5484	delivery	5	17
60329	2020-05-09 09:07:15	2020-05-09	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	21229	delivery	5	31
60330	2020-05-09 09:11:47	2020-05-09	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":2}]	3119	delivery	5	26
60331	2020-05-09 09:12:12	2020-05-09	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	10688	delivery	5	28
60332	2020-05-09 09:15:19	2020-05-09	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	10495	delivery	5	22
60333	2020-05-09 09:16:33	2020-05-09	12	[{"id_menu":1,"count":2}]	21975	pick-up	0	12
60334	2020-05-09 09:20:11	2020-05-09	9	[{"id_menu":6,"count":1}]	18044	delivery	5	14
60335	2020-05-09 09:20:30	2020-05-09	14	[{"id_menu":2,"count":1}]	23571	pick-up	0	14
60336	2020-05-09 09:21:20	2020-05-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23940	delivery	5	22
60337	2020-05-09 09:28:28	2020-05-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8801	delivery	5	23
60338	2020-05-09 09:30:15	2020-05-09	12	[{"id_menu":3,"count":1}]	23981	pick-up	0	12
60339	2020-05-09 09:32:09	2020-05-09	12	[{"id_menu":3,"count":1}]	24070	pick-up	0	12
60340	2020-05-09 09:33:26	2020-05-09	14	[{"id_menu":2,"count":1}]	17551	delivery	5	19
60341	2020-05-09 09:33:57	2020-05-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	23704	delivery	5	28
60342	2020-05-09 09:40:19	2020-05-09	17	[{"id_menu":4,"count":2}]	8250	delivery	5	22
60343	2020-05-09 09:42:59	2020-05-09	17	[{"id_menu":4,"count":1}]	3668	delivery	5	22
60344	2020-05-09 09:45:29	2020-05-09	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4409	pick-up	0	38
60345	2020-05-09 09:49:25	2020-05-09	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	23918	pick-up	0	26
60346	2020-05-09 09:52:50	2020-05-09	9	[{"id_menu":7,"count":2}]	18737	delivery	5	14
60347	2020-05-09 09:55:20	2020-05-09	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5759	delivery	5	39
60348	2020-05-09 10:09:04	2020-05-09	9	[{"id_menu":7,"count":2}]	24060	delivery	5	14
60349	2020-05-09 10:13:51	2020-05-09	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4166	pick-up	0	22
60350	2020-05-09 10:15:39	2020-05-09	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23961	delivery	5	51
60351	2020-05-09 10:22:04	2020-05-09	9	[{"id_menu":7,"count":1}]	23926	delivery	5	14
60352	2020-05-09 10:35:06	2020-05-09	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	23982	delivery	5	23
60353	2020-05-09 10:36:20	2020-05-09	12	[{"id_menu":1,"count":1}]	3314	pick-up	0	12
60354	2020-05-09 10:42:01	2020-05-09	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	10316	delivery	5	31
60355	2020-05-09 10:44:09	2020-05-09	12	[{"id_menu":1,"count":1}]	3584	delivery	5	17
60356	2020-05-09 10:47:32	2020-05-09	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	24017	delivery	5	35
60357	2020-05-09 10:50:54	2020-05-09	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	24079	delivery	5	45
60358	2020-05-09 10:53:32	2020-05-09	12	[{"id_menu":3,"count":1}]	24067	delivery	5	17
60359	2020-05-09 10:54:55	2020-05-09	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	6465	pick-up	0	34
60360	2020-05-09 10:55:13	2020-05-09	9	[{"id_menu":7,"count":1}]	1889	pick-up	0	9
60361	2020-05-09 10:56:04	2020-05-09	9	[{"id_menu":6,"count":1}]	24093	delivery	5	14
60362	2020-05-09 11:01:16	2020-05-09	14	[{"id_menu":2,"count":1}]	3451	pick-up	0	14
60363	2020-05-09 11:02:06	2020-05-09	8	[{"id_menu":5,"count":1}]	712	delivery	5	13
60364	2020-05-09 11:03:22	2020-05-09	8	[{"id_menu":5,"count":1}]	24023	delivery	5	13
60365	2020-05-09 11:06:07	2020-05-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12136	delivery	5	23
60366	2020-05-09 11:08:47	2020-05-09	9	[{"id_menu":7,"count":1}]	24022	delivery	5	14
60367	2020-05-09 11:11:36	2020-05-09	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	24005	delivery	5	40
60368	2020-05-09 11:14:25	2020-05-09	8	[{"id_menu":5,"count":2}]	7591	delivery	5	13
60369	2020-05-09 11:16:22	2020-05-09	9	[{"id_menu":6,"count":1}]	4562	delivery	5	14
60370	2020-05-09 11:18:18	2020-05-09	9	[{"id_menu":7,"count":1}]	21090	delivery	5	14
60371	2020-05-09 11:18:39	2020-05-09	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	24055	delivery	5	36
60372	2020-05-09 11:27:16	2020-05-09	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24038	delivery	5	35
60373	2020-05-09 11:27:35	2020-05-09	8	[{"id_menu":5,"count":1}]	15846	delivery	5	13
60374	2020-05-09 11:32:11	2020-05-09	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	23801	delivery	5	43
60375	2020-05-09 11:36:22	2020-05-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	17918	delivery	5	22
60376	2020-05-09 11:36:49	2020-05-09	12	[{"id_menu":1,"count":1}]	5338	pick-up	0	12
60377	2020-05-09 11:38:08	2020-05-09	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	12274	pick-up	0	26
60378	2020-05-09 11:40:21	2020-05-09	14	[{"id_menu":2,"count":1}]	23987	delivery	5	19
60379	2020-05-09 11:40:34	2020-05-09	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	23999	delivery	5	36
60380	2020-05-09 11:40:46	2020-05-09	12	[{"id_menu":1,"count":1}]	7605	pick-up	0	12
60381	2020-05-09 11:41:39	2020-05-09	9	[{"id_menu":6,"count":1}]	20695	pick-up	0	9
60382	2020-05-09 11:49:18	2020-05-09	9	[{"id_menu":6,"count":1}]	24083	delivery	5	14
60383	2020-05-09 11:50:21	2020-05-09	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	6530	delivery	5	26
60384	2020-05-09 11:51:13	2020-05-09	14	[{"id_menu":2,"count":1}]	1738	pick-up	0	14
60385	2020-05-09 12:02:13	2020-05-09	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	16815	delivery	5	27
60386	2020-05-09 12:04:07	2020-05-09	14	[{"id_menu":2,"count":1}]	13148	pick-up	0	14
60387	2020-05-09 12:08:27	2020-05-09	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24032	delivery	5	43
60388	2020-05-09 12:08:57	2020-05-09	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9646	delivery	5	48
60389	2020-05-09 12:10:42	2020-05-09	12	[{"id_menu":3,"count":1}]	2426	delivery	5	17
60390	2020-05-09 12:13:11	2020-05-09	9	[{"id_menu":6,"count":1}]	23986	delivery	5	14
60391	2020-05-09 12:13:33	2020-05-09	17	[{"id_menu":4,"count":1}]	16175	delivery	5	22
60392	2020-05-09 12:13:50	2020-05-09	12	[{"id_menu":1,"count":1}]	18653	delivery	5	17
60393	2020-05-09 12:14:36	2020-05-09	14	[{"id_menu":2,"count":1}]	15484	delivery	5	19
60394	2020-05-09 12:14:53	2020-05-09	9	[{"id_menu":7,"count":1}]	24037	delivery	5	14
60395	2020-05-09 12:16:06	2020-05-09	8	[{"id_menu":5,"count":1}]	12057	delivery	5	13
60396	2020-05-09 12:17:16	2020-05-09	9	[{"id_menu":7,"count":1}]	1432	delivery	5	14
60397	2020-05-09 12:21:38	2020-05-09	17	[{"id_menu":4,"count":1}]	13639	pick-up	0	17
60398	2020-05-09 12:23:19	2020-05-09	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	9418	delivery	5	26
60399	2020-05-09 12:24:08	2020-05-09	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	24065	delivery	5	34
60400	2020-05-09 12:26:20	2020-05-09	9	[{"id_menu":6,"count":1}]	18811	delivery	5	14
60401	2020-05-09 12:29:23	2020-05-09	9	[{"id_menu":6,"count":1}]	24018	pick-up	0	9
60402	2020-05-09 12:29:27	2020-05-09	14	[{"id_menu":2,"count":2}]	16492	delivery	5	19
60403	2020-05-09 12:33:38	2020-05-09	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	4484	delivery	5	31
60404	2020-05-09 12:34:01	2020-05-09	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	9068	delivery	5	29
60405	2020-05-09 12:44:48	2020-05-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7782	pick-up	0	17
60406	2020-05-09 12:52:14	2020-05-09	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	6853	delivery	5	27
60407	2020-05-09 12:55:35	2020-05-09	9	[{"id_menu":6,"count":1}]	23922	delivery	5	14
60408	2020-05-09 12:56:18	2020-05-09	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	24088	delivery	5	26
60409	2020-05-09 12:58:35	2020-05-09	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24075	delivery	5	36
60410	2020-05-09 13:02:07	2020-05-09	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	23831	delivery	5	43
60411	2020-05-09 13:03:50	2020-05-09	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	6950	delivery	5	25
60412	2020-05-09 13:04:59	2020-05-09	8	[{"id_menu":5,"count":1}]	23334	delivery	5	13
60413	2020-05-09 13:07:07	2020-05-09	14	[{"id_menu":2,"count":1}]	3736	pick-up	0	14
60414	2020-05-09 13:10:46	2020-05-09	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	24086	delivery	5	36
60415	2020-05-09 13:15:36	2020-05-09	8	[{"id_menu":5,"count":1}]	14910	delivery	5	13
60416	2020-05-09 13:17:32	2020-05-09	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	8452	delivery	5	26
60417	2020-05-09 13:22:38	2020-05-09	9	[{"id_menu":6,"count":1}]	2933	delivery	5	14
60418	2020-05-09 13:29:24	2020-05-09	9	[{"id_menu":6,"count":1}]	22549	delivery	5	14
60419	2020-05-09 13:31:28	2020-05-09	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	19750	delivery	5	25
60420	2020-05-09 13:32:59	2020-05-09	12	[{"id_menu":1,"count":1}]	24085	delivery	5	17
60421	2020-05-09 13:36:41	2020-05-09	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	263	delivery	5	26
60422	2020-05-09 13:43:09	2020-05-09	9	[{"id_menu":7,"count":1}]	511	pick-up	0	9
60423	2020-05-09 13:45:41	2020-05-09	8	[{"id_menu":5,"count":1}]	23983	delivery	5	13
60424	2020-05-09 13:45:54	2020-05-09	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	23993	delivery	5	31
60425	2020-05-09 13:46:03	2020-05-09	9	[{"id_menu":6,"count":1}]	22661	delivery	5	14
60426	2020-05-09 13:46:44	2020-05-09	9	[{"id_menu":6,"count":1}]	4605	delivery	5	14
60427	2020-05-09 13:48:49	2020-05-09	14	[{"id_menu":2,"count":1}]	226	pick-up	0	14
60428	2020-05-09 13:48:50	2020-05-09	9	[{"id_menu":7,"count":2}]	6366	delivery	5	14
60429	2020-05-09 13:52:55	2020-05-09	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	10601	delivery	5	34
60430	2020-05-09 13:54:39	2020-05-09	9	[{"id_menu":6,"count":1}]	24087	delivery	5	14
60431	2020-05-09 13:55:04	2020-05-09	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	24027	delivery	5	31
60432	2020-05-09 13:56:47	2020-05-09	14	[{"id_menu":2,"count":1}]	8024	delivery	5	19
60433	2020-05-09 13:57:14	2020-05-09	8	[{"id_menu":5,"count":1}]	23990	delivery	5	13
60434	2020-05-09 13:58:35	2020-05-09	8	[{"id_menu":5,"count":1}]	24008	delivery	5	13
60435	2020-05-09 13:58:59	2020-05-09	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10993	delivery	5	36
60436	2020-05-09 14:03:41	2020-05-09	9	[{"id_menu":7,"count":1}]	4020	delivery	5	14
60437	2020-05-09 14:04:15	2020-05-09	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	21802	delivery	5	39
60438	2020-05-09 14:04:33	2020-05-09	9	[{"id_menu":6,"count":2}]	23937	delivery	5	14
60439	2020-05-09 14:15:27	2020-05-09	17	[{"id_menu":4,"count":1}]	24016	delivery	5	22
60440	2020-05-09 14:17:29	2020-05-09	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14580	delivery	5	43
60441	2020-05-09 14:17:43	2020-05-09	8	[{"id_menu":5,"count":1}]	2520	delivery	5	13
60442	2020-05-09 14:18:07	2020-05-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	24003	delivery	5	23
60443	2020-05-09 14:19:48	2020-05-09	12	[{"id_menu":1,"count":1}]	13930	delivery	5	17
60444	2020-05-09 14:21:53	2020-05-09	14	[{"id_menu":2,"count":1}]	23995	delivery	5	19
60445	2020-05-09 14:27:38	2020-05-09	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	24059	delivery	5	56
60446	2020-05-09 14:29:40	2020-05-09	9	[{"id_menu":6,"count":1}]	4350	pick-up	0	9
60447	2020-05-09 14:30:03	2020-05-09	12	[{"id_menu":3,"count":1}]	22266	delivery	5	17
60448	2020-05-09 14:30:31	2020-05-09	14	[{"id_menu":2,"count":1}]	23960	pick-up	0	14
60449	2020-05-09 14:32:02	2020-05-09	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	22865	delivery	5	27
60450	2020-05-09 14:46:13	2020-05-09	14	[{"id_menu":2,"count":1}]	2916	pick-up	0	14
60451	2020-05-09 14:48:02	2020-05-09	17	[{"id_menu":4,"count":1}]	23970	delivery	5	22
60452	2020-05-09 14:50:40	2020-05-09	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23955	delivery	5	34
60453	2020-05-09 14:52:13	2020-05-09	9	[{"id_menu":6,"count":2}]	7069	pick-up	0	9
60454	2020-05-09 14:52:39	2020-05-09	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	23947	pick-up	0	26
60455	2020-05-09 14:54:04	2020-05-09	17	[{"id_menu":4,"count":1}]	7529	delivery	5	22
60456	2020-05-09 14:54:13	2020-05-09	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	11311	delivery	5	27
60457	2020-05-09 14:54:26	2020-05-09	14	[{"id_menu":2,"count":1}]	14604	delivery	5	19
60458	2020-05-09 14:54:49	2020-05-09	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	24069	delivery	5	35
60459	2020-05-09 14:55:45	2020-05-09	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2373	delivery	5	36
60460	2020-05-09 14:58:13	2020-05-09	12	[{"id_menu":3,"count":1}]	23442	delivery	5	17
60461	2020-05-09 14:58:51	2020-05-09	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	11754	pick-up	0	22
60462	2020-05-09 15:01:20	2020-05-09	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	6786	delivery	5	44
60463	2020-05-09 15:02:28	2020-05-09	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	12387	pick-up	0	29
60464	2020-05-09 15:08:12	2020-05-09	12	[{"id_menu":1,"count":1}]	1713	pick-up	0	12
60465	2020-05-09 15:09:34	2020-05-09	9	[{"id_menu":6,"count":1}]	16762	pick-up	0	9
60466	2020-05-09 15:09:43	2020-05-09	9	[{"id_menu":7,"count":1}]	10296	delivery	5	14
60467	2020-05-09 15:13:24	2020-05-09	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7901	delivery	5	35
60468	2020-05-09 15:16:04	2020-05-09	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3040	delivery	5	53
60469	2020-05-09 15:18:04	2020-05-09	14	[{"id_menu":2,"count":1}]	23972	delivery	5	19
60470	2020-05-09 15:26:56	2020-05-09	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	11330	delivery	5	34
60471	2020-05-09 15:28:07	2020-05-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24040	delivery	5	23
60472	2020-05-09 15:31:48	2020-05-09	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	24089	delivery	5	30
60473	2020-05-09 15:33:25	2020-05-09	9	[{"id_menu":6,"count":1}]	24078	delivery	5	14
60474	2020-05-09 15:36:53	2020-05-09	25	[{"id_menu":4,"count":3},{"id_menu":5,"count":1}]	7375	delivery	5	30
60475	2020-05-09 15:44:16	2020-05-09	43	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	11277	delivery	5	48
60476	2020-05-09 15:45:06	2020-05-09	8	[{"id_menu":5,"count":1}]	8651	delivery	5	13
60477	2020-05-09 15:46:31	2020-05-09	9	[{"id_menu":6,"count":1}]	24092	delivery	5	14
60478	2020-05-09 15:46:45	2020-05-09	12	[{"id_menu":1,"count":2}]	14835	delivery	5	17
60479	2020-05-09 15:49:04	2020-05-09	12	[{"id_menu":3,"count":1}]	16760	pick-up	0	12
60480	2020-05-09 15:49:22	2020-05-09	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	24029	delivery	5	27
60481	2020-05-09 15:51:56	2020-05-09	9	[{"id_menu":6,"count":1}]	11492	delivery	5	14
60482	2020-05-09 15:57:04	2020-05-09	9	[{"id_menu":7,"count":2}]	18320	pick-up	0	9
60483	2020-05-09 16:04:08	2020-05-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	975	delivery	5	28
60484	2020-05-09 16:05:33	2020-05-09	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	7772	pick-up	0	21
60485	2020-05-09 16:06:15	2020-05-09	8	[{"id_menu":5,"count":1}]	23952	delivery	5	13
60486	2020-05-09 16:07:58	2020-05-09	9	[{"id_menu":7,"count":1}]	11401	pick-up	0	9
60487	2020-05-09 16:11:30	2020-05-09	17	[{"id_menu":4,"count":1}]	23963	pick-up	0	17
60488	2020-05-09 16:12:50	2020-05-09	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	22945	delivery	5	36
60489	2020-05-09 16:17:28	2020-05-09	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	4288	delivery	5	31
60490	2020-05-09 16:20:21	2020-05-09	9	[{"id_menu":7,"count":1}]	985	pick-up	0	9
60491	2020-05-09 16:20:53	2020-05-09	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	12484	pick-up	0	29
60492	2020-05-09 16:22:51	2020-05-09	8	[{"id_menu":5,"count":1}]	23973	delivery	5	13
60493	2020-05-09 16:24:28	2020-05-09	17	[{"id_menu":4,"count":1}]	24004	delivery	5	22
60494	2020-05-09 16:25:40	2020-05-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21553	delivery	5	22
60495	2020-05-09 16:27:32	2020-05-09	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8103	delivery	5	40
60496	2020-05-09 16:27:57	2020-05-09	12	[{"id_menu":1,"count":1}]	18898	delivery	5	17
60497	2020-05-09 16:31:52	2020-05-09	8	[{"id_menu":5,"count":1}]	18900	delivery	5	13
60498	2020-05-09 16:47:26	2020-05-09	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	23749	delivery	5	42
60499	2020-05-09 16:50:06	2020-05-09	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	20427	delivery	5	27
60500	2020-05-09 16:50:18	2020-05-09	14	[{"id_menu":2,"count":1}]	3324	delivery	5	19
60501	2020-05-09 16:52:09	2020-05-09	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	23919	delivery	5	34
60502	2020-05-09 16:56:43	2020-05-09	14	[{"id_menu":2,"count":1}]	23965	pick-up	0	14
60503	2020-05-09 17:02:43	2020-05-09	14	[{"id_menu":2,"count":1}]	13957	pick-up	0	14
60504	2020-05-09 17:03:44	2020-05-09	8	[{"id_menu":5,"count":1}]	23944	delivery	5	13
60505	2020-05-09 17:03:51	2020-05-09	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	13049	delivery	5	30
60506	2020-05-09 17:04:00	2020-05-09	12	[{"id_menu":1,"count":1}]	18870	delivery	5	17
60507	2020-05-09 17:04:00	2020-05-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4779	delivery	5	28
60508	2020-05-09 17:06:53	2020-05-09	9	[{"id_menu":7,"count":1}]	491	pick-up	0	9
60509	2020-05-09 17:07:07	2020-05-09	9	[{"id_menu":6,"count":1}]	17430	delivery	5	14
60510	2020-05-09 17:07:59	2020-05-09	9	[{"id_menu":7,"count":1}]	9513	delivery	5	14
60511	2020-05-09 17:08:48	2020-05-09	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":3}]	24058	delivery	5	26
60512	2020-05-09 17:11:12	2020-05-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24020	delivery	5	22
60513	2020-05-09 17:18:59	2020-05-09	8	[{"id_menu":5,"count":1}]	2585	delivery	5	13
60514	2020-05-09 17:19:19	2020-05-09	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4278	delivery	5	27
60515	2020-05-09 17:22:16	2020-05-09	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	24044	delivery	5	25
60516	2020-05-09 17:22:46	2020-05-09	9	[{"id_menu":7,"count":1}]	24073	delivery	5	14
60517	2020-05-09 17:23:50	2020-05-09	9	[{"id_menu":7,"count":1}]	13210	delivery	5	14
60518	2020-05-09 17:25:53	2020-05-09	9	[{"id_menu":7,"count":1}]	23936	delivery	5	14
60519	2020-05-09 17:27:35	2020-05-09	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	23980	delivery	5	34
60520	2020-05-09 17:32:00	2020-05-09	12	[{"id_menu":3,"count":1}]	12799	delivery	5	17
60521	2020-05-09 17:37:48	2020-05-09	8	[{"id_menu":5,"count":1}]	23994	delivery	5	13
60522	2020-05-09 17:43:48	2020-05-09	9	[{"id_menu":6,"count":1}]	18557	pick-up	0	9
60523	2020-05-09 17:43:55	2020-05-09	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":3}]	2492	pick-up	0	29
60524	2020-05-09 17:48:23	2020-05-09	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	11983	delivery	5	28
60525	2020-05-09 17:50:33	2020-05-09	8	[{"id_menu":5,"count":1}]	145	pick-up	0	8
60526	2020-05-09 17:54:27	2020-05-09	8	[{"id_menu":5,"count":1}]	24090	delivery	5	13
60527	2020-05-09 17:59:31	2020-05-09	8	[{"id_menu":5,"count":1}]	15342	delivery	5	13
60528	2020-05-09 18:00:39	2020-05-09	17	[{"id_menu":4,"count":1}]	7348	pick-up	0	17
60529	2020-05-09 18:02:48	2020-05-09	9	[{"id_menu":7,"count":1}]	23958	delivery	5	14
60530	2020-05-09 18:03:24	2020-05-09	8	[{"id_menu":5,"count":1}]	7709	delivery	5	13
60531	2020-05-09 18:03:46	2020-05-09	12	[{"id_menu":3,"count":1}]	609	pick-up	0	12
60532	2020-05-09 18:05:19	2020-05-09	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	3186	pick-up	0	35
60533	2020-05-09 18:07:26	2020-05-09	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	24072	delivery	5	26
60534	2020-05-09 18:07:32	2020-05-09	8	[{"id_menu":5,"count":2}]	24026	delivery	5	13
60535	2020-05-09 18:11:23	2020-05-09	14	[{"id_menu":2,"count":1}]	822	pick-up	0	14
60536	2020-05-09 18:12:38	2020-05-09	9	[{"id_menu":6,"count":1}]	172	pick-up	0	9
60537	2020-05-09 18:14:44	2020-05-09	9	[{"id_menu":7,"count":1}]	5814	delivery	5	14
60538	2020-05-09 18:22:28	2020-05-09	12	[{"id_menu":1,"count":1}]	24041	pick-up	0	12
60539	2020-05-09 18:28:50	2020-05-09	9	[{"id_menu":7,"count":1}]	24033	delivery	5	14
60540	2020-05-09 18:32:59	2020-05-09	17	[{"id_menu":4,"count":1}]	12078	delivery	5	22
60541	2020-05-09 18:34:38	2020-05-09	14	[{"id_menu":2,"count":1}]	24071	delivery	5	19
60542	2020-05-09 18:42:38	2020-05-09	14	[{"id_menu":2,"count":1}]	3399	pick-up	0	14
60543	2020-05-09 18:44:06	2020-05-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19480	delivery	5	23
60544	2020-05-09 18:45:22	2020-05-09	14	[{"id_menu":2,"count":2}]	3679	delivery	5	19
60545	2020-05-09 18:46:28	2020-05-09	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24047	delivery	5	34
60546	2020-05-09 18:49:39	2020-05-09	21	[{"id_menu":3,"count":3},{"id_menu":6,"count":1}]	23941	delivery	5	26
60547	2020-05-09 18:53:56	2020-05-09	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11760	delivery	5	51
60548	2020-05-09 18:57:39	2020-05-09	12	[{"id_menu":3,"count":1}]	3594	pick-up	0	12
60549	2020-05-09 19:06:51	2020-05-09	12	[{"id_menu":3,"count":1}]	9329	delivery	5	17
60550	2020-05-09 19:07:58	2020-05-09	9	[{"id_menu":6,"count":1}]	22327	delivery	5	14
60551	2020-05-09 19:09:01	2020-05-09	14	[{"id_menu":2,"count":1}]	19931	delivery	5	19
60552	2020-05-09 19:11:49	2020-05-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	953	delivery	5	28
60553	2020-05-09 19:18:22	2020-05-09	14	[{"id_menu":2,"count":1}]	16515	delivery	5	19
60554	2020-05-09 19:18:49	2020-05-09	14	[{"id_menu":2,"count":1}]	8098	delivery	5	19
60555	2020-05-09 19:20:26	2020-05-09	9	[{"id_menu":7,"count":1}]	10904	delivery	5	14
60556	2020-05-09 19:21:10	2020-05-09	8	[{"id_menu":5,"count":1}]	24015	delivery	5	13
60557	2020-05-09 19:23:53	2020-05-09	14	[{"id_menu":2,"count":1}]	20504	pick-up	0	14
60558	2020-05-09 19:26:39	2020-05-09	9	[{"id_menu":7,"count":1}]	22799	delivery	5	14
60559	2020-05-09 19:32:43	2020-05-09	12	[{"id_menu":1,"count":2}]	13407	delivery	5	17
60560	2020-05-09 19:33:14	2020-05-09	9	[{"id_menu":7,"count":1}]	3266	delivery	5	14
60561	2020-05-09 19:36:44	2020-05-09	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	20485	delivery	5	25
60562	2020-05-09 19:36:52	2020-05-09	9	[{"id_menu":6,"count":1}]	22941	delivery	5	14
60563	2020-05-09 19:38:01	2020-05-09	14	[{"id_menu":2,"count":1}]	2416	pick-up	0	14
60564	2020-05-09 19:39:28	2020-05-09	17	[{"id_menu":4,"count":1}]	24056	delivery	5	22
60565	2020-05-09 19:46:39	2020-05-09	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	24063	delivery	5	30
60566	2020-05-09 19:48:16	2020-05-09	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23942	delivery	5	39
60567	2020-05-09 19:52:34	2020-05-09	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	18343	delivery	5	48
60568	2020-05-09 19:56:34	2020-05-09	14	[{"id_menu":2,"count":1}]	1818	delivery	5	19
60569	2020-05-09 20:02:09	2020-05-09	9	[{"id_menu":6,"count":1}]	23929	delivery	5	14
60570	2020-05-09 20:04:29	2020-05-09	9	[{"id_menu":6,"count":1}]	10807	pick-up	0	9
60571	2020-05-09 20:05:53	2020-05-09	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23953	delivery	5	54
60572	2020-05-09 20:08:54	2020-05-09	12	[{"id_menu":3,"count":1}]	24025	delivery	5	17
60573	2020-05-09 20:13:03	2020-05-09	9	[{"id_menu":6,"count":1}]	8967	delivery	5	14
60574	2020-05-09 20:18:40	2020-05-09	8	[{"id_menu":5,"count":1}]	7450	delivery	5	13
60575	2020-05-09 20:20:22	2020-05-09	17	[{"id_menu":4,"count":1}]	22882	delivery	5	22
60576	2020-05-09 20:24:45	2020-05-09	9	[{"id_menu":7,"count":1}]	23452	delivery	5	14
60577	2020-05-09 20:30:44	2020-05-09	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23974	delivery	5	47
60578	2020-05-09 20:32:51	2020-05-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	24042	delivery	5	28
60579	2020-05-09 20:34:56	2020-05-09	14	[{"id_menu":2,"count":2}]	4595	pick-up	0	14
60580	2020-05-09 20:38:42	2020-05-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	6720	delivery	5	22
60581	2020-05-09 20:40:52	2020-05-09	17	[{"id_menu":4,"count":1}]	16321	pick-up	0	17
60582	2020-05-09 20:42:40	2020-05-09	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	401	delivery	5	26
60583	2020-05-09 20:43:58	2020-05-09	17	[{"id_menu":4,"count":1}]	24062	delivery	5	22
60584	2020-05-09 20:49:59	2020-05-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	5303	delivery	5	28
60585	2020-05-09 20:50:40	2020-05-09	9	[{"id_menu":7,"count":1}]	23992	delivery	5	14
60586	2020-05-09 20:50:52	2020-05-09	17	[{"id_menu":4,"count":1}]	23931	pick-up	0	17
60587	2020-05-09 20:52:12	2020-05-09	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	15880	pick-up	0	21
60588	2020-05-09 20:53:02	2020-05-09	9	[{"id_menu":7,"count":1}]	16548	delivery	5	14
60589	2020-05-09 20:54:50	2020-05-09	14	[{"id_menu":2,"count":1}]	10717	pick-up	0	14
60590	2020-05-09 20:57:31	2020-05-09	9	[{"id_menu":7,"count":1}]	18796	delivery	5	14
60591	2020-05-09 20:57:51	2020-05-09	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	24046	delivery	5	31
60592	2020-05-09 20:59:35	2020-05-09	12	[{"id_menu":3,"count":1}]	24011	pick-up	0	12
60593	2020-05-09 21:00:00	2020-05-09	17	[{"id_menu":4,"count":1}]	23998	delivery	5	22
60594	2020-05-09 21:01:42	2020-05-09	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	24002	delivery	5	31
60595	2020-05-09 21:03:42	2020-05-09	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12349	delivery	5	45
60596	2020-05-09 21:05:09	2020-05-09	8	[{"id_menu":5,"count":1}]	23949	delivery	5	13
60597	2020-05-09 21:08:54	2020-05-09	8	[{"id_menu":5,"count":1}]	14740	delivery	5	13
60598	2020-05-09 21:13:30	2020-05-09	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	20109	delivery	5	26
60599	2020-05-09 21:14:09	2020-05-09	12	[{"id_menu":1,"count":1}]	15282	delivery	5	17
60600	2020-05-09 21:16:02	2020-05-09	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	14529	delivery	5	26
60601	2020-05-09 21:17:06	2020-05-09	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	10971	pick-up	0	34
60602	2020-05-09 21:18:09	2020-05-09	12	[{"id_menu":3,"count":1}]	3438	delivery	5	17
60603	2020-05-09 21:18:25	2020-05-09	9	[{"id_menu":6,"count":1}]	24000	pick-up	0	9
60604	2020-05-09 21:21:26	2020-05-09	9	[{"id_menu":7,"count":1}]	23979	pick-up	0	9
60605	2020-05-09 21:21:57	2020-05-09	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	18618	delivery	5	40
60606	2020-05-09 21:23:37	2020-05-09	8	[{"id_menu":5,"count":1}]	12019	delivery	5	13
60607	2020-05-09 21:24:55	2020-05-09	12	[{"id_menu":1,"count":1}]	355	pick-up	0	12
60608	2020-05-09 21:32:58	2020-05-09	9	[{"id_menu":6,"count":1}]	3318	pick-up	0	9
60609	2020-05-09 21:38:37	2020-05-09	9	[{"id_menu":6,"count":1}]	12907	delivery	5	14
60610	2020-05-09 21:42:03	2020-05-09	14	[{"id_menu":2,"count":1}]	6441	delivery	5	19
60611	2020-05-09 21:43:44	2020-05-09	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	23985	delivery	5	31
60612	2020-05-09 21:44:36	2020-05-09	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":2}]	9126	delivery	5	28
60613	2020-05-09 21:45:03	2020-05-09	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	15022	delivery	5	38
60614	2020-05-09 21:46:49	2020-05-09	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9607	delivery	5	43
60615	2020-05-09 21:51:35	2020-05-09	14	[{"id_menu":2,"count":2}]	13806	delivery	5	19
60616	2020-05-09 21:55:07	2020-05-09	8	[{"id_menu":5,"count":1}]	19307	delivery	5	13
60617	2020-05-09 21:57:19	2020-05-09	12	[{"id_menu":1,"count":1}]	24010	delivery	5	17
60618	2020-05-09 21:58:05	2020-05-09	8	[{"id_menu":5,"count":1}]	13860	delivery	5	13
60619	2020-05-09 21:58:40	2020-05-09	9	[{"id_menu":6,"count":1}]	1781	pick-up	0	9
60620	2020-05-09 22:02:34	2020-05-09	17	[{"id_menu":4,"count":1}]	24048	delivery	5	22
60621	2020-05-09 22:03:22	2020-05-09	12	[{"id_menu":3,"count":1}]	332	pick-up	0	12
60622	2020-05-09 22:06:55	2020-05-09	9	[{"id_menu":6,"count":1}]	13950	pick-up	0	9
60623	2020-05-09 22:08:39	2020-05-09	8	[{"id_menu":5,"count":1}]	16462	delivery	5	13
60624	2020-05-09 22:08:44	2020-05-09	12	[{"id_menu":1,"count":1}]	20579	delivery	5	17
60625	2020-05-09 22:14:34	2020-05-09	9	[{"id_menu":6,"count":1}]	22045	delivery	5	14
60626	2020-05-09 22:16:36	2020-05-09	9	[{"id_menu":6,"count":1}]	2077	delivery	5	14
60627	2020-05-09 22:17:28	2020-05-09	12	[{"id_menu":1,"count":1}]	677	delivery	5	17
60628	2020-05-09 22:23:39	2020-05-09	12	[{"id_menu":3,"count":1}]	24019	delivery	5	17
60629	2020-05-09 22:33:02	2020-05-09	9	[{"id_menu":7,"count":1}]	14025	pick-up	0	9
60630	2020-05-09 22:35:32	2020-05-09	9	[{"id_menu":6,"count":1}]	3909	delivery	5	14
60631	2020-05-09 22:36:29	2020-05-09	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14631	delivery	5	45
60632	2020-05-09 22:51:52	2020-05-09	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	11336	delivery	5	40
60633	2020-05-09 22:54:04	2020-05-09	9	[{"id_menu":6,"count":1}]	22485	delivery	5	14
60634	2020-05-09 22:58:38	2020-05-09	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	24057	delivery	5	30
60635	2020-05-09 23:00:57	2020-05-09	9	[{"id_menu":7,"count":1}]	18550	delivery	5	14
60636	2020-05-09 23:04:01	2020-05-09	9	[{"id_menu":6,"count":1}]	2726	delivery	5	14
60637	2020-05-09 23:04:22	2020-05-09	12	[{"id_menu":3,"count":1}]	5961	delivery	5	17
60638	2020-05-09 23:04:54	2020-05-09	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	23114	delivery	5	23
60639	2020-05-09 23:06:35	2020-05-09	9	[{"id_menu":6,"count":2}]	24049	delivery	5	14
60640	2020-05-09 23:12:44	2020-05-09	14	[{"id_menu":2,"count":1}]	24014	delivery	5	19
60641	2020-05-09 23:17:04	2020-05-09	9	[{"id_menu":7,"count":2}]	23951	delivery	5	14
60642	2020-05-09 23:24:22	2020-05-09	12	[{"id_menu":1,"count":1}]	24052	delivery	5	17
60643	2020-05-09 23:24:37	2020-05-09	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	20983	delivery	5	31
60644	2020-05-09 23:25:02	2020-05-09	9	[{"id_menu":6,"count":1}]	20581	delivery	5	14
60645	2020-05-09 23:25:15	2020-05-09	9	[{"id_menu":6,"count":1}]	23843	delivery	5	14
60646	2020-05-09 23:27:26	2020-05-09	9	[{"id_menu":7,"count":1}]	23959	delivery	5	14
60647	2020-05-09 23:35:08	2020-05-09	12	[{"id_menu":1,"count":1}]	24068	pick-up	0	12
60648	2020-05-09 23:37:08	2020-05-09	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23921	delivery	5	34
60649	2020-05-09 23:46:17	2020-05-09	8	[{"id_menu":5,"count":1}]	5726	delivery	5	13
60650	2020-05-09 23:47:45	2020-05-09	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	16818	delivery	5	31
60651	2020-05-09 23:53:27	2020-05-09	8	[{"id_menu":5,"count":1}]	2725	delivery	5	13
60652	2020-05-09 23:59:55	2020-05-09	12	[{"id_menu":1,"count":1}]	5642	pick-up	0	12
60653	2020-05-10 00:01:29	2020-05-10	8	[{"id_menu":5,"count":1}]	24172	delivery	5	13
60654	2020-05-10 00:01:35	2020-05-10	9	[{"id_menu":6,"count":1}]	6009	pick-up	0	9
60655	2020-05-10 00:04:10	2020-05-10	8	[{"id_menu":5,"count":1}]	8798	delivery	5	13
60656	2020-05-10 00:11:21	2020-05-10	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	10330	delivery	5	29
60657	2020-05-10 00:12:51	2020-05-10	17	[{"id_menu":4,"count":1}]	9982	delivery	5	22
60658	2020-05-10 00:17:16	2020-05-10	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24224	delivery	5	35
60659	2020-05-10 00:18:31	2020-05-10	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	18885	delivery	5	25
60660	2020-05-10 00:19:37	2020-05-10	12	[{"id_menu":3,"count":1}]	19645	pick-up	0	12
60661	2020-05-10 00:21:16	2020-05-10	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	2832	delivery	5	43
60662	2020-05-10 00:22:00	2020-05-10	17	[{"id_menu":4,"count":1}]	12240	pick-up	0	17
60663	2020-05-10 00:24:50	2020-05-10	9	[{"id_menu":7,"count":2}]	24124	delivery	5	14
60664	2020-05-10 00:27:23	2020-05-10	14	[{"id_menu":2,"count":1}]	8394	pick-up	0	14
60665	2020-05-10 00:27:35	2020-05-10	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2190	pick-up	0	31
60666	2020-05-10 00:31:24	2020-05-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6282	pick-up	0	17
60667	2020-05-10 00:31:57	2020-05-10	8	[{"id_menu":5,"count":1}]	14290	pick-up	0	8
60668	2020-05-10 00:32:34	2020-05-10	8	[{"id_menu":5,"count":1}]	22388	delivery	5	13
60669	2020-05-10 00:32:43	2020-05-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3436	delivery	5	23
60670	2020-05-10 00:35:49	2020-05-10	14	[{"id_menu":2,"count":1}]	16018	pick-up	0	14
60671	2020-05-10 00:36:40	2020-05-10	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24283	delivery	5	35
60672	2020-05-10 00:38:30	2020-05-10	17	[{"id_menu":4,"count":1}]	14877	delivery	5	22
60673	2020-05-10 00:38:59	2020-05-10	12	[{"id_menu":1,"count":1}]	6386	delivery	5	17
60674	2020-05-10 00:41:51	2020-05-10	9	[{"id_menu":6,"count":1}]	19532	delivery	5	14
60675	2020-05-10 00:43:36	2020-05-10	9	[{"id_menu":7,"count":1}]	24257	delivery	5	14
60676	2020-05-10 00:45:43	2020-05-10	17	[{"id_menu":4,"count":1}]	16362	delivery	5	22
60677	2020-05-10 00:48:26	2020-05-10	12	[{"id_menu":3,"count":1}]	2783	pick-up	0	12
60678	2020-05-10 00:54:24	2020-05-10	14	[{"id_menu":2,"count":1}]	9933	delivery	5	19
60679	2020-05-10 00:54:26	2020-05-10	8	[{"id_menu":5,"count":1}]	24183	delivery	5	13
60680	2020-05-10 00:56:53	2020-05-10	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	16114	pick-up	0	29
60681	2020-05-10 00:58:38	2020-05-10	14	[{"id_menu":2,"count":1}]	10877	delivery	5	19
60682	2020-05-10 01:00:15	2020-05-10	9	[{"id_menu":6,"count":1}]	10283	delivery	5	14
60683	2020-05-10 01:00:18	2020-05-10	17	[{"id_menu":4,"count":1}]	1490	pick-up	0	17
60684	2020-05-10 01:05:17	2020-05-10	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	18575	pick-up	0	35
60685	2020-05-10 01:09:09	2020-05-10	9	[{"id_menu":7,"count":1}]	12290	delivery	5	14
60686	2020-05-10 01:11:57	2020-05-10	9	[{"id_menu":7,"count":1}]	13665	delivery	5	14
60687	2020-05-10 01:13:21	2020-05-10	14	[{"id_menu":2,"count":1}]	19035	delivery	5	19
60688	2020-05-10 01:28:56	2020-05-10	9	[{"id_menu":7,"count":1}]	24234	delivery	5	14
60689	2020-05-10 01:30:41	2020-05-10	17	[{"id_menu":4,"count":1}]	24218	delivery	5	22
60690	2020-05-10 01:35:54	2020-05-10	17	[{"id_menu":4,"count":1}]	19664	pick-up	0	17
60691	2020-05-10 01:36:51	2020-05-10	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22259	delivery	5	22
60692	2020-05-10 01:37:59	2020-05-10	9	[{"id_menu":6,"count":1}]	24223	delivery	5	14
60693	2020-05-10 01:39:17	2020-05-10	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10106	pick-up	0	40
60694	2020-05-10 01:41:15	2020-05-10	9	[{"id_menu":7,"count":1}]	24161	delivery	5	14
60695	2020-05-10 01:45:21	2020-05-10	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	23853	delivery	5	30
60696	2020-05-10 01:45:24	2020-05-10	17	[{"id_menu":4,"count":1}]	24129	pick-up	0	17
60697	2020-05-10 01:47:27	2020-05-10	9	[{"id_menu":6,"count":3}]	24235	delivery	5	14
60698	2020-05-10 01:47:28	2020-05-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7041	delivery	5	22
60699	2020-05-10 01:51:02	2020-05-10	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	24157	delivery	5	31
60700	2020-05-10 01:51:37	2020-05-10	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24190	delivery	5	54
60701	2020-05-10 01:58:00	2020-05-10	8	[{"id_menu":5,"count":1}]	460	delivery	5	13
60702	2020-05-10 01:58:27	2020-05-10	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	24158	delivery	5	42
60703	2020-05-10 01:58:46	2020-05-10	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24243	delivery	5	45
60704	2020-05-10 02:00:33	2020-05-10	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	24110	pick-up	0	29
60705	2020-05-10 02:01:07	2020-05-10	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6456	delivery	5	34
60706	2020-05-10 02:04:21	2020-05-10	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	8512	delivery	5	40
60707	2020-05-10 02:07:41	2020-05-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1670	pick-up	0	23
60708	2020-05-10 02:08:59	2020-05-10	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6836	delivery	5	31
60709	2020-05-10 02:11:13	2020-05-10	12	[{"id_menu":1,"count":1}]	1547	pick-up	0	12
60710	2020-05-10 02:11:27	2020-05-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	10862	delivery	5	28
60711	2020-05-10 02:13:56	2020-05-10	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	18398	delivery	5	43
60712	2020-05-10 02:15:45	2020-05-10	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24205	delivery	5	39
60713	2020-05-10 02:17:33	2020-05-10	8	[{"id_menu":5,"count":1}]	15818	pick-up	0	8
60714	2020-05-10 02:18:11	2020-05-10	12	[{"id_menu":3,"count":1}]	12866	delivery	5	17
60715	2020-05-10 02:21:21	2020-05-10	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	11756	delivery	5	23
60716	2020-05-10 02:23:39	2020-05-10	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":2}]	24137	delivery	5	31
60717	2020-05-10 02:24:44	2020-05-10	12	[{"id_menu":3,"count":1}]	13528	pick-up	0	12
60718	2020-05-10 02:28:56	2020-05-10	9	[{"id_menu":7,"count":1}]	12224	delivery	5	14
60719	2020-05-10 02:30:38	2020-05-10	14	[{"id_menu":2,"count":1}]	1636	pick-up	0	14
60720	2020-05-10 02:31:15	2020-05-10	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	19876	delivery	5	43
60721	2020-05-10 02:31:46	2020-05-10	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24254	delivery	5	34
60722	2020-05-10 02:31:46	2020-05-10	8	[{"id_menu":5,"count":1}]	24133	delivery	5	13
60723	2020-05-10 02:40:52	2020-05-10	9	[{"id_menu":7,"count":1}]	11097	delivery	5	14
60724	2020-05-10 02:44:56	2020-05-10	9	[{"id_menu":7,"count":1}]	11553	pick-up	0	9
60725	2020-05-10 02:46:39	2020-05-10	9	[{"id_menu":7,"count":1}]	22721	delivery	5	14
60726	2020-05-10 02:46:39	2020-05-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":3}]	24150	delivery	5	23
60727	2020-05-10 02:54:49	2020-05-10	14	[{"id_menu":2,"count":1}]	2555	delivery	5	19
60728	2020-05-10 02:56:44	2020-05-10	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	24059	delivery	5	40
60729	2020-05-10 02:58:23	2020-05-10	12	[{"id_menu":1,"count":1}]	5508	pick-up	0	12
60730	2020-05-10 02:58:30	2020-05-10	14	[{"id_menu":2,"count":3}]	17906	pick-up	0	14
60731	2020-05-10 02:58:45	2020-05-10	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	24246	delivery	5	31
60732	2020-05-10 02:59:58	2020-05-10	14	[{"id_menu":2,"count":1}]	10679	pick-up	0	14
60733	2020-05-10 03:01:17	2020-05-10	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	24104	delivery	5	34
60734	2020-05-10 03:03:28	2020-05-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	9419	delivery	5	28
60735	2020-05-10 03:05:34	2020-05-10	9	[{"id_menu":7,"count":1}]	24139	delivery	5	14
60736	2020-05-10 03:08:22	2020-05-10	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	24217	delivery	5	40
60737	2020-05-10 03:11:43	2020-05-10	14	[{"id_menu":2,"count":1}]	24264	delivery	5	19
60738	2020-05-10 03:13:15	2020-05-10	9	[{"id_menu":6,"count":1}]	17175	delivery	5	14
60739	2020-05-10 03:14:02	2020-05-10	12	[{"id_menu":1,"count":1}]	14908	delivery	5	17
60740	2020-05-10 03:16:33	2020-05-10	8	[{"id_menu":5,"count":1}]	9805	delivery	5	13
60741	2020-05-10 03:16:42	2020-05-10	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6385	delivery	5	47
60742	2020-05-10 03:27:23	2020-05-10	9	[{"id_menu":6,"count":1}]	17116	delivery	5	14
60743	2020-05-10 03:28:30	2020-05-10	17	[{"id_menu":4,"count":1}]	17625	delivery	5	22
60744	2020-05-10 03:31:00	2020-05-10	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	24249	delivery	5	26
60745	2020-05-10 03:32:05	2020-05-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6609	pick-up	0	23
60746	2020-05-10 03:32:13	2020-05-10	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18921	delivery	5	31
60747	2020-05-10 03:33:45	2020-05-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	24280	pick-up	0	23
60748	2020-05-10 03:34:35	2020-05-10	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	20970	delivery	5	31
60749	2020-05-10 03:34:43	2020-05-10	12	[{"id_menu":1,"count":1}]	7565	pick-up	0	12
60750	2020-05-10 03:35:21	2020-05-10	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3366	pick-up	0	31
60751	2020-05-10 03:36:13	2020-05-10	14	[{"id_menu":2,"count":1}]	18057	pick-up	0	14
60752	2020-05-10 03:36:18	2020-05-10	17	[{"id_menu":4,"count":1}]	24100	delivery	5	22
60753	2020-05-10 03:45:20	2020-05-10	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	4825	pick-up	0	21
60754	2020-05-10 03:48:06	2020-05-10	8	[{"id_menu":5,"count":1}]	13098	delivery	5	13
60755	2020-05-10 03:48:21	2020-05-10	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	24230	delivery	5	31
60756	2020-05-10 03:50:07	2020-05-10	8	[{"id_menu":5,"count":1}]	24277	delivery	5	13
60757	2020-05-10 03:53:29	2020-05-10	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5879	pick-up	0	26
60758	2020-05-10 03:57:43	2020-05-10	9	[{"id_menu":6,"count":1}]	7502	pick-up	0	9
60759	2020-05-10 03:58:31	2020-05-10	8	[{"id_menu":5,"count":2}]	24185	delivery	5	13
60760	2020-05-10 04:03:55	2020-05-10	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6623	delivery	5	34
60761	2020-05-10 04:12:40	2020-05-10	9	[{"id_menu":6,"count":1}]	24120	delivery	5	14
60762	2020-05-10 04:13:57	2020-05-10	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16433	delivery	5	54
60763	2020-05-10 04:14:20	2020-05-10	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	7888	delivery	5	27
60764	2020-05-10 04:26:11	2020-05-10	9	[{"id_menu":7,"count":1}]	24196	delivery	5	14
60765	2020-05-10 04:26:27	2020-05-10	9	[{"id_menu":7,"count":1}]	24201	delivery	5	14
60766	2020-05-10 04:26:34	2020-05-10	12	[{"id_menu":3,"count":1}]	6358	delivery	5	17
60767	2020-05-10 04:30:30	2020-05-10	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	24170	pick-up	0	20
60768	2020-05-10 04:31:41	2020-05-10	17	[{"id_menu":4,"count":1}]	19775	pick-up	0	17
60769	2020-05-10 04:32:52	2020-05-10	17	[{"id_menu":4,"count":1}]	2519	delivery	5	22
60770	2020-05-10 04:38:23	2020-05-10	14	[{"id_menu":2,"count":2}]	15858	delivery	5	19
60771	2020-05-10 04:40:03	2020-05-10	9	[{"id_menu":7,"count":1}]	15563	delivery	5	14
60772	2020-05-10 04:42:08	2020-05-10	9	[{"id_menu":7,"count":2}]	17512	delivery	5	14
60773	2020-05-10 04:42:53	2020-05-10	9	[{"id_menu":7,"count":1}]	14466	delivery	5	14
60774	2020-05-10 04:46:47	2020-05-10	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23949	delivery	5	22
60775	2020-05-10 04:48:09	2020-05-10	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	3002	pick-up	0	34
60776	2020-05-10 04:50:15	2020-05-10	14	[{"id_menu":2,"count":2}]	17888	delivery	5	19
60777	2020-05-10 04:50:26	2020-05-10	9	[{"id_menu":6,"count":1}]	23299	delivery	5	14
60778	2020-05-10 04:56:12	2020-05-10	8	[{"id_menu":5,"count":1}]	6198	delivery	5	13
60779	2020-05-10 05:01:36	2020-05-10	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12879	delivery	5	34
60780	2020-05-10 05:05:04	2020-05-10	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19507	delivery	5	31
60781	2020-05-10 05:06:12	2020-05-10	9	[{"id_menu":7,"count":1}]	24094	delivery	5	14
60782	2020-05-10 05:08:40	2020-05-10	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	24095	delivery	5	40
60783	2020-05-10 05:09:05	2020-05-10	12	[{"id_menu":3,"count":1}]	4387	pick-up	0	12
60784	2020-05-10 05:16:01	2020-05-10	9	[{"id_menu":7,"count":1}]	24198	delivery	5	14
60785	2020-05-10 05:17:23	2020-05-10	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7431	delivery	5	43
60786	2020-05-10 05:17:29	2020-05-10	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	24123	delivery	5	39
60787	2020-05-10 05:19:54	2020-05-10	9	[{"id_menu":6,"count":1}]	1259	pick-up	0	9
60788	2020-05-10 05:21:24	2020-05-10	12	[{"id_menu":3,"count":1}]	11129	delivery	5	17
60789	2020-05-10 05:22:15	2020-05-10	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	22061	delivery	5	31
60790	2020-05-10 05:25:19	2020-05-10	14	[{"id_menu":2,"count":1}]	5761	delivery	5	19
60791	2020-05-10 05:25:42	2020-05-10	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	24176	delivery	5	34
60792	2020-05-10 05:27:33	2020-05-10	9	[{"id_menu":6,"count":1}]	24096	delivery	5	14
60793	2020-05-10 05:33:36	2020-05-10	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	9816	pick-up	0	29
60794	2020-05-10 05:34:14	2020-05-10	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	6586	delivery	5	26
60795	2020-05-10 05:35:25	2020-05-10	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	11509	delivery	5	31
60796	2020-05-10 05:35:44	2020-05-10	14	[{"id_menu":2,"count":1}]	24167	delivery	5	19
60797	2020-05-10 05:36:49	2020-05-10	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	20136	delivery	5	30
60798	2020-05-10 05:37:18	2020-05-10	9	[{"id_menu":6,"count":1}]	19429	delivery	5	14
60799	2020-05-10 05:38:46	2020-05-10	8	[{"id_menu":5,"count":1}]	13172	delivery	5	13
60800	2020-05-10 05:39:51	2020-05-10	12	[{"id_menu":3,"count":1}]	11003	delivery	5	17
60801	2020-05-10 05:41:51	2020-05-10	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	7094	pick-up	0	20
60802	2020-05-10 05:45:30	2020-05-10	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2032	delivery	5	25
60803	2020-05-10 05:46:14	2020-05-10	14	[{"id_menu":2,"count":1}]	13370	pick-up	0	14
60804	2020-05-10 05:49:01	2020-05-10	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13854	delivery	5	31
60805	2020-05-10 05:49:27	2020-05-10	12	[{"id_menu":3,"count":1}]	24181	delivery	5	17
60806	2020-05-10 05:53:12	2020-05-10	9	[{"id_menu":7,"count":1}]	24220	delivery	5	14
60807	2020-05-10 05:55:41	2020-05-10	17	[{"id_menu":4,"count":1}]	4737	delivery	5	22
60808	2020-05-10 05:56:02	2020-05-10	12	[{"id_menu":1,"count":1}]	24194	delivery	5	17
60809	2020-05-10 06:03:40	2020-05-10	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	14479	delivery	5	31
60810	2020-05-10 06:04:02	2020-05-10	9	[{"id_menu":6,"count":1}]	24159	delivery	5	14
60811	2020-05-10 06:04:36	2020-05-10	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	24255	delivery	5	36
60812	2020-05-10 06:04:59	2020-05-10	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	20161	delivery	5	40
60813	2020-05-10 06:06:56	2020-05-10	9	[{"id_menu":6,"count":1}]	24134	pick-up	0	9
60814	2020-05-10 06:07:06	2020-05-10	14	[{"id_menu":2,"count":1}]	18198	pick-up	0	14
60815	2020-05-10 06:08:28	2020-05-10	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24101	delivery	5	39
60816	2020-05-10 06:08:59	2020-05-10	14	[{"id_menu":2,"count":2}]	19733	delivery	5	19
60817	2020-05-10 06:15:27	2020-05-10	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	1432	pick-up	0	18
60818	2020-05-10 06:15:40	2020-05-10	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	24204	pick-up	0	40
60819	2020-05-10 06:16:01	2020-05-10	8	[{"id_menu":5,"count":1}]	24214	delivery	5	13
60820	2020-05-10 06:17:45	2020-05-10	12	[{"id_menu":1,"count":1}]	11189	pick-up	0	12
60821	2020-05-10 06:19:16	2020-05-10	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	24155	delivery	5	34
60822	2020-05-10 06:19:53	2020-05-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	18471	delivery	5	22
60823	2020-05-10 06:23:46	2020-05-10	8	[{"id_menu":5,"count":1}]	9934	delivery	5	13
60824	2020-05-10 06:25:21	2020-05-10	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	881	pick-up	0	35
60825	2020-05-10 06:25:51	2020-05-10	9	[{"id_menu":7,"count":2}]	17985	delivery	5	14
60826	2020-05-10 06:27:48	2020-05-10	9	[{"id_menu":7,"count":1}]	24105	pick-up	0	9
60827	2020-05-10 06:28:04	2020-05-10	9	[{"id_menu":7,"count":1}]	5634	delivery	5	14
60828	2020-05-10 06:30:24	2020-05-10	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	14652	pick-up	0	20
60829	2020-05-10 06:33:05	2020-05-10	17	[{"id_menu":4,"count":1}]	15929	pick-up	0	17
60830	2020-05-10 06:37:58	2020-05-10	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3073	pick-up	0	21
60831	2020-05-10 06:38:58	2020-05-10	17	[{"id_menu":4,"count":1}]	11493	pick-up	0	17
60832	2020-05-10 06:43:41	2020-05-10	14	[{"id_menu":2,"count":1}]	24147	delivery	5	19
60833	2020-05-10 06:43:53	2020-05-10	17	[{"id_menu":4,"count":1}]	23983	delivery	5	22
60834	2020-05-10 06:44:26	2020-05-10	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	13950	pick-up	0	22
60835	2020-05-10 06:48:52	2020-05-10	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21860	pick-up	0	48
60836	2020-05-10 06:49:12	2020-05-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1321	pick-up	0	18
60837	2020-05-10 06:49:51	2020-05-10	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	6091	pick-up	0	43
60838	2020-05-10 06:51:12	2020-05-10	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	6591	pick-up	0	26
60839	2020-05-10 06:51:35	2020-05-10	9	[{"id_menu":7,"count":1}]	24130	delivery	5	14
60840	2020-05-10 06:51:53	2020-05-10	14	[{"id_menu":2,"count":1}]	7806	pick-up	0	14
60841	2020-05-10 06:52:13	2020-05-10	9	[{"id_menu":7,"count":1}]	24164	delivery	5	14
60842	2020-05-10 06:54:17	2020-05-10	12	[{"id_menu":1,"count":1}]	351	pick-up	0	12
60843	2020-05-10 06:55:20	2020-05-10	17	[{"id_menu":4,"count":1}]	24188	delivery	5	22
60844	2020-05-10 06:55:49	2020-05-10	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24128	delivery	5	22
60845	2020-05-10 06:56:04	2020-05-10	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	8493	pick-up	0	21
60846	2020-05-10 06:57:11	2020-05-10	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17451	delivery	5	51
60847	2020-05-10 06:59:41	2020-05-10	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23420	delivery	5	48
60848	2020-05-10 07:07:18	2020-05-10	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	24253	delivery	5	26
60849	2020-05-10 07:07:19	2020-05-10	12	[{"id_menu":3,"count":1}]	5201	pick-up	0	12
60850	2020-05-10 07:08:54	2020-05-10	14	[{"id_menu":2,"count":1}]	24156	pick-up	0	14
60851	2020-05-10 07:16:28	2020-05-10	14	[{"id_menu":2,"count":1}]	22952	pick-up	0	14
60852	2020-05-10 07:17:41	2020-05-10	8	[{"id_menu":5,"count":1}]	8372	pick-up	0	8
60853	2020-05-10 07:19:21	2020-05-10	12	[{"id_menu":1,"count":1}]	24272	delivery	5	17
60854	2020-05-10 07:21:10	2020-05-10	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":2}]	24098	delivery	5	31
60855	2020-05-10 07:22:12	2020-05-10	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16710	pick-up	0	31
60856	2020-05-10 07:24:31	2020-05-10	12	[{"id_menu":1,"count":1}]	15488	delivery	5	17
60857	2020-05-10 07:25:51	2020-05-10	12	[{"id_menu":3,"count":1}]	24263	delivery	5	17
60858	2020-05-10 07:26:32	2020-05-10	8	[{"id_menu":5,"count":1}]	11688	delivery	5	13
60859	2020-05-10 07:26:38	2020-05-10	12	[{"id_menu":1,"count":1}]	7570	delivery	5	17
60860	2020-05-10 07:27:03	2020-05-10	14	[{"id_menu":2,"count":1}]	24284	pick-up	0	14
60861	2020-05-10 07:27:30	2020-05-10	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	22606	delivery	5	31
60862	2020-05-10 07:29:04	2020-05-10	9	[{"id_menu":7,"count":1}]	23072	delivery	5	14
60863	2020-05-10 07:32:54	2020-05-10	12	[{"id_menu":1,"count":1}]	20820	delivery	5	17
60864	2020-05-10 07:41:15	2020-05-10	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	24213	delivery	5	23
60865	2020-05-10 07:44:41	2020-05-10	8	[{"id_menu":5,"count":1}]	24175	delivery	5	13
60866	2020-05-10 07:48:10	2020-05-10	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	15726	delivery	5	31
60867	2020-05-10 07:49:59	2020-05-10	8	[{"id_menu":5,"count":1}]	22544	pick-up	0	8
60868	2020-05-10 07:50:07	2020-05-10	14	[{"id_menu":2,"count":1}]	9698	delivery	5	19
60869	2020-05-10 07:51:06	2020-05-10	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21690	delivery	5	37
60870	2020-05-10 07:52:41	2020-05-10	14	[{"id_menu":2,"count":1}]	23665	delivery	5	19
60871	2020-05-10 07:54:29	2020-05-10	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	5144	pick-up	0	43
60872	2020-05-10 07:59:24	2020-05-10	14	[{"id_menu":2,"count":1}]	11517	delivery	5	19
60873	2020-05-10 08:06:19	2020-05-10	12	[{"id_menu":3,"count":1}]	3232	delivery	5	17
60874	2020-05-10 08:09:51	2020-05-10	17	[{"id_menu":4,"count":1}]	19686	delivery	5	22
60875	2020-05-10 08:15:21	2020-05-10	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3871	pick-up	0	40
60876	2020-05-10 08:20:22	2020-05-10	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	15373	pick-up	0	35
60877	2020-05-10 08:25:52	2020-05-10	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11156	pick-up	0	29
60878	2020-05-10 08:26:26	2020-05-10	9	[{"id_menu":6,"count":1}]	11448	delivery	5	14
60879	2020-05-10 08:32:11	2020-05-10	12	[{"id_menu":3,"count":1}]	24210	delivery	5	17
60880	2020-05-10 08:33:53	2020-05-10	9	[{"id_menu":6,"count":1}]	10760	pick-up	0	9
60881	2020-05-10 08:35:37	2020-05-10	9	[{"id_menu":7,"count":1}]	6883	delivery	5	14
60882	2020-05-10 08:42:06	2020-05-10	9	[{"id_menu":7,"count":1}]	24149	delivery	5	14
60883	2020-05-10 08:43:08	2020-05-10	9	[{"id_menu":6,"count":1}]	22822	pick-up	0	9
60884	2020-05-10 08:45:21	2020-05-10	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24219	delivery	5	22
60885	2020-05-10 08:46:50	2020-05-10	9	[{"id_menu":7,"count":1}]	7202	delivery	5	14
60886	2020-05-10 08:48:31	2020-05-10	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14825	delivery	5	35
60887	2020-05-10 08:48:47	2020-05-10	17	[{"id_menu":4,"count":1}]	1215	pick-up	0	17
60888	2020-05-10 08:50:56	2020-05-10	12	[{"id_menu":3,"count":1}]	24233	delivery	5	17
60889	2020-05-10 08:54:16	2020-05-10	8	[{"id_menu":5,"count":1}]	24266	delivery	5	13
60890	2020-05-10 08:58:14	2020-05-10	20	[{"id_menu":3,"count":3},{"id_menu":5,"count":1}]	1905	pick-up	0	20
60891	2020-05-10 09:00:08	2020-05-10	12	[{"id_menu":3,"count":1}]	19750	delivery	5	17
60892	2020-05-10 09:00:20	2020-05-10	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	7759	delivery	5	31
60893	2020-05-10 09:00:39	2020-05-10	12	[{"id_menu":3,"count":1}]	24166	delivery	5	17
60894	2020-05-10 09:01:35	2020-05-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	20407	delivery	5	28
60895	2020-05-10 09:02:00	2020-05-10	12	[{"id_menu":3,"count":1}]	1375	pick-up	0	12
60896	2020-05-10 09:02:40	2020-05-10	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15495	delivery	5	43
60897	2020-05-10 09:03:40	2020-05-10	9	[{"id_menu":7,"count":1}]	8909	delivery	5	14
60898	2020-05-10 09:05:27	2020-05-10	12	[{"id_menu":1,"count":1}]	24222	delivery	5	17
60899	2020-05-10 09:10:41	2020-05-10	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	4325	delivery	5	34
60900	2020-05-10 09:11:37	2020-05-10	9	[{"id_menu":6,"count":1}]	24247	delivery	5	14
60901	2020-05-10 09:15:48	2020-05-10	9	[{"id_menu":6,"count":1}]	13968	delivery	5	14
60902	2020-05-10 09:17:54	2020-05-10	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	24180	delivery	5	26
60903	2020-05-10 09:20:02	2020-05-10	14	[{"id_menu":2,"count":1}]	13621	delivery	5	19
60904	2020-05-10 09:21:02	2020-05-10	12	[{"id_menu":1,"count":1}]	24271	delivery	5	17
60905	2020-05-10 09:22:12	2020-05-10	9	[{"id_menu":6,"count":1}]	17967	delivery	5	14
60906	2020-05-10 09:26:23	2020-05-10	17	[{"id_menu":4,"count":1}]	18454	delivery	5	22
60907	2020-05-10 09:30:11	2020-05-10	29	[{"id_menu":3,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18475	delivery	5	34
60908	2020-05-10 09:32:03	2020-05-10	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4592	delivery	5	36
60909	2020-05-10 09:33:05	2020-05-10	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	15048	pick-up	0	21
60910	2020-05-10 09:37:12	2020-05-10	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	274	pick-up	0	29
60911	2020-05-10 09:40:19	2020-05-10	12	[{"id_menu":1,"count":1}]	10258	pick-up	0	12
60912	2020-05-10 09:41:02	2020-05-10	17	[{"id_menu":4,"count":1}]	20697	pick-up	0	17
60913	2020-05-10 09:42:01	2020-05-10	14	[{"id_menu":2,"count":1}]	344	delivery	5	19
60914	2020-05-10 09:43:42	2020-05-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	24102	pick-up	0	23
60915	2020-05-10 09:45:26	2020-05-10	12	[{"id_menu":3,"count":1}]	1503	pick-up	0	12
60916	2020-05-10 09:49:35	2020-05-10	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	5730	delivery	5	31
60917	2020-05-10 09:54:59	2020-05-10	9	[{"id_menu":7,"count":1}]	24191	pick-up	0	9
60918	2020-05-10 10:01:47	2020-05-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	21562	delivery	5	28
60919	2020-05-10 10:02:49	2020-05-10	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24121	delivery	5	22
60920	2020-05-10 10:03:34	2020-05-10	9	[{"id_menu":7,"count":1}]	8128	delivery	5	14
60921	2020-05-10 10:09:37	2020-05-10	9	[{"id_menu":6,"count":1}]	5685	delivery	5	14
60922	2020-05-10 10:12:23	2020-05-10	14	[{"id_menu":2,"count":1}]	24252	delivery	5	19
60923	2020-05-10 10:14:48	2020-05-10	9	[{"id_menu":6,"count":1}]	18453	delivery	5	14
60924	2020-05-10 10:14:52	2020-05-10	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	9031	delivery	5	25
60925	2020-05-10 10:18:54	2020-05-10	12	[{"id_menu":3,"count":1}]	8877	delivery	5	17
60926	2020-05-10 10:20:47	2020-05-10	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	24184	delivery	5	36
60927	2020-05-10 10:22:05	2020-05-10	9	[{"id_menu":7,"count":1}]	24146	delivery	5	14
60928	2020-05-10 10:25:54	2020-05-10	9	[{"id_menu":7,"count":1}]	15797	pick-up	0	9
60929	2020-05-10 10:27:08	2020-05-10	9	[{"id_menu":7,"count":1}]	24142	delivery	5	14
60930	2020-05-10 10:28:32	2020-05-10	12	[{"id_menu":1,"count":1}]	20186	delivery	5	17
60931	2020-05-10 10:28:47	2020-05-10	9	[{"id_menu":6,"count":1}]	8618	delivery	5	14
60932	2020-05-10 10:30:05	2020-05-10	9	[{"id_menu":6,"count":1}]	24154	delivery	5	14
60933	2020-05-10 10:31:56	2020-05-10	9	[{"id_menu":7,"count":1}]	23283	delivery	5	14
60934	2020-05-10 10:36:29	2020-05-10	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	18634	delivery	5	26
60935	2020-05-10 10:37:25	2020-05-10	8	[{"id_menu":5,"count":1}]	6645	delivery	5	13
60936	2020-05-10 10:37:39	2020-05-10	14	[{"id_menu":2,"count":1}]	24209	delivery	5	19
60937	2020-05-10 10:38:12	2020-05-10	8	[{"id_menu":5,"count":1}]	14488	delivery	5	13
60938	2020-05-10 10:38:36	2020-05-10	9	[{"id_menu":7,"count":1}]	24163	delivery	5	14
60939	2020-05-10 10:47:11	2020-05-10	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7122	delivery	5	42
60940	2020-05-10 10:49:40	2020-05-10	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	24216	delivery	5	36
60941	2020-05-10 10:51:54	2020-05-10	9	[{"id_menu":6,"count":1}]	11004	delivery	5	14
60942	2020-05-10 10:54:03	2020-05-10	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	22292	delivery	5	42
60943	2020-05-10 10:56:31	2020-05-10	12	[{"id_menu":1,"count":1}]	7098	pick-up	0	12
60944	2020-05-10 10:57:02	2020-05-10	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24258	delivery	5	31
60945	2020-05-10 10:57:25	2020-05-10	8	[{"id_menu":5,"count":1}]	24227	delivery	5	13
60946	2020-05-10 10:57:42	2020-05-10	14	[{"id_menu":2,"count":1}]	24186	delivery	5	19
60947	2020-05-10 11:01:32	2020-05-10	17	[{"id_menu":4,"count":1}]	536	pick-up	0	17
60948	2020-05-10 11:03:02	2020-05-10	9	[{"id_menu":7,"count":1}]	20097	delivery	5	14
60949	2020-05-10 11:03:38	2020-05-10	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	24208	delivery	5	31
60950	2020-05-10 11:04:33	2020-05-10	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2498	delivery	5	31
60951	2020-05-10 11:08:04	2020-05-10	12	[{"id_menu":1,"count":1}]	24265	delivery	5	17
60952	2020-05-10 11:14:01	2020-05-10	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	12480	delivery	5	39
60953	2020-05-10 11:14:52	2020-05-10	8	[{"id_menu":5,"count":1}]	3984	delivery	5	13
60954	2020-05-10 11:15:07	2020-05-10	9	[{"id_menu":7,"count":1}]	2952	delivery	5	14
60955	2020-05-10 11:15:59	2020-05-10	17	[{"id_menu":4,"count":1}]	15263	delivery	5	22
60956	2020-05-10 11:18:33	2020-05-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17723	pick-up	0	18
60957	2020-05-10 11:19:02	2020-05-10	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	24212	pick-up	0	52
60958	2020-05-10 11:19:28	2020-05-10	14	[{"id_menu":2,"count":1}]	304	delivery	5	19
60959	2020-05-10 11:22:56	2020-05-10	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	24282	delivery	5	40
60960	2020-05-10 11:23:43	2020-05-10	9	[{"id_menu":7,"count":3}]	8486	delivery	5	14
60961	2020-05-10 11:23:52	2020-05-10	12	[{"id_menu":3,"count":1}]	24099	delivery	5	17
60962	2020-05-10 11:26:09	2020-05-10	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	24177	delivery	5	34
60963	2020-05-10 11:27:36	2020-05-10	9	[{"id_menu":6,"count":1}]	24097	delivery	5	14
60964	2020-05-10 11:30:10	2020-05-10	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	24232	delivery	5	55
60965	2020-05-10 11:31:41	2020-05-10	9	[{"id_menu":7,"count":1}]	24126	delivery	5	14
60966	2020-05-10 11:35:55	2020-05-10	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	4801	delivery	5	31
60967	2020-05-10 11:38:16	2020-05-10	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6966	delivery	5	36
60968	2020-05-10 11:39:05	2020-05-10	12	[{"id_menu":3,"count":1}]	9222	delivery	5	17
60969	2020-05-10 11:39:20	2020-05-10	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	24203	delivery	5	40
60970	2020-05-10 11:39:27	2020-05-10	9	[{"id_menu":6,"count":1}]	9301	pick-up	0	9
60971	2020-05-10 11:41:57	2020-05-10	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	24229	delivery	5	34
60972	2020-05-10 11:43:13	2020-05-10	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	8027	delivery	5	35
60973	2020-05-10 11:43:54	2020-05-10	12	[{"id_menu":3,"count":1}]	16466	pick-up	0	12
60974	2020-05-10 11:45:03	2020-05-10	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24242	delivery	5	37
60975	2020-05-10 11:48:17	2020-05-10	17	[{"id_menu":4,"count":1}]	5702	pick-up	0	17
60976	2020-05-10 11:49:53	2020-05-10	14	[{"id_menu":2,"count":1}]	11904	delivery	5	19
60977	2020-05-10 11:50:23	2020-05-10	17	[{"id_menu":4,"count":1}]	14025	delivery	5	22
60978	2020-05-10 11:51:04	2020-05-10	17	[{"id_menu":4,"count":1}]	24131	delivery	5	22
60979	2020-05-10 11:54:08	2020-05-10	14	[{"id_menu":2,"count":1}]	24148	delivery	5	19
60980	2020-05-10 11:55:17	2020-05-10	12	[{"id_menu":3,"count":2}]	7320	pick-up	0	12
60981	2020-05-10 11:55:50	2020-05-10	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24140	delivery	5	43
60982	2020-05-10 11:57:13	2020-05-10	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	17994	delivery	5	40
60983	2020-05-10 11:58:05	2020-05-10	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	20907	delivery	5	26
60984	2020-05-10 11:58:29	2020-05-10	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24279	delivery	5	48
60985	2020-05-10 11:58:41	2020-05-10	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	22056	delivery	5	26
60986	2020-05-10 11:59:09	2020-05-10	8	[{"id_menu":5,"count":1}]	24267	delivery	5	13
60987	2020-05-10 11:59:35	2020-05-10	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	8205	delivery	5	26
60988	2020-05-10 12:02:49	2020-05-10	8	[{"id_menu":5,"count":1}]	13371	delivery	5	13
60989	2020-05-10 12:06:13	2020-05-10	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	24260	pick-up	0	31
60990	2020-05-10 12:11:10	2020-05-10	12	[{"id_menu":1,"count":1}]	11222	delivery	5	17
60991	2020-05-10 12:12:25	2020-05-10	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	3455	delivery	5	28
60992	2020-05-10 12:26:15	2020-05-10	9	[{"id_menu":7,"count":1}]	24228	delivery	5	14
60993	2020-05-10 12:28:53	2020-05-10	9	[{"id_menu":6,"count":1}]	24239	delivery	5	14
60994	2020-05-10 12:30:17	2020-05-10	9	[{"id_menu":6,"count":2}]	15469	delivery	5	14
60995	2020-05-10 12:30:24	2020-05-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24160	delivery	5	23
60996	2020-05-10 12:33:02	2020-05-10	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9956	delivery	5	35
60997	2020-05-10 12:33:39	2020-05-10	9	[{"id_menu":7,"count":1}]	24143	pick-up	0	9
60998	2020-05-10 12:34:15	2020-05-10	9	[{"id_menu":6,"count":1}]	15395	delivery	5	14
60999	2020-05-10 12:36:48	2020-05-10	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	24182	delivery	5	34
61000	2020-05-10 12:37:22	2020-05-10	12	[{"id_menu":3,"count":1}]	3261	delivery	5	17
61001	2020-05-10 12:39:02	2020-05-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24165	delivery	5	22
61002	2020-05-10 12:42:03	2020-05-10	8	[{"id_menu":5,"count":1}]	2197	delivery	5	13
61003	2020-05-10 12:42:08	2020-05-10	34	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	18287	delivery	5	39
61004	2020-05-10 12:42:24	2020-05-10	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1911	delivery	5	27
61005	2020-05-10 12:42:33	2020-05-10	14	[{"id_menu":2,"count":1}]	22414	delivery	5	19
61006	2020-05-10 12:43:33	2020-05-10	12	[{"id_menu":3,"count":1}]	13859	pick-up	0	12
61007	2020-05-10 12:45:24	2020-05-10	12	[{"id_menu":1,"count":1}]	383	delivery	5	17
61008	2020-05-10 12:47:36	2020-05-10	12	[{"id_menu":3,"count":2}]	14190	pick-up	0	12
61009	2020-05-10 12:48:59	2020-05-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20480	delivery	5	23
61010	2020-05-10 12:49:09	2020-05-10	9	[{"id_menu":7,"count":1}]	24115	delivery	5	14
61011	2020-05-10 12:54:10	2020-05-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21835	delivery	5	23
61012	2020-05-10 12:57:41	2020-05-10	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	12930	delivery	5	26
61013	2020-05-10 13:02:31	2020-05-10	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24275	delivery	5	40
61014	2020-05-10 13:04:20	2020-05-10	14	[{"id_menu":2,"count":1}]	15350	delivery	5	19
61015	2020-05-10 13:06:06	2020-05-10	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":3}]	8550	pick-up	0	31
61016	2020-05-10 13:09:07	2020-05-10	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8034	delivery	5	31
61017	2020-05-10 13:13:13	2020-05-10	17	[{"id_menu":4,"count":1}]	14358	pick-up	0	17
61018	2020-05-10 13:13:38	2020-05-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	24145	delivery	5	28
61019	2020-05-10 13:15:08	2020-05-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	24169	delivery	5	28
61020	2020-05-10 13:16:48	2020-05-10	14	[{"id_menu":2,"count":1}]	7612	delivery	5	19
61021	2020-05-10 13:16:58	2020-05-10	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2806	delivery	5	48
61022	2020-05-10 13:20:49	2020-05-10	12	[{"id_menu":1,"count":1}]	24262	delivery	5	17
61023	2020-05-10 13:21:29	2020-05-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	10359	delivery	5	28
61024	2020-05-10 13:22:52	2020-05-10	9	[{"id_menu":7,"count":2}]	9907	pick-up	0	9
61025	2020-05-10 13:29:00	2020-05-10	9	[{"id_menu":7,"count":1}]	24226	delivery	5	14
61026	2020-05-10 13:32:32	2020-05-10	8	[{"id_menu":5,"count":1}]	528	delivery	5	13
61027	2020-05-10 13:36:47	2020-05-10	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	23115	delivery	5	39
61028	2020-05-10 13:39:19	2020-05-10	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	22839	delivery	5	39
61029	2020-05-10 13:40:31	2020-05-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	19019	delivery	5	28
61030	2020-05-10 13:43:37	2020-05-10	14	[{"id_menu":2,"count":1}]	3268	pick-up	0	14
61031	2020-05-10 13:44:24	2020-05-10	17	[{"id_menu":4,"count":1}]	16562	delivery	5	22
61032	2020-05-10 13:46:01	2020-05-10	12	[{"id_menu":3,"count":1}]	21520	delivery	5	17
61033	2020-05-10 13:46:51	2020-05-10	17	[{"id_menu":4,"count":1}]	14667	delivery	5	22
61034	2020-05-10 13:47:38	2020-05-10	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	887	delivery	5	34
61035	2020-05-10 13:49:26	2020-05-10	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	20993	delivery	5	36
61036	2020-05-10 13:50:13	2020-05-10	9	[{"id_menu":7,"count":1}]	3706	pick-up	0	9
61037	2020-05-10 13:55:37	2020-05-10	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	24238	delivery	5	31
61038	2020-05-10 13:57:27	2020-05-10	14	[{"id_menu":2,"count":1}]	19554	delivery	5	19
61039	2020-05-10 13:58:39	2020-05-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24135	delivery	5	22
61040	2020-05-10 14:02:43	2020-05-10	9	[{"id_menu":7,"count":1}]	9737	delivery	5	14
61041	2020-05-10 14:03:43	2020-05-10	12	[{"id_menu":3,"count":1}]	8743	pick-up	0	12
61042	2020-05-10 14:05:30	2020-05-10	9	[{"id_menu":7,"count":1}]	24273	delivery	5	14
61043	2020-05-10 14:06:19	2020-05-10	12	[{"id_menu":3,"count":1}]	24206	delivery	5	17
61044	2020-05-10 14:09:58	2020-05-10	14	[{"id_menu":2,"count":1}]	24245	delivery	5	19
61045	2020-05-10 14:10:29	2020-05-10	9	[{"id_menu":6,"count":1}]	10394	pick-up	0	9
61046	2020-05-10 14:12:09	2020-05-10	9	[{"id_menu":6,"count":1}]	13126	delivery	5	14
61047	2020-05-10 14:13:07	2020-05-10	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	24122	pick-up	0	21
61048	2020-05-10 14:13:29	2020-05-10	14	[{"id_menu":2,"count":1}]	23832	delivery	5	19
61049	2020-05-10 14:15:00	2020-05-10	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	12185	delivery	5	25
61050	2020-05-10 14:17:26	2020-05-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3664	delivery	5	28
61051	2020-05-10 14:19:17	2020-05-10	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	17094	delivery	5	31
61052	2020-05-10 14:19:51	2020-05-10	14	[{"id_menu":2,"count":1}]	2301	delivery	5	19
61053	2020-05-10 14:29:34	2020-05-10	8	[{"id_menu":5,"count":1}]	11803	delivery	5	13
61054	2020-05-10 14:31:07	2020-05-10	17	[{"id_menu":4,"count":1}]	1495	delivery	5	22
61055	2020-05-10 14:36:17	2020-05-10	9	[{"id_menu":6,"count":1}]	4836	delivery	5	14
61056	2020-05-10 14:38:34	2020-05-10	12	[{"id_menu":1,"count":1}]	24281	delivery	5	17
61057	2020-05-10 14:40:53	2020-05-10	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24116	pick-up	0	43
61058	2020-05-10 14:41:42	2020-05-10	8	[{"id_menu":5,"count":1}]	6241	delivery	5	13
61059	2020-05-10 14:46:46	2020-05-10	8	[{"id_menu":5,"count":1}]	18579	delivery	5	13
61060	2020-05-10 14:47:28	2020-05-10	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3190	pick-up	0	17
61061	2020-05-10 14:49:52	2020-05-10	17	[{"id_menu":4,"count":1}]	24187	delivery	5	22
61062	2020-05-10 14:52:44	2020-05-10	14	[{"id_menu":2,"count":1}]	4841	pick-up	0	14
61063	2020-05-10 14:55:12	2020-05-10	17	[{"id_menu":4,"count":1}]	13097	delivery	5	22
61064	2020-05-10 14:55:51	2020-05-10	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19230	delivery	5	48
61065	2020-05-10 14:56:53	2020-05-10	17	[{"id_menu":4,"count":1}]	4796	delivery	5	22
61066	2020-05-10 14:57:51	2020-05-10	8	[{"id_menu":5,"count":1}]	24199	pick-up	0	8
61067	2020-05-10 14:57:54	2020-05-10	9	[{"id_menu":7,"count":2}]	12254	pick-up	0	9
61068	2020-05-10 15:01:51	2020-05-10	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	12314	delivery	5	25
61069	2020-05-10 15:02:13	2020-05-10	26	[{"id_menu":2,"count":3},{"id_menu":3,"count":1}]	2956	delivery	5	31
61070	2020-05-10 15:02:22	2020-05-10	9	[{"id_menu":6,"count":1}]	5198	pick-up	0	9
61071	2020-05-10 15:03:40	2020-05-10	9	[{"id_menu":6,"count":1}]	23156	delivery	5	14
61072	2020-05-10 15:04:32	2020-05-10	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	20780	pick-up	0	26
61073	2020-05-10 15:05:54	2020-05-10	12	[{"id_menu":1,"count":1}]	2761	delivery	5	17
61074	2020-05-10 15:06:38	2020-05-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18987	delivery	5	23
61075	2020-05-10 15:10:13	2020-05-10	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16774	delivery	5	51
61076	2020-05-10 15:10:54	2020-05-10	9	[{"id_menu":6,"count":1}]	7776	pick-up	0	9
61077	2020-05-10 15:14:54	2020-05-10	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19657	delivery	5	45
61078	2020-05-10 15:23:54	2020-05-10	9	[{"id_menu":7,"count":1}]	705	pick-up	0	9
61079	2020-05-10 15:26:13	2020-05-10	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	24215	delivery	5	26
61080	2020-05-10 15:26:39	2020-05-10	9	[{"id_menu":7,"count":1}]	24174	delivery	5	14
61081	2020-05-10 15:27:10	2020-05-10	9	[{"id_menu":6,"count":1}]	5019	pick-up	0	9
61082	2020-05-10 15:27:33	2020-05-10	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	19601	pick-up	0	24
61083	2020-05-10 15:28:17	2020-05-10	9	[{"id_menu":7,"count":1}]	8767	delivery	5	14
61084	2020-05-10 15:29:42	2020-05-10	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2630	pick-up	0	43
61085	2020-05-10 15:37:02	2020-05-10	29	[{"id_menu":3,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18125	delivery	5	34
61086	2020-05-10 15:40:22	2020-05-10	12	[{"id_menu":1,"count":1}]	21112	delivery	5	17
61087	2020-05-10 15:43:09	2020-05-10	9	[{"id_menu":6,"count":1}]	9308	pick-up	0	9
61088	2020-05-10 15:44:50	2020-05-10	12	[{"id_menu":1,"count":1}]	14521	pick-up	0	12
61089	2020-05-10 15:50:46	2020-05-10	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	21038	delivery	5	31
61090	2020-05-10 15:54:50	2020-05-10	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	17953	pick-up	0	20
61091	2020-05-10 15:58:06	2020-05-10	9	[{"id_menu":7,"count":1}]	6068	delivery	5	14
61092	2020-05-10 16:01:44	2020-05-10	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	24237	delivery	5	40
61093	2020-05-10 16:02:40	2020-05-10	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	5668	delivery	5	42
61094	2020-05-10 16:09:58	2020-05-10	9	[{"id_menu":7,"count":1}]	2648	delivery	5	14
61095	2020-05-10 16:10:34	2020-05-10	12	[{"id_menu":3,"count":1}]	22742	delivery	5	17
61096	2020-05-10 16:11:58	2020-05-10	8	[{"id_menu":5,"count":1}]	5047	pick-up	0	8
61097	2020-05-10 16:13:31	2020-05-10	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1593	pick-up	0	48
61098	2020-05-10 16:16:47	2020-05-10	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	4447	delivery	5	26
61099	2020-05-10 16:17:30	2020-05-10	9	[{"id_menu":7,"count":1}]	15971	delivery	5	14
61100	2020-05-10 16:23:55	2020-05-10	12	[{"id_menu":1,"count":1}]	14824	delivery	5	17
61101	2020-05-10 16:26:29	2020-05-10	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14273	delivery	5	37
61102	2020-05-10 16:27:01	2020-05-10	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24018	pick-up	0	35
61103	2020-05-10 16:28:40	2020-05-10	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17123	delivery	5	35
61104	2020-05-10 16:29:16	2020-05-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	24189	pick-up	0	23
61105	2020-05-10 16:29:25	2020-05-10	17	[{"id_menu":4,"count":1}]	15994	delivery	5	22
61106	2020-05-10 16:30:58	2020-05-10	8	[{"id_menu":5,"count":1}]	19207	delivery	5	13
61107	2020-05-10 16:33:53	2020-05-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1457	delivery	5	28
61108	2020-05-10 16:34:57	2020-05-10	9	[{"id_menu":6,"count":1}]	1417	pick-up	0	9
61109	2020-05-10 16:38:06	2020-05-10	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	3668	delivery	5	26
61110	2020-05-10 16:38:57	2020-05-10	12	[{"id_menu":3,"count":1}]	21513	delivery	5	17
61111	2020-05-10 16:44:23	2020-05-10	9	[{"id_menu":7,"count":1}]	4384	pick-up	0	9
61112	2020-05-10 16:49:39	2020-05-10	8	[{"id_menu":5,"count":1}]	19717	pick-up	0	8
61113	2020-05-10 16:50:34	2020-05-10	8	[{"id_menu":5,"count":1}]	19892	delivery	5	13
61114	2020-05-10 16:55:07	2020-05-10	9	[{"id_menu":7,"count":1}]	13257	delivery	5	14
61115	2020-05-10 16:56:04	2020-05-10	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	4947	delivery	5	23
61116	2020-05-10 16:56:57	2020-05-10	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18879	delivery	5	48
61117	2020-05-10 16:58:23	2020-05-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4290	delivery	5	28
61118	2020-05-10 17:00:11	2020-05-10	12	[{"id_menu":3,"count":1}]	10331	pick-up	0	12
61119	2020-05-10 17:00:43	2020-05-10	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13825	delivery	5	36
61120	2020-05-10 17:03:03	2020-05-10	17	[{"id_menu":4,"count":1}]	24108	pick-up	0	17
61121	2020-05-10 17:03:16	2020-05-10	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	20806	pick-up	0	31
61122	2020-05-10 17:08:33	2020-05-10	8	[{"id_menu":5,"count":1}]	24251	delivery	5	13
61123	2020-05-10 17:11:10	2020-05-10	12	[{"id_menu":1,"count":1}]	17026	delivery	5	17
61124	2020-05-10 17:11:44	2020-05-10	9	[{"id_menu":6,"count":1}]	20183	delivery	5	14
61125	2020-05-10 17:12:02	2020-05-10	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	24221	delivery	5	27
61126	2020-05-10 17:12:06	2020-05-10	9	[{"id_menu":6,"count":1}]	22161	delivery	5	14
61127	2020-05-10 17:13:37	2020-05-10	12	[{"id_menu":1,"count":1}]	24197	delivery	5	17
61128	2020-05-10 17:16:51	2020-05-10	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	24117	delivery	5	39
61129	2020-05-10 17:19:18	2020-05-10	9	[{"id_menu":6,"count":1}]	24259	delivery	5	14
61130	2020-05-10 17:19:19	2020-05-10	12	[{"id_menu":1,"count":1}]	6769	delivery	5	17
61131	2020-05-10 17:19:34	2020-05-10	17	[{"id_menu":4,"count":1}]	20024	delivery	5	22
61132	2020-05-10 17:22:30	2020-05-10	17	[{"id_menu":4,"count":1}]	24278	pick-up	0	17
61133	2020-05-10 17:22:38	2020-05-10	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2959	pick-up	0	29
61134	2020-05-10 17:29:17	2020-05-10	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24171	delivery	5	39
61135	2020-05-10 17:33:48	2020-05-10	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5792	delivery	5	40
61136	2020-05-10 17:34:16	2020-05-10	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	791	delivery	5	36
61137	2020-05-10 17:36:35	2020-05-10	9	[{"id_menu":6,"count":1}]	7642	delivery	5	14
61138	2020-05-10 17:39:00	2020-05-10	17	[{"id_menu":4,"count":2}]	14558	pick-up	0	17
61139	2020-05-10 17:40:00	2020-05-10	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	18870	delivery	5	31
61140	2020-05-10 17:41:14	2020-05-10	14	[{"id_menu":2,"count":1}]	6668	delivery	5	19
61141	2020-05-10 17:44:43	2020-05-10	12	[{"id_menu":1,"count":1}]	4908	delivery	5	17
61142	2020-05-10 17:46:24	2020-05-10	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20138	delivery	5	40
61143	2020-05-10 17:47:48	2020-05-10	12	[{"id_menu":1,"count":1}]	24193	delivery	5	17
61144	2020-05-10 17:48:43	2020-05-10	9	[{"id_menu":6,"count":1}]	10553	pick-up	0	9
61145	2020-05-10 17:49:01	2020-05-10	9	[{"id_menu":6,"count":1}]	4075	pick-up	0	9
61146	2020-05-10 17:51:14	2020-05-10	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	22232	delivery	5	43
61147	2020-05-10 17:55:39	2020-05-10	9	[{"id_menu":7,"count":2}]	10281	pick-up	0	9
61148	2020-05-10 18:01:36	2020-05-10	9	[{"id_menu":7,"count":1}]	7235	delivery	5	14
61149	2020-05-10 18:02:51	2020-05-10	8	[{"id_menu":5,"count":1}]	7000	delivery	5	13
61150	2020-05-10 18:03:56	2020-05-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	11039	delivery	5	28
61151	2020-05-10 18:05:17	2020-05-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	20842	delivery	5	28
61152	2020-05-10 18:12:45	2020-05-10	14	[{"id_menu":2,"count":1}]	16858	pick-up	0	14
61153	2020-05-10 18:13:26	2020-05-10	9	[{"id_menu":6,"count":1}]	24144	delivery	5	14
61154	2020-05-10 18:13:55	2020-05-10	9	[{"id_menu":7,"count":1}]	24274	pick-up	0	9
61155	2020-05-10 18:15:59	2020-05-10	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	24114	delivery	5	25
61156	2020-05-10 18:21:17	2020-05-10	8	[{"id_menu":5,"count":1}]	10850	pick-up	0	8
61157	2020-05-10 18:23:11	2020-05-10	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2714	pick-up	0	22
61158	2020-05-10 18:24:01	2020-05-10	8	[{"id_menu":5,"count":1}]	21345	pick-up	0	8
61159	2020-05-10 18:25:44	2020-05-10	17	[{"id_menu":4,"count":1}]	2651	pick-up	0	17
61160	2020-05-10 18:27:25	2020-05-10	9	[{"id_menu":7,"count":1}]	24256	delivery	5	14
61161	2020-05-10 18:28:03	2020-05-10	9	[{"id_menu":7,"count":1}]	15425	delivery	5	14
61162	2020-05-10 18:29:03	2020-05-10	12	[{"id_menu":1,"count":1}]	2932	delivery	5	17
61163	2020-05-10 18:33:03	2020-05-10	9	[{"id_menu":7,"count":1}]	15653	delivery	5	14
61164	2020-05-10 18:37:41	2020-05-10	9	[{"id_menu":7,"count":1}]	21976	delivery	5	14
61165	2020-05-10 18:38:09	2020-05-10	9	[{"id_menu":6,"count":1}]	24103	delivery	5	14
61166	2020-05-10 18:41:38	2020-05-10	14	[{"id_menu":2,"count":1}]	24178	delivery	5	19
61167	2020-05-10 18:43:29	2020-05-10	8	[{"id_menu":5,"count":1}]	20231	pick-up	0	8
61168	2020-05-10 18:44:26	2020-05-10	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	14476	delivery	5	36
61169	2020-05-10 18:48:39	2020-05-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	22099	delivery	5	28
61170	2020-05-10 18:50:01	2020-05-10	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	18367	delivery	5	43
61171	2020-05-10 18:50:28	2020-05-10	14	[{"id_menu":2,"count":2}]	6848	pick-up	0	14
61172	2020-05-10 18:52:08	2020-05-10	9	[{"id_menu":7,"count":1}]	24195	delivery	5	14
61173	2020-05-10 18:56:13	2020-05-10	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	24240	delivery	5	25
61174	2020-05-10 18:56:57	2020-05-10	12	[{"id_menu":1,"count":1}]	24244	delivery	5	17
61175	2020-05-10 18:57:48	2020-05-10	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21170	delivery	5	36
61176	2020-05-10 18:58:57	2020-05-10	12	[{"id_menu":1,"count":1}]	24151	delivery	5	17
61177	2020-05-10 18:59:46	2020-05-10	9	[{"id_menu":7,"count":1}]	2508	delivery	5	14
61178	2020-05-10 19:02:35	2020-05-10	12	[{"id_menu":1,"count":1}]	6249	delivery	5	17
61179	2020-05-10 19:03:00	2020-05-10	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24202	delivery	5	35
61180	2020-05-10 19:05:00	2020-05-10	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	24113	delivery	5	31
61181	2020-05-10 19:08:37	2020-05-10	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	24132	delivery	5	43
61182	2020-05-10 19:13:03	2020-05-10	9	[{"id_menu":7,"count":1}]	24241	delivery	5	14
61183	2020-05-10 19:13:53	2020-05-10	9	[{"id_menu":6,"count":1}]	7603	pick-up	0	9
61184	2020-05-10 19:14:53	2020-05-10	9	[{"id_menu":6,"count":1}]	3885	delivery	5	14
61185	2020-05-10 19:19:43	2020-05-10	12	[{"id_menu":1,"count":1}]	16759	pick-up	0	12
61186	2020-05-10 19:20:58	2020-05-10	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	6235	pick-up	0	21
61187	2020-05-10 19:21:28	2020-05-10	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24136	delivery	5	31
61188	2020-05-10 19:25:09	2020-05-10	9	[{"id_menu":6,"count":1}]	24248	delivery	5	14
61189	2020-05-10 19:26:18	2020-05-10	14	[{"id_menu":2,"count":1}]	12248	pick-up	0	14
61190	2020-05-10 19:26:43	2020-05-10	17	[{"id_menu":4,"count":1}]	245	delivery	5	22
61191	2020-05-10 19:26:55	2020-05-10	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	24173	delivery	5	43
61192	2020-05-10 19:28:11	2020-05-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	482	delivery	5	23
61193	2020-05-10 19:28:56	2020-05-10	9	[{"id_menu":7,"count":1}]	3149	delivery	5	14
61194	2020-05-10 19:29:41	2020-05-10	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	13945	pick-up	0	33
61195	2020-05-10 19:31:49	2020-05-10	8	[{"id_menu":5,"count":1}]	9448	delivery	5	13
61196	2020-05-10 19:43:10	2020-05-10	17	[{"id_menu":4,"count":1}]	3389	pick-up	0	17
61197	2020-05-10 19:46:12	2020-05-10	17	[{"id_menu":4,"count":1}]	11639	delivery	5	22
61198	2020-05-10 19:46:24	2020-05-10	12	[{"id_menu":3,"count":1}]	2902	pick-up	0	12
61199	2020-05-10 19:48:37	2020-05-10	9	[{"id_menu":6,"count":1}]	2068	delivery	5	14
61200	2020-05-10 19:52:18	2020-05-10	17	[{"id_menu":4,"count":1}]	24192	delivery	5	22
61201	2020-05-10 19:59:12	2020-05-10	8	[{"id_menu":5,"count":1}]	12545	delivery	5	13
61202	2020-05-10 20:00:40	2020-05-10	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	12648	pick-up	0	31
61203	2020-05-10 20:02:01	2020-05-10	9	[{"id_menu":7,"count":1}]	2477	pick-up	0	9
61204	2020-05-10 20:02:48	2020-05-10	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	24127	delivery	5	40
61205	2020-05-10 20:03:30	2020-05-10	12	[{"id_menu":3,"count":1}]	5640	delivery	5	17
61206	2020-05-10 20:03:32	2020-05-10	9	[{"id_menu":7,"count":3}]	6117	delivery	5	14
61207	2020-05-10 20:03:41	2020-05-10	9	[{"id_menu":7,"count":1}]	12243	delivery	5	14
61208	2020-05-10 20:03:45	2020-05-10	12	[{"id_menu":1,"count":1}]	10153	pick-up	0	12
61209	2020-05-10 20:05:55	2020-05-10	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17569	delivery	5	43
61210	2020-05-10 20:07:21	2020-05-10	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	7371	delivery	5	26
61211	2020-05-10 20:11:39	2020-05-10	8	[{"id_menu":5,"count":1}]	20043	delivery	5	13
61212	2020-05-10 20:11:58	2020-05-10	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10273	pick-up	0	40
61213	2020-05-10 20:14:08	2020-05-10	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	24162	delivery	5	27
61214	2020-05-10 20:16:52	2020-05-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":3}]	3404	delivery	5	28
61215	2020-05-10 20:17:23	2020-05-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18854	delivery	5	22
61216	2020-05-10 20:18:29	2020-05-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10159	delivery	5	22
61217	2020-05-10 20:20:42	2020-05-10	9	[{"id_menu":7,"count":1}]	24250	delivery	5	14
61218	2020-05-10 20:21:53	2020-05-10	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4565	delivery	5	27
61219	2020-05-10 20:22:13	2020-05-10	9	[{"id_menu":7,"count":1}]	24112	delivery	5	14
61220	2020-05-10 20:26:23	2020-05-10	8	[{"id_menu":5,"count":1}]	4670	delivery	5	13
61221	2020-05-10 20:29:37	2020-05-10	8	[{"id_menu":5,"count":1}]	1956	pick-up	0	8
61222	2020-05-10 20:30:21	2020-05-10	17	[{"id_menu":4,"count":1}]	13643	delivery	5	22
61223	2020-05-10 20:33:48	2020-05-10	9	[{"id_menu":6,"count":1}]	4937	pick-up	0	9
61224	2020-05-10 20:37:29	2020-05-10	9	[{"id_menu":7,"count":1}]	24106	delivery	5	14
61225	2020-05-10 20:38:06	2020-05-10	17	[{"id_menu":4,"count":1}]	12365	delivery	5	22
61226	2020-05-10 20:41:12	2020-05-10	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	9282	delivery	5	26
61227	2020-05-10 20:42:25	2020-05-10	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	24118	delivery	5	28
61228	2020-05-10 20:44:32	2020-05-10	14	[{"id_menu":2,"count":1}]	17745	delivery	5	19
61229	2020-05-10 20:47:24	2020-05-10	8	[{"id_menu":5,"count":1}]	12760	delivery	5	13
61230	2020-05-10 20:51:20	2020-05-10	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3274	pick-up	0	26
61231	2020-05-10 20:56:53	2020-05-10	9	[{"id_menu":6,"count":1}]	18294	delivery	5	14
61232	2020-05-10 21:04:49	2020-05-10	9	[{"id_menu":6,"count":1}]	18076	delivery	5	14
61233	2020-05-10 21:05:16	2020-05-10	9	[{"id_menu":6,"count":1}]	1562	pick-up	0	9
61234	2020-05-10 21:07:44	2020-05-10	17	[{"id_menu":4,"count":1}]	1729	delivery	5	22
61235	2020-05-10 21:09:44	2020-05-10	14	[{"id_menu":2,"count":1}]	24276	delivery	5	19
61236	2020-05-10 21:11:40	2020-05-10	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24109	delivery	5	36
61237	2020-05-10 21:15:02	2020-05-10	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	17596	delivery	5	26
61238	2020-05-10 21:15:29	2020-05-10	17	[{"id_menu":4,"count":2}]	1208	pick-up	0	17
61239	2020-05-10 21:23:46	2020-05-10	12	[{"id_menu":3,"count":1}]	1474	delivery	5	17
61240	2020-05-10 21:24:14	2020-05-10	12	[{"id_menu":3,"count":1}]	15905	pick-up	0	12
61241	2020-05-10 21:24:24	2020-05-10	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	292	delivery	5	31
61242	2020-05-10 21:31:23	2020-05-10	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	17566	delivery	5	26
61243	2020-05-10 21:35:02	2020-05-10	12	[{"id_menu":1,"count":1}]	9193	delivery	5	17
61244	2020-05-10 21:38:24	2020-05-10	12	[{"id_menu":1,"count":1}]	14146	pick-up	0	12
61245	2020-05-10 21:38:32	2020-05-10	14	[{"id_menu":2,"count":1}]	24231	delivery	5	19
61246	2020-05-10 21:38:56	2020-05-10	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13960	delivery	5	36
61247	2020-05-10 21:39:39	2020-05-10	12	[{"id_menu":1,"count":2}]	24168	delivery	5	17
61248	2020-05-10 21:42:42	2020-05-10	9	[{"id_menu":6,"count":2}]	24111	delivery	5	14
61249	2020-05-10 21:45:06	2020-05-10	9	[{"id_menu":7,"count":1}]	4710	pick-up	0	9
61250	2020-05-10 21:45:29	2020-05-10	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24268	delivery	5	22
61251	2020-05-10 21:47:05	2020-05-10	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18949	delivery	5	34
61252	2020-05-10 21:47:38	2020-05-10	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2048	pick-up	0	29
61253	2020-05-10 21:48:34	2020-05-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	24119	delivery	5	28
61254	2020-05-10 21:50:44	2020-05-10	9	[{"id_menu":6,"count":1}]	1782	pick-up	0	9
61255	2020-05-10 21:54:21	2020-05-10	12	[{"id_menu":3,"count":1}]	20989	delivery	5	17
61256	2020-05-10 22:00:01	2020-05-10	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6890	delivery	5	45
61257	2020-05-10 22:00:38	2020-05-10	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	24200	pick-up	0	29
61258	2020-05-10 22:02:54	2020-05-10	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10987	delivery	5	36
61259	2020-05-10 22:05:26	2020-05-10	12	[{"id_menu":1,"count":1}]	1387	delivery	5	17
61260	2020-05-10 22:06:46	2020-05-10	12	[{"id_menu":1,"count":1}]	24207	pick-up	0	12
61261	2020-05-10 22:06:49	2020-05-10	8	[{"id_menu":5,"count":1}]	2552	pick-up	0	8
61262	2020-05-10 22:07:59	2020-05-10	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9893	delivery	5	46
61263	2020-05-10 22:08:56	2020-05-10	12	[{"id_menu":3,"count":1}]	24270	delivery	5	17
61264	2020-05-10 22:09:53	2020-05-10	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1896	pick-up	0	22
61265	2020-05-10 22:11:27	2020-05-10	9	[{"id_menu":7,"count":1}]	14559	pick-up	0	9
61266	2020-05-10 22:16:30	2020-05-10	9	[{"id_menu":7,"count":1}]	19711	pick-up	0	9
61267	2020-05-10 22:17:17	2020-05-10	17	[{"id_menu":4,"count":1}]	18672	delivery	5	22
61268	2020-05-10 22:17:36	2020-05-10	8	[{"id_menu":5,"count":1}]	24269	delivery	5	13
61269	2020-05-10 22:17:43	2020-05-10	8	[{"id_menu":5,"count":1}]	3380	delivery	5	13
61270	2020-05-10 22:18:21	2020-05-10	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	21371	delivery	5	34
61271	2020-05-10 22:22:25	2020-05-10	9	[{"id_menu":6,"count":1}]	18889	delivery	5	14
61272	2020-05-10 22:26:05	2020-05-10	9	[{"id_menu":6,"count":1}]	6499	delivery	5	14
61273	2020-05-10 22:33:58	2020-05-10	9	[{"id_menu":6,"count":1}]	9780	delivery	5	14
61274	2020-05-10 22:41:14	2020-05-10	14	[{"id_menu":2,"count":1}]	24211	delivery	5	19
61275	2020-05-10 22:44:05	2020-05-10	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	24225	delivery	5	42
61276	2020-05-10 22:44:21	2020-05-10	17	[{"id_menu":4,"count":1}]	16033	delivery	5	22
61277	2020-05-10 22:45:39	2020-05-10	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24107	delivery	5	31
61278	2020-05-10 22:47:06	2020-05-10	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	9402	pick-up	0	20
61279	2020-05-10 22:49:50	2020-05-10	9	[{"id_menu":6,"count":2}]	4712	delivery	5	14
61280	2020-05-10 22:50:52	2020-05-10	17	[{"id_menu":4,"count":1}]	5790	pick-up	0	17
61281	2020-05-10 22:51:32	2020-05-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	24125	delivery	5	28
61282	2020-05-10 22:53:57	2020-05-10	14	[{"id_menu":2,"count":2}]	20411	delivery	5	19
61283	2020-05-10 22:55:05	2020-05-10	12	[{"id_menu":3,"count":1}]	11717	delivery	5	17
61284	2020-05-10 22:55:18	2020-05-10	17	[{"id_menu":4,"count":1}]	3870	pick-up	0	17
61285	2020-05-10 22:56:05	2020-05-10	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	24141	delivery	5	31
61286	2020-05-10 22:57:06	2020-05-10	9	[{"id_menu":7,"count":1}]	16265	delivery	5	14
61287	2020-05-10 23:02:20	2020-05-10	14	[{"id_menu":2,"count":1}]	24079	delivery	5	19
61288	2020-05-10 23:04:49	2020-05-10	8	[{"id_menu":5,"count":1}]	24152	delivery	5	13
61289	2020-05-10 23:08:59	2020-05-10	9	[{"id_menu":7,"count":1}]	24261	delivery	5	14
61290	2020-05-10 23:09:10	2020-05-10	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1700	delivery	5	27
61291	2020-05-10 23:10:10	2020-05-10	8	[{"id_menu":5,"count":1}]	24236	delivery	5	13
61292	2020-05-10 23:12:44	2020-05-10	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	24153	pick-up	0	26
61293	2020-05-10 23:17:18	2020-05-10	9	[{"id_menu":7,"count":1}]	5928	delivery	5	14
61294	2020-05-10 23:26:41	2020-05-10	9	[{"id_menu":6,"count":1}]	21785	delivery	5	14
61295	2020-05-10 23:28:44	2020-05-10	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11490	delivery	5	40
61296	2020-05-10 23:29:03	2020-05-10	9	[{"id_menu":6,"count":1}]	24138	delivery	5	14
61297	2020-05-10 23:36:36	2020-05-10	17	[{"id_menu":4,"count":1}]	22534	delivery	5	22
61298	2020-05-10 23:38:37	2020-05-10	9	[{"id_menu":6,"count":1}]	16410	delivery	5	14
61299	2020-05-10 23:39:40	2020-05-10	9	[{"id_menu":7,"count":1}]	24179	delivery	5	14
61300	2020-05-10 23:39:49	2020-05-10	14	[{"id_menu":2,"count":1}]	14690	delivery	5	19
61301	2020-05-10 23:42:11	2020-05-10	12	[{"id_menu":3,"count":1}]	13267	delivery	5	17
61302	2020-05-10 23:48:04	2020-05-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7443	delivery	5	22
61303	2020-05-10 23:51:59	2020-05-10	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21492	delivery	5	37
61304	2020-05-10 23:53:31	2020-05-10	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	18666	delivery	5	34
61305	2020-05-10 23:54:10	2020-05-10	14	[{"id_menu":2,"count":1}]	17747	delivery	5	19
61306	2020-05-10 23:54:25	2020-05-10	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11347	delivery	5	31
61307	2020-05-10 23:58:54	2020-05-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	8588	delivery	5	23
61308	2020-05-11 00:00:20	2020-05-11	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	21026	delivery	5	38
61309	2020-05-11 00:00:25	2020-05-11	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	22767	delivery	5	44
61310	2020-05-11 00:00:30	2020-05-11	17	[{"id_menu":4,"count":1}]	8966	delivery	5	22
61311	2020-05-11 00:02:39	2020-05-11	8	[{"id_menu":5,"count":1}]	14027	pick-up	0	8
61312	2020-05-11 00:09:00	2020-05-11	17	[{"id_menu":4,"count":1}]	7691	pick-up	0	17
61313	2020-05-11 00:10:15	2020-05-11	9	[{"id_menu":6,"count":1}]	24395	delivery	5	14
61314	2020-05-11 00:14:43	2020-05-11	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17981	delivery	5	31
61315	2020-05-11 00:15:14	2020-05-11	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	1267	pick-up	0	18
61316	2020-05-11 00:21:34	2020-05-11	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	22302	delivery	5	43
61317	2020-05-11 00:30:19	2020-05-11	9	[{"id_menu":7,"count":1}]	3556	delivery	5	14
61318	2020-05-11 00:30:21	2020-05-11	9	[{"id_menu":7,"count":1}]	19480	delivery	5	14
61319	2020-05-11 00:32:42	2020-05-11	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12699	delivery	5	31
61320	2020-05-11 00:34:11	2020-05-11	12	[{"id_menu":1,"count":2}]	15578	delivery	5	17
61321	2020-05-11 00:50:54	2020-05-11	12	[{"id_menu":3,"count":1}]	5938	delivery	5	17
61322	2020-05-11 00:55:41	2020-05-11	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3073	pick-up	0	26
61323	2020-05-11 00:58:24	2020-05-11	14	[{"id_menu":2,"count":1}]	2885	delivery	5	19
61324	2020-05-11 01:01:22	2020-05-11	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	20329	delivery	5	43
61325	2020-05-11 01:01:38	2020-05-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	22988	delivery	5	22
61326	2020-05-11 01:05:36	2020-05-11	9	[{"id_menu":6,"count":1}]	3213	delivery	5	14
61327	2020-05-11 01:06:16	2020-05-11	14	[{"id_menu":2,"count":1}]	24024	delivery	5	19
61328	2020-05-11 01:10:29	2020-05-11	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	11331	delivery	5	23
61329	2020-05-11 01:15:35	2020-05-11	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	15590	delivery	5	26
61330	2020-05-11 01:19:08	2020-05-11	8	[{"id_menu":5,"count":1}]	17654	delivery	5	13
61331	2020-05-11 01:21:42	2020-05-11	9	[{"id_menu":7,"count":1}]	23819	delivery	5	14
61332	2020-05-11 01:32:21	2020-05-11	14	[{"id_menu":2,"count":1}]	9093	pick-up	0	14
61333	2020-05-11 01:33:29	2020-05-11	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	19838	delivery	5	25
61334	2020-05-11 01:41:58	2020-05-11	17	[{"id_menu":4,"count":1}]	22975	delivery	5	22
61335	2020-05-11 01:50:10	2020-05-11	9	[{"id_menu":6,"count":2}]	6668	delivery	5	14
61336	2020-05-11 01:52:03	2020-05-11	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	13527	delivery	5	34
61337	2020-05-11 01:53:31	2020-05-11	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	24333	delivery	5	48
61338	2020-05-11 02:03:00	2020-05-11	17	[{"id_menu":4,"count":1}]	20283	delivery	5	22
61339	2020-05-11 02:26:35	2020-05-11	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	8056	delivery	5	26
61340	2020-05-11 02:30:52	2020-05-11	8	[{"id_menu":5,"count":1}]	3901	delivery	5	13
61341	2020-05-11 02:43:06	2020-05-11	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	20493	pick-up	0	23
61342	2020-05-11 02:46:42	2020-05-11	14	[{"id_menu":2,"count":1}]	15209	delivery	5	19
61343	2020-05-11 02:51:55	2020-05-11	8	[{"id_menu":5,"count":2}]	4197	delivery	5	13
61344	2020-05-11 02:53:30	2020-05-11	9	[{"id_menu":6,"count":1}]	24342	delivery	5	14
61345	2020-05-11 02:59:15	2020-05-11	17	[{"id_menu":4,"count":1}]	1270	pick-up	0	17
61346	2020-05-11 03:01:21	2020-05-11	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13105	delivery	5	51
61347	2020-05-11 03:01:53	2020-05-11	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9702	delivery	5	45
61348	2020-05-11 03:03:26	2020-05-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	21499	delivery	5	23
61349	2020-05-11 03:08:15	2020-05-11	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	24366	delivery	5	34
61350	2020-05-11 03:10:49	2020-05-11	8	[{"id_menu":5,"count":1}]	13150	delivery	5	13
61351	2020-05-11 03:18:45	2020-05-11	14	[{"id_menu":2,"count":1}]	24328	delivery	5	19
61352	2020-05-11 03:22:11	2020-05-11	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	16091	delivery	5	31
61353	2020-05-11 03:29:10	2020-05-11	8	[{"id_menu":5,"count":1}]	20936	delivery	5	13
61354	2020-05-11 03:29:51	2020-05-11	14	[{"id_menu":2,"count":1}]	8166	delivery	5	19
61355	2020-05-11 03:33:37	2020-05-11	8	[{"id_menu":5,"count":1}]	1187	pick-up	0	8
61356	2020-05-11 03:39:05	2020-05-11	12	[{"id_menu":3,"count":1}]	24350	delivery	5	17
61357	2020-05-11 03:40:04	2020-05-11	14	[{"id_menu":2,"count":1}]	292	delivery	5	19
61358	2020-05-11 03:41:58	2020-05-11	9	[{"id_menu":6,"count":1}]	17353	pick-up	0	9
61359	2020-05-11 03:45:54	2020-05-11	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24349	delivery	5	36
61360	2020-05-11 04:00:04	2020-05-11	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	4412	delivery	5	31
61361	2020-05-11 04:15:20	2020-05-11	17	[{"id_menu":4,"count":1}]	11615	pick-up	0	17
61362	2020-05-11 04:19:32	2020-05-11	9	[{"id_menu":7,"count":1}]	13959	delivery	5	14
61363	2020-05-11 04:28:55	2020-05-11	9	[{"id_menu":6,"count":1}]	21845	pick-up	0	9
61364	2020-05-11 04:30:45	2020-05-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	24315	delivery	5	28
61365	2020-05-11 04:35:48	2020-05-11	14	[{"id_menu":2,"count":1}]	15557	delivery	5	19
61366	2020-05-11 04:39:36	2020-05-11	14	[{"id_menu":2,"count":1}]	19892	delivery	5	19
61367	2020-05-11 04:51:47	2020-05-11	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	16055	delivery	5	27
61368	2020-05-11 04:54:15	2020-05-11	14	[{"id_menu":2,"count":1}]	16707	pick-up	0	14
61369	2020-05-11 05:01:07	2020-05-11	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	22663	delivery	5	25
61370	2020-05-11 05:01:09	2020-05-11	17	[{"id_menu":4,"count":1}]	24288	delivery	5	22
61371	2020-05-11 05:07:01	2020-05-11	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20336	delivery	5	36
61372	2020-05-11 05:12:28	2020-05-11	8	[{"id_menu":5,"count":1}]	24348	delivery	5	13
61373	2020-05-11 05:13:47	2020-05-11	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	24321	pick-up	0	26
61374	2020-05-11 05:34:10	2020-05-11	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10576	delivery	5	31
61375	2020-05-11 05:37:52	2020-05-11	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11834	delivery	5	31
61376	2020-05-11 05:41:16	2020-05-11	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	24371	delivery	5	28
61377	2020-05-11 05:42:17	2020-05-11	12	[{"id_menu":1,"count":1}]	17351	pick-up	0	12
61378	2020-05-11 05:48:42	2020-05-11	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	24398	delivery	5	40
61379	2020-05-11 05:49:50	2020-05-11	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	14358	pick-up	0	39
61380	2020-05-11 05:58:36	2020-05-11	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	24339	delivery	5	43
61381	2020-05-11 05:59:06	2020-05-11	14	[{"id_menu":2,"count":1}]	24354	delivery	5	19
61382	2020-05-11 06:07:15	2020-05-11	8	[{"id_menu":5,"count":1}]	14054	pick-up	0	8
61383	2020-05-11 06:07:47	2020-05-11	17	[{"id_menu":4,"count":1}]	20573	delivery	5	22
61384	2020-05-11 06:09:59	2020-05-11	14	[{"id_menu":2,"count":1}]	21785	pick-up	0	14
61385	2020-05-11 06:17:09	2020-05-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24410	delivery	5	22
61386	2020-05-11 06:17:22	2020-05-11	12	[{"id_menu":1,"count":1}]	20549	pick-up	0	12
61387	2020-05-11 06:17:47	2020-05-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16754	delivery	5	22
61388	2020-05-11 06:20:21	2020-05-11	14	[{"id_menu":2,"count":1}]	24417	pick-up	0	14
61455	2020-05-11 12:43:29	2020-05-11	8	[{"id_menu":5,"count":1}]	15061	delivery	5	13
61389	2020-05-11 06:20:26	2020-05-11	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	23307	delivery	5	52
61390	2020-05-11 06:23:19	2020-05-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	24382	delivery	5	23
61391	2020-05-11 06:35:15	2020-05-11	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	7098	pick-up	0	24
61392	2020-05-11 06:35:31	2020-05-11	12	[{"id_menu":3,"count":1}]	12706	pick-up	0	12
61393	2020-05-11 06:40:53	2020-05-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	24414	delivery	5	23
61394	2020-05-11 06:44:10	2020-05-11	12	[{"id_menu":1,"count":1}]	382	pick-up	0	12
61395	2020-05-11 06:47:06	2020-05-11	17	[{"id_menu":4,"count":1}]	1390	pick-up	0	17
61396	2020-05-11 06:48:30	2020-05-11	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	18593	delivery	5	31
61397	2020-05-11 06:51:43	2020-05-11	12	[{"id_menu":3,"count":1}]	7229	delivery	5	17
61398	2020-05-11 06:51:48	2020-05-11	9	[{"id_menu":6,"count":1}]	13746	delivery	5	14
61399	2020-05-11 07:00:19	2020-05-11	17	[{"id_menu":4,"count":1}]	17182	delivery	5	22
61400	2020-05-11 07:02:40	2020-05-11	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	24386	delivery	5	36
61401	2020-05-11 07:11:57	2020-05-11	8	[{"id_menu":5,"count":1}]	7891	delivery	5	13
61402	2020-05-11 07:12:49	2020-05-11	9	[{"id_menu":7,"count":1}]	24345	pick-up	0	9
61403	2020-05-11 07:18:45	2020-05-11	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	19792	delivery	5	30
61404	2020-05-11 07:21:54	2020-05-11	8	[{"id_menu":5,"count":1}]	24336	delivery	5	13
61405	2020-05-11 07:28:33	2020-05-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1140	pick-up	0	17
61406	2020-05-11 07:30:22	2020-05-11	12	[{"id_menu":3,"count":1}]	11867	delivery	5	17
61407	2020-05-11 07:43:16	2020-05-11	9	[{"id_menu":7,"count":1}]	24312	delivery	5	14
61408	2020-05-11 07:46:56	2020-05-11	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	23961	delivery	5	34
61409	2020-05-11 07:47:47	2020-05-11	14	[{"id_menu":2,"count":1}]	9564	delivery	5	19
61410	2020-05-11 07:53:47	2020-05-11	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	21829	delivery	5	26
61411	2020-05-11 08:03:46	2020-05-11	9	[{"id_menu":7,"count":1}]	17964	delivery	5	14
61412	2020-05-11 08:19:00	2020-05-11	9	[{"id_menu":6,"count":1}]	19966	delivery	5	14
61413	2020-05-11 08:20:05	2020-05-11	12	[{"id_menu":1,"count":1}]	10543	delivery	5	17
61414	2020-05-11 08:32:39	2020-05-11	14	[{"id_menu":2,"count":1}]	24401	delivery	5	19
61415	2020-05-11 08:42:36	2020-05-11	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7897	pick-up	0	44
61416	2020-05-11 08:45:29	2020-05-11	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	24274	pick-up	0	26
61417	2020-05-11 08:45:36	2020-05-11	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2066	pick-up	0	21
61418	2020-05-11 08:46:07	2020-05-11	9	[{"id_menu":6,"count":1}]	24359	delivery	5	14
61419	2020-05-11 09:07:37	2020-05-11	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	18929	delivery	5	26
61420	2020-05-11 09:23:54	2020-05-11	9	[{"id_menu":6,"count":1}]	8050	delivery	5	14
61421	2020-05-11 09:33:55	2020-05-11	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24399	delivery	5	46
61422	2020-05-11 09:37:21	2020-05-11	9	[{"id_menu":7,"count":1}]	4818	delivery	5	14
61423	2020-05-11 09:40:05	2020-05-11	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	24365	delivery	5	34
61424	2020-05-11 09:41:42	2020-05-11	12	[{"id_menu":1,"count":1}]	8454	pick-up	0	12
61425	2020-05-11 09:41:44	2020-05-11	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	12337	delivery	5	26
61426	2020-05-11 09:43:21	2020-05-11	9	[{"id_menu":6,"count":1}]	19133	delivery	5	14
61427	2020-05-11 09:44:32	2020-05-11	9	[{"id_menu":7,"count":1}]	24372	pick-up	0	9
61428	2020-05-11 09:51:50	2020-05-11	9	[{"id_menu":7,"count":1}]	13615	delivery	5	14
61429	2020-05-11 09:52:27	2020-05-11	14	[{"id_menu":2,"count":1}]	807	delivery	5	19
61430	2020-05-11 09:54:06	2020-05-11	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	16525	delivery	5	25
61431	2020-05-11 10:04:30	2020-05-11	14	[{"id_menu":2,"count":1}]	6600	pick-up	0	14
61432	2020-05-11 10:09:59	2020-05-11	9	[{"id_menu":7,"count":1}]	12823	delivery	5	14
61433	2020-05-11 10:13:15	2020-05-11	9	[{"id_menu":7,"count":1}]	11465	pick-up	0	9
61434	2020-05-11 10:20:37	2020-05-11	9	[{"id_menu":7,"count":1}]	23404	delivery	5	14
61435	2020-05-11 10:42:38	2020-05-11	9	[{"id_menu":6,"count":1}]	24305	delivery	5	14
61436	2020-05-11 10:43:46	2020-05-11	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24308	delivery	5	34
61437	2020-05-11 10:44:10	2020-05-11	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7827	pick-up	0	40
61438	2020-05-11 10:49:49	2020-05-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	22679	delivery	5	23
61439	2020-05-11 10:52:07	2020-05-11	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":3}]	24285	delivery	5	28
61440	2020-05-11 10:53:33	2020-05-11	43	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	24391	delivery	5	48
61441	2020-05-11 10:54:49	2020-05-11	12	[{"id_menu":1,"count":1}]	80	pick-up	0	12
61442	2020-05-11 11:02:36	2020-05-11	9	[{"id_menu":6,"count":1}]	12701	delivery	5	14
61443	2020-05-11 11:03:53	2020-05-11	8	[{"id_menu":5,"count":1}]	24407	pick-up	0	8
61444	2020-05-11 11:05:53	2020-05-11	12	[{"id_menu":1,"count":1}]	24387	pick-up	0	12
61445	2020-05-11 11:07:58	2020-05-11	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	5124	delivery	5	26
61446	2020-05-11 11:15:51	2020-05-11	9	[{"id_menu":7,"count":1}]	17263	delivery	5	14
61447	2020-05-11 11:19:58	2020-05-11	12	[{"id_menu":1,"count":1}]	19493	delivery	5	17
61448	2020-05-11 11:21:05	2020-05-11	9	[{"id_menu":7,"count":1}]	2576	pick-up	0	9
61449	2020-05-11 11:21:06	2020-05-11	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4766	delivery	5	47
61450	2020-05-11 11:43:33	2020-05-11	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	24338	delivery	5	23
61451	2020-05-11 11:43:51	2020-05-11	12	[{"id_menu":3,"count":1}]	24413	delivery	5	17
61452	2020-05-11 11:44:37	2020-05-11	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	17116	delivery	5	40
61453	2020-05-11 12:10:39	2020-05-11	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22414	delivery	5	35
61454	2020-05-11 12:29:48	2020-05-11	17	[{"id_menu":4,"count":1}]	24374	delivery	5	22
61456	2020-05-11 12:48:52	2020-05-11	14	[{"id_menu":2,"count":1}]	24408	delivery	5	19
61457	2020-05-11 12:50:28	2020-05-11	14	[{"id_menu":2,"count":1}]	15535	delivery	5	19
61458	2020-05-11 12:52:47	2020-05-11	9	[{"id_menu":7,"count":1}]	19711	pick-up	0	9
61459	2020-05-11 13:08:01	2020-05-11	14	[{"id_menu":2,"count":1}]	1300	delivery	5	19
61460	2020-05-11 13:20:25	2020-05-11	12	[{"id_menu":1,"count":1}]	23754	delivery	5	17
61461	2020-05-11 13:21:46	2020-05-11	12	[{"id_menu":3,"count":1}]	5422	delivery	5	17
61462	2020-05-11 13:25:43	2020-05-11	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	18425	delivery	5	26
61463	2020-05-11 13:26:44	2020-05-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24310	pick-up	0	17
61464	2020-05-11 13:26:52	2020-05-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":3}]	24293	delivery	5	23
61465	2020-05-11 13:34:38	2020-05-11	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	24294	delivery	5	23
61466	2020-05-11 13:35:15	2020-05-11	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	17703	delivery	5	27
61467	2020-05-11 13:37:21	2020-05-11	17	[{"id_menu":4,"count":1}]	17442	delivery	5	22
61468	2020-05-11 13:38:55	2020-05-11	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22966	delivery	5	40
61469	2020-05-11 13:39:25	2020-05-11	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24075	delivery	5	40
61470	2020-05-11 13:42:41	2020-05-11	12	[{"id_menu":3,"count":1}]	20304	pick-up	0	12
61471	2020-05-11 13:44:26	2020-05-11	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24373	delivery	5	36
61472	2020-05-11 13:46:01	2020-05-11	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1988	pick-up	0	38
61473	2020-05-11 13:48:21	2020-05-11	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	4346	delivery	5	31
61474	2020-05-11 13:48:41	2020-05-11	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7924	delivery	5	42
61475	2020-05-11 13:50:20	2020-05-11	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	376	pick-up	0	21
61476	2020-05-11 14:00:41	2020-05-11	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	288	pick-up	0	29
61477	2020-05-11 14:00:42	2020-05-11	8	[{"id_menu":5,"count":1}]	4889	delivery	5	13
61478	2020-05-11 14:18:08	2020-05-11	12	[{"id_menu":3,"count":1}]	8109	pick-up	0	12
61479	2020-05-11 14:21:49	2020-05-11	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	13501	delivery	5	40
61480	2020-05-11 14:24:53	2020-05-11	14	[{"id_menu":2,"count":1}]	24424	delivery	5	19
61481	2020-05-11 14:25:15	2020-05-11	8	[{"id_menu":5,"count":1}]	24356	delivery	5	13
61482	2020-05-11 14:30:36	2020-05-11	9	[{"id_menu":6,"count":1}]	8548	delivery	5	14
61483	2020-05-11 14:31:11	2020-05-11	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	24357	delivery	5	52
61484	2020-05-11 14:36:48	2020-05-11	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14010	pick-up	0	26
61485	2020-05-11 14:38:20	2020-05-11	12	[{"id_menu":1,"count":1}]	143	pick-up	0	12
61486	2020-05-11 14:40:18	2020-05-11	12	[{"id_menu":1,"count":1}]	13855	pick-up	0	12
61487	2020-05-11 14:46:11	2020-05-11	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	24332	delivery	5	40
61488	2020-05-11 14:46:58	2020-05-11	9	[{"id_menu":7,"count":1}]	11488	delivery	5	14
61489	2020-05-11 14:55:40	2020-05-11	17	[{"id_menu":4,"count":1}]	23997	pick-up	0	17
61490	2020-05-11 14:58:46	2020-05-11	14	[{"id_menu":2,"count":2}]	2656	pick-up	0	14
61491	2020-05-11 15:03:09	2020-05-11	12	[{"id_menu":1,"count":1}]	14881	delivery	5	17
61492	2020-05-11 15:05:05	2020-05-11	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	24411	delivery	5	57
61493	2020-05-11 15:14:39	2020-05-11	9	[{"id_menu":7,"count":1}]	6499	delivery	5	14
61494	2020-05-11 15:15:06	2020-05-11	9	[{"id_menu":7,"count":2}]	24155	delivery	5	14
61495	2020-05-11 15:22:07	2020-05-11	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	9995	delivery	5	27
61496	2020-05-11 15:26:13	2020-05-11	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	24375	pick-up	0	25
61497	2020-05-11 15:29:40	2020-05-11	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	17227	delivery	5	31
61498	2020-05-11 15:31:17	2020-05-11	14	[{"id_menu":2,"count":1}]	24400	delivery	5	19
61499	2020-05-11 15:36:13	2020-05-11	14	[{"id_menu":2,"count":1}]	24158	delivery	5	19
61500	2020-05-11 15:38:16	2020-05-11	12	[{"id_menu":1,"count":1}]	6101	pick-up	0	12
61501	2020-05-11 15:41:06	2020-05-11	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4684	pick-up	0	25
61502	2020-05-11 15:44:08	2020-05-11	8	[{"id_menu":5,"count":2}]	10648	pick-up	0	8
61503	2020-05-11 15:56:14	2020-05-11	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	7677	delivery	5	26
61504	2020-05-11 15:59:57	2020-05-11	12	[{"id_menu":1,"count":1}]	2526	delivery	5	17
61505	2020-05-11 16:07:49	2020-05-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	8877	delivery	5	28
61506	2020-05-11 16:10:54	2020-05-11	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	5933	pick-up	0	24
61507	2020-05-11 16:11:32	2020-05-11	8	[{"id_menu":5,"count":1}]	4943	delivery	5	13
61508	2020-05-11 16:13:45	2020-05-11	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	24397	delivery	5	26
61509	2020-05-11 16:13:45	2020-05-11	9	[{"id_menu":7,"count":1}]	8839	pick-up	0	9
61510	2020-05-11 16:16:30	2020-05-11	9	[{"id_menu":6,"count":1}]	5491	pick-up	0	9
61511	2020-05-11 16:27:40	2020-05-11	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8180	pick-up	0	26
61512	2020-05-11 16:37:12	2020-05-11	9	[{"id_menu":6,"count":1}]	4248	pick-up	0	9
61513	2020-05-11 16:39:41	2020-05-11	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	19750	delivery	5	40
61514	2020-05-11 16:44:49	2020-05-11	14	[{"id_menu":2,"count":1}]	20969	delivery	5	19
61515	2020-05-11 16:46:51	2020-05-11	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	16470	delivery	5	30
61516	2020-05-11 16:53:28	2020-05-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	14207	delivery	5	23
61517	2020-05-11 17:00:38	2020-05-11	12	[{"id_menu":1,"count":1}]	24402	pick-up	0	12
61518	2020-05-11 17:03:33	2020-05-11	14	[{"id_menu":2,"count":1}]	7190	delivery	5	19
61519	2020-05-11 17:11:00	2020-05-11	12	[{"id_menu":3,"count":1}]	5238	delivery	5	17
61520	2020-05-11 17:15:42	2020-05-11	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	337	delivery	5	29
61521	2020-05-11 17:19:02	2020-05-11	9	[{"id_menu":6,"count":1}]	3021	pick-up	0	9
61522	2020-05-11 17:22:19	2020-05-11	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	4582	delivery	5	34
61523	2020-05-11 17:22:58	2020-05-11	12	[{"id_menu":3,"count":2}]	24302	pick-up	0	12
61524	2020-05-11 17:23:49	2020-05-11	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10518	delivery	5	44
61525	2020-05-11 17:24:39	2020-05-11	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	11183	pick-up	0	21
61526	2020-05-11 17:25:34	2020-05-11	12	[{"id_menu":3,"count":1}]	21210	delivery	5	17
61527	2020-05-11 17:28:34	2020-05-11	14	[{"id_menu":2,"count":1}]	17368	pick-up	0	14
61528	2020-05-11 17:29:13	2020-05-11	14	[{"id_menu":2,"count":2}]	24404	delivery	5	19
61529	2020-05-11 17:32:05	2020-05-11	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	21542	delivery	5	31
61530	2020-05-11 17:35:35	2020-05-11	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	232	pick-up	0	31
61531	2020-05-11 17:45:15	2020-05-11	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	24355	delivery	5	28
61532	2020-05-11 18:08:01	2020-05-11	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5004	delivery	5	30
61533	2020-05-11 18:10:14	2020-05-11	14	[{"id_menu":2,"count":1}]	8629	pick-up	0	14
61534	2020-05-11 18:12:43	2020-05-11	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	460	delivery	5	51
61535	2020-05-11 18:17:11	2020-05-11	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	24329	delivery	5	28
61536	2020-05-11 18:24:51	2020-05-11	12	[{"id_menu":3,"count":1}]	24307	delivery	5	17
61537	2020-05-11 18:30:12	2020-05-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5800	delivery	5	23
61538	2020-05-11 18:37:19	2020-05-11	9	[{"id_menu":7,"count":1}]	5354	pick-up	0	9
61539	2020-05-11 18:48:40	2020-05-11	9	[{"id_menu":6,"count":1}]	14955	delivery	5	14
61540	2020-05-11 18:50:28	2020-05-11	9	[{"id_menu":7,"count":1}]	24368	delivery	5	14
61541	2020-05-11 18:51:11	2020-05-11	12	[{"id_menu":1,"count":1}]	627	delivery	5	17
61542	2020-05-11 18:59:39	2020-05-11	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	18173	delivery	5	36
61543	2020-05-11 19:04:47	2020-05-11	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	13806	pick-up	0	26
61544	2020-05-11 19:10:37	2020-05-11	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	24396	pick-up	0	29
61545	2020-05-11 19:15:21	2020-05-11	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11979	delivery	5	45
61546	2020-05-11 19:22:16	2020-05-11	17	[{"id_menu":4,"count":1}]	17143	delivery	5	22
61547	2020-05-11 19:22:43	2020-05-11	9	[{"id_menu":7,"count":1}]	24296	delivery	5	14
61548	2020-05-11 19:22:59	2020-05-11	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	18304	delivery	5	29
61549	2020-05-11 19:25:10	2020-05-11	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6255	delivery	5	28
61550	2020-05-11 19:32:49	2020-05-11	9	[{"id_menu":7,"count":1}]	7253	delivery	5	14
61551	2020-05-11 19:33:48	2020-05-11	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	24255	delivery	5	23
61552	2020-05-11 19:35:21	2020-05-11	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24298	delivery	5	36
61553	2020-05-11 19:42:25	2020-05-11	14	[{"id_menu":2,"count":1}]	19299	delivery	5	19
61554	2020-05-11 19:46:55	2020-05-11	9	[{"id_menu":6,"count":2}]	4968	delivery	5	14
61555	2020-05-11 19:54:03	2020-05-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11952	delivery	5	22
61556	2020-05-11 19:59:06	2020-05-11	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	20315	delivery	5	40
61557	2020-05-11 20:04:55	2020-05-11	9	[{"id_menu":6,"count":1}]	24403	delivery	5	14
61558	2020-05-11 20:07:19	2020-05-11	9	[{"id_menu":6,"count":2}]	5841	delivery	5	14
61559	2020-05-11 20:07:22	2020-05-11	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18831	delivery	5	34
61560	2020-05-11 20:08:39	2020-05-11	25	[{"id_menu":4,"count":3},{"id_menu":5,"count":1}]	24286	delivery	5	30
61561	2020-05-11 20:14:06	2020-05-11	14	[{"id_menu":2,"count":1}]	24344	pick-up	0	14
61562	2020-05-11 20:23:39	2020-05-11	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8216	delivery	5	44
61563	2020-05-11 20:24:44	2020-05-11	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	24311	delivery	5	27
61564	2020-05-11 20:26:15	2020-05-11	12	[{"id_menu":3,"count":1}]	12797	pick-up	0	12
61565	2020-05-11 20:26:34	2020-05-11	14	[{"id_menu":2,"count":1}]	9827	delivery	5	19
61566	2020-05-11 20:28:51	2020-05-11	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	24314	delivery	5	40
61567	2020-05-11 20:29:45	2020-05-11	12	[{"id_menu":1,"count":1}]	1445	pick-up	0	12
61568	2020-05-11 20:31:43	2020-05-11	9	[{"id_menu":6,"count":1}]	8749	delivery	5	14
61569	2020-05-11 20:36:57	2020-05-11	9	[{"id_menu":7,"count":1}]	22464	pick-up	0	9
61570	2020-05-11 20:38:58	2020-05-11	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11666	delivery	5	37
61571	2020-05-11 20:40:07	2020-05-11	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13876	delivery	5	57
61572	2020-05-11 20:47:35	2020-05-11	12	[{"id_menu":1,"count":1}]	1687	pick-up	0	12
61573	2020-05-11 20:48:29	2020-05-11	9	[{"id_menu":7,"count":1}]	5192	delivery	5	14
61574	2020-05-11 20:49:24	2020-05-11	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	511	pick-up	0	21
61575	2020-05-11 20:54:45	2020-05-11	17	[{"id_menu":4,"count":1}]	7638	delivery	5	22
61576	2020-05-11 21:05:46	2020-05-11	17	[{"id_menu":4,"count":1}]	8474	pick-up	0	17
61577	2020-05-11 21:12:43	2020-05-11	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	24309	delivery	5	31
61578	2020-05-11 21:14:01	2020-05-11	12	[{"id_menu":1,"count":1}]	16968	delivery	5	17
61579	2020-05-11 21:17:54	2020-05-11	9	[{"id_menu":7,"count":1}]	24313	delivery	5	14
61580	2020-05-11 21:30:36	2020-05-11	14	[{"id_menu":2,"count":1}]	19602	pick-up	0	14
61581	2020-05-11 21:36:27	2020-05-11	9	[{"id_menu":7,"count":1}]	13016	delivery	5	14
61582	2020-05-11 21:38:37	2020-05-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	9633	delivery	5	22
61583	2020-05-11 21:46:42	2020-05-11	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	7675	delivery	5	46
61584	2020-05-11 21:52:58	2020-05-11	12	[{"id_menu":1,"count":1}]	24297	delivery	5	17
61585	2020-05-11 21:58:47	2020-05-11	12	[{"id_menu":3,"count":1}]	2052	delivery	5	17
61586	2020-05-11 22:11:06	2020-05-11	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	10671	delivery	5	22
61587	2020-05-11 22:14:08	2020-05-11	9	[{"id_menu":7,"count":1}]	18695	delivery	5	14
61588	2020-05-11 22:18:51	2020-05-11	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	24381	delivery	5	26
61589	2020-05-11 22:21:03	2020-05-11	17	[{"id_menu":4,"count":1}]	4123	pick-up	0	17
61590	2020-05-11 22:21:32	2020-05-11	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	24353	delivery	5	36
61591	2020-05-11 22:22:08	2020-05-11	12	[{"id_menu":1,"count":1}]	19459	delivery	5	17
61592	2020-05-11 22:24:44	2020-05-11	12	[{"id_menu":3,"count":1}]	24360	delivery	5	17
61593	2020-05-11 22:26:02	2020-05-11	8	[{"id_menu":5,"count":1}]	17061	pick-up	0	8
61594	2020-05-11 22:26:33	2020-05-11	8	[{"id_menu":5,"count":1}]	15991	pick-up	0	8
61595	2020-05-11 22:33:52	2020-05-11	8	[{"id_menu":5,"count":1}]	6478	delivery	5	13
61596	2020-05-11 22:35:01	2020-05-11	12	[{"id_menu":1,"count":1}]	6202	pick-up	0	12
61597	2020-05-11 22:42:25	2020-05-11	8	[{"id_menu":5,"count":1}]	1119	delivery	5	13
61598	2020-05-11 22:49:40	2020-05-11	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13904	delivery	5	45
61599	2020-05-11 22:52:36	2020-05-11	14	[{"id_menu":2,"count":1}]	17404	delivery	5	19
61600	2020-05-11 22:53:50	2020-05-11	34	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	24416	delivery	5	39
61601	2020-05-11 23:01:52	2020-05-11	8	[{"id_menu":5,"count":1}]	24351	delivery	5	13
61602	2020-05-11 23:03:53	2020-05-11	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	24306	pick-up	0	26
61603	2020-05-11 23:04:31	2020-05-11	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2662	pick-up	0	31
61604	2020-05-11 23:08:31	2020-05-11	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19686	delivery	5	37
61605	2020-05-11 23:10:30	2020-05-11	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24376	delivery	5	22
61606	2020-05-11 23:14:19	2020-05-11	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":2}]	24363	delivery	5	22
61607	2020-05-11 23:14:21	2020-05-11	8	[{"id_menu":5,"count":1}]	24383	delivery	5	13
61608	2020-05-11 23:22:08	2020-05-11	9	[{"id_menu":7,"count":1}]	6390	delivery	5	14
61609	2020-05-11 23:25:08	2020-05-11	46	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1118	pick-up	0	46
61610	2020-05-11 23:25:32	2020-05-11	17	[{"id_menu":4,"count":1}]	1344	pick-up	0	17
61611	2020-05-11 23:28:10	2020-05-11	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	24362	delivery	5	34
61612	2020-05-11 23:30:41	2020-05-11	9	[{"id_menu":6,"count":1}]	24369	delivery	5	14
61613	2020-05-11 23:33:05	2020-05-11	9	[{"id_menu":6,"count":1}]	24323	delivery	5	14
61614	2020-05-11 23:34:43	2020-05-11	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7907	delivery	5	31
61615	2020-05-11 23:34:46	2020-05-11	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	19416	delivery	5	23
61616	2020-05-11 23:34:53	2020-05-11	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13803	delivery	5	34
61617	2020-05-11 23:52:46	2020-05-11	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	24337	delivery	5	26
61618	2020-05-11 23:56:39	2020-05-11	14	[{"id_menu":2,"count":1}]	4644	pick-up	0	14
61619	2020-05-12 00:04:10	2020-05-12	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":2}]	15407	delivery	5	26
61620	2020-05-12 00:09:42	2020-05-12	9	[{"id_menu":7,"count":1}]	4846	pick-up	0	9
61621	2020-05-12 00:11:48	2020-05-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	24439	delivery	5	28
61622	2020-05-12 00:16:00	2020-05-12	9	[{"id_menu":6,"count":1}]	23588	pick-up	0	9
61623	2020-05-12 00:16:52	2020-05-12	12	[{"id_menu":3,"count":1}]	8491	delivery	5	17
61624	2020-05-12 00:21:01	2020-05-12	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3610	delivery	5	48
61625	2020-05-12 00:24:01	2020-05-12	17	[{"id_menu":4,"count":1}]	3820	pick-up	0	17
61626	2020-05-12 00:24:56	2020-05-12	12	[{"id_menu":1,"count":1}]	17372	delivery	5	17
61627	2020-05-12 00:30:00	2020-05-12	17	[{"id_menu":4,"count":1}]	2857	pick-up	0	17
61628	2020-05-12 00:33:23	2020-05-12	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	24449	delivery	5	45
61629	2020-05-12 00:33:56	2020-05-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18845	delivery	5	22
61630	2020-05-12 00:34:09	2020-05-12	9	[{"id_menu":7,"count":1}]	23549	delivery	5	14
61631	2020-05-12 00:39:08	2020-05-12	9	[{"id_menu":6,"count":1}]	24523	pick-up	0	9
61632	2020-05-12 00:47:35	2020-05-12	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	4632	delivery	5	31
61633	2020-05-12 00:47:58	2020-05-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	22080	delivery	5	28
61634	2020-05-12 00:52:52	2020-05-12	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	10433	delivery	5	26
61635	2020-05-12 00:55:50	2020-05-12	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	24578	delivery	5	28
61636	2020-05-12 01:00:18	2020-05-12	8	[{"id_menu":5,"count":1}]	17817	delivery	5	13
61637	2020-05-12 01:00:45	2020-05-12	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	24588	delivery	5	26
61638	2020-05-12 01:02:55	2020-05-12	9	[{"id_menu":7,"count":1}]	16228	delivery	5	14
61639	2020-05-12 01:13:01	2020-05-12	9	[{"id_menu":6,"count":1}]	18375	delivery	5	14
61640	2020-05-12 01:14:21	2020-05-12	9	[{"id_menu":7,"count":1}]	14392	delivery	5	14
61641	2020-05-12 01:26:18	2020-05-12	8	[{"id_menu":5,"count":1}]	24518	delivery	5	13
61642	2020-05-12 01:28:37	2020-05-12	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24484	delivery	5	34
61643	2020-05-12 01:41:30	2020-05-12	12	[{"id_menu":1,"count":1}]	7037	delivery	5	17
61644	2020-05-12 01:45:44	2020-05-12	12	[{"id_menu":3,"count":1}]	4303	delivery	5	17
61645	2020-05-12 01:46:00	2020-05-12	14	[{"id_menu":2,"count":1}]	22114	delivery	5	19
61646	2020-05-12 01:49:48	2020-05-12	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	24537	delivery	5	27
61647	2020-05-12 01:50:20	2020-05-12	8	[{"id_menu":5,"count":1}]	4395	pick-up	0	8
61648	2020-05-12 01:53:53	2020-05-12	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	22016	delivery	5	23
61649	2020-05-12 01:54:08	2020-05-12	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24553	delivery	5	40
61650	2020-05-12 01:59:57	2020-05-12	12	[{"id_menu":3,"count":1}]	2252	delivery	5	17
61651	2020-05-12 02:06:27	2020-05-12	8	[{"id_menu":5,"count":1}]	24576	delivery	5	13
61652	2020-05-12 02:12:53	2020-05-12	9	[{"id_menu":7,"count":1}]	12388	pick-up	0	9
61653	2020-05-12 02:13:05	2020-05-12	9	[{"id_menu":6,"count":1}]	4833	pick-up	0	9
61654	2020-05-12 02:15:09	2020-05-12	38	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10515	delivery	5	43
61655	2020-05-12 02:17:37	2020-05-12	9	[{"id_menu":7,"count":1}]	15922	delivery	5	14
61656	2020-05-12 02:22:20	2020-05-12	9	[{"id_menu":7,"count":1}]	24433	delivery	5	14
61657	2020-05-12 02:22:48	2020-05-12	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	24538	delivery	5	45
61658	2020-05-12 02:25:31	2020-05-12	9	[{"id_menu":7,"count":1}]	24429	delivery	5	14
61659	2020-05-12 02:34:55	2020-05-12	14	[{"id_menu":2,"count":1}]	24071	delivery	5	19
61660	2020-05-12 02:35:35	2020-05-12	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7444	delivery	5	35
61661	2020-05-12 02:38:00	2020-05-12	17	[{"id_menu":4,"count":1}]	13034	pick-up	0	17
61662	2020-05-12 02:42:17	2020-05-12	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24536	delivery	5	22
61663	2020-05-12 02:48:10	2020-05-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18997	delivery	5	23
61664	2020-05-12 03:00:46	2020-05-12	14	[{"id_menu":2,"count":1}]	24527	delivery	5	19
61665	2020-05-12 03:00:54	2020-05-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8823	delivery	5	31
61666	2020-05-12 03:01:04	2020-05-12	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16114	delivery	5	31
61667	2020-05-12 03:04:54	2020-05-12	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	24521	delivery	5	25
61668	2020-05-12 03:11:08	2020-05-12	14	[{"id_menu":2,"count":1}]	2392	pick-up	0	14
61669	2020-05-12 03:13:40	2020-05-12	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18778	delivery	5	37
61670	2020-05-12 03:15:05	2020-05-12	12	[{"id_menu":3,"count":1}]	9811	pick-up	0	12
61671	2020-05-12 03:16:45	2020-05-12	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	24471	pick-up	0	21
61672	2020-05-12 03:20:38	2020-05-12	12	[{"id_menu":1,"count":1}]	24543	delivery	5	17
61673	2020-05-12 03:21:12	2020-05-12	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	5071	delivery	5	36
61674	2020-05-12 03:23:59	2020-05-12	9	[{"id_menu":6,"count":1}]	24459	delivery	5	14
61675	2020-05-12 03:34:44	2020-05-12	9	[{"id_menu":6,"count":1}]	18047	pick-up	0	9
61676	2020-05-12 03:35:01	2020-05-12	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	23855	delivery	5	31
61677	2020-05-12 03:36:42	2020-05-12	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	23699	delivery	5	26
61678	2020-05-12 03:40:37	2020-05-12	9	[{"id_menu":6,"count":1}]	10384	delivery	5	14
61679	2020-05-12 03:48:29	2020-05-12	12	[{"id_menu":3,"count":1}]	5048	pick-up	0	12
61680	2020-05-12 03:49:16	2020-05-12	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	24468	delivery	5	22
61681	2020-05-12 04:11:11	2020-05-12	9	[{"id_menu":7,"count":1}]	24493	delivery	5	14
61682	2020-05-12 04:16:21	2020-05-12	17	[{"id_menu":4,"count":1}]	24438	delivery	5	22
61683	2020-05-12 04:21:39	2020-05-12	12	[{"id_menu":1,"count":1}]	17501	pick-up	0	12
61684	2020-05-12 04:29:17	2020-05-12	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	24488	delivery	5	45
61685	2020-05-12 04:31:15	2020-05-12	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8434	delivery	5	48
61686	2020-05-12 04:32:20	2020-05-12	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	11368	pick-up	0	17
61687	2020-05-12 04:36:48	2020-05-12	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	19279	delivery	5	40
61688	2020-05-12 04:36:51	2020-05-12	17	[{"id_menu":4,"count":2}]	6328	pick-up	0	17
61689	2020-05-12 04:38:42	2020-05-12	8	[{"id_menu":5,"count":1}]	24462	delivery	5	13
61690	2020-05-12 04:39:03	2020-05-12	14	[{"id_menu":2,"count":1}]	24461	delivery	5	19
61691	2020-05-12 04:39:09	2020-05-12	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	24559	delivery	5	26
61692	2020-05-12 04:39:52	2020-05-12	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	24513	pick-up	0	26
61693	2020-05-12 04:42:44	2020-05-12	12	[{"id_menu":1,"count":1}]	1106	pick-up	0	12
61694	2020-05-12 04:43:32	2020-05-12	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	24510	delivery	5	45
61695	2020-05-12 04:45:28	2020-05-12	9	[{"id_menu":6,"count":2}]	14630	delivery	5	14
61696	2020-05-12 04:46:14	2020-05-12	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	24486	delivery	5	43
61697	2020-05-12 04:55:10	2020-05-12	9	[{"id_menu":6,"count":1}]	15453	delivery	5	14
61698	2020-05-12 05:07:00	2020-05-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19259	delivery	5	23
61699	2020-05-12 05:10:27	2020-05-12	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	19393	delivery	5	40
61700	2020-05-12 05:27:16	2020-05-12	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	24482	delivery	5	27
61701	2020-05-12 05:31:27	2020-05-12	9	[{"id_menu":6,"count":1}]	24534	pick-up	0	9
61702	2020-05-12 05:31:32	2020-05-12	14	[{"id_menu":2,"count":1}]	295	pick-up	0	14
61703	2020-05-12 05:33:29	2020-05-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7341	delivery	5	23
61704	2020-05-12 05:33:31	2020-05-12	9	[{"id_menu":6,"count":1}]	17134	delivery	5	14
61705	2020-05-12 05:38:18	2020-05-12	12	[{"id_menu":1,"count":1}]	18147	delivery	5	17
61706	2020-05-12 05:39:29	2020-05-12	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	24431	delivery	5	36
61707	2020-05-12 05:41:37	2020-05-12	9	[{"id_menu":6,"count":1}]	24509	delivery	5	14
61708	2020-05-12 05:42:36	2020-05-12	8	[{"id_menu":5,"count":1}]	7953	delivery	5	13
61709	2020-05-12 05:48:41	2020-05-12	12	[{"id_menu":3,"count":1}]	3636	pick-up	0	12
61710	2020-05-12 05:53:02	2020-05-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5783	pick-up	0	18
61711	2020-05-12 05:54:14	2020-05-12	9	[{"id_menu":6,"count":1}]	24089	delivery	5	14
61712	2020-05-12 05:56:41	2020-05-12	9	[{"id_menu":6,"count":1}]	22319	delivery	5	14
61713	2020-05-12 06:00:59	2020-05-12	8	[{"id_menu":5,"count":1}]	24455	delivery	5	13
61714	2020-05-12 06:03:11	2020-05-12	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	13651	delivery	5	27
61715	2020-05-12 06:03:54	2020-05-12	9	[{"id_menu":6,"count":1}]	8149	delivery	5	14
61716	2020-05-12 06:07:38	2020-05-12	9	[{"id_menu":7,"count":2}]	24498	delivery	5	14
61717	2020-05-12 06:11:38	2020-05-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2731	delivery	5	31
61718	2020-05-12 06:12:28	2020-05-12	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7140	delivery	5	45
61719	2020-05-12 06:15:11	2020-05-12	14	[{"id_menu":2,"count":1}]	20787	delivery	5	19
61720	2020-05-12 06:16:28	2020-05-12	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24583	delivery	5	31
61721	2020-05-12 06:17:42	2020-05-12	17	[{"id_menu":4,"count":1}]	24526	delivery	5	22
61722	2020-05-12 06:25:44	2020-05-12	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	24528	delivery	5	36
61723	2020-05-12 06:26:16	2020-05-12	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24592	delivery	5	43
61724	2020-05-12 06:27:43	2020-05-12	12	[{"id_menu":3,"count":1}]	24456	pick-up	0	12
61725	2020-05-12 06:28:11	2020-05-12	14	[{"id_menu":2,"count":1}]	24514	pick-up	0	14
61726	2020-05-12 06:33:31	2020-05-12	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	12418	delivery	5	22
61727	2020-05-12 06:33:37	2020-05-12	8	[{"id_menu":5,"count":1}]	13478	delivery	5	13
61728	2020-05-12 06:39:12	2020-05-12	14	[{"id_menu":2,"count":1}]	18548	pick-up	0	14
61729	2020-05-12 06:42:04	2020-05-12	17	[{"id_menu":4,"count":1}]	8071	pick-up	0	17
61730	2020-05-12 06:50:27	2020-05-12	17	[{"id_menu":4,"count":1}]	24326	pick-up	0	17
61731	2020-05-12 06:55:38	2020-05-12	17	[{"id_menu":4,"count":1}]	24579	delivery	5	22
61732	2020-05-12 06:56:33	2020-05-12	9	[{"id_menu":7,"count":4}]	16755	delivery	5	14
61733	2020-05-12 06:59:09	2020-05-12	14	[{"id_menu":2,"count":1}]	2474	delivery	5	19
61734	2020-05-12 06:59:28	2020-05-12	17	[{"id_menu":4,"count":1}]	1442	pick-up	0	17
61735	2020-05-12 07:03:44	2020-05-12	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	21214	delivery	5	40
61736	2020-05-12 07:04:13	2020-05-12	9	[{"id_menu":6,"count":1}]	382	pick-up	0	9
61737	2020-05-12 07:15:56	2020-05-12	17	[{"id_menu":4,"count":1}]	24445	delivery	5	22
61738	2020-05-12 07:17:26	2020-05-12	21	[{"id_menu":1,"count":3},{"id_menu":6,"count":1}]	14780	delivery	5	26
61739	2020-05-12 07:26:17	2020-05-12	12	[{"id_menu":3,"count":1}]	84	delivery	5	17
61740	2020-05-12 07:29:21	2020-05-12	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	5668	delivery	5	28
61741	2020-05-12 07:36:40	2020-05-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14539	delivery	5	23
61742	2020-05-12 07:45:17	2020-05-12	12	[{"id_menu":1,"count":1}]	15320	delivery	5	17
61743	2020-05-12 07:47:14	2020-05-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3545	delivery	5	22
61744	2020-05-12 07:47:18	2020-05-12	12	[{"id_menu":3,"count":1}]	24564	delivery	5	17
61745	2020-05-12 07:54:44	2020-05-12	8	[{"id_menu":5,"count":1}]	20780	pick-up	0	8
61746	2020-05-12 07:57:41	2020-05-12	12	[{"id_menu":1,"count":1}]	3921	pick-up	0	12
61747	2020-05-12 08:04:05	2020-05-12	12	[{"id_menu":3,"count":1}]	5811	pick-up	0	12
61748	2020-05-12 08:10:58	2020-05-12	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10051	delivery	5	45
61749	2020-05-12 08:16:13	2020-05-12	9	[{"id_menu":7,"count":1}]	19277	delivery	5	14
61750	2020-05-12 08:17:44	2020-05-12	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24507	delivery	5	52
61751	2020-05-12 08:38:06	2020-05-12	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	6351	pick-up	0	24
61752	2020-05-12 08:41:51	2020-05-12	8	[{"id_menu":5,"count":1}]	18560	delivery	5	13
61753	2020-05-12 08:43:08	2020-05-12	17	[{"id_menu":4,"count":1}]	3643	pick-up	0	17
61754	2020-05-12 08:51:30	2020-05-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10203	pick-up	0	26
61755	2020-05-12 08:51:31	2020-05-12	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	24535	delivery	5	34
61756	2020-05-12 08:54:54	2020-05-12	9	[{"id_menu":7,"count":1}]	7122	delivery	5	14
61757	2020-05-12 08:58:46	2020-05-12	12	[{"id_menu":1,"count":1}]	16994	delivery	5	17
61758	2020-05-12 09:00:45	2020-05-12	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1131	delivery	5	25
61759	2020-05-12 09:01:22	2020-05-12	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2272	pick-up	0	26
61760	2020-05-12 09:04:08	2020-05-12	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17363	delivery	5	53
61761	2020-05-12 09:15:49	2020-05-12	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	24590	delivery	5	43
61762	2020-05-12 09:18:10	2020-05-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6959	delivery	5	28
61763	2020-05-12 09:30:49	2020-05-12	9	[{"id_menu":7,"count":1}]	23551	delivery	5	14
61764	2020-05-12 09:33:48	2020-05-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	10575	delivery	5	23
61765	2020-05-12 09:37:32	2020-05-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":3}]	24573	delivery	5	31
61766	2020-05-12 09:39:56	2020-05-12	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	24541	delivery	5	36
61767	2020-05-12 09:41:37	2020-05-12	17	[{"id_menu":4,"count":1}]	8950	delivery	5	22
61768	2020-05-12 10:01:44	2020-05-12	14	[{"id_menu":2,"count":1}]	841	pick-up	0	14
61769	2020-05-12 10:14:41	2020-05-12	12	[{"id_menu":1,"count":1}]	22524	delivery	5	17
61770	2020-05-12 10:17:01	2020-05-12	8	[{"id_menu":5,"count":1}]	17443	delivery	5	13
61771	2020-05-12 10:17:13	2020-05-12	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	8770	delivery	5	22
61772	2020-05-12 10:17:17	2020-05-12	9	[{"id_menu":7,"count":1}]	13929	delivery	5	14
61773	2020-05-12 10:26:16	2020-05-12	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16295	pick-up	0	38
61774	2020-05-12 10:29:33	2020-05-12	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	11764	delivery	5	43
61775	2020-05-12 10:30:38	2020-05-12	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	16549	delivery	5	36
61776	2020-05-12 10:31:11	2020-05-12	12	[{"id_menu":3,"count":1}]	13267	delivery	5	17
61777	2020-05-12 10:47:06	2020-05-12	8	[{"id_menu":5,"count":1}]	356	delivery	5	13
61778	2020-05-12 10:47:55	2020-05-12	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	11794	delivery	5	42
61779	2020-05-12 10:49:35	2020-05-12	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	24575	delivery	5	26
61780	2020-05-12 10:52:15	2020-05-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24560	delivery	5	23
61781	2020-05-12 10:54:10	2020-05-12	12	[{"id_menu":3,"count":1}]	24557	delivery	5	17
61782	2020-05-12 11:03:16	2020-05-12	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15127	delivery	5	36
61783	2020-05-12 11:04:47	2020-05-12	12	[{"id_menu":1,"count":1}]	21694	pick-up	0	12
61784	2020-05-12 11:08:17	2020-05-12	9	[{"id_menu":6,"count":1}]	22645	delivery	5	14
61785	2020-05-12 11:11:26	2020-05-12	17	[{"id_menu":4,"count":1}]	24425	delivery	5	22
61786	2020-05-12 11:21:42	2020-05-12	17	[{"id_menu":4,"count":1}]	24440	delivery	5	22
61787	2020-05-12 11:23:03	2020-05-12	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	18539	delivery	5	27
61788	2020-05-12 11:25:33	2020-05-12	9	[{"id_menu":6,"count":1}]	24500	pick-up	0	9
61789	2020-05-12 11:37:45	2020-05-12	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	24504	delivery	5	38
61790	2020-05-12 11:43:21	2020-05-12	8	[{"id_menu":5,"count":1}]	6369	delivery	5	13
61791	2020-05-12 11:46:39	2020-05-12	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12934	delivery	5	36
61792	2020-05-12 11:47:19	2020-05-12	9	[{"id_menu":6,"count":1}]	24591	delivery	5	14
61793	2020-05-12 11:57:21	2020-05-12	9	[{"id_menu":6,"count":2}]	23419	delivery	5	14
61794	2020-05-12 11:57:25	2020-05-12	17	[{"id_menu":4,"count":1}]	24511	delivery	5	22
61795	2020-05-12 11:57:31	2020-05-12	14	[{"id_menu":2,"count":1}]	24506	delivery	5	19
61796	2020-05-12 11:58:57	2020-05-12	8	[{"id_menu":5,"count":1}]	23432	pick-up	0	8
61797	2020-05-12 12:01:47	2020-05-12	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	18222	pick-up	0	24
61798	2020-05-12 12:06:53	2020-05-12	14	[{"id_menu":2,"count":1}]	17807	pick-up	0	14
61799	2020-05-12 12:18:40	2020-05-12	8	[{"id_menu":5,"count":1}]	15026	pick-up	0	8
61800	2020-05-12 12:20:58	2020-05-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6286	delivery	5	22
61801	2020-05-12 12:24:33	2020-05-12	9	[{"id_menu":6,"count":1}]	24430	delivery	5	14
61802	2020-05-12 12:27:20	2020-05-12	8	[{"id_menu":5,"count":1}]	7705	pick-up	0	8
61803	2020-05-12 12:34:42	2020-05-12	8	[{"id_menu":5,"count":1}]	24562	delivery	5	13
61804	2020-05-12 12:35:50	2020-05-12	17	[{"id_menu":4,"count":1}]	24487	delivery	5	22
61805	2020-05-12 13:07:49	2020-05-12	9	[{"id_menu":7,"count":1}]	16737	pick-up	0	9
61806	2020-05-12 13:09:25	2020-05-12	12	[{"id_menu":3,"count":1}]	7678	pick-up	0	12
61807	2020-05-12 13:12:13	2020-05-12	9	[{"id_menu":7,"count":2}]	16038	delivery	5	14
61808	2020-05-12 13:14:15	2020-05-12	8	[{"id_menu":5,"count":2}]	24593	delivery	5	13
61809	2020-05-12 13:24:20	2020-05-12	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32	pick-up	0	29
61810	2020-05-12 13:28:31	2020-05-12	14	[{"id_menu":2,"count":1}]	11453	delivery	5	19
61811	2020-05-12 13:38:07	2020-05-12	12	[{"id_menu":3,"count":1}]	6827	delivery	5	17
61812	2020-05-12 13:49:41	2020-05-12	17	[{"id_menu":4,"count":1}]	2867	delivery	5	22
61813	2020-05-12 13:49:48	2020-05-12	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	24565	delivery	5	31
61814	2020-05-12 13:54:19	2020-05-12	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10463	delivery	5	30
61815	2020-05-12 13:59:34	2020-05-12	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	20711	delivery	5	23
61816	2020-05-12 13:59:43	2020-05-12	14	[{"id_menu":2,"count":1}]	11732	delivery	5	19
61817	2020-05-12 14:05:41	2020-05-12	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	22942	delivery	5	27
61818	2020-05-12 14:14:45	2020-05-12	12	[{"id_menu":3,"count":1}]	2524	pick-up	0	12
61819	2020-05-12 14:17:05	2020-05-12	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	17769	delivery	5	26
61820	2020-05-12 14:17:37	2020-05-12	9	[{"id_menu":6,"count":1}]	24501	delivery	5	14
61821	2020-05-12 14:47:59	2020-05-12	12	[{"id_menu":1,"count":1}]	10717	pick-up	0	12
61822	2020-05-12 14:53:30	2020-05-12	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7955	delivery	5	49
61823	2020-05-12 14:57:52	2020-05-12	17	[{"id_menu":4,"count":1}]	2885	delivery	5	22
61824	2020-05-12 14:59:32	2020-05-12	12	[{"id_menu":1,"count":1}]	24561	pick-up	0	12
61825	2020-05-12 15:14:44	2020-05-12	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	24474	pick-up	0	31
61826	2020-05-12 15:31:43	2020-05-12	9	[{"id_menu":6,"count":1}]	8966	pick-up	0	9
61827	2020-05-12 15:32:16	2020-05-12	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	24494	delivery	5	22
61828	2020-05-12 15:36:13	2020-05-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	24563	delivery	5	28
61829	2020-05-12 15:38:55	2020-05-12	9	[{"id_menu":7,"count":1}]	16313	delivery	5	14
61830	2020-05-12 15:44:02	2020-05-12	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	24442	delivery	5	28
61831	2020-05-12 15:45:06	2020-05-12	9	[{"id_menu":6,"count":1}]	15028	pick-up	0	9
61832	2020-05-12 15:47:51	2020-05-12	9	[{"id_menu":7,"count":2}]	14726	delivery	5	14
61833	2020-05-12 15:49:02	2020-05-12	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	18958	pick-up	0	26
61834	2020-05-12 15:50:50	2020-05-12	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24505	delivery	5	22
61835	2020-05-12 15:54:00	2020-05-12	8	[{"id_menu":5,"count":1}]	722	pick-up	0	8
61836	2020-05-12 15:58:33	2020-05-12	14	[{"id_menu":2,"count":1}]	5133	delivery	5	19
61837	2020-05-12 15:59:07	2020-05-12	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	24441	pick-up	0	29
61838	2020-05-12 15:59:57	2020-05-12	9	[{"id_menu":6,"count":1}]	24284	pick-up	0	9
61839	2020-05-12 16:00:30	2020-05-12	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	15498	delivery	5	37
61840	2020-05-12 16:04:04	2020-05-12	9	[{"id_menu":6,"count":1}]	24516	delivery	5	14
61841	2020-05-12 16:09:47	2020-05-12	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6046	pick-up	0	25
61842	2020-05-12 16:11:08	2020-05-12	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	14190	pick-up	0	25
61843	2020-05-12 16:19:26	2020-05-12	17	[{"id_menu":4,"count":1}]	7250	delivery	5	22
61844	2020-05-12 16:24:57	2020-05-12	9	[{"id_menu":7,"count":1}]	24556	delivery	5	14
61845	2020-05-12 16:29:28	2020-05-12	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6927	delivery	5	34
61846	2020-05-12 16:30:19	2020-05-12	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	5979	delivery	5	27
61847	2020-05-12 16:33:13	2020-05-12	12	[{"id_menu":1,"count":1}]	24531	delivery	5	17
61848	2020-05-12 16:33:51	2020-05-12	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	5098	delivery	5	40
61849	2020-05-12 16:35:24	2020-05-12	9	[{"id_menu":7,"count":1}]	2055	pick-up	0	9
61850	2020-05-12 16:37:30	2020-05-12	9	[{"id_menu":7,"count":1}]	1546	delivery	5	14
61851	2020-05-12 16:39:59	2020-05-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3447	pick-up	0	26
61852	2020-05-12 16:44:19	2020-05-12	14	[{"id_menu":2,"count":1}]	5558	delivery	5	19
61853	2020-05-12 16:47:43	2020-05-12	9	[{"id_menu":6,"count":1}]	1892	delivery	5	14
61854	2020-05-12 16:48:01	2020-05-12	14	[{"id_menu":2,"count":1}]	13473	pick-up	0	14
61855	2020-05-12 16:53:38	2020-05-12	8	[{"id_menu":5,"count":1}]	17460	pick-up	0	8
61856	2020-05-12 17:00:06	2020-05-12	9	[{"id_menu":7,"count":1}]	18202	pick-up	0	9
61857	2020-05-12 17:01:02	2020-05-12	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	9796	pick-up	0	20
61858	2020-05-12 17:15:30	2020-05-12	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	24480	delivery	5	31
61859	2020-05-12 17:21:06	2020-05-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7396	delivery	5	28
61860	2020-05-12 17:22:59	2020-05-12	8	[{"id_menu":5,"count":1}]	24574	delivery	5	13
61861	2020-05-12 17:29:54	2020-05-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8990	delivery	5	22
61862	2020-05-12 17:31:33	2020-05-12	9	[{"id_menu":7,"count":1}]	4057	delivery	5	14
61863	2020-05-12 17:37:56	2020-05-12	12	[{"id_menu":3,"count":2}]	24458	pick-up	0	12
61864	2020-05-12 17:39:17	2020-05-12	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1914	delivery	5	28
61865	2020-05-12 17:40:54	2020-05-12	9	[{"id_menu":6,"count":1}]	18839	pick-up	0	9
61866	2020-05-12 17:42:05	2020-05-12	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	24454	delivery	5	31
61867	2020-05-12 17:45:32	2020-05-12	9	[{"id_menu":6,"count":1}]	24569	delivery	5	14
61868	2020-05-12 17:46:42	2020-05-12	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	24503	delivery	5	43
61869	2020-05-12 17:50:08	2020-05-12	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	10392	delivery	5	45
61870	2020-05-12 17:53:29	2020-05-12	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	1361	pick-up	0	25
61871	2020-05-12 17:58:49	2020-05-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5201	pick-up	0	17
61872	2020-05-12 18:05:44	2020-05-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	24544	delivery	5	31
61873	2020-05-12 18:12:46	2020-05-12	9	[{"id_menu":7,"count":1}]	24478	delivery	5	14
61874	2020-05-12 18:19:31	2020-05-12	14	[{"id_menu":2,"count":1}]	15798	pick-up	0	14
61875	2020-05-12 18:19:55	2020-05-12	14	[{"id_menu":2,"count":2}]	24529	delivery	5	19
61876	2020-05-12 18:27:30	2020-05-12	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	22077	delivery	5	31
61877	2020-05-12 18:31:05	2020-05-12	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	24463	delivery	5	28
61878	2020-05-12 18:33:16	2020-05-12	9	[{"id_menu":6,"count":1}]	24479	delivery	5	14
61879	2020-05-12 18:36:17	2020-05-12	9	[{"id_menu":7,"count":1}]	20493	pick-up	0	9
61880	2020-05-12 18:40:24	2020-05-12	9	[{"id_menu":6,"count":1}]	24426	delivery	5	14
61881	2020-05-12 18:40:32	2020-05-12	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14127	pick-up	0	31
61882	2020-05-12 18:45:00	2020-05-12	12	[{"id_menu":1,"count":1}]	4834	pick-up	0	12
61883	2020-05-12 18:46:15	2020-05-12	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	24450	delivery	5	29
61884	2020-05-12 18:54:23	2020-05-12	17	[{"id_menu":4,"count":1}]	24428	delivery	5	22
61885	2020-05-12 19:00:59	2020-05-12	9	[{"id_menu":7,"count":1}]	24532	delivery	5	14
61886	2020-05-12 19:02:10	2020-05-12	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24572	delivery	5	45
61887	2020-05-12 19:02:26	2020-05-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24485	delivery	5	22
61888	2020-05-12 19:04:47	2020-05-12	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	11026	pick-up	0	34
61889	2020-05-12 19:14:10	2020-05-12	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	22308	delivery	5	31
61890	2020-05-12 19:14:29	2020-05-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24473	delivery	5	23
61891	2020-05-12 19:20:00	2020-05-12	14	[{"id_menu":2,"count":1}]	3445	delivery	5	19
61892	2020-05-12 19:23:35	2020-05-12	12	[{"id_menu":1,"count":1}]	13303	delivery	5	17
61893	2020-05-12 19:30:46	2020-05-12	12	[{"id_menu":3,"count":1}]	5875	pick-up	0	12
61894	2020-05-12 19:42:44	2020-05-12	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10763	delivery	5	44
61895	2020-05-12 19:46:17	2020-05-12	12	[{"id_menu":1,"count":1}]	5975	delivery	5	17
61896	2020-05-12 19:48:45	2020-05-12	17	[{"id_menu":4,"count":1}]	15686	pick-up	0	17
61897	2020-05-12 19:55:38	2020-05-12	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3048	pick-up	0	35
61898	2020-05-12 19:56:45	2020-05-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	19488	delivery	5	23
61899	2020-05-12 19:57:55	2020-05-12	9	[{"id_menu":6,"count":1}]	3922	delivery	5	14
61900	2020-05-12 19:59:40	2020-05-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8540	delivery	5	23
61901	2020-05-12 20:00:12	2020-05-12	14	[{"id_menu":2,"count":1}]	5966	pick-up	0	14
61902	2020-05-12 20:02:38	2020-05-12	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	8748	pick-up	0	21
61903	2020-05-12 20:04:58	2020-05-12	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":3}]	15044	delivery	5	31
61904	2020-05-12 20:05:22	2020-05-12	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	24489	delivery	5	25
61905	2020-05-12 20:14:11	2020-05-12	14	[{"id_menu":2,"count":1}]	7053	pick-up	0	14
61906	2020-05-12 20:15:52	2020-05-12	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	12022	delivery	5	31
61907	2020-05-12 20:16:51	2020-05-12	14	[{"id_menu":2,"count":1}]	24451	delivery	5	19
61908	2020-05-12 20:18:13	2020-05-12	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3430	pick-up	0	23
61909	2020-05-12 20:18:15	2020-05-12	14	[{"id_menu":2,"count":1}]	7688	pick-up	0	14
61910	2020-05-12 20:19:46	2020-05-12	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	932	delivery	5	34
61911	2020-05-12 20:24:11	2020-05-12	14	[{"id_menu":2,"count":1}]	11946	pick-up	0	14
61912	2020-05-12 20:27:19	2020-05-12	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	13324	pick-up	0	31
61913	2020-05-12 20:28:35	2020-05-12	14	[{"id_menu":2,"count":1}]	18459	delivery	5	19
61914	2020-05-12 20:33:12	2020-05-12	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2123	pick-up	0	35
61915	2020-05-12 20:34:19	2020-05-12	9	[{"id_menu":6,"count":1}]	24495	delivery	5	14
61916	2020-05-12 20:35:38	2020-05-12	9	[{"id_menu":6,"count":1}]	11641	delivery	5	14
61917	2020-05-12 20:49:32	2020-05-12	12	[{"id_menu":1,"count":1}]	24596	delivery	5	17
61918	2020-05-12 20:58:42	2020-05-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	24469	delivery	5	28
61919	2020-05-12 20:59:40	2020-05-12	9	[{"id_menu":6,"count":1}]	22574	delivery	5	14
61920	2020-05-12 21:00:19	2020-05-12	14	[{"id_menu":2,"count":1}]	312	pick-up	0	14
61921	2020-05-12 21:00:36	2020-05-12	9	[{"id_menu":6,"count":1}]	14357	delivery	5	14
61922	2020-05-12 21:00:42	2020-05-12	14	[{"id_menu":2,"count":1}]	8826	pick-up	0	14
61923	2020-05-12 21:06:36	2020-05-12	9	[{"id_menu":6,"count":1}]	23349	delivery	5	14
61924	2020-05-12 21:09:30	2020-05-12	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	14010	pick-up	0	26
61925	2020-05-12 21:16:08	2020-05-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14932	delivery	5	31
61926	2020-05-12 21:16:19	2020-05-12	9	[{"id_menu":6,"count":1}]	609	pick-up	0	9
61927	2020-05-12 21:17:22	2020-05-12	8	[{"id_menu":5,"count":1}]	2068	pick-up	0	8
61928	2020-05-12 21:21:01	2020-05-12	14	[{"id_menu":2,"count":1}]	22422	delivery	5	19
61929	2020-05-12 21:26:04	2020-05-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1485	pick-up	0	23
61930	2020-05-12 21:26:07	2020-05-12	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1255	delivery	5	26
61931	2020-05-12 21:30:59	2020-05-12	12	[{"id_menu":3,"count":1}]	11499	pick-up	0	12
61932	2020-05-12 21:41:03	2020-05-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22656	delivery	5	23
61933	2020-05-12 21:42:41	2020-05-12	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":2}]	12019	delivery	5	26
61934	2020-05-12 21:47:51	2020-05-12	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	24547	pick-up	0	34
61935	2020-05-12 21:52:42	2020-05-12	9	[{"id_menu":7,"count":1}]	4903	delivery	5	14
61936	2020-05-12 21:52:49	2020-05-12	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24585	delivery	5	37
61937	2020-05-12 21:54:52	2020-05-12	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	22398	delivery	5	34
61938	2020-05-12 21:55:42	2020-05-12	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	24554	delivery	5	26
61939	2020-05-12 22:00:54	2020-05-12	17	[{"id_menu":4,"count":1}]	23797	pick-up	0	17
61940	2020-05-12 22:01:44	2020-05-12	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	24005	delivery	5	34
61941	2020-05-12 22:10:47	2020-05-12	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3920	delivery	5	43
61942	2020-05-12 22:11:04	2020-05-12	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24584	delivery	5	22
61943	2020-05-12 22:12:55	2020-05-12	17	[{"id_menu":4,"count":1}]	17490	delivery	5	22
61944	2020-05-12 22:13:26	2020-05-12	9	[{"id_menu":7,"count":1}]	13879	delivery	5	14
61945	2020-05-12 22:17:29	2020-05-12	9	[{"id_menu":6,"count":1}]	23735	delivery	5	14
61946	2020-05-12 22:20:20	2020-05-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	950	pick-up	0	26
61947	2020-05-12 22:21:09	2020-05-12	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12557	delivery	5	37
61948	2020-05-12 22:24:25	2020-05-12	14	[{"id_menu":2,"count":1}]	24520	delivery	5	19
61949	2020-05-12 22:32:42	2020-05-12	9	[{"id_menu":7,"count":1}]	8651	delivery	5	14
61950	2020-05-12 22:37:17	2020-05-12	17	[{"id_menu":4,"count":1}]	24550	pick-up	0	17
61951	2020-05-12 22:37:30	2020-05-12	12	[{"id_menu":3,"count":1}]	2488	pick-up	0	12
61952	2020-05-12 22:41:59	2020-05-12	14	[{"id_menu":2,"count":2}]	18840	delivery	5	19
61953	2020-05-12 22:43:23	2020-05-12	9	[{"id_menu":7,"count":1}]	24552	delivery	5	14
61954	2020-05-12 22:43:39	2020-05-12	14	[{"id_menu":2,"count":1}]	7863	delivery	5	19
61955	2020-05-12 22:46:44	2020-05-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	24436	delivery	5	28
61956	2020-05-12 22:49:57	2020-05-12	9	[{"id_menu":7,"count":1}]	18757	delivery	5	14
61957	2020-05-12 22:53:15	2020-05-12	9	[{"id_menu":6,"count":1}]	24368	delivery	5	14
61958	2020-05-12 22:53:58	2020-05-12	12	[{"id_menu":3,"count":1}]	13098	delivery	5	17
61959	2020-05-12 22:56:32	2020-05-12	8	[{"id_menu":5,"count":1}]	15863	delivery	5	13
61960	2020-05-12 22:56:49	2020-05-12	12	[{"id_menu":1,"count":1}]	24457	delivery	5	17
61961	2020-05-12 22:57:15	2020-05-12	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8591	delivery	5	31
61962	2020-05-12 23:03:27	2020-05-12	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	20054	delivery	5	31
61963	2020-05-12 23:04:37	2020-05-12	14	[{"id_menu":2,"count":1}]	24519	delivery	5	19
61964	2020-05-12 23:04:48	2020-05-12	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	24551	delivery	5	31
61965	2020-05-12 23:16:09	2020-05-12	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13265	delivery	5	35
61966	2020-05-12 23:16:32	2020-05-12	8	[{"id_menu":5,"count":1}]	6916	pick-up	0	8
61967	2020-05-12 23:17:59	2020-05-12	14	[{"id_menu":2,"count":1}]	802	pick-up	0	14
61968	2020-05-12 23:21:17	2020-05-12	17	[{"id_menu":4,"count":1}]	9106	pick-up	0	17
61969	2020-05-12 23:29:42	2020-05-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	24508	delivery	5	22
61970	2020-05-12 23:29:57	2020-05-12	12	[{"id_menu":1,"count":1}]	24452	delivery	5	17
61971	2020-05-12 23:33:03	2020-05-12	17	[{"id_menu":4,"count":1}]	24491	pick-up	0	17
61972	2020-05-12 23:34:07	2020-05-12	8	[{"id_menu":5,"count":1}]	24448	delivery	5	13
61973	2020-05-12 23:44:21	2020-05-12	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	2107	pick-up	0	29
61974	2020-05-12 23:48:21	2020-05-12	17	[{"id_menu":4,"count":1}]	24464	pick-up	0	17
61975	2020-05-12 23:49:16	2020-05-12	12	[{"id_menu":3,"count":1}]	19729	pick-up	0	12
61976	2020-05-12 23:59:01	2020-05-12	9	[{"id_menu":7,"count":1}]	18321	delivery	5	14
61977	2020-05-13 00:00:49	2020-05-13	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4100	delivery	5	52
61978	2020-05-13 00:01:02	2020-05-13	12	[{"id_menu":3,"count":1}]	24387	delivery	5	17
61979	2020-05-13 00:02:21	2020-05-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	17014	delivery	5	23
61980	2020-05-13 00:02:21	2020-05-13	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	14793	delivery	5	35
61981	2020-05-13 00:03:11	2020-05-13	9	[{"id_menu":6,"count":1}]	265	delivery	5	14
61982	2020-05-13 00:05:23	2020-05-13	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	11683	delivery	5	27
61983	2020-05-13 00:05:43	2020-05-13	9	[{"id_menu":6,"count":1}]	24686	delivery	5	14
61984	2020-05-13 00:06:35	2020-05-13	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24618	delivery	5	54
61985	2020-05-13 00:07:26	2020-05-13	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	20138	delivery	5	34
61986	2020-05-13 00:10:38	2020-05-13	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23500	delivery	5	22
61987	2020-05-13 00:14:03	2020-05-13	14	[{"id_menu":2,"count":1}]	24692	pick-up	0	14
61988	2020-05-13 00:19:09	2020-05-13	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	12160	delivery	5	31
61989	2020-05-13 00:32:56	2020-05-13	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	24672	delivery	5	23
61990	2020-05-13 00:33:34	2020-05-13	17	[{"id_menu":4,"count":1}]	20558	delivery	5	22
61991	2020-05-13 00:40:34	2020-05-13	9	[{"id_menu":6,"count":1}]	5180	delivery	5	14
61992	2020-05-13 00:51:57	2020-05-13	9	[{"id_menu":6,"count":1}]	10904	delivery	5	14
61993	2020-05-13 00:53:52	2020-05-13	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18641	delivery	5	37
61994	2020-05-13 00:57:49	2020-05-13	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	24650	pick-up	0	41
61995	2020-05-13 00:58:51	2020-05-13	9	[{"id_menu":7,"count":1}]	19750	delivery	5	14
61996	2020-05-13 01:01:34	2020-05-13	14	[{"id_menu":2,"count":2}]	22338	pick-up	0	14
61997	2020-05-13 01:04:50	2020-05-13	9	[{"id_menu":6,"count":1}]	6855	pick-up	0	9
61998	2020-05-13 01:08:01	2020-05-13	14	[{"id_menu":2,"count":1}]	17046	delivery	5	19
61999	2020-05-13 01:18:43	2020-05-13	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24678	delivery	5	22
62000	2020-05-13 01:18:46	2020-05-13	17	[{"id_menu":4,"count":1}]	24666	delivery	5	22
62001	2020-05-13 01:18:50	2020-05-13	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	396	delivery	5	27
62002	2020-05-13 01:19:33	2020-05-13	12	[{"id_menu":1,"count":1}]	20517	pick-up	0	12
62003	2020-05-13 01:26:02	2020-05-13	9	[{"id_menu":7,"count":1}]	12725	delivery	5	14
62004	2020-05-13 01:34:25	2020-05-13	9	[{"id_menu":6,"count":1}]	22583	delivery	5	14
62005	2020-05-13 01:37:07	2020-05-13	9	[{"id_menu":7,"count":1}]	20607	delivery	5	14
62006	2020-05-13 01:39:28	2020-05-13	8	[{"id_menu":5,"count":1}]	24641	delivery	5	13
62007	2020-05-13 01:51:01	2020-05-13	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	7465	pick-up	0	23
62008	2020-05-13 02:04:57	2020-05-13	12	[{"id_menu":3,"count":1}]	24704	pick-up	0	12
62009	2020-05-13 02:07:29	2020-05-13	14	[{"id_menu":2,"count":1}]	24640	delivery	5	19
62010	2020-05-13 02:18:08	2020-05-13	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	24668	pick-up	0	20
62011	2020-05-13 02:21:17	2020-05-13	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	21532	delivery	5	31
62012	2020-05-13 02:22:23	2020-05-13	12	[{"id_menu":1,"count":1}]	24642	pick-up	0	12
62013	2020-05-13 02:27:11	2020-05-13	9	[{"id_menu":7,"count":1}]	24684	pick-up	0	9
62014	2020-05-13 02:27:54	2020-05-13	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	24710	delivery	5	34
62015	2020-05-13 02:30:55	2020-05-13	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	24689	delivery	5	44
62016	2020-05-13 02:34:34	2020-05-13	17	[{"id_menu":4,"count":2}]	24654	delivery	5	22
62017	2020-05-13 02:35:38	2020-05-13	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20494	delivery	5	39
62018	2020-05-13 02:45:46	2020-05-13	9	[{"id_menu":6,"count":1}]	3948	delivery	5	14
62019	2020-05-13 02:46:08	2020-05-13	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1258	pick-up	0	29
62020	2020-05-13 02:51:14	2020-05-13	14	[{"id_menu":2,"count":1}]	4843	pick-up	0	14
62021	2020-05-13 02:56:47	2020-05-13	14	[{"id_menu":2,"count":2}]	1337	pick-up	0	14
62022	2020-05-13 02:57:30	2020-05-13	9	[{"id_menu":7,"count":1}]	15265	pick-up	0	9
62023	2020-05-13 03:01:46	2020-05-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4576	delivery	5	23
62024	2020-05-13 03:02:44	2020-05-13	9	[{"id_menu":7,"count":1}]	12602	delivery	5	14
62025	2020-05-13 03:09:43	2020-05-13	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12335	delivery	5	22
62026	2020-05-13 03:10:01	2020-05-13	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9949	delivery	5	31
62027	2020-05-13 03:10:14	2020-05-13	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4782	pick-up	0	26
62028	2020-05-13 03:11:07	2020-05-13	9	[{"id_menu":6,"count":1}]	20965	delivery	5	14
62029	2020-05-13 03:11:42	2020-05-13	8	[{"id_menu":5,"count":1}]	16552	delivery	5	13
62030	2020-05-13 03:13:31	2020-05-13	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	24717	delivery	5	22
62031	2020-05-13 03:21:16	2020-05-13	8	[{"id_menu":5,"count":1}]	6232	pick-up	0	8
62032	2020-05-13 03:22:54	2020-05-13	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	24632	delivery	5	31
62033	2020-05-13 03:23:22	2020-05-13	9	[{"id_menu":7,"count":2}]	24620	delivery	5	14
62034	2020-05-13 03:33:13	2020-05-13	8	[{"id_menu":5,"count":1}]	24610	pick-up	0	8
62035	2020-05-13 03:35:44	2020-05-13	12	[{"id_menu":1,"count":1}]	24609	pick-up	0	12
62036	2020-05-13 03:46:28	2020-05-13	8	[{"id_menu":5,"count":1}]	3611	delivery	5	13
62037	2020-05-13 03:48:07	2020-05-13	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	6533	pick-up	0	24
62038	2020-05-13 03:52:41	2020-05-13	9	[{"id_menu":6,"count":1}]	5509	delivery	5	14
62039	2020-05-13 03:57:50	2020-05-13	12	[{"id_menu":3,"count":1}]	10711	delivery	5	17
62040	2020-05-13 04:00:10	2020-05-13	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16089	delivery	5	31
62041	2020-05-13 04:00:16	2020-05-13	9	[{"id_menu":6,"count":1}]	10705	delivery	5	14
62042	2020-05-13 04:01:01	2020-05-13	17	[{"id_menu":4,"count":1}]	12685	delivery	5	22
62043	2020-05-13 04:02:01	2020-05-13	12	[{"id_menu":3,"count":1}]	15720	pick-up	0	12
62044	2020-05-13 04:03:01	2020-05-13	9	[{"id_menu":7,"count":1}]	24700	delivery	5	14
62045	2020-05-13 04:04:03	2020-05-13	12	[{"id_menu":1,"count":1}]	9562	delivery	5	17
62046	2020-05-13 04:07:15	2020-05-13	9	[{"id_menu":6,"count":2}]	21639	delivery	5	14
62047	2020-05-13 04:09:20	2020-05-13	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	24670	delivery	5	46
62048	2020-05-13 04:09:33	2020-05-13	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11634	delivery	5	43
62049	2020-05-13 04:13:22	2020-05-13	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	24707	delivery	5	26
62050	2020-05-13 04:14:39	2020-05-13	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":3}]	22994	delivery	5	25
62051	2020-05-13 04:14:52	2020-05-13	14	[{"id_menu":2,"count":1}]	6511	pick-up	0	14
62052	2020-05-13 04:15:57	2020-05-13	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18335	delivery	5	51
62053	2020-05-13 04:16:08	2020-05-13	12	[{"id_menu":1,"count":1}]	14813	delivery	5	17
62054	2020-05-13 04:19:59	2020-05-13	17	[{"id_menu":4,"count":2}]	10156	delivery	5	22
62055	2020-05-13 04:23:17	2020-05-13	12	[{"id_menu":3,"count":1}]	7510	pick-up	0	12
62056	2020-05-13 04:23:53	2020-05-13	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	22523	delivery	5	25
62057	2020-05-13 04:28:11	2020-05-13	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	10954	delivery	5	38
62058	2020-05-13 04:32:53	2020-05-13	17	[{"id_menu":4,"count":1}]	5987	delivery	5	22
62059	2020-05-13 04:33:31	2020-05-13	9	[{"id_menu":7,"count":2}]	11919	delivery	5	14
62060	2020-05-13 04:41:47	2020-05-13	12	[{"id_menu":3,"count":1}]	19931	pick-up	0	12
62061	2020-05-13 04:42:54	2020-05-13	9	[{"id_menu":7,"count":1}]	21493	delivery	5	14
62062	2020-05-13 04:45:13	2020-05-13	17	[{"id_menu":4,"count":1}]	11116	pick-up	0	17
62063	2020-05-13 04:53:03	2020-05-13	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	17750	delivery	5	39
62064	2020-05-13 04:54:43	2020-05-13	14	[{"id_menu":2,"count":1}]	21045	delivery	5	19
62065	2020-05-13 04:55:50	2020-05-13	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	24715	delivery	5	45
62066	2020-05-13 04:57:11	2020-05-13	14	[{"id_menu":2,"count":1}]	24621	delivery	5	19
62067	2020-05-13 04:57:44	2020-05-13	9	[{"id_menu":7,"count":1}]	24652	delivery	5	14
62068	2020-05-13 04:58:04	2020-05-13	9	[{"id_menu":7,"count":1}]	24709	delivery	5	14
62069	2020-05-13 04:59:35	2020-05-13	9	[{"id_menu":6,"count":1}]	19834	delivery	5	14
62070	2020-05-13 05:04:06	2020-05-13	9	[{"id_menu":6,"count":1}]	20857	delivery	5	14
62071	2020-05-13 05:05:47	2020-05-13	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3227	pick-up	0	26
62072	2020-05-13 05:06:50	2020-05-13	9	[{"id_menu":6,"count":2}]	3858	pick-up	0	9
62073	2020-05-13 05:08:49	2020-05-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7433	delivery	5	28
62074	2020-05-13 05:09:56	2020-05-13	8	[{"id_menu":5,"count":1}]	24688	delivery	5	13
62075	2020-05-13 05:10:26	2020-05-13	17	[{"id_menu":4,"count":2}]	16888	delivery	5	22
62076	2020-05-13 05:13:47	2020-05-13	8	[{"id_menu":5,"count":1}]	14756	pick-up	0	8
62077	2020-05-13 05:14:41	2020-05-13	9	[{"id_menu":7,"count":1}]	24706	delivery	5	14
62078	2020-05-13 05:19:10	2020-05-13	14	[{"id_menu":2,"count":1}]	15059	delivery	5	19
62079	2020-05-13 05:25:02	2020-05-13	9	[{"id_menu":6,"count":1}]	6101	delivery	5	14
62080	2020-05-13 05:26:51	2020-05-13	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	4486	pick-up	0	29
62081	2020-05-13 05:29:52	2020-05-13	12	[{"id_menu":3,"count":1}]	24721	delivery	5	17
62082	2020-05-13 05:31:42	2020-05-13	14	[{"id_menu":2,"count":1}]	1896	pick-up	0	14
62083	2020-05-13 05:33:18	2020-05-13	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24675	delivery	5	36
62084	2020-05-13 05:36:23	2020-05-13	12	[{"id_menu":1,"count":1}]	867	delivery	5	17
62085	2020-05-13 05:41:56	2020-05-13	17	[{"id_menu":4,"count":1}]	5991	delivery	5	22
62086	2020-05-13 05:42:18	2020-05-13	8	[{"id_menu":5,"count":1}]	10666	delivery	5	13
62087	2020-05-13 05:43:33	2020-05-13	8	[{"id_menu":5,"count":1}]	1150	delivery	5	13
62088	2020-05-13 05:47:35	2020-05-13	12	[{"id_menu":3,"count":1}]	24696	delivery	5	17
62089	2020-05-13 05:54:08	2020-05-13	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1024	delivery	5	25
62090	2020-05-13 05:59:50	2020-05-13	17	[{"id_menu":4,"count":1}]	11495	delivery	5	22
62091	2020-05-13 06:00:59	2020-05-13	9	[{"id_menu":7,"count":1}]	24612	delivery	5	14
62092	2020-05-13 06:05:13	2020-05-13	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	11147	delivery	5	22
62093	2020-05-13 06:07:59	2020-05-13	9	[{"id_menu":7,"count":1}]	24604	delivery	5	14
62094	2020-05-13 06:18:24	2020-05-13	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16514	delivery	5	34
62095	2020-05-13 06:21:52	2020-05-13	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	6150	delivery	5	26
62096	2020-05-13 06:26:09	2020-05-13	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18286	delivery	5	39
62097	2020-05-13 06:30:17	2020-05-13	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1759	pick-up	0	43
62098	2020-05-13 06:32:53	2020-05-13	8	[{"id_menu":5,"count":1}]	627	pick-up	0	8
62099	2020-05-13 06:37:29	2020-05-13	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	21495	delivery	5	34
62100	2020-05-13 06:49:00	2020-05-13	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	15849	delivery	5	25
62101	2020-05-13 06:50:04	2020-05-13	8	[{"id_menu":5,"count":1}]	13639	delivery	5	13
62102	2020-05-13 06:50:38	2020-05-13	17	[{"id_menu":4,"count":1}]	1306	pick-up	0	17
62103	2020-05-13 06:52:52	2020-05-13	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	8424	delivery	5	26
62104	2020-05-13 06:56:08	2020-05-13	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	2850	delivery	5	30
62105	2020-05-13 06:56:13	2020-05-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	11279	delivery	5	36
62106	2020-05-13 06:59:14	2020-05-13	9	[{"id_menu":6,"count":1}]	7522	delivery	5	14
62107	2020-05-13 07:03:41	2020-05-13	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6791	delivery	5	36
62108	2020-05-13 07:03:44	2020-05-13	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	14035	delivery	5	34
62109	2020-05-13 07:06:20	2020-05-13	14	[{"id_menu":2,"count":1}]	3503	pick-up	0	14
62110	2020-05-13 07:08:54	2020-05-13	17	[{"id_menu":4,"count":1}]	11356	pick-up	0	17
62111	2020-05-13 07:11:55	2020-05-13	9	[{"id_menu":6,"count":1}]	24683	delivery	5	14
62112	2020-05-13 07:15:09	2020-05-13	12	[{"id_menu":1,"count":1}]	7746	delivery	5	17
62113	2020-05-13 07:16:54	2020-05-13	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24649	delivery	5	35
62114	2020-05-13 07:22:11	2020-05-13	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	24680	delivery	5	31
62115	2020-05-13 07:26:16	2020-05-13	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	8372	delivery	5	26
62116	2020-05-13 07:33:26	2020-05-13	9	[{"id_menu":6,"count":1}]	5600	delivery	5	14
62117	2020-05-13 07:35:48	2020-05-13	9	[{"id_menu":6,"count":1}]	24603	delivery	5	14
62118	2020-05-13 07:44:24	2020-05-13	9	[{"id_menu":7,"count":1}]	11097	delivery	5	14
62119	2020-05-13 07:48:49	2020-05-13	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	12578	pick-up	0	21
62120	2020-05-13 07:57:03	2020-05-13	9	[{"id_menu":7,"count":1}]	19812	delivery	5	14
62121	2020-05-13 07:58:52	2020-05-13	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":2}]	24485	pick-up	0	26
62122	2020-05-13 08:00:12	2020-05-13	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17434	delivery	5	54
62123	2020-05-13 08:00:41	2020-05-13	14	[{"id_menu":2,"count":1}]	23860	delivery	5	19
62124	2020-05-13 08:02:55	2020-05-13	17	[{"id_menu":4,"count":1}]	21625	pick-up	0	17
62125	2020-05-13 08:06:37	2020-05-13	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	22975	delivery	5	31
62126	2020-05-13 08:11:04	2020-05-13	8	[{"id_menu":5,"count":1}]	24697	pick-up	0	8
62127	2020-05-13 08:21:20	2020-05-13	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12290	delivery	5	22
62128	2020-05-13 08:23:23	2020-05-13	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24636	delivery	5	22
62129	2020-05-13 08:28:53	2020-05-13	14	[{"id_menu":2,"count":1}]	3072	pick-up	0	14
62130	2020-05-13 08:31:43	2020-05-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	14068	delivery	5	36
62131	2020-05-13 08:34:33	2020-05-13	9	[{"id_menu":7,"count":1}]	18180	pick-up	0	9
62132	2020-05-13 08:40:59	2020-05-13	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	4804	delivery	5	31
62133	2020-05-13 08:49:51	2020-05-13	9	[{"id_menu":7,"count":1}]	15160	delivery	5	14
62134	2020-05-13 08:57:31	2020-05-13	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10353	delivery	5	48
62135	2020-05-13 08:57:49	2020-05-13	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7638	delivery	5	31
62136	2020-05-13 08:59:22	2020-05-13	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	24607	delivery	5	28
62137	2020-05-13 09:09:31	2020-05-13	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":2}]	1280	pick-up	0	31
62138	2020-05-13 09:09:40	2020-05-13	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	16613	pick-up	0	29
62139	2020-05-13 09:12:34	2020-05-13	9	[{"id_menu":7,"count":1}]	15769	pick-up	0	9
62140	2020-05-13 09:14:10	2020-05-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	24665	delivery	5	36
62141	2020-05-13 09:14:56	2020-05-13	12	[{"id_menu":1,"count":2}]	1721	delivery	5	17
62142	2020-05-13 09:17:28	2020-05-13	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5670	delivery	5	45
62143	2020-05-13 09:23:25	2020-05-13	9	[{"id_menu":6,"count":1}]	24326	delivery	5	14
62144	2020-05-13 09:24:20	2020-05-13	14	[{"id_menu":2,"count":1}]	24661	delivery	5	19
62145	2020-05-13 09:31:56	2020-05-13	8	[{"id_menu":5,"count":1}]	24601	delivery	5	13
62146	2020-05-13 09:35:58	2020-05-13	9	[{"id_menu":7,"count":1}]	10884	delivery	5	14
62147	2020-05-13 09:50:58	2020-05-13	14	[{"id_menu":2,"count":1}]	23729	pick-up	0	14
62148	2020-05-13 09:51:09	2020-05-13	17	[{"id_menu":4,"count":1}]	24639	delivery	5	22
62149	2020-05-13 09:57:44	2020-05-13	17	[{"id_menu":4,"count":1}]	20161	delivery	5	22
62150	2020-05-13 09:58:02	2020-05-13	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	17713	delivery	5	31
62151	2020-05-13 09:58:06	2020-05-13	8	[{"id_menu":5,"count":1}]	24703	delivery	5	13
62152	2020-05-13 10:05:15	2020-05-13	17	[{"id_menu":4,"count":1}]	24685	delivery	5	22
62153	2020-05-13 10:06:55	2020-05-13	9	[{"id_menu":6,"count":1}]	24716	delivery	5	14
62154	2020-05-13 10:14:15	2020-05-13	8	[{"id_menu":5,"count":1}]	24722	delivery	5	13
62155	2020-05-13 10:15:32	2020-05-13	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	9413	delivery	5	26
62156	2020-05-13 10:15:47	2020-05-13	12	[{"id_menu":1,"count":1}]	276	pick-up	0	12
62157	2020-05-13 10:18:40	2020-05-13	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	8839	delivery	5	26
62158	2020-05-13 10:20:48	2020-05-13	9	[{"id_menu":6,"count":1}]	24606	delivery	5	14
62159	2020-05-13 10:34:26	2020-05-13	9	[{"id_menu":6,"count":1}]	18255	delivery	5	14
62160	2020-05-13 10:37:00	2020-05-13	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":3}]	11038	delivery	5	26
62161	2020-05-13 10:41:15	2020-05-13	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3382	pick-up	0	35
62162	2020-05-13 10:45:20	2020-05-13	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	20060	pick-up	0	26
62163	2020-05-13 10:48:51	2020-05-13	12	[{"id_menu":1,"count":1}]	6622	delivery	5	17
62164	2020-05-13 10:50:06	2020-05-13	12	[{"id_menu":1,"count":1}]	5388	delivery	5	17
62165	2020-05-13 10:50:46	2020-05-13	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	24623	delivery	5	39
62166	2020-05-13 10:51:15	2020-05-13	14	[{"id_menu":2,"count":1}]	13129	delivery	5	19
62167	2020-05-13 10:51:25	2020-05-13	9	[{"id_menu":7,"count":1}]	397	delivery	5	14
62168	2020-05-13 10:52:23	2020-05-13	9	[{"id_menu":7,"count":1}]	12501	delivery	5	14
62169	2020-05-13 10:55:36	2020-05-13	12	[{"id_menu":3,"count":1}]	22046	delivery	5	17
62170	2020-05-13 10:56:17	2020-05-13	9	[{"id_menu":6,"count":1}]	21589	delivery	5	14
62171	2020-05-13 11:01:04	2020-05-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	24698	delivery	5	28
62172	2020-05-13 11:02:21	2020-05-13	14	[{"id_menu":2,"count":1}]	24702	delivery	5	19
62173	2020-05-13 11:07:57	2020-05-13	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	24711	delivery	5	29
62174	2020-05-13 11:14:08	2020-05-13	17	[{"id_menu":4,"count":1}]	10526	delivery	5	22
62175	2020-05-13 11:15:09	2020-05-13	9	[{"id_menu":6,"count":1}]	7919	delivery	5	14
62176	2020-05-13 11:16:39	2020-05-13	37	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8780	delivery	5	42
62177	2020-05-13 11:19:38	2020-05-13	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	24643	delivery	5	31
62178	2020-05-13 11:22:21	2020-05-13	12	[{"id_menu":1,"count":1}]	21580	delivery	5	17
62179	2020-05-13 11:23:17	2020-05-13	9	[{"id_menu":6,"count":1}]	2868	delivery	5	14
62180	2020-05-13 11:27:38	2020-05-13	9	[{"id_menu":7,"count":1}]	24657	delivery	5	14
62181	2020-05-13 11:28:59	2020-05-13	14	[{"id_menu":2,"count":1}]	18126	delivery	5	19
62182	2020-05-13 11:33:57	2020-05-13	12	[{"id_menu":3,"count":1}]	8660	delivery	5	17
62183	2020-05-13 11:40:32	2020-05-13	8	[{"id_menu":5,"count":1}]	22472	delivery	5	13
62184	2020-05-13 11:42:12	2020-05-13	9	[{"id_menu":7,"count":1}]	24635	delivery	5	14
62185	2020-05-13 11:51:16	2020-05-13	12	[{"id_menu":3,"count":1}]	15186	pick-up	0	12
62186	2020-05-13 11:54:24	2020-05-13	8	[{"id_menu":5,"count":1}]	17361	delivery	5	13
62187	2020-05-13 11:55:10	2020-05-13	9	[{"id_menu":6,"count":1}]	24599	delivery	5	14
62188	2020-05-13 11:56:35	2020-05-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3656	pick-up	0	23
62189	2020-05-13 11:57:16	2020-05-13	9	[{"id_menu":7,"count":1}]	24673	delivery	5	14
62190	2020-05-13 12:01:01	2020-05-13	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2631	delivery	5	27
62191	2020-05-13 12:02:01	2020-05-13	12	[{"id_menu":3,"count":1}]	24616	delivery	5	17
62192	2020-05-13 12:05:07	2020-05-13	12	[{"id_menu":3,"count":1}]	5253	pick-up	0	12
62193	2020-05-13 12:10:40	2020-05-13	8	[{"id_menu":5,"count":1}]	18933	delivery	5	13
62194	2020-05-13 12:11:16	2020-05-13	12	[{"id_menu":3,"count":1}]	5073	delivery	5	17
62195	2020-05-13 12:12:09	2020-05-13	41	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4498	delivery	5	46
62196	2020-05-13 12:18:27	2020-05-13	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24663	delivery	5	39
62197	2020-05-13 12:27:04	2020-05-13	12	[{"id_menu":3,"count":1}]	15437	delivery	5	17
62198	2020-05-13 12:27:10	2020-05-13	9	[{"id_menu":7,"count":1}]	10101	delivery	5	14
62199	2020-05-13 12:31:19	2020-05-13	8	[{"id_menu":5,"count":1}]	24714	pick-up	0	8
62200	2020-05-13 12:32:16	2020-05-13	9	[{"id_menu":7,"count":1}]	23968	delivery	5	14
62201	2020-05-13 12:37:43	2020-05-13	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	7076	delivery	5	31
62202	2020-05-13 12:43:23	2020-05-13	8	[{"id_menu":5,"count":1}]	12263	delivery	5	13
62203	2020-05-13 12:50:00	2020-05-13	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13954	delivery	5	31
62204	2020-05-13 12:58:57	2020-05-13	17	[{"id_menu":4,"count":1}]	14531	delivery	5	22
62205	2020-05-13 13:01:48	2020-05-13	17	[{"id_menu":4,"count":1}]	4172	pick-up	0	17
62206	2020-05-13 13:02:25	2020-05-13	9	[{"id_menu":7,"count":1}]	18412	delivery	5	14
62207	2020-05-13 13:07:33	2020-05-13	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	17421	delivery	5	29
62208	2020-05-13 13:13:57	2020-05-13	8	[{"id_menu":5,"count":1}]	5486	delivery	5	13
62209	2020-05-13 13:17:05	2020-05-13	9	[{"id_menu":6,"count":1}]	24694	delivery	5	14
62210	2020-05-13 13:19:14	2020-05-13	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	24708	delivery	5	27
62211	2020-05-13 13:22:21	2020-05-13	14	[{"id_menu":2,"count":1}]	24638	delivery	5	19
62212	2020-05-13 13:25:15	2020-05-13	12	[{"id_menu":1,"count":1}]	10372	delivery	5	17
62213	2020-05-13 13:26:30	2020-05-13	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	3410	delivery	5	31
62214	2020-05-13 13:27:13	2020-05-13	14	[{"id_menu":2,"count":1}]	17881	delivery	5	19
62215	2020-05-13 13:31:06	2020-05-13	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11840	delivery	5	31
62216	2020-05-13 13:32:39	2020-05-13	14	[{"id_menu":2,"count":1}]	24677	delivery	5	19
62217	2020-05-13 13:39:58	2020-05-13	14	[{"id_menu":2,"count":1}]	24602	delivery	5	19
62218	2020-05-13 13:40:06	2020-05-13	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24687	pick-up	0	43
62219	2020-05-13 13:41:14	2020-05-13	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1839	pick-up	0	38
62220	2020-05-13 13:41:36	2020-05-13	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	10670	delivery	5	26
62221	2020-05-13 13:41:39	2020-05-13	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	4673	delivery	5	31
62222	2020-05-13 13:42:09	2020-05-13	12	[{"id_menu":1,"count":1}]	9061	delivery	5	17
62223	2020-05-13 13:48:38	2020-05-13	14	[{"id_menu":2,"count":1}]	23411	pick-up	0	14
62224	2020-05-13 13:57:46	2020-05-13	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13705	delivery	5	34
62225	2020-05-13 14:03:19	2020-05-13	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	22070	delivery	5	26
62226	2020-05-13 14:07:43	2020-05-13	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	3616	delivery	5	31
62227	2020-05-13 14:08:25	2020-05-13	9	[{"id_menu":6,"count":1}]	6729	delivery	5	14
62228	2020-05-13 14:13:39	2020-05-13	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	24679	delivery	5	35
62229	2020-05-13 14:13:39	2020-05-13	9	[{"id_menu":6,"count":2}]	19572	delivery	5	14
62230	2020-05-13 14:14:17	2020-05-13	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	15397	delivery	5	23
62231	2020-05-13 14:18:02	2020-05-13	8	[{"id_menu":5,"count":1}]	9554	delivery	5	13
62232	2020-05-13 14:19:28	2020-05-13	17	[{"id_menu":4,"count":1}]	24619	delivery	5	22
62233	2020-05-13 14:23:27	2020-05-13	9	[{"id_menu":6,"count":1}]	5121	delivery	5	14
62234	2020-05-13 14:25:41	2020-05-13	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1663	delivery	5	43
62235	2020-05-13 14:35:39	2020-05-13	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	24705	pick-up	0	38
62236	2020-05-13 14:36:54	2020-05-13	14	[{"id_menu":2,"count":1}]	2283	pick-up	0	14
62237	2020-05-13 14:39:53	2020-05-13	17	[{"id_menu":4,"count":1}]	643	delivery	5	22
62238	2020-05-13 14:42:44	2020-05-13	14	[{"id_menu":2,"count":1}]	23381	pick-up	0	14
62239	2020-05-13 14:43:39	2020-05-13	12	[{"id_menu":3,"count":1}]	21857	delivery	5	17
62240	2020-05-13 14:43:47	2020-05-13	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	3470	pick-up	0	20
62241	2020-05-13 14:55:18	2020-05-13	9	[{"id_menu":6,"count":1}]	8500	delivery	5	14
62242	2020-05-13 14:58:13	2020-05-13	9	[{"id_menu":7,"count":1}]	22010	delivery	5	14
62243	2020-05-13 15:00:36	2020-05-13	9	[{"id_menu":7,"count":1}]	6364	pick-up	0	9
62244	2020-05-13 15:01:57	2020-05-13	17	[{"id_menu":4,"count":3}]	16418	delivery	5	22
62245	2020-05-13 15:03:44	2020-05-13	14	[{"id_menu":2,"count":1}]	19774	delivery	5	19
62246	2020-05-13 15:03:45	2020-05-13	9	[{"id_menu":6,"count":1}]	14621	delivery	5	14
62247	2020-05-13 15:04:36	2020-05-13	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	15592	delivery	5	28
62248	2020-05-13 15:07:15	2020-05-13	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	22208	delivery	5	40
62249	2020-05-13 15:07:18	2020-05-13	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23650	delivery	5	35
62382	2020-05-13 23:15:31	2020-05-13	14	[{"id_menu":2,"count":1}]	17510	delivery	5	19
62250	2020-05-13 15:09:49	2020-05-13	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23633	delivery	5	39
62251	2020-05-13 15:11:34	2020-05-13	14	[{"id_menu":2,"count":1}]	24725	pick-up	0	14
62252	2020-05-13 15:12:19	2020-05-13	9	[{"id_menu":6,"count":1}]	22143	delivery	5	14
62253	2020-05-13 15:13:45	2020-05-13	9	[{"id_menu":6,"count":1}]	21288	delivery	5	14
62254	2020-05-13 15:15:10	2020-05-13	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	24655	delivery	5	44
62255	2020-05-13 15:15:41	2020-05-13	14	[{"id_menu":2,"count":1}]	13677	delivery	5	19
62256	2020-05-13 15:19:50	2020-05-13	9	[{"id_menu":6,"count":1}]	4079	delivery	5	14
62257	2020-05-13 15:29:56	2020-05-13	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	581	delivery	5	22
62258	2020-05-13 15:33:20	2020-05-13	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24651	delivery	5	37
62259	2020-05-13 15:35:08	2020-05-13	8	[{"id_menu":5,"count":1}]	7217	delivery	5	13
62260	2020-05-13 15:37:26	2020-05-13	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	19755	delivery	5	38
62261	2020-05-13 15:39:51	2020-05-13	12	[{"id_menu":1,"count":1}]	23739	delivery	5	17
62262	2020-05-13 15:40:51	2020-05-13	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	8199	delivery	5	34
62263	2020-05-13 15:44:07	2020-05-13	17	[{"id_menu":4,"count":1}]	4613	pick-up	0	17
62264	2020-05-13 15:50:52	2020-05-13	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8225	delivery	5	37
62265	2020-05-13 15:51:54	2020-05-13	9	[{"id_menu":7,"count":1}]	20379	pick-up	0	9
62266	2020-05-13 15:52:13	2020-05-13	12	[{"id_menu":3,"count":1}]	10916	pick-up	0	12
62267	2020-05-13 15:52:29	2020-05-13	9	[{"id_menu":6,"count":2}]	3825	pick-up	0	9
62268	2020-05-13 15:54:46	2020-05-13	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	20381	delivery	5	44
62269	2020-05-13 15:54:58	2020-05-13	14	[{"id_menu":2,"count":1}]	20326	delivery	5	19
62270	2020-05-13 15:59:13	2020-05-13	8	[{"id_menu":5,"count":1}]	24669	delivery	5	13
62271	2020-05-13 16:01:22	2020-05-13	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24646	delivery	5	36
62272	2020-05-13 16:08:43	2020-05-13	17	[{"id_menu":4,"count":1}]	11547	delivery	5	22
62273	2020-05-13 16:10:38	2020-05-13	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	24719	delivery	5	25
62274	2020-05-13 16:18:27	2020-05-13	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	17170	delivery	5	31
62275	2020-05-13 16:25:09	2020-05-13	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	10340	delivery	5	34
62276	2020-05-13 16:26:30	2020-05-13	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24653	delivery	5	51
62277	2020-05-13 16:28:58	2020-05-13	8	[{"id_menu":5,"count":1}]	24664	delivery	5	13
62278	2020-05-13 16:43:26	2020-05-13	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24624	delivery	5	37
62279	2020-05-13 16:47:55	2020-05-13	8	[{"id_menu":5,"count":1}]	24617	delivery	5	13
62280	2020-05-13 16:51:57	2020-05-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17956	pick-up	0	18
62281	2020-05-13 16:56:40	2020-05-13	12	[{"id_menu":3,"count":1}]	24622	delivery	5	17
62282	2020-05-13 17:03:29	2020-05-13	8	[{"id_menu":5,"count":1}]	24718	pick-up	0	8
62283	2020-05-13 17:03:41	2020-05-13	12	[{"id_menu":1,"count":1}]	8149	delivery	5	17
62284	2020-05-13 17:07:40	2020-05-13	12	[{"id_menu":1,"count":1}]	19900	delivery	5	17
62285	2020-05-13 17:13:35	2020-05-13	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	7126	pick-up	0	26
62286	2020-05-13 17:17:49	2020-05-13	8	[{"id_menu":5,"count":1}]	10477	pick-up	0	8
62287	2020-05-13 17:21:30	2020-05-13	9	[{"id_menu":6,"count":1}]	19530	delivery	5	14
62288	2020-05-13 17:21:57	2020-05-13	17	[{"id_menu":4,"count":1}]	24099	delivery	5	22
62289	2020-05-13 17:22:30	2020-05-13	12	[{"id_menu":1,"count":1}]	19629	delivery	5	17
62290	2020-05-13 17:23:55	2020-05-13	12	[{"id_menu":3,"count":1}]	9011	delivery	5	17
62291	2020-05-13 17:25:21	2020-05-13	9	[{"id_menu":7,"count":1}]	24658	delivery	5	14
62292	2020-05-13 17:26:04	2020-05-13	9	[{"id_menu":7,"count":1}]	7115	delivery	5	14
62293	2020-05-13 17:27:44	2020-05-13	9	[{"id_menu":6,"count":1}]	4139	pick-up	0	9
62294	2020-05-13 17:32:03	2020-05-13	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	12541	pick-up	0	23
62295	2020-05-13 17:35:09	2020-05-13	30	[{"id_menu":1,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24630	delivery	5	35
62296	2020-05-13 17:50:56	2020-05-13	9	[{"id_menu":6,"count":3}]	24637	delivery	5	14
62297	2020-05-13 17:51:07	2020-05-13	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15979	delivery	5	37
62298	2020-05-13 17:51:36	2020-05-13	9	[{"id_menu":6,"count":1}]	24634	pick-up	0	9
62299	2020-05-13 17:53:00	2020-05-13	12	[{"id_menu":3,"count":1}]	24625	delivery	5	17
62300	2020-05-13 17:55:15	2020-05-13	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2425	delivery	5	26
62301	2020-05-13 17:57:34	2020-05-13	12	[{"id_menu":1,"count":1}]	5839	pick-up	0	12
62302	2020-05-13 17:58:00	2020-05-13	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	9570	delivery	5	34
62303	2020-05-13 17:59:33	2020-05-13	9	[{"id_menu":7,"count":2}]	7514	delivery	5	14
62304	2020-05-13 18:01:48	2020-05-13	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	7197	delivery	5	40
62305	2020-05-13 18:02:23	2020-05-13	9	[{"id_menu":6,"count":1}]	13410	delivery	5	14
62306	2020-05-13 18:15:05	2020-05-13	17	[{"id_menu":4,"count":1}]	22283	delivery	5	22
62307	2020-05-13 18:18:46	2020-05-13	12	[{"id_menu":3,"count":1}]	8049	delivery	5	17
62308	2020-05-13 18:18:48	2020-05-13	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24674	delivery	5	49
62309	2020-05-13 18:21:23	2020-05-13	17	[{"id_menu":4,"count":1}]	2434	pick-up	0	17
62310	2020-05-13 18:29:11	2020-05-13	9	[{"id_menu":6,"count":1}]	24671	delivery	5	14
62311	2020-05-13 18:30:02	2020-05-13	14	[{"id_menu":2,"count":1}]	11289	delivery	5	19
62312	2020-05-13 18:32:01	2020-05-13	14	[{"id_menu":2,"count":1}]	24648	delivery	5	19
62313	2020-05-13 18:38:13	2020-05-13	12	[{"id_menu":3,"count":1}]	7156	delivery	5	17
62314	2020-05-13 18:43:20	2020-05-13	17	[{"id_menu":4,"count":1}]	15201	delivery	5	22
62315	2020-05-13 18:48:17	2020-05-13	9	[{"id_menu":7,"count":1}]	17453	delivery	5	14
62316	2020-05-13 18:53:55	2020-05-13	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	23123	delivery	5	37
62317	2020-05-13 18:55:15	2020-05-13	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11998	delivery	5	43
62318	2020-05-13 18:59:32	2020-05-13	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	24158	delivery	5	26
62319	2020-05-13 19:04:25	2020-05-13	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	24629	delivery	5	31
62320	2020-05-13 19:04:37	2020-05-13	12	[{"id_menu":3,"count":1}]	3226	pick-up	0	12
62321	2020-05-13 19:07:05	2020-05-13	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4621	delivery	5	27
62322	2020-05-13 19:10:11	2020-05-13	14	[{"id_menu":2,"count":1}]	16774	delivery	5	19
62323	2020-05-13 19:11:44	2020-05-13	14	[{"id_menu":2,"count":1}]	12851	pick-up	0	14
62324	2020-05-13 19:12:52	2020-05-13	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2366	pick-up	0	17
62325	2020-05-13 19:16:26	2020-05-13	12	[{"id_menu":3,"count":1}]	2731	delivery	5	17
62326	2020-05-13 19:18:08	2020-05-13	8	[{"id_menu":5,"count":1}]	11267	delivery	5	13
62327	2020-05-13 19:19:14	2020-05-13	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	24550	pick-up	0	21
62328	2020-05-13 19:27:48	2020-05-13	9	[{"id_menu":7,"count":1}]	5448	delivery	5	14
62329	2020-05-13 19:31:00	2020-05-13	9	[{"id_menu":7,"count":1}]	9911	delivery	5	14
62330	2020-05-13 19:33:37	2020-05-13	12	[{"id_menu":3,"count":1}]	19269	pick-up	0	12
62331	2020-05-13 19:38:06	2020-05-13	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	24600	delivery	5	38
62332	2020-05-13 19:42:10	2020-05-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1147	pick-up	0	31
62333	2020-05-13 19:54:13	2020-05-13	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5133	pick-up	0	44
62334	2020-05-13 19:58:01	2020-05-13	12	[{"id_menu":3,"count":1}]	13028	pick-up	0	12
62335	2020-05-13 20:01:01	2020-05-13	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	6801	delivery	5	25
62336	2020-05-13 20:01:33	2020-05-13	17	[{"id_menu":4,"count":1}]	8561	pick-up	0	17
62337	2020-05-13 20:02:56	2020-05-13	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	24633	delivery	5	25
62338	2020-05-13 20:06:24	2020-05-13	9	[{"id_menu":6,"count":1}]	20515	pick-up	0	9
62339	2020-05-13 20:08:09	2020-05-13	9	[{"id_menu":7,"count":4}]	24608	delivery	5	14
62340	2020-05-13 20:09:26	2020-05-13	8	[{"id_menu":5,"count":1}]	15368	delivery	5	13
62341	2020-05-13 20:20:56	2020-05-13	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	5526	pick-up	0	21
62342	2020-05-13 20:23:12	2020-05-13	9	[{"id_menu":7,"count":1}]	4946	delivery	5	14
62343	2020-05-13 20:28:13	2020-05-13	17	[{"id_menu":4,"count":1}]	17994	delivery	5	22
62344	2020-05-13 20:39:31	2020-05-13	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	24171	delivery	5	29
62345	2020-05-13 20:39:42	2020-05-13	9	[{"id_menu":6,"count":1}]	13393	delivery	5	14
62346	2020-05-13 20:46:30	2020-05-13	12	[{"id_menu":3,"count":2}]	3729	pick-up	0	12
62347	2020-05-13 20:46:51	2020-05-13	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22564	delivery	5	31
62348	2020-05-13 20:47:18	2020-05-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	15948	pick-up	0	31
62349	2020-05-13 20:49:07	2020-05-13	17	[{"id_menu":4,"count":1}]	2339	pick-up	0	17
62350	2020-05-13 20:49:44	2020-05-13	9	[{"id_menu":6,"count":1}]	17870	delivery	5	14
62351	2020-05-13 20:50:04	2020-05-13	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	20310	delivery	5	31
62352	2020-05-13 20:56:12	2020-05-13	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	14066	pick-up	0	23
62353	2020-05-13 21:17:20	2020-05-13	17	[{"id_menu":4,"count":1}]	11932	delivery	5	22
62354	2020-05-13 21:17:24	2020-05-13	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	15515	pick-up	0	23
62355	2020-05-13 21:18:58	2020-05-13	9	[{"id_menu":6,"count":1}]	24605	delivery	5	14
62356	2020-05-13 21:23:00	2020-05-13	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2055	pick-up	0	26
62357	2020-05-13 21:33:59	2020-05-13	12	[{"id_menu":1,"count":1}]	24645	delivery	5	17
62358	2020-05-13 21:45:42	2020-05-13	9	[{"id_menu":7,"count":1}]	4833	pick-up	0	9
62359	2020-05-13 21:51:20	2020-05-13	12	[{"id_menu":1,"count":1}]	12195	pick-up	0	12
62360	2020-05-13 21:54:57	2020-05-13	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	24659	delivery	5	43
62361	2020-05-13 21:56:21	2020-05-13	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	9566	pick-up	0	26
62362	2020-05-13 21:59:53	2020-05-13	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	6284	pick-up	0	21
62363	2020-05-13 22:01:28	2020-05-13	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	24647	delivery	5	31
62364	2020-05-13 22:02:23	2020-05-13	17	[{"id_menu":4,"count":1}]	4395	pick-up	0	17
62365	2020-05-13 22:04:08	2020-05-13	8	[{"id_menu":5,"count":2}]	23997	delivery	5	13
62366	2020-05-13 22:05:34	2020-05-13	14	[{"id_menu":2,"count":1}]	24699	delivery	5	19
62367	2020-05-13 22:07:45	2020-05-13	14	[{"id_menu":2,"count":1}]	8410	delivery	5	19
62368	2020-05-13 22:09:04	2020-05-13	8	[{"id_menu":5,"count":1}]	24614	delivery	5	13
62369	2020-05-13 22:12:40	2020-05-13	8	[{"id_menu":5,"count":1}]	18125	delivery	5	13
62370	2020-05-13 22:19:14	2020-05-13	9	[{"id_menu":6,"count":1}]	17592	pick-up	0	9
62371	2020-05-13 22:19:20	2020-05-13	9	[{"id_menu":7,"count":1}]	9582	delivery	5	14
62372	2020-05-13 22:20:44	2020-05-13	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	24712	delivery	5	45
62373	2020-05-13 22:21:29	2020-05-13	9	[{"id_menu":7,"count":1}]	21009	delivery	5	14
62374	2020-05-13 22:28:38	2020-05-13	14	[{"id_menu":2,"count":1}]	708	delivery	5	19
62375	2020-05-13 22:44:23	2020-05-13	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	18613	delivery	5	26
62376	2020-05-13 23:07:51	2020-05-13	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24723	delivery	5	36
62377	2020-05-13 23:08:30	2020-05-13	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24631	delivery	5	22
62378	2020-05-13 23:08:38	2020-05-13	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1517	pick-up	0	21
62379	2020-05-13 23:12:46	2020-05-13	9	[{"id_menu":6,"count":1}]	4604	delivery	5	14
62380	2020-05-13 23:13:28	2020-05-13	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	7571	pick-up	0	26
62381	2020-05-13 23:15:18	2020-05-13	8	[{"id_menu":5,"count":1}]	2187	pick-up	0	8
62383	2020-05-13 23:22:39	2020-05-13	9	[{"id_menu":7,"count":1}]	15858	delivery	5	14
62384	2020-05-13 23:23:19	2020-05-13	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	24691	delivery	5	27
62385	2020-05-13 23:24:32	2020-05-13	9	[{"id_menu":6,"count":1}]	20327	pick-up	0	9
62386	2020-05-13 23:27:07	2020-05-13	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	1145	pick-up	0	31
62387	2020-05-13 23:28:12	2020-05-13	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	12022	delivery	5	27
62388	2020-05-13 23:30:25	2020-05-13	14	[{"id_menu":2,"count":1}]	24690	delivery	5	19
62389	2020-05-13 23:37:06	2020-05-13	8	[{"id_menu":5,"count":1}]	24611	delivery	5	13
62390	2020-05-13 23:38:43	2020-05-13	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	4738	delivery	5	26
62391	2020-05-13 23:43:05	2020-05-13	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14124	delivery	5	39
62392	2020-05-13 23:45:12	2020-05-13	14	[{"id_menu":2,"count":1}]	7092	delivery	5	19
62393	2020-05-13 23:45:21	2020-05-13	17	[{"id_menu":4,"count":1}]	24627	delivery	5	22
62394	2020-05-13 23:49:28	2020-05-13	9	[{"id_menu":6,"count":1}]	7947	delivery	5	14
62395	2020-05-13 23:50:09	2020-05-13	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20729	delivery	5	40
62396	2020-05-14 00:00:02	2020-05-14	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	24734	delivery	5	39
62397	2020-05-14 00:01:18	2020-05-14	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	24807	delivery	5	27
62398	2020-05-14 00:05:08	2020-05-14	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2078	delivery	5	28
62399	2020-05-14 00:05:46	2020-05-14	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2959	delivery	5	31
62400	2020-05-14 00:06:07	2020-05-14	14	[{"id_menu":2,"count":2}]	2108	pick-up	0	14
62401	2020-05-14 00:12:10	2020-05-14	9	[{"id_menu":6,"count":2}]	4107	delivery	5	14
62402	2020-05-14 00:12:27	2020-05-14	9	[{"id_menu":6,"count":1}]	2068	delivery	5	14
62403	2020-05-14 00:13:55	2020-05-14	12	[{"id_menu":3,"count":1}]	1528	delivery	5	17
62404	2020-05-14 00:17:33	2020-05-14	12	[{"id_menu":1,"count":1}]	274	pick-up	0	12
62405	2020-05-14 00:18:13	2020-05-14	12	[{"id_menu":1,"count":1}]	10287	pick-up	0	12
62406	2020-05-14 00:19:30	2020-05-14	8	[{"id_menu":5,"count":1}]	1889	delivery	5	13
62407	2020-05-14 00:28:47	2020-05-14	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	5397	delivery	5	40
62408	2020-05-14 00:31:35	2020-05-14	9	[{"id_menu":7,"count":1}]	24826	delivery	5	14
62409	2020-05-14 00:31:56	2020-05-14	8	[{"id_menu":5,"count":1}]	24848	delivery	5	13
62410	2020-05-14 00:39:02	2020-05-14	17	[{"id_menu":4,"count":1}]	24816	delivery	5	22
62411	2020-05-14 00:44:07	2020-05-14	17	[{"id_menu":4,"count":1}]	6957	pick-up	0	17
62412	2020-05-14 00:48:30	2020-05-14	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	23264	delivery	5	43
62413	2020-05-14 00:48:42	2020-05-14	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	20987	delivery	5	26
62414	2020-05-14 00:48:57	2020-05-14	8	[{"id_menu":5,"count":2}]	11124	pick-up	0	8
62415	2020-05-14 00:49:11	2020-05-14	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	424	pick-up	0	26
62416	2020-05-14 00:53:06	2020-05-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	17805	pick-up	0	31
62417	2020-05-14 00:54:07	2020-05-14	9	[{"id_menu":7,"count":1}]	21137	delivery	5	14
62418	2020-05-14 00:54:29	2020-05-14	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17743	delivery	5	23
62419	2020-05-14 00:55:01	2020-05-14	9	[{"id_menu":7,"count":1}]	24884	delivery	5	14
62420	2020-05-14 01:03:22	2020-05-14	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24809	delivery	5	52
62421	2020-05-14 01:03:56	2020-05-14	9	[{"id_menu":6,"count":1}]	9102	delivery	5	14
62422	2020-05-14 01:04:50	2020-05-14	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	312	delivery	5	27
62423	2020-05-14 01:08:08	2020-05-14	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6187	delivery	5	36
62424	2020-05-14 01:10:22	2020-05-14	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	9208	delivery	5	25
62425	2020-05-14 01:11:29	2020-05-14	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24835	delivery	5	22
62426	2020-05-14 01:12:39	2020-05-14	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	24737	delivery	5	52
62427	2020-05-14 01:14:28	2020-05-14	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	12189	pick-up	0	21
62428	2020-05-14 01:22:49	2020-05-14	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	24812	delivery	5	34
62429	2020-05-14 01:24:43	2020-05-14	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15799	delivery	5	48
62430	2020-05-14 01:27:03	2020-05-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24878	delivery	5	22
62431	2020-05-14 01:31:33	2020-05-14	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	24577	delivery	5	23
62432	2020-05-14 01:39:28	2020-05-14	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	772	delivery	5	27
62433	2020-05-14 01:40:12	2020-05-14	12	[{"id_menu":3,"count":1}]	11097	delivery	5	17
62434	2020-05-14 01:44:56	2020-05-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	24834	delivery	5	22
62435	2020-05-14 01:45:17	2020-05-14	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	21427	delivery	5	43
62436	2020-05-14 01:49:11	2020-05-14	9	[{"id_menu":6,"count":1}]	24766	pick-up	0	9
62437	2020-05-14 01:52:05	2020-05-14	17	[{"id_menu":4,"count":1}]	14411	delivery	5	22
62438	2020-05-14 01:53:36	2020-05-14	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2649	delivery	5	43
62439	2020-05-14 01:56:42	2020-05-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	24858	delivery	5	31
62440	2020-05-14 02:01:46	2020-05-14	12	[{"id_menu":3,"count":1}]	24728	delivery	5	17
62441	2020-05-14 02:04:43	2020-05-14	9	[{"id_menu":7,"count":1}]	24756	delivery	5	14
62442	2020-05-14 02:05:58	2020-05-14	14	[{"id_menu":2,"count":2}]	15881	delivery	5	19
62443	2020-05-14 02:09:21	2020-05-14	9	[{"id_menu":6,"count":1}]	9076	delivery	5	14
62444	2020-05-14 02:10:21	2020-05-14	9	[{"id_menu":6,"count":1}]	22715	delivery	5	14
62445	2020-05-14 02:12:50	2020-05-14	14	[{"id_menu":2,"count":1}]	6164	pick-up	0	14
62446	2020-05-14 02:24:47	2020-05-14	9	[{"id_menu":6,"count":3}]	24880	delivery	5	14
62447	2020-05-14 02:26:01	2020-05-14	17	[{"id_menu":4,"count":1}]	24798	delivery	5	22
62448	2020-05-14 02:28:14	2020-05-14	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	21575	pick-up	0	26
62449	2020-05-14 02:31:06	2020-05-14	12	[{"id_menu":1,"count":1}]	24836	delivery	5	17
62450	2020-05-14 02:36:33	2020-05-14	14	[{"id_menu":2,"count":1}]	15929	delivery	5	19
62451	2020-05-14 02:47:48	2020-05-14	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	9470	delivery	5	26
62452	2020-05-14 02:53:21	2020-05-14	8	[{"id_menu":5,"count":1}]	1581	delivery	5	13
62453	2020-05-14 03:00:36	2020-05-14	12	[{"id_menu":3,"count":1}]	123	pick-up	0	12
62454	2020-05-14 03:01:01	2020-05-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	24769	delivery	5	31
62455	2020-05-14 03:02:10	2020-05-14	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24819	delivery	5	31
62456	2020-05-14 03:04:19	2020-05-14	14	[{"id_menu":2,"count":1}]	17611	delivery	5	19
62457	2020-05-14 03:04:38	2020-05-14	12	[{"id_menu":3,"count":1}]	16014	delivery	5	17
62458	2020-05-14 03:06:51	2020-05-14	9	[{"id_menu":7,"count":2}]	3639	delivery	5	14
62459	2020-05-14 03:08:13	2020-05-14	14	[{"id_menu":2,"count":1}]	24885	pick-up	0	14
62460	2020-05-14 03:09:03	2020-05-14	17	[{"id_menu":4,"count":1}]	24774	pick-up	0	17
62461	2020-05-14 03:11:15	2020-05-14	12	[{"id_menu":3,"count":1}]	24733	pick-up	0	12
62462	2020-05-14 03:19:01	2020-05-14	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	3820	pick-up	0	26
62463	2020-05-14 03:19:20	2020-05-14	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	18566	delivery	5	31
62464	2020-05-14 03:21:22	2020-05-14	17	[{"id_menu":4,"count":1}]	24033	delivery	5	22
62465	2020-05-14 03:21:32	2020-05-14	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	24777	delivery	5	27
62466	2020-05-14 03:25:23	2020-05-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	24869	delivery	5	36
62467	2020-05-14 03:26:53	2020-05-14	12	[{"id_menu":3,"count":1}]	9420	pick-up	0	12
62468	2020-05-14 03:27:02	2020-05-14	14	[{"id_menu":2,"count":1}]	377	pick-up	0	14
62469	2020-05-14 03:28:11	2020-05-14	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	23951	delivery	5	26
62470	2020-05-14 03:31:06	2020-05-14	8	[{"id_menu":5,"count":1}]	24867	delivery	5	13
62471	2020-05-14 03:37:36	2020-05-14	14	[{"id_menu":2,"count":1}]	24831	delivery	5	19
62472	2020-05-14 03:38:39	2020-05-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17392	pick-up	0	26
62473	2020-05-14 03:46:59	2020-05-14	9	[{"id_menu":6,"count":1}]	24748	delivery	5	14
62474	2020-05-14 03:54:31	2020-05-14	14	[{"id_menu":2,"count":1}]	12157	delivery	5	19
62475	2020-05-14 03:57:21	2020-05-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20573	delivery	5	22
62476	2020-05-14 03:59:30	2020-05-14	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8447	delivery	5	45
62477	2020-05-14 04:01:42	2020-05-14	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5739	delivery	5	45
62478	2020-05-14 04:01:50	2020-05-14	9	[{"id_menu":6,"count":1}]	669	delivery	5	14
62479	2020-05-14 04:04:11	2020-05-14	9	[{"id_menu":6,"count":1}]	5786	delivery	5	14
62480	2020-05-14 04:06:52	2020-05-14	9	[{"id_menu":6,"count":1}]	19502	delivery	5	14
62481	2020-05-14 04:12:06	2020-05-14	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1820	pick-up	0	26
62482	2020-05-14 04:16:13	2020-05-14	9	[{"id_menu":6,"count":1}]	18704	pick-up	0	9
62483	2020-05-14 04:16:43	2020-05-14	9	[{"id_menu":7,"count":2}]	24738	delivery	5	14
62484	2020-05-14 04:18:38	2020-05-14	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9752	delivery	5	22
62485	2020-05-14 04:19:44	2020-05-14	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	24806	delivery	5	31
62486	2020-05-14 04:19:48	2020-05-14	9	[{"id_menu":6,"count":1}]	24620	delivery	5	14
62487	2020-05-14 04:26:12	2020-05-14	12	[{"id_menu":3,"count":1}]	1425	delivery	5	17
62488	2020-05-14 04:29:44	2020-05-14	17	[{"id_menu":4,"count":1}]	24892	delivery	5	22
62489	2020-05-14 04:30:09	2020-05-14	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	14090	delivery	5	25
62490	2020-05-14 04:33:33	2020-05-14	41	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	11967	delivery	5	46
62491	2020-05-14 04:34:33	2020-05-14	12	[{"id_menu":3,"count":1}]	24767	pick-up	0	12
62492	2020-05-14 04:35:48	2020-05-14	8	[{"id_menu":5,"count":1}]	9562	pick-up	0	8
62493	2020-05-14 04:40:28	2020-05-14	9	[{"id_menu":7,"count":1}]	9554	delivery	5	14
62494	2020-05-14 04:41:34	2020-05-14	9	[{"id_menu":6,"count":1}]	1313	pick-up	0	9
62495	2020-05-14 04:42:55	2020-05-14	12	[{"id_menu":1,"count":1}]	17814	pick-up	0	12
62496	2020-05-14 04:47:05	2020-05-14	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	24817	delivery	5	26
62497	2020-05-14 04:49:13	2020-05-14	9	[{"id_menu":6,"count":1}]	16831	delivery	5	14
62498	2020-05-14 04:54:31	2020-05-14	17	[{"id_menu":4,"count":1}]	24180	delivery	5	22
62499	2020-05-14 05:01:23	2020-05-14	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	24862	delivery	5	30
62500	2020-05-14 05:02:19	2020-05-14	14	[{"id_menu":2,"count":1}]	6163	pick-up	0	14
62501	2020-05-14 05:04:42	2020-05-14	9	[{"id_menu":6,"count":1}]	24857	delivery	5	14
62502	2020-05-14 05:17:56	2020-05-14	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	24745	delivery	5	44
62503	2020-05-14 05:19:34	2020-05-14	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	23226	pick-up	0	34
62504	2020-05-14 05:22:58	2020-05-14	8	[{"id_menu":5,"count":1}]	24841	delivery	5	13
62505	2020-05-14 05:23:09	2020-05-14	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	6232	pick-up	0	20
62506	2020-05-14 05:33:04	2020-05-14	9	[{"id_menu":6,"count":1}]	16165	delivery	5	14
62507	2020-05-14 05:33:33	2020-05-14	14	[{"id_menu":2,"count":1}]	24872	delivery	5	19
62508	2020-05-14 05:37:11	2020-05-14	9	[{"id_menu":6,"count":1}]	24780	delivery	5	14
62509	2020-05-14 05:40:37	2020-05-14	8	[{"id_menu":5,"count":1}]	24771	delivery	5	13
62510	2020-05-14 05:41:53	2020-05-14	12	[{"id_menu":3,"count":1}]	2416	delivery	5	17
62511	2020-05-14 05:48:00	2020-05-14	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	5916	delivery	5	29
62512	2020-05-14 05:50:16	2020-05-14	12	[{"id_menu":1,"count":1}]	10194	pick-up	0	12
62513	2020-05-14 05:53:07	2020-05-14	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24820	delivery	5	22
62514	2020-05-14 05:53:19	2020-05-14	12	[{"id_menu":1,"count":1}]	2599	delivery	5	17
62515	2020-05-14 05:54:06	2020-05-14	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	19891	delivery	5	40
62516	2020-05-14 05:54:09	2020-05-14	14	[{"id_menu":2,"count":2}]	24805	delivery	5	19
62517	2020-05-14 05:55:41	2020-05-14	12	[{"id_menu":1,"count":1}]	24890	pick-up	0	12
62518	2020-05-14 05:57:06	2020-05-14	9	[{"id_menu":7,"count":1}]	24847	delivery	5	14
62519	2020-05-14 05:57:39	2020-05-14	12	[{"id_menu":1,"count":1}]	14358	delivery	5	17
62520	2020-05-14 05:58:30	2020-05-14	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	22209	delivery	5	26
62521	2020-05-14 05:59:04	2020-05-14	12	[{"id_menu":1,"count":1}]	12535	delivery	5	17
62522	2020-05-14 05:59:16	2020-05-14	17	[{"id_menu":4,"count":1}]	4710	pick-up	0	17
62523	2020-05-14 05:59:26	2020-05-14	9	[{"id_menu":6,"count":1}]	14263	delivery	5	14
62524	2020-05-14 05:59:57	2020-05-14	9	[{"id_menu":6,"count":1}]	24859	delivery	5	14
62525	2020-05-14 06:08:21	2020-05-14	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	24889	delivery	5	28
62526	2020-05-14 06:09:01	2020-05-14	8	[{"id_menu":5,"count":1}]	17732	delivery	5	13
62527	2020-05-14 06:10:11	2020-05-14	17	[{"id_menu":4,"count":1}]	24772	delivery	5	22
62528	2020-05-14 06:10:52	2020-05-14	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1541	pick-up	0	40
62529	2020-05-14 06:12:18	2020-05-14	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	17303	delivery	5	42
62530	2020-05-14 06:17:40	2020-05-14	14	[{"id_menu":2,"count":2}]	21367	delivery	5	19
62531	2020-05-14 06:20:22	2020-05-14	17	[{"id_menu":4,"count":1}]	3578	pick-up	0	17
62532	2020-05-14 06:22:46	2020-05-14	12	[{"id_menu":3,"count":1}]	24808	delivery	5	17
62533	2020-05-14 06:24:58	2020-05-14	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	20787	delivery	5	26
62534	2020-05-14 06:27:09	2020-05-14	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	11145	delivery	5	45
62535	2020-05-14 06:31:24	2020-05-14	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2916	pick-up	0	26
62536	2020-05-14 06:32:49	2020-05-14	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	11216	delivery	5	31
62537	2020-05-14 06:37:44	2020-05-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	16208	delivery	5	22
62538	2020-05-14 06:38:46	2020-05-14	8	[{"id_menu":5,"count":1}]	14076	delivery	5	13
62539	2020-05-14 06:46:10	2020-05-14	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14944	delivery	5	22
62540	2020-05-14 06:48:57	2020-05-14	14	[{"id_menu":2,"count":1}]	24794	delivery	5	19
62541	2020-05-14 06:55:33	2020-05-14	9	[{"id_menu":6,"count":1}]	24833	delivery	5	14
62542	2020-05-14 07:04:58	2020-05-14	14	[{"id_menu":2,"count":1}]	24829	delivery	5	19
62543	2020-05-14 07:09:45	2020-05-14	9	[{"id_menu":6,"count":1}]	24760	delivery	5	14
62544	2020-05-14 07:13:43	2020-05-14	9	[{"id_menu":6,"count":1}]	9817	pick-up	0	9
62545	2020-05-14 07:14:56	2020-05-14	8	[{"id_menu":5,"count":1}]	24799	delivery	5	13
62546	2020-05-14 07:16:10	2020-05-14	9	[{"id_menu":7,"count":1}]	24403	delivery	5	14
62547	2020-05-14 07:18:03	2020-05-14	9	[{"id_menu":6,"count":1}]	24811	delivery	5	14
62548	2020-05-14 07:21:09	2020-05-14	17	[{"id_menu":4,"count":2}]	22698	delivery	5	22
62549	2020-05-14 07:21:18	2020-05-14	9	[{"id_menu":7,"count":1}]	16157	delivery	5	14
62550	2020-05-14 07:23:45	2020-05-14	9	[{"id_menu":7,"count":1}]	12769	delivery	5	14
62551	2020-05-14 07:27:04	2020-05-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23556	delivery	5	22
62552	2020-05-14 07:39:04	2020-05-14	9	[{"id_menu":6,"count":1}]	3448	pick-up	0	9
62553	2020-05-14 07:43:16	2020-05-14	14	[{"id_menu":2,"count":1}]	2783	delivery	5	19
62554	2020-05-14 07:43:40	2020-05-14	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	24754	delivery	5	43
62555	2020-05-14 07:47:43	2020-05-14	14	[{"id_menu":2,"count":2}]	10342	pick-up	0	14
62556	2020-05-14 07:48:39	2020-05-14	12	[{"id_menu":3,"count":2}]	24759	delivery	5	17
62557	2020-05-14 07:52:30	2020-05-14	12	[{"id_menu":3,"count":1}]	24891	delivery	5	17
62558	2020-05-14 07:56:26	2020-05-14	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	24832	delivery	5	27
62559	2020-05-14 08:13:02	2020-05-14	12	[{"id_menu":3,"count":1}]	23156	pick-up	0	12
62560	2020-05-14 08:15:11	2020-05-14	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	5987	pick-up	0	38
62561	2020-05-14 08:16:32	2020-05-14	9	[{"id_menu":6,"count":1}]	3736	pick-up	0	9
62562	2020-05-14 08:17:25	2020-05-14	9	[{"id_menu":7,"count":1}]	24876	delivery	5	14
62563	2020-05-14 08:21:11	2020-05-14	12	[{"id_menu":1,"count":1}]	14364	pick-up	0	12
62564	2020-05-14 08:22:54	2020-05-14	9	[{"id_menu":6,"count":1}]	24837	delivery	5	14
62565	2020-05-14 08:25:51	2020-05-14	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	24882	delivery	5	34
62566	2020-05-14 08:30:39	2020-05-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	9087	delivery	5	36
62567	2020-05-14 08:30:54	2020-05-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7505	pick-up	0	17
62568	2020-05-14 08:31:29	2020-05-14	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24843	delivery	5	43
62569	2020-05-14 08:34:34	2020-05-14	9	[{"id_menu":6,"count":1}]	20611	delivery	5	14
62570	2020-05-14 08:35:50	2020-05-14	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6836	delivery	5	34
62571	2020-05-14 08:45:24	2020-05-14	12	[{"id_menu":3,"count":1}]	23735	pick-up	0	12
62572	2020-05-14 08:53:21	2020-05-14	12	[{"id_menu":1,"count":1}]	20290	delivery	5	17
62573	2020-05-14 08:53:52	2020-05-14	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	24795	delivery	5	23
62574	2020-05-14 08:56:38	2020-05-14	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22920	delivery	5	37
62575	2020-05-14 09:00:13	2020-05-14	17	[{"id_menu":4,"count":1}]	24765	delivery	5	22
62576	2020-05-14 09:02:07	2020-05-14	9	[{"id_menu":6,"count":1}]	6965	pick-up	0	9
62577	2020-05-14 09:06:43	2020-05-14	9	[{"id_menu":6,"count":1}]	17982	delivery	5	14
62578	2020-05-14 09:09:05	2020-05-14	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	24787	delivery	5	55
62579	2020-05-14 09:12:38	2020-05-14	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	24729	delivery	5	25
62580	2020-05-14 09:13:51	2020-05-14	12	[{"id_menu":3,"count":1}]	4804	delivery	5	17
62581	2020-05-14 09:16:49	2020-05-14	9	[{"id_menu":6,"count":1}]	15787	delivery	5	14
62582	2020-05-14 09:24:02	2020-05-14	9	[{"id_menu":6,"count":1}]	15902	delivery	5	14
62583	2020-05-14 09:25:01	2020-05-14	17	[{"id_menu":4,"count":1}]	4867	pick-up	0	17
62584	2020-05-14 09:29:35	2020-05-14	8	[{"id_menu":5,"count":1}]	16051	delivery	5	13
62585	2020-05-14 09:32:55	2020-05-14	8	[{"id_menu":5,"count":1}]	24630	delivery	5	13
62586	2020-05-14 09:38:11	2020-05-14	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	24730	delivery	5	22
62587	2020-05-14 09:38:38	2020-05-14	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24755	delivery	5	39
62588	2020-05-14 09:48:54	2020-05-14	14	[{"id_menu":2,"count":2}]	24736	delivery	5	19
62589	2020-05-14 09:51:23	2020-05-14	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	12827	delivery	5	31
62590	2020-05-14 09:51:53	2020-05-14	12	[{"id_menu":3,"count":1}]	20373	pick-up	0	12
62591	2020-05-14 09:58:08	2020-05-14	17	[{"id_menu":4,"count":1}]	24763	pick-up	0	17
62592	2020-05-14 10:03:06	2020-05-14	9	[{"id_menu":6,"count":1}]	24845	pick-up	0	9
62593	2020-05-14 10:05:00	2020-05-14	9	[{"id_menu":6,"count":1}]	24906	delivery	5	14
62594	2020-05-14 10:09:39	2020-05-14	8	[{"id_menu":5,"count":1}]	4824	delivery	5	13
62595	2020-05-14 10:09:58	2020-05-14	9	[{"id_menu":7,"count":1}]	24779	delivery	5	14
62596	2020-05-14 10:16:12	2020-05-14	12	[{"id_menu":1,"count":1}]	2386	delivery	5	17
62597	2020-05-14 10:17:29	2020-05-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	5712	delivery	5	36
62598	2020-05-14 10:18:01	2020-05-14	9	[{"id_menu":6,"count":1}]	9573	pick-up	0	9
62599	2020-05-14 10:22:47	2020-05-14	12	[{"id_menu":1,"count":2}]	19798	pick-up	0	12
62600	2020-05-14 10:44:54	2020-05-14	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":3}]	23306	delivery	5	26
62601	2020-05-14 10:49:20	2020-05-14	17	[{"id_menu":4,"count":1}]	24814	delivery	5	22
62602	2020-05-14 10:49:47	2020-05-14	14	[{"id_menu":2,"count":1}]	24883	delivery	5	19
62603	2020-05-14 10:49:48	2020-05-14	14	[{"id_menu":2,"count":2}]	2631	pick-up	0	14
62604	2020-05-14 10:50:41	2020-05-14	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	24900	delivery	5	26
62605	2020-05-14 10:51:06	2020-05-14	17	[{"id_menu":4,"count":1}]	24881	delivery	5	22
62606	2020-05-14 10:52:49	2020-05-14	9	[{"id_menu":7,"count":1}]	21334	pick-up	0	9
62607	2020-05-14 10:53:38	2020-05-14	9	[{"id_menu":6,"count":1}]	4415	delivery	5	14
62608	2020-05-14 10:54:47	2020-05-14	12	[{"id_menu":3,"count":1}]	170	pick-up	0	12
62609	2020-05-14 10:57:48	2020-05-14	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	24605	delivery	5	26
62610	2020-05-14 10:57:49	2020-05-14	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	24887	pick-up	0	26
62611	2020-05-14 11:05:31	2020-05-14	9	[{"id_menu":6,"count":1}]	5128	delivery	5	14
62612	2020-05-14 11:12:46	2020-05-14	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24888	delivery	5	37
62613	2020-05-14 11:13:02	2020-05-14	17	[{"id_menu":4,"count":1}]	24750	delivery	5	22
62614	2020-05-14 11:13:14	2020-05-14	17	[{"id_menu":4,"count":1}]	24886	delivery	5	22
62615	2020-05-14 11:14:22	2020-05-14	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	236	pick-up	0	30
62616	2020-05-14 11:16:35	2020-05-14	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	24758	delivery	5	22
62617	2020-05-14 11:16:35	2020-05-14	17	[{"id_menu":4,"count":1}]	24746	delivery	5	22
62618	2020-05-14 11:22:17	2020-05-14	8	[{"id_menu":5,"count":1}]	9264	delivery	5	13
62619	2020-05-14 11:26:11	2020-05-14	8	[{"id_menu":5,"count":1}]	17997	delivery	5	13
62620	2020-05-14 11:28:06	2020-05-14	9	[{"id_menu":6,"count":1}]	13758	delivery	5	14
62621	2020-05-14 11:28:32	2020-05-14	9	[{"id_menu":6,"count":1}]	15604	delivery	5	14
62622	2020-05-14 11:30:28	2020-05-14	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	739	pick-up	0	22
62623	2020-05-14 11:31:33	2020-05-14	12	[{"id_menu":3,"count":1}]	3287	pick-up	0	12
62624	2020-05-14 11:35:26	2020-05-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3730	delivery	5	28
62625	2020-05-14 11:35:30	2020-05-14	12	[{"id_menu":1,"count":1}]	24387	pick-up	0	12
62626	2020-05-14 11:41:36	2020-05-14	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24773	delivery	5	31
62627	2020-05-14 11:43:33	2020-05-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	24579	delivery	5	28
62628	2020-05-14 11:46:37	2020-05-14	9	[{"id_menu":6,"count":1}]	22208	delivery	5	14
62629	2020-05-14 11:57:47	2020-05-14	8	[{"id_menu":5,"count":1}]	5506	pick-up	0	8
62630	2020-05-14 11:58:56	2020-05-14	8	[{"id_menu":5,"count":1}]	9857	pick-up	0	8
62631	2020-05-14 12:00:28	2020-05-14	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10785	pick-up	0	26
62632	2020-05-14 12:02:05	2020-05-14	9	[{"id_menu":6,"count":1}]	24871	delivery	5	14
62633	2020-05-14 12:02:39	2020-05-14	17	[{"id_menu":4,"count":1}]	24879	pick-up	0	17
62634	2020-05-14 12:04:14	2020-05-14	14	[{"id_menu":2,"count":1}]	11743	delivery	5	19
62635	2020-05-14 12:05:39	2020-05-14	12	[{"id_menu":3,"count":1}]	13996	pick-up	0	12
62636	2020-05-14 12:11:49	2020-05-14	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16185	delivery	5	39
62637	2020-05-14 12:17:23	2020-05-14	9	[{"id_menu":6,"count":1}]	20945	delivery	5	14
62638	2020-05-14 12:21:44	2020-05-14	17	[{"id_menu":4,"count":1}]	16829	delivery	5	22
62639	2020-05-14 12:24:28	2020-05-14	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14028	delivery	5	34
62640	2020-05-14 12:26:53	2020-05-14	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22346	delivery	5	35
62641	2020-05-14 12:27:33	2020-05-14	12	[{"id_menu":3,"count":1}]	12527	pick-up	0	12
62642	2020-05-14 12:32:46	2020-05-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24870	delivery	5	22
62643	2020-05-14 12:36:24	2020-05-14	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	24534	pick-up	0	29
62644	2020-05-14 12:39:28	2020-05-14	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3663	delivery	5	45
62645	2020-05-14 12:42:26	2020-05-14	9	[{"id_menu":7,"count":1}]	24896	delivery	5	14
62646	2020-05-14 12:45:39	2020-05-14	14	[{"id_menu":2,"count":1}]	14696	delivery	5	19
62647	2020-05-14 12:52:15	2020-05-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9106	pick-up	0	26
62648	2020-05-14 12:54:55	2020-05-14	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	13004	delivery	5	31
62649	2020-05-14 12:57:41	2020-05-14	14	[{"id_menu":2,"count":1}]	14616	pick-up	0	14
62650	2020-05-14 12:59:49	2020-05-14	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	24800	delivery	5	45
62651	2020-05-14 13:04:46	2020-05-14	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17909	delivery	5	43
62652	2020-05-14 13:06:09	2020-05-14	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	24688	delivery	5	26
62653	2020-05-14 13:06:57	2020-05-14	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	19737	delivery	5	25
62654	2020-05-14 13:11:26	2020-05-14	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	16772	delivery	5	28
62655	2020-05-14 13:16:03	2020-05-14	12	[{"id_menu":1,"count":1}]	24853	pick-up	0	12
62656	2020-05-14 13:17:01	2020-05-14	8	[{"id_menu":5,"count":1}]	13780	delivery	5	13
62657	2020-05-14 13:27:38	2020-05-14	9	[{"id_menu":6,"count":3}]	24863	delivery	5	14
62658	2020-05-14 13:33:00	2020-05-14	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	24785	delivery	5	39
62659	2020-05-14 13:33:27	2020-05-14	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	24902	delivery	5	23
62660	2020-05-14 13:37:16	2020-05-14	55	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3570	delivery	5	60
62661	2020-05-14 13:40:24	2020-05-14	8	[{"id_menu":5,"count":2}]	24865	delivery	5	13
62662	2020-05-14 13:44:11	2020-05-14	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	24731	delivery	5	26
62663	2020-05-14 14:05:22	2020-05-14	55	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	10151	delivery	5	60
62664	2020-05-14 14:13:27	2020-05-14	9	[{"id_menu":7,"count":1}]	2729	delivery	5	14
62665	2020-05-14 14:14:13	2020-05-14	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11488	delivery	5	36
62666	2020-05-14 14:24:50	2020-05-14	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	17415	pick-up	0	18
62667	2020-05-14 14:25:39	2020-05-14	12	[{"id_menu":1,"count":1}]	4652	pick-up	0	12
62668	2020-05-14 14:29:48	2020-05-14	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	24749	delivery	5	31
62669	2020-05-14 14:31:06	2020-05-14	8	[{"id_menu":5,"count":1}]	24601	delivery	5	13
62670	2020-05-14 14:34:25	2020-05-14	12	[{"id_menu":1,"count":1}]	4060	delivery	5	17
62671	2020-05-14 14:38:09	2020-05-14	9	[{"id_menu":6,"count":1}]	585	delivery	5	14
62672	2020-05-14 14:38:14	2020-05-14	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	15662	delivery	5	48
62673	2020-05-14 14:39:49	2020-05-14	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	24778	delivery	5	30
62674	2020-05-14 14:40:33	2020-05-14	9	[{"id_menu":6,"count":1}]	22217	delivery	5	14
62675	2020-05-14 14:40:40	2020-05-14	8	[{"id_menu":5,"count":1}]	24842	delivery	5	13
62676	2020-05-14 14:41:32	2020-05-14	9	[{"id_menu":7,"count":1}]	4034	delivery	5	14
62677	2020-05-14 14:43:06	2020-05-14	17	[{"id_menu":5,"count":3},{"id_menu":6,"count":1}]	12201	delivery	5	22
62678	2020-05-14 14:47:18	2020-05-14	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	8866	delivery	5	26
62679	2020-05-14 14:47:22	2020-05-14	12	[{"id_menu":1,"count":1}]	9995	delivery	5	17
62680	2020-05-14 14:57:46	2020-05-14	14	[{"id_menu":2,"count":1}]	24851	pick-up	0	14
62681	2020-05-14 14:58:59	2020-05-14	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":2}]	24860	delivery	5	28
62682	2020-05-14 15:00:15	2020-05-14	8	[{"id_menu":5,"count":1}]	22711	delivery	5	13
62683	2020-05-14 15:14:02	2020-05-14	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	24852	delivery	5	31
62684	2020-05-14 15:26:05	2020-05-14	9	[{"id_menu":7,"count":3}]	11155	delivery	5	14
62685	2020-05-14 15:26:26	2020-05-14	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	9193	pick-up	0	26
62686	2020-05-14 15:29:52	2020-05-14	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24905	delivery	5	53
62687	2020-05-14 15:33:08	2020-05-14	8	[{"id_menu":5,"count":1}]	5458	delivery	5	13
62688	2020-05-14 15:38:22	2020-05-14	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	7802	delivery	5	26
62689	2020-05-14 15:41:05	2020-05-14	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	24899	delivery	5	57
62690	2020-05-14 15:42:39	2020-05-14	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	787	pick-up	0	21
62691	2020-05-14 15:53:22	2020-05-14	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4931	delivery	5	45
62692	2020-05-14 15:55:51	2020-05-14	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	14991	delivery	5	22
62693	2020-05-14 15:56:36	2020-05-14	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	24815	delivery	5	27
62694	2020-05-14 15:57:04	2020-05-14	14	[{"id_menu":2,"count":1}]	24893	delivery	5	19
62695	2020-05-14 16:00:34	2020-05-14	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1927	delivery	5	27
62696	2020-05-14 16:07:35	2020-05-14	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	24784	delivery	5	26
62697	2020-05-14 16:07:36	2020-05-14	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24743	delivery	5	48
62698	2020-05-14 16:10:10	2020-05-14	8	[{"id_menu":5,"count":1}]	21512	delivery	5	13
62699	2020-05-14 16:14:29	2020-05-14	8	[{"id_menu":5,"count":1}]	14758	delivery	5	13
62700	2020-05-14 16:24:28	2020-05-14	9	[{"id_menu":7,"count":1}]	24864	delivery	5	14
62701	2020-05-14 16:29:20	2020-05-14	14	[{"id_menu":2,"count":1}]	24877	delivery	5	19
62702	2020-05-14 16:30:19	2020-05-14	9	[{"id_menu":7,"count":1}]	23194	delivery	5	14
62703	2020-05-14 16:31:37	2020-05-14	17	[{"id_menu":4,"count":1}]	4486	pick-up	0	17
62704	2020-05-14 16:33:38	2020-05-14	8	[{"id_menu":5,"count":2}]	13041	delivery	5	13
62705	2020-05-14 16:35:01	2020-05-14	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	24796	delivery	5	30
62706	2020-05-14 16:36:26	2020-05-14	8	[{"id_menu":5,"count":1}]	13468	delivery	5	13
62707	2020-05-14 16:37:14	2020-05-14	9	[{"id_menu":7,"count":1}]	24839	delivery	5	14
62708	2020-05-14 16:38:29	2020-05-14	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24735	delivery	5	40
62709	2020-05-14 16:39:20	2020-05-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5588	pick-up	0	17
62710	2020-05-14 16:41:46	2020-05-14	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24747	delivery	5	34
62711	2020-05-14 16:45:17	2020-05-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	20803	delivery	5	22
62712	2020-05-14 16:56:42	2020-05-14	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23204	delivery	5	49
62713	2020-05-14 16:57:28	2020-05-14	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	24791	delivery	5	40
62714	2020-05-14 16:59:06	2020-05-14	14	[{"id_menu":2,"count":1}]	9194	delivery	5	19
62715	2020-05-14 17:00:09	2020-05-14	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22103	delivery	5	22
62716	2020-05-14 17:01:17	2020-05-14	17	[{"id_menu":4,"count":1}]	9846	pick-up	0	17
62717	2020-05-14 17:02:46	2020-05-14	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	4040	pick-up	0	20
62718	2020-05-14 17:05:23	2020-05-14	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20970	pick-up	0	31
62719	2020-05-14 17:05:42	2020-05-14	14	[{"id_menu":2,"count":1}]	343	pick-up	0	14
62720	2020-05-14 17:06:54	2020-05-14	17	[{"id_menu":4,"count":1}]	1409	pick-up	0	17
62721	2020-05-14 17:07:37	2020-05-14	12	[{"id_menu":1,"count":1}]	17906	delivery	5	17
62722	2020-05-14 17:15:39	2020-05-14	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13454	delivery	5	53
62723	2020-05-14 17:16:47	2020-05-14	9	[{"id_menu":6,"count":1}]	2590	delivery	5	14
62724	2020-05-14 17:17:03	2020-05-14	14	[{"id_menu":2,"count":1}]	7746	pick-up	0	14
62725	2020-05-14 17:17:28	2020-05-14	14	[{"id_menu":2,"count":1}]	9453	delivery	5	19
62726	2020-05-14 17:18:32	2020-05-14	14	[{"id_menu":2,"count":1}]	24788	delivery	5	19
62727	2020-05-14 17:19:26	2020-05-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12024	delivery	5	22
62728	2020-05-14 17:21:32	2020-05-14	9	[{"id_menu":7,"count":1}]	24818	delivery	5	14
62729	2020-05-14 17:21:45	2020-05-14	9	[{"id_menu":6,"count":1}]	4017	delivery	5	14
62730	2020-05-14 17:32:10	2020-05-14	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7289	delivery	5	36
62731	2020-05-14 17:35:13	2020-05-14	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	21577	delivery	5	23
62732	2020-05-14 17:40:11	2020-05-14	9	[{"id_menu":7,"count":1}]	22374	delivery	5	14
62733	2020-05-14 17:44:01	2020-05-14	14	[{"id_menu":2,"count":1}]	452	pick-up	0	14
62734	2020-05-14 17:49:46	2020-05-14	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	24105	delivery	5	31
62735	2020-05-14 17:52:55	2020-05-14	9	[{"id_menu":6,"count":1}]	24726	delivery	5	14
62736	2020-05-14 18:02:03	2020-05-14	8	[{"id_menu":5,"count":1}]	24792	delivery	5	13
62737	2020-05-14 18:03:22	2020-05-14	12	[{"id_menu":1,"count":1}]	18057	pick-up	0	12
62738	2020-05-14 18:05:39	2020-05-14	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	4646	delivery	5	39
62739	2020-05-14 18:11:33	2020-05-14	8	[{"id_menu":5,"count":1}]	24762	delivery	5	13
62740	2020-05-14 18:11:38	2020-05-14	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	9682	pick-up	0	33
62741	2020-05-14 18:13:19	2020-05-14	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7086	delivery	5	23
62742	2020-05-14 18:16:55	2020-05-14	12	[{"id_menu":1,"count":1}]	24752	pick-up	0	12
62743	2020-05-14 18:25:45	2020-05-14	14	[{"id_menu":2,"count":1}]	24768	delivery	5	19
62744	2020-05-14 18:28:14	2020-05-14	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	24790	delivery	5	37
62745	2020-05-14 18:35:44	2020-05-14	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10434	delivery	5	36
62746	2020-05-14 18:39:22	2020-05-14	17	[{"id_menu":4,"count":1}]	3113	delivery	5	22
62747	2020-05-14 18:40:44	2020-05-14	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	24898	pick-up	0	43
62748	2020-05-14 18:51:26	2020-05-14	9	[{"id_menu":7,"count":1}]	24802	delivery	5	14
62749	2020-05-14 18:54:09	2020-05-14	14	[{"id_menu":2,"count":1}]	23403	delivery	5	19
62750	2020-05-14 18:56:01	2020-05-14	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24810	delivery	5	39
62751	2020-05-14 19:00:09	2020-05-14	55	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	18177	delivery	5	60
62752	2020-05-14 19:01:27	2020-05-14	14	[{"id_menu":2,"count":1}]	24904	delivery	5	19
62753	2020-05-14 19:12:06	2020-05-14	12	[{"id_menu":3,"count":1}]	24776	delivery	5	17
62754	2020-05-14 19:12:45	2020-05-14	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11834	delivery	5	22
62755	2020-05-14 19:15:41	2020-05-14	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8837	delivery	5	31
62756	2020-05-14 19:15:57	2020-05-14	14	[{"id_menu":2,"count":1}]	14666	pick-up	0	14
62757	2020-05-14 19:18:18	2020-05-14	9	[{"id_menu":6,"count":1}]	24903	delivery	5	14
62758	2020-05-14 19:19:09	2020-05-14	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19813	delivery	5	35
62759	2020-05-14 19:20:22	2020-05-14	17	[{"id_menu":4,"count":1}]	6199	pick-up	0	17
62760	2020-05-14 19:29:01	2020-05-14	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2334	pick-up	0	35
62761	2020-05-14 19:29:17	2020-05-14	9	[{"id_menu":7,"count":1}]	9778	delivery	5	14
62762	2020-05-14 19:29:26	2020-05-14	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	17197	delivery	5	26
62763	2020-05-14 19:38:58	2020-05-14	9	[{"id_menu":6,"count":1}]	24804	delivery	5	14
62764	2020-05-14 19:41:17	2020-05-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9008	pick-up	0	23
62765	2020-05-14 19:42:36	2020-05-14	8	[{"id_menu":5,"count":1}]	8543	pick-up	0	8
62766	2020-05-14 19:48:44	2020-05-14	12	[{"id_menu":1,"count":1}]	3931	delivery	5	17
62767	2020-05-14 19:49:13	2020-05-14	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22864	delivery	5	43
62768	2020-05-14 19:49:46	2020-05-14	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	11456	delivery	5	39
62769	2020-05-14 19:53:33	2020-05-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	10444	delivery	5	28
62770	2020-05-14 19:53:56	2020-05-14	12	[{"id_menu":1,"count":1}]	24868	pick-up	0	12
62771	2020-05-14 19:55:45	2020-05-14	14	[{"id_menu":2,"count":1}]	6845	pick-up	0	14
62772	2020-05-14 19:57:36	2020-05-14	9	[{"id_menu":6,"count":1}]	14391	pick-up	0	9
62773	2020-05-14 20:02:39	2020-05-14	12	[{"id_menu":3,"count":1}]	3845	delivery	5	17
62774	2020-05-14 20:04:19	2020-05-14	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	24740	delivery	5	48
62775	2020-05-14 20:12:47	2020-05-14	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	24783	delivery	5	39
62776	2020-05-14 20:13:30	2020-05-14	14	[{"id_menu":2,"count":1}]	23621	pick-up	0	14
62777	2020-05-14 20:14:07	2020-05-14	9	[{"id_menu":7,"count":1}]	24830	delivery	5	14
62778	2020-05-14 20:21:44	2020-05-14	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	3294	delivery	5	25
62779	2020-05-14 20:21:51	2020-05-14	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	8071	delivery	5	27
62780	2020-05-14 20:22:24	2020-05-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	20357	pick-up	0	31
62781	2020-05-14 20:29:18	2020-05-14	9	[{"id_menu":6,"count":1}]	8877	delivery	5	14
62782	2020-05-14 20:35:47	2020-05-14	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	13501	delivery	5	34
62783	2020-05-14 20:43:12	2020-05-14	9	[{"id_menu":7,"count":1}]	11848	delivery	5	14
62784	2020-05-14 20:46:07	2020-05-14	17	[{"id_menu":4,"count":1}]	24323	delivery	5	22
62785	2020-05-14 20:46:17	2020-05-14	8	[{"id_menu":5,"count":2}]	24797	delivery	5	13
62786	2020-05-14 20:48:00	2020-05-14	14	[{"id_menu":2,"count":2}]	20452	pick-up	0	14
62787	2020-05-14 20:51:09	2020-05-14	14	[{"id_menu":2,"count":1}]	2519	pick-up	0	14
62788	2020-05-14 20:52:12	2020-05-14	9	[{"id_menu":6,"count":1}]	8271	pick-up	0	9
62789	2020-05-14 20:53:28	2020-05-14	9	[{"id_menu":6,"count":1}]	10433	delivery	5	14
62790	2020-05-14 20:53:30	2020-05-14	17	[{"id_menu":4,"count":1}]	16328	delivery	5	22
62791	2020-05-14 20:59:23	2020-05-14	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	24741	delivery	5	57
62792	2020-05-14 21:00:25	2020-05-14	12	[{"id_menu":3,"count":1}]	24781	delivery	5	17
62793	2020-05-14 21:05:24	2020-05-14	9	[{"id_menu":6,"count":1}]	24894	delivery	5	14
62794	2020-05-14 21:10:58	2020-05-14	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	5123	delivery	5	27
62795	2020-05-14 21:14:31	2020-05-14	8	[{"id_menu":5,"count":1}]	12123	delivery	5	13
62796	2020-05-14 21:16:19	2020-05-14	9	[{"id_menu":7,"count":1}]	13984	pick-up	0	9
62797	2020-05-14 21:23:17	2020-05-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	24274	pick-up	0	31
62798	2020-05-14 21:32:59	2020-05-14	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5407	delivery	5	36
62799	2020-05-14 21:40:01	2020-05-14	9	[{"id_menu":7,"count":2}]	7848	pick-up	0	9
62800	2020-05-14 21:49:41	2020-05-14	12	[{"id_menu":1,"count":1}]	24813	delivery	5	17
62801	2020-05-14 21:50:09	2020-05-14	14	[{"id_menu":2,"count":1}]	11588	delivery	5	19
62802	2020-05-14 21:57:06	2020-05-14	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	23990	delivery	5	29
62803	2020-05-14 22:00:30	2020-05-14	9	[{"id_menu":6,"count":1}]	24895	delivery	5	14
62804	2020-05-14 22:02:57	2020-05-14	17	[{"id_menu":4,"count":1}]	24875	pick-up	0	17
62805	2020-05-14 22:04:49	2020-05-14	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24846	delivery	5	34
62806	2020-05-14 22:05:49	2020-05-14	9	[{"id_menu":7,"count":1}]	11634	pick-up	0	9
62807	2020-05-14 22:08:42	2020-05-14	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12598	delivery	5	34
62808	2020-05-14 22:14:31	2020-05-14	9	[{"id_menu":7,"count":1}]	22055	pick-up	0	9
62809	2020-05-14 22:15:04	2020-05-14	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	24849	delivery	5	23
62810	2020-05-14 22:17:17	2020-05-14	12	[{"id_menu":3,"count":2}]	16342	pick-up	0	12
62811	2020-05-14 22:18:35	2020-05-14	17	[{"id_menu":4,"count":1}]	13448	delivery	5	22
62812	2020-05-14 22:19:07	2020-05-14	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12862	delivery	5	22
62813	2020-05-14 22:20:21	2020-05-14	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24757	delivery	5	23
62814	2020-05-14 22:20:41	2020-05-14	14	[{"id_menu":2,"count":1}]	23963	pick-up	0	14
62815	2020-05-14 22:30:18	2020-05-14	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	12294	delivery	5	26
62816	2020-05-14 22:39:44	2020-05-14	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	24824	delivery	5	43
62817	2020-05-14 22:45:49	2020-05-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	24753	delivery	5	28
62818	2020-05-14 22:51:46	2020-05-14	17	[{"id_menu":4,"count":1}]	22207	delivery	5	22
62819	2020-05-14 22:54:59	2020-05-14	12	[{"id_menu":3,"count":1}]	22872	delivery	5	17
62820	2020-05-14 22:57:50	2020-05-14	9	[{"id_menu":6,"count":1}]	23205	delivery	5	14
62821	2020-05-14 23:05:19	2020-05-14	14	[{"id_menu":2,"count":1}]	24823	delivery	5	19
62822	2020-05-14 23:10:32	2020-05-14	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	5722	delivery	5	28
62823	2020-05-14 23:11:35	2020-05-14	17	[{"id_menu":4,"count":1}]	24850	delivery	5	22
62824	2020-05-14 23:18:15	2020-05-14	14	[{"id_menu":2,"count":1}]	6645	pick-up	0	14
62825	2020-05-14 23:22:33	2020-05-14	14	[{"id_menu":2,"count":1}]	11189	pick-up	0	14
62826	2020-05-14 23:26:40	2020-05-14	9	[{"id_menu":6,"count":1}]	24742	delivery	5	14
62827	2020-05-14 23:26:42	2020-05-14	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	16134	delivery	5	40
62828	2020-05-14 23:30:20	2020-05-14	8	[{"id_menu":5,"count":1}]	23107	delivery	5	13
62829	2020-05-14 23:32:24	2020-05-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	757	pick-up	0	31
62830	2020-05-14 23:36:57	2020-05-14	9	[{"id_menu":7,"count":1}]	24827	delivery	5	14
62831	2020-05-14 23:38:19	2020-05-14	17	[{"id_menu":4,"count":1}]	24732	delivery	5	22
62832	2020-05-14 23:39:57	2020-05-14	17	[{"id_menu":4,"count":1}]	12630	delivery	5	22
62833	2020-05-14 23:40:12	2020-05-14	9	[{"id_menu":7,"count":1}]	5325	delivery	5	14
62834	2020-05-14 23:44:49	2020-05-14	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5829	pick-up	0	52
62835	2020-05-14 23:45:56	2020-05-14	9	[{"id_menu":6,"count":1}]	24856	delivery	5	14
62836	2020-05-14 23:47:50	2020-05-14	9	[{"id_menu":7,"count":1}]	16302	pick-up	0	9
62837	2020-05-14 23:50:24	2020-05-14	12	[{"id_menu":3,"count":1}]	24838	delivery	5	17
62838	2020-05-14 23:50:58	2020-05-14	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	13548	pick-up	0	29
62839	2020-05-14 23:51:08	2020-05-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	24789	delivery	5	31
62840	2020-05-15 00:00:01	2020-05-15	12	[{"id_menu":1,"count":1}]	24971	delivery	5	17
62841	2020-05-15 00:01:21	2020-05-15	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25039	delivery	5	31
62842	2020-05-15 00:01:43	2020-05-15	8	[{"id_menu":5,"count":1}]	2728	pick-up	0	8
62843	2020-05-15 00:05:36	2020-05-15	12	[{"id_menu":1,"count":1}]	17290	delivery	5	17
62844	2020-05-15 00:07:24	2020-05-15	12	[{"id_menu":3,"count":1}]	25009	delivery	5	17
62845	2020-05-15 00:07:26	2020-05-15	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	14475	delivery	5	35
62846	2020-05-15 00:09:36	2020-05-15	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2762	pick-up	0	29
62847	2020-05-15 00:12:00	2020-05-15	17	[{"id_menu":4,"count":1}]	25047	delivery	5	22
62848	2020-05-15 00:16:25	2020-05-15	14	[{"id_menu":2,"count":1}]	12618	delivery	5	19
62849	2020-05-15 00:17:07	2020-05-15	14	[{"id_menu":2,"count":1}]	371	pick-up	0	14
62850	2020-05-15 00:19:53	2020-05-15	9	[{"id_menu":6,"count":1}]	5240	pick-up	0	9
62851	2020-05-15 00:25:17	2020-05-15	14	[{"id_menu":2,"count":1}]	1356	pick-up	0	14
62852	2020-05-15 00:34:38	2020-05-15	8	[{"id_menu":5,"count":1}]	24957	delivery	5	13
62853	2020-05-15 00:39:20	2020-05-15	8	[{"id_menu":5,"count":1}]	4948	delivery	5	13
62854	2020-05-15 00:40:31	2020-05-15	9	[{"id_menu":6,"count":1}]	24948	delivery	5	14
62855	2020-05-15 00:44:33	2020-05-15	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	13776	delivery	5	43
62856	2020-05-15 00:44:41	2020-05-15	9	[{"id_menu":6,"count":1}]	2959	pick-up	0	9
62857	2020-05-15 00:51:04	2020-05-15	14	[{"id_menu":2,"count":1}]	24927	delivery	5	19
62858	2020-05-15 00:54:07	2020-05-15	9	[{"id_menu":7,"count":1}]	24966	delivery	5	14
62859	2020-05-15 00:56:28	2020-05-15	9	[{"id_menu":7,"count":1}]	25091	delivery	5	14
62860	2020-05-15 00:56:54	2020-05-15	17	[{"id_menu":4,"count":1}]	25012	delivery	5	22
62861	2020-05-15 00:58:48	2020-05-15	9	[{"id_menu":6,"count":1}]	21531	delivery	5	14
62862	2020-05-15 00:59:50	2020-05-15	9	[{"id_menu":7,"count":1}]	25046	delivery	5	14
62863	2020-05-15 01:04:39	2020-05-15	9	[{"id_menu":6,"count":1}]	24956	delivery	5	14
62864	2020-05-15 01:04:50	2020-05-15	55	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	25040	delivery	5	60
62865	2020-05-15 01:05:41	2020-05-15	9	[{"id_menu":7,"count":1}]	22320	pick-up	0	9
62866	2020-05-15 01:12:21	2020-05-15	8	[{"id_menu":5,"count":1}]	13783	delivery	5	13
62867	2020-05-15 01:14:35	2020-05-15	17	[{"id_menu":4,"count":1}]	24994	pick-up	0	17
62868	2020-05-15 01:15:52	2020-05-15	9	[{"id_menu":6,"count":1}]	25053	pick-up	0	9
62869	2020-05-15 01:16:19	2020-05-15	9	[{"id_menu":7,"count":1}]	21803	delivery	5	14
62870	2020-05-15 01:26:05	2020-05-15	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	24928	delivery	5	43
62871	2020-05-15 01:36:51	2020-05-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	20302	delivery	5	31
62872	2020-05-15 01:41:06	2020-05-15	8	[{"id_menu":5,"count":1}]	23949	delivery	5	13
62873	2020-05-15 01:43:30	2020-05-15	12	[{"id_menu":1,"count":1}]	7020	delivery	5	17
62874	2020-05-15 01:46:42	2020-05-15	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	25037	delivery	5	34
62875	2020-05-15 01:49:10	2020-05-15	9	[{"id_menu":7,"count":1}]	1871	delivery	5	14
62876	2020-05-15 01:49:12	2020-05-15	8	[{"id_menu":5,"count":1}]	25083	delivery	5	13
62877	2020-05-15 01:51:54	2020-05-15	12	[{"id_menu":3,"count":1}]	6494	delivery	5	17
62878	2020-05-15 01:58:13	2020-05-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	14213	delivery	5	28
62879	2020-05-15 02:09:10	2020-05-15	17	[{"id_menu":4,"count":2}]	3961	pick-up	0	17
62880	2020-05-15 02:12:21	2020-05-15	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3041	delivery	5	44
62881	2020-05-15 02:12:37	2020-05-15	14	[{"id_menu":2,"count":1}]	25000	delivery	5	19
62882	2020-05-15 02:16:12	2020-05-15	17	[{"id_menu":4,"count":1}]	16747	delivery	5	22
62883	2020-05-15 02:16:26	2020-05-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	527	pick-up	0	23
62884	2020-05-15 02:18:48	2020-05-15	12	[{"id_menu":3,"count":1}]	24955	delivery	5	17
62885	2020-05-15 02:21:31	2020-05-15	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	20200	delivery	5	40
62886	2020-05-15 02:24:13	2020-05-15	8	[{"id_menu":5,"count":1}]	25032	delivery	5	13
62887	2020-05-15 02:24:41	2020-05-15	9	[{"id_menu":6,"count":1}]	25073	delivery	5	14
62888	2020-05-15 02:28:40	2020-05-15	29	[{"id_menu":3,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8379	delivery	5	34
62889	2020-05-15 02:37:54	2020-05-15	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	17691	pick-up	0	21
62890	2020-05-15 02:40:53	2020-05-15	12	[{"id_menu":3,"count":1}]	6139	delivery	5	17
62891	2020-05-15 02:41:43	2020-05-15	9	[{"id_menu":7,"count":1}]	15585	delivery	5	14
62892	2020-05-15 02:44:40	2020-05-15	9	[{"id_menu":6,"count":1}]	20207	delivery	5	14
62893	2020-05-15 02:44:45	2020-05-15	8	[{"id_menu":5,"count":1}]	13465	delivery	5	13
62894	2020-05-15 02:46:24	2020-05-15	8	[{"id_menu":5,"count":1}]	19149	delivery	5	13
62895	2020-05-15 02:57:13	2020-05-15	9	[{"id_menu":6,"count":1}]	2855	pick-up	0	9
62896	2020-05-15 02:59:26	2020-05-15	8	[{"id_menu":5,"count":1}]	24943	pick-up	0	8
62897	2020-05-15 03:02:14	2020-05-15	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24917	delivery	5	31
62898	2020-05-15 03:04:15	2020-05-15	9	[{"id_menu":6,"count":1}]	24921	delivery	5	14
62899	2020-05-15 03:06:32	2020-05-15	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11383	pick-up	0	38
62900	2020-05-15 03:07:36	2020-05-15	17	[{"id_menu":4,"count":2}]	7027	delivery	5	22
62901	2020-05-15 03:16:30	2020-05-15	9	[{"id_menu":6,"count":1}]	24974	delivery	5	14
62902	2020-05-15 03:16:51	2020-05-15	9	[{"id_menu":6,"count":1}]	14553	delivery	5	14
62903	2020-05-15 03:23:51	2020-05-15	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	24908	delivery	5	57
62904	2020-05-15 03:26:50	2020-05-15	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	19566	delivery	5	25
62905	2020-05-15 03:27:54	2020-05-15	8	[{"id_menu":5,"count":1}]	24918	delivery	5	13
62906	2020-05-15 03:28:43	2020-05-15	8	[{"id_menu":5,"count":1}]	13162	delivery	5	13
62907	2020-05-15 03:30:27	2020-05-15	9	[{"id_menu":6,"count":1}]	1038	delivery	5	14
62908	2020-05-15 03:35:38	2020-05-15	12	[{"id_menu":3,"count":2}]	12094	delivery	5	17
62909	2020-05-15 03:37:01	2020-05-15	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	23188	delivery	5	38
62910	2020-05-15 03:38:44	2020-05-15	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	21893	delivery	5	48
62911	2020-05-15 03:39:41	2020-05-15	9	[{"id_menu":6,"count":1}]	3606	pick-up	0	9
62912	2020-05-15 03:42:35	2020-05-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24946	delivery	5	23
62913	2020-05-15 03:49:21	2020-05-15	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	25051	delivery	5	22
62914	2020-05-15 03:49:25	2020-05-15	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	23767	delivery	5	40
62915	2020-05-15 03:56:04	2020-05-15	9	[{"id_menu":6,"count":1}]	7305	delivery	5	14
62916	2020-05-15 03:56:58	2020-05-15	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9761	delivery	5	34
62917	2020-05-15 03:57:47	2020-05-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	456	delivery	5	28
62918	2020-05-15 04:01:29	2020-05-15	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	9073	delivery	5	46
62919	2020-05-15 04:05:10	2020-05-15	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24995	delivery	5	37
62920	2020-05-15 04:12:44	2020-05-15	9	[{"id_menu":6,"count":1}]	3684	delivery	5	14
62921	2020-05-15 04:22:43	2020-05-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11054	delivery	5	31
62922	2020-05-15 04:24:27	2020-05-15	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	7119	delivery	5	27
62923	2020-05-15 04:29:02	2020-05-15	17	[{"id_menu":4,"count":1}]	2933	pick-up	0	17
62924	2020-05-15 04:32:31	2020-05-15	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	11401	pick-up	0	29
62925	2020-05-15 04:42:34	2020-05-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20524	delivery	5	23
62926	2020-05-15 04:43:36	2020-05-15	9	[{"id_menu":6,"count":1}]	10633	delivery	5	14
62927	2020-05-15 04:44:46	2020-05-15	14	[{"id_menu":2,"count":1}]	15184	delivery	5	19
62928	2020-05-15 04:44:49	2020-05-15	9	[{"id_menu":7,"count":1}]	18148	delivery	5	14
62929	2020-05-15 04:45:00	2020-05-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4133	delivery	5	28
62930	2020-05-15 04:45:56	2020-05-15	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	25078	delivery	5	43
62931	2020-05-15 04:48:17	2020-05-15	9	[{"id_menu":7,"count":2}]	10558	delivery	5	14
62932	2020-05-15 04:48:25	2020-05-15	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	12623	delivery	5	26
62933	2020-05-15 04:49:27	2020-05-15	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	15321	delivery	5	22
62934	2020-05-15 04:53:26	2020-05-15	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19813	delivery	5	22
62935	2020-05-15 04:53:32	2020-05-15	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	21496	delivery	5	31
62936	2020-05-15 04:53:42	2020-05-15	12	[{"id_menu":3,"count":1}]	16182	delivery	5	17
62937	2020-05-15 05:08:52	2020-05-15	14	[{"id_menu":2,"count":1}]	7612	delivery	5	19
62938	2020-05-15 05:12:10	2020-05-15	9	[{"id_menu":7,"count":1}]	24939	delivery	5	14
62939	2020-05-15 05:19:32	2020-05-15	12	[{"id_menu":1,"count":1}]	23648	delivery	5	17
62940	2020-05-15 05:25:58	2020-05-15	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24981	delivery	5	35
62941	2020-05-15 05:32:51	2020-05-15	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	20723	delivery	5	31
62942	2020-05-15 05:35:53	2020-05-15	8	[{"id_menu":5,"count":1}]	24919	delivery	5	13
62943	2020-05-15 05:37:57	2020-05-15	9	[{"id_menu":7,"count":1}]	18679	pick-up	0	9
62944	2020-05-15 05:40:27	2020-05-15	12	[{"id_menu":3,"count":1}]	19302	delivery	5	17
62945	2020-05-15 05:43:43	2020-05-15	12	[{"id_menu":1,"count":1}]	24926	delivery	5	17
62946	2020-05-15 05:46:08	2020-05-15	14	[{"id_menu":2,"count":1}]	23477	delivery	5	19
62947	2020-05-15 05:46:16	2020-05-15	14	[{"id_menu":2,"count":1}]	4644	pick-up	0	14
62948	2020-05-15 05:46:50	2020-05-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24949	delivery	5	23
62949	2020-05-15 05:47:23	2020-05-15	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	8880	delivery	5	22
62950	2020-05-15 05:49:05	2020-05-15	9	[{"id_menu":7,"count":2}]	3755	pick-up	0	9
62951	2020-05-15 05:56:10	2020-05-15	14	[{"id_menu":2,"count":1}]	25044	delivery	5	19
62952	2020-05-15 05:56:22	2020-05-15	14	[{"id_menu":2,"count":1}]	25041	delivery	5	19
62953	2020-05-15 06:11:53	2020-05-15	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	25058	pick-up	0	26
62954	2020-05-15 06:16:56	2020-05-15	9	[{"id_menu":7,"count":1}]	19042	pick-up	0	9
62955	2020-05-15 06:24:13	2020-05-15	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24998	delivery	5	34
62956	2020-05-15 06:24:27	2020-05-15	9	[{"id_menu":7,"count":1}]	18051	delivery	5	14
62957	2020-05-15 06:28:13	2020-05-15	9	[{"id_menu":6,"count":1}]	2761	delivery	5	14
62958	2020-05-15 06:30:32	2020-05-15	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	3444	pick-up	0	24
62959	2020-05-15 06:42:43	2020-05-15	8	[{"id_menu":5,"count":1}]	25094	delivery	5	13
62960	2020-05-15 06:46:24	2020-05-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	9779	delivery	5	28
62961	2020-05-15 06:48:55	2020-05-15	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	17332	delivery	5	23
62962	2020-05-15 06:49:06	2020-05-15	17	[{"id_menu":4,"count":1}]	24959	delivery	5	22
62963	2020-05-15 06:53:33	2020-05-15	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15085	delivery	5	31
62964	2020-05-15 06:53:47	2020-05-15	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	21483	pick-up	0	25
62965	2020-05-15 06:54:46	2020-05-15	17	[{"id_menu":4,"count":1}]	22383	delivery	5	22
62966	2020-05-15 06:54:50	2020-05-15	12	[{"id_menu":1,"count":1}]	25093	delivery	5	17
62967	2020-05-15 06:55:54	2020-05-15	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	24953	pick-up	0	31
62968	2020-05-15 06:58:03	2020-05-15	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	25022	delivery	5	28
62969	2020-05-15 06:58:54	2020-05-15	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	25069	delivery	5	36
62970	2020-05-15 07:02:48	2020-05-15	14	[{"id_menu":2,"count":2}]	24950	delivery	5	19
62971	2020-05-15 07:03:09	2020-05-15	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12286	delivery	5	43
62972	2020-05-15 07:05:14	2020-05-15	17	[{"id_menu":4,"count":1}]	24932	delivery	5	22
62973	2020-05-15 07:06:48	2020-05-15	8	[{"id_menu":5,"count":1}]	25089	pick-up	0	8
62974	2020-05-15 07:18:40	2020-05-15	9	[{"id_menu":6,"count":1}]	255	delivery	5	14
62975	2020-05-15 07:19:11	2020-05-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	7675	delivery	5	31
62976	2020-05-15 07:19:18	2020-05-15	9	[{"id_menu":6,"count":1}]	25088	pick-up	0	9
62977	2020-05-15 07:19:32	2020-05-15	9	[{"id_menu":6,"count":1}]	24986	delivery	5	14
62978	2020-05-15 07:22:38	2020-05-15	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18330	delivery	5	40
62979	2020-05-15 07:25:30	2020-05-15	8	[{"id_menu":5,"count":1}]	24987	delivery	5	13
62980	2020-05-15 07:28:49	2020-05-15	14	[{"id_menu":2,"count":1}]	1263	pick-up	0	14
62981	2020-05-15 07:32:30	2020-05-15	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	20506	delivery	5	26
62982	2020-05-15 07:34:27	2020-05-15	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25070	delivery	5	35
62983	2020-05-15 07:37:42	2020-05-15	9	[{"id_menu":6,"count":1}]	25066	delivery	5	14
62984	2020-05-15 07:40:31	2020-05-15	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	22597	delivery	5	34
62985	2020-05-15 07:45:29	2020-05-15	17	[{"id_menu":4,"count":1}]	1313	pick-up	0	17
62986	2020-05-15 07:51:03	2020-05-15	17	[{"id_menu":4,"count":1}]	6410	pick-up	0	17
62987	2020-05-15 07:53:39	2020-05-15	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24983	delivery	5	22
62988	2020-05-15 07:54:53	2020-05-15	17	[{"id_menu":4,"count":1}]	1461	delivery	5	22
62989	2020-05-15 08:01:35	2020-05-15	9	[{"id_menu":6,"count":1}]	2590	pick-up	0	9
62990	2020-05-15 08:04:50	2020-05-15	9	[{"id_menu":7,"count":1}]	13984	pick-up	0	9
62991	2020-05-15 08:06:20	2020-05-15	12	[{"id_menu":1,"count":1}]	3000	pick-up	0	12
62992	2020-05-15 08:08:34	2020-05-15	12	[{"id_menu":3,"count":1}]	3339	delivery	5	17
62993	2020-05-15 08:15:13	2020-05-15	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	15359	delivery	5	28
62994	2020-05-15 08:16:44	2020-05-15	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	8102	delivery	5	31
62995	2020-05-15 08:25:46	2020-05-15	14	[{"id_menu":2,"count":1}]	7688	pick-up	0	14
62996	2020-05-15 08:26:19	2020-05-15	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17610	delivery	5	45
62997	2020-05-15 08:30:51	2020-05-15	12	[{"id_menu":3,"count":1}]	2890	pick-up	0	12
62998	2020-05-15 08:35:46	2020-05-15	14	[{"id_menu":2,"count":1}]	2614	pick-up	0	14
62999	2020-05-15 08:39:35	2020-05-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25067	delivery	5	23
63000	2020-05-15 08:47:00	2020-05-15	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25003	delivery	5	48
63001	2020-05-15 08:48:03	2020-05-15	8	[{"id_menu":5,"count":1}]	24923	delivery	5	13
63002	2020-05-15 08:51:42	2020-05-15	12	[{"id_menu":3,"count":1}]	25057	delivery	5	17
63003	2020-05-15 08:55:37	2020-05-15	12	[{"id_menu":3,"count":1}]	5077	delivery	5	17
63004	2020-05-15 08:57:16	2020-05-15	9	[{"id_menu":6,"count":1}]	1065	pick-up	0	9
63005	2020-05-15 08:58:32	2020-05-15	14	[{"id_menu":2,"count":1}]	3940	delivery	5	19
63006	2020-05-15 08:58:46	2020-05-15	12	[{"id_menu":3,"count":1}]	8706	pick-up	0	12
63007	2020-05-15 09:12:04	2020-05-15	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	24912	delivery	5	31
63008	2020-05-15 09:14:52	2020-05-15	9	[{"id_menu":7,"count":1}]	23023	delivery	5	14
63009	2020-05-15 09:18:16	2020-05-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	24985	delivery	5	28
63010	2020-05-15 09:21:01	2020-05-15	17	[{"id_menu":4,"count":1}]	826	pick-up	0	17
63011	2020-05-15 09:22:49	2020-05-15	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	7361	delivery	5	25
63012	2020-05-15 09:24:55	2020-05-15	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	24996	pick-up	0	17
63013	2020-05-15 09:36:08	2020-05-15	9	[{"id_menu":6,"count":1}]	19000	delivery	5	14
63014	2020-05-15 09:40:09	2020-05-15	9	[{"id_menu":6,"count":1}]	25024	pick-up	0	9
63015	2020-05-15 09:42:36	2020-05-15	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	3823	delivery	5	36
63016	2020-05-15 09:43:41	2020-05-15	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19488	delivery	5	37
63017	2020-05-15 09:44:29	2020-05-15	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13375	delivery	5	35
63018	2020-05-15 09:50:34	2020-05-15	14	[{"id_menu":2,"count":1}]	11216	delivery	5	19
63019	2020-05-15 10:03:26	2020-05-15	9	[{"id_menu":6,"count":1}]	24916	delivery	5	14
63020	2020-05-15 10:04:06	2020-05-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4132	pick-up	0	23
63021	2020-05-15 10:05:03	2020-05-15	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	3887	delivery	5	36
63022	2020-05-15 10:06:37	2020-05-15	9	[{"id_menu":7,"count":1}]	25011	delivery	5	14
63023	2020-05-15 10:07:36	2020-05-15	8	[{"id_menu":5,"count":1}]	7118	pick-up	0	8
63024	2020-05-15 10:08:12	2020-05-15	17	[{"id_menu":4,"count":1}]	18744	pick-up	0	17
63025	2020-05-15 10:08:25	2020-05-15	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	11298	delivery	5	26
63026	2020-05-15 10:10:12	2020-05-15	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	24969	delivery	5	31
63027	2020-05-15 10:10:16	2020-05-15	14	[{"id_menu":2,"count":1}]	125	pick-up	0	14
63028	2020-05-15 10:10:31	2020-05-15	17	[{"id_menu":4,"count":1}]	7339	pick-up	0	17
63029	2020-05-15 10:13:59	2020-05-15	8	[{"id_menu":5,"count":1}]	25079	delivery	5	13
63030	2020-05-15 10:14:07	2020-05-15	9	[{"id_menu":7,"count":1}]	13105	delivery	5	14
63031	2020-05-15 10:16:01	2020-05-15	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	23046	pick-up	0	21
63032	2020-05-15 10:17:25	2020-05-15	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	25021	pick-up	0	22
63033	2020-05-15 10:18:29	2020-05-15	17	[{"id_menu":4,"count":1}]	2065	pick-up	0	17
63034	2020-05-15 10:20:40	2020-05-15	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	21018	delivery	5	36
63035	2020-05-15 10:20:56	2020-05-15	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	23729	pick-up	0	31
63036	2020-05-15 10:26:01	2020-05-15	9	[{"id_menu":6,"count":1}]	25005	delivery	5	14
63037	2020-05-15 10:29:49	2020-05-15	8	[{"id_menu":5,"count":1}]	2627	delivery	5	13
63038	2020-05-15 10:31:00	2020-05-15	8	[{"id_menu":5,"count":1}]	10026	delivery	5	13
63039	2020-05-15 10:31:08	2020-05-15	14	[{"id_menu":2,"count":1}]	8303	pick-up	0	14
63040	2020-05-15 10:31:30	2020-05-15	9	[{"id_menu":6,"count":1}]	25017	delivery	5	14
63041	2020-05-15 10:34:45	2020-05-15	9	[{"id_menu":6,"count":1}]	281	pick-up	0	9
63042	2020-05-15 10:38:07	2020-05-15	12	[{"id_menu":1,"count":1}]	24979	delivery	5	17
63043	2020-05-15 10:38:50	2020-05-15	8	[{"id_menu":5,"count":1}]	24984	delivery	5	13
63044	2020-05-15 10:46:00	2020-05-15	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	13303	delivery	5	25
63045	2020-05-15 10:46:06	2020-05-15	12	[{"id_menu":1,"count":1}]	3805	delivery	5	17
63046	2020-05-15 10:54:41	2020-05-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3825	pick-up	0	26
63047	2020-05-15 10:54:45	2020-05-15	12	[{"id_menu":1,"count":1}]	25087	delivery	5	17
63048	2020-05-15 10:54:56	2020-05-15	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	2889	pick-up	0	24
63049	2020-05-15 10:55:40	2020-05-15	14	[{"id_menu":2,"count":1}]	3567	pick-up	0	14
63050	2020-05-15 10:56:05	2020-05-15	8	[{"id_menu":5,"count":1}]	5964	delivery	5	13
63051	2020-05-15 10:59:45	2020-05-15	14	[{"id_menu":2,"count":1}]	21451	delivery	5	19
63052	2020-05-15 11:02:15	2020-05-15	17	[{"id_menu":4,"count":1}]	14695	delivery	5	22
63053	2020-05-15 11:05:52	2020-05-15	9	[{"id_menu":7,"count":1}]	3785	pick-up	0	9
63054	2020-05-15 11:07:26	2020-05-15	14	[{"id_menu":2,"count":1}]	25064	delivery	5	19
63055	2020-05-15 11:09:24	2020-05-15	8	[{"id_menu":5,"count":1}]	25013	delivery	5	13
63056	2020-05-15 11:09:45	2020-05-15	9	[{"id_menu":7,"count":1}]	11471	delivery	5	14
63057	2020-05-15 11:09:59	2020-05-15	9	[{"id_menu":7,"count":1}]	1457	delivery	5	14
63058	2020-05-15 11:15:52	2020-05-15	12	[{"id_menu":1,"count":1}]	24041	pick-up	0	12
63059	2020-05-15 11:16:43	2020-05-15	14	[{"id_menu":2,"count":1}]	1297	delivery	5	19
63060	2020-05-15 11:19:18	2020-05-15	8	[{"id_menu":5,"count":1}]	24930	delivery	5	13
63061	2020-05-15 11:19:39	2020-05-15	12	[{"id_menu":1,"count":2}]	601	pick-up	0	12
63062	2020-05-15 11:25:10	2020-05-15	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	25031	delivery	5	26
63063	2020-05-15 11:32:24	2020-05-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8011	delivery	5	31
63064	2020-05-15 11:34:10	2020-05-15	9	[{"id_menu":7,"count":1}]	25035	delivery	5	14
63065	2020-05-15 11:36:46	2020-05-15	8	[{"id_menu":5,"count":1}]	24967	delivery	5	13
63066	2020-05-15 11:37:49	2020-05-15	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1635	delivery	5	36
63067	2020-05-15 11:42:34	2020-05-15	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	25072	delivery	5	34
63068	2020-05-15 11:44:02	2020-05-15	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7982	delivery	5	22
63069	2020-05-15 11:45:54	2020-05-15	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	25080	delivery	5	40
63070	2020-05-15 11:46:42	2020-05-15	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	25060	delivery	5	34
63071	2020-05-15 11:47:30	2020-05-15	14	[{"id_menu":2,"count":1}]	25029	delivery	5	19
63072	2020-05-15 11:51:06	2020-05-15	9	[{"id_menu":6,"count":1}]	24999	delivery	5	14
63073	2020-05-15 11:53:50	2020-05-15	9	[{"id_menu":6,"count":1}]	17212	delivery	5	14
63074	2020-05-15 11:54:29	2020-05-15	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24965	delivery	5	36
63075	2020-05-15 11:58:00	2020-05-15	9	[{"id_menu":6,"count":1}]	3736	delivery	5	14
63076	2020-05-15 12:00:36	2020-05-15	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	25007	delivery	5	31
63077	2020-05-15 12:01:12	2020-05-15	9	[{"id_menu":6,"count":1}]	81	pick-up	0	9
63078	2020-05-15 12:02:49	2020-05-15	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13547	pick-up	0	17
63079	2020-05-15 12:03:46	2020-05-15	14	[{"id_menu":2,"count":1}]	24964	pick-up	0	14
63080	2020-05-15 12:04:14	2020-05-15	9	[{"id_menu":6,"count":1}]	1592	pick-up	0	9
63081	2020-05-15 12:04:20	2020-05-15	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	18280	delivery	5	31
63082	2020-05-15 12:05:13	2020-05-15	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24980	pick-up	0	29
63083	2020-05-15 12:07:53	2020-05-15	8	[{"id_menu":5,"count":1}]	12063	delivery	5	13
63084	2020-05-15 12:08:07	2020-05-15	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	17046	delivery	5	29
63085	2020-05-15 12:12:44	2020-05-15	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18505	delivery	5	35
63086	2020-05-15 12:19:02	2020-05-15	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	24962	delivery	5	30
63087	2020-05-15 12:24:14	2020-05-15	12	[{"id_menu":1,"count":1}]	25004	delivery	5	17
63088	2020-05-15 12:25:15	2020-05-15	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20182	delivery	5	43
63089	2020-05-15 12:28:04	2020-05-15	14	[{"id_menu":2,"count":1}]	2917	pick-up	0	14
63090	2020-05-15 12:36:45	2020-05-15	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24392	delivery	5	31
63091	2020-05-15 12:46:03	2020-05-15	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	24945	delivery	5	26
63092	2020-05-15 12:47:50	2020-05-15	12	[{"id_menu":3,"count":2}]	1563	pick-up	0	12
63093	2020-05-15 12:51:08	2020-05-15	12	[{"id_menu":3,"count":1}]	2771	pick-up	0	12
63094	2020-05-15 12:52:33	2020-05-15	17	[{"id_menu":4,"count":1}]	4156	pick-up	0	17
63095	2020-05-15 12:56:04	2020-05-15	9	[{"id_menu":7,"count":1}]	25027	delivery	5	14
63096	2020-05-15 12:57:10	2020-05-15	12	[{"id_menu":1,"count":1}]	19883	delivery	5	17
63097	2020-05-15 12:58:07	2020-05-15	14	[{"id_menu":2,"count":1}]	24938	delivery	5	19
63098	2020-05-15 13:00:26	2020-05-15	9	[{"id_menu":7,"count":1}]	245	pick-up	0	9
63099	2020-05-15 13:17:45	2020-05-15	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	6232	pick-up	0	21
63100	2020-05-15 13:21:11	2020-05-15	8	[{"id_menu":5,"count":1}]	24990	delivery	5	13
63101	2020-05-15 13:24:55	2020-05-15	14	[{"id_menu":2,"count":1}]	8311	delivery	5	19
63102	2020-05-15 13:29:40	2020-05-15	9	[{"id_menu":7,"count":1}]	8702	delivery	5	14
63103	2020-05-15 13:32:19	2020-05-15	12	[{"id_menu":3,"count":1}]	8466	delivery	5	17
63104	2020-05-15 13:38:37	2020-05-15	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2492	pick-up	0	21
63105	2020-05-15 13:41:58	2020-05-15	12	[{"id_menu":1,"count":1}]	18428	pick-up	0	12
63106	2020-05-15 13:47:02	2020-05-15	14	[{"id_menu":2,"count":1}]	10296	delivery	5	19
63107	2020-05-15 13:53:56	2020-05-15	17	[{"id_menu":4,"count":1}]	13037	delivery	5	22
63108	2020-05-15 13:55:40	2020-05-15	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	22890	delivery	5	22
63109	2020-05-15 14:00:27	2020-05-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	17594	pick-up	0	18
63110	2020-05-15 14:08:29	2020-05-15	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	24924	delivery	5	45
63111	2020-05-15 14:09:23	2020-05-15	14	[{"id_menu":2,"count":1}]	19276	pick-up	0	14
63112	2020-05-15 14:13:35	2020-05-15	14	[{"id_menu":2,"count":1}]	340	delivery	5	19
63113	2020-05-15 14:17:58	2020-05-15	9	[{"id_menu":6,"count":1}]	12412	delivery	5	14
63114	2020-05-15 14:18:02	2020-05-15	17	[{"id_menu":4,"count":1}]	25002	delivery	5	22
63115	2020-05-15 14:19:32	2020-05-15	9	[{"id_menu":6,"count":1}]	25056	delivery	5	14
63116	2020-05-15 14:22:33	2020-05-15	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	16627	pick-up	0	35
63117	2020-05-15 14:22:50	2020-05-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	25016	delivery	5	31
63118	2020-05-15 14:35:49	2020-05-15	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24991	pick-up	0	34
63119	2020-05-15 14:39:15	2020-05-15	14	[{"id_menu":2,"count":1}]	25026	delivery	5	19
63120	2020-05-15 14:50:03	2020-05-15	17	[{"id_menu":4,"count":1}]	25063	delivery	5	22
63121	2020-05-15 14:58:04	2020-05-15	9	[{"id_menu":6,"count":1}]	1252	delivery	5	14
63122	2020-05-15 14:58:56	2020-05-15	9	[{"id_menu":6,"count":1}]	9912	pick-up	0	9
63123	2020-05-15 15:00:07	2020-05-15	12	[{"id_menu":1,"count":1}]	8229	pick-up	0	12
63124	2020-05-15 15:05:03	2020-05-15	9	[{"id_menu":6,"count":1}]	10240	delivery	5	14
63125	2020-05-15 15:13:08	2020-05-15	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	22311	delivery	5	31
63126	2020-05-15 15:13:35	2020-05-15	12	[{"id_menu":3,"count":1}]	24925	pick-up	0	12
63127	2020-05-15 15:17:00	2020-05-15	12	[{"id_menu":3,"count":1}]	25045	delivery	5	17
63128	2020-05-15 15:17:40	2020-05-15	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25084	delivery	5	37
63129	2020-05-15 15:22:42	2020-05-15	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	22062	delivery	5	25
63130	2020-05-15 15:23:38	2020-05-15	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	4801	delivery	5	26
63131	2020-05-15 15:33:27	2020-05-15	14	[{"id_menu":2,"count":1}]	10968	delivery	5	19
63132	2020-05-15 15:40:09	2020-05-15	17	[{"id_menu":4,"count":2}]	2916	pick-up	0	17
63133	2020-05-15 15:40:22	2020-05-15	8	[{"id_menu":5,"count":1}]	13615	delivery	5	13
63134	2020-05-15 15:45:13	2020-05-15	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	24978	delivery	5	35
63135	2020-05-15 15:46:34	2020-05-15	14	[{"id_menu":2,"count":1}]	15800	pick-up	0	14
63136	2020-05-15 15:47:37	2020-05-15	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2310	pick-up	0	21
63137	2020-05-15 15:49:03	2020-05-15	17	[{"id_menu":4,"count":1}]	15360	delivery	5	22
63138	2020-05-15 15:49:56	2020-05-15	17	[{"id_menu":4,"count":1}]	25090	delivery	5	22
63139	2020-05-15 15:50:25	2020-05-15	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17003	delivery	5	40
63140	2020-05-15 15:56:44	2020-05-15	9	[{"id_menu":6,"count":1}]	12997	delivery	5	14
63141	2020-05-15 16:05:53	2020-05-15	17	[{"id_menu":4,"count":2}]	3054	pick-up	0	17
63142	2020-05-15 16:08:28	2020-05-15	14	[{"id_menu":2,"count":1}]	4938	delivery	5	19
63143	2020-05-15 16:10:34	2020-05-15	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	24934	delivery	5	40
63144	2020-05-15 16:11:09	2020-05-15	12	[{"id_menu":3,"count":1}]	3494	pick-up	0	12
63145	2020-05-15 16:11:20	2020-05-15	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	15052	delivery	5	27
63146	2020-05-15 16:12:36	2020-05-15	8	[{"id_menu":5,"count":2}]	20815	delivery	5	13
63147	2020-05-15 16:13:34	2020-05-15	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	24386	delivery	5	31
63148	2020-05-15 16:14:27	2020-05-15	9	[{"id_menu":7,"count":1}]	24935	pick-up	0	9
63149	2020-05-15 16:16:17	2020-05-15	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	22523	delivery	5	43
63150	2020-05-15 16:20:04	2020-05-15	8	[{"id_menu":5,"count":1}]	24993	delivery	5	13
63151	2020-05-15 16:24:53	2020-05-15	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	24975	delivery	5	43
63152	2020-05-15 16:25:26	2020-05-15	9	[{"id_menu":6,"count":1}]	24970	delivery	5	14
63153	2020-05-15 16:27:38	2020-05-15	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	25062	delivery	5	39
63154	2020-05-15 16:31:05	2020-05-15	8	[{"id_menu":5,"count":1}]	15701	pick-up	0	8
63155	2020-05-15 16:31:28	2020-05-15	17	[{"id_menu":4,"count":1}]	1269	delivery	5	22
63156	2020-05-15 16:35:46	2020-05-15	17	[{"id_menu":4,"count":1}]	11545	delivery	5	22
63157	2020-05-15 16:38:51	2020-05-15	14	[{"id_menu":2,"count":1}]	15565	pick-up	0	14
63158	2020-05-15 16:39:19	2020-05-15	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14970	pick-up	0	31
63159	2020-05-15 16:41:30	2020-05-15	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4828	delivery	5	34
63160	2020-05-15 16:42:13	2020-05-15	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	24960	delivery	5	26
63161	2020-05-15 16:42:56	2020-05-15	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2232	delivery	5	40
63162	2020-05-15 16:48:49	2020-05-15	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	11965	delivery	5	23
63163	2020-05-15 16:49:24	2020-05-15	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	17144	delivery	5	27
63164	2020-05-15 16:52:57	2020-05-15	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	25030	delivery	5	26
63165	2020-05-15 17:00:34	2020-05-15	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	15883	pick-up	0	22
63166	2020-05-15 17:08:21	2020-05-15	8	[{"id_menu":5,"count":1}]	20106	delivery	5	13
63167	2020-05-15 17:08:31	2020-05-15	12	[{"id_menu":1,"count":1}]	25019	delivery	5	17
63168	2020-05-15 17:08:37	2020-05-15	14	[{"id_menu":2,"count":1}]	3616	delivery	5	19
63169	2020-05-15 17:11:45	2020-05-15	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17148	delivery	5	35
63170	2020-05-15 17:15:47	2020-05-15	9	[{"id_menu":6,"count":1}]	5871	delivery	5	14
63171	2020-05-15 17:17:01	2020-05-15	14	[{"id_menu":2,"count":1}]	24402	pick-up	0	14
63172	2020-05-15 17:24:06	2020-05-15	17	[{"id_menu":4,"count":1}]	3702	pick-up	0	17
63173	2020-05-15 17:26:51	2020-05-15	17	[{"id_menu":4,"count":1}]	25077	delivery	5	22
63174	2020-05-15 17:28:55	2020-05-15	9	[{"id_menu":6,"count":1}]	14709	delivery	5	14
63175	2020-05-15 17:30:32	2020-05-15	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	24914	delivery	5	40
63176	2020-05-15 17:34:14	2020-05-15	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	1266	pick-up	0	24
63177	2020-05-15 17:35:03	2020-05-15	8	[{"id_menu":5,"count":1}]	7182	delivery	5	13
63178	2020-05-15 17:52:10	2020-05-15	12	[{"id_menu":1,"count":1}]	13817	delivery	5	17
63179	2020-05-15 17:52:46	2020-05-15	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25033	delivery	5	31
63180	2020-05-15 18:04:27	2020-05-15	9	[{"id_menu":6,"count":1}]	24907	delivery	5	14
63181	2020-05-15 18:10:30	2020-05-15	17	[{"id_menu":4,"count":1}]	19909	delivery	5	22
63182	2020-05-15 18:14:01	2020-05-15	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	25075	delivery	5	40
63183	2020-05-15 18:14:26	2020-05-15	12	[{"id_menu":1,"count":1}]	15998	delivery	5	17
63184	2020-05-15 18:18:34	2020-05-15	8	[{"id_menu":5,"count":1}]	4444	pick-up	0	8
63185	2020-05-15 18:18:46	2020-05-15	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	22242	pick-up	0	29
63186	2020-05-15 18:23:40	2020-05-15	9	[{"id_menu":6,"count":1}]	4085	delivery	5	14
63187	2020-05-15 18:28:51	2020-05-15	17	[{"id_menu":4,"count":2}]	24873	delivery	5	22
63188	2020-05-15 18:33:44	2020-05-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	14652	pick-up	0	23
63189	2020-05-15 18:35:14	2020-05-15	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	19816	pick-up	0	38
63190	2020-05-15 18:37:14	2020-05-15	8	[{"id_menu":5,"count":1}]	25020	delivery	5	13
63191	2020-05-15 18:38:21	2020-05-15	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24961	delivery	5	34
63192	2020-05-15 18:38:44	2020-05-15	12	[{"id_menu":1,"count":1}]	12642	delivery	5	17
63193	2020-05-15 18:40:26	2020-05-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1155	pick-up	0	23
63194	2020-05-15 18:44:59	2020-05-15	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	11862	delivery	5	31
63195	2020-05-15 18:48:36	2020-05-15	8	[{"id_menu":5,"count":1}]	5362	delivery	5	13
63196	2020-05-15 18:53:43	2020-05-15	8	[{"id_menu":5,"count":1}]	17131	delivery	5	13
63197	2020-05-15 18:57:33	2020-05-15	17	[{"id_menu":4,"count":1}]	467	pick-up	0	17
63198	2020-05-15 18:57:35	2020-05-15	8	[{"id_menu":5,"count":1}]	15552	pick-up	0	8
63199	2020-05-15 19:00:53	2020-05-15	14	[{"id_menu":2,"count":1}]	25086	delivery	5	19
63200	2020-05-15 19:02:06	2020-05-15	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	9462	delivery	5	23
63201	2020-05-15 19:05:04	2020-05-15	9	[{"id_menu":6,"count":1}]	25038	delivery	5	14
63202	2020-05-15 19:06:00	2020-05-15	9	[{"id_menu":6,"count":1}]	2816	delivery	5	14
63203	2020-05-15 19:09:22	2020-05-15	9	[{"id_menu":6,"count":1}]	1923	delivery	5	14
63204	2020-05-15 19:09:28	2020-05-15	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	24982	delivery	5	40
63205	2020-05-15 19:09:36	2020-05-15	9	[{"id_menu":6,"count":1}]	4981	pick-up	0	9
63206	2020-05-15 19:11:24	2020-05-15	14	[{"id_menu":2,"count":1}]	5447	pick-up	0	14
63207	2020-05-15 19:14:58	2020-05-15	12	[{"id_menu":1,"count":1}]	2472	delivery	5	17
63208	2020-05-15 19:15:14	2020-05-15	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6182	pick-up	0	40
63209	2020-05-15 19:16:45	2020-05-15	9	[{"id_menu":6,"count":1}]	18310	delivery	5	14
63210	2020-05-15 19:19:11	2020-05-15	12	[{"id_menu":3,"count":1}]	23333	pick-up	0	12
63211	2020-05-15 19:23:36	2020-05-15	9	[{"id_menu":7,"count":1}]	25085	delivery	5	14
63212	2020-05-15 19:23:41	2020-05-15	9	[{"id_menu":7,"count":1}]	22276	delivery	5	14
63213	2020-05-15 19:25:00	2020-05-15	12	[{"id_menu":3,"count":1}]	25050	delivery	5	17
63214	2020-05-15 19:25:32	2020-05-15	12	[{"id_menu":3,"count":1}]	11133	delivery	5	17
63215	2020-05-15 19:27:02	2020-05-15	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	6825	pick-up	0	26
63216	2020-05-15 19:28:32	2020-05-15	8	[{"id_menu":5,"count":1}]	25092	delivery	5	13
63217	2020-05-15 19:33:53	2020-05-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23614	delivery	5	23
63218	2020-05-15 19:34:33	2020-05-15	12	[{"id_menu":1,"count":1}]	22605	pick-up	0	12
63219	2020-05-15 19:39:06	2020-05-15	8	[{"id_menu":5,"count":2}]	5125	delivery	5	13
63220	2020-05-15 19:48:06	2020-05-15	12	[{"id_menu":3,"count":1}]	2277	pick-up	0	12
63221	2020-05-15 19:51:08	2020-05-15	9	[{"id_menu":7,"count":1}]	23355	delivery	5	14
63222	2020-05-15 19:56:20	2020-05-15	9	[{"id_menu":6,"count":2}]	12038	delivery	5	14
63223	2020-05-15 19:57:35	2020-05-15	14	[{"id_menu":2,"count":1}]	16571	pick-up	0	14
63224	2020-05-15 20:00:29	2020-05-15	17	[{"id_menu":4,"count":1}]	24931	pick-up	0	17
63225	2020-05-15 20:00:57	2020-05-15	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	18050	delivery	5	40
63226	2020-05-15 20:05:58	2020-05-15	9	[{"id_menu":6,"count":1}]	788	pick-up	0	9
63227	2020-05-15 20:06:44	2020-05-15	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	20211	delivery	5	31
63228	2020-05-15 20:08:52	2020-05-15	12	[{"id_menu":1,"count":1}]	6399	pick-up	0	12
63229	2020-05-15 20:10:41	2020-05-15	14	[{"id_menu":2,"count":1}]	8743	pick-up	0	14
63230	2020-05-15 20:11:30	2020-05-15	9	[{"id_menu":7,"count":1}]	1756	delivery	5	14
63231	2020-05-15 20:12:22	2020-05-15	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	22512	delivery	5	45
63232	2020-05-15 20:16:04	2020-05-15	14	[{"id_menu":2,"count":1}]	20579	delivery	5	19
63233	2020-05-15 20:18:23	2020-05-15	9	[{"id_menu":6,"count":1}]	24933	delivery	5	14
63234	2020-05-15 20:27:52	2020-05-15	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11038	delivery	5	31
63235	2020-05-15 20:30:41	2020-05-15	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	19786	delivery	5	38
63236	2020-05-15 20:35:44	2020-05-15	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	23896	pick-up	0	21
63237	2020-05-15 20:38:14	2020-05-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	8355	pick-up	0	23
63238	2020-05-15 20:42:33	2020-05-15	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	25018	delivery	5	23
63239	2020-05-15 20:57:14	2020-05-15	14	[{"id_menu":2,"count":1}]	5232	pick-up	0	14
63240	2020-05-15 21:07:35	2020-05-15	8	[{"id_menu":5,"count":2}]	3205	delivery	5	13
63241	2020-05-15 21:13:40	2020-05-15	14	[{"id_menu":2,"count":1}]	13065	delivery	5	19
63242	2020-05-15 21:17:09	2020-05-15	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	25071	delivery	5	26
63243	2020-05-15 21:22:18	2020-05-15	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13026	pick-up	0	32
63244	2020-05-15 21:24:32	2020-05-15	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16754	delivery	5	31
63245	2020-05-15 21:34:29	2020-05-15	8	[{"id_menu":5,"count":1}]	24968	pick-up	0	8
63246	2020-05-15 21:42:27	2020-05-15	9	[{"id_menu":7,"count":1}]	3317	delivery	5	14
63247	2020-05-15 21:43:30	2020-05-15	8	[{"id_menu":5,"count":1}]	2507	delivery	5	13
63248	2020-05-15 21:53:52	2020-05-15	8	[{"id_menu":5,"count":1}]	25034	delivery	5	13
63249	2020-05-15 21:59:24	2020-05-15	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":2}]	25074	delivery	5	28
63250	2020-05-15 22:01:06	2020-05-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17747	delivery	5	31
63251	2020-05-15 22:04:51	2020-05-15	14	[{"id_menu":2,"count":1}]	15815	pick-up	0	14
63252	2020-05-15 22:05:22	2020-05-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	24913	pick-up	0	23
63253	2020-05-15 22:07:03	2020-05-15	14	[{"id_menu":2,"count":1}]	24976	delivery	5	19
63254	2020-05-15 22:07:49	2020-05-15	12	[{"id_menu":1,"count":1}]	4800	delivery	5	17
63255	2020-05-15 22:09:31	2020-05-15	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	4725	delivery	5	22
63256	2020-05-15 22:11:11	2020-05-15	17	[{"id_menu":4,"count":1}]	6243	pick-up	0	17
63257	2020-05-15 22:11:15	2020-05-15	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	20690	pick-up	0	43
63258	2020-05-15 22:17:16	2020-05-15	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24977	delivery	5	43
63259	2020-05-15 22:18:05	2020-05-15	17	[{"id_menu":4,"count":2}]	1021	delivery	5	22
63260	2020-05-15 22:25:14	2020-05-15	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18064	delivery	5	49
63261	2020-05-15 22:30:09	2020-05-15	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2447	pick-up	0	21
63262	2020-05-15 22:33:01	2020-05-15	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	25006	pick-up	0	34
63263	2020-05-15 22:37:15	2020-05-15	8	[{"id_menu":5,"count":1}]	140	pick-up	0	8
63264	2020-05-15 22:38:10	2020-05-15	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	24920	delivery	5	31
63265	2020-05-15 22:42:57	2020-05-15	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3705	delivery	5	42
63266	2020-05-15 22:45:19	2020-05-15	8	[{"id_menu":5,"count":1}]	8137	delivery	5	13
63267	2020-05-15 22:45:46	2020-05-15	9	[{"id_menu":6,"count":1}]	14263	delivery	5	14
63268	2020-05-15 22:45:57	2020-05-15	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	25055	delivery	5	31
63269	2020-05-15 22:47:54	2020-05-15	12	[{"id_menu":3,"count":1}]	15760	delivery	5	17
63270	2020-05-15 22:48:10	2020-05-15	9	[{"id_menu":6,"count":1}]	14299	pick-up	0	9
63271	2020-05-15 22:50:24	2020-05-15	9	[{"id_menu":6,"count":1}]	4382	pick-up	0	9
63272	2020-05-15 22:52:08	2020-05-15	12	[{"id_menu":1,"count":1}]	13172	delivery	5	17
63273	2020-05-15 22:53:50	2020-05-15	8	[{"id_menu":5,"count":1}]	24972	delivery	5	13
63274	2020-05-15 22:58:26	2020-05-15	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	12384	delivery	5	26
63275	2020-05-15 23:03:03	2020-05-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	893	pick-up	0	26
63276	2020-05-15 23:17:01	2020-05-15	14	[{"id_menu":2,"count":1}]	21290	delivery	5	19
63277	2020-05-15 23:17:49	2020-05-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	25059	delivery	5	28
63278	2020-05-15 23:20:05	2020-05-15	14	[{"id_menu":2,"count":1}]	3401	pick-up	0	14
63279	2020-05-15 23:20:06	2020-05-15	17	[{"id_menu":4,"count":1}]	14290	pick-up	0	17
63280	2020-05-15 23:22:54	2020-05-15	9	[{"id_menu":6,"count":2}]	25096	delivery	5	14
63281	2020-05-15 23:24:30	2020-05-15	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	24951	delivery	5	30
63282	2020-05-15 23:27:19	2020-05-15	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	25042	delivery	5	26
63283	2020-05-15 23:29:01	2020-05-15	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	22620	delivery	5	34
63284	2020-05-15 23:30:34	2020-05-15	9	[{"id_menu":7,"count":1}]	20592	delivery	5	14
63285	2020-05-15 23:33:44	2020-05-15	12	[{"id_menu":3,"count":2}]	61	pick-up	0	12
63286	2020-05-15 23:34:58	2020-05-15	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	20187	delivery	5	55
63287	2020-05-15 23:37:33	2020-05-15	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25061	delivery	5	22
63288	2020-05-15 23:37:53	2020-05-15	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	25008	delivery	5	40
63289	2020-05-15 23:43:30	2020-05-15	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	9038	delivery	5	31
63290	2020-05-15 23:44:13	2020-05-15	8	[{"id_menu":5,"count":1}]	7375	delivery	5	13
63291	2020-05-15 23:45:45	2020-05-15	12	[{"id_menu":1,"count":1}]	24937	pick-up	0	12
63292	2020-05-15 23:48:19	2020-05-15	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	20643	delivery	5	46
63293	2020-05-15 23:51:09	2020-05-15	9	[{"id_menu":6,"count":2}]	6301	pick-up	0	9
63294	2020-05-15 23:52:30	2020-05-15	12	[{"id_menu":3,"count":1}]	23312	pick-up	0	12
63295	2020-05-15 23:57:19	2020-05-15	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	25081	delivery	5	56
63296	2020-05-16 00:06:44	2020-05-16	8	[{"id_menu":5,"count":1}]	12305	delivery	5	13
63297	2020-05-16 00:08:41	2020-05-16	9	[{"id_menu":6,"count":1}]	5416	pick-up	0	9
63298	2020-05-16 00:15:15	2020-05-16	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	21258	delivery	5	57
63299	2020-05-16 00:15:25	2020-05-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11723	delivery	5	22
63300	2020-05-16 00:21:18	2020-05-16	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2669	delivery	5	38
63301	2020-05-16 00:21:33	2020-05-16	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25180	delivery	5	22
63302	2020-05-16 00:27:24	2020-05-16	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	25141	delivery	5	34
63303	2020-05-16 00:28:52	2020-05-16	9	[{"id_menu":7,"count":1}]	22952	delivery	5	14
63304	2020-05-16 00:37:05	2020-05-16	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	20635	delivery	5	45
63305	2020-05-16 00:37:11	2020-05-16	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	21405	delivery	5	37
63306	2020-05-16 00:39:49	2020-05-16	9	[{"id_menu":7,"count":1}]	13157	delivery	5	14
63307	2020-05-16 00:42:07	2020-05-16	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	25119	delivery	5	30
63308	2020-05-16 00:50:23	2020-05-16	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12150	pick-up	0	41
63309	2020-05-16 00:51:57	2020-05-16	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	546	delivery	5	35
63310	2020-05-16 01:02:19	2020-05-16	12	[{"id_menu":3,"count":1}]	16217	pick-up	0	12
63311	2020-05-16 01:05:00	2020-05-16	8	[{"id_menu":5,"count":1}]	25228	delivery	5	13
63312	2020-05-16 01:05:40	2020-05-16	12	[{"id_menu":1,"count":1}]	25174	delivery	5	17
63313	2020-05-16 01:06:55	2020-05-16	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9525	delivery	5	40
63314	2020-05-16 01:08:05	2020-05-16	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	7623	delivery	5	38
63315	2020-05-16 01:11:52	2020-05-16	12	[{"id_menu":1,"count":1}]	25178	delivery	5	17
63316	2020-05-16 01:13:10	2020-05-16	9	[{"id_menu":7,"count":1}]	3639	delivery	5	14
63317	2020-05-16 01:13:54	2020-05-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	21607	pick-up	0	23
63318	2020-05-16 01:14:34	2020-05-16	12	[{"id_menu":3,"count":1}]	23536	delivery	5	17
63319	2020-05-16 01:17:07	2020-05-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2680	pick-up	0	23
63320	2020-05-16 01:20:02	2020-05-16	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	25152	delivery	5	26
63321	2020-05-16 01:26:06	2020-05-16	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25208	delivery	5	36
63322	2020-05-16 01:31:05	2020-05-16	8	[{"id_menu":5,"count":1}]	4075	pick-up	0	8
63323	2020-05-16 01:39:16	2020-05-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20447	delivery	5	23
63324	2020-05-16 01:39:17	2020-05-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	8323	pick-up	0	18
63325	2020-05-16 01:41:54	2020-05-16	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	22987	pick-up	0	22
63326	2020-05-16 01:42:22	2020-05-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16127	pick-up	0	26
63327	2020-05-16 01:48:47	2020-05-16	14	[{"id_menu":2,"count":1}]	2758	delivery	5	19
63328	2020-05-16 02:00:00	2020-05-16	12	[{"id_menu":1,"count":1}]	25273	pick-up	0	12
63329	2020-05-16 02:00:58	2020-05-16	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6449	delivery	5	48
63330	2020-05-16 02:06:42	2020-05-16	12	[{"id_menu":1,"count":1}]	25220	delivery	5	17
63331	2020-05-16 02:08:18	2020-05-16	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	2333	pick-up	0	24
63332	2020-05-16 02:14:44	2020-05-16	9	[{"id_menu":7,"count":1}]	6533	pick-up	0	9
63333	2020-05-16 02:16:28	2020-05-16	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	19316	delivery	5	40
63334	2020-05-16 02:16:53	2020-05-16	9	[{"id_menu":7,"count":1}]	7802	delivery	5	14
63335	2020-05-16 02:18:36	2020-05-16	9	[{"id_menu":6,"count":1}]	25181	delivery	5	14
63336	2020-05-16 02:19:55	2020-05-16	17	[{"id_menu":4,"count":1}]	1095	pick-up	0	17
63337	2020-05-16 02:20:00	2020-05-16	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2604	pick-up	0	21
63338	2020-05-16 02:21:36	2020-05-16	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	11254	delivery	5	38
63339	2020-05-16 02:21:57	2020-05-16	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	25272	delivery	5	39
63340	2020-05-16 02:22:57	2020-05-16	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	25182	delivery	5	25
63341	2020-05-16 02:26:40	2020-05-16	12	[{"id_menu":1,"count":1}]	4126	pick-up	0	12
63342	2020-05-16 02:26:58	2020-05-16	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	7591	delivery	5	31
63343	2020-05-16 02:27:05	2020-05-16	9	[{"id_menu":7,"count":1}]	25144	delivery	5	14
63344	2020-05-16 02:28:59	2020-05-16	9	[{"id_menu":6,"count":1}]	7899	delivery	5	14
63345	2020-05-16 02:41:00	2020-05-16	9	[{"id_menu":7,"count":1}]	13371	delivery	5	14
63346	2020-05-16 02:41:56	2020-05-16	9	[{"id_menu":6,"count":2}]	16292	delivery	5	14
63347	2020-05-16 02:42:03	2020-05-16	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	2512	delivery	5	30
63348	2020-05-16 02:44:18	2020-05-16	12	[{"id_menu":3,"count":1}]	15905	pick-up	0	12
63349	2020-05-16 02:48:28	2020-05-16	12	[{"id_menu":3,"count":1}]	25149	delivery	5	17
63350	2020-05-16 02:51:35	2020-05-16	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	6516	delivery	5	34
63351	2020-05-16 02:53:41	2020-05-16	14	[{"id_menu":2,"count":1}]	10847	delivery	5	19
63352	2020-05-16 02:56:36	2020-05-16	8	[{"id_menu":5,"count":1}]	25133	delivery	5	13
63353	2020-05-16 02:57:47	2020-05-16	8	[{"id_menu":5,"count":1}]	19838	delivery	5	13
63354	2020-05-16 03:06:50	2020-05-16	9	[{"id_menu":7,"count":1}]	17867	delivery	5	14
63355	2020-05-16 03:11:03	2020-05-16	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25189	delivery	5	35
63356	2020-05-16 03:14:38	2020-05-16	17	[{"id_menu":5,"count":3},{"id_menu":7,"count":1}]	12289	delivery	5	22
63357	2020-05-16 03:15:16	2020-05-16	14	[{"id_menu":2,"count":1}]	25244	delivery	5	19
63358	2020-05-16 03:15:33	2020-05-16	9	[{"id_menu":6,"count":1}]	12648	delivery	5	14
63359	2020-05-16 03:16:27	2020-05-16	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	25121	delivery	5	30
63360	2020-05-16 03:17:28	2020-05-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	18036	delivery	5	26
63361	2020-05-16 03:18:26	2020-05-16	17	[{"id_menu":4,"count":1}]	25195	delivery	5	22
63362	2020-05-16 03:23:59	2020-05-16	8	[{"id_menu":5,"count":1}]	22054	delivery	5	13
63363	2020-05-16 03:26:13	2020-05-16	8	[{"id_menu":5,"count":1}]	22735	delivery	5	13
63364	2020-05-16 03:26:59	2020-05-16	9	[{"id_menu":6,"count":1}]	10385	pick-up	0	9
63365	2020-05-16 03:27:30	2020-05-16	12	[{"id_menu":1,"count":1}]	1257	pick-up	0	12
63366	2020-05-16 03:27:56	2020-05-16	14	[{"id_menu":2,"count":1}]	25171	delivery	5	19
63367	2020-05-16 03:28:25	2020-05-16	9	[{"id_menu":6,"count":1}]	19464	delivery	5	14
63368	2020-05-16 03:29:08	2020-05-16	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	25128	delivery	5	31
63369	2020-05-16 03:29:43	2020-05-16	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25212	delivery	5	40
63370	2020-05-16 03:31:14	2020-05-16	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21660	delivery	5	34
63371	2020-05-16 03:43:33	2020-05-16	12	[{"id_menu":3,"count":1}]	10859	delivery	5	17
63372	2020-05-16 03:46:18	2020-05-16	12	[{"id_menu":1,"count":1}]	16782	delivery	5	17
63373	2020-05-16 03:50:43	2020-05-16	12	[{"id_menu":3,"count":1}]	25145	delivery	5	17
63374	2020-05-16 03:54:08	2020-05-16	9	[{"id_menu":7,"count":1}]	14964	delivery	5	14
63375	2020-05-16 03:58:21	2020-05-16	14	[{"id_menu":2,"count":2}]	11407	delivery	5	19
63376	2020-05-16 04:01:56	2020-05-16	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	25160	delivery	5	27
63377	2020-05-16 04:03:55	2020-05-16	9	[{"id_menu":7,"count":1}]	25252	delivery	5	14
63378	2020-05-16 04:05:26	2020-05-16	17	[{"id_menu":4,"count":1}]	15788	delivery	5	22
63379	2020-05-16 04:06:47	2020-05-16	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	19234	delivery	5	25
63380	2020-05-16 04:08:32	2020-05-16	14	[{"id_menu":2,"count":1}]	19868	pick-up	0	14
63381	2020-05-16 04:11:29	2020-05-16	9	[{"id_menu":7,"count":1}]	10351	delivery	5	14
63382	2020-05-16 04:12:21	2020-05-16	14	[{"id_menu":2,"count":1}]	11616	delivery	5	19
63383	2020-05-16 04:14:08	2020-05-16	9	[{"id_menu":7,"count":1}]	9198	pick-up	0	9
63384	2020-05-16 04:16:17	2020-05-16	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	21038	delivery	5	26
63385	2020-05-16 04:18:09	2020-05-16	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	18615	delivery	5	36
63386	2020-05-16 04:18:50	2020-05-16	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8761	delivery	5	48
63387	2020-05-16 04:22:40	2020-05-16	9	[{"id_menu":7,"count":1}]	25147	delivery	5	14
63388	2020-05-16 04:25:14	2020-05-16	9	[{"id_menu":6,"count":1}]	5099	delivery	5	14
63389	2020-05-16 04:25:34	2020-05-16	9	[{"id_menu":6,"count":1}]	13713	delivery	5	14
63390	2020-05-16 04:28:50	2020-05-16	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	5503	pick-up	0	21
63391	2020-05-16 04:39:12	2020-05-16	14	[{"id_menu":2,"count":1}]	25249	delivery	5	19
63392	2020-05-16 04:40:04	2020-05-16	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	25109	delivery	5	45
63393	2020-05-16 04:40:47	2020-05-16	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	25155	delivery	5	40
63394	2020-05-16 04:41:12	2020-05-16	8	[{"id_menu":5,"count":1}]	20549	pick-up	0	8
63395	2020-05-16 04:43:20	2020-05-16	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	19191	pick-up	0	31
63396	2020-05-16 04:44:25	2020-05-16	9	[{"id_menu":6,"count":1}]	18390	delivery	5	14
63397	2020-05-16 04:52:23	2020-05-16	8	[{"id_menu":5,"count":1}]	25258	delivery	5	13
63398	2020-05-16 04:54:25	2020-05-16	17	[{"id_menu":4,"count":1}]	14779	delivery	5	22
63399	2020-05-16 04:55:06	2020-05-16	17	[{"id_menu":4,"count":1}]	9921	delivery	5	22
63400	2020-05-16 04:55:16	2020-05-16	9	[{"id_menu":6,"count":1}]	23040	delivery	5	14
63401	2020-05-16 04:57:02	2020-05-16	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4682	pick-up	0	31
63402	2020-05-16 04:57:14	2020-05-16	12	[{"id_menu":1,"count":1}]	2381	pick-up	0	12
63403	2020-05-16 04:57:28	2020-05-16	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	25231	delivery	5	26
63404	2020-05-16 04:57:49	2020-05-16	8	[{"id_menu":5,"count":1}]	25238	delivery	5	13
63405	2020-05-16 05:01:41	2020-05-16	12	[{"id_menu":3,"count":1}]	20215	delivery	5	17
63406	2020-05-16 05:12:08	2020-05-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	21453	delivery	5	31
63407	2020-05-16 05:13:03	2020-05-16	9	[{"id_menu":7,"count":1}]	15437	delivery	5	14
63408	2020-05-16 05:16:10	2020-05-16	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	8339	delivery	5	26
63409	2020-05-16 05:19:33	2020-05-16	9	[{"id_menu":6,"count":1}]	25221	delivery	5	14
63410	2020-05-16 05:19:55	2020-05-16	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25116	delivery	5	35
63411	2020-05-16 05:20:04	2020-05-16	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22521	delivery	5	39
63412	2020-05-16 05:21:35	2020-05-16	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12072	delivery	5	40
63413	2020-05-16 05:25:42	2020-05-16	9	[{"id_menu":7,"count":1}]	21094	delivery	5	14
63414	2020-05-16 05:25:55	2020-05-16	14	[{"id_menu":2,"count":1}]	25190	pick-up	0	14
63415	2020-05-16 05:25:58	2020-05-16	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25224	delivery	5	40
63416	2020-05-16 05:26:16	2020-05-16	9	[{"id_menu":6,"count":1}]	557	pick-up	0	9
63417	2020-05-16 05:28:25	2020-05-16	12	[{"id_menu":3,"count":1}]	178	pick-up	0	12
63418	2020-05-16 05:31:37	2020-05-16	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	8109	delivery	5	34
63419	2020-05-16 05:33:45	2020-05-16	9	[{"id_menu":6,"count":1}]	25255	delivery	5	14
63420	2020-05-16 05:40:19	2020-05-16	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25205	delivery	5	34
63421	2020-05-16 05:43:32	2020-05-16	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	25151	delivery	5	43
63422	2020-05-16 05:43:43	2020-05-16	9	[{"id_menu":7,"count":1}]	25175	delivery	5	14
63423	2020-05-16 05:47:10	2020-05-16	12	[{"id_menu":1,"count":1}]	919	pick-up	0	12
63424	2020-05-16 05:48:18	2020-05-16	9	[{"id_menu":6,"count":1}]	4206	delivery	5	14
63425	2020-05-16 05:52:16	2020-05-16	17	[{"id_menu":4,"count":1}]	1074	delivery	5	22
63426	2020-05-16 05:53:29	2020-05-16	14	[{"id_menu":2,"count":1}]	18811	delivery	5	19
63427	2020-05-16 06:01:27	2020-05-16	9	[{"id_menu":7,"count":1}]	15368	delivery	5	14
63428	2020-05-16 06:12:08	2020-05-16	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	15097	pick-up	0	18
63429	2020-05-16 06:12:44	2020-05-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	20312	pick-up	0	26
63430	2020-05-16 06:12:51	2020-05-16	9	[{"id_menu":7,"count":1}]	4986	delivery	5	14
63431	2020-05-16 06:13:12	2020-05-16	12	[{"id_menu":3,"count":1}]	25126	delivery	5	17
63432	2020-05-16 06:14:04	2020-05-16	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	25158	delivery	5	26
63433	2020-05-16 06:14:07	2020-05-16	9	[{"id_menu":7,"count":3}]	25118	delivery	5	14
63434	2020-05-16 06:18:45	2020-05-16	14	[{"id_menu":2,"count":1}]	25223	delivery	5	19
63435	2020-05-16 06:19:34	2020-05-16	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	25187	delivery	5	22
63436	2020-05-16 06:20:12	2020-05-16	12	[{"id_menu":1,"count":1}]	23665	delivery	5	17
63437	2020-05-16 06:20:12	2020-05-16	14	[{"id_menu":2,"count":1}]	2227	delivery	5	19
63438	2020-05-16 06:22:47	2020-05-16	12	[{"id_menu":1,"count":1}]	15319	pick-up	0	12
63439	2020-05-16 06:27:41	2020-05-16	14	[{"id_menu":2,"count":1}]	11631	delivery	5	19
63440	2020-05-16 06:28:21	2020-05-16	12	[{"id_menu":1,"count":1}]	257	pick-up	0	12
63441	2020-05-16 06:32:01	2020-05-16	17	[{"id_menu":4,"count":1}]	25153	delivery	5	22
63442	2020-05-16 06:32:38	2020-05-16	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25193	delivery	5	43
63443	2020-05-16 06:40:37	2020-05-16	9	[{"id_menu":6,"count":1}]	21927	delivery	5	14
63444	2020-05-16 06:44:46	2020-05-16	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25124	delivery	5	43
63445	2020-05-16 06:45:50	2020-05-16	9	[{"id_menu":6,"count":1}]	25177	delivery	5	14
63446	2020-05-16 06:45:53	2020-05-16	17	[{"id_menu":4,"count":1}]	5958	pick-up	0	17
63447	2020-05-16 06:48:08	2020-05-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	929	pick-up	0	26
63448	2020-05-16 06:49:03	2020-05-16	14	[{"id_menu":2,"count":1}]	18886	delivery	5	19
63449	2020-05-16 06:50:42	2020-05-16	8	[{"id_menu":5,"count":1}]	1168	pick-up	0	8
63450	2020-05-16 06:52:20	2020-05-16	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24262	delivery	5	49
63451	2020-05-16 07:02:34	2020-05-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	25173	delivery	5	31
63452	2020-05-16 07:04:42	2020-05-16	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	25170	pick-up	0	20
63453	2020-05-16 07:06:34	2020-05-16	14	[{"id_menu":2,"count":1}]	25099	pick-up	0	14
63454	2020-05-16 07:07:12	2020-05-16	9	[{"id_menu":6,"count":1}]	7122	delivery	5	14
63455	2020-05-16 07:07:50	2020-05-16	14	[{"id_menu":2,"count":1}]	25259	delivery	5	19
63456	2020-05-16 07:08:31	2020-05-16	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25196	delivery	5	53
63457	2020-05-16 07:14:27	2020-05-16	8	[{"id_menu":5,"count":1}]	25100	pick-up	0	8
63458	2020-05-16 07:19:39	2020-05-16	9	[{"id_menu":6,"count":1}]	575	pick-up	0	9
63459	2020-05-16 07:20:55	2020-05-16	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	12792	delivery	5	34
63460	2020-05-16 07:22:10	2020-05-16	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25188	delivery	5	40
63461	2020-05-16 07:26:17	2020-05-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	13095	delivery	5	28
63462	2020-05-16 07:28:05	2020-05-16	9	[{"id_menu":7,"count":1}]	5041	pick-up	0	9
63463	2020-05-16 07:28:24	2020-05-16	9	[{"id_menu":7,"count":1}]	25217	delivery	5	14
63464	2020-05-16 07:32:46	2020-05-16	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	22368	delivery	5	22
63465	2020-05-16 07:35:24	2020-05-16	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	11614	delivery	5	25
63466	2020-05-16 07:35:45	2020-05-16	12	[{"id_menu":3,"count":1}]	2839	pick-up	0	12
63467	2020-05-16 07:37:00	2020-05-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	14795	delivery	5	28
63468	2020-05-16 07:43:00	2020-05-16	14	[{"id_menu":2,"count":1}]	1525	pick-up	0	14
63469	2020-05-16 07:44:24	2020-05-16	12	[{"id_menu":1,"count":1}]	17652	delivery	5	17
63470	2020-05-16 07:47:18	2020-05-16	8	[{"id_menu":5,"count":1}]	18407	delivery	5	13
63471	2020-05-16 07:52:00	2020-05-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25194	delivery	5	23
63472	2020-05-16 07:53:00	2020-05-16	9	[{"id_menu":7,"count":1}]	10297	delivery	5	14
63473	2020-05-16 07:53:53	2020-05-16	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	8185	pick-up	0	24
63474	2020-05-16 08:01:15	2020-05-16	9	[{"id_menu":6,"count":1}]	2513	pick-up	0	9
63475	2020-05-16 08:08:04	2020-05-16	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	23070	delivery	5	39
63476	2020-05-16 08:10:07	2020-05-16	12	[{"id_menu":1,"count":1}]	21596	delivery	5	17
63477	2020-05-16 08:10:12	2020-05-16	17	[{"id_menu":4,"count":1}]	25130	pick-up	0	17
63478	2020-05-16 08:10:31	2020-05-16	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	25120	delivery	5	38
63479	2020-05-16 08:13:55	2020-05-16	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	2420	delivery	5	22
63480	2020-05-16 08:14:49	2020-05-16	9	[{"id_menu":6,"count":1}]	25165	delivery	5	14
63481	2020-05-16 08:21:58	2020-05-16	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25172	delivery	5	36
63482	2020-05-16 08:26:12	2020-05-16	8	[{"id_menu":5,"count":1}]	7140	pick-up	0	8
63483	2020-05-16 08:27:23	2020-05-16	14	[{"id_menu":2,"count":1}]	11666	delivery	5	19
63484	2020-05-16 08:28:42	2020-05-16	9	[{"id_menu":7,"count":1}]	25263	delivery	5	14
63485	2020-05-16 08:35:59	2020-05-16	14	[{"id_menu":2,"count":1}]	25250	delivery	5	19
63486	2020-05-16 08:41:35	2020-05-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	22249	delivery	5	28
63487	2020-05-16 08:42:53	2020-05-16	14	[{"id_menu":2,"count":1}]	17105	delivery	5	19
63488	2020-05-16 08:45:26	2020-05-16	9	[{"id_menu":6,"count":1}]	25104	delivery	5	14
63489	2020-05-16 08:46:33	2020-05-16	12	[{"id_menu":3,"count":1}]	10281	delivery	5	17
63490	2020-05-16 08:47:59	2020-05-16	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	23074	delivery	5	57
63491	2020-05-16 08:47:59	2020-05-16	14	[{"id_menu":2,"count":1}]	9803	pick-up	0	14
63492	2020-05-16 08:50:03	2020-05-16	14	[{"id_menu":2,"count":1}]	8887	pick-up	0	14
63493	2020-05-16 08:57:05	2020-05-16	9	[{"id_menu":6,"count":1}]	20697	pick-up	0	9
63494	2020-05-16 08:59:38	2020-05-16	9	[{"id_menu":7,"count":1}]	25278	delivery	5	14
63495	2020-05-16 08:59:57	2020-05-16	8	[{"id_menu":5,"count":1}]	25169	delivery	5	13
63496	2020-05-16 09:16:36	2020-05-16	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25110	delivery	5	54
63497	2020-05-16 09:17:22	2020-05-16	9	[{"id_menu":6,"count":1}]	24743	delivery	5	14
63498	2020-05-16 09:20:27	2020-05-16	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	9996	delivery	5	23
63499	2020-05-16 09:20:55	2020-05-16	12	[{"id_menu":1,"count":1}]	668	pick-up	0	12
63500	2020-05-16 09:21:59	2020-05-16	9	[{"id_menu":7,"count":1}]	9191	pick-up	0	9
63501	2020-05-16 09:26:46	2020-05-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	25201	delivery	5	26
63502	2020-05-16 09:27:08	2020-05-16	14	[{"id_menu":2,"count":1}]	14290	delivery	5	19
63503	2020-05-16 09:27:16	2020-05-16	8	[{"id_menu":5,"count":1}]	18940	delivery	5	13
63504	2020-05-16 09:27:40	2020-05-16	12	[{"id_menu":1,"count":1}]	4072	delivery	5	17
63505	2020-05-16 09:29:01	2020-05-16	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25148	delivery	5	36
63506	2020-05-16 09:29:37	2020-05-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	708	pick-up	0	26
63507	2020-05-16 09:42:02	2020-05-16	9	[{"id_menu":6,"count":1}]	25241	delivery	5	14
63508	2020-05-16 09:47:12	2020-05-16	17	[{"id_menu":4,"count":1}]	21964	delivery	5	22
63509	2020-05-16 09:47:45	2020-05-16	12	[{"id_menu":1,"count":1}]	1713	delivery	5	17
63510	2020-05-16 09:52:12	2020-05-16	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	10287	delivery	5	36
63511	2020-05-16 09:53:37	2020-05-16	17	[{"id_menu":4,"count":1}]	9128	pick-up	0	17
63512	2020-05-16 10:03:22	2020-05-16	9	[{"id_menu":7,"count":1}]	16333	pick-up	0	9
63513	2020-05-16 10:04:07	2020-05-16	12	[{"id_menu":1,"count":1}]	381	pick-up	0	12
63514	2020-05-16 10:06:22	2020-05-16	17	[{"id_menu":4,"count":1}]	7206	pick-up	0	17
63515	2020-05-16 10:06:41	2020-05-16	12	[{"id_menu":1,"count":1}]	19289	delivery	5	17
63516	2020-05-16 10:09:48	2020-05-16	12	[{"id_menu":1,"count":1}]	15048	pick-up	0	12
63517	2020-05-16 10:10:54	2020-05-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6328	pick-up	0	26
63518	2020-05-16 10:14:34	2020-05-16	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6088	delivery	5	35
63519	2020-05-16 10:15:42	2020-05-16	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21123	delivery	5	34
63520	2020-05-16 10:18:35	2020-05-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	25215	delivery	5	31
63521	2020-05-16 10:22:36	2020-05-16	9	[{"id_menu":6,"count":1}]	12088	delivery	5	14
63522	2020-05-16 10:30:12	2020-05-16	9	[{"id_menu":7,"count":1}]	25183	delivery	5	14
63523	2020-05-16 10:31:30	2020-05-16	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13681	delivery	5	22
63524	2020-05-16 10:31:49	2020-05-16	17	[{"id_menu":4,"count":1}]	5050	delivery	5	22
63525	2020-05-16 10:32:56	2020-05-16	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2339	delivery	5	31
63526	2020-05-16 10:33:51	2020-05-16	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	18025	pick-up	0	25
63527	2020-05-16 10:37:33	2020-05-16	17	[{"id_menu":4,"count":1}]	20439	delivery	5	22
63528	2020-05-16 10:39:46	2020-05-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	25143	delivery	5	22
63529	2020-05-16 10:42:48	2020-05-16	12	[{"id_menu":1,"count":1}]	19777	delivery	5	17
63530	2020-05-16 10:44:15	2020-05-16	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	10350	delivery	5	23
63531	2020-05-16 10:44:50	2020-05-16	8	[{"id_menu":5,"count":1}]	25254	delivery	5	13
63532	2020-05-16 10:55:46	2020-05-16	17	[{"id_menu":4,"count":1}]	2937	pick-up	0	17
63533	2020-05-16 10:56:07	2020-05-16	9	[{"id_menu":7,"count":1}]	25207	delivery	5	14
63534	2020-05-16 10:57:04	2020-05-16	17	[{"id_menu":4,"count":1}]	11791	pick-up	0	17
63535	2020-05-16 10:57:09	2020-05-16	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	25219	pick-up	0	25
63536	2020-05-16 10:58:44	2020-05-16	9	[{"id_menu":6,"count":1}]	1380	delivery	5	14
63537	2020-05-16 10:58:45	2020-05-16	12	[{"id_menu":1,"count":1}]	23621	pick-up	0	12
63538	2020-05-16 10:59:01	2020-05-16	9	[{"id_menu":6,"count":1}]	1854	pick-up	0	9
63539	2020-05-16 11:02:48	2020-05-16	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	8045	delivery	5	37
63540	2020-05-16 11:06:04	2020-05-16	9	[{"id_menu":6,"count":1}]	19346	delivery	5	14
63541	2020-05-16 11:12:41	2020-05-16	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21803	delivery	5	37
63542	2020-05-16 11:19:27	2020-05-16	12	[{"id_menu":3,"count":1}]	17823	delivery	5	17
63543	2020-05-16 11:22:47	2020-05-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17421	delivery	5	22
63544	2020-05-16 11:27:28	2020-05-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	13432	delivery	5	31
63545	2020-05-16 11:35:37	2020-05-16	14	[{"id_menu":2,"count":1}]	7189	pick-up	0	14
63546	2020-05-16 11:43:51	2020-05-16	8	[{"id_menu":5,"count":2}]	14578	pick-up	0	8
63547	2020-05-16 11:43:59	2020-05-16	9	[{"id_menu":6,"count":1}]	6868	delivery	5	14
63548	2020-05-16 11:45:53	2020-05-16	12	[{"id_menu":3,"count":1}]	25131	delivery	5	17
63549	2020-05-16 11:47:55	2020-05-16	9	[{"id_menu":6,"count":1}]	25167	delivery	5	14
63550	2020-05-16 11:48:47	2020-05-16	9	[{"id_menu":7,"count":1}]	10848	delivery	5	14
63551	2020-05-16 11:51:54	2020-05-16	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3127	delivery	5	36
63552	2020-05-16 11:52:22	2020-05-16	12	[{"id_menu":1,"count":1}]	15550	pick-up	0	12
63553	2020-05-16 11:52:37	2020-05-16	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	25156	delivery	5	22
63554	2020-05-16 12:00:38	2020-05-16	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	25198	delivery	5	28
63555	2020-05-16 12:01:58	2020-05-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4347	delivery	5	28
63556	2020-05-16 12:04:55	2020-05-16	12	[{"id_menu":3,"count":1}]	19172	delivery	5	17
63557	2020-05-16 12:05:06	2020-05-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	25159	delivery	5	23
63558	2020-05-16 12:06:40	2020-05-16	17	[{"id_menu":4,"count":1}]	18395	delivery	5	22
63559	2020-05-16 12:06:54	2020-05-16	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15768	delivery	5	45
63560	2020-05-16 12:10:37	2020-05-16	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	25269	delivery	5	45
63561	2020-05-16 12:12:09	2020-05-16	9	[{"id_menu":7,"count":1}]	24759	delivery	5	14
63562	2020-05-16 12:13:01	2020-05-16	9	[{"id_menu":6,"count":2}]	21256	delivery	5	14
63563	2020-05-16 12:14:49	2020-05-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	25162	delivery	5	31
63564	2020-05-16 12:16:24	2020-05-16	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	7676	delivery	5	31
63565	2020-05-16 12:18:21	2020-05-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	25233	delivery	5	22
63566	2020-05-16 12:18:42	2020-05-16	14	[{"id_menu":2,"count":1}]	25108	delivery	5	19
63567	2020-05-16 12:20:22	2020-05-16	8	[{"id_menu":5,"count":1}]	18043	delivery	5	13
63568	2020-05-16 12:20:36	2020-05-16	8	[{"id_menu":5,"count":1}]	25150	pick-up	0	8
63569	2020-05-16 12:25:09	2020-05-16	12	[{"id_menu":1,"count":1}]	25214	pick-up	0	12
63570	2020-05-16 12:34:46	2020-05-16	12	[{"id_menu":3,"count":1}]	25161	pick-up	0	12
63571	2020-05-16 12:35:28	2020-05-16	8	[{"id_menu":5,"count":1}]	2029	delivery	5	13
63572	2020-05-16 12:36:05	2020-05-16	9	[{"id_menu":6,"count":1}]	10173	delivery	5	14
63573	2020-05-16 12:37:09	2020-05-16	8	[{"id_menu":5,"count":1}]	17530	delivery	5	13
63574	2020-05-16 12:39:41	2020-05-16	17	[{"id_menu":4,"count":1}]	25229	delivery	5	22
63575	2020-05-16 12:40:08	2020-05-16	12	[{"id_menu":3,"count":1}]	21383	delivery	5	17
63576	2020-05-16 12:44:32	2020-05-16	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	8867	delivery	5	25
63577	2020-05-16 12:49:02	2020-05-16	12	[{"id_menu":1,"count":1}]	7342	delivery	5	17
63578	2020-05-16 12:51:00	2020-05-16	9	[{"id_menu":6,"count":1}]	12434	delivery	5	14
63579	2020-05-16 12:51:43	2020-05-16	8	[{"id_menu":5,"count":1}]	6733	pick-up	0	8
63580	2020-05-16 12:56:15	2020-05-16	17	[{"id_menu":4,"count":1}]	25122	delivery	5	22
63581	2020-05-16 13:01:46	2020-05-16	9	[{"id_menu":6,"count":1}]	21936	delivery	5	14
63582	2020-05-16 13:06:09	2020-05-16	9	[{"id_menu":6,"count":1}]	16855	delivery	5	14
63583	2020-05-16 13:08:04	2020-05-16	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25242	delivery	5	22
63584	2020-05-16 13:09:15	2020-05-16	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	25230	delivery	5	36
63585	2020-05-16 13:11:59	2020-05-16	14	[{"id_menu":2,"count":1}]	5943	delivery	5	19
63586	2020-05-16 13:14:23	2020-05-16	9	[{"id_menu":6,"count":1}]	263	delivery	5	14
63587	2020-05-16 13:14:55	2020-05-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	25240	delivery	5	28
63588	2020-05-16 13:15:08	2020-05-16	17	[{"id_menu":4,"count":1}]	25098	delivery	5	22
63589	2020-05-16 13:17:15	2020-05-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":3}]	15556	delivery	5	28
63590	2020-05-16 13:17:38	2020-05-16	12	[{"id_menu":1,"count":1}]	19506	pick-up	0	12
63591	2020-05-16 13:21:30	2020-05-16	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	25123	delivery	5	36
63592	2020-05-16 13:23:22	2020-05-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	14281	delivery	5	28
63593	2020-05-16 13:23:56	2020-05-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	20723	delivery	5	22
63594	2020-05-16 13:31:15	2020-05-16	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	25061	delivery	5	26
63595	2020-05-16 13:31:39	2020-05-16	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5182	delivery	5	22
63596	2020-05-16 13:31:48	2020-05-16	17	[{"id_menu":4,"count":1}]	612	delivery	5	22
63597	2020-05-16 13:32:24	2020-05-16	8	[{"id_menu":5,"count":1}]	25101	delivery	5	13
63598	2020-05-16 13:32:25	2020-05-16	9	[{"id_menu":6,"count":1}]	10393	pick-up	0	9
63599	2020-05-16 13:33:06	2020-05-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":3}]	15822	delivery	5	28
63600	2020-05-16 13:38:08	2020-05-16	9	[{"id_menu":7,"count":1}]	25210	delivery	5	14
63601	2020-05-16 13:40:33	2020-05-16	9	[{"id_menu":6,"count":2}]	25179	delivery	5	14
63602	2020-05-16 13:47:05	2020-05-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	19321	pick-up	0	18
63603	2020-05-16 13:49:33	2020-05-16	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25211	delivery	5	37
63604	2020-05-16 14:02:53	2020-05-16	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1223	pick-up	0	24
63605	2020-05-16 14:05:42	2020-05-16	9	[{"id_menu":7,"count":1}]	25245	delivery	5	14
63606	2020-05-16 14:07:32	2020-05-16	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	5875	delivery	5	31
63607	2020-05-16 14:10:14	2020-05-16	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7902	delivery	5	51
63608	2020-05-16 14:11:18	2020-05-16	12	[{"id_menu":3,"count":1}]	7967	delivery	5	17
63609	2020-05-16 14:12:29	2020-05-16	9	[{"id_menu":7,"count":1}]	24808	delivery	5	14
63610	2020-05-16 14:14:45	2020-05-16	8	[{"id_menu":5,"count":1}]	4356	pick-up	0	8
63611	2020-05-16 14:20:51	2020-05-16	17	[{"id_menu":4,"count":1}]	18176	delivery	5	22
63612	2020-05-16 14:23:11	2020-05-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6507	pick-up	0	26
63613	2020-05-16 14:24:35	2020-05-16	9	[{"id_menu":6,"count":1}]	18197	delivery	5	14
63614	2020-05-16 14:28:22	2020-05-16	12	[{"id_menu":3,"count":1}]	14138	delivery	5	17
63615	2020-05-16 14:30:55	2020-05-16	14	[{"id_menu":2,"count":1}]	12546	delivery	5	19
63616	2020-05-16 14:33:14	2020-05-16	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	25199	delivery	5	36
63617	2020-05-16 14:38:08	2020-05-16	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	14622	pick-up	0	20
63618	2020-05-16 14:39:40	2020-05-16	12	[{"id_menu":3,"count":1}]	4696	delivery	5	17
63619	2020-05-16 14:46:46	2020-05-16	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	25246	delivery	5	31
63620	2020-05-16 14:47:00	2020-05-16	9	[{"id_menu":6,"count":1}]	4166	pick-up	0	9
63621	2020-05-16 14:48:41	2020-05-16	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	16098	pick-up	0	29
63622	2020-05-16 14:53:38	2020-05-16	12	[{"id_menu":1,"count":1}]	25111	delivery	5	17
63623	2020-05-16 14:54:35	2020-05-16	9	[{"id_menu":6,"count":1}]	17483	delivery	5	14
63624	2020-05-16 15:00:08	2020-05-16	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11228	delivery	5	51
63625	2020-05-16 15:00:20	2020-05-16	8	[{"id_menu":5,"count":1}]	11454	delivery	5	13
63626	2020-05-16 15:04:49	2020-05-16	9	[{"id_menu":7,"count":1}]	531	pick-up	0	9
63627	2020-05-16 15:09:03	2020-05-16	9	[{"id_menu":7,"count":1}]	24958	delivery	5	14
63628	2020-05-16 15:09:49	2020-05-16	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	25154	delivery	5	45
63629	2020-05-16 15:17:13	2020-05-16	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	996	pick-up	0	43
63630	2020-05-16 15:21:49	2020-05-16	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	25134	delivery	5	34
63631	2020-05-16 15:24:26	2020-05-16	14	[{"id_menu":2,"count":1}]	25262	delivery	5	19
63632	2020-05-16 15:24:49	2020-05-16	14	[{"id_menu":2,"count":1}]	6163	pick-up	0	14
63633	2020-05-16 15:25:18	2020-05-16	9	[{"id_menu":6,"count":1}]	7451	delivery	5	14
63634	2020-05-16 15:25:19	2020-05-16	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25129	delivery	5	46
63635	2020-05-16 15:26:12	2020-05-16	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	25227	delivery	5	22
63636	2020-05-16 15:27:16	2020-05-16	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	25260	delivery	5	25
63637	2020-05-16 15:28:10	2020-05-16	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25239	delivery	5	35
63638	2020-05-16 15:28:28	2020-05-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":3}]	7544	delivery	5	31
63639	2020-05-16 15:30:43	2020-05-16	9	[{"id_menu":7,"count":1}]	7465	pick-up	0	9
63640	2020-05-16 15:37:43	2020-05-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	25279	pick-up	0	26
63641	2020-05-16 15:42:33	2020-05-16	9	[{"id_menu":7,"count":1}]	2041	pick-up	0	9
63642	2020-05-16 15:44:37	2020-05-16	8	[{"id_menu":5,"count":1}]	25146	delivery	5	13
63643	2020-05-16 15:47:42	2020-05-16	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	25192	delivery	5	26
63644	2020-05-16 15:54:00	2020-05-16	17	[{"id_menu":4,"count":1}]	1541	pick-up	0	17
63645	2020-05-16 15:56:16	2020-05-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":3}]	25135	delivery	5	31
63646	2020-05-16 15:56:41	2020-05-16	14	[{"id_menu":2,"count":1}]	19383	delivery	5	19
63647	2020-05-16 15:58:43	2020-05-16	9	[{"id_menu":7,"count":1}]	17852	delivery	5	14
63648	2020-05-16 16:01:11	2020-05-16	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25222	delivery	5	22
63649	2020-05-16 16:02:24	2020-05-16	9	[{"id_menu":6,"count":1}]	15176	delivery	5	14
63650	2020-05-16 16:04:41	2020-05-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	13699	delivery	5	26
63651	2020-05-16 16:07:57	2020-05-16	9	[{"id_menu":6,"count":1}]	15679	delivery	5	14
63652	2020-05-16 16:10:08	2020-05-16	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	10686	delivery	5	40
63653	2020-05-16 16:10:47	2020-05-16	12	[{"id_menu":1,"count":1}]	16330	pick-up	0	12
63654	2020-05-16 16:13:42	2020-05-16	9	[{"id_menu":7,"count":1}]	23819	delivery	5	14
63655	2020-05-16 16:15:50	2020-05-16	14	[{"id_menu":2,"count":1}]	16747	delivery	5	19
63656	2020-05-16 16:21:02	2020-05-16	14	[{"id_menu":2,"count":1}]	20511	delivery	5	19
63657	2020-05-16 16:22:06	2020-05-16	12	[{"id_menu":3,"count":1}]	25276	pick-up	0	12
63658	2020-05-16 16:33:21	2020-05-16	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23023	delivery	5	31
63659	2020-05-16 16:34:15	2020-05-16	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	5433	delivery	5	52
63660	2020-05-16 16:34:49	2020-05-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4077	delivery	5	31
63661	2020-05-16 16:34:49	2020-05-16	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	22364	delivery	5	35
63662	2020-05-16 16:35:11	2020-05-16	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	25102	delivery	5	26
63663	2020-05-16 16:36:07	2020-05-16	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25268	delivery	5	22
63664	2020-05-16 16:36:11	2020-05-16	14	[{"id_menu":2,"count":1}]	2401	pick-up	0	14
63665	2020-05-16 16:38:10	2020-05-16	9	[{"id_menu":6,"count":1}]	10333	delivery	5	14
63666	2020-05-16 16:42:35	2020-05-16	12	[{"id_menu":1,"count":1}]	3754	pick-up	0	12
63667	2020-05-16 16:52:14	2020-05-16	12	[{"id_menu":1,"count":1}]	1679	pick-up	0	12
63668	2020-05-16 16:54:18	2020-05-16	9	[{"id_menu":6,"count":1}]	22078	delivery	5	14
63669	2020-05-16 16:56:46	2020-05-16	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	25277	delivery	5	31
63670	2020-05-16 17:01:14	2020-05-16	14	[{"id_menu":2,"count":1}]	25157	delivery	5	19
63671	2020-05-16 17:05:06	2020-05-16	9	[{"id_menu":6,"count":1}]	12106	delivery	5	14
63672	2020-05-16 17:05:59	2020-05-16	14	[{"id_menu":2,"count":2}]	25243	delivery	5	19
63673	2020-05-16 17:07:11	2020-05-16	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	855	pick-up	0	20
63674	2020-05-16 17:07:53	2020-05-16	9	[{"id_menu":6,"count":1}]	15738	delivery	5	14
63675	2020-05-16 17:07:59	2020-05-16	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3870	pick-up	0	31
63676	2020-05-16 17:09:00	2020-05-16	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	11403	delivery	5	22
63677	2020-05-16 17:16:45	2020-05-16	17	[{"id_menu":4,"count":1}]	5802	pick-up	0	17
63678	2020-05-16 17:17:52	2020-05-16	8	[{"id_menu":5,"count":1}]	11634	pick-up	0	8
63679	2020-05-16 17:21:46	2020-05-16	9	[{"id_menu":7,"count":1}]	25248	delivery	5	14
63680	2020-05-16 17:24:13	2020-05-16	9	[{"id_menu":6,"count":1}]	5478	delivery	5	14
63681	2020-05-16 17:34:02	2020-05-16	17	[{"id_menu":4,"count":1}]	25266	delivery	5	22
63682	2020-05-16 17:34:58	2020-05-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	22774	delivery	5	28
63683	2020-05-16 17:41:44	2020-05-16	12	[{"id_menu":1,"count":1}]	25265	delivery	5	17
63684	2020-05-16 17:42:32	2020-05-16	8	[{"id_menu":5,"count":1}]	14081	pick-up	0	8
63685	2020-05-16 17:44:49	2020-05-16	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11624	delivery	5	35
63686	2020-05-16 17:46:33	2020-05-16	9	[{"id_menu":6,"count":1}]	3324	pick-up	0	9
63687	2020-05-16 17:48:38	2020-05-16	12	[{"id_menu":3,"count":1}]	23754	delivery	5	17
63688	2020-05-16 17:53:55	2020-05-16	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	20818	delivery	5	23
63689	2020-05-16 17:56:39	2020-05-16	12	[{"id_menu":1,"count":1}]	13441	delivery	5	17
63690	2020-05-16 17:57:43	2020-05-16	9	[{"id_menu":6,"count":1}]	25107	delivery	5	14
63691	2020-05-16 17:59:26	2020-05-16	12	[{"id_menu":1,"count":1}]	20739	delivery	5	17
63692	2020-05-16 18:01:58	2020-05-16	12	[{"id_menu":1,"count":1}]	9011	delivery	5	17
63693	2020-05-16 18:07:34	2020-05-16	9	[{"id_menu":6,"count":2}]	18099	delivery	5	14
63694	2020-05-16 18:14:04	2020-05-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	23992	delivery	5	31
63695	2020-05-16 18:19:24	2020-05-16	12	[{"id_menu":1,"count":1}]	19064	pick-up	0	12
63696	2020-05-16 18:19:27	2020-05-16	14	[{"id_menu":2,"count":1}]	25271	delivery	5	19
63697	2020-05-16 18:19:35	2020-05-16	9	[{"id_menu":7,"count":1}]	18297	delivery	5	14
63698	2020-05-16 18:20:24	2020-05-16	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	25115	delivery	5	29
63699	2020-05-16 18:24:28	2020-05-16	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	9650	delivery	5	34
63700	2020-05-16 18:26:56	2020-05-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	24794	delivery	5	26
63701	2020-05-16 18:29:36	2020-05-16	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	22177	delivery	5	44
63702	2020-05-16 18:34:50	2020-05-16	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	4592	delivery	5	34
63703	2020-05-16 18:37:58	2020-05-16	9	[{"id_menu":7,"count":1}]	2214	delivery	5	14
63704	2020-05-16 18:39:56	2020-05-16	12	[{"id_menu":3,"count":1}]	4480	pick-up	0	12
63705	2020-05-16 18:41:05	2020-05-16	17	[{"id_menu":4,"count":1}]	15302	delivery	5	22
63706	2020-05-16 18:41:22	2020-05-16	17	[{"id_menu":4,"count":1}]	15864	delivery	5	22
63707	2020-05-16 18:42:15	2020-05-16	14	[{"id_menu":2,"count":1}]	5701	pick-up	0	14
63708	2020-05-16 18:42:52	2020-05-16	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25270	delivery	5	34
63709	2020-05-16 18:42:59	2020-05-16	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1684	pick-up	0	32
63710	2020-05-16 18:46:03	2020-05-16	12	[{"id_menu":1,"count":1}]	6290	pick-up	0	12
63711	2020-05-16 18:50:38	2020-05-16	9	[{"id_menu":6,"count":1}]	7734	delivery	5	14
63712	2020-05-16 18:51:02	2020-05-16	9	[{"id_menu":6,"count":2}]	2323	delivery	5	14
63713	2020-05-16 18:53:48	2020-05-16	12	[{"id_menu":3,"count":1}]	25163	pick-up	0	12
63714	2020-05-16 18:54:39	2020-05-16	8	[{"id_menu":5,"count":1}]	25251	delivery	5	13
63715	2020-05-16 18:55:06	2020-05-16	17	[{"id_menu":4,"count":1}]	24690	delivery	5	22
63716	2020-05-16 18:58:09	2020-05-16	9	[{"id_menu":6,"count":1}]	25261	delivery	5	14
63717	2020-05-16 18:58:18	2020-05-16	17	[{"id_menu":4,"count":1}]	25264	delivery	5	22
63718	2020-05-16 19:00:25	2020-05-16	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2582	pick-up	0	22
63719	2020-05-16 19:03:53	2020-05-16	12	[{"id_menu":1,"count":1}]	71	delivery	5	17
63720	2020-05-16 19:05:29	2020-05-16	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	14284	pick-up	0	25
63721	2020-05-16 19:08:05	2020-05-16	9	[{"id_menu":7,"count":1}]	23177	delivery	5	14
63722	2020-05-16 19:09:29	2020-05-16	9	[{"id_menu":6,"count":1}]	17472	pick-up	0	9
63723	2020-05-16 19:18:23	2020-05-16	14	[{"id_menu":2,"count":1}]	17073	delivery	5	19
63724	2020-05-16 19:18:54	2020-05-16	8	[{"id_menu":5,"count":1}]	1100	delivery	5	13
63725	2020-05-16 19:21:18	2020-05-16	9	[{"id_menu":6,"count":1}]	1593	pick-up	0	9
63726	2020-05-16 19:22:34	2020-05-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25225	delivery	5	23
63727	2020-05-16 19:25:34	2020-05-16	9	[{"id_menu":7,"count":1}]	258	delivery	5	14
63728	2020-05-16 19:27:45	2020-05-16	9	[{"id_menu":6,"count":1}]	17366	delivery	5	14
63729	2020-05-16 19:32:28	2020-05-16	8	[{"id_menu":5,"count":1}]	25197	delivery	5	13
63730	2020-05-16 19:35:54	2020-05-16	8	[{"id_menu":5,"count":1}]	25185	pick-up	0	8
63731	2020-05-16 19:36:03	2020-05-16	9	[{"id_menu":7,"count":1}]	12562	delivery	5	14
63732	2020-05-16 19:39:18	2020-05-16	9	[{"id_menu":6,"count":1}]	16456	delivery	5	14
63733	2020-05-16 19:39:33	2020-05-16	8	[{"id_menu":5,"count":1}]	12664	delivery	5	13
63734	2020-05-16 19:39:52	2020-05-16	14	[{"id_menu":2,"count":1}]	25127	delivery	5	19
63735	2020-05-16 19:40:04	2020-05-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	8098	delivery	5	26
63736	2020-05-16 19:40:56	2020-05-16	12	[{"id_menu":3,"count":1}]	9211	delivery	5	17
63737	2020-05-16 19:41:42	2020-05-16	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	25209	delivery	5	34
63738	2020-05-16 19:42:38	2020-05-16	17	[{"id_menu":4,"count":1}]	25168	delivery	5	22
63739	2020-05-16 19:45:59	2020-05-16	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	25267	delivery	5	45
63740	2020-05-16 19:47:06	2020-05-16	9	[{"id_menu":6,"count":2}]	3218	delivery	5	14
63741	2020-05-16 19:53:56	2020-05-16	8	[{"id_menu":5,"count":1}]	20656	delivery	5	13
63742	2020-05-16 19:58:25	2020-05-16	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25140	delivery	5	31
63743	2020-05-16 20:00:46	2020-05-16	9	[{"id_menu":6,"count":1}]	25234	delivery	5	14
63744	2020-05-16 20:03:51	2020-05-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	10122	delivery	5	28
63745	2020-05-16 20:04:50	2020-05-16	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	25138	delivery	5	29
63746	2020-05-16 20:05:23	2020-05-16	9	[{"id_menu":6,"count":2}]	12713	delivery	5	14
63747	2020-05-16 20:12:57	2020-05-16	9	[{"id_menu":7,"count":1}]	13335	pick-up	0	9
63748	2020-05-16 20:14:18	2020-05-16	14	[{"id_menu":2,"count":1}]	3564	pick-up	0	14
63749	2020-05-16 20:15:52	2020-05-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2687	delivery	5	22
63750	2020-05-16 20:16:58	2020-05-16	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9669	delivery	5	22
63751	2020-05-16 20:20:35	2020-05-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	25256	delivery	5	28
63752	2020-05-16 20:23:10	2020-05-16	17	[{"id_menu":4,"count":1}]	2426	pick-up	0	17
63753	2020-05-16 20:24:28	2020-05-16	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3534	delivery	5	22
63754	2020-05-16 20:25:59	2020-05-16	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	25253	delivery	5	30
63755	2020-05-16 20:26:02	2020-05-16	9	[{"id_menu":7,"count":1}]	24466	delivery	5	14
63756	2020-05-16 20:26:48	2020-05-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	25132	delivery	5	26
63757	2020-05-16 20:30:00	2020-05-16	9	[{"id_menu":7,"count":1}]	15159	delivery	5	14
63758	2020-05-16 20:31:14	2020-05-16	12	[{"id_menu":3,"count":2}]	2283	pick-up	0	12
63759	2020-05-16 20:34:20	2020-05-16	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25106	delivery	5	35
63760	2020-05-16 20:36:02	2020-05-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":3}]	19939	delivery	5	22
63761	2020-05-16 20:36:50	2020-05-16	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	25202	delivery	5	25
63762	2020-05-16 20:38:50	2020-05-16	9	[{"id_menu":7,"count":1}]	18948	delivery	5	14
63763	2020-05-16 20:45:01	2020-05-16	17	[{"id_menu":4,"count":2}]	1562	pick-up	0	17
63764	2020-05-16 20:50:51	2020-05-16	8	[{"id_menu":5,"count":1}]	15763	delivery	5	13
63765	2020-05-16 20:52:28	2020-05-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	25103	delivery	5	31
63766	2020-05-16 20:52:38	2020-05-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	25235	delivery	5	28
63767	2020-05-16 20:57:21	2020-05-16	9	[{"id_menu":7,"count":1}]	25203	delivery	5	14
63768	2020-05-16 21:02:20	2020-05-16	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	25112	delivery	5	39
63769	2020-05-16 21:12:26	2020-05-16	9	[{"id_menu":6,"count":1}]	1393	delivery	5	14
63770	2020-05-16 21:13:23	2020-05-16	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	25204	delivery	5	43
63771	2020-05-16 21:18:13	2020-05-16	9	[{"id_menu":6,"count":1}]	25117	pick-up	0	9
63772	2020-05-16 21:20:20	2020-05-16	14	[{"id_menu":2,"count":1}]	25113	delivery	5	19
63773	2020-05-16 21:21:04	2020-05-16	17	[{"id_menu":4,"count":1}]	25139	delivery	5	22
63774	2020-05-16 21:21:21	2020-05-16	8	[{"id_menu":5,"count":1}]	25237	delivery	5	13
63775	2020-05-16 21:22:24	2020-05-16	9	[{"id_menu":6,"count":1}]	2080	pick-up	0	9
63776	2020-05-16 21:24:27	2020-05-16	12	[{"id_menu":1,"count":1}]	25166	delivery	5	17
63777	2020-05-16 21:25:19	2020-05-16	9	[{"id_menu":6,"count":1}]	20074	pick-up	0	9
63778	2020-05-16 21:26:19	2020-05-16	17	[{"id_menu":4,"count":2}]	5406	delivery	5	22
63779	2020-05-16 21:28:23	2020-05-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23502	delivery	5	22
63780	2020-05-16 21:30:36	2020-05-16	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	25257	delivery	5	26
63781	2020-05-16 21:32:15	2020-05-16	9	[{"id_menu":7,"count":1}]	25164	delivery	5	14
63782	2020-05-16 21:32:29	2020-05-16	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	13751	pick-up	0	26
63783	2020-05-16 21:32:41	2020-05-16	8	[{"id_menu":5,"count":2}]	2805	delivery	5	13
63784	2020-05-16 21:34:03	2020-05-16	17	[{"id_menu":4,"count":2}]	13477	pick-up	0	17
63785	2020-05-16 21:36:31	2020-05-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1481	pick-up	0	23
63786	2020-05-16 21:40:39	2020-05-16	17	[{"id_menu":4,"count":1}]	22391	delivery	5	22
63787	2020-05-16 21:41:29	2020-05-16	12	[{"id_menu":1,"count":1}]	2618	delivery	5	17
63788	2020-05-16 21:42:15	2020-05-16	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10235	delivery	5	39
63789	2020-05-16 21:47:53	2020-05-16	14	[{"id_menu":2,"count":2}]	2021	pick-up	0	14
63790	2020-05-16 21:47:59	2020-05-16	9	[{"id_menu":7,"count":1}]	17653	delivery	5	14
63791	2020-05-16 21:50:05	2020-05-16	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	15120	pick-up	0	21
63792	2020-05-16 21:51:16	2020-05-16	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25200	delivery	5	39
63793	2020-05-16 21:57:14	2020-05-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5361	pick-up	0	23
63794	2020-05-16 21:57:56	2020-05-16	17	[{"id_menu":4,"count":1}]	25247	delivery	5	22
63795	2020-05-16 21:58:59	2020-05-16	9	[{"id_menu":7,"count":1}]	24431	delivery	5	14
63796	2020-05-16 22:03:37	2020-05-16	17	[{"id_menu":4,"count":1}]	25213	delivery	5	22
63797	2020-05-16 22:03:47	2020-05-16	17	[{"id_menu":4,"count":1}]	12260	delivery	5	22
63798	2020-05-16 22:04:58	2020-05-16	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4246	pick-up	0	35
63799	2020-05-16 22:07:55	2020-05-16	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	15042	delivery	5	45
63800	2020-05-16 22:08:04	2020-05-16	12	[{"id_menu":3,"count":1}]	25236	pick-up	0	12
63801	2020-05-16 22:09:06	2020-05-16	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	22935	delivery	5	40
63802	2020-05-16 22:09:12	2020-05-16	12	[{"id_menu":3,"count":1}]	19432	delivery	5	17
63803	2020-05-16 22:11:10	2020-05-16	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	3658	delivery	5	27
63804	2020-05-16 22:13:43	2020-05-16	9	[{"id_menu":7,"count":1}]	1896	pick-up	0	9
63805	2020-05-16 22:30:11	2020-05-16	9	[{"id_menu":6,"count":2}]	13458	delivery	5	14
63806	2020-05-16 22:30:39	2020-05-16	8	[{"id_menu":5,"count":1}]	4056	delivery	5	13
63807	2020-05-16 22:34:46	2020-05-16	9	[{"id_menu":6,"count":1}]	24187	delivery	5	14
63808	2020-05-16 22:48:42	2020-05-16	17	[{"id_menu":4,"count":1}]	1687	delivery	5	22
63809	2020-05-16 22:50:52	2020-05-16	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	25206	delivery	5	44
63810	2020-05-16 23:01:17	2020-05-16	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5606	delivery	5	36
63811	2020-05-16 23:03:38	2020-05-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	25176	delivery	5	28
63812	2020-05-16 23:03:54	2020-05-16	8	[{"id_menu":5,"count":1}]	19243	pick-up	0	8
63813	2020-05-16 23:03:59	2020-05-16	9	[{"id_menu":6,"count":1}]	11039	delivery	5	14
63814	2020-05-16 23:10:39	2020-05-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	25114	delivery	5	31
63815	2020-05-16 23:11:43	2020-05-16	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	21142	delivery	5	34
63816	2020-05-16 23:12:13	2020-05-16	9	[{"id_menu":7,"count":1}]	16829	delivery	5	14
63817	2020-05-16 23:12:35	2020-05-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3332	pick-up	0	26
63818	2020-05-16 23:14:02	2020-05-16	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6143	delivery	5	36
63819	2020-05-16 23:14:17	2020-05-16	9	[{"id_menu":7,"count":1}]	2370	pick-up	0	9
63820	2020-05-16 23:15:37	2020-05-16	8	[{"id_menu":5,"count":1}]	14165	delivery	5	13
63821	2020-05-16 23:22:35	2020-05-16	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	7527	delivery	5	29
63822	2020-05-16 23:22:39	2020-05-16	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	11148	delivery	5	26
63823	2020-05-16 23:23:35	2020-05-16	14	[{"id_menu":2,"count":1}]	8702	delivery	5	19
63824	2020-05-16 23:24:43	2020-05-16	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13159	delivery	5	35
63825	2020-05-16 23:25:48	2020-05-16	9	[{"id_menu":7,"count":1}]	25274	delivery	5	14
63826	2020-05-16 23:26:38	2020-05-16	14	[{"id_menu":2,"count":1}]	25125	delivery	5	19
63827	2020-05-16 23:27:50	2020-05-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8145	delivery	5	28
63828	2020-05-16 23:29:17	2020-05-16	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	9440	delivery	5	34
63829	2020-05-16 23:30:18	2020-05-16	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13685	delivery	5	48
63830	2020-05-16 23:34:24	2020-05-16	12	[{"id_menu":3,"count":1}]	14299	delivery	5	17
63831	2020-05-16 23:34:26	2020-05-16	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	25191	delivery	5	27
63832	2020-05-16 23:36:16	2020-05-16	12	[{"id_menu":1,"count":1}]	11926	pick-up	0	12
63833	2020-05-16 23:41:18	2020-05-16	12	[{"id_menu":1,"count":1}]	25105	delivery	5	17
63834	2020-05-16 23:47:17	2020-05-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	25275	delivery	5	31
63835	2020-05-16 23:51:05	2020-05-16	8	[{"id_menu":5,"count":1}]	4912	delivery	5	13
63836	2020-05-16 23:51:55	2020-05-16	17	[{"id_menu":4,"count":1}]	14913	delivery	5	22
63837	2020-05-16 23:52:28	2020-05-16	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	23132	delivery	5	40
63838	2020-05-16 23:53:32	2020-05-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6818	delivery	5	23
63839	2020-05-16 23:53:57	2020-05-16	9	[{"id_menu":7,"count":1}]	25136	delivery	5	14
63840	2020-05-16 23:54:39	2020-05-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	20407	delivery	5	28
63841	2020-05-17 00:00:49	2020-05-17	9	[{"id_menu":6,"count":1}]	25085	delivery	5	14
63842	2020-05-17 00:01:06	2020-05-17	14	[{"id_menu":2,"count":1}]	14358	pick-up	0	14
63911	2020-05-17 03:09:39	2020-05-17	9	[{"id_menu":7,"count":1}]	25401	pick-up	0	9
63843	2020-05-17 00:01:36	2020-05-17	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19783	delivery	5	34
63844	2020-05-17 00:03:36	2020-05-17	8	[{"id_menu":5,"count":1}]	22572	delivery	5	13
63845	2020-05-17 00:11:44	2020-05-17	9	[{"id_menu":6,"count":1}]	25329	delivery	5	14
63846	2020-05-17 00:12:30	2020-05-17	8	[{"id_menu":5,"count":1}]	23784	pick-up	0	8
63847	2020-05-17 00:15:18	2020-05-17	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	10560	delivery	5	28
63848	2020-05-17 00:17:50	2020-05-17	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	14695	delivery	5	44
63849	2020-05-17 00:23:58	2020-05-17	9	[{"id_menu":6,"count":1}]	12818	delivery	5	14
63850	2020-05-17 00:25:34	2020-05-17	17	[{"id_menu":4,"count":1}]	25357	pick-up	0	17
63851	2020-05-17 00:28:52	2020-05-17	14	[{"id_menu":2,"count":1}]	14086	pick-up	0	14
63852	2020-05-17 00:31:53	2020-05-17	9	[{"id_menu":6,"count":1}]	12129	pick-up	0	9
63853	2020-05-17 00:33:51	2020-05-17	9	[{"id_menu":7,"count":2}]	24819	delivery	5	14
63854	2020-05-17 00:34:29	2020-05-17	9	[{"id_menu":6,"count":1}]	2846	delivery	5	14
63855	2020-05-17 00:34:35	2020-05-17	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	757	pick-up	0	21
63856	2020-05-17 00:35:17	2020-05-17	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	229	pick-up	0	29
63857	2020-05-17 00:35:43	2020-05-17	9	[{"id_menu":6,"count":1}]	48	delivery	5	14
63858	2020-05-17 00:42:50	2020-05-17	12	[{"id_menu":3,"count":1}]	13984	delivery	5	17
63859	2020-05-17 00:44:40	2020-05-17	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":2}]	5585	delivery	5	26
63860	2020-05-17 00:46:19	2020-05-17	8	[{"id_menu":5,"count":1}]	25388	delivery	5	13
63861	2020-05-17 00:49:26	2020-05-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	12344	delivery	5	28
63862	2020-05-17 00:52:58	2020-05-17	9	[{"id_menu":6,"count":1}]	721	delivery	5	14
63863	2020-05-17 00:58:52	2020-05-17	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	25325	pick-up	0	46
63864	2020-05-17 01:00:01	2020-05-17	9	[{"id_menu":6,"count":1}]	25431	delivery	5	14
63865	2020-05-17 01:00:19	2020-05-17	17	[{"id_menu":4,"count":1}]	22433	delivery	5	22
63866	2020-05-17 01:01:15	2020-05-17	14	[{"id_menu":2,"count":1}]	25422	delivery	5	19
63867	2020-05-17 01:02:40	2020-05-17	9	[{"id_menu":7,"count":1}]	4021	delivery	5	14
63868	2020-05-17 01:06:23	2020-05-17	14	[{"id_menu":2,"count":1}]	25338	delivery	5	19
63869	2020-05-17 01:06:25	2020-05-17	12	[{"id_menu":1,"count":2}]	3624	pick-up	0	12
63870	2020-05-17 01:09:39	2020-05-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	6953	delivery	5	28
63871	2020-05-17 01:14:37	2020-05-17	12	[{"id_menu":3,"count":1}]	16358	delivery	5	17
63872	2020-05-17 01:18:18	2020-05-17	12	[{"id_menu":1,"count":1}]	1685	pick-up	0	12
63873	2020-05-17 01:21:49	2020-05-17	12	[{"id_menu":3,"count":1}]	10303	delivery	5	17
63874	2020-05-17 01:24:36	2020-05-17	12	[{"id_menu":1,"count":1}]	1832	pick-up	0	12
63875	2020-05-17 01:25:43	2020-05-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18307	delivery	5	23
63876	2020-05-17 01:27:55	2020-05-17	9	[{"id_menu":7,"count":1}]	11509	pick-up	0	9
63877	2020-05-17 01:31:12	2020-05-17	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	24297	delivery	5	39
63878	2020-05-17 01:32:00	2020-05-17	9	[{"id_menu":7,"count":1}]	24597	pick-up	0	9
63879	2020-05-17 01:36:13	2020-05-17	17	[{"id_menu":4,"count":1}]	5509	delivery	5	22
63880	2020-05-17 01:38:20	2020-05-17	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	25286	delivery	5	26
63881	2020-05-17 01:40:49	2020-05-17	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24538	delivery	5	53
63882	2020-05-17 01:41:03	2020-05-17	9	[{"id_menu":7,"count":1}]	22096	delivery	5	14
63883	2020-05-17 01:42:57	2020-05-17	12	[{"id_menu":3,"count":1}]	25370	delivery	5	17
63884	2020-05-17 01:46:17	2020-05-17	9	[{"id_menu":6,"count":1}]	11332	pick-up	0	9
63885	2020-05-17 01:46:52	2020-05-17	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2208	pick-up	0	17
63886	2020-05-17 01:50:40	2020-05-17	14	[{"id_menu":2,"count":1}]	15535	pick-up	0	14
63887	2020-05-17 01:51:28	2020-05-17	8	[{"id_menu":5,"count":1}]	15161	delivery	5	13
63888	2020-05-17 01:52:00	2020-05-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7383	pick-up	0	26
63889	2020-05-17 01:53:23	2020-05-17	12	[{"id_menu":3,"count":1}]	1526	pick-up	0	12
63890	2020-05-17 01:55:28	2020-05-17	12	[{"id_menu":3,"count":1}]	25330	delivery	5	17
63891	2020-05-17 01:58:32	2020-05-17	17	[{"id_menu":4,"count":1}]	3647	pick-up	0	17
63892	2020-05-17 02:05:34	2020-05-17	12	[{"id_menu":1,"count":1}]	25292	delivery	5	17
63893	2020-05-17 02:09:05	2020-05-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3393	delivery	5	28
63894	2020-05-17 02:09:08	2020-05-17	14	[{"id_menu":2,"count":1}]	25314	delivery	5	19
63895	2020-05-17 02:12:21	2020-05-17	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	25282	pick-up	0	26
63896	2020-05-17 02:16:01	2020-05-17	8	[{"id_menu":5,"count":1}]	20729	delivery	5	13
63897	2020-05-17 02:20:35	2020-05-17	12	[{"id_menu":3,"count":1}]	20739	delivery	5	17
63898	2020-05-17 02:29:28	2020-05-17	8	[{"id_menu":5,"count":1}]	25337	delivery	5	13
63899	2020-05-17 02:30:29	2020-05-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9738	pick-up	0	18
63900	2020-05-17 02:31:40	2020-05-17	9	[{"id_menu":7,"count":1}]	23999	delivery	5	14
63901	2020-05-17 02:33:27	2020-05-17	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7594	delivery	5	36
63902	2020-05-17 02:34:43	2020-05-17	9	[{"id_menu":6,"count":1}]	6068	delivery	5	14
63903	2020-05-17 02:42:01	2020-05-17	8	[{"id_menu":5,"count":1}]	13829	delivery	5	13
63904	2020-05-17 02:51:08	2020-05-17	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	22414	delivery	5	26
63905	2020-05-17 02:51:52	2020-05-17	9	[{"id_menu":7,"count":1}]	25355	delivery	5	14
63906	2020-05-17 03:00:50	2020-05-17	8	[{"id_menu":5,"count":1}]	25397	delivery	5	13
63907	2020-05-17 03:01:10	2020-05-17	12	[{"id_menu":1,"count":1}]	25279	pick-up	0	12
63908	2020-05-17 03:01:33	2020-05-17	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12592	delivery	5	47
63909	2020-05-17 03:02:01	2020-05-17	12	[{"id_menu":3,"count":1}]	16572	delivery	5	17
63910	2020-05-17 03:08:39	2020-05-17	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	25378	delivery	5	40
63912	2020-05-17 03:10:13	2020-05-17	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	18959	delivery	5	26
63913	2020-05-17 03:17:06	2020-05-17	9	[{"id_menu":7,"count":1}]	21995	delivery	5	14
63914	2020-05-17 03:20:18	2020-05-17	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	25395	delivery	5	31
63915	2020-05-17 03:24:03	2020-05-17	9	[{"id_menu":6,"count":1}]	15929	delivery	5	14
63916	2020-05-17 03:24:05	2020-05-17	8	[{"id_menu":5,"count":2}]	15615	delivery	5	13
63917	2020-05-17 03:25:42	2020-05-17	12	[{"id_menu":1,"count":1}]	8635	delivery	5	17
63918	2020-05-17 03:26:14	2020-05-17	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	440	delivery	5	25
63919	2020-05-17 03:27:43	2020-05-17	9	[{"id_menu":6,"count":1}]	15659	delivery	5	14
63920	2020-05-17 03:29:18	2020-05-17	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	11419	delivery	5	31
63921	2020-05-17 03:30:10	2020-05-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	25363	delivery	5	31
63922	2020-05-17 03:36:20	2020-05-17	12	[{"id_menu":1,"count":1}]	4044	delivery	5	17
63923	2020-05-17 03:40:03	2020-05-17	8	[{"id_menu":5,"count":1}]	25383	delivery	5	13
63924	2020-05-17 03:44:22	2020-05-17	8	[{"id_menu":5,"count":2}]	25402	delivery	5	13
63925	2020-05-17 03:45:17	2020-05-17	12	[{"id_menu":3,"count":1}]	17318	delivery	5	17
63926	2020-05-17 03:45:55	2020-05-17	9	[{"id_menu":6,"count":1}]	19137	pick-up	0	9
63927	2020-05-17 03:46:29	2020-05-17	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":2}]	14183	delivery	5	22
63928	2020-05-17 03:47:18	2020-05-17	8	[{"id_menu":5,"count":1}]	1792	pick-up	0	8
63929	2020-05-17 03:49:04	2020-05-17	17	[{"id_menu":4,"count":1}]	24725	pick-up	0	17
63930	2020-05-17 03:53:02	2020-05-17	9	[{"id_menu":6,"count":1}]	14146	pick-up	0	9
63931	2020-05-17 03:54:17	2020-05-17	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	14999	delivery	5	39
63932	2020-05-17 03:56:16	2020-05-17	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	5642	pick-up	0	21
63933	2020-05-17 03:56:38	2020-05-17	14	[{"id_menu":2,"count":1}]	18332	delivery	5	19
63934	2020-05-17 03:56:46	2020-05-17	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	25420	delivery	5	34
63935	2020-05-17 03:57:14	2020-05-17	9	[{"id_menu":6,"count":1}]	25377	delivery	5	14
63936	2020-05-17 03:59:35	2020-05-17	14	[{"id_menu":2,"count":1}]	11983	delivery	5	19
63937	2020-05-17 04:01:00	2020-05-17	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	19686	delivery	5	26
63938	2020-05-17 04:01:50	2020-05-17	8	[{"id_menu":5,"count":1}]	25352	delivery	5	13
63939	2020-05-17 04:04:35	2020-05-17	9	[{"id_menu":6,"count":1}]	2076	pick-up	0	9
63940	2020-05-17 04:05:23	2020-05-17	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	23939	pick-up	0	29
63941	2020-05-17 04:05:42	2020-05-17	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	25358	delivery	5	22
63942	2020-05-17 04:07:40	2020-05-17	9	[{"id_menu":7,"count":1}]	8205	delivery	5	14
63943	2020-05-17 04:14:02	2020-05-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	15314	delivery	5	28
63944	2020-05-17 04:15:15	2020-05-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	20819	delivery	5	28
63945	2020-05-17 04:16:54	2020-05-17	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9669	delivery	5	30
63946	2020-05-17 04:17:22	2020-05-17	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	7293	delivery	5	26
63947	2020-05-17 04:17:24	2020-05-17	12	[{"id_menu":1,"count":1}]	10741	pick-up	0	12
63948	2020-05-17 04:18:15	2020-05-17	9	[{"id_menu":7,"count":2}]	19213	delivery	5	14
63949	2020-05-17 04:22:48	2020-05-17	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24040	delivery	5	53
63950	2020-05-17 04:26:51	2020-05-17	12	[{"id_menu":3,"count":1}]	5206	delivery	5	17
63951	2020-05-17 04:28:45	2020-05-17	9	[{"id_menu":6,"count":1}]	25436	delivery	5	14
63952	2020-05-17 04:31:24	2020-05-17	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12755	delivery	5	57
63953	2020-05-17 04:31:27	2020-05-17	9	[{"id_menu":6,"count":1}]	10212	pick-up	0	9
63954	2020-05-17 04:31:33	2020-05-17	9	[{"id_menu":6,"count":1}]	16450	delivery	5	14
63955	2020-05-17 04:32:38	2020-05-17	12	[{"id_menu":1,"count":1}]	8064	delivery	5	17
63956	2020-05-17 04:36:57	2020-05-17	17	[{"id_menu":4,"count":2}]	13335	pick-up	0	17
63957	2020-05-17 04:38:15	2020-05-17	9	[{"id_menu":6,"count":1}]	17392	pick-up	0	9
63958	2020-05-17 04:40:28	2020-05-17	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	25318	pick-up	0	34
63959	2020-05-17 04:42:28	2020-05-17	9	[{"id_menu":6,"count":1}]	12108	pick-up	0	9
63960	2020-05-17 04:51:32	2020-05-17	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	8863	pick-up	0	21
63961	2020-05-17 04:51:46	2020-05-17	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10597	delivery	5	34
63962	2020-05-17 04:52:24	2020-05-17	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21749	delivery	5	51
63963	2020-05-17 05:00:27	2020-05-17	8	[{"id_menu":5,"count":1}]	13082	delivery	5	13
63964	2020-05-17 05:02:00	2020-05-17	9	[{"id_menu":7,"count":1}]	20741	delivery	5	14
63965	2020-05-17 05:03:06	2020-05-17	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	10266	delivery	5	29
63966	2020-05-17 05:05:11	2020-05-17	17	[{"id_menu":4,"count":1}]	14776	delivery	5	22
63967	2020-05-17 05:06:10	2020-05-17	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24310	pick-up	0	17
63968	2020-05-17 05:07:12	2020-05-17	9	[{"id_menu":6,"count":1}]	17923	delivery	5	14
63969	2020-05-17 05:08:33	2020-05-17	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	25312	delivery	5	26
63970	2020-05-17 05:10:20	2020-05-17	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	15956	pick-up	0	21
63971	2020-05-17 05:14:44	2020-05-17	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	15407	delivery	5	36
63972	2020-05-17 05:16:55	2020-05-17	8	[{"id_menu":5,"count":1}]	25354	delivery	5	13
63973	2020-05-17 05:19:28	2020-05-17	12	[{"id_menu":1,"count":1}]	7832	delivery	5	17
63974	2020-05-17 05:22:02	2020-05-17	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3125	delivery	5	26
63975	2020-05-17 05:25:06	2020-05-17	9	[{"id_menu":6,"count":1}]	6331	delivery	5	14
63976	2020-05-17 05:25:49	2020-05-17	9	[{"id_menu":6,"count":1}]	22201	delivery	5	14
63977	2020-05-17 05:27:48	2020-05-17	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	25412	pick-up	0	35
63978	2020-05-17 05:28:34	2020-05-17	9	[{"id_menu":7,"count":1}]	8973	delivery	5	14
63979	2020-05-17 05:29:50	2020-05-17	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15326	pick-up	0	29
63980	2020-05-17 05:31:01	2020-05-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17812	pick-up	0	18
63981	2020-05-17 05:32:08	2020-05-17	8	[{"id_menu":5,"count":1}]	3808	delivery	5	13
63982	2020-05-17 05:35:17	2020-05-17	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	19976	delivery	5	48
63983	2020-05-17 05:38:18	2020-05-17	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	20170	delivery	5	52
63984	2020-05-17 05:38:24	2020-05-17	8	[{"id_menu":5,"count":1}]	25291	delivery	5	13
63985	2020-05-17 05:42:13	2020-05-17	12	[{"id_menu":1,"count":1}]	25373	pick-up	0	12
63986	2020-05-17 05:44:37	2020-05-17	17	[{"id_menu":4,"count":1}]	25288	pick-up	0	17
63987	2020-05-17 05:47:31	2020-05-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25376	delivery	5	23
63988	2020-05-17 05:50:36	2020-05-17	17	[{"id_menu":4,"count":1}]	24070	pick-up	0	17
63989	2020-05-17 05:52:16	2020-05-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	18529	delivery	5	28
63990	2020-05-17 05:52:43	2020-05-17	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	8988	delivery	5	27
63991	2020-05-17 05:53:48	2020-05-17	9	[{"id_menu":7,"count":1}]	4351	pick-up	0	9
63992	2020-05-17 05:59:18	2020-05-17	9	[{"id_menu":7,"count":1}]	21273	pick-up	0	9
63993	2020-05-17 05:59:35	2020-05-17	9	[{"id_menu":6,"count":1}]	21825	pick-up	0	9
63994	2020-05-17 06:01:10	2020-05-17	9	[{"id_menu":6,"count":1}]	20473	delivery	5	14
63995	2020-05-17 06:01:19	2020-05-17	17	[{"id_menu":4,"count":1}]	25438	delivery	5	22
63996	2020-05-17 06:06:00	2020-05-17	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	22952	pick-up	0	38
63997	2020-05-17 06:13:05	2020-05-17	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	25302	delivery	5	31
63998	2020-05-17 06:16:47	2020-05-17	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	25323	delivery	5	26
63999	2020-05-17 06:17:48	2020-05-17	8	[{"id_menu":5,"count":1}]	11254	delivery	5	13
64000	2020-05-17 06:19:12	2020-05-17	9	[{"id_menu":7,"count":1}]	18013	delivery	5	14
64001	2020-05-17 06:20:18	2020-05-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7483	delivery	5	23
64002	2020-05-17 06:22:17	2020-05-17	12	[{"id_menu":3,"count":1}]	25419	delivery	5	17
64003	2020-05-17 06:26:20	2020-05-17	17	[{"id_menu":4,"count":2}]	14065	pick-up	0	17
64004	2020-05-17 06:26:49	2020-05-17	14	[{"id_menu":2,"count":1}]	15539	delivery	5	19
64005	2020-05-17 06:27:49	2020-05-17	9	[{"id_menu":7,"count":1}]	25391	delivery	5	14
64006	2020-05-17 06:28:26	2020-05-17	9	[{"id_menu":7,"count":1}]	25408	delivery	5	14
64007	2020-05-17 06:31:18	2020-05-17	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25371	delivery	5	36
64008	2020-05-17 06:34:29	2020-05-17	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2708	delivery	5	31
64009	2020-05-17 06:34:55	2020-05-17	9	[{"id_menu":6,"count":1}]	25365	delivery	5	14
64010	2020-05-17 06:42:54	2020-05-17	14	[{"id_menu":2,"count":1}]	5370	delivery	5	19
64011	2020-05-17 06:44:41	2020-05-17	9	[{"id_menu":7,"count":1}]	24356	delivery	5	14
64012	2020-05-17 06:46:13	2020-05-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	13523	delivery	5	28
64013	2020-05-17 06:50:16	2020-05-17	17	[{"id_menu":4,"count":1}]	20598	pick-up	0	17
64014	2020-05-17 06:50:28	2020-05-17	9	[{"id_menu":7,"count":1}]	16045	delivery	5	14
64015	2020-05-17 06:52:22	2020-05-17	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	15059	delivery	5	39
64016	2020-05-17 06:53:15	2020-05-17	12	[{"id_menu":1,"count":1}]	6055	delivery	5	17
64017	2020-05-17 06:54:13	2020-05-17	8	[{"id_menu":5,"count":1}]	11799	delivery	5	13
64018	2020-05-17 06:57:26	2020-05-17	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17153	delivery	5	31
64019	2020-05-17 07:03:22	2020-05-17	12	[{"id_menu":1,"count":1}]	25324	pick-up	0	12
64020	2020-05-17 07:04:33	2020-05-17	8	[{"id_menu":5,"count":1}]	2931	delivery	5	13
64021	2020-05-17 07:07:48	2020-05-17	8	[{"id_menu":5,"count":1}]	3579	delivery	5	13
64022	2020-05-17 07:09:59	2020-05-17	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25437	delivery	5	22
64023	2020-05-17 07:10:13	2020-05-17	9	[{"id_menu":7,"count":1}]	25301	pick-up	0	9
64024	2020-05-17 07:11:02	2020-05-17	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23642	delivery	5	34
64025	2020-05-17 07:11:07	2020-05-17	9	[{"id_menu":7,"count":1}]	4096	pick-up	0	9
64026	2020-05-17 07:13:36	2020-05-17	12	[{"id_menu":1,"count":1}]	8229	delivery	5	17
64027	2020-05-17 07:13:48	2020-05-17	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	25283	delivery	5	42
64028	2020-05-17 07:14:26	2020-05-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14291	delivery	5	23
64029	2020-05-17 07:17:31	2020-05-17	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	22393	delivery	5	25
64030	2020-05-17 07:17:55	2020-05-17	12	[{"id_menu":3,"count":1}]	23979	pick-up	0	12
64031	2020-05-17 07:22:39	2020-05-17	9	[{"id_menu":7,"count":1}]	23824	delivery	5	14
64032	2020-05-17 07:23:11	2020-05-17	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9833	delivery	5	22
64033	2020-05-17 07:23:24	2020-05-17	14	[{"id_menu":2,"count":1}]	4735	delivery	5	19
64034	2020-05-17 07:24:14	2020-05-17	12	[{"id_menu":1,"count":1}]	9813	pick-up	0	12
64035	2020-05-17 07:24:33	2020-05-17	14	[{"id_menu":2,"count":1}]	16023	pick-up	0	14
64036	2020-05-17 07:25:26	2020-05-17	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	25305	delivery	5	22
64037	2020-05-17 07:31:22	2020-05-17	9	[{"id_menu":7,"count":1}]	13232	pick-up	0	9
64038	2020-05-17 07:32:37	2020-05-17	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2761	delivery	5	36
64039	2020-05-17 07:33:56	2020-05-17	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	12080	delivery	5	34
64040	2020-05-17 07:38:24	2020-05-17	8	[{"id_menu":5,"count":1}]	7151	delivery	5	13
64041	2020-05-17 07:42:47	2020-05-17	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	9801	delivery	5	26
64042	2020-05-17 07:44:21	2020-05-17	17	[{"id_menu":4,"count":1}]	5455	delivery	5	22
64043	2020-05-17 07:46:05	2020-05-17	14	[{"id_menu":2,"count":1}]	25284	delivery	5	19
64044	2020-05-17 07:47:57	2020-05-17	8	[{"id_menu":5,"count":1}]	20804	pick-up	0	8
64045	2020-05-17 07:50:00	2020-05-17	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	15510	delivery	5	26
64046	2020-05-17 07:51:29	2020-05-17	12	[{"id_menu":3,"count":1}]	21334	pick-up	0	12
64047	2020-05-17 07:57:46	2020-05-17	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	4825	pick-up	0	26
64048	2020-05-17 07:57:59	2020-05-17	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9365	delivery	5	36
64049	2020-05-17 07:58:03	2020-05-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	14018	pick-up	0	23
64050	2020-05-17 07:58:49	2020-05-17	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	18957	delivery	5	52
64051	2020-05-17 08:00:30	2020-05-17	9	[{"id_menu":7,"count":1}]	24802	pick-up	0	9
64052	2020-05-17 08:01:08	2020-05-17	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25316	delivery	5	22
64053	2020-05-17 08:02:39	2020-05-17	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9855	delivery	5	31
64054	2020-05-17 08:03:38	2020-05-17	9	[{"id_menu":7,"count":1}]	3299	pick-up	0	9
64055	2020-05-17 08:05:27	2020-05-17	14	[{"id_menu":2,"count":1}]	25403	pick-up	0	14
64056	2020-05-17 08:12:26	2020-05-17	17	[{"id_menu":4,"count":1}]	8146	pick-up	0	17
64057	2020-05-17 08:14:15	2020-05-17	9	[{"id_menu":6,"count":1}]	3570	pick-up	0	9
64058	2020-05-17 08:15:10	2020-05-17	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19817	delivery	5	34
64059	2020-05-17 08:15:20	2020-05-17	8	[{"id_menu":5,"count":1}]	25300	delivery	5	13
64060	2020-05-17 08:20:43	2020-05-17	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	19800	delivery	5	45
64061	2020-05-17 08:24:35	2020-05-17	14	[{"id_menu":2,"count":1}]	3688	delivery	5	19
64062	2020-05-17 08:25:09	2020-05-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	16934	delivery	5	28
64063	2020-05-17 08:25:54	2020-05-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1676	delivery	5	31
64064	2020-05-17 08:28:54	2020-05-17	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25423	delivery	5	22
64065	2020-05-17 08:31:59	2020-05-17	12	[{"id_menu":3,"count":1}]	4459	delivery	5	17
64066	2020-05-17 08:41:22	2020-05-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	18344	pick-up	0	23
64067	2020-05-17 08:43:47	2020-05-17	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12182	delivery	5	34
64068	2020-05-17 08:43:57	2020-05-17	17	[{"id_menu":4,"count":1}]	1276	pick-up	0	17
64069	2020-05-17 08:44:21	2020-05-17	12	[{"id_menu":3,"count":1}]	25289	delivery	5	17
64070	2020-05-17 08:44:57	2020-05-17	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11624	delivery	5	52
64071	2020-05-17 08:47:38	2020-05-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25349	delivery	5	23
64072	2020-05-17 08:47:52	2020-05-17	14	[{"id_menu":2,"count":1}]	25399	delivery	5	19
64073	2020-05-17 08:49:57	2020-05-17	9	[{"id_menu":7,"count":1}]	25427	delivery	5	14
64074	2020-05-17 08:50:16	2020-05-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	25384	delivery	5	31
64075	2020-05-17 08:51:11	2020-05-17	12	[{"id_menu":3,"count":1}]	2759	pick-up	0	12
64076	2020-05-17 08:55:22	2020-05-17	8	[{"id_menu":5,"count":1}]	7835	pick-up	0	8
64077	2020-05-17 08:58:00	2020-05-17	14	[{"id_menu":2,"count":1}]	541	delivery	5	19
64078	2020-05-17 08:58:11	2020-05-17	8	[{"id_menu":5,"count":1}]	5758	pick-up	0	8
64079	2020-05-17 08:59:10	2020-05-17	14	[{"id_menu":2,"count":2}]	17351	pick-up	0	14
64080	2020-05-17 08:59:45	2020-05-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	5478	pick-up	0	23
64081	2020-05-17 09:04:45	2020-05-17	12	[{"id_menu":3,"count":1}]	25360	pick-up	0	12
64082	2020-05-17 09:06:17	2020-05-17	14	[{"id_menu":2,"count":1}]	5543	pick-up	0	14
64083	2020-05-17 09:08:19	2020-05-17	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	25342	delivery	5	25
64084	2020-05-17 09:13:23	2020-05-17	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	17839	delivery	5	44
64085	2020-05-17 09:16:29	2020-05-17	8	[{"id_menu":5,"count":1}]	21256	pick-up	0	8
64086	2020-05-17 09:21:26	2020-05-17	9	[{"id_menu":7,"count":1}]	25417	delivery	5	14
64087	2020-05-17 09:23:35	2020-05-17	8	[{"id_menu":5,"count":1}]	15082	pick-up	0	8
64088	2020-05-17 09:23:52	2020-05-17	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	1161	delivery	5	26
64089	2020-05-17 09:26:09	2020-05-17	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	22263	delivery	5	23
64090	2020-05-17 09:28:00	2020-05-17	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	25296	delivery	5	36
64091	2020-05-17 09:29:42	2020-05-17	12	[{"id_menu":1,"count":1}]	15322	delivery	5	17
64092	2020-05-17 09:30:54	2020-05-17	8	[{"id_menu":5,"count":1}]	17984	delivery	5	13
64093	2020-05-17 09:31:36	2020-05-17	12	[{"id_menu":1,"count":1}]	22313	pick-up	0	12
64094	2020-05-17 09:32:02	2020-05-17	9	[{"id_menu":7,"count":1}]	25347	delivery	5	14
64095	2020-05-17 09:33:51	2020-05-17	8	[{"id_menu":5,"count":1}]	20021	delivery	5	13
64096	2020-05-17 09:34:08	2020-05-17	12	[{"id_menu":1,"count":1}]	2422	delivery	5	17
64097	2020-05-17 09:34:17	2020-05-17	9	[{"id_menu":7,"count":1}]	22957	delivery	5	14
64098	2020-05-17 09:34:31	2020-05-17	12	[{"id_menu":3,"count":1}]	25418	delivery	5	17
64099	2020-05-17 09:43:16	2020-05-17	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	25332	delivery	5	39
64100	2020-05-17 09:45:30	2020-05-17	12	[{"id_menu":1,"count":2}]	2321	pick-up	0	12
64101	2020-05-17 09:47:44	2020-05-17	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12050	delivery	5	31
64102	2020-05-17 09:49:06	2020-05-17	9	[{"id_menu":7,"count":1}]	25287	delivery	5	14
64103	2020-05-17 09:51:31	2020-05-17	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	20755	delivery	5	31
64104	2020-05-17 09:51:35	2020-05-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	25333	pick-up	0	23
64105	2020-05-17 09:51:42	2020-05-17	14	[{"id_menu":2,"count":1}]	20696	delivery	5	19
64106	2020-05-17 09:54:16	2020-05-17	12	[{"id_menu":1,"count":1}]	9907	pick-up	0	12
64107	2020-05-17 09:55:49	2020-05-17	8	[{"id_menu":5,"count":1}]	9740	delivery	5	13
64108	2020-05-17 09:59:58	2020-05-17	14	[{"id_menu":2,"count":1}]	25396	pick-up	0	14
64109	2020-05-17 10:03:40	2020-05-17	9	[{"id_menu":6,"count":1}]	2654	pick-up	0	9
64110	2020-05-17 10:05:35	2020-05-17	9	[{"id_menu":7,"count":2}]	13833	delivery	5	14
64111	2020-05-17 10:10:29	2020-05-17	12	[{"id_menu":1,"count":1}]	25400	delivery	5	17
64112	2020-05-17 10:11:02	2020-05-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	25321	delivery	5	31
64113	2020-05-17 10:11:19	2020-05-17	8	[{"id_menu":5,"count":1}]	14292	delivery	5	13
64114	2020-05-17 10:12:16	2020-05-17	8	[{"id_menu":5,"count":1}]	25353	delivery	5	13
64115	2020-05-17 10:13:16	2020-05-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16158	delivery	5	23
64116	2020-05-17 10:14:14	2020-05-17	8	[{"id_menu":5,"count":1}]	24530	delivery	5	13
64117	2020-05-17 10:17:46	2020-05-17	17	[{"id_menu":4,"count":1}]	25320	delivery	5	22
64118	2020-05-17 10:18:46	2020-05-17	17	[{"id_menu":4,"count":1}]	7411	delivery	5	22
64119	2020-05-17 10:19:17	2020-05-17	9	[{"id_menu":6,"count":1}]	4814	delivery	5	14
64120	2020-05-17 10:21:07	2020-05-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	24281	delivery	5	28
64121	2020-05-17 10:22:20	2020-05-17	8	[{"id_menu":5,"count":1}]	15390	delivery	5	13
64122	2020-05-17 10:26:09	2020-05-17	8	[{"id_menu":5,"count":1}]	2641	pick-up	0	8
64123	2020-05-17 10:35:49	2020-05-17	8	[{"id_menu":5,"count":1}]	25368	delivery	5	13
64124	2020-05-17 10:40:00	2020-05-17	9	[{"id_menu":7,"count":1}]	17144	delivery	5	14
64125	2020-05-17 10:41:43	2020-05-17	12	[{"id_menu":3,"count":1}]	256	pick-up	0	12
64126	2020-05-17 10:41:47	2020-05-17	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	135	delivery	5	34
64127	2020-05-17 10:42:18	2020-05-17	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	6950	delivery	5	31
64128	2020-05-17 10:45:00	2020-05-17	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	13563	delivery	5	42
64129	2020-05-17 10:48:38	2020-05-17	8	[{"id_menu":5,"count":1}]	25374	delivery	5	13
64130	2020-05-17 10:52:26	2020-05-17	14	[{"id_menu":2,"count":1}]	9291	pick-up	0	14
64131	2020-05-17 10:53:49	2020-05-17	14	[{"id_menu":2,"count":1}]	2287	pick-up	0	14
64132	2020-05-17 10:58:40	2020-05-17	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	25369	delivery	5	25
64133	2020-05-17 10:59:29	2020-05-17	8	[{"id_menu":5,"count":1}]	15456	pick-up	0	8
64134	2020-05-17 11:00:29	2020-05-17	8	[{"id_menu":5,"count":1}]	9603	delivery	5	13
64135	2020-05-17 11:03:02	2020-05-17	12	[{"id_menu":1,"count":1}]	25394	delivery	5	17
64136	2020-05-17 11:05:08	2020-05-17	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	17594	delivery	5	37
64137	2020-05-17 11:06:14	2020-05-17	17	[{"id_menu":4,"count":1}]	2018	delivery	5	22
64138	2020-05-17 11:07:35	2020-05-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3898	pick-up	0	26
64139	2020-05-17 11:08:41	2020-05-17	14	[{"id_menu":2,"count":1}]	21426	delivery	5	19
64140	2020-05-17 11:09:18	2020-05-17	17	[{"id_menu":4,"count":1}]	1664	pick-up	0	17
64141	2020-05-17 11:20:51	2020-05-17	17	[{"id_menu":4,"count":1}]	23750	delivery	5	22
64142	2020-05-17 11:24:43	2020-05-17	17	[{"id_menu":4,"count":1}]	11615	pick-up	0	17
64143	2020-05-17 11:32:34	2020-05-17	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14711	delivery	5	45
64144	2020-05-17 11:32:57	2020-05-17	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25379	delivery	5	22
64145	2020-05-17 11:34:43	2020-05-17	12	[{"id_menu":1,"count":1}]	1727	pick-up	0	12
64146	2020-05-17 11:34:45	2020-05-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	8311	delivery	5	28
64147	2020-05-17 11:36:34	2020-05-17	9	[{"id_menu":7,"count":1}]	20444	delivery	5	14
64148	2020-05-17 11:37:26	2020-05-17	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20271	delivery	5	35
64149	2020-05-17 11:38:03	2020-05-17	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7431	delivery	5	36
64150	2020-05-17 11:38:16	2020-05-17	14	[{"id_menu":2,"count":1}]	5536	delivery	5	19
64151	2020-05-17 11:44:00	2020-05-17	12	[{"id_menu":1,"count":1}]	10766	delivery	5	17
64152	2020-05-17 11:45:14	2020-05-17	9	[{"id_menu":6,"count":1}]	7902	delivery	5	14
64153	2020-05-17 11:50:20	2020-05-17	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	3799	delivery	5	31
64154	2020-05-17 11:51:06	2020-05-17	9	[{"id_menu":6,"count":2}]	3174	delivery	5	14
64155	2020-05-17 11:55:56	2020-05-17	14	[{"id_menu":2,"count":1}]	14133	pick-up	0	14
64156	2020-05-17 11:57:15	2020-05-17	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	8640	pick-up	0	26
64157	2020-05-17 11:59:25	2020-05-17	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12974	delivery	5	46
64158	2020-05-17 12:03:43	2020-05-17	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	17821	delivery	5	43
64159	2020-05-17 12:07:09	2020-05-17	9	[{"id_menu":7,"count":1}]	25410	delivery	5	14
64160	2020-05-17 12:09:39	2020-05-17	9	[{"id_menu":6,"count":1}]	20989	delivery	5	14
64161	2020-05-17 12:10:47	2020-05-17	9	[{"id_menu":7,"count":1}]	25421	delivery	5	14
64162	2020-05-17 12:11:24	2020-05-17	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1212	delivery	5	40
64163	2020-05-17 12:12:31	2020-05-17	14	[{"id_menu":2,"count":1}]	25364	delivery	5	19
64164	2020-05-17 12:13:05	2020-05-17	9	[{"id_menu":7,"count":1}]	23895	delivery	5	14
64165	2020-05-17 12:14:01	2020-05-17	12	[{"id_menu":3,"count":1}]	295	delivery	5	17
64166	2020-05-17 12:16:33	2020-05-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10732	delivery	5	23
64167	2020-05-17 12:17:22	2020-05-17	9	[{"id_menu":6,"count":1}]	18519	pick-up	0	9
64168	2020-05-17 12:17:39	2020-05-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25290	delivery	5	23
64169	2020-05-17 12:20:11	2020-05-17	9	[{"id_menu":6,"count":1}]	15666	delivery	5	14
64170	2020-05-17 12:21:02	2020-05-17	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	16788	delivery	5	40
64171	2020-05-17 12:25:15	2020-05-17	9	[{"id_menu":6,"count":1}]	1514	delivery	5	14
64172	2020-05-17 12:25:34	2020-05-17	9	[{"id_menu":6,"count":1}]	25322	delivery	5	14
64173	2020-05-17 12:29:54	2020-05-17	9	[{"id_menu":6,"count":1}]	25307	delivery	5	14
64174	2020-05-17 12:30:40	2020-05-17	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	21869	delivery	5	45
64175	2020-05-17 12:30:42	2020-05-17	9	[{"id_menu":7,"count":1}]	19232	delivery	5	14
64176	2020-05-17 12:33:01	2020-05-17	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	25309	delivery	5	22
64177	2020-05-17 12:34:57	2020-05-17	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	25311	pick-up	0	31
64178	2020-05-17 12:37:41	2020-05-17	12	[{"id_menu":3,"count":1}]	13948	delivery	5	17
64179	2020-05-17 12:37:51	2020-05-17	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	5945	pick-up	0	21
64180	2020-05-17 12:38:49	2020-05-17	9	[{"id_menu":6,"count":1}]	5709	pick-up	0	9
64181	2020-05-17 12:47:56	2020-05-17	9	[{"id_menu":6,"count":1}]	4058	delivery	5	14
64182	2020-05-17 12:48:44	2020-05-17	12	[{"id_menu":3,"count":1}]	18558	delivery	5	17
64183	2020-05-17 12:52:27	2020-05-17	12	[{"id_menu":1,"count":1}]	25281	pick-up	0	12
64184	2020-05-17 12:53:09	2020-05-17	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	25326	delivery	5	29
64185	2020-05-17 12:53:10	2020-05-17	9	[{"id_menu":7,"count":1}]	16975	delivery	5	14
64186	2020-05-17 12:55:21	2020-05-17	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	6127	delivery	5	31
64187	2020-05-17 12:58:47	2020-05-17	8	[{"id_menu":5,"count":1}]	2338	delivery	5	13
64188	2020-05-17 13:01:25	2020-05-17	8	[{"id_menu":5,"count":1}]	23918	pick-up	0	8
64189	2020-05-17 13:03:01	2020-05-17	9	[{"id_menu":7,"count":1}]	2050	pick-up	0	9
64190	2020-05-17 13:06:13	2020-05-17	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7283	delivery	5	37
64191	2020-05-17 13:09:31	2020-05-17	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	25308	delivery	5	36
64192	2020-05-17 13:15:59	2020-05-17	8	[{"id_menu":5,"count":1}]	13040	delivery	5	13
64193	2020-05-17 13:19:07	2020-05-17	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1015	pick-up	0	20
64194	2020-05-17 13:19:21	2020-05-17	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	24441	pick-up	0	29
64195	2020-05-17 13:21:09	2020-05-17	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	8139	delivery	5	45
64196	2020-05-17 13:23:01	2020-05-17	14	[{"id_menu":2,"count":1}]	9231	pick-up	0	14
64197	2020-05-17 13:27:49	2020-05-17	8	[{"id_menu":5,"count":1}]	25361	delivery	5	13
64198	2020-05-17 13:33:58	2020-05-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7387	delivery	5	31
64199	2020-05-17 13:36:51	2020-05-17	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	5970	delivery	5	39
64200	2020-05-17 13:40:50	2020-05-17	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	24766	delivery	5	26
64201	2020-05-17 13:41:13	2020-05-17	8	[{"id_menu":5,"count":1}]	25385	delivery	5	13
64202	2020-05-17 13:41:31	2020-05-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	23362	delivery	5	28
64203	2020-05-17 13:44:18	2020-05-17	9	[{"id_menu":6,"count":1}]	11083	pick-up	0	9
64204	2020-05-17 13:49:25	2020-05-17	17	[{"id_menu":4,"count":1}]	3168	pick-up	0	17
64205	2020-05-17 13:50:08	2020-05-17	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20711	delivery	5	34
64206	2020-05-17 13:51:03	2020-05-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2270	delivery	5	28
64207	2020-05-17 13:51:52	2020-05-17	12	[{"id_menu":1,"count":1}]	19637	pick-up	0	12
64208	2020-05-17 13:52:08	2020-05-17	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	17582	delivery	5	43
64209	2020-05-17 13:57:33	2020-05-17	14	[{"id_menu":2,"count":1}]	8877	delivery	5	19
64210	2020-05-17 13:57:37	2020-05-17	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	19582	delivery	5	43
64211	2020-05-17 13:59:13	2020-05-17	14	[{"id_menu":2,"count":1}]	14701	delivery	5	19
64212	2020-05-17 14:01:39	2020-05-17	9	[{"id_menu":7,"count":1}]	10230	delivery	5	14
64213	2020-05-17 14:02:18	2020-05-17	9	[{"id_menu":6,"count":1}]	4997	pick-up	0	9
64214	2020-05-17 14:04:17	2020-05-17	9	[{"id_menu":6,"count":1}]	17794	delivery	5	14
64215	2020-05-17 14:04:51	2020-05-17	17	[{"id_menu":4,"count":1}]	1038	delivery	5	22
64216	2020-05-17 14:05:42	2020-05-17	12	[{"id_menu":1,"count":1}]	3326	delivery	5	17
64217	2020-05-17 14:06:29	2020-05-17	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	25424	delivery	5	34
64218	2020-05-17 14:06:39	2020-05-17	12	[{"id_menu":3,"count":1}]	25327	delivery	5	17
64219	2020-05-17 14:16:34	2020-05-17	8	[{"id_menu":5,"count":1}]	8730	delivery	5	13
64220	2020-05-17 14:23:18	2020-05-17	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	25413	delivery	5	39
64221	2020-05-17 14:26:49	2020-05-17	14	[{"id_menu":2,"count":1}]	173	pick-up	0	14
64222	2020-05-17 14:27:42	2020-05-17	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	23289	delivery	5	31
64223	2020-05-17 14:31:18	2020-05-17	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	4331	delivery	5	23
64224	2020-05-17 14:31:51	2020-05-17	9	[{"id_menu":6,"count":1}]	10567	delivery	5	14
64225	2020-05-17 14:35:11	2020-05-17	14	[{"id_menu":2,"count":1}]	21786	delivery	5	19
64226	2020-05-17 14:35:12	2020-05-17	9	[{"id_menu":7,"count":1}]	15595	delivery	5	14
64227	2020-05-17 14:36:21	2020-05-17	14	[{"id_menu":2,"count":1}]	5290	pick-up	0	14
64228	2020-05-17 14:39:29	2020-05-17	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	25336	delivery	5	26
64229	2020-05-17 14:40:57	2020-05-17	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4924	delivery	5	27
64230	2020-05-17 14:43:53	2020-05-17	9	[{"id_menu":6,"count":1}]	25393	pick-up	0	9
64231	2020-05-17 14:44:19	2020-05-17	9	[{"id_menu":7,"count":1}]	25306	delivery	5	14
64232	2020-05-17 14:46:23	2020-05-17	14	[{"id_menu":2,"count":1}]	6009	delivery	5	19
64233	2020-05-17 14:54:08	2020-05-17	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17387	delivery	5	48
64234	2020-05-17 14:59:25	2020-05-17	8	[{"id_menu":5,"count":1}]	3540	delivery	5	13
64235	2020-05-17 14:59:53	2020-05-17	8	[{"id_menu":5,"count":1}]	12360	delivery	5	13
64236	2020-05-17 15:01:12	2020-05-17	9	[{"id_menu":6,"count":1}]	486	delivery	5	14
64237	2020-05-17 15:03:52	2020-05-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25404	delivery	5	23
64238	2020-05-17 15:12:03	2020-05-17	9	[{"id_menu":6,"count":1}]	3211	delivery	5	14
64239	2020-05-17 15:12:31	2020-05-17	9	[{"id_menu":6,"count":2}]	10820	delivery	5	14
64240	2020-05-17 15:13:05	2020-05-17	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	25434	delivery	5	36
64241	2020-05-17 15:17:47	2020-05-17	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	21488	delivery	5	43
64242	2020-05-17 15:19:19	2020-05-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17501	pick-up	0	26
64243	2020-05-17 15:21:44	2020-05-17	9	[{"id_menu":6,"count":1}]	9716	pick-up	0	9
64244	2020-05-17 15:22:20	2020-05-17	17	[{"id_menu":4,"count":1}]	19159	delivery	5	22
64245	2020-05-17 15:23:45	2020-05-17	12	[{"id_menu":3,"count":1}]	17904	delivery	5	17
64246	2020-05-17 15:24:19	2020-05-17	12	[{"id_menu":1,"count":1}]	1889	pick-up	0	12
64247	2020-05-17 15:24:31	2020-05-17	12	[{"id_menu":3,"count":1}]	9270	delivery	5	17
64248	2020-05-17 15:25:08	2020-05-17	9	[{"id_menu":7,"count":1}]	25409	delivery	5	14
64249	2020-05-17 15:25:17	2020-05-17	8	[{"id_menu":5,"count":1}]	3358	delivery	5	13
64250	2020-05-17 15:26:05	2020-05-17	8	[{"id_menu":5,"count":1}]	25390	delivery	5	13
64251	2020-05-17 15:29:24	2020-05-17	9	[{"id_menu":6,"count":1}]	7709	delivery	5	14
64252	2020-05-17 15:33:16	2020-05-17	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	14572	delivery	5	29
64253	2020-05-17 15:35:43	2020-05-17	9	[{"id_menu":6,"count":1}]	7924	delivery	5	14
64254	2020-05-17 15:42:28	2020-05-17	9	[{"id_menu":7,"count":1}]	25310	pick-up	0	9
64255	2020-05-17 15:44:03	2020-05-17	14	[{"id_menu":2,"count":1}]	1485	pick-up	0	14
64256	2020-05-17 15:44:16	2020-05-17	17	[{"id_menu":4,"count":1}]	25303	delivery	5	22
64257	2020-05-17 15:52:35	2020-05-17	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	23470	delivery	5	40
64258	2020-05-17 15:53:28	2020-05-17	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	25428	delivery	5	45
64259	2020-05-17 15:54:22	2020-05-17	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9435	delivery	5	22
64260	2020-05-17 15:56:25	2020-05-17	12	[{"id_menu":3,"count":1}]	13851	delivery	5	17
64261	2020-05-17 15:59:24	2020-05-17	9	[{"id_menu":6,"count":1}]	13268	delivery	5	14
64262	2020-05-17 16:00:08	2020-05-17	8	[{"id_menu":5,"count":1}]	25331	delivery	5	13
64263	2020-05-17 16:00:52	2020-05-17	14	[{"id_menu":2,"count":1}]	25285	delivery	5	19
64264	2020-05-17 16:02:00	2020-05-17	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	15907	delivery	5	31
64265	2020-05-17 16:06:25	2020-05-17	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	24408	delivery	5	43
64266	2020-05-17 16:06:32	2020-05-17	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16810	pick-up	0	32
64267	2020-05-17 16:06:47	2020-05-17	8	[{"id_menu":5,"count":1}]	17986	delivery	5	13
64268	2020-05-17 16:16:15	2020-05-17	8	[{"id_menu":5,"count":1}]	20463	pick-up	0	8
64269	2020-05-17 16:19:42	2020-05-17	9	[{"id_menu":6,"count":1}]	20883	delivery	5	14
64270	2020-05-17 16:22:27	2020-05-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2541	delivery	5	23
64271	2020-05-17 16:22:49	2020-05-17	9	[{"id_menu":6,"count":1}]	25299	delivery	5	14
64272	2020-05-17 16:23:56	2020-05-17	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	25405	delivery	5	31
64273	2020-05-17 16:25:17	2020-05-17	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	25433	delivery	5	26
64274	2020-05-17 16:25:45	2020-05-17	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	25298	delivery	5	57
64275	2020-05-17 16:26:53	2020-05-17	9	[{"id_menu":6,"count":1}]	18666	delivery	5	14
64276	2020-05-17 16:27:38	2020-05-17	9	[{"id_menu":6,"count":1}]	21237	delivery	5	14
64277	2020-05-17 16:31:23	2020-05-17	8	[{"id_menu":5,"count":1}]	25295	delivery	5	13
64278	2020-05-17 16:31:54	2020-05-17	9	[{"id_menu":7,"count":1}]	20789	delivery	5	14
64279	2020-05-17 16:34:22	2020-05-17	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	25435	delivery	5	45
64280	2020-05-17 16:38:46	2020-05-17	9	[{"id_menu":6,"count":1}]	14090	delivery	5	14
64281	2020-05-17 16:39:49	2020-05-17	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	25319	delivery	5	48
64282	2020-05-17 16:40:27	2020-05-17	14	[{"id_menu":2,"count":1}]	1169	pick-up	0	14
64283	2020-05-17 16:40:29	2020-05-17	8	[{"id_menu":5,"count":1}]	25348	delivery	5	13
64284	2020-05-17 16:40:32	2020-05-17	14	[{"id_menu":2,"count":1}]	6848	pick-up	0	14
64285	2020-05-17 16:43:19	2020-05-17	9	[{"id_menu":6,"count":1}]	379	pick-up	0	9
64286	2020-05-17 16:45:23	2020-05-17	12	[{"id_menu":1,"count":1}]	2807	pick-up	0	12
64287	2020-05-17 16:45:50	2020-05-17	9	[{"id_menu":6,"count":1}]	16436	delivery	5	14
64288	2020-05-17 16:46:40	2020-05-17	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	16084	delivery	5	29
64289	2020-05-17 16:47:15	2020-05-17	9	[{"id_menu":7,"count":1}]	14027	pick-up	0	9
64290	2020-05-17 16:50:23	2020-05-17	9	[{"id_menu":7,"count":1}]	25407	delivery	5	14
64291	2020-05-17 16:51:07	2020-05-17	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23996	delivery	5	34
64292	2020-05-17 16:53:19	2020-05-17	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	25381	delivery	5	57
64293	2020-05-17 16:58:28	2020-05-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4468	delivery	5	31
64294	2020-05-17 17:00:14	2020-05-17	9	[{"id_menu":7,"count":1}]	17091	delivery	5	14
64295	2020-05-17 17:00:45	2020-05-17	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	18773	delivery	5	31
64296	2020-05-17 17:09:37	2020-05-17	17	[{"id_menu":4,"count":1}]	19382	pick-up	0	17
64297	2020-05-17 17:11:05	2020-05-17	9	[{"id_menu":7,"count":1}]	5475	delivery	5	14
64298	2020-05-17 17:12:09	2020-05-17	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	9985	delivery	5	25
64299	2020-05-17 17:17:08	2020-05-17	12	[{"id_menu":1,"count":1}]	37	pick-up	0	12
64300	2020-05-17 17:17:58	2020-05-17	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	14227	delivery	5	22
64301	2020-05-17 17:19:04	2020-05-17	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	25362	delivery	5	22
64302	2020-05-17 17:21:07	2020-05-17	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24245	delivery	5	34
64303	2020-05-17 17:22:32	2020-05-17	17	[{"id_menu":4,"count":1}]	4981	delivery	5	22
64304	2020-05-17 17:25:40	2020-05-17	9	[{"id_menu":6,"count":1}]	14179	delivery	5	14
64305	2020-05-17 17:26:20	2020-05-17	14	[{"id_menu":2,"count":1}]	9611	delivery	5	19
64306	2020-05-17 17:34:35	2020-05-17	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25293	delivery	5	22
64307	2020-05-17 17:36:52	2020-05-17	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11826	delivery	5	31
64308	2020-05-17 17:40:01	2020-05-17	14	[{"id_menu":2,"count":1}]	25343	delivery	5	19
64309	2020-05-17 17:40:20	2020-05-17	9	[{"id_menu":6,"count":1}]	9476	pick-up	0	9
64310	2020-05-17 17:44:30	2020-05-17	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	25313	delivery	5	22
64311	2020-05-17 17:47:40	2020-05-17	17	[{"id_menu":4,"count":1}]	18616	delivery	5	22
64312	2020-05-17 17:53:21	2020-05-17	9	[{"id_menu":7,"count":1}]	4007	pick-up	0	9
64313	2020-05-17 17:55:39	2020-05-17	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25426	delivery	5	37
64314	2020-05-17 17:58:01	2020-05-17	8	[{"id_menu":5,"count":1}]	10019	delivery	5	13
64315	2020-05-17 18:01:22	2020-05-17	14	[{"id_menu":2,"count":1}]	15601	delivery	5	19
64316	2020-05-17 18:02:26	2020-05-17	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	23144	delivery	5	26
64317	2020-05-17 18:02:41	2020-05-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	19065	delivery	5	31
64318	2020-05-17 18:04:55	2020-05-17	17	[{"id_menu":4,"count":1}]	24171	delivery	5	22
64319	2020-05-17 18:05:46	2020-05-17	17	[{"id_menu":4,"count":1}]	17803	delivery	5	22
64320	2020-05-17 18:08:08	2020-05-17	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	25359	pick-up	0	24
64321	2020-05-17 18:10:56	2020-05-17	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	136	delivery	5	40
64322	2020-05-17 18:12:42	2020-05-17	12	[{"id_menu":3,"count":1}]	5756	pick-up	0	12
64323	2020-05-17 18:15:29	2020-05-17	12	[{"id_menu":1,"count":1}]	7572	pick-up	0	12
64324	2020-05-17 18:16:38	2020-05-17	17	[{"id_menu":4,"count":1}]	19608	delivery	5	22
64325	2020-05-17 18:18:28	2020-05-17	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2317	pick-up	0	21
64326	2020-05-17 18:20:36	2020-05-17	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	3314	pick-up	0	29
64327	2020-05-17 18:21:59	2020-05-17	9	[{"id_menu":7,"count":1}]	8166	delivery	5	14
64328	2020-05-17 18:22:41	2020-05-17	8	[{"id_menu":5,"count":1}]	25416	delivery	5	13
64329	2020-05-17 18:25:21	2020-05-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	25398	delivery	5	31
64330	2020-05-17 18:27:57	2020-05-17	14	[{"id_menu":2,"count":1}]	15816	pick-up	0	14
64331	2020-05-17 18:31:01	2020-05-17	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	25382	delivery	5	34
64332	2020-05-17 18:31:34	2020-05-17	14	[{"id_menu":2,"count":2}]	25414	delivery	5	19
64333	2020-05-17 18:38:49	2020-05-17	8	[{"id_menu":5,"count":1}]	25350	delivery	5	13
64334	2020-05-17 18:42:13	2020-05-17	9	[{"id_menu":7,"count":2}]	25334	delivery	5	14
64335	2020-05-17 18:46:37	2020-05-17	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	18195	delivery	5	26
64336	2020-05-17 18:48:51	2020-05-17	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	19953	delivery	5	26
64337	2020-05-17 18:50:18	2020-05-17	14	[{"id_menu":2,"count":1}]	7128	pick-up	0	14
64338	2020-05-17 18:51:03	2020-05-17	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	25335	delivery	5	27
64339	2020-05-17 18:51:40	2020-05-17	9	[{"id_menu":7,"count":1}]	176	delivery	5	14
64340	2020-05-17 18:52:21	2020-05-17	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	4737	delivery	5	43
64341	2020-05-17 18:55:04	2020-05-17	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2855	delivery	5	43
64342	2020-05-17 18:55:13	2020-05-17	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1164	pick-up	0	31
64343	2020-05-17 19:01:24	2020-05-17	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	13060	delivery	5	23
64344	2020-05-17 19:01:31	2020-05-17	14	[{"id_menu":2,"count":1}]	19391	pick-up	0	14
64345	2020-05-17 19:03:47	2020-05-17	9	[{"id_menu":6,"count":1}]	6894	delivery	5	14
64346	2020-05-17 19:07:18	2020-05-17	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5473	pick-up	0	17
64347	2020-05-17 19:10:24	2020-05-17	9	[{"id_menu":6,"count":1}]	25304	delivery	5	14
64348	2020-05-17 19:11:08	2020-05-17	17	[{"id_menu":4,"count":1}]	10458	delivery	5	22
64349	2020-05-17 19:15:01	2020-05-17	8	[{"id_menu":5,"count":1}]	2627	pick-up	0	8
64350	2020-05-17 19:20:23	2020-05-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	17805	pick-up	0	23
64351	2020-05-17 19:22:13	2020-05-17	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	14103	delivery	5	27
64352	2020-05-17 19:24:15	2020-05-17	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25389	delivery	5	22
64353	2020-05-17 19:26:13	2020-05-17	14	[{"id_menu":2,"count":1}]	11093	delivery	5	19
64354	2020-05-17 19:27:16	2020-05-17	12	[{"id_menu":3,"count":1}]	25380	pick-up	0	12
64355	2020-05-17 19:28:22	2020-05-17	9	[{"id_menu":7,"count":1}]	23890	pick-up	0	9
64356	2020-05-17 19:29:55	2020-05-17	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21624	delivery	5	46
64357	2020-05-17 19:35:22	2020-05-17	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	9816	pick-up	0	35
64358	2020-05-17 19:35:25	2020-05-17	14	[{"id_menu":2,"count":3}]	6470	pick-up	0	14
64359	2020-05-17 19:36:10	2020-05-17	8	[{"id_menu":5,"count":1}]	19442	pick-up	0	8
64360	2020-05-17 19:39:06	2020-05-17	17	[{"id_menu":4,"count":1}]	868	pick-up	0	17
64361	2020-05-17 19:41:54	2020-05-17	12	[{"id_menu":1,"count":1}]	22363	delivery	5	17
64362	2020-05-17 19:45:30	2020-05-17	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	3112	delivery	5	31
64363	2020-05-17 19:45:51	2020-05-17	8	[{"id_menu":5,"count":1}]	25429	delivery	5	13
64364	2020-05-17 19:47:31	2020-05-17	17	[{"id_menu":4,"count":1}]	7421	delivery	5	22
64365	2020-05-17 19:47:48	2020-05-17	12	[{"id_menu":1,"count":1}]	25430	delivery	5	17
64366	2020-05-17 19:50:32	2020-05-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	21321	delivery	5	31
64367	2020-05-17 19:50:43	2020-05-17	9	[{"id_menu":7,"count":1}]	7415	pick-up	0	9
64368	2020-05-17 19:56:25	2020-05-17	8	[{"id_menu":5,"count":1}]	21546	delivery	5	13
64369	2020-05-17 19:57:56	2020-05-17	17	[{"id_menu":4,"count":1}]	14764	delivery	5	22
64370	2020-05-17 19:58:38	2020-05-17	14	[{"id_menu":2,"count":1}]	25339	delivery	5	19
64371	2020-05-17 20:03:30	2020-05-17	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18546	delivery	5	22
64372	2020-05-17 20:08:49	2020-05-17	12	[{"id_menu":1,"count":1}]	21263	delivery	5	17
64373	2020-05-17 20:10:30	2020-05-17	43	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	25340	delivery	5	48
64374	2020-05-17 20:12:00	2020-05-17	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	25392	delivery	5	26
64375	2020-05-17 20:13:37	2020-05-17	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	3797	delivery	5	26
64376	2020-05-17 20:26:54	2020-05-17	9	[{"id_menu":6,"count":1}]	2054	pick-up	0	9
64377	2020-05-17 20:28:22	2020-05-17	9	[{"id_menu":6,"count":1}]	22383	pick-up	0	9
64378	2020-05-17 20:32:39	2020-05-17	17	[{"id_menu":4,"count":1}]	8148	pick-up	0	17
64379	2020-05-17 20:32:51	2020-05-17	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10312	delivery	5	37
64380	2020-05-17 20:33:06	2020-05-17	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19883	delivery	5	43
64381	2020-05-17 20:33:35	2020-05-17	12	[{"id_menu":3,"count":1}]	12581	delivery	5	17
64382	2020-05-17 20:34:04	2020-05-17	17	[{"id_menu":4,"count":1}]	14665	delivery	5	22
64383	2020-05-17 20:38:55	2020-05-17	8	[{"id_menu":5,"count":1}]	8657	pick-up	0	8
64384	2020-05-17 20:40:56	2020-05-17	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25346	delivery	5	37
64385	2020-05-17 20:40:56	2020-05-17	14	[{"id_menu":2,"count":1}]	12784	delivery	5	19
64386	2020-05-17 20:42:37	2020-05-17	14	[{"id_menu":2,"count":1}]	25294	delivery	5	19
64387	2020-05-17 20:47:57	2020-05-17	9	[{"id_menu":6,"count":1}]	19233	pick-up	0	9
64388	2020-05-17 20:48:03	2020-05-17	9	[{"id_menu":7,"count":1}]	14054	pick-up	0	9
64389	2020-05-17 20:53:13	2020-05-17	9	[{"id_menu":6,"count":1}]	2727	delivery	5	14
64390	2020-05-17 20:55:14	2020-05-17	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	19553	delivery	5	26
64391	2020-05-17 20:55:42	2020-05-17	9	[{"id_menu":7,"count":1}]	3130	pick-up	0	9
64392	2020-05-17 20:55:59	2020-05-17	9	[{"id_menu":6,"count":1}]	23897	delivery	5	14
64393	2020-05-17 21:00:12	2020-05-17	9	[{"id_menu":6,"count":1}]	25425	delivery	5	14
64394	2020-05-17 21:02:15	2020-05-17	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2085	delivery	5	35
64395	2020-05-17 21:06:40	2020-05-17	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	25406	delivery	5	34
64396	2020-05-17 21:07:29	2020-05-17	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	12425	delivery	5	26
64397	2020-05-17 21:14:18	2020-05-17	9	[{"id_menu":7,"count":2}]	25280	delivery	5	14
64398	2020-05-17 21:16:30	2020-05-17	9	[{"id_menu":7,"count":1}]	25415	delivery	5	14
64399	2020-05-17 21:17:25	2020-05-17	14	[{"id_menu":2,"count":1}]	16257	delivery	5	19
64400	2020-05-17 21:22:23	2020-05-17	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7147	delivery	5	48
64401	2020-05-17 21:23:52	2020-05-17	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	25315	delivery	5	26
64402	2020-05-17 21:25:05	2020-05-17	9	[{"id_menu":7,"count":1}]	688	pick-up	0	9
64403	2020-05-17 21:29:49	2020-05-17	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	6678	delivery	5	34
64404	2020-05-17 21:33:55	2020-05-17	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	16190	delivery	5	31
64405	2020-05-17 21:40:14	2020-05-17	14	[{"id_menu":2,"count":1}]	15528	pick-up	0	14
64406	2020-05-17 21:41:42	2020-05-17	12	[{"id_menu":1,"count":1}]	7886	pick-up	0	12
64407	2020-05-17 21:41:54	2020-05-17	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2185	pick-up	0	26
64408	2020-05-17 21:42:53	2020-05-17	9	[{"id_menu":7,"count":1}]	4589	delivery	5	14
64409	2020-05-17 21:44:25	2020-05-17	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	25387	delivery	5	40
64410	2020-05-17 21:50:21	2020-05-17	12	[{"id_menu":1,"count":1}]	23946	pick-up	0	12
64411	2020-05-17 21:54:26	2020-05-17	9	[{"id_menu":7,"count":1}]	25372	delivery	5	14
64412	2020-05-17 21:58:24	2020-05-17	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	10399	delivery	5	22
64413	2020-05-17 22:02:17	2020-05-17	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	13056	delivery	5	26
64414	2020-05-17 22:14:05	2020-05-17	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	5647	delivery	5	40
64415	2020-05-17 22:16:43	2020-05-17	12	[{"id_menu":1,"count":1}]	15829	pick-up	0	12
64416	2020-05-17 22:24:18	2020-05-17	9	[{"id_menu":7,"count":1}]	4646	delivery	5	14
64417	2020-05-17 22:25:49	2020-05-17	12	[{"id_menu":1,"count":1}]	25367	pick-up	0	12
64418	2020-05-17 22:27:41	2020-05-17	9	[{"id_menu":7,"count":1}]	13656	pick-up	0	9
64419	2020-05-17 22:28:06	2020-05-17	9	[{"id_menu":6,"count":1}]	16569	delivery	5	14
64420	2020-05-17 22:29:50	2020-05-17	14	[{"id_menu":2,"count":1}]	2642	pick-up	0	14
64421	2020-05-17 22:30:54	2020-05-17	9	[{"id_menu":7,"count":1}]	25297	delivery	5	14
64422	2020-05-17 22:31:58	2020-05-17	12	[{"id_menu":1,"count":1}]	18729	pick-up	0	12
64423	2020-05-17 22:33:17	2020-05-17	9	[{"id_menu":6,"count":1}]	7603	delivery	5	14
64424	2020-05-17 22:39:23	2020-05-17	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15933	delivery	5	34
64425	2020-05-17 22:41:39	2020-05-17	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	25341	delivery	5	22
64426	2020-05-17 22:41:57	2020-05-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1531	delivery	5	28
64427	2020-05-17 22:42:16	2020-05-17	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	17363	delivery	5	52
64428	2020-05-17 22:43:31	2020-05-17	9	[{"id_menu":6,"count":1}]	25317	delivery	5	14
64429	2020-05-17 22:43:32	2020-05-17	14	[{"id_menu":2,"count":1}]	23022	delivery	5	19
64430	2020-05-17 22:44:55	2020-05-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	15025	delivery	5	28
64431	2020-05-17 22:45:25	2020-05-17	14	[{"id_menu":2,"count":1}]	8743	pick-up	0	14
64432	2020-05-17 22:47:00	2020-05-17	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	20633	delivery	5	43
64433	2020-05-17 22:49:12	2020-05-17	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	25366	delivery	5	34
64434	2020-05-17 22:50:45	2020-05-17	12	[{"id_menu":3,"count":1}]	16517	delivery	5	17
64435	2020-05-17 22:52:50	2020-05-17	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	25345	delivery	5	36
64436	2020-05-17 22:58:53	2020-05-17	9	[{"id_menu":7,"count":1}]	25356	delivery	5	14
64437	2020-05-17 23:08:16	2020-05-17	12	[{"id_menu":3,"count":1}]	24626	delivery	5	17
64438	2020-05-17 23:10:10	2020-05-17	12	[{"id_menu":1,"count":1}]	25411	delivery	5	17
64439	2020-05-17 23:10:24	2020-05-17	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	22523	delivery	5	26
64440	2020-05-17 23:16:16	2020-05-17	17	[{"id_menu":4,"count":1}]	12779	delivery	5	22
64441	2020-05-17 23:19:59	2020-05-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	13267	pick-up	0	23
64442	2020-05-17 23:20:44	2020-05-17	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	22730	delivery	5	35
64443	2020-05-17 23:24:12	2020-05-17	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11485	delivery	5	54
64444	2020-05-17 23:24:22	2020-05-17	12	[{"id_menu":1,"count":1}]	25386	delivery	5	17
64445	2020-05-17 23:26:47	2020-05-17	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	12361	delivery	5	35
64446	2020-05-17 23:27:49	2020-05-17	9	[{"id_menu":6,"count":1}]	25344	delivery	5	14
64447	2020-05-17 23:28:16	2020-05-17	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	20345	delivery	5	34
64448	2020-05-17 23:29:19	2020-05-17	9	[{"id_menu":7,"count":1}]	5934	delivery	5	14
64449	2020-05-17 23:32:41	2020-05-17	17	[{"id_menu":4,"count":1}]	4629	pick-up	0	17
64450	2020-05-17 23:33:36	2020-05-17	12	[{"id_menu":1,"count":1}]	4309	pick-up	0	12
64451	2020-05-17 23:41:51	2020-05-17	12	[{"id_menu":3,"count":1}]	9921	pick-up	0	12
64452	2020-05-17 23:47:06	2020-05-17	14	[{"id_menu":2,"count":1}]	24030	pick-up	0	14
64453	2020-05-17 23:47:30	2020-05-17	17	[{"id_menu":4,"count":1}]	21485	pick-up	0	17
64454	2020-05-17 23:49:14	2020-05-17	9	[{"id_menu":7,"count":1}]	19121	delivery	5	14
64455	2020-05-17 23:49:59	2020-05-17	9	[{"id_menu":6,"count":1}]	25375	delivery	5	14
64456	2020-05-17 23:52:09	2020-05-17	9	[{"id_menu":7,"count":1}]	5048	pick-up	0	9
64457	2020-05-17 23:54:36	2020-05-17	14	[{"id_menu":2,"count":1}]	25432	delivery	5	19
64458	2020-05-17 23:54:45	2020-05-17	9	[{"id_menu":6,"count":2}]	25351	delivery	5	14
64459	2020-05-17 23:56:20	2020-05-17	9	[{"id_menu":6,"count":1}]	25328	delivery	5	14
64460	2020-05-17 23:56:35	2020-05-17	14	[{"id_menu":2,"count":1}]	5377	pick-up	0	14
64461	2020-05-17 23:58:59	2020-05-17	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4195	pick-up	0	38
64462	2020-05-17 23:59:35	2020-05-17	17	[{"id_menu":4,"count":1}]	5110	delivery	5	22
64463	2020-05-17 23:59:37	2020-05-17	9	[{"id_menu":6,"count":1}]	1255	pick-up	0	9
64464	2020-05-18 00:07:51	2020-05-18	12	[{"id_menu":3,"count":1}]	23167	delivery	5	17
64465	2020-05-18 00:12:35	2020-05-18	17	[{"id_menu":4,"count":1}]	12949	delivery	5	22
64466	2020-05-18 00:19:54	2020-05-18	8	[{"id_menu":5,"count":1}]	14941	delivery	5	13
64467	2020-05-18 00:20:54	2020-05-18	12	[{"id_menu":1,"count":1}]	1461	delivery	5	17
64468	2020-05-18 00:32:10	2020-05-18	9	[{"id_menu":6,"count":1}]	25484	delivery	5	14
64469	2020-05-18 00:40:10	2020-05-18	9	[{"id_menu":7,"count":1}]	25567	delivery	5	14
64470	2020-05-18 00:48:39	2020-05-18	9	[{"id_menu":6,"count":1}]	17273	delivery	5	14
64471	2020-05-18 00:51:28	2020-05-18	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	9451	delivery	5	25
64472	2020-05-18 00:52:37	2020-05-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9631	delivery	5	23
64473	2020-05-18 00:52:43	2020-05-18	17	[{"id_menu":4,"count":1}]	25532	pick-up	0	17
64474	2020-05-18 00:57:46	2020-05-18	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	25550	delivery	5	26
64475	2020-05-18 00:58:14	2020-05-18	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	24038	delivery	5	26
64476	2020-05-18 00:59:53	2020-05-18	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	599	pick-up	0	24
64477	2020-05-18 01:05:50	2020-05-18	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":2}]	292	delivery	5	22
64478	2020-05-18 01:07:02	2020-05-18	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	10479	pick-up	0	20
64479	2020-05-18 01:15:11	2020-05-18	17	[{"id_menu":4,"count":1}]	25525	pick-up	0	17
64480	2020-05-18 01:16:15	2020-05-18	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	25580	pick-up	0	17
64481	2020-05-18 01:17:22	2020-05-18	14	[{"id_menu":2,"count":1}]	10007	delivery	5	19
64482	2020-05-18 01:24:25	2020-05-18	33	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	25582	delivery	5	38
64483	2020-05-18 01:24:32	2020-05-18	14	[{"id_menu":2,"count":1}]	25563	delivery	5	19
64484	2020-05-18 01:25:59	2020-05-18	9	[{"id_menu":6,"count":1}]	19493	delivery	5	14
64485	2020-05-18 01:27:59	2020-05-18	9	[{"id_menu":6,"count":1}]	25500	pick-up	0	9
64486	2020-05-18 01:33:51	2020-05-18	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	25531	delivery	5	29
64487	2020-05-18 01:38:29	2020-05-18	8	[{"id_menu":5,"count":1}]	8651	delivery	5	13
64488	2020-05-18 01:46:35	2020-05-18	9	[{"id_menu":7,"count":1}]	24877	delivery	5	14
64489	2020-05-18 01:46:49	2020-05-18	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	12420	delivery	5	31
64490	2020-05-18 01:52:29	2020-05-18	9	[{"id_menu":6,"count":1}]	2134	pick-up	0	9
64491	2020-05-18 01:56:51	2020-05-18	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	11124	pick-up	0	17
64492	2020-05-18 01:56:58	2020-05-18	9	[{"id_menu":6,"count":1}]	4595	pick-up	0	9
64493	2020-05-18 02:17:20	2020-05-18	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	25464	pick-up	0	17
64494	2020-05-18 02:18:17	2020-05-18	9	[{"id_menu":7,"count":1}]	20595	pick-up	0	9
64495	2020-05-18 02:24:11	2020-05-18	14	[{"id_menu":2,"count":1}]	22855	delivery	5	19
64496	2020-05-18 02:25:34	2020-05-18	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25486	delivery	5	37
64497	2020-05-18 02:45:54	2020-05-18	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5930	delivery	5	36
64498	2020-05-18 02:47:33	2020-05-18	17	[{"id_menu":4,"count":1}]	1860	pick-up	0	17
64499	2020-05-18 02:48:07	2020-05-18	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	21138	delivery	5	45
64500	2020-05-18 02:53:32	2020-05-18	17	[{"id_menu":4,"count":1}]	3153	pick-up	0	17
64501	2020-05-18 03:01:02	2020-05-18	17	[{"id_menu":4,"count":1}]	11407	pick-up	0	17
64502	2020-05-18 03:13:39	2020-05-18	14	[{"id_menu":2,"count":1}]	10954	delivery	5	19
64503	2020-05-18 03:17:19	2020-05-18	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	18874	delivery	5	43
64504	2020-05-18 03:23:19	2020-05-18	17	[{"id_menu":4,"count":1}]	25478	delivery	5	22
64505	2020-05-18 03:27:53	2020-05-18	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	25504	pick-up	0	21
64506	2020-05-18 03:29:57	2020-05-18	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25456	delivery	5	31
64507	2020-05-18 03:39:44	2020-05-18	21	[{"id_menu":1,"count":3},{"id_menu":7,"count":1}]	2444	pick-up	0	21
64508	2020-05-18 03:43:08	2020-05-18	17	[{"id_menu":4,"count":1}]	5963	pick-up	0	17
64509	2020-05-18 03:43:35	2020-05-18	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13191	delivery	5	54
64510	2020-05-18 03:47:37	2020-05-18	9	[{"id_menu":6,"count":2}]	11903	delivery	5	14
64511	2020-05-18 03:54:26	2020-05-18	8	[{"id_menu":5,"count":1}]	20536	delivery	5	13
64512	2020-05-18 03:56:45	2020-05-18	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	6250	pick-up	0	22
64513	2020-05-18 04:01:04	2020-05-18	17	[{"id_menu":4,"count":1}]	527	pick-up	0	17
64514	2020-05-18 04:01:15	2020-05-18	14	[{"id_menu":2,"count":1}]	11333	delivery	5	19
64515	2020-05-18 04:09:40	2020-05-18	14	[{"id_menu":2,"count":1}]	11713	delivery	5	19
64516	2020-05-18 04:11:44	2020-05-18	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4624	pick-up	0	39
64517	2020-05-18 04:13:23	2020-05-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	19971	delivery	5	28
64518	2020-05-18 04:15:51	2020-05-18	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	25487	delivery	5	46
64519	2020-05-18 04:24:22	2020-05-18	9	[{"id_menu":6,"count":1}]	22952	pick-up	0	9
64520	2020-05-18 04:28:55	2020-05-18	12	[{"id_menu":3,"count":1}]	25466	delivery	5	17
64521	2020-05-18 04:30:02	2020-05-18	9	[{"id_menu":7,"count":1}]	1600	pick-up	0	9
64522	2020-05-18 04:34:44	2020-05-18	9	[{"id_menu":6,"count":1}]	25541	delivery	5	14
64523	2020-05-18 04:38:17	2020-05-18	8	[{"id_menu":5,"count":2}]	21705	delivery	5	13
64524	2020-05-18 04:44:47	2020-05-18	17	[{"id_menu":4,"count":2}]	17115	delivery	5	22
64525	2020-05-18 04:51:40	2020-05-18	17	[{"id_menu":4,"count":1}]	18136	delivery	5	22
64526	2020-05-18 04:59:36	2020-05-18	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	12546	delivery	5	35
64527	2020-05-18 05:01:32	2020-05-18	9	[{"id_menu":6,"count":1}]	25474	delivery	5	14
64528	2020-05-18 05:06:35	2020-05-18	9	[{"id_menu":7,"count":1}]	25479	delivery	5	14
64529	2020-05-18 05:06:46	2020-05-18	9	[{"id_menu":6,"count":1}]	660	pick-up	0	9
64530	2020-05-18 05:07:44	2020-05-18	14	[{"id_menu":2,"count":1}]	15301	delivery	5	19
64531	2020-05-18 05:09:21	2020-05-18	9	[{"id_menu":6,"count":1}]	730	pick-up	0	9
64532	2020-05-18 05:15:27	2020-05-18	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	25557	delivery	5	36
64533	2020-05-18 05:16:29	2020-05-18	12	[{"id_menu":1,"count":1}]	197	pick-up	0	12
64534	2020-05-18 05:16:40	2020-05-18	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	25517	delivery	5	23
64535	2020-05-18 05:21:53	2020-05-18	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	17018	delivery	5	31
64536	2020-05-18 05:24:40	2020-05-18	55	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	25524	delivery	5	60
64537	2020-05-18 05:29:28	2020-05-18	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	14711	delivery	5	31
64538	2020-05-18 05:30:41	2020-05-18	8	[{"id_menu":5,"count":1}]	283	pick-up	0	8
64539	2020-05-18 05:33:52	2020-05-18	9	[{"id_menu":7,"count":1}]	11254	delivery	5	14
64540	2020-05-18 05:53:24	2020-05-18	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	25446	delivery	5	36
64541	2020-05-18 06:02:59	2020-05-18	14	[{"id_menu":2,"count":2}]	16495	delivery	5	19
64542	2020-05-18 06:10:41	2020-05-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22928	delivery	5	23
64543	2020-05-18 06:11:21	2020-05-18	9	[{"id_menu":6,"count":2}]	20965	delivery	5	14
64544	2020-05-18 06:15:20	2020-05-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":3}]	21173	delivery	5	28
64545	2020-05-18 06:21:11	2020-05-18	12	[{"id_menu":3,"count":1}]	6441	delivery	5	17
64546	2020-05-18 06:21:27	2020-05-18	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	18840	delivery	5	25
64547	2020-05-18 06:23:15	2020-05-18	17	[{"id_menu":4,"count":2}]	4295	pick-up	0	17
64548	2020-05-18 06:30:49	2020-05-18	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7650	delivery	5	30
64549	2020-05-18 06:32:41	2020-05-18	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	23555	pick-up	0	21
64550	2020-05-18 06:32:59	2020-05-18	17	[{"id_menu":4,"count":1}]	12519	delivery	5	22
64551	2020-05-18 06:34:20	2020-05-18	17	[{"id_menu":4,"count":1}]	23986	delivery	5	22
64552	2020-05-18 06:49:23	2020-05-18	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	485	delivery	5	31
64553	2020-05-18 06:50:36	2020-05-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	25543	delivery	5	23
64554	2020-05-18 06:56:18	2020-05-18	12	[{"id_menu":3,"count":1}]	19438	delivery	5	17
64555	2020-05-18 06:58:14	2020-05-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21617	delivery	5	22
64556	2020-05-18 06:58:55	2020-05-18	8	[{"id_menu":5,"count":1}]	11988	delivery	5	13
64557	2020-05-18 07:05:16	2020-05-18	12	[{"id_menu":1,"count":1}]	25452	delivery	5	17
64558	2020-05-18 07:07:43	2020-05-18	12	[{"id_menu":3,"count":1}]	25489	delivery	5	17
64559	2020-05-18 07:09:52	2020-05-18	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	837	delivery	5	31
64560	2020-05-18 07:20:37	2020-05-18	9	[{"id_menu":7,"count":1}]	1871	pick-up	0	9
64561	2020-05-18 07:21:37	2020-05-18	9	[{"id_menu":6,"count":1}]	11962	delivery	5	14
64562	2020-05-18 07:32:24	2020-05-18	9	[{"id_menu":6,"count":1}]	25485	delivery	5	14
64563	2020-05-18 07:38:30	2020-05-18	8	[{"id_menu":5,"count":3}]	13636	delivery	5	13
64564	2020-05-18 07:45:52	2020-05-18	9	[{"id_menu":6,"count":1}]	20421	delivery	5	14
64565	2020-05-18 07:47:32	2020-05-18	9	[{"id_menu":6,"count":1}]	8514	delivery	5	14
64566	2020-05-18 07:57:59	2020-05-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	25533	delivery	5	28
64567	2020-05-18 08:00:16	2020-05-18	17	[{"id_menu":4,"count":1}]	5701	pick-up	0	17
64568	2020-05-18 08:06:01	2020-05-18	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	25608	delivery	5	29
64569	2020-05-18 08:13:12	2020-05-18	8	[{"id_menu":5,"count":1}]	25496	delivery	5	13
64570	2020-05-18 08:13:22	2020-05-18	9	[{"id_menu":7,"count":1}]	25313	delivery	5	14
64571	2020-05-18 08:17:07	2020-05-18	12	[{"id_menu":1,"count":1}]	25476	delivery	5	17
64572	2020-05-18 08:23:54	2020-05-18	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	23350	pick-up	0	22
64573	2020-05-18 08:24:15	2020-05-18	17	[{"id_menu":4,"count":1}]	25443	delivery	5	22
64574	2020-05-18 08:33:47	2020-05-18	9	[{"id_menu":6,"count":1}]	10258	delivery	5	14
64575	2020-05-18 08:36:05	2020-05-18	8	[{"id_menu":5,"count":1}]	25610	delivery	5	13
64576	2020-05-18 08:38:06	2020-05-18	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	7076	delivery	5	25
64577	2020-05-18 08:38:34	2020-05-18	9	[{"id_menu":6,"count":1}]	6503	delivery	5	14
64578	2020-05-18 08:40:30	2020-05-18	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	11529	delivery	5	29
64579	2020-05-18 08:55:58	2020-05-18	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25483	delivery	5	43
64580	2020-05-18 09:04:49	2020-05-18	14	[{"id_menu":2,"count":1}]	6518	delivery	5	19
64581	2020-05-18 09:10:27	2020-05-18	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	784	pick-up	0	29
64582	2020-05-18 09:16:48	2020-05-18	12	[{"id_menu":1,"count":1}]	19075	pick-up	0	12
64583	2020-05-18 09:38:31	2020-05-18	14	[{"id_menu":2,"count":1}]	25596	pick-up	0	14
64584	2020-05-18 09:42:09	2020-05-18	9	[{"id_menu":7,"count":1}]	25558	delivery	5	14
64585	2020-05-18 09:43:12	2020-05-18	8	[{"id_menu":5,"count":1}]	22197	delivery	5	13
64586	2020-05-18 09:54:23	2020-05-18	8	[{"id_menu":5,"count":1}]	19705	delivery	5	13
64587	2020-05-18 10:06:48	2020-05-18	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	25577	delivery	5	26
64588	2020-05-18 10:08:17	2020-05-18	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	25549	delivery	5	36
64589	2020-05-18 10:13:16	2020-05-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	11030	delivery	5	28
64590	2020-05-18 10:14:53	2020-05-18	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	25493	delivery	5	25
64591	2020-05-18 10:16:04	2020-05-18	9	[{"id_menu":6,"count":1}]	18057	pick-up	0	9
64592	2020-05-18 10:16:26	2020-05-18	14	[{"id_menu":2,"count":1}]	4790	pick-up	0	14
64593	2020-05-18 10:22:13	2020-05-18	14	[{"id_menu":2,"count":1}]	21107	delivery	5	19
64594	2020-05-18 10:25:13	2020-05-18	9	[{"id_menu":7,"count":1}]	25513	delivery	5	14
64595	2020-05-18 10:28:56	2020-05-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25565	delivery	5	23
64596	2020-05-18 10:29:08	2020-05-18	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	25599	delivery	5	29
64597	2020-05-18 10:39:12	2020-05-18	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	16578	delivery	5	48
64598	2020-05-18 10:40:42	2020-05-18	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25600	delivery	5	35
64599	2020-05-18 10:44:08	2020-05-18	8	[{"id_menu":5,"count":1}]	19128	delivery	5	13
64600	2020-05-18 10:46:02	2020-05-18	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10798	pick-up	0	25
64601	2020-05-18 10:49:02	2020-05-18	12	[{"id_menu":3,"count":1}]	14551	delivery	5	17
64602	2020-05-18 10:50:48	2020-05-18	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2761	delivery	5	31
64603	2020-05-18 10:54:27	2020-05-18	9	[{"id_menu":6,"count":1}]	25606	delivery	5	14
64604	2020-05-18 10:56:02	2020-05-18	17	[{"id_menu":4,"count":1}]	12524	delivery	5	22
64605	2020-05-18 11:00:31	2020-05-18	12	[{"id_menu":1,"count":1}]	25601	delivery	5	17
64606	2020-05-18 11:02:00	2020-05-18	9	[{"id_menu":7,"count":1}]	2804	delivery	5	14
64607	2020-05-18 11:02:10	2020-05-18	9	[{"id_menu":7,"count":1}]	7115	delivery	5	14
64608	2020-05-18 11:04:31	2020-05-18	14	[{"id_menu":2,"count":1}]	12095	pick-up	0	14
64609	2020-05-18 11:04:35	2020-05-18	9	[{"id_menu":7,"count":1}]	1839	pick-up	0	9
64610	2020-05-18 11:07:36	2020-05-18	14	[{"id_menu":2,"count":1}]	256	pick-up	0	14
64611	2020-05-18 11:14:19	2020-05-18	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	25555	delivery	5	23
64612	2020-05-18 11:17:11	2020-05-18	8	[{"id_menu":5,"count":1}]	1836	pick-up	0	8
64613	2020-05-18 11:22:15	2020-05-18	14	[{"id_menu":2,"count":1}]	18575	pick-up	0	14
64614	2020-05-18 11:27:04	2020-05-18	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	10250	delivery	5	25
64615	2020-05-18 11:43:36	2020-05-18	12	[{"id_menu":1,"count":1}]	25442	delivery	5	17
64616	2020-05-18 11:44:28	2020-05-18	9	[{"id_menu":6,"count":2}]	24304	delivery	5	14
64617	2020-05-18 11:45:24	2020-05-18	12	[{"id_menu":1,"count":1}]	3299	pick-up	0	12
64618	2020-05-18 11:50:17	2020-05-18	9	[{"id_menu":6,"count":1}]	25465	delivery	5	14
64619	2020-05-18 11:53:04	2020-05-18	9	[{"id_menu":7,"count":1}]	25572	pick-up	0	9
64620	2020-05-18 11:53:22	2020-05-18	8	[{"id_menu":5,"count":1}]	12944	delivery	5	13
64621	2020-05-18 11:55:32	2020-05-18	9	[{"id_menu":7,"count":1}]	968	delivery	5	14
64622	2020-05-18 11:58:37	2020-05-18	9	[{"id_menu":6,"count":2}]	24181	delivery	5	14
64623	2020-05-18 12:01:26	2020-05-18	17	[{"id_menu":4,"count":2}]	25521	delivery	5	22
64624	2020-05-18 12:04:14	2020-05-18	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	25447	delivery	5	26
64625	2020-05-18 12:07:07	2020-05-18	9	[{"id_menu":7,"count":1}]	25552	delivery	5	14
64626	2020-05-18 12:09:32	2020-05-18	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	11670	delivery	5	26
64627	2020-05-18 12:12:01	2020-05-18	9	[{"id_menu":7,"count":1}]	25460	delivery	5	14
64628	2020-05-18 12:12:09	2020-05-18	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	23903	pick-up	0	26
64629	2020-05-18 12:12:44	2020-05-18	8	[{"id_menu":5,"count":1}]	18125	delivery	5	13
64630	2020-05-18 12:12:47	2020-05-18	9	[{"id_menu":7,"count":1}]	19068	delivery	5	14
64631	2020-05-18 12:22:51	2020-05-18	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	23486	delivery	5	55
64632	2020-05-18 12:29:54	2020-05-18	14	[{"id_menu":2,"count":1}]	17912	delivery	5	19
64633	2020-05-18 12:32:38	2020-05-18	9	[{"id_menu":6,"count":1}]	25583	delivery	5	14
64634	2020-05-18 12:37:04	2020-05-18	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	9215	delivery	5	31
64635	2020-05-18 12:41:17	2020-05-18	9	[{"id_menu":6,"count":1}]	15701	pick-up	0	9
64636	2020-05-18 12:41:34	2020-05-18	8	[{"id_menu":5,"count":1}]	2302	delivery	5	13
64637	2020-05-18 12:42:54	2020-05-18	9	[{"id_menu":6,"count":1}]	9836	delivery	5	14
64638	2020-05-18 12:57:33	2020-05-18	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	25508	pick-up	0	21
64639	2020-05-18 13:00:31	2020-05-18	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	25519	delivery	5	31
64640	2020-05-18 13:04:25	2020-05-18	9	[{"id_menu":6,"count":2}]	3940	pick-up	0	9
64641	2020-05-18 13:11:36	2020-05-18	8	[{"id_menu":5,"count":1}]	25548	pick-up	0	8
64642	2020-05-18 13:15:21	2020-05-18	12	[{"id_menu":3,"count":1}]	25490	delivery	5	17
64643	2020-05-18 13:16:00	2020-05-18	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	25498	delivery	5	37
64644	2020-05-18 13:18:18	2020-05-18	9	[{"id_menu":6,"count":2}]	25561	delivery	5	14
64645	2020-05-18 13:18:22	2020-05-18	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	4973	delivery	5	26
64646	2020-05-18 13:24:13	2020-05-18	17	[{"id_menu":4,"count":2}]	25491	delivery	5	22
64647	2020-05-18 13:28:29	2020-05-18	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	13064	delivery	5	43
64648	2020-05-18 13:28:38	2020-05-18	12	[{"id_menu":3,"count":1}]	1021	pick-up	0	12
64649	2020-05-18 13:30:22	2020-05-18	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":2}]	7821	delivery	5	26
64650	2020-05-18 13:33:30	2020-05-18	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2415	delivery	5	36
64651	2020-05-18 13:36:54	2020-05-18	17	[{"id_menu":4,"count":1}]	25568	delivery	5	22
64652	2020-05-18 13:38:44	2020-05-18	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17404	delivery	5	31
64653	2020-05-18 13:40:53	2020-05-18	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	8347	pick-up	0	23
64654	2020-05-18 13:47:41	2020-05-18	8	[{"id_menu":5,"count":1}]	7169	delivery	5	13
64655	2020-05-18 13:47:43	2020-05-18	12	[{"id_menu":1,"count":1}]	25584	delivery	5	17
64656	2020-05-18 13:49:53	2020-05-18	12	[{"id_menu":3,"count":1}]	21785	pick-up	0	12
64657	2020-05-18 13:55:00	2020-05-18	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6348	delivery	5	31
64658	2020-05-18 13:55:49	2020-05-18	12	[{"id_menu":3,"count":1}]	2440	delivery	5	17
64659	2020-05-18 14:06:55	2020-05-18	9	[{"id_menu":6,"count":1}]	2907	pick-up	0	9
64660	2020-05-18 14:15:01	2020-05-18	9	[{"id_menu":6,"count":1}]	13131	delivery	5	14
64661	2020-05-18 14:20:03	2020-05-18	17	[{"id_menu":4,"count":1}]	25578	delivery	5	22
64662	2020-05-18 14:25:07	2020-05-18	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	144	pick-up	0	25
64663	2020-05-18 14:28:58	2020-05-18	9	[{"id_menu":6,"count":1}]	25455	pick-up	0	9
64664	2020-05-18 14:37:54	2020-05-18	14	[{"id_menu":2,"count":1}]	4049	pick-up	0	14
64665	2020-05-18 14:37:57	2020-05-18	8	[{"id_menu":5,"count":1}]	25574	delivery	5	13
64666	2020-05-18 14:41:25	2020-05-18	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5146	delivery	5	31
64667	2020-05-18 14:42:49	2020-05-18	9	[{"id_menu":7,"count":1}]	25471	delivery	5	14
64668	2020-05-18 14:47:14	2020-05-18	17	[{"id_menu":4,"count":1}]	25457	delivery	5	22
64669	2020-05-18 14:48:07	2020-05-18	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	18459	delivery	5	27
64670	2020-05-18 14:48:45	2020-05-18	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	25461	delivery	5	30
64671	2020-05-18 14:50:39	2020-05-18	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	25440	delivery	5	26
64672	2020-05-18 15:06:23	2020-05-18	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25609	delivery	5	54
64673	2020-05-18 15:07:11	2020-05-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25503	delivery	5	22
64674	2020-05-18 15:09:17	2020-05-18	9	[{"id_menu":7,"count":1}]	4826	delivery	5	14
64675	2020-05-18 15:10:52	2020-05-18	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	25588	delivery	5	22
64676	2020-05-18 15:12:16	2020-05-18	12	[{"id_menu":1,"count":1}]	18409	pick-up	0	12
64677	2020-05-18 15:23:33	2020-05-18	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	15271	delivery	5	28
64678	2020-05-18 15:26:14	2020-05-18	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	20277	delivery	5	26
64679	2020-05-18 15:39:23	2020-05-18	12	[{"id_menu":3,"count":1}]	2694	delivery	5	17
64680	2020-05-18 15:43:12	2020-05-18	12	[{"id_menu":1,"count":1}]	25544	delivery	5	17
64681	2020-05-18 15:52:48	2020-05-18	14	[{"id_menu":2,"count":1}]	3647	delivery	5	19
64682	2020-05-18 15:54:08	2020-05-18	17	[{"id_menu":4,"count":1}]	2288	pick-up	0	17
64683	2020-05-18 15:54:54	2020-05-18	12	[{"id_menu":3,"count":1}]	20592	delivery	5	17
64684	2020-05-18 15:58:47	2020-05-18	8	[{"id_menu":5,"count":1}]	25495	delivery	5	13
64685	2020-05-18 16:03:02	2020-05-18	8	[{"id_menu":5,"count":1}]	4159	delivery	5	13
64686	2020-05-18 16:04:26	2020-05-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	14954	delivery	5	28
64687	2020-05-18 16:16:43	2020-05-18	9	[{"id_menu":7,"count":1}]	19966	delivery	5	14
64688	2020-05-18 16:19:04	2020-05-18	17	[{"id_menu":4,"count":1}]	3002	delivery	5	22
64689	2020-05-18 16:31:51	2020-05-18	12	[{"id_menu":3,"count":2}]	5839	delivery	5	17
64690	2020-05-18 16:33:56	2020-05-18	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25450	delivery	5	35
64691	2020-05-18 16:35:41	2020-05-18	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	7510	pick-up	0	25
64692	2020-05-18 16:36:55	2020-05-18	17	[{"id_menu":4,"count":1}]	1434	pick-up	0	17
64693	2020-05-18 16:38:03	2020-05-18	9	[{"id_menu":6,"count":1}]	25506	delivery	5	14
64694	2020-05-18 16:38:51	2020-05-18	9	[{"id_menu":7,"count":1}]	22459	pick-up	0	9
64695	2020-05-18 16:39:01	2020-05-18	9	[{"id_menu":6,"count":1}]	11990	delivery	5	14
64696	2020-05-18 16:40:52	2020-05-18	12	[{"id_menu":1,"count":1}]	1411	delivery	5	17
64697	2020-05-18 16:41:23	2020-05-18	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	25594	delivery	5	34
64698	2020-05-18 16:42:58	2020-05-18	9	[{"id_menu":6,"count":2}]	20907	delivery	5	14
64699	2020-05-18 16:51:03	2020-05-18	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	16669	delivery	5	31
64700	2020-05-18 17:04:52	2020-05-18	8	[{"id_menu":5,"count":1}]	7941	pick-up	0	8
64701	2020-05-18 17:11:14	2020-05-18	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	25515	delivery	5	31
64702	2020-05-18 17:21:06	2020-05-18	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	24605	delivery	5	45
64703	2020-05-18 17:28:49	2020-05-18	17	[{"id_menu":4,"count":1}]	18901	delivery	5	22
64704	2020-05-18 17:28:55	2020-05-18	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	25559	delivery	5	22
64705	2020-05-18 17:31:04	2020-05-18	17	[{"id_menu":4,"count":1}]	15564	delivery	5	22
64706	2020-05-18 17:34:12	2020-05-18	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	25505	delivery	5	31
64707	2020-05-18 17:39:29	2020-05-18	12	[{"id_menu":1,"count":1}]	25279	pick-up	0	12
64708	2020-05-18 17:39:47	2020-05-18	9	[{"id_menu":6,"count":1}]	25523	delivery	5	14
64709	2020-05-18 17:49:59	2020-05-18	9	[{"id_menu":6,"count":1}]	25560	delivery	5	14
64710	2020-05-18 17:53:05	2020-05-18	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	23453	delivery	5	26
64711	2020-05-18 17:57:38	2020-05-18	17	[{"id_menu":4,"count":1}]	10589	pick-up	0	17
64712	2020-05-18 18:01:44	2020-05-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	25482	delivery	5	22
64713	2020-05-18 18:02:58	2020-05-18	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25556	delivery	5	47
64714	2020-05-18 18:03:03	2020-05-18	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	333	pick-up	0	20
64715	2020-05-18 18:08:52	2020-05-18	9	[{"id_menu":6,"count":1}]	25467	delivery	5	14
64716	2020-05-18 18:14:54	2020-05-18	9	[{"id_menu":6,"count":1}]	4337	delivery	5	14
64717	2020-05-18 18:26:55	2020-05-18	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	21392	delivery	5	23
64718	2020-05-18 18:33:50	2020-05-18	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	25470	delivery	5	34
64719	2020-05-18 18:34:13	2020-05-18	9	[{"id_menu":6,"count":1}]	25542	delivery	5	14
64720	2020-05-18 18:37:33	2020-05-18	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	25488	pick-up	0	21
64721	2020-05-18 18:45:06	2020-05-18	9	[{"id_menu":7,"count":1}]	7227	delivery	5	14
64722	2020-05-18 18:48:44	2020-05-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19429	delivery	5	22
64723	2020-05-18 18:53:06	2020-05-18	9	[{"id_menu":7,"count":1}]	2540	pick-up	0	9
64724	2020-05-18 18:56:03	2020-05-18	14	[{"id_menu":2,"count":1}]	16629	pick-up	0	14
64725	2020-05-18 18:56:03	2020-05-18	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	12108	pick-up	0	31
64726	2020-05-18 18:59:53	2020-05-18	9	[{"id_menu":6,"count":1}]	16102	delivery	5	14
64727	2020-05-18 19:01:03	2020-05-18	9	[{"id_menu":7,"count":1}]	25510	delivery	5	14
64728	2020-05-18 19:01:50	2020-05-18	12	[{"id_menu":1,"count":1}]	2590	delivery	5	17
64729	2020-05-18 19:03:20	2020-05-18	9	[{"id_menu":7,"count":1}]	25576	delivery	5	14
64730	2020-05-18 19:09:04	2020-05-18	9	[{"id_menu":7,"count":1}]	16828	delivery	5	14
64731	2020-05-18 19:13:26	2020-05-18	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	25445	delivery	5	22
64732	2020-05-18 19:20:01	2020-05-18	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7426	delivery	5	45
64733	2020-05-18 19:31:47	2020-05-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	25540	delivery	5	28
64734	2020-05-18 19:38:45	2020-05-18	8	[{"id_menu":5,"count":1}]	10039	pick-up	0	8
64735	2020-05-18 19:40:00	2020-05-18	12	[{"id_menu":3,"count":1}]	21152	delivery	5	17
64736	2020-05-18 19:43:02	2020-05-18	14	[{"id_menu":2,"count":1}]	5629	delivery	5	19
64737	2020-05-18 19:57:41	2020-05-18	14	[{"id_menu":2,"count":1}]	25501	delivery	5	19
64738	2020-05-18 20:09:25	2020-05-18	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21370	delivery	5	40
64739	2020-05-18 20:16:04	2020-05-18	14	[{"id_menu":2,"count":1}]	19815	pick-up	0	14
64740	2020-05-18 20:21:49	2020-05-18	8	[{"id_menu":5,"count":1}]	25590	delivery	5	13
64741	2020-05-18 20:28:32	2020-05-18	17	[{"id_menu":5,"count":3},{"id_menu":6,"count":1}]	25575	delivery	5	22
64742	2020-05-18 20:33:38	2020-05-18	14	[{"id_menu":2,"count":1}]	25545	delivery	5	19
64743	2020-05-18 20:38:54	2020-05-18	9	[{"id_menu":7,"count":1}]	8298	pick-up	0	9
64744	2020-05-18 20:50:07	2020-05-18	38	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16230	delivery	5	43
64745	2020-05-18 20:50:42	2020-05-18	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	23040	pick-up	0	21
64746	2020-05-18 20:52:06	2020-05-18	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	25598	delivery	5	22
64747	2020-05-18 20:52:08	2020-05-18	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6824	delivery	5	22
64748	2020-05-18 20:53:30	2020-05-18	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25520	delivery	5	45
64749	2020-05-18 20:57:04	2020-05-18	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	16223	delivery	5	31
64750	2020-05-18 21:00:02	2020-05-18	8	[{"id_menu":5,"count":1}]	8300	delivery	5	13
64751	2020-05-18 21:04:57	2020-05-18	12	[{"id_menu":1,"count":1}]	5201	delivery	5	17
64752	2020-05-18 21:08:47	2020-05-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9364	delivery	5	28
64753	2020-05-18 21:27:11	2020-05-18	12	[{"id_menu":3,"count":2}]	25571	pick-up	0	12
64754	2020-05-18 21:35:21	2020-05-18	14	[{"id_menu":2,"count":1}]	23863	delivery	5	19
64755	2020-05-18 21:36:08	2020-05-18	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2185	pick-up	0	26
64756	2020-05-18 22:10:55	2020-05-18	9	[{"id_menu":7,"count":1}]	2187	pick-up	0	9
64757	2020-05-18 22:14:18	2020-05-18	9	[{"id_menu":6,"count":1}]	14088	pick-up	0	9
64758	2020-05-18 22:41:04	2020-05-18	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	25475	delivery	5	25
64759	2020-05-18 22:57:45	2020-05-18	17	[{"id_menu":4,"count":1}]	25526	pick-up	0	17
64760	2020-05-18 23:00:09	2020-05-18	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	25507	delivery	5	39
64761	2020-05-18 23:02:58	2020-05-18	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	18764	delivery	5	45
64762	2020-05-18 23:06:37	2020-05-18	12	[{"id_menu":1,"count":1}]	25451	pick-up	0	12
64763	2020-05-18 23:09:07	2020-05-18	9	[{"id_menu":7,"count":2}]	12366	delivery	5	14
64764	2020-05-18 23:10:27	2020-05-18	12	[{"id_menu":3,"count":1}]	25480	delivery	5	17
64765	2020-05-18 23:25:19	2020-05-18	9	[{"id_menu":7,"count":1}]	25569	delivery	5	14
64766	2020-05-18 23:27:23	2020-05-18	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	409	delivery	5	51
64767	2020-05-18 23:28:11	2020-05-18	12	[{"id_menu":3,"count":2}]	18132	delivery	5	17
64768	2020-05-18 23:30:31	2020-05-18	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	25585	delivery	5	26
64769	2020-05-18 23:32:07	2020-05-18	12	[{"id_menu":3,"count":1}]	19783	delivery	5	17
64770	2020-05-18 23:38:10	2020-05-18	12	[{"id_menu":1,"count":1}]	14679	delivery	5	17
64771	2020-05-18 23:53:08	2020-05-18	14	[{"id_menu":2,"count":1}]	8900	pick-up	0	14
64772	2020-05-18 23:59:18	2020-05-18	12	[{"id_menu":1,"count":1}]	15720	delivery	5	17
64773	2020-05-19 00:04:59	2020-05-19	12	[{"id_menu":1,"count":1}]	16322	delivery	5	17
64774	2020-05-19 00:08:17	2020-05-19	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	20796	delivery	5	26
64775	2020-05-19 00:11:56	2020-05-19	12	[{"id_menu":3,"count":1}]	16914	pick-up	0	12
64776	2020-05-19 00:15:12	2020-05-19	14	[{"id_menu":2,"count":2}]	21053	delivery	5	19
64777	2020-05-19 00:25:19	2020-05-19	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	4079	delivery	5	26
64778	2020-05-19 00:28:36	2020-05-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17697	delivery	5	31
64779	2020-05-19 00:28:46	2020-05-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6855	pick-up	0	26
64780	2020-05-19 00:29:30	2020-05-19	14	[{"id_menu":2,"count":1}]	25682	delivery	5	19
64781	2020-05-19 00:29:41	2020-05-19	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	25654	delivery	5	31
64782	2020-05-19 00:37:48	2020-05-19	9	[{"id_menu":6,"count":1}]	16469	pick-up	0	9
64783	2020-05-19 00:39:12	2020-05-19	8	[{"id_menu":5,"count":1}]	11732	pick-up	0	8
64784	2020-05-19 00:45:11	2020-05-19	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	20524	delivery	5	36
64785	2020-05-19 00:46:10	2020-05-19	12	[{"id_menu":1,"count":1}]	13456	delivery	5	17
64786	2020-05-19 00:46:44	2020-05-19	9	[{"id_menu":6,"count":1}]	14190	delivery	5	14
64787	2020-05-19 00:48:22	2020-05-19	12	[{"id_menu":3,"count":1}]	8047	delivery	5	17
64788	2020-05-19 00:52:25	2020-05-19	9	[{"id_menu":7,"count":1}]	12588	delivery	5	14
64789	2020-05-19 00:53:24	2020-05-19	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23061	delivery	5	51
64790	2020-05-19 00:55:35	2020-05-19	9	[{"id_menu":7,"count":1}]	25799	delivery	5	14
64791	2020-05-19 00:57:31	2020-05-19	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	14144	delivery	5	26
64792	2020-05-19 01:04:26	2020-05-19	17	[{"id_menu":4,"count":1}]	25697	delivery	5	22
64793	2020-05-19 01:05:10	2020-05-19	17	[{"id_menu":4,"count":1}]	25197	delivery	5	22
64794	2020-05-19 01:16:41	2020-05-19	9	[{"id_menu":6,"count":1}]	2101	pick-up	0	9
64795	2020-05-19 01:16:55	2020-05-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2351	pick-up	0	31
64796	2020-05-19 01:19:43	2020-05-19	30	[{"id_menu":1,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2783	pick-up	0	30
64797	2020-05-19 01:21:25	2020-05-19	12	[{"id_menu":3,"count":1}]	21378	delivery	5	17
64798	2020-05-19 01:22:16	2020-05-19	9	[{"id_menu":6,"count":1}]	9635	pick-up	0	9
64799	2020-05-19 01:22:41	2020-05-19	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	16183	delivery	5	26
64800	2020-05-19 01:23:06	2020-05-19	17	[{"id_menu":4,"count":1}]	22500	delivery	5	22
64801	2020-05-19 01:23:36	2020-05-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6484	pick-up	0	31
64802	2020-05-19 01:26:57	2020-05-19	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1885	pick-up	0	24
64803	2020-05-19 01:29:01	2020-05-19	9	[{"id_menu":6,"count":1}]	25650	delivery	5	14
64804	2020-05-19 01:31:21	2020-05-19	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	517	delivery	5	36
64805	2020-05-19 01:31:28	2020-05-19	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	14065	pick-up	0	43
64806	2020-05-19 01:33:05	2020-05-19	12	[{"id_menu":3,"count":1}]	25748	delivery	5	17
64807	2020-05-19 01:33:20	2020-05-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6957	delivery	5	23
64808	2020-05-19 01:33:40	2020-05-19	9	[{"id_menu":6,"count":1}]	287	pick-up	0	9
64809	2020-05-19 01:38:47	2020-05-19	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	25749	delivery	5	31
64810	2020-05-19 01:39:52	2020-05-19	8	[{"id_menu":5,"count":1}]	25689	delivery	5	13
64811	2020-05-19 01:45:44	2020-05-19	9	[{"id_menu":6,"count":1}]	6880	delivery	5	14
64812	2020-05-19 01:45:47	2020-05-19	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14649	delivery	5	34
64813	2020-05-19 01:52:51	2020-05-19	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13371	delivery	5	34
64814	2020-05-19 01:53:46	2020-05-19	12	[{"id_menu":1,"count":1}]	25668	delivery	5	17
64815	2020-05-19 01:57:18	2020-05-19	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	20424	delivery	5	43
64816	2020-05-19 02:05:14	2020-05-19	8	[{"id_menu":5,"count":1}]	9798	delivery	5	13
64817	2020-05-19 02:18:07	2020-05-19	12	[{"id_menu":1,"count":1}]	1069	pick-up	0	12
64818	2020-05-19 02:18:10	2020-05-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6796	pick-up	0	23
64819	2020-05-19 02:20:58	2020-05-19	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24585	pick-up	0	49
64820	2020-05-19 02:22:48	2020-05-19	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	14519	pick-up	0	29
64821	2020-05-19 02:25:40	2020-05-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	25740	delivery	5	31
64822	2020-05-19 02:28:18	2020-05-19	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	16438	delivery	5	26
64823	2020-05-19 02:30:12	2020-05-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6947	pick-up	0	31
64824	2020-05-19 02:35:21	2020-05-19	17	[{"id_menu":4,"count":1}]	25674	delivery	5	22
64825	2020-05-19 02:36:24	2020-05-19	12	[{"id_menu":1,"count":1}]	8324	delivery	5	17
64826	2020-05-19 02:39:34	2020-05-19	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	18929	delivery	5	45
64827	2020-05-19 02:44:26	2020-05-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	3903	pick-up	0	31
64828	2020-05-19 03:01:15	2020-05-19	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25625	delivery	5	34
64829	2020-05-19 03:04:51	2020-05-19	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17114	pick-up	0	38
64830	2020-05-19 03:05:07	2020-05-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	25676	delivery	5	31
64831	2020-05-19 03:05:31	2020-05-19	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	17526	pick-up	0	26
64832	2020-05-19 03:16:03	2020-05-19	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25665	delivery	5	48
64833	2020-05-19 03:17:04	2020-05-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	11825	delivery	5	23
64834	2020-05-19 03:17:47	2020-05-19	9	[{"id_menu":7,"count":2}]	25613	delivery	5	14
64835	2020-05-19 03:19:56	2020-05-19	9	[{"id_menu":7,"count":1}]	25700	pick-up	0	9
64836	2020-05-19 03:23:49	2020-05-19	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	74	delivery	5	34
64837	2020-05-19 03:26:23	2020-05-19	12	[{"id_menu":3,"count":1}]	25620	delivery	5	17
64838	2020-05-19 03:34:17	2020-05-19	9	[{"id_menu":6,"count":1}]	1325	delivery	5	14
64839	2020-05-19 03:37:28	2020-05-19	14	[{"id_menu":2,"count":1}]	4702	delivery	5	19
64840	2020-05-19 03:50:03	2020-05-19	9	[{"id_menu":6,"count":1}]	25709	delivery	5	14
64841	2020-05-19 03:54:48	2020-05-19	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21038	delivery	5	37
64842	2020-05-19 03:56:21	2020-05-19	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25794	delivery	5	53
64843	2020-05-19 03:58:38	2020-05-19	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	25673	delivery	5	27
64844	2020-05-19 04:12:45	2020-05-19	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	25653	delivery	5	28
64845	2020-05-19 04:16:15	2020-05-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	7390	delivery	5	23
64846	2020-05-19 04:18:50	2020-05-19	9	[{"id_menu":6,"count":1}]	2097	delivery	5	14
64847	2020-05-19 04:20:12	2020-05-19	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	14228	delivery	5	30
64848	2020-05-19 04:22:02	2020-05-19	12	[{"id_menu":3,"count":1}]	13497	delivery	5	17
64849	2020-05-19 04:23:03	2020-05-19	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48	delivery	5	54
64850	2020-05-19 04:26:56	2020-05-19	8	[{"id_menu":5,"count":1}]	18927	delivery	5	13
64851	2020-05-19 04:31:18	2020-05-19	8	[{"id_menu":5,"count":1}]	4408	pick-up	0	8
64852	2020-05-19 04:32:07	2020-05-19	9	[{"id_menu":6,"count":1}]	11840	delivery	5	14
64853	2020-05-19 04:38:13	2020-05-19	9	[{"id_menu":7,"count":1}]	25628	delivery	5	14
64854	2020-05-19 04:38:19	2020-05-19	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17698	delivery	5	40
64855	2020-05-19 04:38:55	2020-05-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2761	delivery	5	23
64856	2020-05-19 04:41:12	2020-05-19	9	[{"id_menu":6,"count":1}]	352	pick-up	0	9
64857	2020-05-19 04:42:16	2020-05-19	12	[{"id_menu":1,"count":1}]	23696	pick-up	0	12
64858	2020-05-19 04:42:51	2020-05-19	17	[{"id_menu":4,"count":1}]	14558	pick-up	0	17
64859	2020-05-19 04:49:39	2020-05-19	12	[{"id_menu":3,"count":1}]	25450	delivery	5	17
64860	2020-05-19 04:51:01	2020-05-19	12	[{"id_menu":3,"count":1}]	6250	delivery	5	17
64861	2020-05-19 04:51:46	2020-05-19	12	[{"id_menu":1,"count":1}]	368	delivery	5	17
64862	2020-05-19 04:54:02	2020-05-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1822	pick-up	0	26
64863	2020-05-19 05:01:43	2020-05-19	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	23201	delivery	5	39
64864	2020-05-19 05:09:19	2020-05-19	12	[{"id_menu":3,"count":2}]	3590	delivery	5	17
64865	2020-05-19 05:12:40	2020-05-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1176	pick-up	0	31
64866	2020-05-19 05:20:12	2020-05-19	12	[{"id_menu":3,"count":1}]	3399	pick-up	0	12
64867	2020-05-19 05:33:20	2020-05-19	12	[{"id_menu":3,"count":2}]	1715	delivery	5	17
64868	2020-05-19 05:55:04	2020-05-19	9	[{"id_menu":6,"count":1}]	2601	pick-up	0	9
64869	2020-05-19 05:57:10	2020-05-19	12	[{"id_menu":1,"count":1}]	25646	delivery	5	17
64870	2020-05-19 06:01:13	2020-05-19	12	[{"id_menu":3,"count":1}]	22060	delivery	5	17
64871	2020-05-19 06:01:37	2020-05-19	9	[{"id_menu":7,"count":1}]	10525	delivery	5	14
64872	2020-05-19 06:02:40	2020-05-19	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2436	pick-up	0	25
64873	2020-05-19 06:10:34	2020-05-19	9	[{"id_menu":7,"count":1}]	25622	delivery	5	14
64874	2020-05-19 06:12:11	2020-05-19	17	[{"id_menu":4,"count":1}]	8866	delivery	5	22
64875	2020-05-19 06:13:09	2020-05-19	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	20805	delivery	5	31
64876	2020-05-19 06:13:51	2020-05-19	9	[{"id_menu":6,"count":1}]	25636	pick-up	0	9
64877	2020-05-19 06:16:09	2020-05-19	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6576	delivery	5	36
64878	2020-05-19 06:18:18	2020-05-19	12	[{"id_menu":3,"count":1}]	25787	pick-up	0	12
64879	2020-05-19 06:18:26	2020-05-19	14	[{"id_menu":2,"count":2}]	16550	pick-up	0	14
64880	2020-05-19 06:20:22	2020-05-19	9	[{"id_menu":6,"count":1}]	25658	delivery	5	14
64881	2020-05-19 06:24:15	2020-05-19	8	[{"id_menu":5,"count":1}]	25652	delivery	5	13
64882	2020-05-19 06:28:36	2020-05-19	12	[{"id_menu":1,"count":1}]	23964	delivery	5	17
64883	2020-05-19 06:29:54	2020-05-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	17570	pick-up	0	31
64884	2020-05-19 06:30:05	2020-05-19	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	12532	pick-up	0	21
64885	2020-05-19 06:31:43	2020-05-19	17	[{"id_menu":4,"count":1}]	3735	pick-up	0	17
64886	2020-05-19 06:36:45	2020-05-19	12	[{"id_menu":3,"count":2}]	2176	pick-up	0	12
64887	2020-05-19 06:47:00	2020-05-19	17	[{"id_menu":4,"count":2}]	25621	delivery	5	22
64888	2020-05-19 06:49:19	2020-05-19	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	25633	delivery	5	40
64889	2020-05-19 06:53:12	2020-05-19	9	[{"id_menu":7,"count":1}]	25779	delivery	5	14
64890	2020-05-19 06:57:52	2020-05-19	8	[{"id_menu":5,"count":1}]	25671	delivery	5	13
64891	2020-05-19 06:58:47	2020-05-19	9	[{"id_menu":7,"count":1}]	25725	delivery	5	14
64892	2020-05-19 07:03:00	2020-05-19	9	[{"id_menu":7,"count":1}]	23205	delivery	5	14
64893	2020-05-19 07:03:17	2020-05-19	9	[{"id_menu":7,"count":1}]	22170	delivery	5	14
64894	2020-05-19 07:06:27	2020-05-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7465	pick-up	0	31
64895	2020-05-19 07:11:34	2020-05-19	12	[{"id_menu":1,"count":1}]	17952	pick-up	0	12
64896	2020-05-19 07:17:44	2020-05-19	9	[{"id_menu":7,"count":2}]	22773	pick-up	0	9
64897	2020-05-19 07:23:12	2020-05-19	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	16480	delivery	5	27
64898	2020-05-19 07:24:23	2020-05-19	9	[{"id_menu":7,"count":1}]	14175	delivery	5	14
64899	2020-05-19 07:34:43	2020-05-19	12	[{"id_menu":1,"count":1}]	8417	delivery	5	17
64900	2020-05-19 07:37:11	2020-05-19	8	[{"id_menu":5,"count":1}]	2599	pick-up	0	8
64901	2020-05-19 07:43:20	2020-05-19	14	[{"id_menu":2,"count":1}]	1700	pick-up	0	14
64902	2020-05-19 08:05:29	2020-05-19	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	18152	delivery	5	40
64903	2020-05-19 08:11:02	2020-05-19	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10481	delivery	5	39
64904	2020-05-19 08:12:47	2020-05-19	8	[{"id_menu":5,"count":1}]	5392	delivery	5	13
64905	2020-05-19 08:14:27	2020-05-19	9	[{"id_menu":7,"count":1}]	21377	delivery	5	14
64906	2020-05-19 08:14:57	2020-05-19	17	[{"id_menu":4,"count":1}]	22142	delivery	5	22
64907	2020-05-19 08:20:04	2020-05-19	9	[{"id_menu":6,"count":1}]	16928	delivery	5	14
64908	2020-05-19 08:29:23	2020-05-19	14	[{"id_menu":2,"count":1}]	7571	pick-up	0	14
64909	2020-05-19 08:32:44	2020-05-19	8	[{"id_menu":5,"count":1}]	23280	delivery	5	13
64910	2020-05-19 08:38:35	2020-05-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	20534	delivery	5	28
64911	2020-05-19 08:38:38	2020-05-19	9	[{"id_menu":6,"count":1}]	1597	pick-up	0	9
64912	2020-05-19 08:43:42	2020-05-19	14	[{"id_menu":2,"count":1}]	16839	delivery	5	19
64913	2020-05-19 08:46:45	2020-05-19	12	[{"id_menu":3,"count":1}]	5003	delivery	5	17
64914	2020-05-19 08:49:05	2020-05-19	9	[{"id_menu":6,"count":1}]	25686	delivery	5	14
64915	2020-05-19 08:58:42	2020-05-19	8	[{"id_menu":5,"count":1}]	18928	pick-up	0	8
64916	2020-05-19 09:01:28	2020-05-19	9	[{"id_menu":7,"count":1}]	4555	delivery	5	14
64917	2020-05-19 09:15:10	2020-05-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	25788	delivery	5	22
64918	2020-05-19 09:19:06	2020-05-19	12	[{"id_menu":1,"count":1}]	1781	pick-up	0	12
64919	2020-05-19 09:22:36	2020-05-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	25727	delivery	5	28
64920	2020-05-19 09:23:00	2020-05-19	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	25760	delivery	5	31
64921	2020-05-19 09:28:57	2020-05-19	14	[{"id_menu":2,"count":1}]	25761	delivery	5	19
64922	2020-05-19 09:35:53	2020-05-19	14	[{"id_menu":2,"count":1}]	25644	delivery	5	19
64923	2020-05-19 09:44:04	2020-05-19	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	25614	delivery	5	51
64924	2020-05-19 09:48:22	2020-05-19	14	[{"id_menu":2,"count":1}]	11792	delivery	5	19
64925	2020-05-19 09:51:39	2020-05-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	21236	delivery	5	31
64926	2020-05-19 09:56:31	2020-05-19	9	[{"id_menu":6,"count":1}]	25759	delivery	5	14
64927	2020-05-19 10:01:13	2020-05-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	25649	delivery	5	28
64928	2020-05-19 10:05:37	2020-05-19	8	[{"id_menu":5,"count":1}]	25705	delivery	5	13
64929	2020-05-19 10:10:40	2020-05-19	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20615	delivery	5	34
64930	2020-05-19 10:18:52	2020-05-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2384	pick-up	0	26
64931	2020-05-19 10:20:20	2020-05-19	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	25655	delivery	5	45
64932	2020-05-19 10:21:15	2020-05-19	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	4757	delivery	5	43
64933	2020-05-19 10:28:07	2020-05-19	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9420	pick-up	0	35
64934	2020-05-19 10:29:29	2020-05-19	12	[{"id_menu":1,"count":1}]	19231	delivery	5	17
64935	2020-05-19 10:30:48	2020-05-19	9	[{"id_menu":7,"count":2}]	6600	pick-up	0	9
64936	2020-05-19 10:31:05	2020-05-19	17	[{"id_menu":4,"count":1}]	8915	delivery	5	22
64937	2020-05-19 10:48:07	2020-05-19	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11822	delivery	5	45
64938	2020-05-19 10:54:31	2020-05-19	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25648	delivery	5	37
64939	2020-05-19 10:55:32	2020-05-19	14	[{"id_menu":2,"count":1}]	25746	delivery	5	19
64940	2020-05-19 10:56:12	2020-05-19	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":2}]	23535	delivery	5	26
64941	2020-05-19 10:57:09	2020-05-19	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2602	pick-up	0	26
64942	2020-05-19 11:01:25	2020-05-19	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	25758	delivery	5	34
64943	2020-05-19 11:02:05	2020-05-19	9	[{"id_menu":7,"count":1}]	8992	delivery	5	14
64944	2020-05-19 11:03:33	2020-05-19	17	[{"id_menu":4,"count":1}]	14997	pick-up	0	17
64945	2020-05-19 11:06:39	2020-05-19	12	[{"id_menu":1,"count":1}]	5466	pick-up	0	12
64946	2020-05-19 11:06:47	2020-05-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20915	delivery	5	22
64947	2020-05-19 11:07:12	2020-05-19	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16002	delivery	5	43
64948	2020-05-19 11:07:50	2020-05-19	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25738	delivery	5	34
64949	2020-05-19 11:08:30	2020-05-19	9	[{"id_menu":6,"count":1}]	25763	delivery	5	14
64950	2020-05-19 11:11:44	2020-05-19	14	[{"id_menu":2,"count":2}]	3755	delivery	5	19
64951	2020-05-19 11:14:20	2020-05-19	9	[{"id_menu":6,"count":1}]	511	pick-up	0	9
64952	2020-05-19 11:17:55	2020-05-19	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	20996	delivery	5	40
64953	2020-05-19 11:20:22	2020-05-19	8	[{"id_menu":5,"count":1}]	2729	delivery	5	13
64954	2020-05-19 11:22:10	2020-05-19	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	3318	delivery	5	34
64955	2020-05-19 11:23:20	2020-05-19	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	22478	delivery	5	27
64956	2020-05-19 11:25:44	2020-05-19	9	[{"id_menu":7,"count":1}]	21860	delivery	5	14
64957	2020-05-19 11:31:25	2020-05-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	19490	pick-up	0	31
64958	2020-05-19 11:41:37	2020-05-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":3}]	8884	delivery	5	28
64959	2020-05-19 11:46:10	2020-05-19	9	[{"id_menu":7,"count":1}]	22389	delivery	5	14
64960	2020-05-19 11:48:04	2020-05-19	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25744	delivery	5	31
64961	2020-05-19 11:59:33	2020-05-19	12	[{"id_menu":1,"count":1}]	11458	delivery	5	17
64962	2020-05-19 12:01:58	2020-05-19	8	[{"id_menu":5,"count":1}]	25640	delivery	5	13
64963	2020-05-19 12:04:30	2020-05-19	14	[{"id_menu":2,"count":1}]	25637	delivery	5	19
64964	2020-05-19 12:08:09	2020-05-19	17	[{"id_menu":4,"count":1}]	25627	delivery	5	22
64965	2020-05-19 12:09:14	2020-05-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	25739	delivery	5	23
64966	2020-05-19 12:13:02	2020-05-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	12078	delivery	5	22
64967	2020-05-19 12:15:00	2020-05-19	12	[{"id_menu":1,"count":1}]	6074	delivery	5	17
64968	2020-05-19 12:16:49	2020-05-19	12	[{"id_menu":1,"count":1}]	14565	delivery	5	17
64969	2020-05-19 12:17:35	2020-05-19	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	13263	delivery	5	37
64970	2020-05-19 12:28:31	2020-05-19	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	25670	delivery	5	34
64971	2020-05-19 12:33:35	2020-05-19	8	[{"id_menu":5,"count":1}]	4864	pick-up	0	8
64972	2020-05-19 12:45:45	2020-05-19	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	11754	pick-up	0	26
64973	2020-05-19 12:46:33	2020-05-19	12	[{"id_menu":3,"count":1}]	1424	pick-up	0	12
64974	2020-05-19 12:49:10	2020-05-19	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	22000	delivery	5	55
64975	2020-05-19 12:51:54	2020-05-19	12	[{"id_menu":1,"count":1}]	25770	delivery	5	17
64976	2020-05-19 12:52:40	2020-05-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	9821	delivery	5	31
64977	2020-05-19 12:56:38	2020-05-19	8	[{"id_menu":5,"count":1}]	25755	delivery	5	13
64978	2020-05-19 12:56:51	2020-05-19	8	[{"id_menu":5,"count":1}]	11893	delivery	5	13
64979	2020-05-19 12:57:39	2020-05-19	9	[{"id_menu":6,"count":1}]	20577	delivery	5	14
64980	2020-05-19 12:58:18	2020-05-19	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	25669	delivery	5	27
64981	2020-05-19 13:13:21	2020-05-19	14	[{"id_menu":2,"count":1}]	25699	delivery	5	19
64982	2020-05-19 13:17:45	2020-05-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	15368	delivery	5	28
64983	2020-05-19 13:24:51	2020-05-19	9	[{"id_menu":6,"count":2}]	5999	delivery	5	14
64984	2020-05-19 13:28:44	2020-05-19	14	[{"id_menu":2,"count":1}]	8141	pick-up	0	14
64985	2020-05-19 13:32:42	2020-05-19	14	[{"id_menu":2,"count":1}]	1375	pick-up	0	14
64986	2020-05-19 13:33:29	2020-05-19	14	[{"id_menu":2,"count":1}]	25642	delivery	5	19
64987	2020-05-19 13:35:21	2020-05-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	20371	delivery	5	28
64988	2020-05-19 13:37:14	2020-05-19	14	[{"id_menu":2,"count":1}]	20586	delivery	5	19
64989	2020-05-19 13:43:34	2020-05-19	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	24093	pick-up	0	21
64990	2020-05-19 13:44:48	2020-05-19	14	[{"id_menu":2,"count":1}]	1390	pick-up	0	14
64991	2020-05-19 13:49:39	2020-05-19	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25679	pick-up	0	34
64992	2020-05-19 13:53:59	2020-05-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	25678	delivery	5	28
64993	2020-05-19 13:56:18	2020-05-19	8	[{"id_menu":5,"count":1}]	10326	delivery	5	13
64994	2020-05-19 13:57:20	2020-05-19	9	[{"id_menu":6,"count":1}]	20792	delivery	5	14
64995	2020-05-19 13:58:20	2020-05-19	9	[{"id_menu":6,"count":1}]	25747	delivery	5	14
64996	2020-05-19 13:59:43	2020-05-19	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	21724	delivery	5	26
64997	2020-05-19 14:00:52	2020-05-19	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	25726	delivery	5	26
64998	2020-05-19 14:00:54	2020-05-19	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	25728	delivery	5	31
64999	2020-05-19 14:02:58	2020-05-19	9	[{"id_menu":7,"count":1}]	18526	pick-up	0	9
65000	2020-05-19 14:06:52	2020-05-19	12	[{"id_menu":1,"count":1}]	11550	delivery	5	17
65001	2020-05-19 14:08:51	2020-05-19	12	[{"id_menu":1,"count":1}]	19664	pick-up	0	12
65002	2020-05-19 14:09:01	2020-05-19	9	[{"id_menu":6,"count":1}]	25733	delivery	5	14
65003	2020-05-19 14:09:32	2020-05-19	17	[{"id_menu":4,"count":1}]	6628	delivery	5	22
65004	2020-05-19 14:11:37	2020-05-19	9	[{"id_menu":7,"count":1}]	25691	delivery	5	14
65005	2020-05-19 14:17:34	2020-05-19	12	[{"id_menu":3,"count":1}]	5189	pick-up	0	12
65006	2020-05-19 14:25:08	2020-05-19	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	25757	delivery	5	23
65007	2020-05-19 14:25:39	2020-05-19	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	25782	delivery	5	39
65008	2020-05-19 14:31:35	2020-05-19	9	[{"id_menu":7,"count":1}]	7159	delivery	5	14
65009	2020-05-19 14:34:18	2020-05-19	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	25716	delivery	5	40
65010	2020-05-19 14:37:23	2020-05-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14984	delivery	5	22
65011	2020-05-19 14:37:51	2020-05-19	14	[{"id_menu":2,"count":1}]	21048	delivery	5	19
65012	2020-05-19 14:44:40	2020-05-19	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	25702	delivery	5	25
65013	2020-05-19 14:44:47	2020-05-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	25703	delivery	5	22
65014	2020-05-19 14:45:18	2020-05-19	8	[{"id_menu":5,"count":1}]	25704	delivery	5	13
65015	2020-05-19 14:45:21	2020-05-19	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12788	delivery	5	40
65016	2020-05-19 15:04:46	2020-05-19	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	25729	delivery	5	43
65017	2020-05-19 15:06:28	2020-05-19	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	5622	delivery	5	26
65018	2020-05-19 15:06:57	2020-05-19	9	[{"id_menu":6,"count":1}]	6516	pick-up	0	9
65019	2020-05-19 15:11:40	2020-05-19	12	[{"id_menu":1,"count":1}]	6037	pick-up	0	12
65020	2020-05-19 15:14:07	2020-05-19	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	17434	delivery	5	56
65021	2020-05-19 15:16:45	2020-05-19	12	[{"id_menu":3,"count":1}]	20579	delivery	5	17
65022	2020-05-19 15:24:51	2020-05-19	14	[{"id_menu":2,"count":1}]	25742	delivery	5	19
65023	2020-05-19 15:25:49	2020-05-19	12	[{"id_menu":3,"count":1}]	841	pick-up	0	12
65024	2020-05-19 15:28:07	2020-05-19	12	[{"id_menu":1,"count":1}]	25790	delivery	5	17
65025	2020-05-19 15:29:12	2020-05-19	9	[{"id_menu":6,"count":1}]	5694	pick-up	0	9
65026	2020-05-19 15:41:39	2020-05-19	17	[{"id_menu":4,"count":1}]	1143	pick-up	0	17
65027	2020-05-19 15:43:56	2020-05-19	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	7089	delivery	5	27
65028	2020-05-19 15:45:05	2020-05-19	12	[{"id_menu":1,"count":1}]	739	delivery	5	17
65029	2020-05-19 15:50:46	2020-05-19	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10350	delivery	5	31
65030	2020-05-19 15:55:02	2020-05-19	8	[{"id_menu":5,"count":1}]	5354	pick-up	0	8
65031	2020-05-19 15:55:36	2020-05-19	17	[{"id_menu":4,"count":1}]	9276	delivery	5	22
65032	2020-05-19 15:58:10	2020-05-19	9	[{"id_menu":6,"count":1}]	17911	delivery	5	14
65033	2020-05-19 15:59:25	2020-05-19	9	[{"id_menu":6,"count":2}]	25773	delivery	5	14
65034	2020-05-19 16:05:25	2020-05-19	9	[{"id_menu":6,"count":1}]	22363	delivery	5	14
65035	2020-05-19 16:07:16	2020-05-19	9	[{"id_menu":7,"count":1}]	1485	pick-up	0	9
65036	2020-05-19 16:08:18	2020-05-19	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8557	delivery	5	45
65037	2020-05-19 16:13:05	2020-05-19	17	[{"id_menu":4,"count":1}]	7821	delivery	5	22
65038	2020-05-19 16:20:12	2020-05-19	14	[{"id_menu":2,"count":1}]	25775	pick-up	0	14
65039	2020-05-19 16:29:50	2020-05-19	14	[{"id_menu":2,"count":1}]	245	pick-up	0	14
65040	2020-05-19 16:30:42	2020-05-19	9	[{"id_menu":6,"count":1}]	25690	delivery	5	14
65041	2020-05-19 16:36:23	2020-05-19	8	[{"id_menu":5,"count":1}]	14508	delivery	5	13
65042	2020-05-19 16:41:08	2020-05-19	17	[{"id_menu":4,"count":2}]	25667	delivery	5	22
65043	2020-05-19 16:42:12	2020-05-19	9	[{"id_menu":6,"count":1}]	25711	delivery	5	14
65044	2020-05-19 16:45:55	2020-05-19	12	[{"id_menu":3,"count":1}]	9575	delivery	5	17
65045	2020-05-19 16:49:59	2020-05-19	17	[{"id_menu":4,"count":1}]	25656	delivery	5	22
65046	2020-05-19 16:50:45	2020-05-19	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	6095	delivery	5	27
65047	2020-05-19 16:51:49	2020-05-19	9	[{"id_menu":7,"count":1}]	25641	delivery	5	14
65048	2020-05-19 16:53:40	2020-05-19	14	[{"id_menu":2,"count":1}]	1794	delivery	5	19
65049	2020-05-19 16:57:22	2020-05-19	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23863	delivery	5	34
65050	2020-05-19 17:00:48	2020-05-19	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	9364	delivery	5	31
65051	2020-05-19 17:02:55	2020-05-19	17	[{"id_menu":4,"count":1}]	2104	pick-up	0	17
65052	2020-05-19 17:08:30	2020-05-19	9	[{"id_menu":7,"count":1}]	17802	delivery	5	14
65053	2020-05-19 17:10:53	2020-05-19	9	[{"id_menu":6,"count":1}]	4487	delivery	5	14
65054	2020-05-19 17:15:33	2020-05-19	12	[{"id_menu":1,"count":1}]	25778	delivery	5	17
65055	2020-05-19 17:19:05	2020-05-19	12	[{"id_menu":3,"count":1}]	25754	delivery	5	17
65056	2020-05-19 17:23:40	2020-05-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24690	delivery	5	22
65057	2020-05-19 17:28:53	2020-05-19	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2083	pick-up	0	35
65058	2020-05-19 17:29:04	2020-05-19	17	[{"id_menu":4,"count":1}]	10194	delivery	5	22
65059	2020-05-19 17:30:42	2020-05-19	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	9718	delivery	5	44
65060	2020-05-19 17:38:29	2020-05-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	25089	pick-up	0	23
65061	2020-05-19 17:39:18	2020-05-19	12	[{"id_menu":3,"count":1}]	25750	pick-up	0	12
65062	2020-05-19 17:40:51	2020-05-19	14	[{"id_menu":2,"count":1}]	10098	pick-up	0	14
65063	2020-05-19 17:41:58	2020-05-19	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10488	delivery	5	45
65064	2020-05-19 17:42:00	2020-05-19	17	[{"id_menu":4,"count":1}]	14440	delivery	5	22
65065	2020-05-19 17:47:25	2020-05-19	9	[{"id_menu":6,"count":1}]	25762	delivery	5	14
65066	2020-05-19 17:57:33	2020-05-19	12	[{"id_menu":1,"count":1}]	25663	delivery	5	17
65067	2020-05-19 17:57:52	2020-05-19	9	[{"id_menu":7,"count":1}]	769	delivery	5	14
65068	2020-05-19 18:03:13	2020-05-19	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1258	delivery	5	31
65069	2020-05-19 18:03:34	2020-05-19	9	[{"id_menu":6,"count":1}]	72	delivery	5	14
65070	2020-05-19 18:04:10	2020-05-19	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	15127	delivery	5	34
65071	2020-05-19 18:06:00	2020-05-19	9	[{"id_menu":7,"count":1}]	25789	delivery	5	14
65072	2020-05-19 18:09:41	2020-05-19	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	25675	delivery	5	57
65073	2020-05-19 18:16:46	2020-05-19	12	[{"id_menu":3,"count":1}]	9352	delivery	5	17
65074	2020-05-19 18:17:50	2020-05-19	17	[{"id_menu":4,"count":1}]	25797	delivery	5	22
65075	2020-05-19 18:18:09	2020-05-19	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9594	delivery	5	34
65076	2020-05-19 18:23:54	2020-05-19	8	[{"id_menu":5,"count":1}]	25643	delivery	5	13
65077	2020-05-19 18:26:52	2020-05-19	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	25645	delivery	5	26
65078	2020-05-19 18:29:38	2020-05-19	9	[{"id_menu":7,"count":1}]	7576	delivery	5	14
65079	2020-05-19 18:30:59	2020-05-19	9	[{"id_menu":7,"count":1}]	6900	delivery	5	14
65080	2020-05-19 18:31:42	2020-05-19	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3030	delivery	5	26
65081	2020-05-19 18:34:55	2020-05-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8802	pick-up	0	26
65082	2020-05-19 18:40:02	2020-05-19	9	[{"id_menu":7,"count":1}]	9356	pick-up	0	9
65083	2020-05-19 18:41:51	2020-05-19	9	[{"id_menu":7,"count":1}]	6724	delivery	5	14
65084	2020-05-19 18:48:25	2020-05-19	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	6883	delivery	5	39
65085	2020-05-19 18:53:43	2020-05-19	9	[{"id_menu":6,"count":1}]	25721	delivery	5	14
65086	2020-05-19 18:54:18	2020-05-19	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	19541	pick-up	0	22
65087	2020-05-19 19:04:51	2020-05-19	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	25619	delivery	5	22
65088	2020-05-19 19:19:14	2020-05-19	9	[{"id_menu":7,"count":1}]	12122	delivery	5	14
65089	2020-05-19 19:20:57	2020-05-19	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	22098	delivery	5	26
65090	2020-05-19 19:29:56	2020-05-19	9	[{"id_menu":6,"count":1}]	25780	delivery	5	14
65091	2020-05-19 19:34:19	2020-05-19	8	[{"id_menu":5,"count":1}]	7482	pick-up	0	8
65092	2020-05-19 19:34:43	2020-05-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20136	pick-up	0	17
65093	2020-05-19 19:36:28	2020-05-19	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24987	delivery	5	34
65094	2020-05-19 19:50:32	2020-05-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	25786	delivery	5	28
65095	2020-05-19 19:56:26	2020-05-19	9	[{"id_menu":6,"count":1}]	25753	pick-up	0	9
65096	2020-05-19 19:59:25	2020-05-19	9	[{"id_menu":7,"count":1}]	9894	delivery	5	14
65097	2020-05-19 20:03:01	2020-05-19	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	25723	delivery	5	26
65098	2020-05-19 20:03:10	2020-05-19	9	[{"id_menu":6,"count":1}]	15392	delivery	5	14
65099	2020-05-19 20:03:36	2020-05-19	14	[{"id_menu":2,"count":1}]	25119	delivery	5	19
65100	2020-05-19 20:05:47	2020-05-19	17	[{"id_menu":4,"count":1}]	2392	pick-up	0	17
65101	2020-05-19 20:09:53	2020-05-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1893	pick-up	0	23
65102	2020-05-19 20:10:44	2020-05-19	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16686	delivery	5	43
65103	2020-05-19 20:15:12	2020-05-19	8	[{"id_menu":5,"count":1}]	13112	pick-up	0	8
65104	2020-05-19 20:15:46	2020-05-19	14	[{"id_menu":2,"count":1}]	25683	delivery	5	19
65105	2020-05-19 20:17:22	2020-05-19	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10369	delivery	5	43
65106	2020-05-19 20:20:09	2020-05-19	14	[{"id_menu":2,"count":1}]	838	delivery	5	19
65107	2020-05-19 20:21:43	2020-05-19	9	[{"id_menu":7,"count":1}]	2857	pick-up	0	9
65108	2020-05-19 20:23:42	2020-05-19	17	[{"id_menu":4,"count":1}]	1337	pick-up	0	17
65109	2020-05-19 20:23:45	2020-05-19	8	[{"id_menu":5,"count":1}]	24218	delivery	5	13
65110	2020-05-19 20:28:08	2020-05-19	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	581	delivery	5	31
65111	2020-05-19 20:35:33	2020-05-19	12	[{"id_menu":1,"count":1}]	13862	delivery	5	17
65112	2020-05-19 20:36:05	2020-05-19	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25772	delivery	5	40
65113	2020-05-19 20:38:10	2020-05-19	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	25713	delivery	5	31
65114	2020-05-19 20:43:55	2020-05-19	9	[{"id_menu":6,"count":1}]	16399	delivery	5	14
65115	2020-05-19 20:44:12	2020-05-19	9	[{"id_menu":6,"count":1}]	4445	pick-up	0	9
65116	2020-05-19 20:48:26	2020-05-19	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	6469	pick-up	0	29
65117	2020-05-19 20:49:57	2020-05-19	12	[{"id_menu":1,"count":1}]	2951	delivery	5	17
65118	2020-05-19 20:54:36	2020-05-19	12	[{"id_menu":3,"count":1}]	6901	pick-up	0	12
65119	2020-05-19 20:56:02	2020-05-19	17	[{"id_menu":4,"count":1}]	14288	delivery	5	22
65120	2020-05-19 20:59:51	2020-05-19	14	[{"id_menu":2,"count":1}]	3980	delivery	5	19
65121	2020-05-19 21:00:22	2020-05-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	25651	delivery	5	28
65122	2020-05-19 21:01:15	2020-05-19	17	[{"id_menu":4,"count":1}]	14593	pick-up	0	17
65123	2020-05-19 21:02:55	2020-05-19	17	[{"id_menu":4,"count":1}]	17406	delivery	5	22
65124	2020-05-19 21:04:33	2020-05-19	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	11256	delivery	5	25
65125	2020-05-19 21:05:43	2020-05-19	14	[{"id_menu":2,"count":1}]	18468	delivery	5	19
65126	2020-05-19 21:09:45	2020-05-19	12	[{"id_menu":1,"count":1}]	25735	delivery	5	17
65127	2020-05-19 21:15:59	2020-05-19	17	[{"id_menu":4,"count":1}]	5963	pick-up	0	17
65128	2020-05-19 21:21:43	2020-05-19	14	[{"id_menu":2,"count":1}]	21297	delivery	5	19
65129	2020-05-19 21:23:24	2020-05-19	9	[{"id_menu":6,"count":1}]	1016	pick-up	0	9
65130	2020-05-19 21:30:13	2020-05-19	8	[{"id_menu":5,"count":1}]	25722	delivery	5	13
65131	2020-05-19 21:32:35	2020-05-19	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	23917	pick-up	0	21
65132	2020-05-19 21:38:04	2020-05-19	12	[{"id_menu":1,"count":2}]	22228	pick-up	0	12
65133	2020-05-19 21:41:26	2020-05-19	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1883	pick-up	0	44
65134	2020-05-19 22:00:09	2020-05-19	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	8323	pick-up	0	21
65135	2020-05-19 22:01:32	2020-05-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15902	delivery	5	22
65136	2020-05-19 22:02:53	2020-05-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4546	pick-up	0	23
65137	2020-05-19 22:07:58	2020-05-19	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	25696	delivery	5	36
65138	2020-05-19 22:11:11	2020-05-19	8	[{"id_menu":5,"count":1}]	16484	delivery	5	13
65139	2020-05-19 22:15:06	2020-05-19	12	[{"id_menu":1,"count":1}]	25706	delivery	5	17
65140	2020-05-19 22:17:59	2020-05-19	12	[{"id_menu":1,"count":1}]	2003	pick-up	0	12
65141	2020-05-19 22:19:33	2020-05-19	8	[{"id_menu":5,"count":1}]	16096	delivery	5	13
65142	2020-05-19 22:22:00	2020-05-19	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	3828	delivery	5	37
65143	2020-05-19 22:23:02	2020-05-19	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	19697	delivery	5	31
65144	2020-05-19 22:28:47	2020-05-19	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	4872	delivery	5	31
65145	2020-05-19 22:29:07	2020-05-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	24620	pick-up	0	31
65146	2020-05-19 22:37:32	2020-05-19	9	[{"id_menu":7,"count":1}]	788	pick-up	0	9
65147	2020-05-19 22:38:31	2020-05-19	12	[{"id_menu":1,"count":1}]	23911	delivery	5	17
65148	2020-05-19 22:38:34	2020-05-19	12	[{"id_menu":1,"count":1}]	25692	delivery	5	17
65149	2020-05-19 22:40:18	2020-05-19	12	[{"id_menu":3,"count":1}]	2877	delivery	5	17
65150	2020-05-19 22:45:38	2020-05-19	8	[{"id_menu":5,"count":1}]	21205	delivery	5	13
65151	2020-05-19 22:46:21	2020-05-19	12	[{"id_menu":1,"count":1}]	9832	delivery	5	17
65152	2020-05-19 22:47:15	2020-05-19	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	19798	pick-up	0	21
65153	2020-05-19 22:56:11	2020-05-19	12	[{"id_menu":3,"count":1}]	25800	delivery	5	17
65154	2020-05-19 22:59:35	2020-05-19	14	[{"id_menu":2,"count":1}]	25672	delivery	5	19
65155	2020-05-19 23:00:04	2020-05-19	12	[{"id_menu":1,"count":1}]	1121	pick-up	0	12
65156	2020-05-19 23:03:36	2020-05-19	17	[{"id_menu":4,"count":1}]	24789	delivery	5	22
65157	2020-05-19 23:07:21	2020-05-19	12	[{"id_menu":1,"count":1}]	1855	pick-up	0	12
65158	2020-05-19 23:11:43	2020-05-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	25701	delivery	5	28
65159	2020-05-19 23:13:23	2020-05-19	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	11276	pick-up	0	21
65160	2020-05-19 23:13:41	2020-05-19	17	[{"id_menu":4,"count":1}]	25660	delivery	5	22
65161	2020-05-19 23:17:31	2020-05-19	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	25781	delivery	5	36
65162	2020-05-19 23:20:07	2020-05-19	12	[{"id_menu":1,"count":1}]	223	pick-up	0	12
65163	2020-05-19 23:32:23	2020-05-19	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	15233	delivery	5	37
65164	2020-05-19 23:32:26	2020-05-19	17	[{"id_menu":4,"count":1}]	21856	delivery	5	22
65165	2020-05-19 23:41:32	2020-05-19	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	25751	delivery	5	23
65166	2020-05-19 23:47:47	2020-05-19	9	[{"id_menu":6,"count":1}]	14149	delivery	5	14
65167	2020-05-19 23:48:43	2020-05-19	9	[{"id_menu":7,"count":1}]	23490	delivery	5	14
65168	2020-05-19 23:59:31	2020-05-19	12	[{"id_menu":1,"count":1}]	25741	pick-up	0	12
65169	2020-05-20 00:00:33	2020-05-20	12	[{"id_menu":3,"count":1}]	3845	delivery	5	17
65170	2020-05-20 00:01:00	2020-05-20	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25853	pick-up	0	29
65171	2020-05-20 00:02:46	2020-05-20	17	[{"id_menu":4,"count":1}]	13923	delivery	5	22
65172	2020-05-20 00:10:10	2020-05-20	9	[{"id_menu":6,"count":2}]	24411	delivery	5	14
65173	2020-05-20 00:12:48	2020-05-20	14	[{"id_menu":2,"count":2}]	19403	delivery	5	19
65174	2020-05-20 00:13:47	2020-05-20	9	[{"id_menu":7,"count":1}]	4798	pick-up	0	9
65175	2020-05-20 00:16:07	2020-05-20	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	25875	delivery	5	51
65176	2020-05-20 00:17:56	2020-05-20	8	[{"id_menu":5,"count":1}]	25871	delivery	5	13
65177	2020-05-20 00:21:17	2020-05-20	12	[{"id_menu":1,"count":1}]	25650	delivery	5	17
65178	2020-05-20 00:23:42	2020-05-20	14	[{"id_menu":2,"count":1}]	25894	delivery	5	19
65179	2020-05-20 00:24:24	2020-05-20	12	[{"id_menu":3,"count":1}]	1971	delivery	5	17
65180	2020-05-20 00:24:35	2020-05-20	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	9688	delivery	5	26
65181	2020-05-20 00:25:02	2020-05-20	14	[{"id_menu":2,"count":1}]	12095	pick-up	0	14
65182	2020-05-20 00:35:41	2020-05-20	9	[{"id_menu":6,"count":1}]	1484	pick-up	0	9
65183	2020-05-20 00:43:08	2020-05-20	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	14805	delivery	5	34
65184	2020-05-20 00:44:49	2020-05-20	14	[{"id_menu":2,"count":1}]	23729	delivery	5	19
65185	2020-05-20 00:46:51	2020-05-20	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	25883	delivery	5	26
65186	2020-05-20 00:47:44	2020-05-20	12	[{"id_menu":3,"count":2}]	16621	delivery	5	17
65187	2020-05-20 00:50:48	2020-05-20	17	[{"id_menu":4,"count":1}]	10291	delivery	5	22
65188	2020-05-20 00:53:16	2020-05-20	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	19706	delivery	5	43
65189	2020-05-20 00:53:34	2020-05-20	17	[{"id_menu":4,"count":1}]	25900	delivery	5	22
65190	2020-05-20 00:59:58	2020-05-20	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	2293	delivery	5	23
65191	2020-05-20 01:03:01	2020-05-20	9	[{"id_menu":6,"count":1}]	12159	delivery	5	14
65192	2020-05-20 01:11:07	2020-05-20	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	11289	pick-up	0	20
65193	2020-05-20 01:14:49	2020-05-20	8	[{"id_menu":5,"count":1}]	20579	delivery	5	13
65194	2020-05-20 01:16:22	2020-05-20	8	[{"id_menu":5,"count":1}]	25826	delivery	5	13
65195	2020-05-20 01:24:18	2020-05-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2006	pick-up	0	17
65196	2020-05-20 01:24:58	2020-05-20	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	16710	pick-up	0	43
65197	2020-05-20 01:26:44	2020-05-20	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	2336	delivery	5	31
65198	2020-05-20 01:30:23	2020-05-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5032	delivery	5	23
65199	2020-05-20 01:31:19	2020-05-20	12	[{"id_menu":3,"count":1}]	5097	delivery	5	17
65200	2020-05-20 01:34:44	2020-05-20	9	[{"id_menu":6,"count":1}]	24771	delivery	5	14
65201	2020-05-20 01:35:56	2020-05-20	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	15807	delivery	5	26
65202	2020-05-20 01:37:50	2020-05-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	11151	delivery	5	28
65203	2020-05-20 01:38:52	2020-05-20	9	[{"id_menu":6,"count":1}]	25917	delivery	5	14
65204	2020-05-20 01:40:17	2020-05-20	12	[{"id_menu":3,"count":1}]	15244	delivery	5	17
65205	2020-05-20 01:45:37	2020-05-20	12	[{"id_menu":3,"count":1}]	22116	pick-up	0	12
65206	2020-05-20 01:52:46	2020-05-20	12	[{"id_menu":1,"count":1}]	15109	pick-up	0	12
65207	2020-05-20 01:56:29	2020-05-20	9	[{"id_menu":7,"count":1}]	25904	delivery	5	14
65208	2020-05-20 01:58:52	2020-05-20	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	25949	delivery	5	34
65209	2020-05-20 02:01:53	2020-05-20	14	[{"id_menu":2,"count":1}]	22263	delivery	5	19
65210	2020-05-20 02:02:14	2020-05-20	12	[{"id_menu":3,"count":1}]	16996	pick-up	0	12
65211	2020-05-20 02:02:58	2020-05-20	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4684	delivery	5	52
65212	2020-05-20 02:03:00	2020-05-20	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	454	delivery	5	26
65213	2020-05-20 02:03:03	2020-05-20	9	[{"id_menu":7,"count":1}]	25878	delivery	5	14
65214	2020-05-20 02:04:38	2020-05-20	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11756	delivery	5	31
65215	2020-05-20 02:06:12	2020-05-20	9	[{"id_menu":7,"count":1}]	18235	delivery	5	14
65216	2020-05-20 02:06:42	2020-05-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9977	pick-up	0	17
65217	2020-05-20 02:11:14	2020-05-20	9	[{"id_menu":6,"count":1}]	2706	delivery	5	14
65218	2020-05-20 02:26:43	2020-05-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6037	delivery	5	28
65219	2020-05-20 02:30:17	2020-05-20	12	[{"id_menu":3,"count":1}]	25812	delivery	5	17
65220	2020-05-20 02:34:25	2020-05-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15105	delivery	5	22
65221	2020-05-20 02:36:49	2020-05-20	17	[{"id_menu":4,"count":1}]	12541	pick-up	0	17
65222	2020-05-20 02:37:30	2020-05-20	12	[{"id_menu":1,"count":1}]	1286	pick-up	0	12
65223	2020-05-20 02:38:01	2020-05-20	8	[{"id_menu":5,"count":1}]	25895	delivery	5	13
65224	2020-05-20 02:38:46	2020-05-20	8	[{"id_menu":5,"count":1}]	9505	delivery	5	13
65225	2020-05-20 02:39:31	2020-05-20	12	[{"id_menu":1,"count":1}]	23022	delivery	5	17
65226	2020-05-20 02:41:44	2020-05-20	9	[{"id_menu":7,"count":2}]	2928	pick-up	0	9
65227	2020-05-20 02:46:11	2020-05-20	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	25689	delivery	5	31
65228	2020-05-20 02:49:41	2020-05-20	14	[{"id_menu":2,"count":1}]	25915	pick-up	0	14
65229	2020-05-20 02:52:01	2020-05-20	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	14202	delivery	5	31
65230	2020-05-20 02:52:22	2020-05-20	9	[{"id_menu":6,"count":1}]	813	pick-up	0	9
65231	2020-05-20 02:53:07	2020-05-20	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	11425	delivery	5	36
65232	2020-05-20 02:53:16	2020-05-20	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	24643	delivery	5	31
65233	2020-05-20 02:54:07	2020-05-20	12	[{"id_menu":1,"count":1}]	13065	delivery	5	17
65234	2020-05-20 02:54:26	2020-05-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3289	pick-up	0	17
65235	2020-05-20 02:57:57	2020-05-20	12	[{"id_menu":3,"count":1}]	25930	pick-up	0	12
65236	2020-05-20 02:59:54	2020-05-20	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	25939	delivery	5	31
65237	2020-05-20 03:02:51	2020-05-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6114	delivery	5	23
65238	2020-05-20 03:05:23	2020-05-20	8	[{"id_menu":5,"count":2}]	2943	delivery	5	13
65239	2020-05-20 03:05:53	2020-05-20	9	[{"id_menu":7,"count":1}]	25964	pick-up	0	9
65240	2020-05-20 03:10:02	2020-05-20	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	16279	delivery	5	38
65241	2020-05-20 03:10:43	2020-05-20	12	[{"id_menu":3,"count":1}]	3968	delivery	5	17
65242	2020-05-20 03:18:05	2020-05-20	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	25847	delivery	5	26
65243	2020-05-20 03:18:18	2020-05-20	9	[{"id_menu":6,"count":1}]	8486	delivery	5	14
65244	2020-05-20 03:23:00	2020-05-20	8	[{"id_menu":5,"count":1}]	25867	delivery	5	13
65245	2020-05-20 03:23:19	2020-05-20	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20326	delivery	5	22
65313	2020-05-20 07:36:19	2020-05-20	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	13786	delivery	5	27
65246	2020-05-20 03:26:46	2020-05-20	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10039	pick-up	0	37
65247	2020-05-20 03:31:24	2020-05-20	12	[{"id_menu":3,"count":1}]	25882	pick-up	0	12
65248	2020-05-20 03:33:28	2020-05-20	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	11534	pick-up	0	21
65249	2020-05-20 03:43:13	2020-05-20	9	[{"id_menu":6,"count":1}]	25810	delivery	5	14
65250	2020-05-20 03:45:38	2020-05-20	9	[{"id_menu":6,"count":1}]	22600	delivery	5	14
65251	2020-05-20 03:48:34	2020-05-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1258	delivery	5	28
65252	2020-05-20 03:49:45	2020-05-20	9	[{"id_menu":6,"count":1}]	25884	delivery	5	14
65253	2020-05-20 03:52:33	2020-05-20	8	[{"id_menu":5,"count":1}]	25927	delivery	5	13
65254	2020-05-20 03:55:02	2020-05-20	17	[{"id_menu":4,"count":1}]	2153	delivery	5	22
65255	2020-05-20 03:55:25	2020-05-20	9	[{"id_menu":7,"count":1}]	16930	delivery	5	14
65256	2020-05-20 03:57:50	2020-05-20	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	25825	delivery	5	43
65257	2020-05-20 04:01:45	2020-05-20	14	[{"id_menu":2,"count":1}]	32	pick-up	0	14
65258	2020-05-20 04:03:39	2020-05-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25940	delivery	5	23
65259	2020-05-20 04:04:06	2020-05-20	8	[{"id_menu":5,"count":1}]	10233	delivery	5	13
65260	2020-05-20 04:04:35	2020-05-20	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	22188	pick-up	0	25
65261	2020-05-20 04:18:08	2020-05-20	8	[{"id_menu":5,"count":1}]	1143	delivery	5	13
65262	2020-05-20 04:23:30	2020-05-20	12	[{"id_menu":3,"count":1}]	18381	delivery	5	17
65263	2020-05-20 04:26:49	2020-05-20	12	[{"id_menu":3,"count":1}]	5701	delivery	5	17
65264	2020-05-20 04:27:32	2020-05-20	8	[{"id_menu":5,"count":1}]	23088	delivery	5	13
65265	2020-05-20 04:28:22	2020-05-20	8	[{"id_menu":5,"count":1}]	25953	delivery	5	13
65266	2020-05-20 04:29:12	2020-05-20	8	[{"id_menu":5,"count":1}]	11943	delivery	5	13
65267	2020-05-20 04:31:22	2020-05-20	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3705	delivery	5	42
65268	2020-05-20 04:31:43	2020-05-20	12	[{"id_menu":1,"count":1}]	8873	delivery	5	17
65269	2020-05-20 04:34:20	2020-05-20	12	[{"id_menu":1,"count":1}]	25956	delivery	5	17
65270	2020-05-20 04:43:40	2020-05-20	8	[{"id_menu":5,"count":1}]	17226	delivery	5	13
65271	2020-05-20 04:59:26	2020-05-20	17	[{"id_menu":4,"count":1}]	10802	delivery	5	22
65272	2020-05-20 05:04:05	2020-05-20	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	25830	delivery	5	45
65273	2020-05-20 05:06:59	2020-05-20	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	25287	delivery	5	22
65274	2020-05-20 05:07:33	2020-05-20	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	25860	delivery	5	46
65275	2020-05-20 05:11:47	2020-05-20	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	6163	pick-up	0	26
65276	2020-05-20 05:14:27	2020-05-20	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	22863	delivery	5	36
65277	2020-05-20 05:18:05	2020-05-20	37	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	21624	delivery	5	42
65278	2020-05-20 05:19:20	2020-05-20	9	[{"id_menu":7,"count":1}]	19486	pick-up	0	9
65279	2020-05-20 05:22:30	2020-05-20	9	[{"id_menu":7,"count":1}]	25908	delivery	5	14
65280	2020-05-20 05:25:25	2020-05-20	14	[{"id_menu":2,"count":1}]	2453	pick-up	0	14
65281	2020-05-20 05:29:52	2020-05-20	9	[{"id_menu":6,"count":1}]	5835	delivery	5	14
65282	2020-05-20 05:35:26	2020-05-20	17	[{"id_menu":4,"count":1}]	23534	delivery	5	22
65283	2020-05-20 05:35:58	2020-05-20	9	[{"id_menu":7,"count":1}]	13758	delivery	5	14
65284	2020-05-20 05:39:08	2020-05-20	14	[{"id_menu":2,"count":1}]	25343	pick-up	0	14
65285	2020-05-20 05:39:51	2020-05-20	12	[{"id_menu":1,"count":1}]	12664	delivery	5	17
65286	2020-05-20 05:57:26	2020-05-20	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24807	delivery	5	35
65287	2020-05-20 05:59:27	2020-05-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	25040	delivery	5	28
65288	2020-05-20 06:00:22	2020-05-20	12	[{"id_menu":3,"count":1}]	2228	delivery	5	17
65289	2020-05-20 06:01:26	2020-05-20	14	[{"id_menu":2,"count":1}]	2581	delivery	5	19
65290	2020-05-20 06:05:36	2020-05-20	9	[{"id_menu":6,"count":1}]	3310	delivery	5	14
65291	2020-05-20 06:07:44	2020-05-20	14	[{"id_menu":2,"count":2}]	1912	pick-up	0	14
65292	2020-05-20 06:08:25	2020-05-20	17	[{"id_menu":4,"count":2}]	11448	delivery	5	22
65293	2020-05-20 06:09:13	2020-05-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2776	pick-up	0	23
65294	2020-05-20 06:17:58	2020-05-20	14	[{"id_menu":2,"count":1}]	1513	pick-up	0	14
65295	2020-05-20 06:23:46	2020-05-20	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	10461	delivery	5	22
65296	2020-05-20 06:25:07	2020-05-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	25815	delivery	5	28
65297	2020-05-20 06:26:11	2020-05-20	14	[{"id_menu":2,"count":1}]	13447	pick-up	0	14
65298	2020-05-20 06:26:43	2020-05-20	17	[{"id_menu":4,"count":1}]	25931	delivery	5	22
65299	2020-05-20 06:35:57	2020-05-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	25928	delivery	5	23
65300	2020-05-20 06:39:57	2020-05-20	17	[{"id_menu":4,"count":1}]	11454	pick-up	0	17
65301	2020-05-20 06:45:56	2020-05-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	25963	delivery	5	28
65302	2020-05-20 06:52:50	2020-05-20	12	[{"id_menu":3,"count":1}]	24650	pick-up	0	12
65303	2020-05-20 06:57:14	2020-05-20	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	7628	delivery	5	25
65304	2020-05-20 06:57:47	2020-05-20	12	[{"id_menu":1,"count":1}]	16426	delivery	5	17
65305	2020-05-20 06:59:45	2020-05-20	9	[{"id_menu":6,"count":1}]	25937	delivery	5	14
65306	2020-05-20 07:08:42	2020-05-20	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	25880	delivery	5	31
65307	2020-05-20 07:09:34	2020-05-20	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	21612	pick-up	0	24
65308	2020-05-20 07:18:22	2020-05-20	8	[{"id_menu":5,"count":1}]	3997	delivery	5	13
65309	2020-05-20 07:28:50	2020-05-20	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	10679	pick-up	0	26
65310	2020-05-20 07:30:09	2020-05-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	25831	pick-up	0	23
65311	2020-05-20 07:30:53	2020-05-20	9	[{"id_menu":6,"count":1}]	4242	pick-up	0	9
65312	2020-05-20 07:32:52	2020-05-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17430	pick-up	0	17
65314	2020-05-20 07:38:20	2020-05-20	9	[{"id_menu":6,"count":1}]	13193	pick-up	0	9
65315	2020-05-20 07:42:24	2020-05-20	9	[{"id_menu":6,"count":1}]	491	pick-up	0	9
65316	2020-05-20 07:54:17	2020-05-20	12	[{"id_menu":1,"count":1}]	6296	delivery	5	17
65317	2020-05-20 07:55:02	2020-05-20	8	[{"id_menu":5,"count":1}]	25933	delivery	5	13
65318	2020-05-20 07:56:35	2020-05-20	12	[{"id_menu":1,"count":1}]	12582	delivery	5	17
65319	2020-05-20 08:06:34	2020-05-20	9	[{"id_menu":6,"count":1}]	25808	pick-up	0	9
65320	2020-05-20 08:08:11	2020-05-20	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	9947	pick-up	0	43
65321	2020-05-20 08:08:57	2020-05-20	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2333	pick-up	0	26
65322	2020-05-20 08:15:28	2020-05-20	8	[{"id_menu":5,"count":1}]	1743	pick-up	0	8
65323	2020-05-20 08:21:27	2020-05-20	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4951	delivery	5	34
65324	2020-05-20 08:22:46	2020-05-20	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3948	delivery	5	30
65325	2020-05-20 08:22:55	2020-05-20	9	[{"id_menu":6,"count":1}]	20489	delivery	5	14
65326	2020-05-20 08:25:51	2020-05-20	17	[{"id_menu":4,"count":1}]	5783	delivery	5	22
65327	2020-05-20 08:26:33	2020-05-20	14	[{"id_menu":2,"count":1}]	25905	pick-up	0	14
65328	2020-05-20 08:30:21	2020-05-20	9	[{"id_menu":7,"count":1}]	18507	delivery	5	14
65329	2020-05-20 08:32:18	2020-05-20	8	[{"id_menu":5,"count":1}]	15110	delivery	5	13
65330	2020-05-20 08:33:26	2020-05-20	12	[{"id_menu":3,"count":1}]	25807	delivery	5	17
65331	2020-05-20 08:36:23	2020-05-20	9	[{"id_menu":6,"count":1}]	20700	delivery	5	14
65332	2020-05-20 08:36:59	2020-05-20	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	2755	delivery	5	29
65333	2020-05-20 08:39:31	2020-05-20	9	[{"id_menu":6,"count":1}]	13082	delivery	5	14
65334	2020-05-20 08:41:21	2020-05-20	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	25952	delivery	5	31
65335	2020-05-20 08:41:41	2020-05-20	9	[{"id_menu":6,"count":1}]	1139	delivery	5	14
65336	2020-05-20 08:41:51	2020-05-20	17	[{"id_menu":4,"count":1}]	25816	delivery	5	22
65337	2020-05-20 08:42:20	2020-05-20	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3835	delivery	5	40
65338	2020-05-20 08:47:39	2020-05-20	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6553	delivery	5	44
65339	2020-05-20 08:48:57	2020-05-20	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	25936	delivery	5	40
65340	2020-05-20 08:50:07	2020-05-20	9	[{"id_menu":7,"count":1}]	7951	delivery	5	14
65341	2020-05-20 08:55:30	2020-05-20	17	[{"id_menu":4,"count":1}]	609	pick-up	0	17
65342	2020-05-20 08:57:21	2020-05-20	9	[{"id_menu":7,"count":1}]	23212	delivery	5	14
65343	2020-05-20 08:57:43	2020-05-20	8	[{"id_menu":5,"count":1}]	15816	pick-up	0	8
65344	2020-05-20 08:57:49	2020-05-20	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	25944	delivery	5	40
65345	2020-05-20 08:58:05	2020-05-20	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	24566	delivery	5	34
65346	2020-05-20 09:04:34	2020-05-20	14	[{"id_menu":2,"count":1}]	313	pick-up	0	14
65347	2020-05-20 09:08:23	2020-05-20	17	[{"id_menu":4,"count":1}]	25819	delivery	5	22
65348	2020-05-20 09:09:42	2020-05-20	12	[{"id_menu":3,"count":1}]	25885	delivery	5	17
65349	2020-05-20 09:11:33	2020-05-20	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	25870	delivery	5	57
65350	2020-05-20 09:19:40	2020-05-20	9	[{"id_menu":6,"count":2}]	18922	delivery	5	14
65351	2020-05-20 09:27:50	2020-05-20	9	[{"id_menu":6,"count":1}]	25817	delivery	5	14
65352	2020-05-20 09:27:53	2020-05-20	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	22251	delivery	5	22
65353	2020-05-20 09:30:34	2020-05-20	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25920	delivery	5	22
65354	2020-05-20 09:35:30	2020-05-20	8	[{"id_menu":5,"count":1}]	525	delivery	5	13
65355	2020-05-20 09:39:36	2020-05-20	9	[{"id_menu":7,"count":1}]	25899	delivery	5	14
65356	2020-05-20 09:51:16	2020-05-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	19025	delivery	5	23
65357	2020-05-20 09:52:26	2020-05-20	9	[{"id_menu":6,"count":1}]	25865	delivery	5	14
65358	2020-05-20 09:56:12	2020-05-20	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	4888	delivery	5	43
65359	2020-05-20 09:57:38	2020-05-20	14	[{"id_menu":2,"count":1}]	14052	pick-up	0	14
65360	2020-05-20 10:04:58	2020-05-20	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	6915	delivery	5	25
65361	2020-05-20 10:09:12	2020-05-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16538	delivery	5	22
65362	2020-05-20 10:11:34	2020-05-20	9	[{"id_menu":6,"count":1}]	24842	delivery	5	14
65363	2020-05-20 10:14:44	2020-05-20	9	[{"id_menu":6,"count":1}]	25960	delivery	5	14
65364	2020-05-20 10:14:59	2020-05-20	9	[{"id_menu":6,"count":2}]	729	delivery	5	14
65365	2020-05-20 10:19:00	2020-05-20	12	[{"id_menu":1,"count":1}]	1559	pick-up	0	12
65366	2020-05-20 10:20:30	2020-05-20	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	7056	delivery	5	43
65367	2020-05-20 10:25:47	2020-05-20	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3268	pick-up	0	46
65368	2020-05-20 10:29:23	2020-05-20	8	[{"id_menu":5,"count":1}]	8513	delivery	5	13
65369	2020-05-20 10:33:18	2020-05-20	12	[{"id_menu":3,"count":1}]	12810	delivery	5	17
65370	2020-05-20 10:34:02	2020-05-20	9	[{"id_menu":7,"count":1}]	25897	delivery	5	14
65371	2020-05-20 10:34:03	2020-05-20	12	[{"id_menu":3,"count":1}]	24375	pick-up	0	12
65372	2020-05-20 10:36:52	2020-05-20	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	20415	delivery	5	31
65373	2020-05-20 10:42:51	2020-05-20	8	[{"id_menu":5,"count":1}]	25876	delivery	5	13
65374	2020-05-20 10:43:28	2020-05-20	17	[{"id_menu":4,"count":1}]	7864	delivery	5	22
65375	2020-05-20 10:54:48	2020-05-20	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	25821	pick-up	0	22
65376	2020-05-20 10:55:28	2020-05-20	8	[{"id_menu":5,"count":3}]	9275	delivery	5	13
65377	2020-05-20 11:04:57	2020-05-20	9	[{"id_menu":6,"count":1}]	25862	delivery	5	14
65378	2020-05-20 11:04:59	2020-05-20	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	13444	delivery	5	26
65379	2020-05-20 11:10:38	2020-05-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25219	pick-up	0	18
65380	2020-05-20 11:12:49	2020-05-20	9	[{"id_menu":7,"count":1}]	13111	delivery	5	14
65381	2020-05-20 11:13:55	2020-05-20	14	[{"id_menu":2,"count":1}]	25852	pick-up	0	14
65382	2020-05-20 11:25:27	2020-05-20	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17703	delivery	5	45
65383	2020-05-20 11:26:13	2020-05-20	12	[{"id_menu":3,"count":1}]	25838	delivery	5	17
65384	2020-05-20 11:27:35	2020-05-20	12	[{"id_menu":1,"count":1}]	3659	pick-up	0	12
65385	2020-05-20 11:30:07	2020-05-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	24658	delivery	5	28
65386	2020-05-20 11:32:35	2020-05-20	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	25850	delivery	5	34
65387	2020-05-20 11:32:49	2020-05-20	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	23060	delivery	5	25
65388	2020-05-20 11:34:00	2020-05-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11732	delivery	5	22
65389	2020-05-20 11:34:03	2020-05-20	9	[{"id_menu":7,"count":1}]	18586	delivery	5	14
65390	2020-05-20 11:35:56	2020-05-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	15335	delivery	5	28
65391	2020-05-20 11:40:50	2020-05-20	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	25844	delivery	5	26
65392	2020-05-20 11:50:26	2020-05-20	12	[{"id_menu":1,"count":1}]	3224	delivery	5	17
65393	2020-05-20 11:52:16	2020-05-20	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12991	delivery	5	52
65394	2020-05-20 11:59:48	2020-05-20	9	[{"id_menu":7,"count":1}]	25866	delivery	5	14
65395	2020-05-20 12:10:20	2020-05-20	17	[{"id_menu":4,"count":1}]	5427	pick-up	0	17
65396	2020-05-20 12:14:21	2020-05-20	9	[{"id_menu":6,"count":2}]	5006	delivery	5	14
65397	2020-05-20 12:15:01	2020-05-20	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	7253	delivery	5	36
65398	2020-05-20 12:15:28	2020-05-20	14	[{"id_menu":2,"count":1}]	23835	delivery	5	19
65399	2020-05-20 12:25:10	2020-05-20	17	[{"id_menu":4,"count":1}]	14002	pick-up	0	17
65400	2020-05-20 12:31:10	2020-05-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7691	pick-up	0	23
65401	2020-05-20 12:37:59	2020-05-20	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	20277	delivery	5	31
65402	2020-05-20 12:38:35	2020-05-20	9	[{"id_menu":6,"count":1}]	25874	delivery	5	14
65403	2020-05-20 12:40:11	2020-05-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18166	delivery	5	23
65404	2020-05-20 12:42:54	2020-05-20	17	[{"id_menu":4,"count":2}]	25861	delivery	5	22
65405	2020-05-20 12:43:11	2020-05-20	17	[{"id_menu":4,"count":1}]	19801	delivery	5	22
65406	2020-05-20 12:45:55	2020-05-20	12	[{"id_menu":3,"count":1}]	25863	delivery	5	17
65407	2020-05-20 12:46:51	2020-05-20	8	[{"id_menu":5,"count":1}]	25958	delivery	5	13
65408	2020-05-20 12:48:02	2020-05-20	12	[{"id_menu":1,"count":1}]	1085	delivery	5	17
65409	2020-05-20 12:49:06	2020-05-20	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	19248	delivery	5	39
65410	2020-05-20 12:56:47	2020-05-20	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	8670	delivery	5	34
65411	2020-05-20 12:58:05	2020-05-20	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	286	pick-up	0	46
65412	2020-05-20 12:58:07	2020-05-20	14	[{"id_menu":2,"count":1}]	17691	delivery	5	19
65413	2020-05-20 12:58:52	2020-05-20	12	[{"id_menu":3,"count":1}]	25829	delivery	5	17
65414	2020-05-20 13:00:42	2020-05-20	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	17511	delivery	5	26
65415	2020-05-20 13:04:52	2020-05-20	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	9621	delivery	5	43
65416	2020-05-20 13:10:08	2020-05-20	8	[{"id_menu":5,"count":1}]	25929	delivery	5	13
65417	2020-05-20 13:10:37	2020-05-20	8	[{"id_menu":5,"count":1}]	19497	delivery	5	13
65418	2020-05-20 13:12:18	2020-05-20	14	[{"id_menu":2,"count":2}]	80	pick-up	0	14
65419	2020-05-20 13:16:57	2020-05-20	9	[{"id_menu":7,"count":1}]	19324	delivery	5	14
65420	2020-05-20 13:17:15	2020-05-20	39	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	25886	delivery	5	44
65421	2020-05-20 13:17:49	2020-05-20	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4622	delivery	5	43
65422	2020-05-20 13:29:26	2020-05-20	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	19342	delivery	5	34
65423	2020-05-20 13:31:46	2020-05-20	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21774	delivery	5	39
65424	2020-05-20 13:44:04	2020-05-20	14	[{"id_menu":2,"count":1}]	25914	delivery	5	19
65425	2020-05-20 13:45:23	2020-05-20	9	[{"id_menu":7,"count":4}]	25962	delivery	5	14
65426	2020-05-20 13:45:42	2020-05-20	12	[{"id_menu":1,"count":1}]	13662	pick-up	0	12
65427	2020-05-20 13:49:04	2020-05-20	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	536	pick-up	0	24
65428	2020-05-20 13:52:04	2020-05-20	12	[{"id_menu":1,"count":1}]	1138	pick-up	0	12
65429	2020-05-20 13:57:57	2020-05-20	9	[{"id_menu":7,"count":1}]	3539	delivery	5	14
65430	2020-05-20 14:02:54	2020-05-20	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	25888	delivery	5	57
65431	2020-05-20 14:03:48	2020-05-20	17	[{"id_menu":4,"count":1}]	25827	delivery	5	22
65432	2020-05-20 14:05:29	2020-05-20	9	[{"id_menu":6,"count":2}]	575	pick-up	0	9
65433	2020-05-20 14:06:26	2020-05-20	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25902	delivery	5	22
65434	2020-05-20 14:07:13	2020-05-20	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25943	delivery	5	35
65435	2020-05-20 14:08:27	2020-05-20	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1956	pick-up	0	39
65436	2020-05-20 14:10:51	2020-05-20	14	[{"id_menu":2,"count":1}]	16226	delivery	5	19
65437	2020-05-20 14:14:15	2020-05-20	8	[{"id_menu":5,"count":1}]	15155	delivery	5	13
65438	2020-05-20 14:15:23	2020-05-20	9	[{"id_menu":6,"count":1}]	2590	delivery	5	14
65439	2020-05-20 14:18:09	2020-05-20	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	5354	pick-up	0	31
65440	2020-05-20 14:18:11	2020-05-20	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	25946	delivery	5	26
65441	2020-05-20 14:23:17	2020-05-20	9	[{"id_menu":6,"count":1}]	5055	delivery	5	14
65442	2020-05-20 14:23:37	2020-05-20	9	[{"id_menu":6,"count":1}]	25804	delivery	5	14
65443	2020-05-20 14:25:48	2020-05-20	9	[{"id_menu":7,"count":1}]	24697	pick-up	0	9
65444	2020-05-20 14:25:52	2020-05-20	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	20124	delivery	5	30
65445	2020-05-20 14:27:06	2020-05-20	12	[{"id_menu":1,"count":1}]	9847	pick-up	0	12
65446	2020-05-20 14:30:30	2020-05-20	14	[{"id_menu":2,"count":1}]	10546	delivery	5	19
65447	2020-05-20 14:36:50	2020-05-20	9	[{"id_menu":7,"count":1}]	25925	delivery	5	14
65448	2020-05-20 14:37:10	2020-05-20	12	[{"id_menu":1,"count":1}]	13855	pick-up	0	12
65449	2020-05-20 14:39:46	2020-05-20	14	[{"id_menu":2,"count":1}]	1592	pick-up	0	14
65450	2020-05-20 14:41:37	2020-05-20	8	[{"id_menu":5,"count":1}]	23766	delivery	5	13
65451	2020-05-20 14:42:01	2020-05-20	9	[{"id_menu":6,"count":1}]	25822	delivery	5	14
65452	2020-05-20 14:42:59	2020-05-20	12	[{"id_menu":3,"count":1}]	626	pick-up	0	12
65453	2020-05-20 14:45:43	2020-05-20	9	[{"id_menu":6,"count":1}]	25823	delivery	5	14
65454	2020-05-20 14:51:05	2020-05-20	9	[{"id_menu":6,"count":1}]	11006	delivery	5	14
65455	2020-05-20 14:53:00	2020-05-20	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14929	delivery	5	31
65456	2020-05-20 14:53:07	2020-05-20	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	25911	delivery	5	43
65457	2020-05-20 14:55:35	2020-05-20	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25901	delivery	5	35
65458	2020-05-20 14:59:28	2020-05-20	12	[{"id_menu":1,"count":1}]	20162	delivery	5	17
65459	2020-05-20 15:00:41	2020-05-20	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	12254	pick-up	0	26
65460	2020-05-20 15:11:21	2020-05-20	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	12189	delivery	5	25
65461	2020-05-20 15:13:22	2020-05-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23929	delivery	5	22
65462	2020-05-20 15:14:34	2020-05-20	17	[{"id_menu":4,"count":1}]	16548	delivery	5	22
65463	2020-05-20 15:21:06	2020-05-20	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	25892	delivery	5	29
65464	2020-05-20 15:23:19	2020-05-20	17	[{"id_menu":4,"count":1}]	25836	delivery	5	22
65465	2020-05-20 15:23:30	2020-05-20	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	25906	delivery	5	43
65466	2020-05-20 15:30:45	2020-05-20	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	16195	delivery	5	25
65467	2020-05-20 15:34:36	2020-05-20	12	[{"id_menu":1,"count":1}]	654	pick-up	0	12
65468	2020-05-20 15:35:14	2020-05-20	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	20673	delivery	5	26
65469	2020-05-20 15:35:54	2020-05-20	14	[{"id_menu":2,"count":1}]	19912	delivery	5	19
65470	2020-05-20 15:36:38	2020-05-20	9	[{"id_menu":7,"count":1}]	25813	delivery	5	14
65471	2020-05-20 15:40:02	2020-05-20	17	[{"id_menu":4,"count":1}]	25913	delivery	5	22
65472	2020-05-20 15:53:34	2020-05-20	9	[{"id_menu":6,"count":1}]	25935	delivery	5	14
65473	2020-05-20 15:54:04	2020-05-20	14	[{"id_menu":2,"count":1}]	25910	delivery	5	19
65474	2020-05-20 15:54:50	2020-05-20	14	[{"id_menu":2,"count":1}]	12888	pick-up	0	14
65475	2020-05-20 15:58:41	2020-05-20	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	10273	pick-up	0	38
65476	2020-05-20 16:03:00	2020-05-20	9	[{"id_menu":7,"count":1}]	10641	delivery	5	14
65477	2020-05-20 16:05:46	2020-05-20	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3825	pick-up	0	26
65478	2020-05-20 16:12:25	2020-05-20	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	21771	delivery	5	26
65479	2020-05-20 16:17:45	2020-05-20	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	16831	delivery	5	23
65480	2020-05-20 16:20:14	2020-05-20	9	[{"id_menu":7,"count":1}]	25843	delivery	5	14
65481	2020-05-20 16:22:09	2020-05-20	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	25805	delivery	5	42
65482	2020-05-20 16:28:19	2020-05-20	12	[{"id_menu":3,"count":1}]	24913	pick-up	0	12
65483	2020-05-20 16:30:30	2020-05-20	14	[{"id_menu":2,"count":1}]	25924	delivery	5	19
65484	2020-05-20 16:33:15	2020-05-20	9	[{"id_menu":6,"count":1}]	25907	pick-up	0	9
65485	2020-05-20 16:38:35	2020-05-20	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	25842	delivery	5	31
65486	2020-05-20 16:41:28	2020-05-20	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	18807	delivery	5	31
65487	2020-05-20 16:42:01	2020-05-20	17	[{"id_menu":4,"count":1}]	25854	delivery	5	22
65488	2020-05-20 16:44:14	2020-05-20	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25938	delivery	5	35
65489	2020-05-20 16:46:16	2020-05-20	9	[{"id_menu":6,"count":1}]	12268	pick-up	0	9
65490	2020-05-20 16:50:50	2020-05-20	12	[{"id_menu":3,"count":1}]	23859	delivery	5	17
65491	2020-05-20 16:52:03	2020-05-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	12945	delivery	5	28
65492	2020-05-20 16:52:22	2020-05-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	22695	delivery	5	28
65493	2020-05-20 16:56:17	2020-05-20	9	[{"id_menu":6,"count":1}]	25896	delivery	5	14
65494	2020-05-20 16:58:43	2020-05-20	8	[{"id_menu":5,"count":1}]	25955	delivery	5	13
65495	2020-05-20 16:59:02	2020-05-20	9	[{"id_menu":6,"count":1}]	7806	pick-up	0	9
65496	2020-05-20 17:03:12	2020-05-20	14	[{"id_menu":2,"count":1}]	13948	delivery	5	19
65497	2020-05-20 17:13:55	2020-05-20	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	25855	delivery	5	39
65498	2020-05-20 17:23:39	2020-05-20	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	21386	pick-up	0	26
65499	2020-05-20 17:26:04	2020-05-20	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25814	delivery	5	31
65500	2020-05-20 17:28:28	2020-05-20	17	[{"id_menu":4,"count":1}]	25834	delivery	5	22
65501	2020-05-20 17:31:05	2020-05-20	14	[{"id_menu":2,"count":1}]	25923	delivery	5	19
65502	2020-05-20 17:37:29	2020-05-20	9	[{"id_menu":7,"count":1}]	25833	pick-up	0	9
65503	2020-05-20 17:48:43	2020-05-20	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":3}]	14496	delivery	5	26
65504	2020-05-20 17:53:40	2020-05-20	9	[{"id_menu":7,"count":1}]	1273	pick-up	0	9
65505	2020-05-20 17:53:59	2020-05-20	17	[{"id_menu":4,"count":1}]	17403	delivery	5	22
65506	2020-05-20 17:59:14	2020-05-20	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	25828	delivery	5	40
65507	2020-05-20 18:04:39	2020-05-20	8	[{"id_menu":5,"count":1}]	17522	delivery	5	13
65508	2020-05-20 18:09:03	2020-05-20	9	[{"id_menu":6,"count":1}]	16239	delivery	5	14
65509	2020-05-20 18:10:07	2020-05-20	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	25932	delivery	5	36
65510	2020-05-20 18:18:15	2020-05-20	9	[{"id_menu":6,"count":1}]	25818	delivery	5	14
65511	2020-05-20 18:21:35	2020-05-20	17	[{"id_menu":4,"count":1}]	4909	delivery	5	22
65512	2020-05-20 18:22:26	2020-05-20	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	20288	delivery	5	26
65513	2020-05-20 18:33:15	2020-05-20	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	25942	delivery	5	26
65514	2020-05-20 18:35:29	2020-05-20	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	12415	pick-up	0	38
65515	2020-05-20 18:38:53	2020-05-20	12	[{"id_menu":1,"count":1}]	22107	delivery	5	17
65516	2020-05-20 18:43:18	2020-05-20	12	[{"id_menu":1,"count":1}]	14157	delivery	5	17
65517	2020-05-20 18:44:06	2020-05-20	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	25864	delivery	5	36
65518	2020-05-20 18:55:43	2020-05-20	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	15528	pick-up	0	35
65519	2020-05-20 18:58:40	2020-05-20	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	25877	delivery	5	37
65520	2020-05-20 19:00:14	2020-05-20	14	[{"id_menu":2,"count":1}]	25857	delivery	5	19
65521	2020-05-20 19:03:14	2020-05-20	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	20245	delivery	5	26
65522	2020-05-20 19:04:11	2020-05-20	9	[{"id_menu":6,"count":1}]	7912	delivery	5	14
65523	2020-05-20 19:13:14	2020-05-20	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	25835	delivery	5	23
65524	2020-05-20 19:14:32	2020-05-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	25926	delivery	5	22
65525	2020-05-20 19:15:23	2020-05-20	9	[{"id_menu":7,"count":1}]	6062	pick-up	0	9
65526	2020-05-20 19:18:20	2020-05-20	14	[{"id_menu":2,"count":1}]	11531	pick-up	0	14
65527	2020-05-20 19:22:59	2020-05-20	8	[{"id_menu":5,"count":1}]	10517	delivery	5	13
65528	2020-05-20 19:31:22	2020-05-20	9	[{"id_menu":6,"count":1}]	25851	delivery	5	14
65529	2020-05-20 19:33:12	2020-05-20	9	[{"id_menu":7,"count":1}]	24831	delivery	5	14
65530	2020-05-20 19:43:10	2020-05-20	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11298	delivery	5	48
65531	2020-05-20 19:45:42	2020-05-20	12	[{"id_menu":3,"count":1}]	25840	delivery	5	17
65532	2020-05-20 19:51:40	2020-05-20	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8583	delivery	5	40
65533	2020-05-20 19:58:03	2020-05-20	12	[{"id_menu":1,"count":1}]	20136	delivery	5	17
65534	2020-05-20 19:58:15	2020-05-20	9	[{"id_menu":7,"count":1}]	9913	pick-up	0	9
65535	2020-05-20 20:08:38	2020-05-20	9	[{"id_menu":6,"count":1}]	25832	delivery	5	14
65536	2020-05-20 20:10:43	2020-05-20	8	[{"id_menu":5,"count":1}]	14175	delivery	5	13
65537	2020-05-20 20:11:09	2020-05-20	14	[{"id_menu":2,"count":1}]	25841	delivery	5	19
65538	2020-05-20 20:11:30	2020-05-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	25869	delivery	5	23
65539	2020-05-20 20:12:27	2020-05-20	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	3593	pick-up	0	21
65540	2020-05-20 20:13:57	2020-05-20	9	[{"id_menu":6,"count":1}]	19598	pick-up	0	9
65541	2020-05-20 20:14:25	2020-05-20	9	[{"id_menu":6,"count":1}]	25103	delivery	5	14
65542	2020-05-20 20:14:54	2020-05-20	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	184	pick-up	0	48
65543	2020-05-20 20:15:11	2020-05-20	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	21483	pick-up	0	25
65544	2020-05-20 20:16:03	2020-05-20	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3927	pick-up	0	43
65545	2020-05-20 20:18:24	2020-05-20	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	25266	delivery	5	23
65546	2020-05-20 20:22:23	2020-05-20	14	[{"id_menu":2,"count":1}]	18468	delivery	5	19
65547	2020-05-20 20:27:38	2020-05-20	14	[{"id_menu":2,"count":1}]	16774	delivery	5	19
65548	2020-05-20 20:34:57	2020-05-20	9	[{"id_menu":6,"count":1}]	12654	pick-up	0	9
65549	2020-05-20 20:35:30	2020-05-20	12	[{"id_menu":1,"count":1}]	9115	delivery	5	17
65550	2020-05-20 20:41:02	2020-05-20	9	[{"id_menu":7,"count":1}]	25891	delivery	5	14
65551	2020-05-20 20:45:32	2020-05-20	9	[{"id_menu":7,"count":1}]	25965	delivery	5	14
65552	2020-05-20 20:56:02	2020-05-20	14	[{"id_menu":2,"count":1}]	25909	delivery	5	19
65553	2020-05-20 20:56:55	2020-05-20	8	[{"id_menu":5,"count":1}]	6390	delivery	5	13
65554	2020-05-20 21:01:22	2020-05-20	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25959	delivery	5	31
65555	2020-05-20 21:01:46	2020-05-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8176	delivery	5	23
65556	2020-05-20 21:03:04	2020-05-20	8	[{"id_menu":5,"count":1}]	25127	delivery	5	13
65557	2020-05-20 21:03:18	2020-05-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	25951	delivery	5	28
65558	2020-05-20 21:07:20	2020-05-20	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4247	delivery	5	49
65559	2020-05-20 21:08:00	2020-05-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1025	pick-up	0	17
65560	2020-05-20 21:08:21	2020-05-20	17	[{"id_menu":4,"count":1}]	2623	delivery	5	22
65561	2020-05-20 21:11:21	2020-05-20	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	9964	delivery	5	45
65562	2020-05-20 21:13:38	2020-05-20	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11772	delivery	5	31
65563	2020-05-20 21:14:26	2020-05-20	9	[{"id_menu":7,"count":1}]	25837	delivery	5	14
65564	2020-05-20 21:16:11	2020-05-20	12	[{"id_menu":1,"count":1}]	5972	pick-up	0	12
65565	2020-05-20 21:19:18	2020-05-20	17	[{"id_menu":4,"count":1}]	6134	delivery	5	22
65566	2020-05-20 21:20:26	2020-05-20	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	9005	delivery	5	34
65567	2020-05-20 21:20:33	2020-05-20	9	[{"id_menu":7,"count":1}]	17636	delivery	5	14
65568	2020-05-20 21:22:08	2020-05-20	17	[{"id_menu":4,"count":1}]	25954	pick-up	0	17
65569	2020-05-20 21:29:01	2020-05-20	9	[{"id_menu":6,"count":1}]	23909	delivery	5	14
65570	2020-05-20 21:30:12	2020-05-20	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15659	delivery	5	22
65571	2020-05-20 21:30:31	2020-05-20	17	[{"id_menu":4,"count":1}]	12111	delivery	5	22
65572	2020-05-20 21:33:32	2020-05-20	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	25881	delivery	5	43
65573	2020-05-20 21:34:52	2020-05-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23990	delivery	5	22
65574	2020-05-20 21:35:29	2020-05-20	12	[{"id_menu":1,"count":1}]	1799	delivery	5	17
65575	2020-05-20 21:35:30	2020-05-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14332	delivery	5	23
65576	2020-05-20 21:38:43	2020-05-20	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	21888	delivery	5	34
65577	2020-05-20 21:39:16	2020-05-20	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	25941	delivery	5	35
65578	2020-05-20 21:40:18	2020-05-20	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1309	pick-up	0	22
65579	2020-05-20 21:40:43	2020-05-20	12	[{"id_menu":1,"count":1}]	25879	delivery	5	17
65580	2020-05-20 21:45:21	2020-05-20	9	[{"id_menu":7,"count":1}]	24615	pick-up	0	9
65581	2020-05-20 21:46:31	2020-05-20	9	[{"id_menu":6,"count":1}]	13345	delivery	5	14
65582	2020-05-20 21:46:33	2020-05-20	8	[{"id_menu":5,"count":1}]	2729	delivery	5	13
65583	2020-05-20 21:48:09	2020-05-20	9	[{"id_menu":6,"count":1}]	15907	delivery	5	14
65584	2020-05-20 21:51:10	2020-05-20	12	[{"id_menu":1,"count":1}]	11465	pick-up	0	12
65585	2020-05-20 21:51:24	2020-05-20	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25820	delivery	5	34
65586	2020-05-20 21:55:11	2020-05-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25806	delivery	5	23
65587	2020-05-20 21:58:21	2020-05-20	12	[{"id_menu":3,"count":1}]	2526	pick-up	0	12
65588	2020-05-20 21:59:19	2020-05-20	9	[{"id_menu":6,"count":1}]	5447	delivery	5	14
65589	2020-05-20 22:00:03	2020-05-20	8	[{"id_menu":5,"count":1}]	25948	pick-up	0	8
65590	2020-05-20 22:05:16	2020-05-20	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	25846	delivery	5	36
65591	2020-05-20 22:12:24	2020-05-20	12	[{"id_menu":3,"count":1}]	24716	delivery	5	17
65592	2020-05-20 22:12:31	2020-05-20	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	3344	delivery	5	30
65593	2020-05-20 22:12:35	2020-05-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8663	delivery	5	28
65594	2020-05-20 22:15:50	2020-05-20	8	[{"id_menu":5,"count":1}]	25903	delivery	5	13
65595	2020-05-20 22:18:17	2020-05-20	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	25918	delivery	5	28
65596	2020-05-20 22:19:06	2020-05-20	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25934	delivery	5	35
65597	2020-05-20 22:24:47	2020-05-20	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	25872	delivery	5	31
65598	2020-05-20 22:28:28	2020-05-20	17	[{"id_menu":4,"count":1}]	2431	delivery	5	22
65599	2020-05-20 22:29:27	2020-05-20	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	25661	pick-up	0	29
65600	2020-05-20 22:31:04	2020-05-20	9	[{"id_menu":6,"count":1}]	25893	pick-up	0	9
65601	2020-05-20 22:32:59	2020-05-20	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	13698	delivery	5	22
65602	2020-05-20 22:37:17	2020-05-20	9	[{"id_menu":6,"count":1}]	666	pick-up	0	9
65603	2020-05-20 22:42:23	2020-05-20	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17103	delivery	5	48
65604	2020-05-20 22:43:50	2020-05-20	17	[{"id_menu":4,"count":1}]	126	pick-up	0	17
65605	2020-05-20 22:44:04	2020-05-20	8	[{"id_menu":5,"count":1}]	20853	delivery	5	13
65606	2020-05-20 22:50:57	2020-05-20	17	[{"id_menu":4,"count":1}]	3113	pick-up	0	17
65607	2020-05-20 22:52:15	2020-05-20	8	[{"id_menu":5,"count":1}]	20617	delivery	5	13
65608	2020-05-20 22:53:13	2020-05-20	9	[{"id_menu":6,"count":1}]	25898	delivery	5	14
65609	2020-05-20 22:59:01	2020-05-20	12	[{"id_menu":1,"count":1}]	3467	delivery	5	17
65610	2020-05-20 22:59:28	2020-05-20	14	[{"id_menu":2,"count":3}]	3222	pick-up	0	14
65611	2020-05-20 23:00:04	2020-05-20	12	[{"id_menu":1,"count":1}]	5786	delivery	5	17
65612	2020-05-20 23:09:42	2020-05-20	14	[{"id_menu":2,"count":1}]	25015	delivery	5	19
65613	2020-05-20 23:11:30	2020-05-20	12	[{"id_menu":1,"count":1}]	8431	pick-up	0	12
65614	2020-05-20 23:12:34	2020-05-20	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1897	delivery	5	39
65615	2020-05-20 23:16:42	2020-05-20	12	[{"id_menu":1,"count":1}]	20391	pick-up	0	12
65616	2020-05-20 23:21:53	2020-05-20	9	[{"id_menu":6,"count":1}]	25916	delivery	5	14
65617	2020-05-20 23:30:06	2020-05-20	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	17582	pick-up	0	21
65618	2020-05-20 23:33:34	2020-05-20	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	4792	delivery	5	30
65619	2020-05-20 23:38:39	2020-05-20	17	[{"id_menu":4,"count":1}]	25947	pick-up	0	17
65620	2020-05-20 23:39:41	2020-05-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	371	pick-up	0	18
65621	2020-05-20 23:39:51	2020-05-20	12	[{"id_menu":1,"count":1}]	25809	delivery	5	17
65622	2020-05-20 23:43:54	2020-05-20	12	[{"id_menu":3,"count":1}]	25824	delivery	5	17
65623	2020-05-20 23:46:18	2020-05-20	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16110	delivery	5	34
65624	2020-05-20 23:50:45	2020-05-20	12	[{"id_menu":1,"count":1}]	25919	delivery	5	17
65625	2020-05-20 23:54:10	2020-05-20	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	6773	delivery	5	27
65626	2020-05-20 23:56:12	2020-05-20	9	[{"id_menu":6,"count":1}]	2975	delivery	5	14
65627	2020-05-21 00:00:36	2020-05-21	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	25992	delivery	5	45
65628	2020-05-21 00:04:37	2020-05-21	9	[{"id_menu":6,"count":1}]	21567	delivery	5	14
65629	2020-05-21 00:05:18	2020-05-21	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	10421	delivery	5	34
65630	2020-05-21 00:06:21	2020-05-21	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	13241	delivery	5	22
65631	2020-05-21 00:11:59	2020-05-21	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	26109	delivery	5	29
65632	2020-05-21 00:19:01	2020-05-21	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20229	delivery	5	35
65633	2020-05-21 00:20:41	2020-05-21	9	[{"id_menu":6,"count":1}]	21978	delivery	5	14
65634	2020-05-21 00:24:14	2020-05-21	9	[{"id_menu":6,"count":1}]	26104	pick-up	0	9
65635	2020-05-21 00:26:22	2020-05-21	12	[{"id_menu":3,"count":1}]	17685	pick-up	0	12
65636	2020-05-21 00:28:27	2020-05-21	14	[{"id_menu":2,"count":1}]	20215	pick-up	0	14
65637	2020-05-21 00:31:42	2020-05-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	15408	delivery	5	28
65638	2020-05-21 00:32:01	2020-05-21	8	[{"id_menu":5,"count":1}]	26128	delivery	5	13
65639	2020-05-21 00:37:05	2020-05-21	9	[{"id_menu":6,"count":1}]	6046	pick-up	0	9
65640	2020-05-21 00:38:38	2020-05-21	12	[{"id_menu":3,"count":1}]	25571	pick-up	0	12
65641	2020-05-21 00:39:06	2020-05-21	14	[{"id_menu":2,"count":1}]	14808	delivery	5	19
65642	2020-05-21 00:39:27	2020-05-21	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	16496	pick-up	0	21
65643	2020-05-21 00:41:38	2020-05-21	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	16361	delivery	5	31
65644	2020-05-21 00:46:39	2020-05-21	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	8181	delivery	5	36
65645	2020-05-21 00:47:39	2020-05-21	14	[{"id_menu":2,"count":1}]	21820	delivery	5	19
65646	2020-05-21 00:48:12	2020-05-21	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	8230	delivery	5	26
65647	2020-05-21 00:48:23	2020-05-21	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	23665	delivery	5	26
65648	2020-05-21 00:52:40	2020-05-21	14	[{"id_menu":2,"count":1}]	26116	delivery	5	19
65649	2020-05-21 00:54:20	2020-05-21	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	12093	delivery	5	36
65650	2020-05-21 00:54:47	2020-05-21	12	[{"id_menu":3,"count":1}]	14089	delivery	5	17
65651	2020-05-21 00:58:42	2020-05-21	9	[{"id_menu":6,"count":1}]	14670	delivery	5	14
65652	2020-05-21 00:59:57	2020-05-21	9	[{"id_menu":7,"count":1}]	6702	delivery	5	14
65653	2020-05-21 01:01:40	2020-05-21	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	5958	pick-up	0	22
65654	2020-05-21 01:02:15	2020-05-21	8	[{"id_menu":5,"count":2}]	4680	delivery	5	13
65655	2020-05-21 01:03:33	2020-05-21	14	[{"id_menu":2,"count":1}]	26127	pick-up	0	14
65656	2020-05-21 01:04:17	2020-05-21	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	23907	delivery	5	37
65657	2020-05-21 01:04:17	2020-05-21	9	[{"id_menu":7,"count":1}]	15360	delivery	5	14
65658	2020-05-21 01:04:23	2020-05-21	9	[{"id_menu":6,"count":1}]	26026	delivery	5	14
65659	2020-05-21 01:05:17	2020-05-21	17	[{"id_menu":4,"count":1}]	9202	pick-up	0	17
65660	2020-05-21 01:06:48	2020-05-21	8	[{"id_menu":5,"count":1}]	24807	delivery	5	13
65661	2020-05-21 01:09:45	2020-05-21	12	[{"id_menu":3,"count":1}]	6074	pick-up	0	12
65662	2020-05-21 01:10:20	2020-05-21	12	[{"id_menu":1,"count":1}]	26029	delivery	5	17
65663	2020-05-21 01:11:06	2020-05-21	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	2416	delivery	5	26
65664	2020-05-21 01:12:06	2020-05-21	9	[{"id_menu":6,"count":1}]	15737	delivery	5	14
65665	2020-05-21 01:13:07	2020-05-21	9	[{"id_menu":6,"count":1}]	26075	delivery	5	14
65666	2020-05-21 01:18:16	2020-05-21	12	[{"id_menu":1,"count":1}]	1539	delivery	5	17
65667	2020-05-21 01:21:52	2020-05-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	20055	delivery	5	28
65668	2020-05-21 01:22:00	2020-05-21	12	[{"id_menu":3,"count":1}]	19476	delivery	5	17
65669	2020-05-21 01:24:38	2020-05-21	9	[{"id_menu":6,"count":1}]	11926	pick-up	0	9
65670	2020-05-21 01:27:27	2020-05-21	9	[{"id_menu":7,"count":1}]	22361	delivery	5	14
65671	2020-05-21 01:30:02	2020-05-21	9	[{"id_menu":6,"count":1}]	25978	delivery	5	14
65672	2020-05-21 01:30:16	2020-05-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3077	pick-up	0	23
65673	2020-05-21 01:31:21	2020-05-21	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	26117	delivery	5	44
65674	2020-05-21 01:33:56	2020-05-21	9	[{"id_menu":7,"count":1}]	7253	delivery	5	14
65675	2020-05-21 01:39:08	2020-05-21	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24511	delivery	5	36
65676	2020-05-21 01:39:40	2020-05-21	8	[{"id_menu":5,"count":1}]	18233	delivery	5	13
65677	2020-05-21 01:40:09	2020-05-21	14	[{"id_menu":2,"count":1}]	26070	delivery	5	19
65678	2020-05-21 01:40:58	2020-05-21	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	16039	pick-up	0	29
65679	2020-05-21 01:51:42	2020-05-21	9	[{"id_menu":6,"count":1}]	5811	pick-up	0	9
65680	2020-05-21 02:06:47	2020-05-21	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	15105	delivery	5	29
65681	2020-05-21 02:08:08	2020-05-21	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	16010	delivery	5	29
65682	2020-05-21 02:11:20	2020-05-21	14	[{"id_menu":2,"count":1}]	26079	pick-up	0	14
65683	2020-05-21 02:14:16	2020-05-21	9	[{"id_menu":6,"count":1}]	9973	delivery	5	14
65684	2020-05-21 02:18:32	2020-05-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	23815	delivery	5	31
65685	2020-05-21 02:18:51	2020-05-21	12	[{"id_menu":3,"count":1}]	9593	delivery	5	17
65686	2020-05-21 02:21:11	2020-05-21	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10061	delivery	5	45
65687	2020-05-21 02:21:58	2020-05-21	8	[{"id_menu":5,"count":2}]	13923	pick-up	0	8
65688	2020-05-21 02:23:48	2020-05-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6862	delivery	5	22
65689	2020-05-21 02:25:14	2020-05-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2401	pick-up	0	23
65690	2020-05-21 02:27:31	2020-05-21	14	[{"id_menu":2,"count":1}]	7410	pick-up	0	14
65691	2020-05-21 02:30:45	2020-05-21	12	[{"id_menu":3,"count":1}]	2408	pick-up	0	12
65692	2020-05-21 02:33:38	2020-05-21	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	21084	delivery	5	26
65693	2020-05-21 02:34:10	2020-05-21	12	[{"id_menu":1,"count":1}]	8355	pick-up	0	12
65694	2020-05-21 02:40:15	2020-05-21	9	[{"id_menu":6,"count":1}]	24583	delivery	5	14
65695	2020-05-21 02:42:03	2020-05-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6412	pick-up	0	26
65696	2020-05-21 02:42:42	2020-05-21	17	[{"id_menu":4,"count":1}]	1223	pick-up	0	17
65697	2020-05-21 02:47:12	2020-05-21	12	[{"id_menu":3,"count":1}]	371	pick-up	0	12
65698	2020-05-21 02:48:32	2020-05-21	12	[{"id_menu":3,"count":1}]	16298	delivery	5	17
65699	2020-05-21 02:59:57	2020-05-21	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	26041	delivery	5	45
65700	2020-05-21 03:02:50	2020-05-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	26015	delivery	5	22
65701	2020-05-21 03:05:47	2020-05-21	9	[{"id_menu":6,"count":2}]	26044	delivery	5	14
65702	2020-05-21 03:08:20	2020-05-21	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1215	delivery	5	26
65703	2020-05-21 03:11:10	2020-05-21	12	[{"id_menu":3,"count":1}]	2139	pick-up	0	12
65704	2020-05-21 03:15:55	2020-05-21	12	[{"id_menu":3,"count":1}]	12837	delivery	5	17
65705	2020-05-21 03:17:13	2020-05-21	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	26004	delivery	5	26
65706	2020-05-21 03:24:20	2020-05-21	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	26110	delivery	5	36
65707	2020-05-21 03:24:30	2020-05-21	14	[{"id_menu":2,"count":1}]	26042	delivery	5	19
65708	2020-05-21 03:24:37	2020-05-21	12	[{"id_menu":1,"count":1}]	15780	delivery	5	17
65709	2020-05-21 03:27:17	2020-05-21	12	[{"id_menu":3,"count":1}]	26019	delivery	5	17
65710	2020-05-21 03:34:42	2020-05-21	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	26087	delivery	5	31
65711	2020-05-21 03:36:47	2020-05-21	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	25981	delivery	5	27
65712	2020-05-21 03:37:50	2020-05-21	17	[{"id_menu":4,"count":1}]	17780	delivery	5	22
65713	2020-05-21 03:42:50	2020-05-21	12	[{"id_menu":1,"count":1}]	26065	pick-up	0	12
65714	2020-05-21 03:44:14	2020-05-21	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	25350	delivery	5	38
65715	2020-05-21 03:48:16	2020-05-21	8	[{"id_menu":5,"count":1}]	24419	delivery	5	13
65716	2020-05-21 03:50:14	2020-05-21	14	[{"id_menu":2,"count":1}]	26055	pick-up	0	14
65717	2020-05-21 03:51:25	2020-05-21	9	[{"id_menu":6,"count":1}]	21692	delivery	5	14
65718	2020-05-21 03:51:50	2020-05-21	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	26022	delivery	5	40
65719	2020-05-21 03:55:22	2020-05-21	8	[{"id_menu":5,"count":2}]	25999	pick-up	0	8
65720	2020-05-21 04:06:09	2020-05-21	14	[{"id_menu":2,"count":1}]	4993	delivery	5	19
65721	2020-05-21 04:14:43	2020-05-21	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	26036	delivery	5	30
65722	2020-05-21 04:15:22	2020-05-21	8	[{"id_menu":5,"count":1}]	11932	delivery	5	13
65723	2020-05-21 04:26:13	2020-05-21	17	[{"id_menu":4,"count":1}]	20128	delivery	5	22
65724	2020-05-21 04:27:02	2020-05-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	4588	delivery	5	28
65725	2020-05-21 04:29:03	2020-05-21	9	[{"id_menu":7,"count":1}]	26120	pick-up	0	9
65726	2020-05-21 04:35:18	2020-05-21	9	[{"id_menu":6,"count":1}]	26011	delivery	5	14
65727	2020-05-21 04:39:18	2020-05-21	14	[{"id_menu":2,"count":1}]	13651	pick-up	0	14
65728	2020-05-21 04:43:38	2020-05-21	12	[{"id_menu":1,"count":1}]	5286	pick-up	0	12
65729	2020-05-21 04:44:53	2020-05-21	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25003	delivery	5	35
65730	2020-05-21 04:45:58	2020-05-21	17	[{"id_menu":4,"count":1}]	2932	pick-up	0	17
65731	2020-05-21 04:46:34	2020-05-21	9	[{"id_menu":7,"count":1}]	12598	delivery	5	14
65732	2020-05-21 04:58:39	2020-05-21	9	[{"id_menu":6,"count":1}]	26132	delivery	5	14
65733	2020-05-21 04:59:49	2020-05-21	9	[{"id_menu":6,"count":1}]	2912	pick-up	0	9
65734	2020-05-21 05:05:25	2020-05-21	9	[{"id_menu":6,"count":1}]	26071	delivery	5	14
65735	2020-05-21 05:07:24	2020-05-21	12	[{"id_menu":1,"count":1}]	26039	delivery	5	17
65736	2020-05-21 05:10:41	2020-05-21	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	10329	delivery	5	31
65737	2020-05-21 05:10:44	2020-05-21	9	[{"id_menu":6,"count":1}]	26093	delivery	5	14
65738	2020-05-21 05:14:53	2020-05-21	9	[{"id_menu":7,"count":1}]	25974	delivery	5	14
65739	2020-05-21 05:15:32	2020-05-21	8	[{"id_menu":5,"count":1}]	7942	delivery	5	13
65740	2020-05-21 05:20:29	2020-05-21	30	[{"id_menu":1,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9061	delivery	5	35
65741	2020-05-21 05:21:01	2020-05-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12389	delivery	5	23
65742	2020-05-21 05:21:18	2020-05-21	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	26083	delivery	5	40
65743	2020-05-21 05:28:32	2020-05-21	9	[{"id_menu":6,"count":1}]	15194	pick-up	0	9
65744	2020-05-21 05:28:55	2020-05-21	8	[{"id_menu":5,"count":1}]	20666	delivery	5	13
65745	2020-05-21 05:29:51	2020-05-21	8	[{"id_menu":5,"count":1}]	5839	pick-up	0	8
65746	2020-05-21 05:31:10	2020-05-21	14	[{"id_menu":2,"count":1}]	1382	pick-up	0	14
65747	2020-05-21 05:36:47	2020-05-21	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12304	delivery	5	36
65748	2020-05-21 05:41:23	2020-05-21	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	25989	delivery	5	28
65749	2020-05-21 05:46:24	2020-05-21	14	[{"id_menu":2,"count":1}]	9144	delivery	5	19
65750	2020-05-21 06:05:12	2020-05-21	9	[{"id_menu":6,"count":1}]	25967	delivery	5	14
65751	2020-05-21 06:07:02	2020-05-21	12	[{"id_menu":3,"count":1}]	26034	delivery	5	17
65752	2020-05-21 06:11:10	2020-05-21	12	[{"id_menu":3,"count":1}]	4230	delivery	5	17
65753	2020-05-21 06:14:58	2020-05-21	9	[{"id_menu":7,"count":2}]	26066	delivery	5	14
65754	2020-05-21 06:19:55	2020-05-21	8	[{"id_menu":5,"count":1}]	26072	delivery	5	13
65755	2020-05-21 06:22:22	2020-05-21	8	[{"id_menu":5,"count":1}]	13093	delivery	5	13
65756	2020-05-21 06:24:24	2020-05-21	17	[{"id_menu":4,"count":1}]	18124	delivery	5	22
65757	2020-05-21 06:28:05	2020-05-21	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	12905	pick-up	0	22
65758	2020-05-21 06:33:08	2020-05-21	9	[{"id_menu":6,"count":1}]	17218	delivery	5	14
65759	2020-05-21 06:35:12	2020-05-21	9	[{"id_menu":7,"count":1}]	6444	delivery	5	14
65760	2020-05-21 06:36:21	2020-05-21	14	[{"id_menu":2,"count":1}]	11412	delivery	5	19
65761	2020-05-21 06:39:58	2020-05-21	17	[{"id_menu":4,"count":1}]	25982	delivery	5	22
65762	2020-05-21 06:46:29	2020-05-21	9	[{"id_menu":6,"count":1}]	26061	delivery	5	14
65763	2020-05-21 06:48:19	2020-05-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	11005	pick-up	0	23
65764	2020-05-21 06:51:41	2020-05-21	12	[{"id_menu":3,"count":1}]	6950	pick-up	0	12
65765	2020-05-21 06:52:09	2020-05-21	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	25331	delivery	5	25
65766	2020-05-21 06:52:51	2020-05-21	8	[{"id_menu":5,"count":1}]	8655	delivery	5	13
65767	2020-05-21 06:53:38	2020-05-21	9	[{"id_menu":7,"count":1}]	25972	delivery	5	14
65768	2020-05-21 06:56:39	2020-05-21	8	[{"id_menu":5,"count":1}]	11961	delivery	5	13
65769	2020-05-21 06:59:26	2020-05-21	12	[{"id_menu":1,"count":1}]	9173	pick-up	0	12
65770	2020-05-21 07:01:54	2020-05-21	8	[{"id_menu":5,"count":1}]	24238	delivery	5	13
65771	2020-05-21 07:11:40	2020-05-21	17	[{"id_menu":4,"count":1}]	26081	delivery	5	22
65772	2020-05-21 07:11:43	2020-05-21	12	[{"id_menu":3,"count":1}]	26091	delivery	5	17
65773	2020-05-21 07:12:56	2020-05-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	16160	delivery	5	22
65774	2020-05-21 07:19:40	2020-05-21	8	[{"id_menu":5,"count":1}]	26092	delivery	5	13
65775	2020-05-21 07:22:42	2020-05-21	14	[{"id_menu":2,"count":2}]	1418	pick-up	0	14
65776	2020-05-21 07:23:04	2020-05-21	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	26076	delivery	5	31
65777	2020-05-21 07:27:44	2020-05-21	14	[{"id_menu":2,"count":1}]	26003	delivery	5	19
65778	2020-05-21 07:29:16	2020-05-21	17	[{"id_menu":4,"count":1}]	7523	delivery	5	22
65779	2020-05-21 07:32:47	2020-05-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	26005	delivery	5	22
65780	2020-05-21 07:35:48	2020-05-21	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	11203	delivery	5	40
65781	2020-05-21 07:36:32	2020-05-21	8	[{"id_menu":5,"count":1}]	10588	delivery	5	13
65782	2020-05-21 07:38:46	2020-05-21	8	[{"id_menu":5,"count":1}]	16810	pick-up	0	8
65783	2020-05-21 07:44:27	2020-05-21	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	7203	pick-up	0	29
65784	2020-05-21 07:47:48	2020-05-21	12	[{"id_menu":3,"count":1}]	25990	delivery	5	17
65785	2020-05-21 07:48:27	2020-05-21	17	[{"id_menu":4,"count":1}]	6492	delivery	5	22
65786	2020-05-21 08:01:52	2020-05-21	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1376	pick-up	0	29
65787	2020-05-21 08:02:36	2020-05-21	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	26032	delivery	5	39
65788	2020-05-21 08:06:15	2020-05-21	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	16840	delivery	5	40
65789	2020-05-21 08:07:05	2020-05-21	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	18202	pick-up	0	25
65790	2020-05-21 08:11:36	2020-05-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8471	delivery	5	31
65791	2020-05-21 08:16:39	2020-05-21	9	[{"id_menu":7,"count":1}]	25983	delivery	5	14
65792	2020-05-21 08:17:58	2020-05-21	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1490	delivery	5	36
65793	2020-05-21 08:25:22	2020-05-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12772	delivery	5	31
65794	2020-05-21 08:31:31	2020-05-21	12	[{"id_menu":1,"count":1}]	26037	delivery	5	17
65795	2020-05-21 08:32:06	2020-05-21	14	[{"id_menu":2,"count":1}]	26002	delivery	5	19
65796	2020-05-21 08:35:41	2020-05-21	12	[{"id_menu":3,"count":1}]	17943	pick-up	0	12
65797	2020-05-21 08:43:50	2020-05-21	12	[{"id_menu":1,"count":1}]	26094	delivery	5	17
65798	2020-05-21 08:54:01	2020-05-21	12	[{"id_menu":3,"count":1}]	240	delivery	5	17
65799	2020-05-21 08:55:05	2020-05-21	17	[{"id_menu":4,"count":1}]	18399	delivery	5	22
65800	2020-05-21 09:01:03	2020-05-21	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	23033	delivery	5	31
65801	2020-05-21 09:08:22	2020-05-21	9	[{"id_menu":6,"count":2}]	12981	delivery	5	14
65802	2020-05-21 09:08:52	2020-05-21	17	[{"id_menu":4,"count":1}]	23831	pick-up	0	17
65803	2020-05-21 09:09:31	2020-05-21	9	[{"id_menu":7,"count":2}]	14164	delivery	5	14
65804	2020-05-21 09:11:03	2020-05-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15550	delivery	5	23
65805	2020-05-21 09:20:15	2020-05-21	8	[{"id_menu":5,"count":1}]	26118	delivery	5	13
65806	2020-05-21 09:27:05	2020-05-21	8	[{"id_menu":5,"count":2}]	26106	delivery	5	13
65807	2020-05-21 09:28:24	2020-05-21	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2424	delivery	5	31
65808	2020-05-21 09:34:06	2020-05-21	17	[{"id_menu":4,"count":1}]	9772	pick-up	0	17
65809	2020-05-21 09:35:44	2020-05-21	17	[{"id_menu":4,"count":1}]	10330	pick-up	0	17
65810	2020-05-21 09:38:20	2020-05-21	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	26139	delivery	5	37
65811	2020-05-21 09:43:07	2020-05-21	9	[{"id_menu":7,"count":1}]	3711	delivery	5	14
65812	2020-05-21 09:46:47	2020-05-21	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	13969	delivery	5	27
65813	2020-05-21 09:48:03	2020-05-21	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3887	delivery	5	38
65814	2020-05-21 09:48:33	2020-05-21	9	[{"id_menu":6,"count":1}]	17033	delivery	5	14
65815	2020-05-21 09:53:52	2020-05-21	9	[{"id_menu":7,"count":1}]	25987	delivery	5	14
65816	2020-05-21 10:05:20	2020-05-21	17	[{"id_menu":4,"count":1}]	26063	delivery	5	22
65817	2020-05-21 10:13:05	2020-05-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	13844	pick-up	0	23
65818	2020-05-21 10:14:14	2020-05-21	9	[{"id_menu":7,"count":1}]	2770	delivery	5	14
65819	2020-05-21 10:17:40	2020-05-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	16190	delivery	5	28
65820	2020-05-21 10:19:37	2020-05-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	26125	delivery	5	31
65821	2020-05-21 10:20:52	2020-05-21	17	[{"id_menu":4,"count":1}]	22579	pick-up	0	17
65822	2020-05-21 10:23:16	2020-05-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	26137	delivery	5	23
65823	2020-05-21 10:30:21	2020-05-21	12	[{"id_menu":3,"count":1}]	26090	delivery	5	17
65824	2020-05-21 10:30:40	2020-05-21	12	[{"id_menu":1,"count":1}]	14903	pick-up	0	12
65825	2020-05-21 10:31:49	2020-05-21	14	[{"id_menu":2,"count":1}]	171	delivery	5	19
65826	2020-05-21 10:32:16	2020-05-21	9	[{"id_menu":7,"count":1}]	13899	delivery	5	14
65827	2020-05-21 10:35:22	2020-05-21	9	[{"id_menu":6,"count":1}]	25423	delivery	5	14
65828	2020-05-21 10:35:24	2020-05-21	8	[{"id_menu":5,"count":1}]	4190	delivery	5	13
65829	2020-05-21 10:36:04	2020-05-21	12	[{"id_menu":3,"count":1}]	26141	delivery	5	17
65830	2020-05-21 10:38:27	2020-05-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	11503	delivery	5	28
65831	2020-05-21 10:40:58	2020-05-21	12	[{"id_menu":1,"count":1}]	10331	pick-up	0	12
65832	2020-05-21 10:48:29	2020-05-21	12	[{"id_menu":3,"count":1}]	3314	delivery	5	17
65833	2020-05-21 10:56:07	2020-05-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7510	delivery	5	28
65834	2020-05-21 11:05:53	2020-05-21	9	[{"id_menu":6,"count":1}]	26035	delivery	5	14
65835	2020-05-21 11:06:30	2020-05-21	8	[{"id_menu":5,"count":1}]	25997	pick-up	0	8
65836	2020-05-21 11:08:49	2020-05-21	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2310	delivery	5	36
65837	2020-05-21 11:12:05	2020-05-21	12	[{"id_menu":1,"count":1}]	24363	delivery	5	17
65838	2020-05-21 11:13:44	2020-05-21	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	26049	delivery	5	30
65839	2020-05-21 11:17:57	2020-05-21	9	[{"id_menu":6,"count":1}]	23990	delivery	5	14
65840	2020-05-21 11:19:10	2020-05-21	14	[{"id_menu":2,"count":1}]	2567	pick-up	0	14
65841	2020-05-21 11:19:55	2020-05-21	14	[{"id_menu":2,"count":1}]	11779	pick-up	0	14
65842	2020-05-21 11:23:29	2020-05-21	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	7673	delivery	5	36
65843	2020-05-21 11:25:01	2020-05-21	8	[{"id_menu":5,"count":1}]	23268	delivery	5	13
65844	2020-05-21 11:26:26	2020-05-21	9	[{"id_menu":6,"count":1}]	26000	delivery	5	14
65845	2020-05-21 11:26:48	2020-05-21	9	[{"id_menu":7,"count":1}]	25980	delivery	5	14
65846	2020-05-21 11:28:01	2020-05-21	17	[{"id_menu":4,"count":1}]	7443	delivery	5	22
65847	2020-05-21 11:28:19	2020-05-21	12	[{"id_menu":1,"count":1}]	23679	pick-up	0	12
65848	2020-05-21 11:29:46	2020-05-21	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	5343	pick-up	0	31
65849	2020-05-21 11:30:16	2020-05-21	9	[{"id_menu":7,"count":1}]	26119	pick-up	0	9
65850	2020-05-21 11:31:16	2020-05-21	12	[{"id_menu":3,"count":1}]	1905	pick-up	0	12
65851	2020-05-21 11:32:08	2020-05-21	12	[{"id_menu":3,"count":1}]	20136	pick-up	0	12
65852	2020-05-21 11:34:01	2020-05-21	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	6419	delivery	5	26
65853	2020-05-21 11:36:45	2020-05-21	12	[{"id_menu":3,"count":1}]	1368	pick-up	0	12
65854	2020-05-21 11:38:43	2020-05-21	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	1343	pick-up	0	26
65855	2020-05-21 11:39:31	2020-05-21	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	6957	delivery	5	46
65856	2020-05-21 11:41:30	2020-05-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13527	delivery	5	31
65857	2020-05-21 11:43:04	2020-05-21	12	[{"id_menu":1,"count":1}]	26017	delivery	5	17
65858	2020-05-21 11:50:03	2020-05-21	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	26105	delivery	5	42
65859	2020-05-21 11:50:52	2020-05-21	8	[{"id_menu":5,"count":1}]	25986	delivery	5	13
65860	2020-05-21 11:50:53	2020-05-21	17	[{"id_menu":4,"count":1}]	26054	delivery	5	22
65861	2020-05-21 11:56:30	2020-05-21	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	26138	delivery	5	45
65862	2020-05-21 11:57:00	2020-05-21	9	[{"id_menu":7,"count":1}]	9114	delivery	5	14
65863	2020-05-21 11:58:04	2020-05-21	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	25971	delivery	5	34
65864	2020-05-21 11:58:16	2020-05-21	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	26089	delivery	5	43
65865	2020-05-21 11:59:03	2020-05-21	17	[{"id_menu":4,"count":1}]	6858	delivery	5	22
65866	2020-05-21 12:06:25	2020-05-21	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	19172	delivery	5	31
65867	2020-05-21 12:08:03	2020-05-21	12	[{"id_menu":3,"count":1}]	2237	delivery	5	17
65868	2020-05-21 12:12:18	2020-05-21	14	[{"id_menu":2,"count":1}]	827	pick-up	0	14
65869	2020-05-21 12:13:46	2020-05-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25918	delivery	5	23
65870	2020-05-21 12:20:13	2020-05-21	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	26073	delivery	5	26
65871	2020-05-21 12:21:14	2020-05-21	9	[{"id_menu":6,"count":1}]	16795	delivery	5	14
65872	2020-05-21 12:23:35	2020-05-21	17	[{"id_menu":4,"count":1}]	24230	delivery	5	22
65873	2020-05-21 12:35:06	2020-05-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	26008	delivery	5	31
65874	2020-05-21 12:38:10	2020-05-21	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16621	delivery	5	37
65875	2020-05-21 12:44:11	2020-05-21	12	[{"id_menu":3,"count":1}]	16079	pick-up	0	12
65876	2020-05-21 12:49:38	2020-05-21	12	[{"id_menu":3,"count":1}]	26103	delivery	5	17
65877	2020-05-21 12:50:51	2020-05-21	9	[{"id_menu":6,"count":1}]	13948	delivery	5	14
65878	2020-05-21 12:51:03	2020-05-21	9	[{"id_menu":7,"count":1}]	19366	delivery	5	14
65879	2020-05-21 12:52:45	2020-05-21	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	3243	delivery	5	26
65880	2020-05-21 12:55:02	2020-05-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22966	delivery	5	22
65881	2020-05-21 12:56:49	2020-05-21	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2743	delivery	5	43
65882	2020-05-21 13:00:21	2020-05-21	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	730	pick-up	0	21
65883	2020-05-21 13:00:56	2020-05-21	12	[{"id_menu":3,"count":2}]	638	pick-up	0	12
65884	2020-05-21 13:02:31	2020-05-21	12	[{"id_menu":3,"count":1}]	26136	delivery	5	17
65885	2020-05-21 13:05:36	2020-05-21	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	25977	delivery	5	25
65886	2020-05-21 13:07:18	2020-05-21	8	[{"id_menu":5,"count":1}]	12966	delivery	5	13
65887	2020-05-21 13:07:34	2020-05-21	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":2}]	3260	pick-up	0	29
65888	2020-05-21 13:07:37	2020-05-21	12	[{"id_menu":3,"count":1}]	6609	delivery	5	17
65889	2020-05-21 13:14:19	2020-05-21	9	[{"id_menu":6,"count":1}]	10928	pick-up	0	9
65890	2020-05-21 13:15:56	2020-05-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	25995	delivery	5	28
65891	2020-05-21 13:16:04	2020-05-21	9	[{"id_menu":7,"count":3}]	17928	delivery	5	14
65892	2020-05-21 13:16:08	2020-05-21	9	[{"id_menu":7,"count":1}]	10524	delivery	5	14
65893	2020-05-21 13:23:07	2020-05-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	26131	delivery	5	22
65894	2020-05-21 13:31:34	2020-05-21	17	[{"id_menu":4,"count":1}]	18983	delivery	5	22
65895	2020-05-21 13:32:54	2020-05-21	9	[{"id_menu":7,"count":2}]	26133	delivery	5	14
65896	2020-05-21 13:33:12	2020-05-21	14	[{"id_menu":2,"count":1}]	8575	delivery	5	19
65897	2020-05-21 13:33:54	2020-05-21	17	[{"id_menu":4,"count":1}]	19523	pick-up	0	17
65898	2020-05-21 13:36:28	2020-05-21	14	[{"id_menu":2,"count":1}]	14003	delivery	5	19
65899	2020-05-21 13:47:20	2020-05-21	9	[{"id_menu":6,"count":1}]	13837	delivery	5	14
65900	2020-05-21 13:51:27	2020-05-21	8	[{"id_menu":5,"count":1}]	23709	delivery	5	13
65901	2020-05-21 13:51:41	2020-05-21	12	[{"id_menu":3,"count":1}]	26021	delivery	5	17
65902	2020-05-21 13:54:05	2020-05-21	17	[{"id_menu":4,"count":1}]	10060	delivery	5	22
65903	2020-05-21 13:55:06	2020-05-21	17	[{"id_menu":4,"count":1}]	3778	delivery	5	22
65904	2020-05-21 14:04:24	2020-05-21	12	[{"id_menu":3,"count":1}]	13465	delivery	5	17
65905	2020-05-21 14:05:04	2020-05-21	12	[{"id_menu":3,"count":1}]	24885	delivery	5	17
65906	2020-05-21 14:07:54	2020-05-21	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	26027	delivery	5	46
65907	2020-05-21 14:08:59	2020-05-21	12	[{"id_menu":1,"count":1}]	26048	delivery	5	17
65908	2020-05-21 14:14:54	2020-05-21	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":3}]	26096	delivery	5	26
65909	2020-05-21 14:29:43	2020-05-21	9	[{"id_menu":6,"count":1}]	4894	delivery	5	14
65910	2020-05-21 14:31:41	2020-05-21	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	26052	delivery	5	34
65911	2020-05-21 14:39:19	2020-05-21	9	[{"id_menu":7,"count":1}]	5923	delivery	5	14
65912	2020-05-21 14:43:25	2020-05-21	17	[{"id_menu":4,"count":1}]	1795	pick-up	0	17
65913	2020-05-21 14:44:32	2020-05-21	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	26045	delivery	5	51
65914	2020-05-21 14:46:37	2020-05-21	9	[{"id_menu":6,"count":1}]	1392	pick-up	0	9
65915	2020-05-21 14:51:35	2020-05-21	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2318	pick-up	0	26
65916	2020-05-21 14:54:12	2020-05-21	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4293	delivery	5	46
65917	2020-05-21 14:54:41	2020-05-21	17	[{"id_menu":4,"count":1}]	4021	delivery	5	22
65918	2020-05-21 14:54:59	2020-05-21	8	[{"id_menu":5,"count":1}]	26050	delivery	5	13
65919	2020-05-21 15:01:35	2020-05-21	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	19399	delivery	5	39
65920	2020-05-21 15:03:16	2020-05-21	9	[{"id_menu":7,"count":1}]	20595	pick-up	0	9
65921	2020-05-21 15:03:45	2020-05-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	16907	delivery	5	22
65922	2020-05-21 15:04:16	2020-05-21	14	[{"id_menu":2,"count":1}]	24899	delivery	5	19
65923	2020-05-21 15:05:21	2020-05-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	26095	delivery	5	31
65924	2020-05-21 15:05:53	2020-05-21	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	26038	delivery	5	43
65925	2020-05-21 15:11:05	2020-05-21	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	26062	delivery	5	44
65926	2020-05-21 15:12:12	2020-05-21	9	[{"id_menu":6,"count":1}]	15864	delivery	5	14
65927	2020-05-21 15:12:29	2020-05-21	14	[{"id_menu":2,"count":1}]	15720	pick-up	0	14
65928	2020-05-21 15:12:52	2020-05-21	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	26031	delivery	5	34
65929	2020-05-21 15:13:05	2020-05-21	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17826	delivery	5	52
65930	2020-05-21 15:17:46	2020-05-21	9	[{"id_menu":7,"count":1}]	12600	delivery	5	14
65931	2020-05-21 15:21:25	2020-05-21	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	26012	delivery	5	34
65932	2020-05-21 15:22:13	2020-05-21	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	26134	delivery	5	45
65933	2020-05-21 15:26:01	2020-05-21	8	[{"id_menu":5,"count":1}]	19279	delivery	5	13
65934	2020-05-21 15:26:48	2020-05-21	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	26107	delivery	5	23
65935	2020-05-21 15:31:28	2020-05-21	9	[{"id_menu":7,"count":1}]	26113	delivery	5	14
65936	2020-05-21 15:36:47	2020-05-21	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4436	pick-up	0	31
65937	2020-05-21 15:43:37	2020-05-21	17	[{"id_menu":4,"count":1}]	26099	pick-up	0	17
65938	2020-05-21 15:50:33	2020-05-21	9	[{"id_menu":7,"count":1}]	3212	delivery	5	14
65939	2020-05-21 15:52:20	2020-05-21	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9395	delivery	5	31
65940	2020-05-21 15:58:25	2020-05-21	9	[{"id_menu":6,"count":1}]	21718	delivery	5	14
65941	2020-05-21 15:59:34	2020-05-21	8	[{"id_menu":5,"count":1}]	24950	pick-up	0	8
65942	2020-05-21 16:02:02	2020-05-21	9	[{"id_menu":7,"count":1}]	17910	delivery	5	14
65943	2020-05-21 16:02:36	2020-05-21	9	[{"id_menu":7,"count":1}]	26086	delivery	5	14
65944	2020-05-21 16:03:35	2020-05-21	9	[{"id_menu":6,"count":1}]	286	pick-up	0	9
65945	2020-05-21 16:05:34	2020-05-21	9	[{"id_menu":7,"count":1}]	26056	delivery	5	14
65946	2020-05-21 16:05:48	2020-05-21	12	[{"id_menu":1,"count":1}]	14463	pick-up	0	12
65947	2020-05-21 16:05:54	2020-05-21	12	[{"id_menu":3,"count":1}]	20421	delivery	5	17
65948	2020-05-21 16:06:06	2020-05-21	8	[{"id_menu":5,"count":1}]	4498	delivery	5	13
65949	2020-05-21 16:07:41	2020-05-21	8	[{"id_menu":5,"count":1}]	24018	pick-up	0	8
65950	2020-05-21 16:10:54	2020-05-21	9	[{"id_menu":6,"count":1}]	8563	delivery	5	14
65951	2020-05-21 16:11:25	2020-05-21	8	[{"id_menu":5,"count":1}]	26114	delivery	5	13
65952	2020-05-21 16:14:21	2020-05-21	9	[{"id_menu":7,"count":1}]	1316	delivery	5	14
65953	2020-05-21 16:22:50	2020-05-21	17	[{"id_menu":4,"count":1}]	3736	pick-up	0	17
65954	2020-05-21 16:24:17	2020-05-21	14	[{"id_menu":2,"count":1}]	19750	delivery	5	19
65955	2020-05-21 16:29:33	2020-05-21	12	[{"id_menu":1,"count":1}]	3393	delivery	5	17
65956	2020-05-21 16:29:44	2020-05-21	9	[{"id_menu":7,"count":2}]	1922	delivery	5	14
65957	2020-05-21 16:30:02	2020-05-21	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	16252	delivery	5	26
65958	2020-05-21 16:35:11	2020-05-21	9	[{"id_menu":7,"count":2}]	26024	delivery	5	14
65959	2020-05-21 16:35:17	2020-05-21	14	[{"id_menu":2,"count":2}]	17138	pick-up	0	14
65960	2020-05-21 16:35:26	2020-05-21	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	4022	delivery	5	23
65961	2020-05-21 16:39:01	2020-05-21	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	25979	delivery	5	31
65962	2020-05-21 16:44:33	2020-05-21	9	[{"id_menu":7,"count":1}]	4862	pick-up	0	9
65963	2020-05-21 16:46:09	2020-05-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	25976	delivery	5	28
65964	2020-05-21 16:47:00	2020-05-21	12	[{"id_menu":3,"count":1}]	26028	delivery	5	17
65965	2020-05-21 17:00:49	2020-05-21	12	[{"id_menu":3,"count":1}]	21575	delivery	5	17
65966	2020-05-21 17:07:59	2020-05-21	9	[{"id_menu":6,"count":1}]	9112	pick-up	0	9
65967	2020-05-21 17:09:00	2020-05-21	12	[{"id_menu":1,"count":1}]	1093	pick-up	0	12
65968	2020-05-21 17:09:02	2020-05-21	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	22981	delivery	5	39
65969	2020-05-21 17:12:25	2020-05-21	9	[{"id_menu":6,"count":1}]	14331	delivery	5	14
65970	2020-05-21 17:26:53	2020-05-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	26101	delivery	5	22
65971	2020-05-21 17:40:02	2020-05-21	12	[{"id_menu":1,"count":1}]	26001	pick-up	0	12
65972	2020-05-21 17:40:34	2020-05-21	14	[{"id_menu":2,"count":1}]	15698	pick-up	0	14
65973	2020-05-21 17:43:08	2020-05-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9107	pick-up	0	23
65974	2020-05-21 17:50:12	2020-05-21	9	[{"id_menu":6,"count":1}]	26080	delivery	5	14
65975	2020-05-21 17:51:21	2020-05-21	17	[{"id_menu":4,"count":1}]	26130	pick-up	0	17
65976	2020-05-21 17:58:18	2020-05-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1055	delivery	5	28
65977	2020-05-21 18:02:57	2020-05-21	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	16150	delivery	5	26
65978	2020-05-21 18:04:45	2020-05-21	12	[{"id_menu":1,"count":1}]	8472	delivery	5	17
65979	2020-05-21 18:07:55	2020-05-21	9	[{"id_menu":6,"count":1}]	25984	pick-up	0	9
65980	2020-05-21 18:08:05	2020-05-21	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	13413	delivery	5	25
65981	2020-05-21 18:09:23	2020-05-21	9	[{"id_menu":6,"count":1}]	16660	delivery	5	14
65982	2020-05-21 18:09:35	2020-05-21	17	[{"id_menu":4,"count":1}]	19287	delivery	5	22
65983	2020-05-21 18:11:05	2020-05-21	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	13677	pick-up	0	20
65984	2020-05-21 18:13:48	2020-05-21	8	[{"id_menu":5,"count":2}]	25975	pick-up	0	8
65985	2020-05-21 18:14:41	2020-05-21	14	[{"id_menu":2,"count":1}]	10039	delivery	5	19
65986	2020-05-21 18:16:04	2020-05-21	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	26018	delivery	5	26
65987	2020-05-21 18:16:29	2020-05-21	17	[{"id_menu":4,"count":1}]	5277	pick-up	0	17
65988	2020-05-21 18:16:51	2020-05-21	12	[{"id_menu":3,"count":1}]	25017	delivery	5	17
65989	2020-05-21 18:20:20	2020-05-21	17	[{"id_menu":4,"count":1}]	21259	delivery	5	22
65990	2020-05-21 18:26:17	2020-05-21	14	[{"id_menu":2,"count":1}]	10097	pick-up	0	14
65991	2020-05-21 18:28:00	2020-05-21	9	[{"id_menu":7,"count":1}]	22794	delivery	5	14
65992	2020-05-21 18:28:09	2020-05-21	9	[{"id_menu":7,"count":1}]	26060	delivery	5	14
65993	2020-05-21 18:28:09	2020-05-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8050	delivery	5	28
65994	2020-05-21 18:32:22	2020-05-21	12	[{"id_menu":3,"count":1}]	11298	delivery	5	17
65995	2020-05-21 18:35:07	2020-05-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	8482	delivery	5	22
65996	2020-05-21 18:37:29	2020-05-21	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	14526	pick-up	0	22
65997	2020-05-21 18:41:34	2020-05-21	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	8811	pick-up	0	21
65998	2020-05-21 18:46:23	2020-05-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10243	delivery	5	31
65999	2020-05-21 18:48:29	2020-05-21	12	[{"id_menu":1,"count":1}]	12648	pick-up	0	12
66000	2020-05-21 18:49:45	2020-05-21	12	[{"id_menu":3,"count":1}]	21098	pick-up	0	12
66001	2020-05-21 18:53:10	2020-05-21	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	24625	delivery	5	44
66002	2020-05-21 18:56:22	2020-05-21	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22558	delivery	5	37
66003	2020-05-21 18:59:12	2020-05-21	14	[{"id_menu":2,"count":1}]	25969	delivery	5	19
66004	2020-05-21 18:59:38	2020-05-21	8	[{"id_menu":5,"count":1}]	22010	delivery	5	13
66005	2020-05-21 19:00:20	2020-05-21	9	[{"id_menu":6,"count":1}]	7918	pick-up	0	9
66006	2020-05-21 19:00:35	2020-05-21	12	[{"id_menu":3,"count":1}]	2341	delivery	5	17
66007	2020-05-21 19:02:05	2020-05-21	9	[{"id_menu":6,"count":1}]	26068	delivery	5	14
66008	2020-05-21 19:09:27	2020-05-21	9	[{"id_menu":7,"count":1}]	26074	pick-up	0	9
66009	2020-05-21 19:09:52	2020-05-21	17	[{"id_menu":4,"count":1}]	491	pick-up	0	17
66010	2020-05-21 19:12:43	2020-05-21	12	[{"id_menu":1,"count":1}]	24866	delivery	5	17
66011	2020-05-21 19:13:32	2020-05-21	17	[{"id_menu":4,"count":1}]	8552	delivery	5	22
66012	2020-05-21 19:14:01	2020-05-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13876	delivery	5	22
66013	2020-05-21 19:18:02	2020-05-21	8	[{"id_menu":5,"count":1}]	25357	pick-up	0	8
66014	2020-05-21 19:23:23	2020-05-21	14	[{"id_menu":2,"count":1}]	25985	delivery	5	19
66015	2020-05-21 19:28:21	2020-05-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	11038	delivery	5	22
66016	2020-05-21 19:33:51	2020-05-21	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	21061	delivery	5	43
66017	2020-05-21 19:42:26	2020-05-21	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	424	pick-up	0	21
66018	2020-05-21 19:45:00	2020-05-21	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	23213	delivery	5	29
66019	2020-05-21 19:45:43	2020-05-21	14	[{"id_menu":2,"count":2}]	24344	delivery	5	19
66020	2020-05-21 19:52:59	2020-05-21	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	26088	delivery	5	25
66021	2020-05-21 19:56:24	2020-05-21	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	26102	delivery	5	31
66022	2020-05-21 20:02:33	2020-05-21	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	17503	delivery	5	26
66023	2020-05-21 20:08:51	2020-05-21	17	[{"id_menu":4,"count":1}]	26129	pick-up	0	17
66024	2020-05-21 20:11:56	2020-05-21	9	[{"id_menu":7,"count":1}]	4395	pick-up	0	9
66025	2020-05-21 20:14:50	2020-05-21	17	[{"id_menu":4,"count":1}]	9115	delivery	5	22
66026	2020-05-21 20:14:57	2020-05-21	12	[{"id_menu":1,"count":1}]	11884	delivery	5	17
66027	2020-05-21 20:19:14	2020-05-21	9	[{"id_menu":6,"count":1}]	13127	delivery	5	14
66028	2020-05-21 20:23:31	2020-05-21	9	[{"id_menu":6,"count":1}]	26023	delivery	5	14
66029	2020-05-21 20:23:47	2020-05-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21934	delivery	5	22
66030	2020-05-21 20:25:50	2020-05-21	8	[{"id_menu":5,"count":1}]	1101	pick-up	0	8
66031	2020-05-21 20:45:35	2020-05-21	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	5099	pick-up	0	34
66032	2020-05-21 20:49:36	2020-05-21	8	[{"id_menu":5,"count":1}]	26067	delivery	5	13
66033	2020-05-21 20:49:53	2020-05-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	25970	delivery	5	31
66034	2020-05-21 20:52:38	2020-05-21	8	[{"id_menu":5,"count":1}]	20183	delivery	5	13
66035	2020-05-21 20:54:21	2020-05-21	9	[{"id_menu":7,"count":1}]	25996	delivery	5	14
66036	2020-05-21 20:57:30	2020-05-21	17	[{"id_menu":4,"count":1}]	26122	delivery	5	22
66037	2020-05-21 20:59:23	2020-05-21	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	26009	delivery	5	30
66038	2020-05-21 21:01:26	2020-05-21	17	[{"id_menu":4,"count":1}]	26014	delivery	5	22
66039	2020-05-21 21:03:13	2020-05-21	8	[{"id_menu":5,"count":1}]	26064	delivery	5	13
66040	2020-05-21 21:03:48	2020-05-21	9	[{"id_menu":6,"count":1}]	26126	delivery	5	14
66041	2020-05-21 21:10:51	2020-05-21	17	[{"id_menu":4,"count":1}]	7527	delivery	5	22
66042	2020-05-21 21:11:21	2020-05-21	9	[{"id_menu":7,"count":1}]	26124	delivery	5	14
66043	2020-05-21 21:12:38	2020-05-21	8	[{"id_menu":5,"count":1}]	26100	delivery	5	13
66044	2020-05-21 21:18:08	2020-05-21	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	26047	delivery	5	25
66045	2020-05-21 21:18:23	2020-05-21	14	[{"id_menu":2,"count":1}]	20338	pick-up	0	14
66046	2020-05-21 21:23:30	2020-05-21	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25966	delivery	5	34
66047	2020-05-21 21:24:09	2020-05-21	9	[{"id_menu":6,"count":1}]	26121	pick-up	0	9
66048	2020-05-21 21:25:14	2020-05-21	8	[{"id_menu":5,"count":1}]	7320	delivery	5	13
66049	2020-05-21 21:25:33	2020-05-21	9	[{"id_menu":6,"count":3}]	8858	delivery	5	14
66050	2020-05-21 21:25:59	2020-05-21	12	[{"id_menu":3,"count":1}]	26097	delivery	5	17
66051	2020-05-21 21:30:24	2020-05-21	12	[{"id_menu":1,"count":1}]	24902	delivery	5	17
66052	2020-05-21 21:30:25	2020-05-21	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	26082	delivery	5	30
66053	2020-05-21 21:32:10	2020-05-21	17	[{"id_menu":4,"count":1}]	4950	pick-up	0	17
66054	2020-05-21 21:32:47	2020-05-21	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	17899	pick-up	0	24
66055	2020-05-21 21:36:54	2020-05-21	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7378	delivery	5	35
66056	2020-05-21 21:37:03	2020-05-21	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	21494	delivery	5	45
66057	2020-05-21 21:37:13	2020-05-21	12	[{"id_menu":3,"count":1}]	17054	delivery	5	17
66058	2020-05-21 21:49:14	2020-05-21	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	26069	delivery	5	22
66059	2020-05-21 21:50:50	2020-05-21	14	[{"id_menu":2,"count":1}]	24716	delivery	5	19
66060	2020-05-21 21:56:31	2020-05-21	17	[{"id_menu":4,"count":2}]	4116	delivery	5	22
66061	2020-05-21 21:57:08	2020-05-21	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	19817	delivery	5	42
66062	2020-05-21 22:00:35	2020-05-21	9	[{"id_menu":7,"count":1}]	752	delivery	5	14
66063	2020-05-21 22:00:50	2020-05-21	9	[{"id_menu":6,"count":1}]	21628	delivery	5	14
66064	2020-05-21 22:04:05	2020-05-21	8	[{"id_menu":5,"count":1}]	878	pick-up	0	8
66065	2020-05-21 22:05:59	2020-05-21	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26123	delivery	5	31
66066	2020-05-21 22:09:52	2020-05-21	9	[{"id_menu":6,"count":1}]	26007	delivery	5	14
66067	2020-05-21 22:12:21	2020-05-21	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18754	delivery	5	45
66068	2020-05-21 22:13:10	2020-05-21	9	[{"id_menu":6,"count":1}]	26051	delivery	5	14
66069	2020-05-21 22:13:23	2020-05-21	14	[{"id_menu":2,"count":1}]	1396	delivery	5	19
66070	2020-05-21 22:13:50	2020-05-21	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	26111	delivery	5	23
66071	2020-05-21 22:14:01	2020-05-21	12	[{"id_menu":1,"count":1}]	4130	delivery	5	17
66072	2020-05-21 22:23:24	2020-05-21	12	[{"id_menu":1,"count":1}]	18409	delivery	5	17
66073	2020-05-21 22:24:18	2020-05-21	9	[{"id_menu":7,"count":1}]	5642	pick-up	0	9
66074	2020-05-21 22:24:32	2020-05-21	17	[{"id_menu":4,"count":1}]	22982	pick-up	0	17
66075	2020-05-21 22:27:33	2020-05-21	12	[{"id_menu":1,"count":1}]	6134	pick-up	0	12
66076	2020-05-21 22:32:25	2020-05-21	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	25061	delivery	5	38
66077	2020-05-21 22:33:34	2020-05-21	9	[{"id_menu":6,"count":1}]	26058	delivery	5	14
66078	2020-05-21 22:33:37	2020-05-21	8	[{"id_menu":5,"count":1}]	2618	pick-up	0	8
66079	2020-05-21 22:38:30	2020-05-21	29	[{"id_menu":3,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12154	delivery	5	34
66080	2020-05-21 22:51:44	2020-05-21	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	136	pick-up	0	37
66081	2020-05-21 22:54:45	2020-05-21	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	22564	delivery	5	39
66082	2020-05-21 22:55:38	2020-05-21	9	[{"id_menu":6,"count":1}]	16393	delivery	5	14
66083	2020-05-21 22:57:11	2020-05-21	8	[{"id_menu":5,"count":1}]	4482	delivery	5	13
66084	2020-05-21 23:04:26	2020-05-21	9	[{"id_menu":6,"count":1}]	20214	delivery	5	14
66085	2020-05-21 23:06:36	2020-05-21	12	[{"id_menu":3,"count":1}]	14025	pick-up	0	12
66086	2020-05-21 23:11:34	2020-05-21	9	[{"id_menu":7,"count":1}]	2354	pick-up	0	9
66087	2020-05-21 23:13:26	2020-05-21	17	[{"id_menu":4,"count":1}]	3054	pick-up	0	17
66088	2020-05-21 23:20:21	2020-05-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	26057	delivery	5	31
66089	2020-05-21 23:24:06	2020-05-21	14	[{"id_menu":2,"count":1}]	17916	delivery	5	19
66090	2020-05-21 23:33:18	2020-05-21	8	[{"id_menu":5,"count":1}]	1504	delivery	5	13
66091	2020-05-21 23:35:00	2020-05-21	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	585	delivery	5	26
66092	2020-05-21 23:36:06	2020-05-21	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	5461	delivery	5	26
66093	2020-05-21 23:42:59	2020-05-21	12	[{"id_menu":1,"count":1}]	25266	delivery	5	17
66094	2020-05-21 23:43:52	2020-05-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10430	delivery	5	22
66095	2020-05-21 23:47:16	2020-05-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11254	delivery	5	23
66096	2020-05-21 23:55:17	2020-05-21	8	[{"id_menu":5,"count":1}]	26108	pick-up	0	8
66097	2020-05-21 23:55:37	2020-05-21	9	[{"id_menu":7,"count":1}]	9043	pick-up	0	9
66098	2020-05-21 23:57:01	2020-05-21	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	21528	delivery	5	26
66099	2020-05-21 23:57:45	2020-05-21	12	[{"id_menu":1,"count":1}]	25988	delivery	5	17
66100	2020-05-21 23:59:31	2020-05-21	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	26085	delivery	5	31
66101	2020-05-21 23:59:36	2020-05-21	14	[{"id_menu":2,"count":1}]	5205	delivery	5	19
66102	2020-05-22 00:02:21	2020-05-22	12	[{"id_menu":3,"count":1}]	13930	delivery	5	17
66103	2020-05-22 00:02:24	2020-05-22	9	[{"id_menu":6,"count":1}]	23890	pick-up	0	9
66104	2020-05-22 00:05:04	2020-05-22	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	7019	delivery	5	26
66105	2020-05-22 00:05:40	2020-05-22	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	24665	delivery	5	31
66106	2020-05-22 00:06:45	2020-05-22	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	26213	delivery	5	46
66107	2020-05-22 00:06:58	2020-05-22	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	1709	delivery	5	26
66108	2020-05-22 00:21:13	2020-05-22	17	[{"id_menu":4,"count":1}]	4414	delivery	5	22
66109	2020-05-22 00:25:51	2020-05-22	14	[{"id_menu":2,"count":1}]	7046	pick-up	0	14
66110	2020-05-22 00:26:32	2020-05-22	9	[{"id_menu":7,"count":1}]	22744	delivery	5	14
66111	2020-05-22 00:32:04	2020-05-22	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1559	pick-up	0	29
66112	2020-05-22 00:33:12	2020-05-22	9	[{"id_menu":6,"count":1}]	11586	delivery	5	14
66113	2020-05-22 00:36:27	2020-05-22	17	[{"id_menu":4,"count":1}]	26208	delivery	5	22
66114	2020-05-22 00:38:15	2020-05-22	8	[{"id_menu":5,"count":1}]	15071	delivery	5	13
66115	2020-05-22 00:46:44	2020-05-22	12	[{"id_menu":3,"count":1}]	8815	delivery	5	17
66116	2020-05-22 00:48:34	2020-05-22	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	22320	pick-up	0	21
66117	2020-05-22 00:52:12	2020-05-22	9	[{"id_menu":6,"count":2}]	23298	delivery	5	14
66118	2020-05-22 00:59:49	2020-05-22	12	[{"id_menu":3,"count":1}]	26231	pick-up	0	12
66119	2020-05-22 00:59:56	2020-05-22	9	[{"id_menu":6,"count":2}]	17757	delivery	5	14
66120	2020-05-22 01:03:31	2020-05-22	9	[{"id_menu":6,"count":1}]	17788	pick-up	0	9
66121	2020-05-22 01:03:40	2020-05-22	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	13249	delivery	5	26
66122	2020-05-22 01:11:06	2020-05-22	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	26313	delivery	5	34
66123	2020-05-22 01:12:15	2020-05-22	17	[{"id_menu":4,"count":1}]	24343	delivery	5	22
66124	2020-05-22 01:14:32	2020-05-22	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	26182	delivery	5	43
66125	2020-05-22 01:17:41	2020-05-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1361	delivery	5	28
66126	2020-05-22 01:19:12	2020-05-22	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	21601	delivery	5	31
66127	2020-05-22 01:25:39	2020-05-22	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	26202	delivery	5	36
66128	2020-05-22 01:27:28	2020-05-22	12	[{"id_menu":1,"count":1}]	26255	delivery	5	17
66129	2020-05-22 01:31:09	2020-05-22	9	[{"id_menu":6,"count":1}]	26265	delivery	5	14
66130	2020-05-22 01:37:36	2020-05-22	14	[{"id_menu":2,"count":1}]	5713	delivery	5	19
66131	2020-05-22 01:42:30	2020-05-22	12	[{"id_menu":3,"count":1}]	19855	delivery	5	17
66132	2020-05-22 01:42:42	2020-05-22	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	10707	delivery	5	26
66133	2020-05-22 01:49:40	2020-05-22	12	[{"id_menu":1,"count":1}]	21	pick-up	0	12
66134	2020-05-22 01:51:41	2020-05-22	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	26249	delivery	5	31
66135	2020-05-22 01:53:23	2020-05-22	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	26153	delivery	5	31
66136	2020-05-22 01:57:35	2020-05-22	8	[{"id_menu":5,"count":1}]	13736	delivery	5	13
66137	2020-05-22 01:57:51	2020-05-22	9	[{"id_menu":7,"count":1}]	5485	delivery	5	14
66138	2020-05-22 02:02:48	2020-05-22	12	[{"id_menu":1,"count":1}]	1504	delivery	5	17
66139	2020-05-22 02:03:16	2020-05-22	8	[{"id_menu":5,"count":1}]	26314	delivery	5	13
66140	2020-05-22 02:07:36	2020-05-22	12	[{"id_menu":3,"count":1}]	1148	pick-up	0	12
66141	2020-05-22 02:08:12	2020-05-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	22605	delivery	5	28
66142	2020-05-22 02:11:03	2020-05-22	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	7096	pick-up	0	43
66143	2020-05-22 02:11:48	2020-05-22	8	[{"id_menu":5,"count":1}]	26321	delivery	5	13
66144	2020-05-22 02:12:13	2020-05-22	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	25839	delivery	5	43
66145	2020-05-22 02:17:22	2020-05-22	8	[{"id_menu":5,"count":1}]	17808	delivery	5	13
66146	2020-05-22 02:18:31	2020-05-22	17	[{"id_menu":4,"count":1}]	26152	delivery	5	22
66147	2020-05-22 02:21:54	2020-05-22	9	[{"id_menu":6,"count":1}]	26303	delivery	5	14
66148	2020-05-22 02:22:36	2020-05-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24134	delivery	5	23
66149	2020-05-22 02:26:01	2020-05-22	17	[{"id_menu":4,"count":1}]	3626	delivery	5	22
66150	2020-05-22 02:29:36	2020-05-22	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22464	delivery	5	34
66151	2020-05-22 02:31:42	2020-05-22	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	26278	delivery	5	40
66152	2020-05-22 02:32:51	2020-05-22	9	[{"id_menu":7,"count":1}]	26284	delivery	5	14
66153	2020-05-22 02:34:08	2020-05-22	8	[{"id_menu":5,"count":1}]	23863	delivery	5	13
66154	2020-05-22 02:36:20	2020-05-22	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	6535	pick-up	0	26
66155	2020-05-22 02:37:54	2020-05-22	55	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	6009	delivery	5	60
66156	2020-05-22 02:40:08	2020-05-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	14887	pick-up	0	23
66157	2020-05-22 02:40:32	2020-05-22	14	[{"id_menu":2,"count":1}]	26178	delivery	5	19
66158	2020-05-22 02:41:41	2020-05-22	9	[{"id_menu":6,"count":1}]	23148	delivery	5	14
66159	2020-05-22 02:50:16	2020-05-22	8	[{"id_menu":5,"count":1}]	26168	delivery	5	13
66160	2020-05-22 02:53:33	2020-05-22	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	4962	delivery	5	39
66161	2020-05-22 02:59:33	2020-05-22	9	[{"id_menu":7,"count":1}]	26175	delivery	5	14
66162	2020-05-22 03:00:01	2020-05-22	14	[{"id_menu":2,"count":1}]	11488	delivery	5	19
66163	2020-05-22 03:04:35	2020-05-22	12	[{"id_menu":1,"count":1}]	11666	delivery	5	17
66164	2020-05-22 03:09:20	2020-05-22	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	15151	delivery	5	26
66165	2020-05-22 03:11:06	2020-05-22	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	24964	pick-up	0	35
66166	2020-05-22 03:15:53	2020-05-22	17	[{"id_menu":4,"count":1}]	26196	delivery	5	22
66167	2020-05-22 03:16:32	2020-05-22	17	[{"id_menu":4,"count":1}]	26183	delivery	5	22
66168	2020-05-22 03:18:28	2020-05-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5097	delivery	5	23
66169	2020-05-22 03:19:05	2020-05-22	9	[{"id_menu":7,"count":1}]	26238	delivery	5	14
66170	2020-05-22 03:19:47	2020-05-22	12	[{"id_menu":3,"count":1}]	26159	pick-up	0	12
66171	2020-05-22 03:22:57	2020-05-22	8	[{"id_menu":5,"count":1}]	8204	delivery	5	13
66172	2020-05-22 03:27:31	2020-05-22	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	15244	delivery	5	27
66173	2020-05-22 03:30:27	2020-05-22	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2425	delivery	5	31
66174	2020-05-22 03:38:12	2020-05-22	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1760	pick-up	0	29
66175	2020-05-22 03:40:49	2020-05-22	12	[{"id_menu":3,"count":1}]	26322	pick-up	0	12
66176	2020-05-22 03:46:46	2020-05-22	14	[{"id_menu":2,"count":1}]	17857	delivery	5	19
66177	2020-05-22 03:46:51	2020-05-22	12	[{"id_menu":1,"count":1}]	1063	pick-up	0	12
66178	2020-05-22 03:49:15	2020-05-22	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	26320	delivery	5	31
66179	2020-05-22 03:54:44	2020-05-22	12	[{"id_menu":1,"count":1}]	26164	delivery	5	17
66180	2020-05-22 03:58:21	2020-05-22	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	12851	pick-up	0	37
66181	2020-05-22 03:59:00	2020-05-22	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	12090	delivery	5	23
66182	2020-05-22 04:01:32	2020-05-22	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	14993	delivery	5	22
66183	2020-05-22 04:01:35	2020-05-22	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	26218	delivery	5	30
66184	2020-05-22 04:05:20	2020-05-22	9	[{"id_menu":7,"count":1}]	13097	delivery	5	14
66185	2020-05-22 04:13:56	2020-05-22	17	[{"id_menu":5,"count":3},{"id_menu":6,"count":1}]	25077	delivery	5	22
66186	2020-05-22 04:16:52	2020-05-22	9	[{"id_menu":6,"count":1}]	24057	delivery	5	14
66187	2020-05-22 04:22:42	2020-05-22	9	[{"id_menu":6,"count":1}]	19749	delivery	5	14
66188	2020-05-22 04:27:58	2020-05-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	11250	delivery	5	28
66189	2020-05-22 04:29:14	2020-05-22	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	26211	delivery	5	25
66190	2020-05-22 04:29:33	2020-05-22	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	26270	delivery	5	22
66191	2020-05-22 04:47:33	2020-05-22	9	[{"id_menu":7,"count":1}]	26228	pick-up	0	9
66192	2020-05-22 04:50:39	2020-05-22	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1309	delivery	5	31
66193	2020-05-22 04:52:54	2020-05-22	9	[{"id_menu":6,"count":1}]	11961	delivery	5	14
66194	2020-05-22 04:54:12	2020-05-22	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	20963	delivery	5	31
66195	2020-05-22 04:54:45	2020-05-22	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	26212	pick-up	0	26
66196	2020-05-22 04:55:55	2020-05-22	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26259	delivery	5	37
66197	2020-05-22 05:01:10	2020-05-22	14	[{"id_menu":2,"count":1}]	7854	pick-up	0	14
66198	2020-05-22 05:06:10	2020-05-22	8	[{"id_menu":5,"count":1}]	4999	delivery	5	13
66199	2020-05-22 05:10:00	2020-05-22	17	[{"id_menu":4,"count":1}]	18582	delivery	5	22
66200	2020-05-22 05:13:23	2020-05-22	8	[{"id_menu":5,"count":2}]	26267	delivery	5	13
66201	2020-05-22 05:13:59	2020-05-22	9	[{"id_menu":7,"count":1}]	26268	pick-up	0	9
66202	2020-05-22 05:14:49	2020-05-22	9	[{"id_menu":6,"count":1}]	23870	delivery	5	14
66203	2020-05-22 05:18:25	2020-05-22	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24035	delivery	5	31
66204	2020-05-22 05:20:57	2020-05-22	14	[{"id_menu":2,"count":1}]	21825	pick-up	0	14
66205	2020-05-22 05:33:32	2020-05-22	14	[{"id_menu":2,"count":1}]	15604	delivery	5	19
66206	2020-05-22 05:38:36	2020-05-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1132	delivery	5	36
66207	2020-05-22 05:40:29	2020-05-22	9	[{"id_menu":7,"count":1}]	981	pick-up	0	9
66208	2020-05-22 05:40:56	2020-05-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	26263	delivery	5	28
66209	2020-05-22 05:43:40	2020-05-22	12	[{"id_menu":1,"count":1}]	896	delivery	5	17
66210	2020-05-22 05:45:33	2020-05-22	12	[{"id_menu":3,"count":1}]	4142	delivery	5	17
66211	2020-05-22 05:46:05	2020-05-22	12	[{"id_menu":1,"count":1}]	700	delivery	5	17
66212	2020-05-22 05:48:34	2020-05-22	9	[{"id_menu":7,"count":1}]	26169	delivery	5	14
66213	2020-05-22 05:48:48	2020-05-22	12	[{"id_menu":1,"count":2}]	26129	pick-up	0	12
66214	2020-05-22 05:49:33	2020-05-22	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7112	delivery	5	31
66215	2020-05-22 05:55:46	2020-05-22	14	[{"id_menu":2,"count":1}]	24647	delivery	5	19
66216	2020-05-22 05:59:37	2020-05-22	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	26319	delivery	5	23
66217	2020-05-22 06:01:56	2020-05-22	9	[{"id_menu":7,"count":1}]	22383	delivery	5	14
66218	2020-05-22 06:02:45	2020-05-22	9	[{"id_menu":7,"count":1}]	18939	delivery	5	14
66219	2020-05-22 06:04:40	2020-05-22	17	[{"id_menu":4,"count":1}]	11916	delivery	5	22
66220	2020-05-22 06:08:20	2020-05-22	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	26327	delivery	5	31
66221	2020-05-22 06:13:19	2020-05-22	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1266	pick-up	0	34
66222	2020-05-22 06:17:29	2020-05-22	8	[{"id_menu":5,"count":1}]	741	delivery	5	13
66223	2020-05-22 06:21:42	2020-05-22	17	[{"id_menu":4,"count":1}]	8357	delivery	5	22
66224	2020-05-22 06:22:30	2020-05-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3031	pick-up	0	23
66225	2020-05-22 06:23:45	2020-05-22	17	[{"id_menu":4,"count":1}]	11904	pick-up	0	17
66226	2020-05-22 06:29:12	2020-05-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5570	delivery	5	23
66227	2020-05-22 06:36:03	2020-05-22	12	[{"id_menu":1,"count":1}]	3629	delivery	5	17
66228	2020-05-22 06:38:22	2020-05-22	9	[{"id_menu":7,"count":1}]	1155	delivery	5	14
66229	2020-05-22 06:40:25	2020-05-22	9	[{"id_menu":7,"count":1}]	26252	pick-up	0	9
66230	2020-05-22 06:42:01	2020-05-22	14	[{"id_menu":2,"count":1}]	8923	delivery	5	19
66231	2020-05-22 06:46:23	2020-05-22	14	[{"id_menu":2,"count":1}]	11052	delivery	5	19
66232	2020-05-22 06:58:11	2020-05-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	26312	delivery	5	28
66233	2020-05-22 07:02:46	2020-05-22	12	[{"id_menu":1,"count":1}]	26316	delivery	5	17
66234	2020-05-22 07:07:29	2020-05-22	12	[{"id_menu":3,"count":1}]	26302	delivery	5	17
66235	2020-05-22 07:07:52	2020-05-22	17	[{"id_menu":4,"count":1}]	26242	delivery	5	22
66236	2020-05-22 07:11:46	2020-05-22	12	[{"id_menu":3,"count":1}]	6235	pick-up	0	12
66237	2020-05-22 07:13:14	2020-05-22	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	13866	delivery	5	40
66238	2020-05-22 07:22:14	2020-05-22	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	11102	delivery	5	30
66239	2020-05-22 07:22:27	2020-05-22	9	[{"id_menu":6,"count":2}]	12132	delivery	5	14
66240	2020-05-22 07:27:39	2020-05-22	9	[{"id_menu":7,"count":1}]	18343	delivery	5	14
66241	2020-05-22 07:37:24	2020-05-22	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	26207	delivery	5	36
66242	2020-05-22 07:47:22	2020-05-22	14	[{"id_menu":2,"count":1}]	26239	pick-up	0	14
66243	2020-05-22 07:47:55	2020-05-22	14	[{"id_menu":2,"count":1}]	26144	delivery	5	19
66244	2020-05-22 07:48:42	2020-05-22	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	10759	delivery	5	34
66245	2020-05-22 07:56:17	2020-05-22	17	[{"id_menu":4,"count":1}]	5640	delivery	5	22
66246	2020-05-22 07:58:58	2020-05-22	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	17861	pick-up	0	20
66247	2020-05-22 08:01:33	2020-05-22	9	[{"id_menu":7,"count":1}]	26323	delivery	5	14
66248	2020-05-22 08:03:09	2020-05-22	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	10507	delivery	5	26
66249	2020-05-22 08:07:15	2020-05-22	9	[{"id_menu":7,"count":1}]	22987	pick-up	0	9
66250	2020-05-22 08:10:28	2020-05-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	5293	delivery	5	36
66251	2020-05-22 08:16:39	2020-05-22	9	[{"id_menu":6,"count":1}]	8651	delivery	5	14
66252	2020-05-22 08:31:17	2020-05-22	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	19307	delivery	5	31
66253	2020-05-22 08:33:10	2020-05-22	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	20426	delivery	5	31
66254	2020-05-22 08:33:25	2020-05-22	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6600	delivery	5	30
66255	2020-05-22 08:34:01	2020-05-22	8	[{"id_menu":5,"count":1}]	770	pick-up	0	8
66256	2020-05-22 08:36:21	2020-05-22	12	[{"id_menu":3,"count":1}]	21974	delivery	5	17
66257	2020-05-22 08:48:08	2020-05-22	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15597	delivery	5	22
66258	2020-05-22 08:51:24	2020-05-22	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15829	delivery	5	31
66259	2020-05-22 08:52:07	2020-05-22	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	26162	delivery	5	26
66260	2020-05-22 08:59:44	2020-05-22	9	[{"id_menu":6,"count":1}]	4060	delivery	5	14
66261	2020-05-22 09:04:59	2020-05-22	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10484	delivery	5	48
66262	2020-05-22 09:07:41	2020-05-22	12	[{"id_menu":1,"count":1}]	506	pick-up	0	12
66263	2020-05-22 09:09:54	2020-05-22	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1919	pick-up	0	21
66264	2020-05-22 09:10:17	2020-05-22	9	[{"id_menu":6,"count":1}]	11342	delivery	5	14
66265	2020-05-22 09:12:56	2020-05-22	14	[{"id_menu":2,"count":1}]	20767	delivery	5	19
66266	2020-05-22 09:13:55	2020-05-22	8	[{"id_menu":5,"count":1}]	26180	delivery	5	13
66267	2020-05-22 09:19:38	2020-05-22	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	11311	delivery	5	23
66268	2020-05-22 09:20:36	2020-05-22	9	[{"id_menu":6,"count":1}]	4574	delivery	5	14
66269	2020-05-22 09:25:04	2020-05-22	17	[{"id_menu":4,"count":1}]	19601	pick-up	0	17
66270	2020-05-22 09:27:04	2020-05-22	9	[{"id_menu":7,"count":1}]	8900	delivery	5	14
66271	2020-05-22 09:28:43	2020-05-22	8	[{"id_menu":5,"count":1}]	26260	delivery	5	13
66272	2020-05-22 09:29:15	2020-05-22	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	22756	delivery	5	23
66273	2020-05-22 09:30:22	2020-05-22	8	[{"id_menu":5,"count":1}]	20895	delivery	5	13
66274	2020-05-22 09:36:47	2020-05-22	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	25397	delivery	5	26
66275	2020-05-22 09:43:12	2020-05-22	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	24872	delivery	5	27
66276	2020-05-22 09:47:04	2020-05-22	12	[{"id_menu":1,"count":1}]	19313	pick-up	0	12
66277	2020-05-22 09:51:07	2020-05-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	13767	delivery	5	36
66278	2020-05-22 10:04:35	2020-05-22	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3263	pick-up	0	26
66279	2020-05-22 10:20:35	2020-05-22	9	[{"id_menu":7,"count":1}]	26197	delivery	5	14
66280	2020-05-22 10:21:00	2020-05-22	14	[{"id_menu":2,"count":1}]	26191	delivery	5	19
66281	2020-05-22 10:21:05	2020-05-22	17	[{"id_menu":4,"count":1}]	1922	pick-up	0	17
66282	2020-05-22 10:25:19	2020-05-22	8	[{"id_menu":5,"count":1}]	17722	delivery	5	13
66283	2020-05-22 10:27:41	2020-05-22	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	26310	delivery	5	27
66284	2020-05-22 10:29:20	2020-05-22	9	[{"id_menu":6,"count":1}]	15593	delivery	5	14
66285	2020-05-22 10:34:15	2020-05-22	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14479	delivery	5	36
66286	2020-05-22 10:34:18	2020-05-22	12	[{"id_menu":1,"count":1}]	14234	delivery	5	17
66287	2020-05-22 10:34:50	2020-05-22	9	[{"id_menu":6,"count":1}]	5525	delivery	5	14
66288	2020-05-22 10:37:26	2020-05-22	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12462	delivery	5	57
66289	2020-05-22 10:39:53	2020-05-22	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5322	delivery	5	45
66290	2020-05-22 10:41:51	2020-05-22	17	[{"id_menu":4,"count":1}]	397	delivery	5	22
66291	2020-05-22 10:42:07	2020-05-22	9	[{"id_menu":6,"count":1}]	26155	delivery	5	14
66292	2020-05-22 10:42:35	2020-05-22	9	[{"id_menu":6,"count":1}]	8748	pick-up	0	9
66293	2020-05-22 10:42:51	2020-05-22	14	[{"id_menu":2,"count":1}]	17351	delivery	5	19
66294	2020-05-22 10:48:29	2020-05-22	12	[{"id_menu":3,"count":1}]	1455	pick-up	0	12
66295	2020-05-22 10:49:20	2020-05-22	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	24789	delivery	5	57
66296	2020-05-22 10:55:00	2020-05-22	12	[{"id_menu":1,"count":2}]	2140	pick-up	0	12
66297	2020-05-22 11:01:14	2020-05-22	14	[{"id_menu":2,"count":1}]	26250	delivery	5	19
66298	2020-05-22 11:03:15	2020-05-22	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	26187	delivery	5	40
66299	2020-05-22 11:03:32	2020-05-22	38	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	25714	delivery	5	43
66300	2020-05-22 11:06:54	2020-05-22	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	26237	delivery	5	30
66301	2020-05-22 11:07:47	2020-05-22	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	26294	delivery	5	34
66302	2020-05-22 11:09:00	2020-05-22	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	21383	delivery	5	40
66303	2020-05-22 11:09:35	2020-05-22	14	[{"id_menu":2,"count":1}]	12502	pick-up	0	14
66304	2020-05-22 11:09:56	2020-05-22	9	[{"id_menu":6,"count":1}]	26161	delivery	5	14
66305	2020-05-22 11:14:23	2020-05-22	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2197	pick-up	0	29
66306	2020-05-22 11:14:23	2020-05-22	17	[{"id_menu":4,"count":1}]	15672	delivery	5	22
66307	2020-05-22 11:19:41	2020-05-22	12	[{"id_menu":1,"count":1}]	2000	pick-up	0	12
66308	2020-05-22 11:32:20	2020-05-22	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11174	delivery	5	53
66309	2020-05-22 11:33:06	2020-05-22	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26179	delivery	5	31
66310	2020-05-22 11:35:44	2020-05-22	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	688	pick-up	0	21
66311	2020-05-22 11:43:09	2020-05-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18306	delivery	5	23
66312	2020-05-22 11:52:44	2020-05-22	9	[{"id_menu":7,"count":1}]	19172	delivery	5	14
66313	2020-05-22 11:57:17	2020-05-22	8	[{"id_menu":5,"count":2}]	2633	pick-up	0	8
66314	2020-05-22 11:58:29	2020-05-22	12	[{"id_menu":3,"count":1}]	26262	pick-up	0	12
66315	2020-05-22 11:58:43	2020-05-22	9	[{"id_menu":7,"count":2}]	24775	delivery	5	14
66316	2020-05-22 11:59:35	2020-05-22	9	[{"id_menu":7,"count":2}]	2735	delivery	5	14
66317	2020-05-22 12:00:50	2020-05-22	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23928	delivery	5	36
66318	2020-05-22 12:00:54	2020-05-22	9	[{"id_menu":6,"count":1}]	8300	pick-up	0	9
66319	2020-05-22 12:01:21	2020-05-22	14	[{"id_menu":2,"count":1}]	26288	delivery	5	19
66320	2020-05-22 12:04:24	2020-05-22	8	[{"id_menu":5,"count":1}]	2737	pick-up	0	8
66321	2020-05-22 12:11:30	2020-05-22	14	[{"id_menu":2,"count":1}]	8273	delivery	5	19
66322	2020-05-22 12:16:18	2020-05-22	14	[{"id_menu":2,"count":1}]	18461	delivery	5	19
66323	2020-05-22 12:20:26	2020-05-22	17	[{"id_menu":4,"count":1}]	12268	delivery	5	22
66324	2020-05-22 12:20:41	2020-05-22	17	[{"id_menu":4,"count":1}]	1443	delivery	5	22
66325	2020-05-22 12:25:51	2020-05-22	9	[{"id_menu":6,"count":1}]	26304	delivery	5	14
66326	2020-05-22 12:28:21	2020-05-22	12	[{"id_menu":1,"count":1}]	26210	delivery	5	17
66327	2020-05-22 12:28:54	2020-05-22	12	[{"id_menu":1,"count":1}]	21599	delivery	5	17
66328	2020-05-22 12:41:33	2020-05-22	9	[{"id_menu":6,"count":1}]	26204	delivery	5	14
66329	2020-05-22 12:43:32	2020-05-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24629	delivery	5	22
66330	2020-05-22 12:50:29	2020-05-22	8	[{"id_menu":5,"count":1}]	3688	delivery	5	13
66331	2020-05-22 12:50:32	2020-05-22	12	[{"id_menu":3,"count":1}]	26130	pick-up	0	12
66332	2020-05-22 12:55:57	2020-05-22	8	[{"id_menu":5,"count":1}]	5337	delivery	5	13
66333	2020-05-22 13:02:31	2020-05-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4983	delivery	5	23
66334	2020-05-22 13:02:55	2020-05-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	842	pick-up	0	17
66335	2020-05-22 13:06:03	2020-05-22	8	[{"id_menu":5,"count":1}]	584	pick-up	0	8
66336	2020-05-22 13:09:18	2020-05-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	10935	pick-up	0	23
66337	2020-05-22 13:09:33	2020-05-22	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	25270	delivery	5	27
66338	2020-05-22 13:09:33	2020-05-22	14	[{"id_menu":2,"count":1}]	26280	delivery	5	19
66339	2020-05-22 13:10:43	2020-05-22	12	[{"id_menu":1,"count":1}]	23988	delivery	5	17
66340	2020-05-22 13:13:49	2020-05-22	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23207	delivery	5	49
66341	2020-05-22 13:18:17	2020-05-22	12	[{"id_menu":1,"count":1}]	26193	delivery	5	17
66342	2020-05-22 13:21:39	2020-05-22	9	[{"id_menu":6,"count":2}]	26329	delivery	5	14
66343	2020-05-22 13:22:01	2020-05-22	17	[{"id_menu":4,"count":1}]	15368	delivery	5	22
66344	2020-05-22 13:23:37	2020-05-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	26293	delivery	5	28
66345	2020-05-22 13:23:46	2020-05-22	9	[{"id_menu":6,"count":1}]	25589	delivery	5	14
66346	2020-05-22 13:23:50	2020-05-22	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	15730	delivery	5	25
66347	2020-05-22 13:25:35	2020-05-22	9	[{"id_menu":6,"count":1}]	26170	delivery	5	14
66348	2020-05-22 13:28:15	2020-05-22	8	[{"id_menu":5,"count":2}]	17769	delivery	5	13
66349	2020-05-22 13:29:35	2020-05-22	8	[{"id_menu":5,"count":1}]	26308	delivery	5	13
66350	2020-05-22 13:37:19	2020-05-22	9	[{"id_menu":6,"count":2}]	26176	delivery	5	14
66351	2020-05-22 13:37:55	2020-05-22	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	17652	delivery	5	52
66352	2020-05-22 13:39:07	2020-05-22	17	[{"id_menu":4,"count":1}]	4102	delivery	5	22
66353	2020-05-22 13:40:05	2020-05-22	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	24600	delivery	5	38
66354	2020-05-22 13:40:29	2020-05-22	12	[{"id_menu":3,"count":1}]	20565	delivery	5	17
66355	2020-05-22 13:46:35	2020-05-22	14	[{"id_menu":2,"count":1}]	2602	pick-up	0	14
66356	2020-05-22 13:48:24	2020-05-22	8	[{"id_menu":5,"count":1}]	9846	delivery	5	13
66357	2020-05-22 13:50:06	2020-05-22	9	[{"id_menu":7,"count":2}]	604	delivery	5	14
66358	2020-05-22 13:53:44	2020-05-22	9	[{"id_menu":7,"count":1}]	24548	delivery	5	14
66359	2020-05-22 13:59:59	2020-05-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9135	delivery	5	23
66360	2020-05-22 14:00:48	2020-05-22	12	[{"id_menu":3,"count":1}]	26248	delivery	5	17
66361	2020-05-22 14:08:10	2020-05-22	8	[{"id_menu":5,"count":1}]	26200	delivery	5	13
66362	2020-05-22 14:11:13	2020-05-22	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	5302	delivery	5	25
66363	2020-05-22 14:13:03	2020-05-22	9	[{"id_menu":6,"count":1}]	5642	pick-up	0	9
66364	2020-05-22 14:19:29	2020-05-22	12	[{"id_menu":1,"count":1}]	7125	delivery	5	17
66365	2020-05-22 14:25:58	2020-05-22	9	[{"id_menu":7,"count":1}]	19552	delivery	5	14
66366	2020-05-22 14:26:45	2020-05-22	14	[{"id_menu":2,"count":1}]	13890	delivery	5	19
66367	2020-05-22 14:33:38	2020-05-22	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	26147	delivery	5	51
66368	2020-05-22 14:34:20	2020-05-22	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11540	delivery	5	36
66369	2020-05-22 14:36:49	2020-05-22	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11136	delivery	5	31
66370	2020-05-22 14:37:59	2020-05-22	9	[{"id_menu":7,"count":1}]	26253	pick-up	0	9
66371	2020-05-22 14:39:15	2020-05-22	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	3265	pick-up	0	21
66372	2020-05-22 14:39:20	2020-05-22	17	[{"id_menu":4,"count":2}]	20505	delivery	5	22
66373	2020-05-22 14:39:56	2020-05-22	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	22068	delivery	5	31
66374	2020-05-22 14:40:00	2020-05-22	12	[{"id_menu":1,"count":1}]	2392	pick-up	0	12
66375	2020-05-22 14:40:13	2020-05-22	8	[{"id_menu":5,"count":1}]	8992	delivery	5	13
66376	2020-05-22 14:40:14	2020-05-22	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	9021	delivery	5	26
66377	2020-05-22 14:41:19	2020-05-22	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	8382	delivery	5	43
66378	2020-05-22 14:42:30	2020-05-22	17	[{"id_menu":4,"count":1}]	26325	delivery	5	22
66379	2020-05-22 14:49:06	2020-05-22	9	[{"id_menu":6,"count":1}]	21274	pick-up	0	9
66380	2020-05-22 14:50:38	2020-05-22	8	[{"id_menu":5,"count":1}]	20304	pick-up	0	8
66381	2020-05-22 14:53:25	2020-05-22	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11860	delivery	5	31
66382	2020-05-22 14:54:56	2020-05-22	12	[{"id_menu":1,"count":1}]	26172	delivery	5	17
66383	2020-05-22 14:55:16	2020-05-22	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	26160	delivery	5	27
66384	2020-05-22 15:03:19	2020-05-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26154	delivery	5	23
66385	2020-05-22 15:03:32	2020-05-22	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	26224	delivery	5	22
66386	2020-05-22 15:03:37	2020-05-22	9	[{"id_menu":6,"count":1}]	13827	delivery	5	14
66387	2020-05-22 15:09:48	2020-05-22	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	4836	delivery	5	34
66388	2020-05-22 15:10:19	2020-05-22	17	[{"id_menu":4,"count":1}]	23461	pick-up	0	17
66389	2020-05-22 15:12:06	2020-05-22	9	[{"id_menu":7,"count":1}]	26220	delivery	5	14
66390	2020-05-22 15:15:22	2020-05-22	9	[{"id_menu":7,"count":1}]	10485	delivery	5	14
66391	2020-05-22 15:16:15	2020-05-22	12	[{"id_menu":1,"count":1}]	17470	pick-up	0	12
66392	2020-05-22 15:18:43	2020-05-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8763	delivery	5	22
66393	2020-05-22 15:22:43	2020-05-22	12	[{"id_menu":1,"count":1}]	24706	delivery	5	17
66394	2020-05-22 15:35:38	2020-05-22	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19493	delivery	5	35
66395	2020-05-22 15:40:23	2020-05-22	9	[{"id_menu":7,"count":1}]	12938	delivery	5	14
66396	2020-05-22 15:40:37	2020-05-22	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	26229	delivery	5	43
66397	2020-05-22 15:44:14	2020-05-22	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	9733	delivery	5	35
66398	2020-05-22 15:47:47	2020-05-22	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	26274	delivery	5	31
66399	2020-05-22 15:52:20	2020-05-22	12	[{"id_menu":1,"count":1}]	2993	pick-up	0	12
66400	2020-05-22 15:55:30	2020-05-22	14	[{"id_menu":2,"count":2}]	9580	delivery	5	19
66401	2020-05-22 16:00:26	2020-05-22	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	26146	delivery	5	31
66402	2020-05-22 16:06:20	2020-05-22	8	[{"id_menu":5,"count":1}]	26203	delivery	5	13
66403	2020-05-22 16:07:22	2020-05-22	8	[{"id_menu":5,"count":1}]	26291	delivery	5	13
66404	2020-05-22 16:13:31	2020-05-22	17	[{"id_menu":4,"count":1}]	3102	pick-up	0	17
66405	2020-05-22 16:14:27	2020-05-22	8	[{"id_menu":5,"count":1}]	20122	delivery	5	13
66406	2020-05-22 16:15:21	2020-05-22	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	997	delivery	5	31
66407	2020-05-22 16:18:14	2020-05-22	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	25997	pick-up	0	26
66408	2020-05-22 16:18:49	2020-05-22	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	26194	delivery	5	34
66409	2020-05-22 16:20:34	2020-05-22	12	[{"id_menu":1,"count":1}]	26188	delivery	5	17
66410	2020-05-22 16:21:11	2020-05-22	9	[{"id_menu":6,"count":1}]	26290	delivery	5	14
66411	2020-05-22 16:23:09	2020-05-22	14	[{"id_menu":2,"count":1}]	25907	pick-up	0	14
66412	2020-05-22 16:29:23	2020-05-22	8	[{"id_menu":5,"count":1}]	16831	delivery	5	13
66413	2020-05-22 16:30:42	2020-05-22	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	2317	pick-up	0	26
66414	2020-05-22 16:32:29	2020-05-22	9	[{"id_menu":7,"count":1}]	13155	pick-up	0	9
66415	2020-05-22 16:33:20	2020-05-22	9	[{"id_menu":6,"count":1}]	81	delivery	5	14
66416	2020-05-22 16:36:29	2020-05-22	9	[{"id_menu":7,"count":1}]	26298	pick-up	0	9
66417	2020-05-22 16:36:36	2020-05-22	9	[{"id_menu":6,"count":1}]	26328	delivery	5	14
66418	2020-05-22 16:41:28	2020-05-22	12	[{"id_menu":3,"count":1}]	2653	pick-up	0	12
66419	2020-05-22 16:44:35	2020-05-22	8	[{"id_menu":5,"count":1}]	26279	delivery	5	13
66420	2020-05-22 16:46:17	2020-05-22	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	11454	pick-up	0	24
66421	2020-05-22 16:58:50	2020-05-22	9	[{"id_menu":7,"count":1}]	16652	delivery	5	14
66422	2020-05-22 17:11:59	2020-05-22	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12481	delivery	5	34
66423	2020-05-22 17:15:24	2020-05-22	14	[{"id_menu":2,"count":1}]	9662	delivery	5	19
66424	2020-05-22 17:30:38	2020-05-22	9	[{"id_menu":6,"count":1}]	17046	pick-up	0	9
66425	2020-05-22 17:35:45	2020-05-22	12	[{"id_menu":3,"count":1}]	12129	pick-up	0	12
66426	2020-05-22 17:37:27	2020-05-22	14	[{"id_menu":2,"count":1}]	26285	delivery	5	19
66427	2020-05-22 17:40:18	2020-05-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	26269	delivery	5	22
66428	2020-05-22 17:44:57	2020-05-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	8192	pick-up	0	23
66429	2020-05-22 17:45:09	2020-05-22	17	[{"id_menu":4,"count":1}]	26206	delivery	5	22
66430	2020-05-22 17:46:25	2020-05-22	17	[{"id_menu":4,"count":2}]	5986	delivery	5	22
66431	2020-05-22 17:47:09	2020-05-22	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	12011	pick-up	0	21
66432	2020-05-22 17:59:31	2020-05-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7675	delivery	5	28
66433	2020-05-22 18:00:35	2020-05-22	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	23621	delivery	5	31
66434	2020-05-22 18:02:12	2020-05-22	8	[{"id_menu":5,"count":1}]	15470	delivery	5	13
66435	2020-05-22 18:06:07	2020-05-22	17	[{"id_menu":4,"count":2}]	26299	delivery	5	22
66436	2020-05-22 18:11:03	2020-05-22	12	[{"id_menu":1,"count":1}]	6596	delivery	5	17
66437	2020-05-22 18:12:52	2020-05-22	17	[{"id_menu":4,"count":1}]	26177	pick-up	0	17
66438	2020-05-22 18:13:42	2020-05-22	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10258	pick-up	0	17
66439	2020-05-22 18:15:27	2020-05-22	9	[{"id_menu":6,"count":1}]	16643	delivery	5	14
66440	2020-05-22 18:16:46	2020-05-22	14	[{"id_menu":2,"count":1}]	13638	delivery	5	19
66441	2020-05-22 18:19:25	2020-05-22	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	8546	pick-up	0	24
66442	2020-05-22 18:19:27	2020-05-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	25296	pick-up	0	23
66443	2020-05-22 18:24:47	2020-05-22	9	[{"id_menu":7,"count":1}]	6956	delivery	5	14
66444	2020-05-22 18:40:24	2020-05-22	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	2906	delivery	5	34
66445	2020-05-22 18:45:20	2020-05-22	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	22299	delivery	5	36
66446	2020-05-22 18:46:58	2020-05-22	8	[{"id_menu":5,"count":1}]	26286	delivery	5	13
66447	2020-05-22 19:00:21	2020-05-22	12	[{"id_menu":3,"count":1}]	3595	pick-up	0	12
66448	2020-05-22 19:03:31	2020-05-22	14	[{"id_menu":2,"count":1}]	23760	pick-up	0	14
66449	2020-05-22 19:07:40	2020-05-22	17	[{"id_menu":4,"count":1}]	1541	delivery	5	22
66450	2020-05-22 19:12:09	2020-05-22	12	[{"id_menu":1,"count":1}]	1628	pick-up	0	12
66451	2020-05-22 19:14:32	2020-05-22	12	[{"id_menu":1,"count":1}]	6560	pick-up	0	12
66452	2020-05-22 19:15:48	2020-05-22	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1202	delivery	5	34
66453	2020-05-22 19:16:17	2020-05-22	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5466	pick-up	0	38
66454	2020-05-22 19:23:24	2020-05-22	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	26174	delivery	5	31
66455	2020-05-22 19:26:42	2020-05-22	9	[{"id_menu":6,"count":1}]	26227	delivery	5	14
66456	2020-05-22 19:31:14	2020-05-22	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	18348	delivery	5	30
66457	2020-05-22 19:35:04	2020-05-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	20495	delivery	5	23
66458	2020-05-22 19:35:25	2020-05-22	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	25308	delivery	5	25
66459	2020-05-22 19:36:53	2020-05-22	9	[{"id_menu":6,"count":1}]	26145	delivery	5	14
66460	2020-05-22 19:37:17	2020-05-22	9	[{"id_menu":7,"count":1}]	9011	delivery	5	14
66461	2020-05-22 19:40:48	2020-05-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26305	delivery	5	23
66462	2020-05-22 19:44:10	2020-05-22	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24619	delivery	5	34
66463	2020-05-22 19:44:55	2020-05-22	12	[{"id_menu":1,"count":1}]	5950	delivery	5	17
66464	2020-05-22 19:45:40	2020-05-22	12	[{"id_menu":3,"count":1}]	26173	delivery	5	17
66465	2020-05-22 19:45:56	2020-05-22	17	[{"id_menu":4,"count":1}]	1934	pick-up	0	17
66466	2020-05-22 19:50:46	2020-05-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8639	delivery	5	28
66467	2020-05-22 19:59:53	2020-05-22	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9358	delivery	5	42
66468	2020-05-22 19:59:57	2020-05-22	14	[{"id_menu":2,"count":1}]	11465	delivery	5	19
66469	2020-05-22 20:08:21	2020-05-22	14	[{"id_menu":2,"count":1}]	26258	delivery	5	19
66470	2020-05-22 20:10:10	2020-05-22	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":2}]	18843	delivery	5	26
66471	2020-05-22 20:11:01	2020-05-22	9	[{"id_menu":6,"count":1}]	26226	delivery	5	14
66472	2020-05-22 20:11:02	2020-05-22	30	[{"id_menu":1,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16018	delivery	5	35
66473	2020-05-22 20:13:42	2020-05-22	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	13960	delivery	5	37
66474	2020-05-22 20:15:54	2020-05-22	17	[{"id_menu":4,"count":2}]	621	delivery	5	22
66475	2020-05-22 20:16:21	2020-05-22	9	[{"id_menu":6,"count":1}]	26232	pick-up	0	9
66476	2020-05-22 20:17:40	2020-05-22	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	3004	delivery	5	29
66477	2020-05-22 20:18:42	2020-05-22	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21280	delivery	5	35
66478	2020-05-22 20:23:55	2020-05-22	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	9191	pick-up	0	21
66479	2020-05-22 20:29:00	2020-05-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	16703	delivery	5	36
66480	2020-05-22 20:29:18	2020-05-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	24975	delivery	5	28
66481	2020-05-22 20:29:38	2020-05-22	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	26181	delivery	5	43
66482	2020-05-22 20:31:22	2020-05-22	12	[{"id_menu":3,"count":1}]	21091	delivery	5	17
66483	2020-05-22 20:34:32	2020-05-22	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	4201	delivery	5	22
66484	2020-05-22 20:37:49	2020-05-22	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	19945	delivery	5	26
66485	2020-05-22 20:41:34	2020-05-22	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	11442	delivery	5	30
66486	2020-05-22 20:51:46	2020-05-22	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	6489	delivery	5	26
66487	2020-05-22 20:54:08	2020-05-22	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	26306	delivery	5	40
66488	2020-05-22 20:54:27	2020-05-22	8	[{"id_menu":5,"count":1}]	24059	delivery	5	13
66489	2020-05-22 20:57:49	2020-05-22	9	[{"id_menu":6,"count":1}]	26315	pick-up	0	9
66490	2020-05-22 20:58:05	2020-05-22	8	[{"id_menu":5,"count":1}]	26257	delivery	5	13
66491	2020-05-22 21:04:47	2020-05-22	9	[{"id_menu":6,"count":1}]	26281	delivery	5	14
66492	2020-05-22 21:07:28	2020-05-22	8	[{"id_menu":5,"count":1}]	26283	delivery	5	13
66493	2020-05-22 21:09:00	2020-05-22	9	[{"id_menu":6,"count":1}]	24825	delivery	5	14
66494	2020-05-22 21:11:00	2020-05-22	8	[{"id_menu":5,"count":1}]	10567	delivery	5	13
66495	2020-05-22 21:11:26	2020-05-22	14	[{"id_menu":2,"count":2}]	8955	delivery	5	19
66496	2020-05-22 21:12:24	2020-05-22	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	26326	pick-up	0	24
66497	2020-05-22 21:22:55	2020-05-22	14	[{"id_menu":2,"count":1}]	26309	delivery	5	19
66498	2020-05-22 21:24:41	2020-05-22	12	[{"id_menu":3,"count":1}]	26209	pick-up	0	12
66499	2020-05-22 21:30:24	2020-05-22	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	26292	delivery	5	31
66500	2020-05-22 21:32:02	2020-05-22	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4953	delivery	5	39
66501	2020-05-22 21:41:33	2020-05-22	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	10461	delivery	5	26
66502	2020-05-22 21:41:38	2020-05-22	14	[{"id_menu":2,"count":1}]	4702	delivery	5	19
66503	2020-05-22 21:45:58	2020-05-22	9	[{"id_menu":7,"count":1}]	9017	pick-up	0	9
66504	2020-05-22 21:47:20	2020-05-22	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	24602	delivery	5	48
66505	2020-05-22 21:51:22	2020-05-22	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	26190	delivery	5	26
66506	2020-05-22 21:51:51	2020-05-22	12	[{"id_menu":1,"count":1}]	18374	delivery	5	17
66507	2020-05-22 22:03:36	2020-05-22	14	[{"id_menu":2,"count":1}]	231	delivery	5	19
66508	2020-05-22 22:06:54	2020-05-22	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	26271	pick-up	0	26
66509	2020-05-22 22:08:47	2020-05-22	9	[{"id_menu":6,"count":1}]	26185	delivery	5	14
66510	2020-05-22 22:19:16	2020-05-22	17	[{"id_menu":4,"count":1}]	9740	delivery	5	22
66511	2020-05-22 22:20:11	2020-05-22	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	26264	pick-up	0	21
66512	2020-05-22 22:22:22	2020-05-22	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	26151	delivery	5	46
66513	2020-05-22 22:23:40	2020-05-22	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	26157	delivery	5	34
66514	2020-05-22 22:24:20	2020-05-22	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3853	delivery	5	48
66515	2020-05-22 22:32:32	2020-05-22	12	[{"id_menu":3,"count":1}]	21767	delivery	5	17
66516	2020-05-22 22:34:20	2020-05-22	8	[{"id_menu":5,"count":1}]	12388	pick-up	0	8
66517	2020-05-22 22:34:27	2020-05-22	17	[{"id_menu":4,"count":1}]	6152	delivery	5	22
66518	2020-05-22 22:34:36	2020-05-22	9	[{"id_menu":7,"count":1}]	8427	delivery	5	14
66519	2020-05-22 22:35:42	2020-05-22	9	[{"id_menu":7,"count":1}]	26163	delivery	5	14
66520	2020-05-22 22:36:23	2020-05-22	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	5568	delivery	5	34
66521	2020-05-22 22:45:46	2020-05-22	12	[{"id_menu":1,"count":1}]	21308	pick-up	0	12
66522	2020-05-22 22:52:53	2020-05-22	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6760	delivery	5	30
66523	2020-05-22 22:56:01	2020-05-22	12	[{"id_menu":3,"count":1}]	20339	delivery	5	17
66524	2020-05-22 22:57:56	2020-05-22	17	[{"id_menu":4,"count":1}]	26222	pick-up	0	17
66525	2020-05-22 22:57:59	2020-05-22	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	19212	pick-up	0	21
66526	2020-05-22 23:05:52	2020-05-22	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	26277	delivery	5	27
66527	2020-05-22 23:05:55	2020-05-22	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	4929	pick-up	0	24
66528	2020-05-22 23:17:43	2020-05-22	9	[{"id_menu":6,"count":1}]	26261	delivery	5	14
66529	2020-05-22 23:17:58	2020-05-22	12	[{"id_menu":3,"count":1}]	8655	delivery	5	17
66530	2020-05-22 23:18:04	2020-05-22	17	[{"id_menu":4,"count":1}]	15082	pick-up	0	17
66531	2020-05-22 23:20:52	2020-05-22	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	26223	delivery	5	31
66532	2020-05-22 23:21:13	2020-05-22	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	5380	delivery	5	29
66533	2020-05-22 23:21:31	2020-05-22	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	18602	delivery	5	26
66534	2020-05-22 23:27:21	2020-05-22	14	[{"id_menu":2,"count":1}]	3340	delivery	5	19
66535	2020-05-22 23:34:02	2020-05-22	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	21867	delivery	5	26
66536	2020-05-22 23:35:58	2020-05-22	8	[{"id_menu":5,"count":1}]	14190	pick-up	0	8
66537	2020-05-22 23:44:41	2020-05-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":3}]	6919	delivery	5	22
66538	2020-05-22 23:45:17	2020-05-22	9	[{"id_menu":6,"count":1}]	26148	delivery	5	14
66539	2020-05-22 23:49:31	2020-05-22	9	[{"id_menu":7,"count":1}]	7490	delivery	5	14
66540	2020-05-22 23:52:29	2020-05-22	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6820	delivery	5	36
66541	2020-05-22 23:59:05	2020-05-22	9	[{"id_menu":7,"count":1}]	26201	delivery	5	14
66542	2020-05-23 00:01:06	2020-05-23	8	[{"id_menu":5,"count":1}]	26400	delivery	5	13
66543	2020-05-23 00:03:21	2020-05-23	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	14682	delivery	5	23
66544	2020-05-23 00:05:23	2020-05-23	17	[{"id_menu":4,"count":1}]	6385	pick-up	0	17
66545	2020-05-23 00:06:02	2020-05-23	9	[{"id_menu":7,"count":1}]	26356	delivery	5	14
66546	2020-05-23 00:10:09	2020-05-23	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	8404	delivery	5	31
66547	2020-05-23 00:12:12	2020-05-23	12	[{"id_menu":1,"count":1}]	456	pick-up	0	12
66548	2020-05-23 00:16:53	2020-05-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14739	delivery	5	22
66549	2020-05-23 00:18:32	2020-05-23	9	[{"id_menu":6,"count":1}]	21341	delivery	5	14
66550	2020-05-23 00:18:42	2020-05-23	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	11296	delivery	5	28
66551	2020-05-23 00:19:13	2020-05-23	14	[{"id_menu":2,"count":1}]	18328	delivery	5	19
66552	2020-05-23 00:20:20	2020-05-23	12	[{"id_menu":3,"count":1}]	12361	delivery	5	17
66553	2020-05-23 00:21:39	2020-05-23	12	[{"id_menu":3,"count":1}]	10741	delivery	5	17
66554	2020-05-23 00:22:36	2020-05-23	17	[{"id_menu":4,"count":1}]	8481	delivery	5	22
66555	2020-05-23 00:24:00	2020-05-23	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	20965	delivery	5	43
66556	2020-05-23 00:30:17	2020-05-23	9	[{"id_menu":7,"count":1}]	11436	delivery	5	14
66557	2020-05-23 00:32:15	2020-05-23	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	26452	pick-up	0	24
66558	2020-05-23 00:38:37	2020-05-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	26549	delivery	5	28
66559	2020-05-23 00:40:33	2020-05-23	12	[{"id_menu":3,"count":1}]	26381	delivery	5	17
66560	2020-05-23 00:45:41	2020-05-23	9	[{"id_menu":6,"count":1}]	25313	delivery	5	14
66561	2020-05-23 00:45:43	2020-05-23	9	[{"id_menu":6,"count":1}]	26341	delivery	5	14
66562	2020-05-23 00:47:53	2020-05-23	12	[{"id_menu":1,"count":1}]	23979	pick-up	0	12
66563	2020-05-23 00:48:32	2020-05-23	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	10785	pick-up	0	33
66564	2020-05-23 00:50:19	2020-05-23	17	[{"id_menu":4,"count":1}]	24621	pick-up	0	17
66565	2020-05-23 00:50:20	2020-05-23	9	[{"id_menu":6,"count":1}]	23152	delivery	5	14
66566	2020-05-23 00:53:07	2020-05-23	9	[{"id_menu":6,"count":1}]	26507	delivery	5	14
66567	2020-05-23 00:53:27	2020-05-23	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	519	pick-up	0	21
66568	2020-05-23 00:55:39	2020-05-23	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25637	delivery	5	40
66569	2020-05-23 00:59:12	2020-05-23	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	25550	delivery	5	48
66570	2020-05-23 00:59:34	2020-05-23	9	[{"id_menu":7,"count":2}]	26371	delivery	5	14
66571	2020-05-23 01:02:48	2020-05-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	11268	delivery	5	26
66572	2020-05-23 01:07:47	2020-05-23	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	26407	delivery	5	51
66573	2020-05-23 01:11:29	2020-05-23	17	[{"id_menu":4,"count":1}]	972	delivery	5	22
66574	2020-05-23 01:12:22	2020-05-23	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15042	delivery	5	39
66575	2020-05-23 01:14:30	2020-05-23	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26330	delivery	5	52
66576	2020-05-23 01:17:21	2020-05-23	12	[{"id_menu":3,"count":1}]	18283	delivery	5	17
66577	2020-05-23 01:20:30	2020-05-23	17	[{"id_menu":4,"count":1}]	5004	delivery	5	22
66578	2020-05-23 01:22:35	2020-05-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17209	pick-up	0	26
66579	2020-05-23 01:24:17	2020-05-23	14	[{"id_menu":2,"count":1}]	26480	delivery	5	19
66580	2020-05-23 01:28:33	2020-05-23	17	[{"id_menu":4,"count":1}]	1280	delivery	5	22
66581	2020-05-23 01:28:57	2020-05-23	8	[{"id_menu":5,"count":1}]	17938	pick-up	0	8
66582	2020-05-23 01:29:47	2020-05-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	26101	delivery	5	28
66583	2020-05-23 01:31:52	2020-05-23	8	[{"id_menu":5,"count":1}]	23931	pick-up	0	8
66584	2020-05-23 01:37:38	2020-05-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7084	delivery	5	28
66585	2020-05-23 01:41:13	2020-05-23	14	[{"id_menu":2,"count":1}]	26453	delivery	5	19
66586	2020-05-23 01:42:03	2020-05-23	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	24788	delivery	5	52
66587	2020-05-23 01:47:42	2020-05-23	9	[{"id_menu":7,"count":1}]	22668	delivery	5	14
66588	2020-05-23 01:51:01	2020-05-23	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	12390	delivery	5	40
66589	2020-05-23 01:51:54	2020-05-23	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	26470	delivery	5	23
66590	2020-05-23 01:53:33	2020-05-23	9	[{"id_menu":7,"count":1}]	7566	delivery	5	14
66591	2020-05-23 01:54:37	2020-05-23	9	[{"id_menu":7,"count":1}]	26554	delivery	5	14
66592	2020-05-23 01:55:43	2020-05-23	8	[{"id_menu":5,"count":1}]	2123	pick-up	0	8
66593	2020-05-23 01:59:00	2020-05-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	5843	delivery	5	28
66594	2020-05-23 02:01:06	2020-05-23	14	[{"id_menu":2,"count":1}]	8407	pick-up	0	14
66595	2020-05-23 02:08:23	2020-05-23	8	[{"id_menu":5,"count":1}]	19291	delivery	5	13
66596	2020-05-23 02:11:14	2020-05-23	17	[{"id_menu":4,"count":1}]	22322	delivery	5	22
66597	2020-05-23 02:12:20	2020-05-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9894	delivery	5	22
66598	2020-05-23 02:12:24	2020-05-23	14	[{"id_menu":2,"count":1}]	15834	delivery	5	19
66599	2020-05-23 02:17:46	2020-05-23	8	[{"id_menu":5,"count":1}]	2311	delivery	5	13
66600	2020-05-23 02:18:08	2020-05-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	26523	delivery	5	31
66601	2020-05-23 02:18:27	2020-05-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	2153	pick-up	0	26
66602	2020-05-23 02:25:54	2020-05-23	12	[{"id_menu":1,"count":1}]	6567	delivery	5	17
66603	2020-05-23 02:27:23	2020-05-23	12	[{"id_menu":3,"count":1}]	26349	delivery	5	17
66604	2020-05-23 02:31:01	2020-05-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	10482	pick-up	0	26
66605	2020-05-23 02:33:27	2020-05-23	14	[{"id_menu":2,"count":1}]	26383	delivery	5	19
66606	2020-05-23 02:33:59	2020-05-23	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	26357	delivery	5	34
66607	2020-05-23 02:34:17	2020-05-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25718	delivery	5	22
66608	2020-05-23 02:35:14	2020-05-23	14	[{"id_menu":2,"count":1}]	20670	delivery	5	19
66609	2020-05-23 02:37:13	2020-05-23	12	[{"id_menu":1,"count":1}]	14025	delivery	5	17
66610	2020-05-23 02:37:41	2020-05-23	14	[{"id_menu":2,"count":1}]	20780	delivery	5	19
66611	2020-05-23 02:41:49	2020-05-23	8	[{"id_menu":5,"count":1}]	26443	delivery	5	13
66612	2020-05-23 02:43:12	2020-05-23	12	[{"id_menu":3,"count":1}]	877	delivery	5	17
66613	2020-05-23 02:45:27	2020-05-23	17	[{"id_menu":4,"count":1}]	26435	delivery	5	22
66614	2020-05-23 02:47:39	2020-05-23	9	[{"id_menu":6,"count":1}]	19268	pick-up	0	9
66615	2020-05-23 02:48:41	2020-05-23	8	[{"id_menu":5,"count":1}]	26337	delivery	5	13
66616	2020-05-23 02:51:59	2020-05-23	17	[{"id_menu":4,"count":1}]	11534	pick-up	0	17
66617	2020-05-23 02:55:40	2020-05-23	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	26414	delivery	5	22
66618	2020-05-23 02:57:35	2020-05-23	9	[{"id_menu":6,"count":1}]	26372	delivery	5	14
66619	2020-05-23 02:58:40	2020-05-23	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	9296	delivery	5	27
66620	2020-05-23 03:00:12	2020-05-23	17	[{"id_menu":4,"count":2}]	26491	delivery	5	22
66621	2020-05-23 03:01:51	2020-05-23	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	26459	pick-up	0	29
66622	2020-05-23 03:04:10	2020-05-23	12	[{"id_menu":1,"count":1}]	11779	pick-up	0	12
66623	2020-05-23 03:04:17	2020-05-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5144	pick-up	0	23
66624	2020-05-23 03:07:20	2020-05-23	14	[{"id_menu":2,"count":2}]	26404	delivery	5	19
66625	2020-05-23 03:09:10	2020-05-23	12	[{"id_menu":3,"count":1}]	1373	delivery	5	17
66626	2020-05-23 03:10:09	2020-05-23	9	[{"id_menu":7,"count":1}]	23835	delivery	5	14
66627	2020-05-23 03:11:27	2020-05-23	14	[{"id_menu":2,"count":1}]	5075	pick-up	0	14
66628	2020-05-23 03:11:47	2020-05-23	14	[{"id_menu":2,"count":1}]	23822	delivery	5	19
66629	2020-05-23 03:13:36	2020-05-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	26416	delivery	5	36
66630	2020-05-23 03:14:42	2020-05-23	8	[{"id_menu":5,"count":1}]	10467	delivery	5	13
66631	2020-05-23 03:17:51	2020-05-23	9	[{"id_menu":6,"count":1}]	26489	delivery	5	14
66632	2020-05-23 03:19:54	2020-05-23	9	[{"id_menu":7,"count":1}]	26421	delivery	5	14
66633	2020-05-23 03:21:26	2020-05-23	8	[{"id_menu":5,"count":1}]	3619	delivery	5	13
66634	2020-05-23 03:23:11	2020-05-23	9	[{"id_menu":7,"count":1}]	20749	delivery	5	14
66635	2020-05-23 03:25:20	2020-05-23	9	[{"id_menu":6,"count":1}]	6869	pick-up	0	9
66636	2020-05-23 03:25:58	2020-05-23	17	[{"id_menu":4,"count":2}]	10272	delivery	5	22
66637	2020-05-23 03:30:19	2020-05-23	14	[{"id_menu":2,"count":1}]	13865	delivery	5	19
66638	2020-05-23 03:32:18	2020-05-23	17	[{"id_menu":4,"count":1}]	13012	delivery	5	22
66639	2020-05-23 03:32:38	2020-05-23	17	[{"id_menu":4,"count":1}]	16434	pick-up	0	17
66640	2020-05-23 03:35:19	2020-05-23	12	[{"id_menu":3,"count":1}]	20117	delivery	5	17
66641	2020-05-23 03:40:50	2020-05-23	14	[{"id_menu":2,"count":1}]	6646	delivery	5	19
66642	2020-05-23 03:44:14	2020-05-23	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7912	delivery	5	53
66643	2020-05-23 03:48:30	2020-05-23	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	22934	delivery	5	26
66644	2020-05-23 03:49:34	2020-05-23	9	[{"id_menu":6,"count":1}]	25747	delivery	5	14
66645	2020-05-23 03:57:44	2020-05-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	14283	pick-up	0	23
66646	2020-05-23 04:00:38	2020-05-23	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26436	delivery	5	31
66647	2020-05-23 04:02:53	2020-05-23	9	[{"id_menu":7,"count":1}]	21975	delivery	5	14
66648	2020-05-23 04:05:32	2020-05-23	9	[{"id_menu":6,"count":1}]	26463	delivery	5	14
66649	2020-05-23 04:06:06	2020-05-23	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16404	delivery	5	37
66650	2020-05-23 04:06:44	2020-05-23	12	[{"id_menu":1,"count":1}]	26358	delivery	5	17
66651	2020-05-23 04:07:50	2020-05-23	8	[{"id_menu":5,"count":1}]	9315	delivery	5	13
66652	2020-05-23 04:07:59	2020-05-23	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	3000	pick-up	0	21
66653	2020-05-23 04:09:21	2020-05-23	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26369	delivery	5	40
66654	2020-05-23 04:09:58	2020-05-23	8	[{"id_menu":5,"count":1}]	13050	pick-up	0	8
66655	2020-05-23 04:12:05	2020-05-23	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	24792	delivery	5	40
66656	2020-05-23 04:14:04	2020-05-23	9	[{"id_menu":7,"count":1}]	26497	delivery	5	14
66657	2020-05-23 04:14:38	2020-05-23	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":3}]	26530	delivery	5	31
66658	2020-05-23 04:18:08	2020-05-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4356	pick-up	0	17
66659	2020-05-23 04:19:51	2020-05-23	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	26454	delivery	5	26
66660	2020-05-23 04:20:00	2020-05-23	9	[{"id_menu":7,"count":1}]	3125	delivery	5	14
66661	2020-05-23 04:22:29	2020-05-23	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	26485	delivery	5	23
66662	2020-05-23 04:25:27	2020-05-23	17	[{"id_menu":4,"count":1}]	26348	pick-up	0	17
66663	2020-05-23 04:25:59	2020-05-23	9	[{"id_menu":7,"count":1}]	26482	delivery	5	14
66664	2020-05-23 04:28:17	2020-05-23	8	[{"id_menu":5,"count":1}]	8702	delivery	5	13
66665	2020-05-23 04:28:43	2020-05-23	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5158	delivery	5	37
66666	2020-05-23 04:29:11	2020-05-23	12	[{"id_menu":1,"count":1}]	26546	delivery	5	17
66667	2020-05-23 04:29:45	2020-05-23	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	6880	delivery	5	26
66668	2020-05-23 04:32:58	2020-05-23	12	[{"id_menu":3,"count":1}]	18898	delivery	5	17
66669	2020-05-23 04:35:12	2020-05-23	9	[{"id_menu":6,"count":1}]	26367	pick-up	0	9
66670	2020-05-23 04:41:13	2020-05-23	12	[{"id_menu":3,"count":1}]	23450	delivery	5	17
66671	2020-05-23 04:42:34	2020-05-23	14	[{"id_menu":2,"count":1}]	1272	delivery	5	19
66672	2020-05-23 04:47:19	2020-05-23	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15122	delivery	5	49
66673	2020-05-23 04:50:50	2020-05-23	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	12412	delivery	5	37
66674	2020-05-23 04:56:19	2020-05-23	9	[{"id_menu":7,"count":1}]	1063	pick-up	0	9
66675	2020-05-23 04:57:36	2020-05-23	12	[{"id_menu":1,"count":1}]	26363	delivery	5	17
66676	2020-05-23 04:59:00	2020-05-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2012	pick-up	0	26
66677	2020-05-23 05:00:00	2020-05-23	12	[{"id_menu":3,"count":1}]	11104	delivery	5	17
66678	2020-05-23 05:05:35	2020-05-23	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	20469	delivery	5	40
66679	2020-05-23 05:09:02	2020-05-23	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	11869	delivery	5	26
66680	2020-05-23 05:10:27	2020-05-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18541	pick-up	0	17
66681	2020-05-23 05:11:46	2020-05-23	9	[{"id_menu":7,"count":1}]	11279	delivery	5	14
66682	2020-05-23 05:24:01	2020-05-23	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	12378	delivery	5	31
66683	2020-05-23 05:24:41	2020-05-23	8	[{"id_menu":5,"count":1}]	26352	delivery	5	13
66684	2020-05-23 05:26:00	2020-05-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	26537	delivery	5	31
66685	2020-05-23 05:26:31	2020-05-23	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	26321	delivery	5	26
66686	2020-05-23 05:28:08	2020-05-23	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7781	delivery	5	30
66687	2020-05-23 05:29:17	2020-05-23	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	19495	delivery	5	34
66688	2020-05-23 05:35:19	2020-05-23	8	[{"id_menu":5,"count":1}]	17341	delivery	5	13
66689	2020-05-23 05:36:53	2020-05-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	12823	delivery	5	28
66690	2020-05-23 05:37:30	2020-05-23	17	[{"id_menu":4,"count":1}]	494	pick-up	0	17
66691	2020-05-23 05:43:32	2020-05-23	9	[{"id_menu":6,"count":2}]	204	delivery	5	14
66692	2020-05-23 05:45:07	2020-05-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2564	pick-up	0	17
66693	2020-05-23 05:48:36	2020-05-23	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	26379	delivery	5	26
66694	2020-05-23 05:55:39	2020-05-23	12	[{"id_menu":1,"count":1}]	2508	pick-up	0	12
66695	2020-05-23 05:57:25	2020-05-23	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	13188	delivery	5	43
66696	2020-05-23 05:57:41	2020-05-23	9	[{"id_menu":6,"count":3}]	13725	delivery	5	14
66697	2020-05-23 05:57:45	2020-05-23	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	24058	delivery	5	43
66698	2020-05-23 05:58:14	2020-05-23	9	[{"id_menu":7,"count":1}]	3784	delivery	5	14
66699	2020-05-23 06:01:10	2020-05-23	14	[{"id_menu":2,"count":1}]	26396	delivery	5	19
66700	2020-05-23 06:03:50	2020-05-23	17	[{"id_menu":4,"count":1}]	5094	pick-up	0	17
66701	2020-05-23 06:09:22	2020-05-23	17	[{"id_menu":4,"count":1}]	9040	pick-up	0	17
66702	2020-05-23 06:13:28	2020-05-23	17	[{"id_menu":4,"count":1}]	5369	pick-up	0	17
66703	2020-05-23 06:16:30	2020-05-23	8	[{"id_menu":5,"count":1}]	26532	delivery	5	13
66704	2020-05-23 06:17:58	2020-05-23	9	[{"id_menu":7,"count":1}]	26411	delivery	5	14
66705	2020-05-23 06:20:47	2020-05-23	17	[{"id_menu":4,"count":1}]	26471	delivery	5	22
66706	2020-05-23 06:22:11	2020-05-23	12	[{"id_menu":3,"count":1}]	6901	pick-up	0	12
66707	2020-05-23 06:23:55	2020-05-23	9	[{"id_menu":7,"count":1}]	26434	pick-up	0	9
66708	2020-05-23 06:24:44	2020-05-23	14	[{"id_menu":2,"count":1}]	26398	delivery	5	19
66709	2020-05-23 06:34:48	2020-05-23	9	[{"id_menu":6,"count":1}]	5139	delivery	5	14
66710	2020-05-23 06:42:15	2020-05-23	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	15048	pick-up	0	25
66711	2020-05-23 06:46:47	2020-05-23	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	14140	delivery	5	40
66712	2020-05-23 06:50:05	2020-05-23	8	[{"id_menu":5,"count":1}]	7098	pick-up	0	8
66713	2020-05-23 06:53:20	2020-05-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	24870	pick-up	0	21
66714	2020-05-23 06:56:53	2020-05-23	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	26335	delivery	5	43
66715	2020-05-23 06:59:20	2020-05-23	12	[{"id_menu":1,"count":1}]	13639	pick-up	0	12
66716	2020-05-23 07:01:39	2020-05-23	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	21436	delivery	5	30
66717	2020-05-23 07:06:09	2020-05-23	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2627	pick-up	0	22
66718	2020-05-23 07:12:20	2020-05-23	8	[{"id_menu":5,"count":1}]	4148	delivery	5	13
66719	2020-05-23 07:13:36	2020-05-23	43	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1655	delivery	5	48
66720	2020-05-23 07:13:58	2020-05-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23507	delivery	5	22
66721	2020-05-23 07:18:28	2020-05-23	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	26444	delivery	5	22
66722	2020-05-23 07:21:42	2020-05-23	14	[{"id_menu":2,"count":1}]	26455	delivery	5	19
66723	2020-05-23 07:22:06	2020-05-23	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	26446	delivery	5	27
66724	2020-05-23 07:23:03	2020-05-23	12	[{"id_menu":3,"count":1}]	5138	pick-up	0	12
66725	2020-05-23 07:29:10	2020-05-23	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	26433	delivery	5	30
66726	2020-05-23 07:29:36	2020-05-23	9	[{"id_menu":7,"count":1}]	22819	delivery	5	14
66727	2020-05-23 07:33:38	2020-05-23	9	[{"id_menu":7,"count":1}]	24	pick-up	0	9
66728	2020-05-23 07:36:20	2020-05-23	8	[{"id_menu":5,"count":1}]	20267	delivery	5	13
66729	2020-05-23 07:36:35	2020-05-23	14	[{"id_menu":2,"count":1}]	701	delivery	5	19
66730	2020-05-23 07:38:39	2020-05-23	12	[{"id_menu":1,"count":2}]	11087	delivery	5	17
66731	2020-05-23 07:39:42	2020-05-23	12	[{"id_menu":3,"count":1}]	26360	delivery	5	17
66732	2020-05-23 07:41:33	2020-05-23	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7748	delivery	5	30
66733	2020-05-23 07:43:26	2020-05-23	9	[{"id_menu":7,"count":1}]	26462	delivery	5	14
66734	2020-05-23 07:43:32	2020-05-23	17	[{"id_menu":4,"count":1}]	11735	delivery	5	22
66735	2020-05-23 07:59:31	2020-05-23	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	5642	pick-up	0	24
66736	2020-05-23 08:01:37	2020-05-23	9	[{"id_menu":6,"count":1}]	18568	delivery	5	14
66737	2020-05-23 08:03:44	2020-05-23	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17268	delivery	5	53
66738	2020-05-23 08:03:44	2020-05-23	9	[{"id_menu":7,"count":1}]	26340	delivery	5	14
66739	2020-05-23 08:05:02	2020-05-23	17	[{"id_menu":4,"count":1}]	26522	delivery	5	22
66740	2020-05-23 08:05:25	2020-05-23	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1314	delivery	5	34
66741	2020-05-23 08:08:35	2020-05-23	8	[{"id_menu":5,"count":1}]	26539	delivery	5	13
66742	2020-05-23 08:09:41	2020-05-23	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	26441	delivery	5	42
66743	2020-05-23 08:15:46	2020-05-23	12	[{"id_menu":1,"count":1}]	26450	delivery	5	17
66744	2020-05-23 08:18:26	2020-05-23	12	[{"id_menu":1,"count":1}]	2429	pick-up	0	12
66745	2020-05-23 08:18:27	2020-05-23	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	6455	delivery	5	40
66746	2020-05-23 08:21:39	2020-05-23	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	26366	delivery	5	39
66747	2020-05-23 08:22:37	2020-05-23	9	[{"id_menu":7,"count":1}]	4060	delivery	5	14
66748	2020-05-23 08:24:51	2020-05-23	12	[{"id_menu":1,"count":1}]	2943	delivery	5	17
66749	2020-05-23 08:27:50	2020-05-23	17	[{"id_menu":4,"count":1}]	14938	delivery	5	22
66750	2020-05-23 08:32:11	2020-05-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	26542	pick-up	0	26
66751	2020-05-23 08:33:33	2020-05-23	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	26114	delivery	5	26
66752	2020-05-23 08:35:54	2020-05-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	424	pick-up	0	17
66753	2020-05-23 08:40:01	2020-05-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	26376	delivery	5	26
66754	2020-05-23 08:42:55	2020-05-23	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26412	delivery	5	40
66755	2020-05-23 08:47:15	2020-05-23	17	[{"id_menu":4,"count":1}]	7983	pick-up	0	17
66756	2020-05-23 08:49:59	2020-05-23	8	[{"id_menu":5,"count":1}]	26493	delivery	5	13
66757	2020-05-23 08:54:23	2020-05-23	8	[{"id_menu":5,"count":2}]	12141	delivery	5	13
66758	2020-05-23 08:59:55	2020-05-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	21675	delivery	5	28
66759	2020-05-23 09:02:58	2020-05-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	9061	delivery	5	28
66760	2020-05-23 09:06:11	2020-05-23	12	[{"id_menu":1,"count":1}]	26547	delivery	5	17
66761	2020-05-23 09:09:34	2020-05-23	8	[{"id_menu":5,"count":1}]	743	delivery	5	13
66762	2020-05-23 09:12:12	2020-05-23	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	26494	delivery	5	39
66763	2020-05-23 09:12:32	2020-05-23	12	[{"id_menu":3,"count":1}]	15148	delivery	5	17
66764	2020-05-23 09:15:50	2020-05-23	8	[{"id_menu":5,"count":1}]	10471	delivery	5	13
66765	2020-05-23 09:16:34	2020-05-23	9	[{"id_menu":7,"count":1}]	26510	delivery	5	14
66766	2020-05-23 09:21:30	2020-05-23	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	26431	delivery	5	31
66767	2020-05-23 09:22:14	2020-05-23	14	[{"id_menu":2,"count":1}]	18602	pick-up	0	14
66768	2020-05-23 09:23:40	2020-05-23	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15853	delivery	5	53
66769	2020-05-23 09:24:17	2020-05-23	12	[{"id_menu":3,"count":1}]	9907	pick-up	0	12
66770	2020-05-23 09:27:02	2020-05-23	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	26556	delivery	5	43
66771	2020-05-23 09:27:30	2020-05-23	17	[{"id_menu":4,"count":1}]	26391	pick-up	0	17
66772	2020-05-23 09:32:29	2020-05-23	14	[{"id_menu":2,"count":1}]	14027	pick-up	0	14
66773	2020-05-23 09:34:42	2020-05-23	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	22414	delivery	5	36
66774	2020-05-23 09:35:58	2020-05-23	12	[{"id_menu":1,"count":1}]	26520	delivery	5	17
66775	2020-05-23 09:37:41	2020-05-23	9	[{"id_menu":7,"count":1}]	25666	delivery	5	14
66776	2020-05-23 09:39:01	2020-05-23	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	26513	delivery	5	25
66777	2020-05-23 09:39:24	2020-05-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16349	delivery	5	31
66778	2020-05-23 09:39:37	2020-05-23	12	[{"id_menu":1,"count":1}]	17419	delivery	5	17
66779	2020-05-23 09:40:47	2020-05-23	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	26380	delivery	5	34
66780	2020-05-23 09:40:49	2020-05-23	12	[{"id_menu":1,"count":1}]	26428	pick-up	0	12
66781	2020-05-23 09:41:35	2020-05-23	9	[{"id_menu":6,"count":1}]	24056	delivery	5	14
66782	2020-05-23 09:43:07	2020-05-23	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	26457	delivery	5	27
66783	2020-05-23 09:43:38	2020-05-23	14	[{"id_menu":2,"count":1}]	26375	delivery	5	19
66784	2020-05-23 09:48:27	2020-05-23	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":3}]	25342	delivery	5	22
66785	2020-05-23 09:49:18	2020-05-23	12	[{"id_menu":3,"count":1}]	13341	delivery	5	17
66786	2020-05-23 09:52:33	2020-05-23	12	[{"id_menu":3,"count":1}]	13010	delivery	5	17
66787	2020-05-23 09:52:48	2020-05-23	9	[{"id_menu":7,"count":1}]	26343	delivery	5	14
66788	2020-05-23 09:53:21	2020-05-23	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	21321	delivery	5	23
66789	2020-05-23 09:53:28	2020-05-23	9	[{"id_menu":6,"count":1}]	73	pick-up	0	9
66790	2020-05-23 09:53:42	2020-05-23	9	[{"id_menu":6,"count":1}]	12222	delivery	5	14
66791	2020-05-23 09:55:37	2020-05-23	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	26538	delivery	5	56
66792	2020-05-23 09:56:01	2020-05-23	9	[{"id_menu":6,"count":1}]	24538	delivery	5	14
66793	2020-05-23 09:59:17	2020-05-23	12	[{"id_menu":1,"count":1}]	26403	pick-up	0	12
66794	2020-05-23 10:05:51	2020-05-23	17	[{"id_menu":4,"count":1}]	26232	pick-up	0	17
66795	2020-05-23 10:07:26	2020-05-23	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	9841	delivery	5	23
66796	2020-05-23 10:09:01	2020-05-23	9	[{"id_menu":6,"count":1}]	26439	delivery	5	14
66797	2020-05-23 10:09:37	2020-05-23	14	[{"id_menu":2,"count":1}]	26486	delivery	5	19
66798	2020-05-23 10:12:25	2020-05-23	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	26516	delivery	5	40
66799	2020-05-23 10:13:22	2020-05-23	12	[{"id_menu":3,"count":1}]	17366	delivery	5	17
66800	2020-05-23 10:16:27	2020-05-23	12	[{"id_menu":3,"count":1}]	13677	delivery	5	17
66801	2020-05-23 10:17:56	2020-05-23	17	[{"id_menu":4,"count":1}]	25852	delivery	5	22
66802	2020-05-23 10:24:31	2020-05-23	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	26458	delivery	5	25
66803	2020-05-23 10:26:24	2020-05-23	14	[{"id_menu":2,"count":1}]	17614	delivery	5	19
66804	2020-05-23 10:28:31	2020-05-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	285	pick-up	0	23
66805	2020-05-23 10:31:55	2020-05-23	12	[{"id_menu":1,"count":1}]	10831	delivery	5	17
66806	2020-05-23 10:32:48	2020-05-23	14	[{"id_menu":2,"count":1}]	26514	delivery	5	19
66807	2020-05-23 10:33:05	2020-05-23	9	[{"id_menu":6,"count":1}]	26418	delivery	5	14
66808	2020-05-23 10:42:22	2020-05-23	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	26465	delivery	5	27
66809	2020-05-23 10:43:52	2020-05-23	9	[{"id_menu":7,"count":1}]	26399	delivery	5	14
66810	2020-05-23 10:44:11	2020-05-23	9	[{"id_menu":6,"count":1}]	15925	delivery	5	14
66811	2020-05-23 10:46:54	2020-05-23	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	19100	pick-up	0	26
66812	2020-05-23 10:48:53	2020-05-23	9	[{"id_menu":7,"count":1}]	19929	delivery	5	14
66813	2020-05-23 10:50:31	2020-05-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	24048	delivery	5	31
66814	2020-05-23 10:56:29	2020-05-23	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26534	delivery	5	37
66815	2020-05-23 10:58:19	2020-05-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	26475	delivery	5	31
66816	2020-05-23 11:00:46	2020-05-23	9	[{"id_menu":6,"count":1}]	5716	pick-up	0	9
66817	2020-05-23 11:01:39	2020-05-23	12	[{"id_menu":1,"count":1}]	10469	delivery	5	17
66818	2020-05-23 11:05:15	2020-05-23	14	[{"id_menu":2,"count":1}]	9995	pick-up	0	14
66819	2020-05-23 11:06:20	2020-05-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2386	delivery	5	22
66820	2020-05-23 11:09:03	2020-05-23	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":3}]	13719	delivery	5	26
66821	2020-05-23 11:12:52	2020-05-23	12	[{"id_menu":1,"count":1}]	19787	delivery	5	17
66822	2020-05-23 11:13:58	2020-05-23	9	[{"id_menu":7,"count":1}]	26401	delivery	5	14
66823	2020-05-23 11:14:25	2020-05-23	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	9554	delivery	5	29
66824	2020-05-23 11:16:53	2020-05-23	9	[{"id_menu":7,"count":1}]	26553	delivery	5	14
66825	2020-05-23 11:17:20	2020-05-23	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9362	delivery	5	34
66826	2020-05-23 11:20:30	2020-05-23	12	[{"id_menu":1,"count":1}]	26364	delivery	5	17
66827	2020-05-23 11:25:54	2020-05-23	9	[{"id_menu":7,"count":1}]	2055	pick-up	0	9
66828	2020-05-23 11:27:59	2020-05-23	8	[{"id_menu":5,"count":1}]	17089	delivery	5	13
66829	2020-05-23 11:28:18	2020-05-23	9	[{"id_menu":6,"count":1}]	23044	delivery	5	14
66830	2020-05-23 11:31:58	2020-05-23	9	[{"id_menu":6,"count":1}]	26382	delivery	5	14
66831	2020-05-23 11:33:01	2020-05-23	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2238	delivery	5	26
66832	2020-05-23 11:35:01	2020-05-23	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	20968	delivery	5	31
66833	2020-05-23 11:35:20	2020-05-23	14	[{"id_menu":2,"count":1}]	7543	delivery	5	19
66834	2020-05-23 11:37:18	2020-05-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	14463	pick-up	0	21
66835	2020-05-23 11:38:18	2020-05-23	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	26351	delivery	5	26
66836	2020-05-23 11:39:18	2020-05-23	17	[{"id_menu":4,"count":1}]	4185	delivery	5	22
66837	2020-05-23 11:40:14	2020-05-23	12	[{"id_menu":3,"count":1}]	25296	pick-up	0	12
66838	2020-05-23 11:40:46	2020-05-23	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	6168	delivery	5	29
66839	2020-05-23 11:43:26	2020-05-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	5293	delivery	5	23
66840	2020-05-23 11:53:25	2020-05-23	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	26350	delivery	5	31
66841	2020-05-23 11:55:06	2020-05-23	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3580	delivery	5	39
66842	2020-05-23 11:57:44	2020-05-23	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26496	delivery	5	37
66843	2020-05-23 11:58:51	2020-05-23	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	24228	delivery	5	46
66844	2020-05-23 12:00:06	2020-05-23	9	[{"id_menu":6,"count":1}]	3393	delivery	5	14
66845	2020-05-23 12:00:54	2020-05-23	12	[{"id_menu":3,"count":1}]	847	pick-up	0	12
66846	2020-05-23 12:03:06	2020-05-23	9	[{"id_menu":7,"count":1}]	3660	pick-up	0	9
66847	2020-05-23 12:04:12	2020-05-23	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	26395	delivery	5	42
66848	2020-05-23 12:04:38	2020-05-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	16460	delivery	5	36
66849	2020-05-23 12:07:18	2020-05-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23405	delivery	5	23
66850	2020-05-23 12:09:39	2020-05-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	26384	pick-up	0	31
66851	2020-05-23 12:11:52	2020-05-23	12	[{"id_menu":1,"count":2}]	7068	delivery	5	17
66852	2020-05-23 12:12:52	2020-05-23	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2017	delivery	5	54
66853	2020-05-23 12:15:14	2020-05-23	9	[{"id_menu":6,"count":1}]	20129	delivery	5	14
66854	2020-05-23 12:24:08	2020-05-23	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	26374	delivery	5	39
66855	2020-05-23 12:27:11	2020-05-23	9	[{"id_menu":6,"count":1}]	26502	delivery	5	14
66856	2020-05-23 12:28:40	2020-05-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	10632	delivery	5	31
66857	2020-05-23 12:29:08	2020-05-23	14	[{"id_menu":2,"count":1}]	12768	delivery	5	19
66858	2020-05-23 12:32:23	2020-05-23	14	[{"id_menu":2,"count":1}]	26481	delivery	5	19
66859	2020-05-23 12:32:57	2020-05-23	12	[{"id_menu":3,"count":1}]	26468	delivery	5	17
66860	2020-05-23 12:38:38	2020-05-23	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9598	delivery	5	46
66861	2020-05-23 12:39:51	2020-05-23	9	[{"id_menu":6,"count":1}]	26540	delivery	5	14
66862	2020-05-23 12:43:04	2020-05-23	14	[{"id_menu":2,"count":1}]	3021	delivery	5	19
66863	2020-05-23 12:44:40	2020-05-23	9	[{"id_menu":7,"count":1}]	7151	pick-up	0	9
66864	2020-05-23 12:45:22	2020-05-23	9	[{"id_menu":7,"count":1}]	18534	delivery	5	14
66865	2020-05-23 12:45:50	2020-05-23	12	[{"id_menu":1,"count":1}]	739	delivery	5	17
66866	2020-05-23 12:47:07	2020-05-23	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	354	pick-up	0	29
66867	2020-05-23 12:48:03	2020-05-23	12	[{"id_menu":1,"count":1}]	16985	delivery	5	17
66868	2020-05-23 12:53:10	2020-05-23	9	[{"id_menu":6,"count":1}]	4624	pick-up	0	9
66869	2020-05-23 12:54:47	2020-05-23	12	[{"id_menu":3,"count":1}]	25544	pick-up	0	12
66870	2020-05-23 12:55:32	2020-05-23	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17794	delivery	5	34
66871	2020-05-23 12:59:19	2020-05-23	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":2}]	26406	delivery	5	31
66872	2020-05-23 12:59:21	2020-05-23	17	[{"id_menu":4,"count":1}]	235	pick-up	0	17
66873	2020-05-23 13:01:26	2020-05-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3285	pick-up	0	23
66874	2020-05-23 13:02:49	2020-05-23	8	[{"id_menu":5,"count":1}]	594	pick-up	0	8
66875	2020-05-23 13:04:35	2020-05-23	9	[{"id_menu":7,"count":1}]	7888	delivery	5	14
66876	2020-05-23 13:09:14	2020-05-23	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	26365	pick-up	0	37
66877	2020-05-23 13:09:22	2020-05-23	14	[{"id_menu":2,"count":1}]	22733	delivery	5	19
66878	2020-05-23 13:09:33	2020-05-23	14	[{"id_menu":2,"count":1}]	17589	delivery	5	19
66879	2020-05-23 13:09:51	2020-05-23	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	26345	delivery	5	26
66880	2020-05-23 13:10:28	2020-05-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	13563	delivery	5	28
66881	2020-05-23 13:17:53	2020-05-23	14	[{"id_menu":2,"count":1}]	2187	delivery	5	19
66882	2020-05-23 13:19:15	2020-05-23	12	[{"id_menu":3,"count":1}]	11287	delivery	5	17
66883	2020-05-23 13:21:36	2020-05-23	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24349	delivery	5	39
66884	2020-05-23 13:25:14	2020-05-23	9	[{"id_menu":7,"count":1}]	5354	delivery	5	14
66885	2020-05-23 13:31:53	2020-05-23	12	[{"id_menu":1,"count":1}]	26524	delivery	5	17
66886	2020-05-23 13:34:51	2020-05-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	26474	delivery	5	28
66887	2020-05-23 13:37:18	2020-05-23	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	18610	delivery	5	31
66888	2020-05-23 13:48:28	2020-05-23	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25721	delivery	5	40
66889	2020-05-23 13:50:16	2020-05-23	14	[{"id_menu":2,"count":2}]	2352	pick-up	0	14
66890	2020-05-23 13:51:20	2020-05-23	9	[{"id_menu":7,"count":1}]	15302	delivery	5	14
66891	2020-05-23 13:51:33	2020-05-23	12	[{"id_menu":3,"count":1}]	26370	pick-up	0	12
66892	2020-05-23 13:51:42	2020-05-23	12	[{"id_menu":3,"count":1}]	6169	delivery	5	17
66893	2020-05-23 13:53:33	2020-05-23	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	4368	delivery	5	43
66894	2020-05-23 13:54:10	2020-05-23	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	26536	delivery	5	25
66895	2020-05-23 13:54:40	2020-05-23	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	26417	delivery	5	34
66896	2020-05-23 13:57:38	2020-05-23	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	26501	delivery	5	30
66897	2020-05-23 14:01:55	2020-05-23	9	[{"id_menu":6,"count":1}]	9847	pick-up	0	9
66898	2020-05-23 14:03:38	2020-05-23	12	[{"id_menu":1,"count":1}]	26378	delivery	5	17
66899	2020-05-23 14:04:03	2020-05-23	14	[{"id_menu":2,"count":1}]	11394	pick-up	0	14
66900	2020-05-23 14:04:05	2020-05-23	9	[{"id_menu":6,"count":1}]	26385	delivery	5	14
66901	2020-05-23 14:04:14	2020-05-23	12	[{"id_menu":3,"count":1}]	22899	delivery	5	17
66902	2020-05-23 14:05:27	2020-05-23	9	[{"id_menu":6,"count":1}]	24892	delivery	5	14
66903	2020-05-23 14:08:16	2020-05-23	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	11774	delivery	5	29
66904	2020-05-23 14:08:55	2020-05-23	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	26339	delivery	5	40
66905	2020-05-23 14:10:18	2020-05-23	29	[{"id_menu":3,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	26386	delivery	5	34
66906	2020-05-23 14:10:53	2020-05-23	8	[{"id_menu":5,"count":1}]	26492	delivery	5	13
66907	2020-05-23 14:20:41	2020-05-23	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	13517	delivery	5	44
66908	2020-05-23 14:22:10	2020-05-23	17	[{"id_menu":4,"count":1}]	1715	pick-up	0	17
66909	2020-05-23 14:22:10	2020-05-23	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	5041	pick-up	0	29
66910	2020-05-23 14:25:20	2020-05-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	26442	pick-up	0	21
66911	2020-05-23 14:31:26	2020-05-23	9	[{"id_menu":7,"count":1}]	10651	delivery	5	14
66912	2020-05-23 14:32:27	2020-05-23	14	[{"id_menu":2,"count":1}]	26084	delivery	5	19
66913	2020-05-23 14:36:41	2020-05-23	8	[{"id_menu":5,"count":1}]	26413	delivery	5	13
66914	2020-05-23 14:38:32	2020-05-23	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	23512	delivery	5	37
66915	2020-05-23 14:39:44	2020-05-23	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14756	delivery	5	39
66916	2020-05-23 14:40:54	2020-05-23	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	21434	delivery	5	25
66917	2020-05-23 14:48:57	2020-05-23	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	18915	delivery	5	37
66918	2020-05-23 14:50:09	2020-05-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	26410	delivery	5	23
66919	2020-05-23 14:52:22	2020-05-23	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	26387	delivery	5	39
66920	2020-05-23 14:57:31	2020-05-23	9	[{"id_menu":6,"count":1}]	12253	pick-up	0	9
66921	2020-05-23 14:57:35	2020-05-23	12	[{"id_menu":3,"count":1}]	26552	delivery	5	17
66922	2020-05-23 14:59:06	2020-05-23	9	[{"id_menu":6,"count":1}]	26427	delivery	5	14
66923	2020-05-23 14:59:09	2020-05-23	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	26355	delivery	5	26
66924	2020-05-23 14:59:58	2020-05-23	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19783	delivery	5	36
66925	2020-05-23 15:00:24	2020-05-23	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	18457	delivery	5	26
66926	2020-05-23 15:05:27	2020-05-23	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	6365	delivery	5	27
66927	2020-05-23 15:07:32	2020-05-23	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	22888	delivery	5	26
66928	2020-05-23 15:10:22	2020-05-23	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	26460	delivery	5	39
66929	2020-05-23 15:10:38	2020-05-23	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	11014	delivery	5	26
66930	2020-05-23 15:12:27	2020-05-23	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	26388	delivery	5	43
66931	2020-05-23 15:13:04	2020-05-23	12	[{"id_menu":1,"count":1}]	1148	delivery	5	17
66932	2020-05-23 15:13:25	2020-05-23	9	[{"id_menu":6,"count":1}]	8054	pick-up	0	9
66933	2020-05-23 15:16:09	2020-05-23	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	26506	delivery	5	31
66934	2020-05-23 15:25:17	2020-05-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2855	pick-up	0	31
66935	2020-05-23 15:28:21	2020-05-23	12	[{"id_menu":1,"count":1}]	6278	delivery	5	17
66936	2020-05-23 15:31:05	2020-05-23	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	26071	delivery	5	26
66937	2020-05-23 15:35:01	2020-05-23	14	[{"id_menu":2,"count":1}]	17560	delivery	5	19
66938	2020-05-23 15:36:49	2020-05-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	26440	delivery	5	22
66939	2020-05-23 15:36:49	2020-05-23	9	[{"id_menu":7,"count":1}]	26402	delivery	5	14
66940	2020-05-23 15:40:09	2020-05-23	9	[{"id_menu":6,"count":1}]	26535	delivery	5	14
66941	2020-05-23 15:45:31	2020-05-23	8	[{"id_menu":5,"count":1}]	11989	delivery	5	13
66942	2020-05-23 15:45:37	2020-05-23	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	26333	delivery	5	44
66943	2020-05-23 15:45:55	2020-05-23	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	26476	delivery	5	26
66944	2020-05-23 15:49:01	2020-05-23	12	[{"id_menu":3,"count":1}]	1905	pick-up	0	12
66945	2020-05-23 15:50:08	2020-05-23	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	21664	delivery	5	22
66946	2020-05-23 15:51:36	2020-05-23	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	26432	delivery	5	52
66947	2020-05-23 15:53:05	2020-05-23	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	26338	delivery	5	31
66948	2020-05-23 15:55:49	2020-05-23	14	[{"id_menu":2,"count":1}]	26519	delivery	5	19
66949	2020-05-23 15:57:40	2020-05-23	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	26448	delivery	5	27
66950	2020-05-23 16:00:04	2020-05-23	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	26405	delivery	5	45
66951	2020-05-23 16:00:57	2020-05-23	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	15731	delivery	5	31
66952	2020-05-23 16:05:20	2020-05-23	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23606	delivery	5	40
66953	2020-05-23 16:07:00	2020-05-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	26512	delivery	5	28
66954	2020-05-23 16:09:43	2020-05-23	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	26353	delivery	5	23
66955	2020-05-23 16:11:06	2020-05-23	9	[{"id_menu":6,"count":1}]	25462	delivery	5	14
66956	2020-05-23 16:15:07	2020-05-23	12	[{"id_menu":1,"count":2}]	9824	delivery	5	17
66957	2020-05-23 16:15:18	2020-05-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	26429	delivery	5	22
66958	2020-05-23 16:16:26	2020-05-23	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	26550	delivery	5	27
66959	2020-05-23 16:18:21	2020-05-23	14	[{"id_menu":2,"count":1}]	26362	delivery	5	19
66960	2020-05-23 16:20:21	2020-05-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	26389	delivery	5	26
66961	2020-05-23 16:20:42	2020-05-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	26479	delivery	5	31
66962	2020-05-23 16:22:13	2020-05-23	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	5994	delivery	5	43
66963	2020-05-23 16:24:23	2020-05-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	9377	delivery	5	22
66964	2020-05-23 16:25:32	2020-05-23	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10673	delivery	5	31
66965	2020-05-23 16:27:40	2020-05-23	17	[{"id_menu":4,"count":1}]	26393	delivery	5	22
66966	2020-05-23 16:29:29	2020-05-23	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	26490	delivery	5	28
66967	2020-05-23 16:29:35	2020-05-23	33	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	26466	delivery	5	38
66968	2020-05-23 16:30:38	2020-05-23	17	[{"id_menu":4,"count":1}]	22511	delivery	5	22
66969	2020-05-23 16:32:13	2020-05-23	12	[{"id_menu":3,"count":1}]	26390	delivery	5	17
66970	2020-05-23 16:34:35	2020-05-23	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	5649	delivery	5	31
66971	2020-05-23 16:35:02	2020-05-23	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26394	delivery	5	35
66972	2020-05-23 16:35:17	2020-05-23	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	26461	delivery	5	43
66973	2020-05-23 16:35:27	2020-05-23	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	12701	delivery	5	22
66974	2020-05-23 16:38:00	2020-05-23	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":2}]	26517	delivery	5	31
66975	2020-05-23 16:38:43	2020-05-23	14	[{"id_menu":2,"count":2}]	20882	delivery	5	19
66976	2020-05-23 16:38:48	2020-05-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	9259	delivery	5	36
66977	2020-05-23 16:41:19	2020-05-23	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	7444	delivery	5	26
66978	2020-05-23 16:42:35	2020-05-23	12	[{"id_menu":3,"count":1}]	18174	delivery	5	17
66979	2020-05-23 16:45:11	2020-05-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":3}]	25364	delivery	5	23
66980	2020-05-23 16:46:05	2020-05-23	9	[{"id_menu":6,"count":1}]	26511	delivery	5	14
66981	2020-05-23 16:47:52	2020-05-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15679	delivery	5	31
66982	2020-05-23 16:52:35	2020-05-23	8	[{"id_menu":5,"count":1}]	26420	delivery	5	13
66983	2020-05-23 16:54:30	2020-05-23	12	[{"id_menu":1,"count":1}]	26518	pick-up	0	12
66984	2020-05-23 16:55:11	2020-05-23	14	[{"id_menu":2,"count":1}]	18761	pick-up	0	14
66985	2020-05-23 16:55:12	2020-05-23	9	[{"id_menu":6,"count":1}]	7578	delivery	5	14
66986	2020-05-23 16:55:41	2020-05-23	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2907	pick-up	0	26
66987	2020-05-23 16:57:20	2020-05-23	9	[{"id_menu":7,"count":1}]	5494	delivery	5	14
66988	2020-05-23 16:58:04	2020-05-23	17	[{"id_menu":4,"count":1}]	26392	delivery	5	22
66989	2020-05-23 16:59:12	2020-05-23	14	[{"id_menu":2,"count":1}]	26354	delivery	5	19
66990	2020-05-23 17:01:27	2020-05-23	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	26361	delivery	5	31
66991	2020-05-23 17:01:45	2020-05-23	9	[{"id_menu":7,"count":1}]	26525	delivery	5	14
66992	2020-05-23 17:05:15	2020-05-23	17	[{"id_menu":4,"count":1}]	26545	delivery	5	22
66993	2020-05-23 17:09:53	2020-05-23	12	[{"id_menu":1,"count":1}]	26498	delivery	5	17
66994	2020-05-23 17:11:51	2020-05-23	14	[{"id_menu":2,"count":1}]	1649	pick-up	0	14
66995	2020-05-23 17:12:07	2020-05-23	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10872	delivery	5	45
66996	2020-05-23 17:13:00	2020-05-23	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5740	delivery	5	43
66997	2020-05-23 17:13:02	2020-05-23	8	[{"id_menu":5,"count":1}]	26528	delivery	5	13
66998	2020-05-23 17:15:08	2020-05-23	9	[{"id_menu":7,"count":1}]	26469	delivery	5	14
66999	2020-05-23 17:17:19	2020-05-23	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19926	delivery	5	48
67000	2020-05-23 17:18:40	2020-05-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	21167	delivery	5	28
67001	2020-05-23 17:22:44	2020-05-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1572	delivery	5	36
67002	2020-05-23 17:29:52	2020-05-23	26	[{"id_menu":4,"count":3},{"id_menu":7,"count":1}]	26334	delivery	5	31
67003	2020-05-23 17:31:45	2020-05-23	17	[{"id_menu":4,"count":1}]	26332	delivery	5	22
67004	2020-05-23 17:33:54	2020-05-23	8	[{"id_menu":5,"count":1}]	9571	delivery	5	13
67005	2020-05-23 17:36:48	2020-05-23	17	[{"id_menu":4,"count":1}]	26487	pick-up	0	17
67006	2020-05-23 17:37:14	2020-05-23	14	[{"id_menu":2,"count":1}]	14239	delivery	5	19
67007	2020-05-23 17:40:00	2020-05-23	9	[{"id_menu":6,"count":1}]	26342	delivery	5	14
67008	2020-05-23 17:40:04	2020-05-23	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	26472	delivery	5	31
67009	2020-05-23 17:42:33	2020-05-23	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	626	pick-up	0	29
67010	2020-05-23 17:43:41	2020-05-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	26464	delivery	5	36
67011	2020-05-23 17:45:50	2020-05-23	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26477	delivery	5	37
67012	2020-05-23 17:50:40	2020-05-23	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	18227	delivery	5	44
67013	2020-05-23 17:52:00	2020-05-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	14722	pick-up	0	23
67014	2020-05-23 17:53:36	2020-05-23	9	[{"id_menu":7,"count":1}]	11444	pick-up	0	9
67015	2020-05-23 17:55:59	2020-05-23	9	[{"id_menu":6,"count":1}]	26415	delivery	5	14
67016	2020-05-23 17:57:37	2020-05-23	12	[{"id_menu":1,"count":1}]	5790	pick-up	0	12
67017	2020-05-23 18:00:19	2020-05-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4546	pick-up	0	26
67018	2020-05-23 18:00:24	2020-05-23	14	[{"id_menu":2,"count":1}]	773	pick-up	0	14
67019	2020-05-23 18:01:43	2020-05-23	12	[{"id_menu":3,"count":1}]	26527	delivery	5	17
67020	2020-05-23 18:02:48	2020-05-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12261	delivery	5	31
67021	2020-05-23 18:06:27	2020-05-23	8	[{"id_menu":5,"count":1}]	26503	delivery	5	13
67022	2020-05-23 18:07:24	2020-05-23	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	24229	delivery	5	28
67023	2020-05-23 18:07:27	2020-05-23	9	[{"id_menu":7,"count":1}]	26447	delivery	5	14
67024	2020-05-23 18:07:27	2020-05-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":3}]	9236	delivery	5	31
67025	2020-05-23 18:07:58	2020-05-23	9	[{"id_menu":7,"count":1}]	1441	delivery	5	14
67026	2020-05-23 18:10:25	2020-05-23	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10129	delivery	5	34
67027	2020-05-23 18:10:55	2020-05-23	9	[{"id_menu":6,"count":1}]	10481	delivery	5	14
67028	2020-05-23 18:19:04	2020-05-23	14	[{"id_menu":2,"count":1}]	26533	delivery	5	19
67029	2020-05-23 18:31:31	2020-05-23	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26500	delivery	5	43
67030	2020-05-23 18:33:24	2020-05-23	9	[{"id_menu":7,"count":2}]	26555	delivery	5	14
67031	2020-05-23 18:34:17	2020-05-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	10479	pick-up	0	26
67032	2020-05-23 18:39:14	2020-05-23	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	23844	delivery	5	40
67033	2020-05-23 18:40:15	2020-05-23	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	26408	pick-up	0	22
67034	2020-05-23 18:44:30	2020-05-23	9	[{"id_menu":6,"count":1}]	12304	delivery	5	14
67035	2020-05-23 18:53:14	2020-05-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	26346	delivery	5	31
67036	2020-05-23 18:54:18	2020-05-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	20285	delivery	5	31
67037	2020-05-23 18:57:51	2020-05-23	17	[{"id_menu":4,"count":1}]	26373	pick-up	0	17
67038	2020-05-23 18:59:17	2020-05-23	8	[{"id_menu":5,"count":1}]	19637	delivery	5	13
67039	2020-05-23 18:59:35	2020-05-23	9	[{"id_menu":7,"count":1}]	26344	delivery	5	14
67040	2020-05-23 19:03:57	2020-05-23	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	7250	pick-up	0	20
67041	2020-05-23 19:05:50	2020-05-23	9	[{"id_menu":6,"count":1}]	17807	pick-up	0	9
67042	2020-05-23 19:06:12	2020-05-23	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	12224	pick-up	0	26
67043	2020-05-23 19:07:52	2020-05-23	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26499	delivery	5	40
67044	2020-05-23 19:08:51	2020-05-23	14	[{"id_menu":2,"count":1}]	1245	delivery	5	19
67045	2020-05-23 19:09:14	2020-05-23	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	26424	delivery	5	36
67046	2020-05-23 19:14:20	2020-05-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1862	pick-up	0	21
67047	2020-05-23 19:16:02	2020-05-23	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	26495	delivery	5	39
67048	2020-05-23 19:18:17	2020-05-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	12039	delivery	5	26
67049	2020-05-23 19:21:58	2020-05-23	17	[{"id_menu":4,"count":2}]	5579	delivery	5	22
67050	2020-05-23 19:22:00	2020-05-23	14	[{"id_menu":2,"count":2}]	26359	delivery	5	19
67051	2020-05-23 19:23:30	2020-05-23	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	26478	pick-up	0	26
67052	2020-05-23 19:24:05	2020-05-23	14	[{"id_menu":2,"count":1}]	3449	delivery	5	19
67053	2020-05-23 19:24:21	2020-05-23	12	[{"id_menu":1,"count":1}]	19366	delivery	5	17
67054	2020-05-23 19:25:42	2020-05-23	12	[{"id_menu":1,"count":2}]	612	pick-up	0	12
67055	2020-05-23 19:26:37	2020-05-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5527	delivery	5	23
67056	2020-05-23 19:29:29	2020-05-23	9	[{"id_menu":6,"count":1}]	26508	delivery	5	14
67057	2020-05-23 19:36:58	2020-05-23	9	[{"id_menu":7,"count":1}]	26419	delivery	5	14
67058	2020-05-23 19:40:42	2020-05-23	12	[{"id_menu":3,"count":1}]	11464	delivery	5	17
67059	2020-05-23 19:41:28	2020-05-23	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	21363	delivery	5	56
67060	2020-05-23 19:41:41	2020-05-23	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23457	delivery	5	51
67061	2020-05-23 19:42:55	2020-05-23	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	8385	delivery	5	48
67062	2020-05-23 19:43:21	2020-05-23	14	[{"id_menu":2,"count":1}]	19799	delivery	5	19
67063	2020-05-23 19:45:16	2020-05-23	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	24807	delivery	5	35
67064	2020-05-23 19:45:47	2020-05-23	17	[{"id_menu":4,"count":1}]	23695	pick-up	0	17
67065	2020-05-23 19:46:16	2020-05-23	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	26526	delivery	5	26
67066	2020-05-23 19:48:45	2020-05-23	9	[{"id_menu":7,"count":1}]	6026	delivery	5	14
67067	2020-05-23 19:52:21	2020-05-23	12	[{"id_menu":3,"count":1}]	17995	delivery	5	17
67068	2020-05-23 19:53:06	2020-05-23	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	26467	delivery	5	37
67069	2020-05-23 19:56:01	2020-05-23	17	[{"id_menu":4,"count":1}]	4736	delivery	5	22
67070	2020-05-23 20:00:43	2020-05-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21551	pick-up	0	17
67071	2020-05-23 20:02:42	2020-05-23	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	26548	delivery	5	34
67072	2020-05-23 20:04:21	2020-05-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	12711	delivery	5	36
67073	2020-05-23 20:11:55	2020-05-23	9	[{"id_menu":7,"count":1}]	26445	pick-up	0	9
67074	2020-05-23 20:14:26	2020-05-23	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15768	delivery	5	35
67075	2020-05-23 20:14:40	2020-05-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6848	pick-up	0	31
67076	2020-05-23 20:18:17	2020-05-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	26504	delivery	5	26
67077	2020-05-23 20:19:48	2020-05-23	9	[{"id_menu":7,"count":1}]	26484	delivery	5	14
67078	2020-05-23 20:20:21	2020-05-23	9	[{"id_menu":6,"count":1}]	26430	pick-up	0	9
67079	2020-05-23 20:25:02	2020-05-23	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26438	delivery	5	40
67080	2020-05-23 20:27:39	2020-05-23	9	[{"id_menu":7,"count":1}]	5318	delivery	5	14
67081	2020-05-23 20:31:20	2020-05-23	9	[{"id_menu":7,"count":1}]	25338	delivery	5	14
67082	2020-05-23 20:41:50	2020-05-23	9	[{"id_menu":7,"count":1}]	19529	delivery	5	14
67083	2020-05-23 20:44:22	2020-05-23	14	[{"id_menu":2,"count":1}]	26292	delivery	5	19
67084	2020-05-23 20:45:18	2020-05-23	14	[{"id_menu":2,"count":1}]	26483	delivery	5	19
67085	2020-05-23 20:45:50	2020-05-23	12	[{"id_menu":3,"count":1}]	15473	pick-up	0	12
67086	2020-05-23 20:47:45	2020-05-23	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	26422	delivery	5	31
67087	2020-05-23 20:47:54	2020-05-23	12	[{"id_menu":1,"count":1}]	26028	delivery	5	17
67088	2020-05-23 20:47:59	2020-05-23	12	[{"id_menu":3,"count":1}]	1679	pick-up	0	12
67089	2020-05-23 20:50:29	2020-05-23	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7067	pick-up	0	26
67090	2020-05-23 20:53:11	2020-05-23	12	[{"id_menu":1,"count":1}]	23863	delivery	5	17
67091	2020-05-23 20:55:03	2020-05-23	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	26473	delivery	5	44
67092	2020-05-23 20:56:08	2020-05-23	8	[{"id_menu":5,"count":1}]	5587	delivery	5	13
67093	2020-05-23 21:00:02	2020-05-23	14	[{"id_menu":2,"count":1}]	26377	delivery	5	19
67094	2020-05-23 21:04:16	2020-05-23	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	6573	pick-up	0	37
67095	2020-05-23 21:08:03	2020-05-23	12	[{"id_menu":1,"count":1}]	26529	delivery	5	17
67096	2020-05-23 21:09:49	2020-05-23	8	[{"id_menu":5,"count":1}]	26521	delivery	5	13
67097	2020-05-23 21:11:02	2020-05-23	9	[{"id_menu":7,"count":1}]	18140	delivery	5	14
67098	2020-05-23 21:12:31	2020-05-23	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18643	pick-up	0	29
67099	2020-05-23 21:14:36	2020-05-23	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3493	delivery	5	39
67100	2020-05-23 21:15:24	2020-05-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	48	pick-up	0	26
67101	2020-05-23 21:26:21	2020-05-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	20910	pick-up	0	31
67102	2020-05-23 21:28:38	2020-05-23	9	[{"id_menu":7,"count":1}]	26426	delivery	5	14
67103	2020-05-23 21:28:48	2020-05-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26557	delivery	5	23
67104	2020-05-23 21:31:09	2020-05-23	12	[{"id_menu":1,"count":1}]	26336	pick-up	0	12
67105	2020-05-23 21:31:32	2020-05-23	9	[{"id_menu":6,"count":1}]	17658	delivery	5	14
67106	2020-05-23 21:34:26	2020-05-23	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4355	delivery	5	31
67107	2020-05-23 21:38:09	2020-05-23	9	[{"id_menu":6,"count":1}]	26425	delivery	5	14
67108	2020-05-23 21:45:45	2020-05-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	26347	delivery	5	28
67109	2020-05-23 21:54:52	2020-05-23	9	[{"id_menu":6,"count":2}]	19763	delivery	5	14
67110	2020-05-23 21:56:57	2020-05-23	17	[{"id_menu":4,"count":1}]	1484	pick-up	0	17
67111	2020-05-23 21:58:04	2020-05-23	9	[{"id_menu":6,"count":1}]	19737	delivery	5	14
67112	2020-05-23 22:03:29	2020-05-23	9	[{"id_menu":6,"count":1}]	8215	delivery	5	14
67113	2020-05-23 22:03:52	2020-05-23	8	[{"id_menu":5,"count":1}]	26397	delivery	5	13
67114	2020-05-23 22:08:50	2020-05-23	14	[{"id_menu":2,"count":1}]	24842	delivery	5	19
67115	2020-05-23 22:09:42	2020-05-23	8	[{"id_menu":5,"count":2}]	12946	delivery	5	13
67116	2020-05-23 22:12:23	2020-05-23	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	25573	delivery	5	30
67117	2020-05-23 22:12:24	2020-05-23	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	14611	delivery	5	39
67118	2020-05-23 22:12:39	2020-05-23	9	[{"id_menu":6,"count":1}]	14064	delivery	5	14
67119	2020-05-23 22:14:13	2020-05-23	8	[{"id_menu":5,"count":1}]	25823	delivery	5	13
67120	2020-05-23 22:16:06	2020-05-23	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	26544	delivery	5	22
67121	2020-05-23 22:20:43	2020-05-23	14	[{"id_menu":2,"count":1}]	18526	pick-up	0	14
67122	2020-05-23 22:23:57	2020-05-23	9	[{"id_menu":6,"count":1}]	26551	delivery	5	14
67123	2020-05-23 22:24:34	2020-05-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":3}]	22529	delivery	5	28
67124	2020-05-23 22:26:09	2020-05-23	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	16324	delivery	5	48
67125	2020-05-23 22:27:47	2020-05-23	12	[{"id_menu":3,"count":1}]	14521	pick-up	0	12
67126	2020-05-23 22:35:47	2020-05-23	12	[{"id_menu":3,"count":1}]	22014	delivery	5	17
67127	2020-05-23 22:41:02	2020-05-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7001	delivery	5	31
67128	2020-05-23 22:42:56	2020-05-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	15383	delivery	5	28
67129	2020-05-23 22:44:56	2020-05-23	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1618	pick-up	0	26
67130	2020-05-23 22:45:41	2020-05-23	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	26456	delivery	5	45
67131	2020-05-23 22:47:26	2020-05-23	9	[{"id_menu":6,"count":1}]	26509	delivery	5	14
67132	2020-05-23 22:48:34	2020-05-23	9	[{"id_menu":7,"count":1}]	11770	delivery	5	14
67133	2020-05-23 22:53:14	2020-05-23	29	[{"id_menu":3,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13521	delivery	5	34
67134	2020-05-23 22:53:47	2020-05-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	26409	delivery	5	28
67135	2020-05-23 22:56:35	2020-05-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	26543	delivery	5	31
67136	2020-05-23 22:57:51	2020-05-23	17	[{"id_menu":4,"count":1}]	7344	pick-up	0	17
67137	2020-05-23 23:02:23	2020-05-23	17	[{"id_menu":4,"count":1}]	26541	delivery	5	22
67138	2020-05-23 23:05:09	2020-05-23	12	[{"id_menu":3,"count":1}]	10381	pick-up	0	12
67139	2020-05-23 23:06:27	2020-05-23	9	[{"id_menu":7,"count":1}]	5939	delivery	5	14
67140	2020-05-23 23:07:44	2020-05-23	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	245	pick-up	0	29
67141	2020-05-23 23:11:09	2020-05-23	17	[{"id_menu":4,"count":1}]	26451	delivery	5	22
67142	2020-05-23 23:23:56	2020-05-23	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26437	delivery	5	31
67143	2020-05-23 23:25:15	2020-05-23	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	14373	delivery	5	45
67144	2020-05-23 23:38:23	2020-05-23	17	[{"id_menu":4,"count":1}]	26505	delivery	5	22
67145	2020-05-23 23:39:14	2020-05-23	12	[{"id_menu":1,"count":1}]	22626	pick-up	0	12
67146	2020-05-23 23:42:50	2020-05-23	8	[{"id_menu":5,"count":1}]	22654	delivery	5	13
67147	2020-05-23 23:43:58	2020-05-23	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	26488	delivery	5	43
67148	2020-05-23 23:44:06	2020-05-23	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	3174	delivery	5	31
67149	2020-05-23 23:44:31	2020-05-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7891	delivery	5	36
67150	2020-05-23 23:45:17	2020-05-23	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19192	delivery	5	39
67151	2020-05-23 23:47:20	2020-05-23	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	14625	delivery	5	42
67152	2020-05-23 23:49:04	2020-05-23	9	[{"id_menu":6,"count":1}]	925	pick-up	0	9
67153	2020-05-23 23:50:46	2020-05-23	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	8673	pick-up	0	21
67154	2020-05-23 23:53:59	2020-05-23	17	[{"id_menu":4,"count":1}]	20072	delivery	5	22
67155	2020-05-23 23:55:00	2020-05-23	17	[{"id_menu":4,"count":1}]	17460	pick-up	0	17
67156	2020-05-23 23:58:50	2020-05-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8656	delivery	5	22
67157	2020-05-24 00:01:02	2020-05-24	9	[{"id_menu":6,"count":1}]	1618	pick-up	0	9
67158	2020-05-24 00:03:48	2020-05-24	12	[{"id_menu":3,"count":1}]	26671	delivery	5	17
67159	2020-05-24 00:04:30	2020-05-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	15910	delivery	5	28
67160	2020-05-24 00:04:45	2020-05-24	12	[{"id_menu":3,"count":1}]	2232	pick-up	0	12
67161	2020-05-24 00:06:15	2020-05-24	8	[{"id_menu":5,"count":1}]	5520	delivery	5	13
67162	2020-05-24 00:06:26	2020-05-24	8	[{"id_menu":5,"count":1}]	17464	delivery	5	13
67163	2020-05-24 00:07:15	2020-05-24	9	[{"id_menu":6,"count":1}]	14775	delivery	5	14
67164	2020-05-24 00:09:14	2020-05-24	9	[{"id_menu":6,"count":1}]	26674	delivery	5	14
67165	2020-05-24 00:12:13	2020-05-24	12	[{"id_menu":1,"count":1}]	23728	delivery	5	17
67166	2020-05-24 00:14:18	2020-05-24	14	[{"id_menu":2,"count":1}]	7050	pick-up	0	14
67167	2020-05-24 00:14:29	2020-05-24	14	[{"id_menu":2,"count":1}]	10081	delivery	5	19
67168	2020-05-24 00:20:24	2020-05-24	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23551	delivery	5	34
67169	2020-05-24 00:27:13	2020-05-24	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	552	delivery	5	36
67170	2020-05-24 00:28:37	2020-05-24	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26701	delivery	5	52
67171	2020-05-24 00:30:39	2020-05-24	17	[{"id_menu":4,"count":1}]	17086	delivery	5	22
67172	2020-05-24 00:32:32	2020-05-24	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	26750	delivery	5	44
67173	2020-05-24 00:38:10	2020-05-24	14	[{"id_menu":2,"count":1}]	24554	delivery	5	19
67174	2020-05-24 00:40:32	2020-05-24	12	[{"id_menu":1,"count":1}]	14616	pick-up	0	12
67175	2020-05-24 00:42:05	2020-05-24	8	[{"id_menu":5,"count":1}]	23349	pick-up	0	8
67176	2020-05-24 00:42:30	2020-05-24	12	[{"id_menu":1,"count":1}]	18430	pick-up	0	12
67177	2020-05-24 00:42:55	2020-05-24	12	[{"id_menu":1,"count":1}]	8839	delivery	5	17
67178	2020-05-24 00:44:05	2020-05-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1756	delivery	5	31
67179	2020-05-24 00:46:19	2020-05-24	9	[{"id_menu":7,"count":1}]	11572	delivery	5	14
67180	2020-05-24 00:46:51	2020-05-24	9	[{"id_menu":7,"count":1}]	15163	delivery	5	14
67181	2020-05-24 00:47:35	2020-05-24	9	[{"id_menu":6,"count":1}]	26342	delivery	5	14
67182	2020-05-24 00:47:47	2020-05-24	9	[{"id_menu":6,"count":1}]	13918	delivery	5	14
67183	2020-05-24 00:57:02	2020-05-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	9344	delivery	5	23
67184	2020-05-24 01:02:17	2020-05-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	17941	delivery	5	28
67185	2020-05-24 01:12:42	2020-05-24	9	[{"id_menu":6,"count":1}]	15123	delivery	5	14
67186	2020-05-24 01:15:16	2020-05-24	9	[{"id_menu":6,"count":1}]	22062	delivery	5	14
67187	2020-05-24 01:15:55	2020-05-24	12	[{"id_menu":1,"count":1}]	1068	pick-up	0	12
67188	2020-05-24 01:16:57	2020-05-24	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	16006	delivery	5	22
67189	2020-05-24 01:21:33	2020-05-24	8	[{"id_menu":5,"count":1}]	1366	pick-up	0	8
67190	2020-05-24 01:22:31	2020-05-24	9	[{"id_menu":7,"count":1}]	14579	delivery	5	14
67191	2020-05-24 01:31:56	2020-05-24	8	[{"id_menu":5,"count":1}]	26131	delivery	5	13
67192	2020-05-24 01:37:20	2020-05-24	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	13623	delivery	5	43
67193	2020-05-24 01:47:56	2020-05-24	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	26666	delivery	5	25
67194	2020-05-24 01:49:05	2020-05-24	9	[{"id_menu":7,"count":1}]	9031	delivery	5	14
67195	2020-05-24 01:50:58	2020-05-24	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	24350	pick-up	0	25
67196	2020-05-24 01:51:34	2020-05-24	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	26630	delivery	5	34
67197	2020-05-24 01:51:37	2020-05-24	9	[{"id_menu":7,"count":2}]	26620	delivery	5	14
67198	2020-05-24 01:52:04	2020-05-24	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	20841	delivery	5	22
67199	2020-05-24 01:56:28	2020-05-24	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	4426	delivery	5	43
67200	2020-05-24 01:57:06	2020-05-24	9	[{"id_menu":7,"count":1}]	26563	pick-up	0	9
67201	2020-05-24 01:59:34	2020-05-24	9	[{"id_menu":7,"count":1}]	26634	delivery	5	14
67202	2020-05-24 02:03:43	2020-05-24	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	6553	delivery	5	31
67203	2020-05-24 02:04:01	2020-05-24	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	21496	delivery	5	40
67204	2020-05-24 02:06:12	2020-05-24	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	26610	delivery	5	26
67205	2020-05-24 02:06:18	2020-05-24	8	[{"id_menu":5,"count":1}]	910	pick-up	0	8
67206	2020-05-24 02:06:42	2020-05-24	12	[{"id_menu":3,"count":1}]	15860	delivery	5	17
67207	2020-05-24 02:07:15	2020-05-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	26591	delivery	5	28
67208	2020-05-24 02:08:16	2020-05-24	14	[{"id_menu":2,"count":1}]	13335	pick-up	0	14
67209	2020-05-24 02:09:36	2020-05-24	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	10083	delivery	5	52
67210	2020-05-24 02:09:59	2020-05-24	9	[{"id_menu":6,"count":1}]	7261	delivery	5	14
67211	2020-05-24 02:11:51	2020-05-24	8	[{"id_menu":5,"count":1}]	21291	delivery	5	13
67212	2020-05-24 02:13:18	2020-05-24	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6215	delivery	5	31
67213	2020-05-24 02:13:54	2020-05-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13317	pick-up	0	18
67214	2020-05-24 02:14:56	2020-05-24	9	[{"id_menu":6,"count":1}]	26722	delivery	5	14
67215	2020-05-24 02:17:48	2020-05-24	14	[{"id_menu":2,"count":1}]	409	delivery	5	19
67216	2020-05-24 02:18:30	2020-05-24	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	10880	pick-up	0	31
67217	2020-05-24 02:19:13	2020-05-24	8	[{"id_menu":5,"count":1}]	23269	delivery	5	13
67218	2020-05-24 02:20:19	2020-05-24	14	[{"id_menu":2,"count":1}]	26562	delivery	5	19
67219	2020-05-24 02:24:45	2020-05-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4198	delivery	5	23
67220	2020-05-24 02:26:59	2020-05-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15903	delivery	5	31
67221	2020-05-24 02:27:12	2020-05-24	14	[{"id_menu":2,"count":1}]	24752	delivery	5	19
67222	2020-05-24 02:29:37	2020-05-24	9	[{"id_menu":6,"count":1}]	26594	delivery	5	14
67223	2020-05-24 02:30:42	2020-05-24	12	[{"id_menu":1,"count":1}]	25930	pick-up	0	12
67224	2020-05-24 02:30:45	2020-05-24	8	[{"id_menu":5,"count":1}]	12403	delivery	5	13
67225	2020-05-24 02:33:45	2020-05-24	8	[{"id_menu":5,"count":4}]	14860	delivery	5	13
67226	2020-05-24 02:36:42	2020-05-24	12	[{"id_menu":3,"count":1}]	26649	delivery	5	17
67227	2020-05-24 02:37:16	2020-05-24	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21374	delivery	5	45
67228	2020-05-24 02:37:50	2020-05-24	17	[{"id_menu":4,"count":1}]	3898	pick-up	0	17
67229	2020-05-24 02:38:38	2020-05-24	17	[{"id_menu":4,"count":1}]	5236	delivery	5	22
67230	2020-05-24 02:43:11	2020-05-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	26144	delivery	5	22
67231	2020-05-24 02:45:31	2020-05-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	24047	delivery	5	31
67232	2020-05-24 02:46:59	2020-05-24	9	[{"id_menu":6,"count":1}]	18047	pick-up	0	9
67233	2020-05-24 02:47:18	2020-05-24	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	8771	delivery	5	29
67234	2020-05-24 02:50:12	2020-05-24	14	[{"id_menu":2,"count":1}]	26622	delivery	5	19
67235	2020-05-24 02:50:17	2020-05-24	9	[{"id_menu":6,"count":2}]	26578	delivery	5	14
67236	2020-05-24 02:50:27	2020-05-24	9	[{"id_menu":6,"count":1}]	20907	delivery	5	14
67237	2020-05-24 02:55:14	2020-05-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1789	delivery	5	28
67238	2020-05-24 02:58:44	2020-05-24	17	[{"id_menu":4,"count":1}]	371	delivery	5	22
67239	2020-05-24 02:59:43	2020-05-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3688	delivery	5	22
67240	2020-05-24 03:01:05	2020-05-24	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	26570	delivery	5	36
67241	2020-05-24 03:01:33	2020-05-24	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7491	delivery	5	34
67242	2020-05-24 03:03:02	2020-05-24	9	[{"id_menu":7,"count":1}]	26692	delivery	5	14
67243	2020-05-24 03:03:02	2020-05-24	17	[{"id_menu":4,"count":1}]	26693	delivery	5	22
67244	2020-05-24 03:03:26	2020-05-24	12	[{"id_menu":3,"count":1}]	12344	delivery	5	17
67245	2020-05-24 03:03:34	2020-05-24	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26679	delivery	5	40
67246	2020-05-24 03:04:11	2020-05-24	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26641	delivery	5	48
67247	2020-05-24 03:06:49	2020-05-24	14	[{"id_menu":2,"count":1}]	26558	delivery	5	19
67248	2020-05-24 03:07:17	2020-05-24	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	26638	pick-up	0	21
67249	2020-05-24 03:10:41	2020-05-24	8	[{"id_menu":5,"count":1}]	12474	delivery	5	13
67250	2020-05-24 03:18:33	2020-05-24	8	[{"id_menu":5,"count":1}]	15621	delivery	5	13
67251	2020-05-24 03:26:36	2020-05-24	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15888	delivery	5	40
67252	2020-05-24 03:30:26	2020-05-24	12	[{"id_menu":1,"count":1}]	12990	pick-up	0	12
67253	2020-05-24 03:31:11	2020-05-24	14	[{"id_menu":2,"count":1}]	15992	delivery	5	19
67254	2020-05-24 03:38:29	2020-05-24	9	[{"id_menu":6,"count":1}]	26667	delivery	5	14
67255	2020-05-24 03:38:51	2020-05-24	9	[{"id_menu":6,"count":1}]	10905	delivery	5	14
67256	2020-05-24 03:45:31	2020-05-24	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	3567	pick-up	0	20
67257	2020-05-24 03:46:59	2020-05-24	12	[{"id_menu":3,"count":1}]	20246	delivery	5	17
67258	2020-05-24 03:47:48	2020-05-24	8	[{"id_menu":5,"count":1}]	26683	pick-up	0	8
67259	2020-05-24 03:49:41	2020-05-24	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	26703	delivery	5	29
67260	2020-05-24 03:51:19	2020-05-24	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	26714	delivery	5	30
67261	2020-05-24 03:52:16	2020-05-24	9	[{"id_menu":6,"count":1}]	26599	delivery	5	14
67262	2020-05-24 03:52:24	2020-05-24	12	[{"id_menu":3,"count":1}]	10525	pick-up	0	12
67263	2020-05-24 03:56:01	2020-05-24	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26593	delivery	5	54
67264	2020-05-24 03:58:24	2020-05-24	17	[{"id_menu":4,"count":1}]	16434	pick-up	0	17
67265	2020-05-24 03:58:24	2020-05-24	14	[{"id_menu":2,"count":2}]	17799	delivery	5	19
67266	2020-05-24 03:58:26	2020-05-24	17	[{"id_menu":4,"count":1}]	1813	delivery	5	22
67267	2020-05-24 04:00:32	2020-05-24	12	[{"id_menu":1,"count":1}]	26650	delivery	5	17
67268	2020-05-24 04:03:37	2020-05-24	9	[{"id_menu":6,"count":1}]	17474	delivery	5	14
67269	2020-05-24 04:08:48	2020-05-24	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	16498	delivery	5	28
67270	2020-05-24 04:10:50	2020-05-24	17	[{"id_menu":4,"count":1}]	26565	delivery	5	22
67271	2020-05-24 04:12:39	2020-05-24	9	[{"id_menu":6,"count":1}]	11199	pick-up	0	9
67272	2020-05-24 04:15:41	2020-05-24	12	[{"id_menu":1,"count":1}]	9312	delivery	5	17
67273	2020-05-24 04:17:53	2020-05-24	12	[{"id_menu":1,"count":1}]	6965	delivery	5	17
67274	2020-05-24 04:18:17	2020-05-24	9	[{"id_menu":6,"count":1}]	21076	delivery	5	14
67275	2020-05-24 04:19:53	2020-05-24	17	[{"id_menu":4,"count":2}]	26637	delivery	5	22
67276	2020-05-24 04:20:48	2020-05-24	8	[{"id_menu":5,"count":1}]	8597	delivery	5	13
67277	2020-05-24 04:21:05	2020-05-24	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	5301	delivery	5	29
67278	2020-05-24 04:22:14	2020-05-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9318	delivery	5	31
67279	2020-05-24 04:23:49	2020-05-24	9	[{"id_menu":6,"count":1}]	4546	pick-up	0	9
67280	2020-05-24 04:29:10	2020-05-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	20494	delivery	5	23
67281	2020-05-24 04:31:08	2020-05-24	14	[{"id_menu":2,"count":1}]	26690	delivery	5	19
67282	2020-05-24 04:33:29	2020-05-24	9	[{"id_menu":7,"count":1}]	8560	delivery	5	14
67283	2020-05-24 04:42:27	2020-05-24	8	[{"id_menu":5,"count":1}]	16237	delivery	5	13
67284	2020-05-24 04:44:37	2020-05-24	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7710	pick-up	0	38
67285	2020-05-24 04:47:51	2020-05-24	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	7251	delivery	5	40
67286	2020-05-24 04:51:13	2020-05-24	9	[{"id_menu":6,"count":1}]	23147	pick-up	0	9
67287	2020-05-24 04:52:32	2020-05-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	205	delivery	5	28
67288	2020-05-24 04:53:10	2020-05-24	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	23484	delivery	5	26
67289	2020-05-24 04:56:23	2020-05-24	17	[{"id_menu":4,"count":1}]	7900	delivery	5	22
67290	2020-05-24 05:00:08	2020-05-24	14	[{"id_menu":2,"count":1}]	22708	pick-up	0	14
67291	2020-05-24 05:01:06	2020-05-24	9	[{"id_menu":6,"count":1}]	19683	delivery	5	14
67292	2020-05-24 05:02:35	2020-05-24	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	26678	delivery	5	22
67293	2020-05-24 05:05:42	2020-05-24	12	[{"id_menu":1,"count":1}]	1435	pick-up	0	12
67294	2020-05-24 05:06:04	2020-05-24	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	25512	delivery	5	26
67295	2020-05-24 05:06:16	2020-05-24	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	8020	pick-up	0	24
67296	2020-05-24 05:07:06	2020-05-24	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3535	pick-up	0	26
67297	2020-05-24 05:12:06	2020-05-24	9	[{"id_menu":7,"count":1}]	18561	delivery	5	14
67298	2020-05-24 05:14:30	2020-05-24	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	5180	pick-up	0	21
67299	2020-05-24 05:17:31	2020-05-24	14	[{"id_menu":2,"count":2}]	7341	pick-up	0	14
67300	2020-05-24 05:17:39	2020-05-24	8	[{"id_menu":5,"count":1}]	26738	delivery	5	13
67301	2020-05-24 05:20:51	2020-05-24	9	[{"id_menu":6,"count":1}]	5649	delivery	5	14
67302	2020-05-24 05:23:50	2020-05-24	14	[{"id_menu":2,"count":1}]	26292	delivery	5	19
67303	2020-05-24 05:25:13	2020-05-24	9	[{"id_menu":7,"count":1}]	26747	delivery	5	14
67304	2020-05-24 05:32:31	2020-05-24	12	[{"id_menu":1,"count":1}]	22940	pick-up	0	12
67305	2020-05-24 05:34:23	2020-05-24	9	[{"id_menu":7,"count":1}]	24842	delivery	5	14
67306	2020-05-24 05:36:35	2020-05-24	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15371	delivery	5	39
67307	2020-05-24 05:38:11	2020-05-24	9	[{"id_menu":7,"count":1}]	26579	delivery	5	14
67308	2020-05-24 05:40:16	2020-05-24	17	[{"id_menu":4,"count":1}]	705	pick-up	0	17
67309	2020-05-24 05:42:45	2020-05-24	8	[{"id_menu":5,"count":1}]	26661	delivery	5	13
67310	2020-05-24 05:43:32	2020-05-24	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4075	delivery	5	26
67311	2020-05-24 05:52:18	2020-05-24	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	1303	delivery	5	43
67312	2020-05-24 05:53:07	2020-05-24	8	[{"id_menu":5,"count":1}]	26746	pick-up	0	8
67313	2020-05-24 05:56:12	2020-05-24	9	[{"id_menu":6,"count":1}]	12292	delivery	5	14
67314	2020-05-24 05:58:05	2020-05-24	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8098	pick-up	0	17
67315	2020-05-24 06:00:29	2020-05-24	8	[{"id_menu":5,"count":1}]	26623	delivery	5	13
67316	2020-05-24 06:02:37	2020-05-24	9	[{"id_menu":7,"count":1}]	26726	delivery	5	14
67317	2020-05-24 06:09:27	2020-05-24	9	[{"id_menu":7,"count":1}]	26566	delivery	5	14
67318	2020-05-24 06:10:38	2020-05-24	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	26612	delivery	5	23
67319	2020-05-24 06:15:31	2020-05-24	12	[{"id_menu":3,"count":1}]	26728	delivery	5	17
67320	2020-05-24 06:18:03	2020-05-24	9	[{"id_menu":7,"count":1}]	13248	delivery	5	14
67321	2020-05-24 06:20:36	2020-05-24	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	13048	delivery	5	23
67322	2020-05-24 06:20:59	2020-05-24	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8600	delivery	5	37
67323	2020-05-24 06:25:26	2020-05-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26681	delivery	5	23
67324	2020-05-24 06:27:53	2020-05-24	8	[{"id_menu":5,"count":1}]	26652	delivery	5	13
67325	2020-05-24 06:28:41	2020-05-24	12	[{"id_menu":3,"count":1}]	2494	pick-up	0	12
67326	2020-05-24 06:34:59	2020-05-24	14	[{"id_menu":2,"count":1}]	11246	pick-up	0	14
67327	2020-05-24 06:39:02	2020-05-24	12	[{"id_menu":3,"count":1}]	20302	delivery	5	17
67328	2020-05-24 06:40:24	2020-05-24	9	[{"id_menu":6,"count":3}]	13345	delivery	5	14
67329	2020-05-24 06:40:58	2020-05-24	9	[{"id_menu":6,"count":1}]	2374	pick-up	0	9
67330	2020-05-24 06:42:10	2020-05-24	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	19973	delivery	5	26
67331	2020-05-24 06:47:47	2020-05-24	9	[{"id_menu":7,"count":1}]	19490	pick-up	0	9
67332	2020-05-24 06:50:39	2020-05-24	14	[{"id_menu":2,"count":1}]	26710	delivery	5	19
67333	2020-05-24 06:51:22	2020-05-24	9	[{"id_menu":6,"count":1}]	14695	delivery	5	14
67334	2020-05-24 06:52:01	2020-05-24	49	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	26718	pick-up	0	49
67335	2020-05-24 06:54:33	2020-05-24	14	[{"id_menu":2,"count":1}]	19598	delivery	5	19
67336	2020-05-24 06:56:52	2020-05-24	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	19386	delivery	5	22
67337	2020-05-24 06:58:22	2020-05-24	9	[{"id_menu":6,"count":1}]	265	pick-up	0	9
67338	2020-05-24 07:02:13	2020-05-24	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	26676	pick-up	0	23
67339	2020-05-24 07:03:23	2020-05-24	9	[{"id_menu":6,"count":1}]	24411	delivery	5	14
67340	2020-05-24 07:08:47	2020-05-24	14	[{"id_menu":2,"count":1}]	8855	delivery	5	19
67341	2020-05-24 07:08:55	2020-05-24	12	[{"id_menu":1,"count":1}]	14410	delivery	5	17
67342	2020-05-24 07:10:24	2020-05-24	14	[{"id_menu":2,"count":1}]	18810	pick-up	0	14
67343	2020-05-24 07:14:44	2020-05-24	12	[{"id_menu":1,"count":1}]	26601	delivery	5	17
67344	2020-05-24 07:20:24	2020-05-24	9	[{"id_menu":7,"count":1}]	26748	delivery	5	14
67345	2020-05-24 07:21:16	2020-05-24	17	[{"id_menu":4,"count":1}]	17795	delivery	5	22
67346	2020-05-24 07:21:16	2020-05-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	26749	delivery	5	22
67347	2020-05-24 07:21:55	2020-05-24	9	[{"id_menu":7,"count":1}]	26741	delivery	5	14
67348	2020-05-24 07:24:43	2020-05-24	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	13453	delivery	5	40
67349	2020-05-24 07:28:07	2020-05-24	9	[{"id_menu":6,"count":1}]	26729	delivery	5	14
67350	2020-05-24 07:32:39	2020-05-24	9	[{"id_menu":6,"count":1}]	511	pick-up	0	9
67351	2020-05-24 07:36:20	2020-05-24	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26677	delivery	5	35
67352	2020-05-24 07:43:59	2020-05-24	9	[{"id_menu":6,"count":1}]	26734	delivery	5	14
67353	2020-05-24 07:44:50	2020-05-24	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	11254	delivery	5	31
67354	2020-05-24 07:47:22	2020-05-24	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17964	delivery	5	43
67355	2020-05-24 07:48:33	2020-05-24	12	[{"id_menu":1,"count":1}]	9157	delivery	5	17
67356	2020-05-24 07:48:54	2020-05-24	8	[{"id_menu":5,"count":1}]	26725	delivery	5	13
67357	2020-05-24 07:52:21	2020-05-24	12	[{"id_menu":1,"count":1}]	26651	pick-up	0	12
67358	2020-05-24 07:53:23	2020-05-24	12	[{"id_menu":1,"count":1}]	29	delivery	5	17
67359	2020-05-24 07:54:54	2020-05-24	12	[{"id_menu":3,"count":1}]	26629	delivery	5	17
67360	2020-05-24 08:02:56	2020-05-24	12	[{"id_menu":3,"count":1}]	9444	delivery	5	17
67361	2020-05-24 08:03:09	2020-05-24	8	[{"id_menu":5,"count":1}]	5514	pick-up	0	8
67362	2020-05-24 08:03:35	2020-05-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	8024	delivery	5	28
67363	2020-05-24 08:08:04	2020-05-24	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13172	delivery	5	36
67364	2020-05-24 08:10:08	2020-05-24	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	26603	pick-up	0	34
67365	2020-05-24 08:11:48	2020-05-24	8	[{"id_menu":5,"count":1}]	26602	delivery	5	13
67366	2020-05-24 08:12:06	2020-05-24	9	[{"id_menu":7,"count":1}]	26668	delivery	5	14
67367	2020-05-24 08:13:16	2020-05-24	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17977	delivery	5	31
67368	2020-05-24 08:13:31	2020-05-24	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	8683	delivery	5	31
67369	2020-05-24 08:19:23	2020-05-24	9	[{"id_menu":6,"count":1}]	19442	pick-up	0	9
67370	2020-05-24 08:19:50	2020-05-24	12	[{"id_menu":1,"count":1}]	14696	delivery	5	17
67371	2020-05-24 08:22:47	2020-05-24	12	[{"id_menu":3,"count":1}]	26659	delivery	5	17
67372	2020-05-24 08:24:42	2020-05-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1979	delivery	5	28
67373	2020-05-24 08:27:15	2020-05-24	9	[{"id_menu":6,"count":1}]	10385	pick-up	0	9
67374	2020-05-24 08:29:08	2020-05-24	12	[{"id_menu":3,"count":1}]	26609	delivery	5	17
67375	2020-05-24 08:29:50	2020-05-24	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	11834	delivery	5	38
67376	2020-05-24 08:30:34	2020-05-24	8	[{"id_menu":5,"count":1}]	4981	delivery	5	13
67377	2020-05-24 08:30:36	2020-05-24	14	[{"id_menu":2,"count":1}]	26631	delivery	5	19
67378	2020-05-24 08:31:43	2020-05-24	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2071	delivery	5	42
67379	2020-05-24 08:35:02	2020-05-24	8	[{"id_menu":5,"count":2}]	15689	delivery	5	13
67380	2020-05-24 08:35:15	2020-05-24	8	[{"id_menu":5,"count":1}]	171	pick-up	0	8
67381	2020-05-24 08:38:00	2020-05-24	12	[{"id_menu":1,"count":1}]	15578	delivery	5	17
67382	2020-05-24 08:40:04	2020-05-24	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2170	pick-up	0	22
67383	2020-05-24 08:40:33	2020-05-24	9	[{"id_menu":7,"count":1}]	7691	pick-up	0	9
67384	2020-05-24 08:45:22	2020-05-24	9	[{"id_menu":6,"count":1}]	11616	delivery	5	14
67385	2020-05-24 08:47:36	2020-05-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	22713	delivery	5	28
67386	2020-05-24 08:48:19	2020-05-24	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	26608	delivery	5	35
67387	2020-05-24 08:54:13	2020-05-24	17	[{"id_menu":4,"count":1}]	177	delivery	5	22
67388	2020-05-24 08:55:05	2020-05-24	8	[{"id_menu":5,"count":1}]	16271	delivery	5	13
67389	2020-05-24 09:03:13	2020-05-24	14	[{"id_menu":2,"count":1}]	26715	delivery	5	19
67390	2020-05-24 09:04:13	2020-05-24	8	[{"id_menu":5,"count":1}]	4089	pick-up	0	8
67391	2020-05-24 09:05:03	2020-05-24	14	[{"id_menu":2,"count":1}]	9996	delivery	5	19
67392	2020-05-24 09:05:29	2020-05-24	17	[{"id_menu":4,"count":1}]	26735	delivery	5	22
67393	2020-05-24 09:09:09	2020-05-24	12	[{"id_menu":1,"count":1}]	26684	pick-up	0	12
67394	2020-05-24 09:10:56	2020-05-24	12	[{"id_menu":1,"count":1}]	16789	delivery	5	17
67395	2020-05-24 09:11:20	2020-05-24	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	26745	delivery	5	31
67396	2020-05-24 09:16:25	2020-05-24	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	18700	delivery	5	23
67397	2020-05-24 09:19:19	2020-05-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5771	delivery	5	31
67398	2020-05-24 09:19:37	2020-05-24	9	[{"id_menu":6,"count":1}]	26645	pick-up	0	9
67399	2020-05-24 09:23:14	2020-05-24	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1343	pick-up	0	38
67400	2020-05-24 09:27:12	2020-05-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	26585	delivery	5	22
67401	2020-05-24 09:27:56	2020-05-24	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	26615	delivery	5	36
67402	2020-05-24 09:28:06	2020-05-24	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	5286	pick-up	0	26
67403	2020-05-24 09:31:48	2020-05-24	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	11535	delivery	5	22
67404	2020-05-24 09:31:58	2020-05-24	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	26743	delivery	5	38
67405	2020-05-24 09:33:42	2020-05-24	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	26493	delivery	5	22
67406	2020-05-24 09:35:12	2020-05-24	14	[{"id_menu":2,"count":1}]	12320	delivery	5	19
67407	2020-05-24 09:35:34	2020-05-24	17	[{"id_menu":4,"count":1}]	11681	pick-up	0	17
67408	2020-05-24 09:35:55	2020-05-24	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	26595	delivery	5	26
67409	2020-05-24 09:39:59	2020-05-24	9	[{"id_menu":6,"count":1}]	26709	delivery	5	14
67410	2020-05-24 09:42:30	2020-05-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23990	delivery	5	23
67411	2020-05-24 09:45:25	2020-05-24	12	[{"id_menu":3,"count":1}]	26712	delivery	5	17
67412	2020-05-24 09:45:36	2020-05-24	8	[{"id_menu":5,"count":1}]	26582	delivery	5	13
67413	2020-05-24 09:48:01	2020-05-24	12	[{"id_menu":3,"count":1}]	13136	pick-up	0	12
67414	2020-05-24 09:50:34	2020-05-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9682	pick-up	0	18
67415	2020-05-24 09:50:37	2020-05-24	9	[{"id_menu":7,"count":1}]	2518	pick-up	0	9
67416	2020-05-24 09:51:53	2020-05-24	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	26675	delivery	5	40
67417	2020-05-24 09:53:04	2020-05-24	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25550	delivery	5	36
67418	2020-05-24 09:53:51	2020-05-24	9	[{"id_menu":6,"count":1}]	16459	delivery	5	14
67419	2020-05-24 09:59:04	2020-05-24	14	[{"id_menu":2,"count":1}]	2078	pick-up	0	14
67420	2020-05-24 10:00:28	2020-05-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	26707	delivery	5	28
67421	2020-05-24 10:01:39	2020-05-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3115	pick-up	0	26
67422	2020-05-24 10:01:53	2020-05-24	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	26644	pick-up	0	26
67423	2020-05-24 10:03:12	2020-05-24	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	13461	pick-up	0	26
67424	2020-05-24 10:03:35	2020-05-24	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3230	delivery	5	38
67425	2020-05-24 10:10:05	2020-05-24	9	[{"id_menu":7,"count":1}]	26737	delivery	5	14
67426	2020-05-24 10:10:15	2020-05-24	14	[{"id_menu":2,"count":1}]	26694	pick-up	0	14
67427	2020-05-24 10:15:06	2020-05-24	9	[{"id_menu":6,"count":1}]	25097	delivery	5	14
67428	2020-05-24 10:23:07	2020-05-24	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21151	delivery	5	47
67429	2020-05-24 10:24:09	2020-05-24	17	[{"id_menu":4,"count":1}]	14735	pick-up	0	17
67430	2020-05-24 10:24:43	2020-05-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	12231	delivery	5	28
67431	2020-05-24 10:27:25	2020-05-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11835	delivery	5	23
67432	2020-05-24 10:39:37	2020-05-24	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	8872	delivery	5	36
67433	2020-05-24 10:44:38	2020-05-24	14	[{"id_menu":2,"count":1}]	5473	pick-up	0	14
67434	2020-05-24 10:46:09	2020-05-24	14	[{"id_menu":2,"count":1}]	1545	delivery	5	19
67435	2020-05-24 10:46:15	2020-05-24	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	26696	delivery	5	27
67436	2020-05-24 10:47:54	2020-05-24	8	[{"id_menu":5,"count":1}]	9907	pick-up	0	8
67437	2020-05-24 10:49:30	2020-05-24	9	[{"id_menu":7,"count":1}]	11067	delivery	5	14
67438	2020-05-24 10:51:27	2020-05-24	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	9030	delivery	5	31
67439	2020-05-24 10:52:26	2020-05-24	8	[{"id_menu":5,"count":1}]	26614	delivery	5	13
67440	2020-05-24 10:53:35	2020-05-24	17	[{"id_menu":4,"count":1}]	6756	delivery	5	22
67441	2020-05-24 10:55:49	2020-05-24	8	[{"id_menu":5,"count":1}]	17695	delivery	5	13
67442	2020-05-24 10:57:12	2020-05-24	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5449	pick-up	0	38
67443	2020-05-24 10:59:44	2020-05-24	12	[{"id_menu":3,"count":1}]	140	pick-up	0	12
67444	2020-05-24 11:01:58	2020-05-24	12	[{"id_menu":3,"count":1}]	12759	delivery	5	17
67445	2020-05-24 11:03:41	2020-05-24	9	[{"id_menu":6,"count":1}]	20342	delivery	5	14
67446	2020-05-24 11:16:05	2020-05-24	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4577	pick-up	0	52
67447	2020-05-24 11:17:46	2020-05-24	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	26658	delivery	5	31
67448	2020-05-24 11:23:13	2020-05-24	9	[{"id_menu":7,"count":1}]	6971	delivery	5	14
67449	2020-05-24 11:29:16	2020-05-24	14	[{"id_menu":2,"count":1}]	26736	delivery	5	19
67450	2020-05-24 11:29:58	2020-05-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26625	delivery	5	23
67451	2020-05-24 11:32:29	2020-05-24	14	[{"id_menu":2,"count":1}]	14185	delivery	5	19
67452	2020-05-24 11:34:27	2020-05-24	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3531	delivery	5	26
67453	2020-05-24 11:35:00	2020-05-24	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	24727	delivery	5	39
67454	2020-05-24 11:38:21	2020-05-24	17	[{"id_menu":4,"count":1}]	10369	delivery	5	22
67455	2020-05-24 11:40:48	2020-05-24	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16383	delivery	5	49
67456	2020-05-24 11:41:03	2020-05-24	14	[{"id_menu":2,"count":1}]	26628	delivery	5	19
67457	2020-05-24 11:43:58	2020-05-24	9	[{"id_menu":7,"count":1}]	26721	delivery	5	14
67458	2020-05-24 11:45:06	2020-05-24	17	[{"id_menu":4,"count":1}]	5857	pick-up	0	17
67459	2020-05-24 11:45:08	2020-05-24	8	[{"id_menu":5,"count":2}]	16231	delivery	5	13
67460	2020-05-24 11:45:25	2020-05-24	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	25299	delivery	5	25
67461	2020-05-24 11:48:17	2020-05-24	8	[{"id_menu":5,"count":1}]	15715	delivery	5	13
67462	2020-05-24 11:49:23	2020-05-24	9	[{"id_menu":6,"count":1}]	26600	pick-up	0	9
67463	2020-05-24 11:52:02	2020-05-24	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	26702	delivery	5	43
67464	2020-05-24 11:55:42	2020-05-24	9	[{"id_menu":7,"count":2}]	20304	pick-up	0	9
67465	2020-05-24 11:58:45	2020-05-24	9	[{"id_menu":6,"count":1}]	26687	delivery	5	14
67466	2020-05-24 11:59:38	2020-05-24	9	[{"id_menu":7,"count":1}]	8014	pick-up	0	9
67467	2020-05-24 12:01:56	2020-05-24	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	26656	delivery	5	26
67468	2020-05-24 12:05:25	2020-05-24	14	[{"id_menu":2,"count":1}]	26688	delivery	5	19
67469	2020-05-24 12:07:19	2020-05-24	39	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7709	delivery	5	44
67470	2020-05-24 12:10:26	2020-05-24	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	18271	delivery	5	26
67471	2020-05-24 12:12:10	2020-05-24	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	26640	delivery	5	25
67472	2020-05-24 12:15:29	2020-05-24	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	26248	delivery	5	36
67473	2020-05-24 12:16:13	2020-05-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	26583	pick-up	0	23
67474	2020-05-24 12:18:46	2020-05-24	14	[{"id_menu":2,"count":1}]	23445	delivery	5	19
67475	2020-05-24 12:20:35	2020-05-24	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26632	delivery	5	37
67476	2020-05-24 12:28:03	2020-05-24	12	[{"id_menu":3,"count":1}]	22865	delivery	5	17
67477	2020-05-24 12:34:31	2020-05-24	12	[{"id_menu":1,"count":1}]	5318	pick-up	0	12
67478	2020-05-24 12:36:03	2020-05-24	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	11806	delivery	5	26
67479	2020-05-24 12:37:35	2020-05-24	8	[{"id_menu":5,"count":1}]	12420	pick-up	0	8
67480	2020-05-24 12:39:28	2020-05-24	9	[{"id_menu":6,"count":1}]	14873	delivery	5	14
67481	2020-05-24 12:43:06	2020-05-24	14	[{"id_menu":2,"count":1}]	2827	pick-up	0	14
67482	2020-05-24 12:45:21	2020-05-24	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	26592	delivery	5	23
67483	2020-05-24 12:45:28	2020-05-24	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	26621	delivery	5	40
67484	2020-05-24 12:47:38	2020-05-24	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	26635	delivery	5	26
67485	2020-05-24 12:49:12	2020-05-24	17	[{"id_menu":4,"count":1}]	26708	delivery	5	22
67486	2020-05-24 12:53:59	2020-05-24	12	[{"id_menu":3,"count":1}]	228	delivery	5	17
67487	2020-05-24 12:55:25	2020-05-24	9	[{"id_menu":6,"count":1}]	26589	delivery	5	14
67488	2020-05-24 12:56:46	2020-05-24	17	[{"id_menu":4,"count":1}]	13134	delivery	5	22
67489	2020-05-24 12:57:03	2020-05-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	26596	delivery	5	28
67490	2020-05-24 13:05:52	2020-05-24	17	[{"id_menu":4,"count":1}]	14127	delivery	5	22
67491	2020-05-24 13:08:10	2020-05-24	9	[{"id_menu":7,"count":1}]	26646	delivery	5	14
67492	2020-05-24 13:11:18	2020-05-24	12	[{"id_menu":3,"count":1}]	7835	delivery	5	17
67493	2020-05-24 13:11:18	2020-05-24	9	[{"id_menu":7,"count":1}]	18939	delivery	5	14
67494	2020-05-24 13:12:45	2020-05-24	12	[{"id_menu":1,"count":1}]	26695	delivery	5	17
67495	2020-05-24 13:14:21	2020-05-24	9	[{"id_menu":6,"count":1}]	5831	delivery	5	14
67496	2020-05-24 13:15:08	2020-05-24	14	[{"id_menu":2,"count":1}]	5518	delivery	5	19
67497	2020-05-24 13:15:51	2020-05-24	9	[{"id_menu":6,"count":1}]	16170	delivery	5	14
67498	2020-05-24 13:18:46	2020-05-24	14	[{"id_menu":2,"count":1}]	7589	pick-up	0	14
67499	2020-05-24 13:19:47	2020-05-24	9	[{"id_menu":7,"count":1}]	26723	delivery	5	14
67500	2020-05-24 13:20:34	2020-05-24	14	[{"id_menu":2,"count":1}]	21583	delivery	5	19
67501	2020-05-24 13:26:23	2020-05-24	8	[{"id_menu":5,"count":1}]	22450	delivery	5	13
67502	2020-05-24 13:30:24	2020-05-24	14	[{"id_menu":2,"count":1}]	26567	delivery	5	19
67503	2020-05-24 13:30:43	2020-05-24	8	[{"id_menu":5,"count":1}]	16388	delivery	5	13
67504	2020-05-24 13:31:23	2020-05-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	26689	delivery	5	28
67505	2020-05-24 13:32:42	2020-05-24	14	[{"id_menu":2,"count":1}]	26669	delivery	5	19
67506	2020-05-24 13:33:12	2020-05-24	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11934	delivery	5	35
67507	2020-05-24 13:41:49	2020-05-24	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	26732	delivery	5	29
67508	2020-05-24 13:42:33	2020-05-24	9	[{"id_menu":7,"count":1}]	23274	delivery	5	14
67509	2020-05-24 13:43:10	2020-05-24	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	23552	delivery	5	44
67510	2020-05-24 13:43:45	2020-05-24	12	[{"id_menu":1,"count":1}]	2923	delivery	5	17
67511	2020-05-24 13:48:20	2020-05-24	9	[{"id_menu":7,"count":1}]	19899	pick-up	0	9
67512	2020-05-24 13:52:04	2020-05-24	12	[{"id_menu":3,"count":1}]	1172	pick-up	0	12
67513	2020-05-24 13:54:36	2020-05-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7790	delivery	5	22
67514	2020-05-24 13:57:26	2020-05-24	14	[{"id_menu":2,"count":1}]	26739	pick-up	0	14
67515	2020-05-24 13:57:41	2020-05-24	12	[{"id_menu":1,"count":1}]	4028	pick-up	0	12
67516	2020-05-24 14:00:45	2020-05-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	26662	delivery	5	28
67517	2020-05-24 14:02:31	2020-05-24	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	10287	delivery	5	48
67518	2020-05-24 14:05:39	2020-05-24	8	[{"id_menu":5,"count":2}]	466	delivery	5	13
67519	2020-05-24 14:09:33	2020-05-24	12	[{"id_menu":1,"count":1}]	931	delivery	5	17
67520	2020-05-24 14:09:56	2020-05-24	14	[{"id_menu":2,"count":1}]	4486	pick-up	0	14
67521	2020-05-24 14:13:07	2020-05-24	12	[{"id_menu":3,"count":1}]	17373	delivery	5	17
67522	2020-05-24 14:17:20	2020-05-24	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26617	delivery	5	31
67523	2020-05-24 14:22:19	2020-05-24	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	23099	delivery	5	34
67524	2020-05-24 14:24:03	2020-05-24	14	[{"id_menu":2,"count":1}]	16951	delivery	5	19
67525	2020-05-24 14:25:39	2020-05-24	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6019	delivery	5	30
67526	2020-05-24 14:27:49	2020-05-24	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	17721	delivery	5	26
67527	2020-05-24 14:29:10	2020-05-24	8	[{"id_menu":5,"count":1}]	26705	delivery	5	13
67528	2020-05-24 14:32:04	2020-05-24	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	13355	delivery	5	26
67529	2020-05-24 14:32:11	2020-05-24	12	[{"id_menu":3,"count":1}]	4833	delivery	5	17
67530	2020-05-24 14:32:26	2020-05-24	12	[{"id_menu":1,"count":2}]	12654	pick-up	0	12
67531	2020-05-24 14:33:41	2020-05-24	9	[{"id_menu":7,"count":1}]	634	pick-up	0	9
67532	2020-05-24 14:40:53	2020-05-24	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	11208	delivery	5	40
67533	2020-05-24 14:41:39	2020-05-24	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23006	delivery	5	35
67534	2020-05-24 14:42:18	2020-05-24	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	26607	delivery	5	34
67535	2020-05-24 14:42:38	2020-05-24	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2252	pick-up	0	37
67536	2020-05-24 14:43:58	2020-05-24	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1255	pick-up	0	26
67537	2020-05-24 14:44:50	2020-05-24	8	[{"id_menu":5,"count":1}]	18316	pick-up	0	8
67538	2020-05-24 14:45:13	2020-05-24	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	22871	delivery	5	29
67539	2020-05-24 14:45:47	2020-05-24	14	[{"id_menu":2,"count":1}]	26665	pick-up	0	14
67540	2020-05-24 14:51:12	2020-05-24	17	[{"id_menu":4,"count":1}]	16295	pick-up	0	17
67541	2020-05-24 14:51:41	2020-05-24	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	26713	delivery	5	22
67542	2020-05-24 14:51:42	2020-05-24	9	[{"id_menu":6,"count":1}]	4409	pick-up	0	9
67543	2020-05-24 14:59:19	2020-05-24	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	19767	delivery	5	40
67544	2020-05-24 15:05:05	2020-05-24	8	[{"id_menu":5,"count":1}]	20957	delivery	5	13
67545	2020-05-24 15:11:40	2020-05-24	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	26731	delivery	5	31
67546	2020-05-24 15:13:35	2020-05-24	8	[{"id_menu":5,"count":1}]	5756	pick-up	0	8
67547	2020-05-24 15:13:53	2020-05-24	9	[{"id_menu":6,"count":1}]	348	pick-up	0	9
67548	2020-05-24 15:16:08	2020-05-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	22535	delivery	5	31
67549	2020-05-24 15:23:41	2020-05-24	9	[{"id_menu":6,"count":1}]	11764	pick-up	0	9
67550	2020-05-24 15:23:46	2020-05-24	8	[{"id_menu":5,"count":1}]	22804	delivery	5	13
67551	2020-05-24 15:24:11	2020-05-24	8	[{"id_menu":5,"count":1}]	11816	delivery	5	13
67552	2020-05-24 15:24:34	2020-05-24	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	17879	delivery	5	45
67553	2020-05-24 15:25:33	2020-05-24	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	26587	delivery	5	31
67554	2020-05-24 15:28:59	2020-05-24	8	[{"id_menu":5,"count":2}]	16705	delivery	5	13
67555	2020-05-24 15:29:20	2020-05-24	8	[{"id_menu":5,"count":1}]	5642	pick-up	0	8
67556	2020-05-24 15:31:19	2020-05-24	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	412	pick-up	0	26
67557	2020-05-24 15:33:07	2020-05-24	9	[{"id_menu":6,"count":3}]	20022	delivery	5	14
67558	2020-05-24 15:34:15	2020-05-24	12	[{"id_menu":3,"count":1}]	9507	delivery	5	17
67559	2020-05-24 15:35:21	2020-05-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	22137	delivery	5	31
67560	2020-05-24 15:35:55	2020-05-24	9	[{"id_menu":7,"count":1}]	26699	delivery	5	14
67561	2020-05-24 15:36:01	2020-05-24	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	16422	pick-up	0	31
67562	2020-05-24 15:37:21	2020-05-24	12	[{"id_menu":1,"count":1}]	26742	delivery	5	17
67563	2020-05-24 15:39:02	2020-05-24	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	26576	delivery	5	26
67564	2020-05-24 15:40:43	2020-05-24	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14504	delivery	5	40
67565	2020-05-24 15:44:06	2020-05-24	14	[{"id_menu":2,"count":1}]	25053	delivery	5	19
67566	2020-05-24 15:44:55	2020-05-24	14	[{"id_menu":2,"count":1}]	4064	delivery	5	19
67567	2020-05-24 15:46:06	2020-05-24	14	[{"id_menu":2,"count":1}]	13337	pick-up	0	14
67568	2020-05-24 15:51:57	2020-05-24	12	[{"id_menu":3,"count":1}]	19503	delivery	5	17
67569	2020-05-24 15:53:49	2020-05-24	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	26605	delivery	5	34
67570	2020-05-24 15:54:07	2020-05-24	8	[{"id_menu":5,"count":1}]	23912	delivery	5	13
67571	2020-05-24 15:57:42	2020-05-24	9	[{"id_menu":6,"count":1}]	10482	pick-up	0	9
67572	2020-05-24 15:58:34	2020-05-24	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	292	delivery	5	43
67573	2020-05-24 15:59:25	2020-05-24	9	[{"id_menu":6,"count":1}]	5861	delivery	5	14
67574	2020-05-24 16:00:20	2020-05-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26343	delivery	5	23
67575	2020-05-24 16:02:48	2020-05-24	14	[{"id_menu":2,"count":1}]	26573	delivery	5	19
67576	2020-05-24 16:03:35	2020-05-24	8	[{"id_menu":5,"count":1}]	2426	pick-up	0	8
67577	2020-05-24 16:06:26	2020-05-24	9	[{"id_menu":7,"count":1}]	15752	delivery	5	14
67578	2020-05-24 16:07:57	2020-05-24	12	[{"id_menu":3,"count":1}]	640	delivery	5	17
67579	2020-05-24 16:09:15	2020-05-24	8	[{"id_menu":5,"count":1}]	13994	delivery	5	13
67580	2020-05-24 16:19:32	2020-05-24	8	[{"id_menu":5,"count":1}]	26724	pick-up	0	8
67581	2020-05-24 16:19:43	2020-05-24	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	6869	pick-up	0	21
67582	2020-05-24 16:21:26	2020-05-24	17	[{"id_menu":4,"count":1}]	13537	pick-up	0	17
67583	2020-05-24 16:22:18	2020-05-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	16037	delivery	5	31
67584	2020-05-24 16:22:40	2020-05-24	9	[{"id_menu":7,"count":2}]	26604	delivery	5	14
67585	2020-05-24 16:25:22	2020-05-24	17	[{"id_menu":4,"count":1}]	26580	pick-up	0	17
67586	2020-05-24 16:26:13	2020-05-24	12	[{"id_menu":1,"count":1}]	26647	delivery	5	17
67587	2020-05-24 16:28:55	2020-05-24	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	19313	delivery	5	26
67588	2020-05-24 16:30:04	2020-05-24	9	[{"id_menu":7,"count":1}]	25082	delivery	5	14
67589	2020-05-24 16:31:44	2020-05-24	12	[{"id_menu":3,"count":1}]	2179	pick-up	0	12
67590	2020-05-24 16:31:59	2020-05-24	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23764	delivery	5	36
67591	2020-05-24 16:32:23	2020-05-24	14	[{"id_menu":2,"count":1}]	24381	delivery	5	19
67592	2020-05-24 16:36:01	2020-05-24	9	[{"id_menu":6,"count":1}]	26564	delivery	5	14
67593	2020-05-24 16:40:06	2020-05-24	9	[{"id_menu":6,"count":1}]	26711	delivery	5	14
67594	2020-05-24 16:40:47	2020-05-24	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	26568	pick-up	0	25
67595	2020-05-24 16:45:04	2020-05-24	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3911	delivery	5	34
67596	2020-05-24 16:45:43	2020-05-24	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	26720	delivery	5	30
67597	2020-05-24 16:46:54	2020-05-24	12	[{"id_menu":3,"count":2}]	3852	pick-up	0	12
67598	2020-05-24 16:48:01	2020-05-24	17	[{"id_menu":4,"count":1}]	20341	delivery	5	22
67599	2020-05-24 16:48:19	2020-05-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13371	delivery	5	22
67600	2020-05-24 16:49:09	2020-05-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26577	delivery	5	23
67601	2020-05-24 16:50:17	2020-05-24	17	[{"id_menu":4,"count":2}]	18063	pick-up	0	17
67602	2020-05-24 16:50:55	2020-05-24	12	[{"id_menu":1,"count":1}]	26619	delivery	5	17
67603	2020-05-24 16:50:56	2020-05-24	12	[{"id_menu":3,"count":1}]	26660	delivery	5	17
67604	2020-05-24 16:52:22	2020-05-24	8	[{"id_menu":5,"count":1}]	21395	delivery	5	13
67605	2020-05-24 16:52:36	2020-05-24	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1514	delivery	5	54
67606	2020-05-24 16:52:55	2020-05-24	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	22201	delivery	5	31
67607	2020-05-24 16:54:39	2020-05-24	12	[{"id_menu":1,"count":1}]	22605	pick-up	0	12
67608	2020-05-24 16:56:05	2020-05-24	9	[{"id_menu":6,"count":1}]	12700	delivery	5	14
67609	2020-05-24 16:56:48	2020-05-24	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	12709	pick-up	0	25
67610	2020-05-24 17:03:29	2020-05-24	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	11600	delivery	5	31
67611	2020-05-24 17:03:46	2020-05-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	22740	delivery	5	28
67612	2020-05-24 17:04:18	2020-05-24	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	26700	delivery	5	26
67613	2020-05-24 17:06:38	2020-05-24	17	[{"id_menu":4,"count":1}]	21163	delivery	5	22
67614	2020-05-24 17:09:30	2020-05-24	9	[{"id_menu":7,"count":2}]	26574	delivery	5	14
67615	2020-05-24 17:10:10	2020-05-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":3}]	5140	delivery	5	31
67616	2020-05-24 17:11:00	2020-05-24	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	26751	delivery	5	45
67617	2020-05-24 17:12:33	2020-05-24	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5873	delivery	5	49
67618	2020-05-24 17:15:02	2020-05-24	9	[{"id_menu":6,"count":2}]	26691	pick-up	0	9
67619	2020-05-24 17:16:13	2020-05-24	12	[{"id_menu":1,"count":1}]	16011	delivery	5	17
67620	2020-05-24 17:16:39	2020-05-24	9	[{"id_menu":6,"count":1}]	26717	delivery	5	14
67621	2020-05-24 17:23:21	2020-05-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	15616	delivery	5	28
67622	2020-05-24 17:23:36	2020-05-24	14	[{"id_menu":2,"count":1}]	18839	delivery	5	19
67623	2020-05-24 17:26:04	2020-05-24	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15244	delivery	5	31
67624	2020-05-24 17:26:36	2020-05-24	8	[{"id_menu":5,"count":1}]	1655	delivery	5	13
67625	2020-05-24 17:26:58	2020-05-24	17	[{"id_menu":4,"count":1}]	9421	delivery	5	22
67626	2020-05-24 17:33:52	2020-05-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	23312	pick-up	0	23
67627	2020-05-24 17:35:01	2020-05-24	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	26581	delivery	5	22
67628	2020-05-24 17:37:18	2020-05-24	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	26643	delivery	5	38
67629	2020-05-24 17:37:52	2020-05-24	12	[{"id_menu":1,"count":1}]	26653	delivery	5	17
67630	2020-05-24 17:38:39	2020-05-24	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	22912	pick-up	0	22
67631	2020-05-24 17:40:52	2020-05-24	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4995	pick-up	0	26
67632	2020-05-24 17:42:17	2020-05-24	17	[{"id_menu":4,"count":1}]	16926	pick-up	0	17
67633	2020-05-24 17:42:31	2020-05-24	17	[{"id_menu":4,"count":1}]	2443	pick-up	0	17
67634	2020-05-24 17:42:59	2020-05-24	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5527	delivery	5	31
67635	2020-05-24 17:43:45	2020-05-24	9	[{"id_menu":7,"count":1}]	13017	delivery	5	14
67636	2020-05-24 17:45:05	2020-05-24	8	[{"id_menu":5,"count":1}]	1204	delivery	5	13
67637	2020-05-24 17:46:27	2020-05-24	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22326	delivery	5	45
67638	2020-05-24 17:47:39	2020-05-24	14	[{"id_menu":2,"count":1}]	26618	delivery	5	19
67639	2020-05-24 17:48:20	2020-05-24	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	26657	delivery	5	31
67640	2020-05-24 17:49:27	2020-05-24	9	[{"id_menu":7,"count":1}]	6055	delivery	5	14
67641	2020-05-24 17:53:59	2020-05-24	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	10988	pick-up	0	29
67642	2020-05-24 17:56:03	2020-05-24	12	[{"id_menu":3,"count":1}]	17435	delivery	5	17
67643	2020-05-24 17:57:39	2020-05-24	12	[{"id_menu":3,"count":1}]	19006	delivery	5	17
67644	2020-05-24 18:13:14	2020-05-24	8	[{"id_menu":5,"count":1}]	1819	pick-up	0	8
67645	2020-05-24 18:14:32	2020-05-24	14	[{"id_menu":2,"count":1}]	2959	pick-up	0	14
67646	2020-05-24 18:19:30	2020-05-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17503	delivery	5	22
67647	2020-05-24 18:20:47	2020-05-24	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26627	delivery	5	37
67648	2020-05-24 18:23:03	2020-05-24	8	[{"id_menu":5,"count":1}]	6195	pick-up	0	8
67649	2020-05-24 18:23:20	2020-05-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22827	delivery	5	23
67650	2020-05-24 18:25:18	2020-05-24	9	[{"id_menu":6,"count":2}]	26633	delivery	5	14
67651	2020-05-24 18:27:43	2020-05-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	21862	delivery	5	28
67652	2020-05-24 18:29:08	2020-05-24	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10644	delivery	5	56
67653	2020-05-24 18:31:24	2020-05-24	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	15131	delivery	5	31
67654	2020-05-24 18:31:38	2020-05-24	14	[{"id_menu":2,"count":1}]	26613	delivery	5	19
67655	2020-05-24 18:33:26	2020-05-24	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	13613	pick-up	0	29
67656	2020-05-24 18:35:30	2020-05-24	14	[{"id_menu":2,"count":1}]	26642	pick-up	0	14
67657	2020-05-24 18:38:50	2020-05-24	30	[{"id_menu":3,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25772	delivery	5	35
67658	2020-05-24 18:39:53	2020-05-24	17	[{"id_menu":4,"count":1}]	26639	delivery	5	22
67659	2020-05-24 18:41:21	2020-05-24	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	24663	delivery	5	56
67660	2020-05-24 18:43:11	2020-05-24	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9011	delivery	5	51
67661	2020-05-24 18:43:21	2020-05-24	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8934	delivery	5	35
67662	2020-05-24 18:44:09	2020-05-24	14	[{"id_menu":2,"count":2}]	19208	pick-up	0	14
67663	2020-05-24 18:46:06	2020-05-24	12	[{"id_menu":1,"count":2}]	1972	delivery	5	17
67664	2020-05-24 18:50:16	2020-05-24	8	[{"id_menu":5,"count":1}]	26727	delivery	5	13
67665	2020-05-24 18:51:05	2020-05-24	9	[{"id_menu":7,"count":1}]	26624	delivery	5	14
67666	2020-05-24 18:52:34	2020-05-24	12	[{"id_menu":3,"count":2}]	22913	delivery	5	17
67667	2020-05-24 18:56:41	2020-05-24	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4825	delivery	5	34
67668	2020-05-24 18:56:46	2020-05-24	12	[{"id_menu":1,"count":1}]	10598	delivery	5	17
67669	2020-05-24 18:57:38	2020-05-24	17	[{"id_menu":4,"count":1}]	18755	delivery	5	22
67670	2020-05-24 18:59:13	2020-05-24	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3858	delivery	5	30
67671	2020-05-24 19:00:44	2020-05-24	12	[{"id_menu":3,"count":1}]	7446	delivery	5	17
67672	2020-05-24 19:03:56	2020-05-24	9	[{"id_menu":7,"count":1}]	26598	delivery	5	14
67673	2020-05-24 19:05:35	2020-05-24	9	[{"id_menu":6,"count":1}]	26586	delivery	5	14
67674	2020-05-24 19:06:11	2020-05-24	17	[{"id_menu":4,"count":1}]	26655	delivery	5	22
67675	2020-05-24 19:10:27	2020-05-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9946	delivery	5	28
67676	2020-05-24 19:11:43	2020-05-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3314	delivery	5	28
67677	2020-05-24 19:12:02	2020-05-24	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	7869	delivery	5	39
67678	2020-05-24 19:18:54	2020-05-24	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26740	delivery	5	35
67679	2020-05-24 19:20:11	2020-05-24	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	26636	delivery	5	30
67680	2020-05-24 19:23:20	2020-05-24	9	[{"id_menu":7,"count":1}]	26698	delivery	5	14
67681	2020-05-24 19:23:25	2020-05-24	8	[{"id_menu":5,"count":1}]	23149	delivery	5	13
67682	2020-05-24 19:24:14	2020-05-24	12	[{"id_menu":3,"count":1}]	4102	pick-up	0	12
67683	2020-05-24 19:25:41	2020-05-24	9	[{"id_menu":6,"count":1}]	14145	delivery	5	14
67684	2020-05-24 19:28:11	2020-05-24	12	[{"id_menu":3,"count":1}]	19228	delivery	5	17
67685	2020-05-24 19:29:17	2020-05-24	12	[{"id_menu":1,"count":1}]	26575	delivery	5	17
67686	2020-05-24 19:35:47	2020-05-24	9	[{"id_menu":6,"count":1}]	23086	delivery	5	14
67687	2020-05-24 19:36:30	2020-05-24	9	[{"id_menu":7,"count":1}]	15022	delivery	5	14
67688	2020-05-24 19:36:47	2020-05-24	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	26730	delivery	5	26
67689	2020-05-24 19:36:57	2020-05-24	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	12679	delivery	5	28
67690	2020-05-24 19:37:44	2020-05-24	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	5817	delivery	5	26
67691	2020-05-24 19:42:26	2020-05-24	12	[{"id_menu":3,"count":1}]	7595	pick-up	0	12
67692	2020-05-24 19:44:23	2020-05-24	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	19694	delivery	5	25
67693	2020-05-24 19:44:46	2020-05-24	9	[{"id_menu":7,"count":1}]	19515	delivery	5	14
67694	2020-05-24 19:47:02	2020-05-24	12	[{"id_menu":1,"count":1}]	20697	delivery	5	17
67695	2020-05-24 19:47:25	2020-05-24	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	7419	delivery	5	25
67696	2020-05-24 19:49:08	2020-05-24	14	[{"id_menu":2,"count":1}]	3363	pick-up	0	14
67697	2020-05-24 19:50:49	2020-05-24	8	[{"id_menu":5,"count":1}]	26611	pick-up	0	8
67698	2020-05-24 19:52:18	2020-05-24	9	[{"id_menu":7,"count":1}]	2995	delivery	5	14
67699	2020-05-24 19:53:11	2020-05-24	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	26719	delivery	5	28
67700	2020-05-24 19:53:35	2020-05-24	14	[{"id_menu":2,"count":1}]	15686	pick-up	0	14
67701	2020-05-24 19:54:28	2020-05-24	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26664	delivery	5	35
67702	2020-05-24 19:59:33	2020-05-24	17	[{"id_menu":4,"count":1}]	26670	delivery	5	22
67703	2020-05-24 20:02:16	2020-05-24	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	10570	delivery	5	25
67704	2020-05-24 20:05:48	2020-05-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	581	delivery	5	28
67705	2020-05-24 20:08:34	2020-05-24	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	17268	delivery	5	45
67706	2020-05-24 20:12:27	2020-05-24	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	737	pick-up	0	26
67707	2020-05-24 20:14:39	2020-05-24	14	[{"id_menu":2,"count":1}]	3949	pick-up	0	14
67708	2020-05-24 20:16:18	2020-05-24	12	[{"id_menu":1,"count":1}]	17036	pick-up	0	12
67709	2020-05-24 20:16:18	2020-05-24	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26571	delivery	5	43
67710	2020-05-24 20:19:24	2020-05-24	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7349	delivery	5	22
67711	2020-05-24 20:20:21	2020-05-24	14	[{"id_menu":2,"count":1}]	1507	pick-up	0	14
67712	2020-05-24 20:22:22	2020-05-24	9	[{"id_menu":6,"count":1}]	16406	delivery	5	14
67713	2020-05-24 20:30:05	2020-05-24	9	[{"id_menu":7,"count":1}]	15120	pick-up	0	9
67714	2020-05-24 20:33:06	2020-05-24	14	[{"id_menu":2,"count":1}]	11909	delivery	5	19
67715	2020-05-24 20:35:34	2020-05-24	9	[{"id_menu":7,"count":1}]	26597	delivery	5	14
67716	2020-05-24 20:37:41	2020-05-24	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20398	delivery	5	45
67717	2020-05-24 20:40:30	2020-05-24	8	[{"id_menu":5,"count":1}]	23280	delivery	5	13
67718	2020-05-24 20:48:03	2020-05-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6367	delivery	5	22
67719	2020-05-24 20:49:19	2020-05-24	9	[{"id_menu":6,"count":1}]	9107	pick-up	0	9
67720	2020-05-24 20:50:38	2020-05-24	8	[{"id_menu":5,"count":1}]	26626	pick-up	0	8
67721	2020-05-24 20:52:36	2020-05-24	14	[{"id_menu":2,"count":1}]	11829	delivery	5	19
67722	2020-05-24 20:53:38	2020-05-24	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	8648	delivery	5	26
67723	2020-05-24 20:54:09	2020-05-24	14	[{"id_menu":2,"count":1}]	26561	delivery	5	19
67724	2020-05-24 21:09:50	2020-05-24	12	[{"id_menu":3,"count":1}]	9423	pick-up	0	12
67725	2020-05-24 21:10:32	2020-05-24	12	[{"id_menu":1,"count":1}]	26616	delivery	5	17
67726	2020-05-24 21:11:35	2020-05-24	12	[{"id_menu":1,"count":1}]	1939	delivery	5	17
67727	2020-05-24 21:12:19	2020-05-24	12	[{"id_menu":1,"count":1}]	13199	pick-up	0	12
67728	2020-05-24 21:12:31	2020-05-24	9	[{"id_menu":7,"count":1}]	20335	delivery	5	14
67729	2020-05-24 21:14:23	2020-05-24	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	15603	delivery	5	26
67730	2020-05-24 21:16:28	2020-05-24	14	[{"id_menu":2,"count":1}]	10387	delivery	5	19
67731	2020-05-24 21:17:11	2020-05-24	17	[{"id_menu":4,"count":1}]	609	pick-up	0	17
67732	2020-05-24 21:18:38	2020-05-24	12	[{"id_menu":1,"count":1}]	26697	delivery	5	17
67733	2020-05-24 21:19:53	2020-05-24	8	[{"id_menu":5,"count":1}]	7570	delivery	5	13
67734	2020-05-24 21:23:16	2020-05-24	9	[{"id_menu":7,"count":1}]	26733	delivery	5	14
67735	2020-05-24 21:24:22	2020-05-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10432	delivery	5	31
67736	2020-05-24 21:25:12	2020-05-24	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	9727	delivery	5	31
67737	2020-05-24 21:25:48	2020-05-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	3343	delivery	5	28
67738	2020-05-24 21:29:28	2020-05-24	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	11999	delivery	5	37
67739	2020-05-24 21:30:57	2020-05-24	12	[{"id_menu":1,"count":1}]	18976	pick-up	0	12
67740	2020-05-24 21:31:30	2020-05-24	14	[{"id_menu":2,"count":1}]	23601	delivery	5	19
67741	2020-05-24 21:32:32	2020-05-24	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	20330	pick-up	0	35
67742	2020-05-24 21:36:13	2020-05-24	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	14454	delivery	5	25
67743	2020-05-24 21:36:54	2020-05-24	12	[{"id_menu":1,"count":1}]	26560	delivery	5	17
67744	2020-05-24 21:40:05	2020-05-24	12	[{"id_menu":1,"count":1}]	16627	delivery	5	17
67745	2020-05-24 21:45:34	2020-05-24	9	[{"id_menu":7,"count":1}]	14477	delivery	5	14
67746	2020-05-24 21:46:21	2020-05-24	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21048	delivery	5	36
67747	2020-05-24 21:46:49	2020-05-24	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	20835	pick-up	0	26
67748	2020-05-24 21:47:20	2020-05-24	8	[{"id_menu":5,"count":1}]	11635	delivery	5	13
67749	2020-05-24 21:47:59	2020-05-24	12	[{"id_menu":3,"count":2}]	5913	pick-up	0	12
67750	2020-05-24 21:49:24	2020-05-24	17	[{"id_menu":4,"count":1}]	26590	delivery	5	22
67751	2020-05-24 21:53:30	2020-05-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2555	delivery	5	28
67752	2020-05-24 21:53:34	2020-05-24	12	[{"id_menu":1,"count":1}]	5238	pick-up	0	12
67753	2020-05-24 21:56:36	2020-05-24	17	[{"id_menu":4,"count":1}]	26584	delivery	5	22
67754	2020-05-24 22:01:49	2020-05-24	9	[{"id_menu":6,"count":1}]	2085	pick-up	0	9
67755	2020-05-24 22:03:25	2020-05-24	9	[{"id_menu":6,"count":3}]	13663	delivery	5	14
67756	2020-05-24 22:04:10	2020-05-24	8	[{"id_menu":5,"count":1}]	15130	pick-up	0	8
67757	2020-05-24 22:12:27	2020-05-24	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	628	delivery	5	43
67758	2020-05-24 22:16:34	2020-05-24	12	[{"id_menu":3,"count":1}]	932	pick-up	0	12
67759	2020-05-24 22:19:32	2020-05-24	17	[{"id_menu":4,"count":1}]	7058	pick-up	0	17
67760	2020-05-24 22:20:29	2020-05-24	12	[{"id_menu":3,"count":1}]	159	pick-up	0	12
67761	2020-05-24 22:21:54	2020-05-24	9	[{"id_menu":6,"count":1}]	7388	delivery	5	14
67762	2020-05-24 22:22:57	2020-05-24	9	[{"id_menu":7,"count":1}]	2885	delivery	5	14
67763	2020-05-24 22:23:09	2020-05-24	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	23747	delivery	5	22
67764	2020-05-24 22:25:25	2020-05-24	8	[{"id_menu":5,"count":1}]	26744	delivery	5	13
67765	2020-05-24 22:26:38	2020-05-24	12	[{"id_menu":3,"count":1}]	15127	delivery	5	17
67766	2020-05-24 22:26:47	2020-05-24	9	[{"id_menu":7,"count":1}]	5143	pick-up	0	9
67767	2020-05-24 22:27:48	2020-05-24	9	[{"id_menu":6,"count":1}]	17547	delivery	5	14
67768	2020-05-24 22:37:30	2020-05-24	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	26704	delivery	5	23
67769	2020-05-24 22:39:25	2020-05-24	17	[{"id_menu":4,"count":1}]	17597	delivery	5	22
67770	2020-05-24 22:40:19	2020-05-24	17	[{"id_menu":4,"count":1}]	6733	delivery	5	22
67771	2020-05-24 22:41:14	2020-05-24	9	[{"id_menu":6,"count":1}]	17534	delivery	5	14
67772	2020-05-24 22:42:44	2020-05-24	12	[{"id_menu":3,"count":1}]	23883	delivery	5	17
67773	2020-05-24 22:43:01	2020-05-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1166	pick-up	0	18
67774	2020-05-24 22:43:45	2020-05-24	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	26686	delivery	5	34
67775	2020-05-24 22:51:06	2020-05-24	8	[{"id_menu":5,"count":3}]	12232	delivery	5	13
67776	2020-05-24 22:51:10	2020-05-24	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	26606	delivery	5	43
67777	2020-05-24 22:53:45	2020-05-24	8	[{"id_menu":5,"count":1}]	11289	pick-up	0	8
67778	2020-05-24 22:54:07	2020-05-24	12	[{"id_menu":1,"count":1}]	26716	delivery	5	17
67779	2020-05-24 22:57:01	2020-05-24	9	[{"id_menu":6,"count":1}]	2575	delivery	5	14
67780	2020-05-24 22:58:38	2020-05-24	12	[{"id_menu":1,"count":1}]	26663	delivery	5	17
67781	2020-05-24 22:59:32	2020-05-24	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":2}]	26672	delivery	5	28
67782	2020-05-24 23:02:29	2020-05-24	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	26682	delivery	5	36
67783	2020-05-24 23:03:37	2020-05-24	9	[{"id_menu":7,"count":1}]	26654	delivery	5	14
67784	2020-05-24 23:06:41	2020-05-24	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	12205	pick-up	0	30
67785	2020-05-24 23:09:03	2020-05-24	14	[{"id_menu":2,"count":1}]	11077	delivery	5	19
67786	2020-05-24 23:09:06	2020-05-24	8	[{"id_menu":5,"count":1}]	1592	pick-up	0	8
67787	2020-05-24 23:09:13	2020-05-24	9	[{"id_menu":6,"count":1}]	18227	pick-up	0	9
67788	2020-05-24 23:12:57	2020-05-24	17	[{"id_menu":4,"count":1}]	23631	delivery	5	22
67789	2020-05-24 23:14:27	2020-05-24	17	[{"id_menu":4,"count":1}]	21067	delivery	5	22
67790	2020-05-24 23:15:53	2020-05-24	9	[{"id_menu":7,"count":1}]	26680	delivery	5	14
67791	2020-05-24 23:17:05	2020-05-24	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	7988	pick-up	0	20
67792	2020-05-24 23:20:37	2020-05-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8678	pick-up	0	23
67793	2020-05-24 23:22:47	2020-05-24	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	3578	pick-up	0	20
67794	2020-05-24 23:23:35	2020-05-24	9	[{"id_menu":6,"count":1}]	26648	pick-up	0	9
67795	2020-05-24 23:26:24	2020-05-24	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	113	pick-up	0	29
67796	2020-05-24 23:27:05	2020-05-24	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	18745	delivery	5	26
67797	2020-05-24 23:29:22	2020-05-24	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	16909	pick-up	0	24
67798	2020-05-24 23:31:14	2020-05-24	12	[{"id_menu":1,"count":1}]	26685	delivery	5	17
67799	2020-05-24 23:31:48	2020-05-24	12	[{"id_menu":3,"count":1}]	26588	delivery	5	17
67800	2020-05-24 23:32:49	2020-05-24	9	[{"id_menu":6,"count":1}]	18437	delivery	5	14
67801	2020-05-24 23:37:39	2020-05-24	14	[{"id_menu":2,"count":1}]	78	delivery	5	19
67802	2020-05-24 23:44:44	2020-05-24	12	[{"id_menu":3,"count":1}]	26559	delivery	5	17
67803	2020-05-24 23:45:05	2020-05-24	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	20745	pick-up	0	31
67804	2020-05-24 23:46:18	2020-05-24	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1941	pick-up	0	21
67805	2020-05-24 23:46:21	2020-05-24	9	[{"id_menu":7,"count":1}]	26572	pick-up	0	9
67806	2020-05-24 23:48:17	2020-05-24	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	23561	delivery	5	55
67807	2020-05-24 23:49:56	2020-05-24	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	26673	delivery	5	26
67808	2020-05-24 23:50:15	2020-05-24	9	[{"id_menu":6,"count":1}]	17767	pick-up	0	9
67809	2020-05-24 23:52:28	2020-05-24	9	[{"id_menu":6,"count":1}]	4242	pick-up	0	9
67810	2020-05-24 23:56:13	2020-05-24	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9278	delivery	5	39
67811	2020-05-24 23:59:26	2020-05-24	12	[{"id_menu":3,"count":1}]	2540	delivery	5	17
67812	2020-05-25 00:02:37	2020-05-25	14	[{"id_menu":2,"count":2}]	26752	delivery	5	19
67813	2020-05-25 00:03:59	2020-05-25	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2993	pick-up	0	21
67814	2020-05-25 00:05:49	2020-05-25	14	[{"id_menu":2,"count":1}]	26767	delivery	5	19
67815	2020-05-25 00:06:09	2020-05-25	9	[{"id_menu":7,"count":1}]	26911	delivery	5	14
67816	2020-05-25 00:09:19	2020-05-25	12	[{"id_menu":1,"count":1}]	12019	pick-up	0	12
67817	2020-05-25 00:10:10	2020-05-25	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	16672	delivery	5	30
67818	2020-05-25 00:19:16	2020-05-25	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	19163	delivery	5	38
67819	2020-05-25 00:23:04	2020-05-25	9	[{"id_menu":6,"count":1}]	26817	pick-up	0	9
67820	2020-05-25 00:31:31	2020-05-25	12	[{"id_menu":3,"count":1}]	5527	delivery	5	17
67821	2020-05-25 00:34:55	2020-05-25	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15901	delivery	5	43
67822	2020-05-25 00:37:54	2020-05-25	9	[{"id_menu":7,"count":1}]	26798	pick-up	0	9
67823	2020-05-25 00:42:05	2020-05-25	9	[{"id_menu":7,"count":1}]	11686	pick-up	0	9
67824	2020-05-25 00:43:39	2020-05-25	12	[{"id_menu":3,"count":1}]	26771	delivery	5	17
67825	2020-05-25 00:47:30	2020-05-25	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	15457	delivery	5	40
67826	2020-05-25 00:49:23	2020-05-25	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	26932	delivery	5	45
67827	2020-05-25 00:54:42	2020-05-25	8	[{"id_menu":5,"count":1}]	26784	delivery	5	13
67828	2020-05-25 00:57:00	2020-05-25	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	8179	delivery	5	27
67829	2020-05-25 01:06:31	2020-05-25	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	12489	delivery	5	26
67830	2020-05-25 01:15:09	2020-05-25	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	13560	delivery	5	26
67831	2020-05-25 01:17:25	2020-05-25	9	[{"id_menu":7,"count":1}]	26064	delivery	5	14
67832	2020-05-25 01:20:50	2020-05-25	9	[{"id_menu":7,"count":2}]	18178	delivery	5	14
67833	2020-05-25 01:20:59	2020-05-25	8	[{"id_menu":5,"count":2}]	15545	delivery	5	13
67834	2020-05-25 01:28:28	2020-05-25	8	[{"id_menu":5,"count":1}]	26870	delivery	5	13
67835	2020-05-25 01:28:29	2020-05-25	39	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	26951	delivery	5	44
67836	2020-05-25 01:28:44	2020-05-25	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	26827	delivery	5	25
67837	2020-05-25 01:34:48	2020-05-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	26770	delivery	5	31
67838	2020-05-25 01:39:23	2020-05-25	8	[{"id_menu":5,"count":1}]	11947	delivery	5	13
67839	2020-05-25 01:41:06	2020-05-25	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	9813	pick-up	0	20
67840	2020-05-25 01:43:29	2020-05-25	14	[{"id_menu":2,"count":1}]	7086	pick-up	0	14
67841	2020-05-25 01:43:58	2020-05-25	17	[{"id_menu":4,"count":1}]	26769	delivery	5	22
67842	2020-05-25 01:46:59	2020-05-25	8	[{"id_menu":5,"count":1}]	24498	delivery	5	13
67843	2020-05-25 01:51:02	2020-05-25	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	26913	delivery	5	26
67844	2020-05-25 01:59:22	2020-05-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26855	delivery	5	23
67845	2020-05-25 02:03:01	2020-05-25	14	[{"id_menu":2,"count":2}]	11624	delivery	5	19
67846	2020-05-25 02:05:23	2020-05-25	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23871	delivery	5	36
67847	2020-05-25 02:08:31	2020-05-25	9	[{"id_menu":7,"count":1}]	24022	delivery	5	14
67848	2020-05-25 02:10:50	2020-05-25	9	[{"id_menu":7,"count":1}]	26807	delivery	5	14
67849	2020-05-25 02:12:49	2020-05-25	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	26902	delivery	5	42
67850	2020-05-25 02:15:08	2020-05-25	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	19212	delivery	5	46
67851	2020-05-25 02:24:58	2020-05-25	12	[{"id_menu":1,"count":1}]	7341	pick-up	0	12
67852	2020-05-25 02:25:50	2020-05-25	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8950	delivery	5	48
67853	2020-05-25 02:30:10	2020-05-25	9	[{"id_menu":7,"count":1}]	19965	delivery	5	14
67854	2020-05-25 02:43:03	2020-05-25	12	[{"id_menu":1,"count":1}]	4333	delivery	5	17
67855	2020-05-25 02:46:24	2020-05-25	14	[{"id_menu":2,"count":1}]	26863	delivery	5	19
67856	2020-05-25 02:46:39	2020-05-25	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	26786	delivery	5	29
67857	2020-05-25 02:54:10	2020-05-25	8	[{"id_menu":5,"count":1}]	6799	delivery	5	13
67858	2020-05-25 02:56:21	2020-05-25	9	[{"id_menu":6,"count":2}]	13414	delivery	5	14
67859	2020-05-25 03:08:56	2020-05-25	17	[{"id_menu":4,"count":1}]	26860	pick-up	0	17
67860	2020-05-25 03:09:01	2020-05-25	8	[{"id_menu":5,"count":1}]	10787	delivery	5	13
67861	2020-05-25 03:13:25	2020-05-25	9	[{"id_menu":7,"count":1}]	12907	delivery	5	14
67862	2020-05-25 03:14:59	2020-05-25	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	26795	delivery	5	36
67863	2020-05-25 03:18:53	2020-05-25	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	26955	delivery	5	30
67864	2020-05-25 03:20:16	2020-05-25	9	[{"id_menu":7,"count":1}]	19504	delivery	5	14
67865	2020-05-25 03:39:25	2020-05-25	12	[{"id_menu":1,"count":1}]	931	pick-up	0	12
67866	2020-05-25 03:42:35	2020-05-25	9	[{"id_menu":7,"count":1}]	439	delivery	5	14
67867	2020-05-25 03:44:33	2020-05-25	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22377	delivery	5	34
67868	2020-05-25 03:48:27	2020-05-25	8	[{"id_menu":5,"count":1}]	26852	delivery	5	13
67869	2020-05-25 03:52:30	2020-05-25	12	[{"id_menu":1,"count":1}]	25214	pick-up	0	12
67870	2020-05-25 03:56:54	2020-05-25	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	26962	delivery	5	34
67871	2020-05-25 03:59:52	2020-05-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19428	delivery	5	22
67872	2020-05-25 04:01:07	2020-05-25	9	[{"id_menu":6,"count":1}]	19038	delivery	5	14
67873	2020-05-25 04:01:47	2020-05-25	14	[{"id_menu":2,"count":1}]	2894	pick-up	0	14
67874	2020-05-25 04:03:46	2020-05-25	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	17402	delivery	5	31
67875	2020-05-25 04:12:48	2020-05-25	12	[{"id_menu":3,"count":1}]	26805	delivery	5	17
67876	2020-05-25 04:14:00	2020-05-25	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	18343	delivery	5	23
67877	2020-05-25 04:15:38	2020-05-25	8	[{"id_menu":5,"count":1}]	26845	delivery	5	13
67878	2020-05-25 04:16:37	2020-05-25	12	[{"id_menu":3,"count":1}]	4020	delivery	5	17
67879	2020-05-25 04:25:56	2020-05-25	14	[{"id_menu":2,"count":1}]	19798	pick-up	0	14
67880	2020-05-25 04:34:06	2020-05-25	9	[{"id_menu":6,"count":1}]	26002	delivery	5	14
67881	2020-05-25 04:37:09	2020-05-25	8	[{"id_menu":5,"count":1}]	2416	pick-up	0	8
67882	2020-05-25 04:43:39	2020-05-25	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11608	delivery	5	53
67883	2020-05-25 04:48:31	2020-05-25	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	23029	delivery	5	44
67884	2020-05-25 04:54:03	2020-05-25	8	[{"id_menu":5,"count":1}]	26935	delivery	5	13
67885	2020-05-25 04:58:28	2020-05-25	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	25533	delivery	5	26
67886	2020-05-25 05:04:13	2020-05-25	8	[{"id_menu":5,"count":2}]	4788	delivery	5	13
67887	2020-05-25 05:09:56	2020-05-25	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17268	delivery	5	35
67888	2020-05-25 05:12:21	2020-05-25	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	26938	delivery	5	25
67889	2020-05-25 05:12:40	2020-05-25	14	[{"id_menu":2,"count":1}]	26920	delivery	5	19
67890	2020-05-25 05:21:02	2020-05-25	12	[{"id_menu":1,"count":1}]	1681	pick-up	0	12
67891	2020-05-25 05:24:21	2020-05-25	12	[{"id_menu":3,"count":1}]	26013	delivery	5	17
67892	2020-05-25 05:26:48	2020-05-25	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	26956	delivery	5	27
67893	2020-05-25 05:27:37	2020-05-25	14	[{"id_menu":2,"count":1}]	26793	delivery	5	19
67894	2020-05-25 05:33:42	2020-05-25	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5936	delivery	5	34
67895	2020-05-25 05:40:28	2020-05-25	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	26874	delivery	5	31
67896	2020-05-25 05:43:48	2020-05-25	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	26862	delivery	5	28
67897	2020-05-25 05:45:04	2020-05-25	8	[{"id_menu":5,"count":1}]	1195	delivery	5	13
67898	2020-05-25 05:50:11	2020-05-25	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	18010	delivery	5	27
67899	2020-05-25 05:52:33	2020-05-25	9	[{"id_menu":6,"count":1}]	9254	delivery	5	14
67900	2020-05-25 05:54:48	2020-05-25	9	[{"id_menu":7,"count":2}]	26765	delivery	5	14
67901	2020-05-25 05:59:54	2020-05-25	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17799	delivery	5	39
67902	2020-05-25 06:01:31	2020-05-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	25279	delivery	5	28
67903	2020-05-25 06:02:53	2020-05-25	9	[{"id_menu":7,"count":1}]	2107	delivery	5	14
67904	2020-05-25 06:09:01	2020-05-25	9	[{"id_menu":7,"count":1}]	1523	pick-up	0	9
67905	2020-05-25 06:09:58	2020-05-25	9	[{"id_menu":7,"count":1}]	26923	delivery	5	14
67906	2020-05-25 06:16:15	2020-05-25	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	19019	delivery	5	42
67907	2020-05-25 06:16:23	2020-05-25	17	[{"id_menu":4,"count":1}]	2538	pick-up	0	17
67908	2020-05-25 06:17:08	2020-05-25	17	[{"id_menu":4,"count":1}]	15017	delivery	5	22
67909	2020-05-25 06:21:17	2020-05-25	12	[{"id_menu":3,"count":1}]	26755	pick-up	0	12
67910	2020-05-25 06:22:15	2020-05-25	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	26823	delivery	5	31
67911	2020-05-25 06:22:21	2020-05-25	12	[{"id_menu":3,"count":1}]	2000	pick-up	0	12
67912	2020-05-25 06:22:56	2020-05-25	9	[{"id_menu":6,"count":1}]	21600	pick-up	0	9
67913	2020-05-25 06:25:27	2020-05-25	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	17937	delivery	5	25
67914	2020-05-25 06:30:11	2020-05-25	12	[{"id_menu":1,"count":1}]	26940	delivery	5	17
67915	2020-05-25 06:46:17	2020-05-25	12	[{"id_menu":3,"count":1}]	15996	delivery	5	17
67916	2020-05-25 06:46:27	2020-05-25	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18344	pick-up	0	29
67917	2020-05-25 06:47:32	2020-05-25	9	[{"id_menu":7,"count":1}]	26927	delivery	5	14
67918	2020-05-25 06:50:42	2020-05-25	12	[{"id_menu":3,"count":1}]	2217	pick-up	0	12
67919	2020-05-25 07:04:02	2020-05-25	14	[{"id_menu":2,"count":1}]	23238	delivery	5	19
67920	2020-05-25 07:36:27	2020-05-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	16524	delivery	5	28
67921	2020-05-25 07:37:44	2020-05-25	12	[{"id_menu":3,"count":1}]	26829	delivery	5	17
67922	2020-05-25 07:39:00	2020-05-25	12	[{"id_menu":1,"count":1}]	2134	pick-up	0	12
67923	2020-05-25 07:40:48	2020-05-25	9	[{"id_menu":7,"count":2}]	14874	delivery	5	14
67924	2020-05-25 07:42:45	2020-05-25	12	[{"id_menu":1,"count":1}]	19996	delivery	5	17
67925	2020-05-25 07:46:29	2020-05-25	9	[{"id_menu":6,"count":1}]	19294	delivery	5	14
67926	2020-05-25 07:48:37	2020-05-25	8	[{"id_menu":5,"count":1}]	2068	pick-up	0	8
67927	2020-05-25 07:55:41	2020-05-25	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	26908	delivery	5	22
67928	2020-05-25 07:59:43	2020-05-25	12	[{"id_menu":3,"count":1}]	14947	delivery	5	17
67929	2020-05-25 08:02:41	2020-05-25	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	26866	delivery	5	34
67930	2020-05-25 08:07:59	2020-05-25	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	24536	delivery	5	31
67931	2020-05-25 08:15:12	2020-05-25	14	[{"id_menu":2,"count":1}]	4021	delivery	5	19
67932	2020-05-25 08:23:24	2020-05-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	381	pick-up	0	17
67933	2020-05-25 08:32:56	2020-05-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	26826	delivery	5	23
67934	2020-05-25 08:35:32	2020-05-25	14	[{"id_menu":2,"count":1}]	26918	delivery	5	19
67935	2020-05-25 08:39:56	2020-05-25	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16896	delivery	5	31
67936	2020-05-25 08:41:52	2020-05-25	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17895	delivery	5	53
67937	2020-05-25 08:41:54	2020-05-25	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	2672	pick-up	0	24
67938	2020-05-25 08:42:31	2020-05-25	12	[{"id_menu":3,"count":1}]	24671	delivery	5	17
67939	2020-05-25 08:47:09	2020-05-25	9	[{"id_menu":6,"count":1}]	5992	delivery	5	14
67940	2020-05-25 08:55:49	2020-05-25	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	26906	delivery	5	53
67941	2020-05-25 09:07:11	2020-05-25	12	[{"id_menu":3,"count":1}]	612	pick-up	0	12
67942	2020-05-25 09:09:00	2020-05-25	17	[{"id_menu":4,"count":1}]	24441	pick-up	0	17
67943	2020-05-25 09:12:27	2020-05-25	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	21854	delivery	5	34
67944	2020-05-25 09:19:22	2020-05-25	12	[{"id_menu":1,"count":1}]	26839	delivery	5	17
67945	2020-05-25 09:19:26	2020-05-25	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	26963	delivery	5	43
67946	2020-05-25 09:26:16	2020-05-25	17	[{"id_menu":4,"count":1}]	22778	delivery	5	22
67947	2020-05-25 09:31:26	2020-05-25	12	[{"id_menu":3,"count":1}]	905	pick-up	0	12
67948	2020-05-25 09:33:55	2020-05-25	8	[{"id_menu":5,"count":1}]	7888	delivery	5	13
67949	2020-05-25 09:43:15	2020-05-25	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	23549	delivery	5	57
67950	2020-05-25 09:43:57	2020-05-25	9	[{"id_menu":6,"count":1}]	26774	delivery	5	14
67951	2020-05-25 09:49:33	2020-05-25	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	26921	delivery	5	26
67952	2020-05-25 09:55:33	2020-05-25	9	[{"id_menu":7,"count":1}]	7572	pick-up	0	9
67953	2020-05-25 09:57:30	2020-05-25	8	[{"id_menu":5,"count":1}]	26881	delivery	5	13
67954	2020-05-25 09:57:46	2020-05-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	26812	delivery	5	31
67955	2020-05-25 10:01:35	2020-05-25	12	[{"id_menu":3,"count":1}]	26877	delivery	5	17
67956	2020-05-25 10:13:58	2020-05-25	8	[{"id_menu":5,"count":1}]	26763	delivery	5	13
67957	2020-05-25 10:15:31	2020-05-25	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	379	pick-up	0	21
67958	2020-05-25 10:15:38	2020-05-25	12	[{"id_menu":1,"count":1}]	9081	delivery	5	17
67959	2020-05-25 10:21:49	2020-05-25	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16229	delivery	5	36
67960	2020-05-25 10:22:50	2020-05-25	9	[{"id_menu":6,"count":3}]	11421	delivery	5	14
67961	2020-05-25 10:34:08	2020-05-25	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	15563	delivery	5	30
67962	2020-05-25 10:34:24	2020-05-25	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7536	delivery	5	31
67963	2020-05-25 10:35:52	2020-05-25	14	[{"id_menu":2,"count":1}]	26757	delivery	5	19
67964	2020-05-25 10:47:14	2020-05-25	8	[{"id_menu":5,"count":1}]	8976	delivery	5	13
67965	2020-05-25 10:55:31	2020-05-25	14	[{"id_menu":2,"count":2}]	17653	delivery	5	19
67966	2020-05-25 11:03:09	2020-05-25	9	[{"id_menu":6,"count":1}]	26871	delivery	5	14
67967	2020-05-25 11:06:03	2020-05-25	9	[{"id_menu":6,"count":1}]	26856	delivery	5	14
67968	2020-05-25 11:09:06	2020-05-25	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	9266	pick-up	0	21
67969	2020-05-25 11:18:37	2020-05-25	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6836	delivery	5	40
67970	2020-05-25 11:22:34	2020-05-25	17	[{"id_menu":4,"count":1}]	18730	delivery	5	22
67971	2020-05-25 11:26:37	2020-05-25	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	18223	delivery	5	31
67972	2020-05-25 11:33:19	2020-05-25	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2495	pick-up	0	31
67973	2020-05-25 11:35:35	2020-05-25	9	[{"id_menu":6,"count":1}]	26759	delivery	5	14
67974	2020-05-25 11:38:53	2020-05-25	12	[{"id_menu":1,"count":1}]	8501	pick-up	0	12
67975	2020-05-25 11:39:49	2020-05-25	9	[{"id_menu":6,"count":1}]	26851	delivery	5	14
67976	2020-05-25 11:41:31	2020-05-25	12	[{"id_menu":1,"count":1}]	5471	pick-up	0	12
67977	2020-05-25 11:46:33	2020-05-25	12	[{"id_menu":3,"count":1}]	21671	delivery	5	17
67978	2020-05-25 11:52:06	2020-05-25	12	[{"id_menu":3,"count":1}]	858	pick-up	0	12
67979	2020-05-25 12:00:01	2020-05-25	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	6835	delivery	5	27
67980	2020-05-25 12:01:16	2020-05-25	8	[{"id_menu":5,"count":1}]	20668	delivery	5	13
67981	2020-05-25 12:02:28	2020-05-25	12	[{"id_menu":1,"count":1}]	2738	pick-up	0	12
67982	2020-05-25 12:04:06	2020-05-25	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	24674	delivery	5	43
67983	2020-05-25 12:06:54	2020-05-25	8	[{"id_menu":5,"count":1}]	26790	delivery	5	13
67984	2020-05-25 12:10:25	2020-05-25	12	[{"id_menu":1,"count":1}]	7189	pick-up	0	12
67985	2020-05-25 12:10:40	2020-05-25	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	24943	pick-up	0	26
67986	2020-05-25 12:11:46	2020-05-25	17	[{"id_menu":4,"count":1}]	173	pick-up	0	17
67987	2020-05-25 12:13:21	2020-05-25	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	13068	pick-up	0	21
67988	2020-05-25 12:29:36	2020-05-25	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	26777	delivery	5	28
67989	2020-05-25 12:29:49	2020-05-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6093	pick-up	0	18
67990	2020-05-25 12:34:13	2020-05-25	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4967	pick-up	0	29
67991	2020-05-25 12:41:02	2020-05-25	14	[{"id_menu":2,"count":1}]	3044	delivery	5	19
67992	2020-05-25 12:43:06	2020-05-25	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	25324	pick-up	0	26
67993	2020-05-25 12:45:37	2020-05-25	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	23831	pick-up	0	21
67994	2020-05-25 12:49:40	2020-05-25	8	[{"id_menu":5,"count":1}]	26778	delivery	5	13
67995	2020-05-25 12:53:01	2020-05-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5494	delivery	5	31
67996	2020-05-25 12:53:57	2020-05-25	17	[{"id_menu":4,"count":1}]	26127	pick-up	0	17
67997	2020-05-25 12:58:35	2020-05-25	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26801	delivery	5	31
67998	2020-05-25 13:01:07	2020-05-25	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	4620	delivery	5	25
67999	2020-05-25 13:11:47	2020-05-25	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	643	pick-up	0	21
68000	2020-05-25 13:19:49	2020-05-25	9	[{"id_menu":6,"count":1}]	16155	pick-up	0	9
68001	2020-05-25 13:20:03	2020-05-25	55	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	26837	delivery	5	60
68002	2020-05-25 13:26:11	2020-05-25	17	[{"id_menu":4,"count":1}]	26924	pick-up	0	17
68003	2020-05-25 13:31:48	2020-05-25	14	[{"id_menu":2,"count":1}]	12771	delivery	5	19
68004	2020-05-25 13:32:17	2020-05-25	12	[{"id_menu":1,"count":2}]	13332	delivery	5	17
68005	2020-05-25 13:41:31	2020-05-25	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	456	delivery	5	25
68006	2020-05-25 13:58:41	2020-05-25	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	14295	delivery	5	25
68007	2020-05-25 13:59:24	2020-05-25	14	[{"id_menu":2,"count":1}]	12727	delivery	5	19
68008	2020-05-25 14:07:12	2020-05-25	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	13308	delivery	5	31
68009	2020-05-25 14:12:55	2020-05-25	12	[{"id_menu":3,"count":1}]	25158	delivery	5	17
68010	2020-05-25 14:17:05	2020-05-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	556	pick-up	0	26
68011	2020-05-25 14:18:43	2020-05-25	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	26818	delivery	5	45
68012	2020-05-25 14:28:42	2020-05-25	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26948	delivery	5	31
68013	2020-05-25 14:30:26	2020-05-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12912	pick-up	0	26
68014	2020-05-25 14:30:42	2020-05-25	9	[{"id_menu":6,"count":1}]	26849	delivery	5	14
68015	2020-05-25 14:31:19	2020-05-25	9	[{"id_menu":6,"count":1}]	25349	delivery	5	14
68016	2020-05-25 14:32:45	2020-05-25	8	[{"id_menu":5,"count":1}]	2112	delivery	5	13
68017	2020-05-25 14:35:01	2020-05-25	9	[{"id_menu":7,"count":1}]	14932	delivery	5	14
68018	2020-05-25 14:35:39	2020-05-25	9	[{"id_menu":7,"count":1}]	23086	delivery	5	14
68019	2020-05-25 14:36:42	2020-05-25	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	6238	delivery	5	25
68020	2020-05-25 14:38:00	2020-05-25	9	[{"id_menu":7,"count":1}]	1107	pick-up	0	9
68021	2020-05-25 14:38:48	2020-05-25	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	22845	delivery	5	27
68022	2020-05-25 14:40:33	2020-05-25	8	[{"id_menu":5,"count":1}]	2995	delivery	5	13
68023	2020-05-25 14:42:23	2020-05-25	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1475	delivery	5	26
68024	2020-05-25 14:43:20	2020-05-25	9	[{"id_menu":7,"count":1}]	26792	delivery	5	14
68025	2020-05-25 14:45:53	2020-05-25	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2420	pick-up	0	31
68026	2020-05-25 14:50:19	2020-05-25	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	16052	delivery	5	34
68027	2020-05-25 14:52:27	2020-05-25	14	[{"id_menu":2,"count":1}]	6844	pick-up	0	14
68028	2020-05-25 14:53:03	2020-05-25	8	[{"id_menu":5,"count":1}]	16078	delivery	5	13
68029	2020-05-25 14:53:20	2020-05-25	12	[{"id_menu":3,"count":1}]	26931	pick-up	0	12
68030	2020-05-25 14:53:22	2020-05-25	9	[{"id_menu":7,"count":1}]	26842	delivery	5	14
68031	2020-05-25 15:04:57	2020-05-25	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	9977	delivery	5	34
68032	2020-05-25 15:07:18	2020-05-25	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	26794	delivery	5	36
68033	2020-05-25 15:08:10	2020-05-25	12	[{"id_menu":3,"count":1}]	26891	pick-up	0	12
68034	2020-05-25 15:17:36	2020-05-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17527	delivery	5	31
68035	2020-05-25 15:20:06	2020-05-25	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18400	delivery	5	36
68036	2020-05-25 15:23:18	2020-05-25	9	[{"id_menu":7,"count":1}]	26781	delivery	5	14
68037	2020-05-25 15:23:55	2020-05-25	14	[{"id_menu":2,"count":1}]	8394	pick-up	0	14
68038	2020-05-25 15:35:44	2020-05-25	9	[{"id_menu":7,"count":1}]	26894	delivery	5	14
68039	2020-05-25 15:35:51	2020-05-25	14	[{"id_menu":2,"count":1}]	20503	pick-up	0	14
68040	2020-05-25 15:37:44	2020-05-25	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	26934	delivery	5	52
68041	2020-05-25 15:45:27	2020-05-25	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	22774	delivery	5	35
68042	2020-05-25 15:47:28	2020-05-25	9	[{"id_menu":6,"count":1}]	19599	delivery	5	14
68043	2020-05-25 15:49:55	2020-05-25	8	[{"id_menu":5,"count":1}]	543	pick-up	0	8
68044	2020-05-25 15:53:37	2020-05-25	9	[{"id_menu":6,"count":1}]	1072	pick-up	0	9
68045	2020-05-25 15:57:02	2020-05-25	8	[{"id_menu":5,"count":1}]	26922	delivery	5	13
68046	2020-05-25 15:58:38	2020-05-25	17	[{"id_menu":4,"count":1}]	26824	delivery	5	22
68047	2020-05-25 16:03:35	2020-05-25	17	[{"id_menu":4,"count":2}]	17614	pick-up	0	17
68048	2020-05-25 16:06:59	2020-05-25	9	[{"id_menu":7,"count":1}]	26898	delivery	5	14
68049	2020-05-25 16:15:16	2020-05-25	14	[{"id_menu":2,"count":1}]	26947	delivery	5	19
68050	2020-05-25 16:16:04	2020-05-25	12	[{"id_menu":1,"count":1}]	26960	delivery	5	17
68051	2020-05-25 16:20:21	2020-05-25	9	[{"id_menu":6,"count":1}]	17073	delivery	5	14
68052	2020-05-25 16:22:37	2020-05-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4763	delivery	5	22
68053	2020-05-25 16:29:19	2020-05-25	8	[{"id_menu":5,"count":2}]	26803	delivery	5	13
68054	2020-05-25 16:40:21	2020-05-25	12	[{"id_menu":3,"count":1}]	20408	pick-up	0	12
68055	2020-05-25 16:40:35	2020-05-25	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	23935	delivery	5	27
68056	2020-05-25 16:54:22	2020-05-25	9	[{"id_menu":6,"count":2}]	24865	delivery	5	14
68057	2020-05-25 16:57:33	2020-05-25	9	[{"id_menu":7,"count":1}]	26773	delivery	5	14
68058	2020-05-25 16:57:49	2020-05-25	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	13579	pick-up	0	29
68059	2020-05-25 16:59:57	2020-05-25	9	[{"id_menu":7,"count":1}]	20219	delivery	5	14
68060	2020-05-25 17:01:56	2020-05-25	9	[{"id_menu":7,"count":1}]	26929	delivery	5	14
68061	2020-05-25 17:06:03	2020-05-25	9	[{"id_menu":6,"count":1}]	1011	delivery	5	14
68062	2020-05-25 17:23:55	2020-05-25	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	25363	delivery	5	43
68063	2020-05-25 17:29:55	2020-05-25	9	[{"id_menu":6,"count":1}]	22614	pick-up	0	9
68064	2020-05-25 17:33:45	2020-05-25	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	18739	delivery	5	38
68065	2020-05-25 17:37:27	2020-05-25	34	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	26833	delivery	5	39
68066	2020-05-25 17:48:49	2020-05-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	15597	delivery	5	23
68067	2020-05-25 17:51:04	2020-05-25	9	[{"id_menu":7,"count":1}]	26916	delivery	5	14
68068	2020-05-25 17:52:46	2020-05-25	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	26754	delivery	5	40
68069	2020-05-25 18:01:21	2020-05-25	17	[{"id_menu":4,"count":1}]	586	delivery	5	22
68070	2020-05-25 18:05:38	2020-05-25	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	26828	delivery	5	48
68071	2020-05-25 18:06:07	2020-05-25	8	[{"id_menu":5,"count":1}]	26919	delivery	5	13
68072	2020-05-25 18:09:10	2020-05-25	9	[{"id_menu":7,"count":1}]	26825	delivery	5	14
68073	2020-05-25 18:15:53	2020-05-25	9	[{"id_menu":6,"count":1}]	19940	delivery	5	14
68074	2020-05-25 18:17:12	2020-05-25	14	[{"id_menu":2,"count":1}]	26787	delivery	5	19
68075	2020-05-25 18:21:37	2020-05-25	8	[{"id_menu":5,"count":1}]	2818	delivery	5	13
68076	2020-05-25 18:35:26	2020-05-25	9	[{"id_menu":7,"count":1}]	26859	delivery	5	14
68077	2020-05-25 18:36:15	2020-05-25	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	18565	delivery	5	25
68078	2020-05-25 18:40:54	2020-05-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	26775	delivery	5	22
68079	2020-05-25 18:41:02	2020-05-25	8	[{"id_menu":5,"count":1}]	21771	delivery	5	13
68080	2020-05-25 18:46:19	2020-05-25	17	[{"id_menu":4,"count":1}]	13841	pick-up	0	17
68081	2020-05-25 18:53:00	2020-05-25	17	[{"id_menu":4,"count":1}]	16870	delivery	5	22
68082	2020-05-25 18:53:34	2020-05-25	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	784	pick-up	0	21
68083	2020-05-25 18:55:09	2020-05-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19566	delivery	5	23
68084	2020-05-25 18:58:53	2020-05-25	17	[{"id_menu":4,"count":2}]	3550	delivery	5	22
68085	2020-05-25 19:04:04	2020-05-25	17	[{"id_menu":4,"count":1}]	4747	pick-up	0	17
68086	2020-05-25 19:05:54	2020-05-25	8	[{"id_menu":5,"count":2}]	26937	delivery	5	13
68087	2020-05-25 19:08:47	2020-05-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	26959	delivery	5	28
68088	2020-05-25 19:09:20	2020-05-25	9	[{"id_menu":6,"count":1}]	6420	delivery	5	14
68089	2020-05-25 19:10:09	2020-05-25	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	26804	pick-up	0	20
68090	2020-05-25 19:10:38	2020-05-25	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	6301	delivery	5	26
68091	2020-05-25 19:15:05	2020-05-25	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24672	delivery	5	35
68092	2020-05-25 19:22:15	2020-05-25	9	[{"id_menu":7,"count":1}]	26883	delivery	5	14
68093	2020-05-25 19:29:42	2020-05-25	8	[{"id_menu":5,"count":1}]	26779	delivery	5	13
68094	2020-05-25 19:30:47	2020-05-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24325	pick-up	0	18
68095	2020-05-25 19:30:48	2020-05-25	14	[{"id_menu":2,"count":1}]	26942	delivery	5	19
68096	2020-05-25 19:36:15	2020-05-25	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	26846	pick-up	0	20
68097	2020-05-25 19:44:26	2020-05-25	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	11005	pick-up	0	29
68098	2020-05-25 19:49:48	2020-05-25	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	5050	pick-up	0	29
68099	2020-05-25 19:58:00	2020-05-25	12	[{"id_menu":3,"count":1}]	26780	delivery	5	17
68100	2020-05-25 20:07:12	2020-05-25	14	[{"id_menu":2,"count":1}]	26857	delivery	5	19
68101	2020-05-25 20:12:18	2020-05-25	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	26879	delivery	5	22
68102	2020-05-25 20:13:16	2020-05-25	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	9485	delivery	5	31
68103	2020-05-25 20:15:48	2020-05-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5292	delivery	5	31
68104	2020-05-25 20:16:05	2020-05-25	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	26761	delivery	5	42
68105	2020-05-25 20:19:09	2020-05-25	14	[{"id_menu":2,"count":1}]	7528	delivery	5	19
68106	2020-05-25 20:21:13	2020-05-25	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7574	pick-up	0	17
68107	2020-05-25 20:22:18	2020-05-25	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	22640	delivery	5	48
68108	2020-05-25 20:22:40	2020-05-25	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	25089	pick-up	0	38
68109	2020-05-25 20:23:47	2020-05-25	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	26819	delivery	5	34
68110	2020-05-25 20:25:19	2020-05-25	12	[{"id_menu":3,"count":1}]	1255	delivery	5	17
68111	2020-05-25 20:25:46	2020-05-25	17	[{"id_menu":4,"count":1}]	26853	delivery	5	22
68112	2020-05-25 20:25:53	2020-05-25	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	26802	delivery	5	27
68113	2020-05-25 20:28:41	2020-05-25	12	[{"id_menu":1,"count":1}]	12059	delivery	5	17
68114	2020-05-25 20:35:59	2020-05-25	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	24401	delivery	5	23
68115	2020-05-25 20:36:24	2020-05-25	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	11696	pick-up	0	25
68116	2020-05-25 20:59:38	2020-05-25	14	[{"id_menu":2,"count":3}]	26811	delivery	5	19
68117	2020-05-25 21:01:09	2020-05-25	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	12183	pick-up	0	29
68118	2020-05-25 21:02:30	2020-05-25	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	26900	delivery	5	36
68119	2020-05-25 21:03:01	2020-05-25	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	26903	delivery	5	22
68120	2020-05-25 21:05:41	2020-05-25	12	[{"id_menu":1,"count":1}]	1677	pick-up	0	12
68121	2020-05-25 21:11:10	2020-05-25	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":3}]	6746	delivery	5	28
68122	2020-05-25 21:12:10	2020-05-25	8	[{"id_menu":5,"count":1}]	13878	delivery	5	13
68123	2020-05-25 21:12:50	2020-05-25	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	25627	delivery	5	26
68124	2020-05-25 21:15:50	2020-05-25	8	[{"id_menu":5,"count":1}]	9659	delivery	5	13
68125	2020-05-25 21:22:25	2020-05-25	12	[{"id_menu":1,"count":1}]	1263	pick-up	0	12
68126	2020-05-25 21:29:46	2020-05-25	12	[{"id_menu":3,"count":1}]	806	delivery	5	17
68127	2020-05-25 21:38:45	2020-05-25	9	[{"id_menu":6,"count":1}]	25367	delivery	5	14
68128	2020-05-25 21:40:27	2020-05-25	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	26930	pick-up	0	20
68129	2020-05-25 21:44:24	2020-05-25	12	[{"id_menu":1,"count":1}]	25003	delivery	5	17
68130	2020-05-25 21:47:47	2020-05-25	12	[{"id_menu":3,"count":2}]	26783	delivery	5	17
68131	2020-05-25 21:49:15	2020-05-25	8	[{"id_menu":5,"count":1}]	26815	delivery	5	13
68132	2020-05-25 21:49:28	2020-05-25	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6638	delivery	5	37
68133	2020-05-25 21:49:50	2020-05-25	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	26925	delivery	5	26
68134	2020-05-25 21:56:08	2020-05-25	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	26865	delivery	5	36
68135	2020-05-25 22:04:55	2020-05-25	9	[{"id_menu":6,"count":3}]	26895	delivery	5	14
68136	2020-05-25 22:08:05	2020-05-25	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	5293	pick-up	0	34
68137	2020-05-25 22:08:22	2020-05-25	17	[{"id_menu":4,"count":1}]	17235	delivery	5	22
68138	2020-05-25 22:11:02	2020-05-25	17	[{"id_menu":4,"count":1}]	26909	delivery	5	22
68139	2020-05-25 22:11:21	2020-05-25	9	[{"id_menu":6,"count":1}]	245	pick-up	0	9
68140	2020-05-25 22:17:47	2020-05-25	12	[{"id_menu":1,"count":1}]	2552	delivery	5	17
68141	2020-05-25 22:23:14	2020-05-25	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	26814	pick-up	0	26
68142	2020-05-25 22:28:02	2020-05-25	12	[{"id_menu":1,"count":1}]	12124	pick-up	0	12
68143	2020-05-25 22:29:45	2020-05-25	14	[{"id_menu":2,"count":1}]	10254	delivery	5	19
68144	2020-05-25 22:30:07	2020-05-25	9	[{"id_menu":6,"count":1}]	26933	delivery	5	14
68145	2020-05-25 22:38:14	2020-05-25	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	21089	delivery	5	31
68146	2020-05-25 22:41:23	2020-05-25	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	19456	delivery	5	27
68147	2020-05-25 22:52:54	2020-05-25	9	[{"id_menu":7,"count":1}]	22629	delivery	5	14
68148	2020-05-25 22:53:20	2020-05-25	8	[{"id_menu":5,"count":1}]	22872	delivery	5	13
68149	2020-05-25 22:54:01	2020-05-25	8	[{"id_menu":5,"count":1}]	26939	delivery	5	13
68150	2020-05-25 23:08:32	2020-05-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	12772	delivery	5	22
68151	2020-05-25 23:09:08	2020-05-25	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	26914	delivery	5	40
68152	2020-05-25 23:14:48	2020-05-25	17	[{"id_menu":4,"count":1}]	1700	delivery	5	22
68153	2020-05-25 23:16:29	2020-05-25	9	[{"id_menu":7,"count":1}]	2529	pick-up	0	9
68154	2020-05-25 23:26:20	2020-05-25	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2434	pick-up	0	21
68155	2020-05-25 23:31:01	2020-05-25	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	26832	delivery	5	30
68156	2020-05-25 23:34:50	2020-05-25	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	23790	delivery	5	43
68157	2020-05-25 23:36:04	2020-05-25	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4295	pick-up	0	31
68158	2020-05-25 23:39:20	2020-05-25	9	[{"id_menu":6,"count":1}]	26953	delivery	5	14
68159	2020-05-25 23:40:32	2020-05-25	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	14175	delivery	5	28
68160	2020-05-25 23:55:16	2020-05-25	9	[{"id_menu":6,"count":1}]	11534	pick-up	0	9
68161	2020-05-25 23:58:45	2020-05-25	8	[{"id_menu":5,"count":1}]	26946	delivery	5	13
68162	2020-05-26 00:04:03	2020-05-26	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27057	delivery	5	52
68163	2020-05-26 00:05:39	2020-05-26	8	[{"id_menu":5,"count":1}]	12957	delivery	5	13
68164	2020-05-26 00:08:57	2020-05-26	8	[{"id_menu":5,"count":1}]	9531	pick-up	0	8
68165	2020-05-26 00:16:09	2020-05-26	9	[{"id_menu":6,"count":1}]	13105	delivery	5	14
68166	2020-05-26 00:18:28	2020-05-26	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	27103	delivery	5	31
68167	2020-05-26 00:23:19	2020-05-26	9	[{"id_menu":6,"count":1}]	2780	pick-up	0	9
68168	2020-05-26 00:24:32	2020-05-26	17	[{"id_menu":4,"count":1}]	12370	delivery	5	22
68169	2020-05-26 00:24:48	2020-05-26	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	26295	delivery	5	31
68170	2020-05-26 00:30:00	2020-05-26	8	[{"id_menu":5,"count":1}]	27064	delivery	5	13
68171	2020-05-26 00:30:26	2020-05-26	14	[{"id_menu":2,"count":1}]	1636	pick-up	0	14
68172	2020-05-26 00:37:19	2020-05-26	14	[{"id_menu":2,"count":1}]	6800	delivery	5	19
68173	2020-05-26 00:38:25	2020-05-26	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26706	delivery	5	45
68174	2020-05-26 00:39:51	2020-05-26	14	[{"id_menu":2,"count":1}]	23571	pick-up	0	14
68175	2020-05-26 00:40:38	2020-05-26	8	[{"id_menu":5,"count":1}]	27163	delivery	5	13
68176	2020-05-26 00:40:57	2020-05-26	17	[{"id_menu":4,"count":1}]	26991	delivery	5	22
68177	2020-05-26 00:46:18	2020-05-26	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21634	pick-up	0	49
68178	2020-05-26 00:50:45	2020-05-26	8	[{"id_menu":5,"count":1}]	27176	delivery	5	13
68179	2020-05-26 00:53:53	2020-05-26	9	[{"id_menu":7,"count":1}]	23831	pick-up	0	9
68180	2020-05-26 00:55:14	2020-05-26	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	23074	delivery	5	36
68181	2020-05-26 00:57:02	2020-05-26	9	[{"id_menu":7,"count":1}]	3160	pick-up	0	9
68182	2020-05-26 00:58:24	2020-05-26	12	[{"id_menu":3,"count":1}]	27180	delivery	5	17
68183	2020-05-26 01:01:24	2020-05-26	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27089	delivery	5	48
68184	2020-05-26 01:06:13	2020-05-26	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	10746	delivery	5	29
68185	2020-05-26 01:09:23	2020-05-26	49	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	27012	delivery	5	54
68186	2020-05-26 01:10:20	2020-05-26	14	[{"id_menu":2,"count":1}]	1266	delivery	5	19
68187	2020-05-26 01:11:36	2020-05-26	12	[{"id_menu":3,"count":1}]	27121	delivery	5	17
68188	2020-05-26 01:14:40	2020-05-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4697	delivery	5	23
68189	2020-05-26 01:14:46	2020-05-26	9	[{"id_menu":6,"count":1}]	7733	delivery	5	14
68190	2020-05-26 01:25:40	2020-05-26	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	22259	delivery	5	53
68191	2020-05-26 01:27:10	2020-05-26	14	[{"id_menu":2,"count":1}]	14972	delivery	5	19
68192	2020-05-26 01:28:58	2020-05-26	17	[{"id_menu":4,"count":1}]	23620	delivery	5	22
68193	2020-05-26 01:33:47	2020-05-26	9	[{"id_menu":7,"count":1}]	1924	delivery	5	14
68194	2020-05-26 01:36:28	2020-05-26	8	[{"id_menu":5,"count":1}]	27098	delivery	5	13
68195	2020-05-26 01:41:23	2020-05-26	12	[{"id_menu":3,"count":1}]	2404	delivery	5	17
68196	2020-05-26 01:44:21	2020-05-26	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11276	delivery	5	43
68197	2020-05-26 01:48:46	2020-05-26	12	[{"id_menu":1,"count":1}]	660	pick-up	0	12
68198	2020-05-26 01:50:16	2020-05-26	9	[{"id_menu":6,"count":1}]	25193	delivery	5	14
68199	2020-05-26 01:51:54	2020-05-26	8	[{"id_menu":5,"count":1}]	27058	delivery	5	13
68200	2020-05-26 01:55:19	2020-05-26	14	[{"id_menu":2,"count":1}]	13656	pick-up	0	14
68201	2020-05-26 01:56:26	2020-05-26	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	27106	delivery	5	43
68202	2020-05-26 02:01:33	2020-05-26	8	[{"id_menu":5,"count":1}]	10234	delivery	5	13
68203	2020-05-26 02:02:06	2020-05-26	9	[{"id_menu":6,"count":1}]	16891	delivery	5	14
68204	2020-05-26 02:02:58	2020-05-26	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	8700	pick-up	0	24
68205	2020-05-26 02:03:30	2020-05-26	14	[{"id_menu":2,"count":1}]	27131	delivery	5	19
68206	2020-05-26 02:07:46	2020-05-26	17	[{"id_menu":4,"count":1}]	8323	pick-up	0	17
68207	2020-05-26 02:08:42	2020-05-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17085	delivery	5	22
68208	2020-05-26 02:08:51	2020-05-26	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	12615	delivery	5	31
68209	2020-05-26 02:11:06	2020-05-26	8	[{"id_menu":5,"count":1}]	17536	delivery	5	13
68210	2020-05-26 02:25:02	2020-05-26	9	[{"id_menu":6,"count":1}]	27021	pick-up	0	9
68211	2020-05-26 02:25:03	2020-05-26	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23143	delivery	5	47
68212	2020-05-26 02:26:16	2020-05-26	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	22993	delivery	5	31
68213	2020-05-26 02:27:49	2020-05-26	17	[{"id_menu":4,"count":1}]	27102	delivery	5	22
68214	2020-05-26 02:35:56	2020-05-26	12	[{"id_menu":3,"count":1}]	10244	pick-up	0	12
68215	2020-05-26 02:36:58	2020-05-26	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13326	delivery	5	45
68216	2020-05-26 02:44:05	2020-05-26	9	[{"id_menu":6,"count":1}]	27020	delivery	5	14
68217	2020-05-26 02:45:35	2020-05-26	9	[{"id_menu":7,"count":1}]	1900	delivery	5	14
68218	2020-05-26 02:58:06	2020-05-26	8	[{"id_menu":5,"count":1}]	10365	delivery	5	13
68219	2020-05-26 02:58:54	2020-05-26	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	27164	delivery	5	38
68220	2020-05-26 03:00:22	2020-05-26	12	[{"id_menu":3,"count":1}]	2052	delivery	5	17
68221	2020-05-26 03:04:45	2020-05-26	9	[{"id_menu":7,"count":1}]	27052	delivery	5	14
68222	2020-05-26 03:06:54	2020-05-26	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21555	delivery	5	51
68223	2020-05-26 03:08:41	2020-05-26	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	27157	delivery	5	34
68224	2020-05-26 03:10:15	2020-05-26	12	[{"id_menu":3,"count":1}]	27113	delivery	5	17
68225	2020-05-26 03:12:43	2020-05-26	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	113	pick-up	0	38
68226	2020-05-26 03:13:19	2020-05-26	12	[{"id_menu":1,"count":1}]	25920	delivery	5	17
68227	2020-05-26 03:17:48	2020-05-26	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	27101	delivery	5	23
68228	2020-05-26 03:22:09	2020-05-26	9	[{"id_menu":7,"count":1}]	19957	pick-up	0	9
68229	2020-05-26 03:26:30	2020-05-26	9	[{"id_menu":7,"count":1}]	4688	pick-up	0	9
68230	2020-05-26 03:29:23	2020-05-26	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	3647	delivery	5	25
68231	2020-05-26 03:39:10	2020-05-26	9	[{"id_menu":6,"count":1}]	27061	delivery	5	14
68232	2020-05-26 03:51:09	2020-05-26	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27046	delivery	5	43
68233	2020-05-26 03:51:58	2020-05-26	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	27152	delivery	5	31
68234	2020-05-26 03:55:09	2020-05-26	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	14678	delivery	5	38
68235	2020-05-26 03:57:25	2020-05-26	17	[{"id_menu":4,"count":1}]	18375	delivery	5	22
68236	2020-05-26 04:02:42	2020-05-26	17	[{"id_menu":4,"count":1}]	26334	delivery	5	22
68237	2020-05-26 04:05:07	2020-05-26	8	[{"id_menu":5,"count":1}]	27003	delivery	5	13
68238	2020-05-26 04:06:21	2020-05-26	14	[{"id_menu":2,"count":1}]	27174	delivery	5	19
68239	2020-05-26 04:12:32	2020-05-26	9	[{"id_menu":7,"count":2}]	27076	delivery	5	14
68240	2020-05-26 04:12:53	2020-05-26	14	[{"id_menu":2,"count":1}]	26603	pick-up	0	14
68241	2020-05-26 04:14:13	2020-05-26	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	7137	delivery	5	37
68242	2020-05-26 04:14:59	2020-05-26	14	[{"id_menu":2,"count":1}]	27028	pick-up	0	14
68243	2020-05-26 04:18:08	2020-05-26	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	27179	delivery	5	22
68244	2020-05-26 04:19:41	2020-05-26	9	[{"id_menu":6,"count":1}]	27172	delivery	5	14
68245	2020-05-26 04:20:05	2020-05-26	9	[{"id_menu":7,"count":1}]	965	delivery	5	14
68246	2020-05-26 04:20:20	2020-05-26	9	[{"id_menu":7,"count":1}]	26223	delivery	5	14
68247	2020-05-26 04:21:36	2020-05-26	9	[{"id_menu":7,"count":2}]	27117	pick-up	0	9
68248	2020-05-26 04:25:25	2020-05-26	9	[{"id_menu":7,"count":1}]	6931	pick-up	0	9
68249	2020-05-26 04:25:47	2020-05-26	9	[{"id_menu":7,"count":1}]	12484	pick-up	0	9
68250	2020-05-26 04:28:04	2020-05-26	14	[{"id_menu":2,"count":1}]	1627	pick-up	0	14
68251	2020-05-26 04:35:15	2020-05-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	13634	delivery	5	26
68252	2020-05-26 04:35:35	2020-05-26	9	[{"id_menu":6,"count":1}]	27177	delivery	5	14
68253	2020-05-26 04:35:42	2020-05-26	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	11635	delivery	5	43
68254	2020-05-26 04:38:52	2020-05-26	9	[{"id_menu":6,"count":1}]	20091	delivery	5	14
68255	2020-05-26 04:41:26	2020-05-26	12	[{"id_menu":1,"count":1}]	17159	delivery	5	17
68256	2020-05-26 04:42:47	2020-05-26	9	[{"id_menu":6,"count":1}]	4824	delivery	5	14
68257	2020-05-26 04:44:17	2020-05-26	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	20378	delivery	5	45
68258	2020-05-26 04:46:51	2020-05-26	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	19507	delivery	5	39
68259	2020-05-26 04:47:21	2020-05-26	17	[{"id_menu":4,"count":1}]	15216	delivery	5	22
68260	2020-05-26 04:54:42	2020-05-26	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	27027	delivery	5	26
68261	2020-05-26 04:58:48	2020-05-26	9	[{"id_menu":6,"count":1}]	27062	delivery	5	14
68262	2020-05-26 05:00:09	2020-05-26	12	[{"id_menu":3,"count":1}]	4309	pick-up	0	12
68263	2020-05-26 05:07:31	2020-05-26	14	[{"id_menu":2,"count":1}]	12979	delivery	5	19
68264	2020-05-26 05:11:19	2020-05-26	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	1479	delivery	5	40
68265	2020-05-26 05:12:42	2020-05-26	12	[{"id_menu":1,"count":1}]	10452	pick-up	0	12
68266	2020-05-26 05:18:32	2020-05-26	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	27166	pick-up	0	24
68267	2020-05-26 05:18:41	2020-05-26	12	[{"id_menu":3,"count":1}]	6637	pick-up	0	12
68268	2020-05-26 05:19:19	2020-05-26	9	[{"id_menu":6,"count":1}]	26969	delivery	5	14
68269	2020-05-26 05:25:25	2020-05-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	26993	delivery	5	26
68270	2020-05-26 05:30:39	2020-05-26	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	27070	delivery	5	31
68271	2020-05-26 05:31:52	2020-05-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4006	delivery	5	28
68272	2020-05-26 05:36:30	2020-05-26	8	[{"id_menu":5,"count":1}]	22085	delivery	5	13
68273	2020-05-26 05:38:14	2020-05-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16508	delivery	5	23
68274	2020-05-26 05:39:47	2020-05-26	8	[{"id_menu":5,"count":1}]	26751	delivery	5	13
68275	2020-05-26 05:40:19	2020-05-26	8	[{"id_menu":5,"count":1}]	1860	pick-up	0	8
68276	2020-05-26 05:42:15	2020-05-26	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	13383	delivery	5	36
68277	2020-05-26 05:43:54	2020-05-26	12	[{"id_menu":1,"count":1}]	18	pick-up	0	12
68278	2020-05-26 05:44:37	2020-05-26	12	[{"id_menu":3,"count":1}]	4681	delivery	5	17
68279	2020-05-26 05:45:55	2020-05-26	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15118	delivery	5	34
68280	2020-05-26 05:49:32	2020-05-26	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27060	delivery	5	52
68281	2020-05-26 05:49:53	2020-05-26	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2309	pick-up	0	21
68282	2020-05-26 05:52:15	2020-05-26	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1536	pick-up	0	21
68283	2020-05-26 06:10:34	2020-05-26	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	27128	delivery	5	34
68284	2020-05-26 06:11:04	2020-05-26	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	27120	delivery	5	36
68285	2020-05-26 06:11:44	2020-05-26	9	[{"id_menu":7,"count":1}]	11370	pick-up	0	9
68286	2020-05-26 06:13:29	2020-05-26	9	[{"id_menu":7,"count":1}]	27165	delivery	5	14
68287	2020-05-26 06:25:03	2020-05-26	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	4105	delivery	5	31
68288	2020-05-26 06:25:03	2020-05-26	17	[{"id_menu":4,"count":2}]	22207	pick-up	0	17
68289	2020-05-26 06:29:32	2020-05-26	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	27099	delivery	5	48
68290	2020-05-26 06:34:09	2020-05-26	9	[{"id_menu":7,"count":1}]	27084	delivery	5	14
68291	2020-05-26 06:37:23	2020-05-26	8	[{"id_menu":5,"count":1}]	379	pick-up	0	8
68292	2020-05-26 06:46:29	2020-05-26	9	[{"id_menu":6,"count":1}]	1254	pick-up	0	9
68293	2020-05-26 06:47:32	2020-05-26	9	[{"id_menu":6,"count":1}]	26974	delivery	5	14
68294	2020-05-26 06:49:38	2020-05-26	8	[{"id_menu":5,"count":1}]	27038	pick-up	0	8
68295	2020-05-26 06:51:08	2020-05-26	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	12098	delivery	5	26
68296	2020-05-26 06:51:32	2020-05-26	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	26977	delivery	5	40
68297	2020-05-26 06:52:41	2020-05-26	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	12997	delivery	5	26
68298	2020-05-26 06:53:24	2020-05-26	9	[{"id_menu":7,"count":1}]	11296	delivery	5	14
68299	2020-05-26 06:57:38	2020-05-26	9	[{"id_menu":6,"count":1}]	906	pick-up	0	9
68300	2020-05-26 06:58:04	2020-05-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	380	delivery	5	26
68301	2020-05-26 06:59:03	2020-05-26	17	[{"id_menu":4,"count":1}]	17766	pick-up	0	17
68302	2020-05-26 07:02:12	2020-05-26	9	[{"id_menu":6,"count":1}]	27008	delivery	5	14
68303	2020-05-26 07:06:06	2020-05-26	12	[{"id_menu":1,"count":1}]	19545	delivery	5	17
68304	2020-05-26 07:10:05	2020-05-26	17	[{"id_menu":4,"count":2}]	27054	delivery	5	22
68305	2020-05-26 07:11:41	2020-05-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6561	delivery	5	22
68306	2020-05-26 07:13:56	2020-05-26	9	[{"id_menu":6,"count":1}]	14304	delivery	5	14
68307	2020-05-26 07:13:58	2020-05-26	8	[{"id_menu":5,"count":1}]	9459	delivery	5	13
68308	2020-05-26 07:28:12	2020-05-26	9	[{"id_menu":6,"count":1}]	6919	delivery	5	14
68309	2020-05-26 07:31:29	2020-05-26	9	[{"id_menu":7,"count":1}]	19143	delivery	5	14
68310	2020-05-26 07:33:31	2020-05-26	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2406	delivery	5	42
68311	2020-05-26 07:33:57	2020-05-26	9	[{"id_menu":7,"count":1}]	27144	delivery	5	14
68312	2020-05-26 07:34:37	2020-05-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	20325	delivery	5	31
68313	2020-05-26 07:36:58	2020-05-26	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	27016	delivery	5	34
68314	2020-05-26 07:38:33	2020-05-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14072	delivery	5	23
68315	2020-05-26 07:40:14	2020-05-26	9	[{"id_menu":6,"count":1}]	27129	delivery	5	14
68316	2020-05-26 07:41:35	2020-05-26	9	[{"id_menu":7,"count":1}]	26976	delivery	5	14
68317	2020-05-26 07:45:12	2020-05-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	24459	delivery	5	28
68318	2020-05-26 07:46:08	2020-05-26	12	[{"id_menu":3,"count":1}]	26972	delivery	5	17
68319	2020-05-26 07:49:50	2020-05-26	17	[{"id_menu":4,"count":2}]	9830	pick-up	0	17
68320	2020-05-26 07:58:04	2020-05-26	9	[{"id_menu":6,"count":1}]	4495	delivery	5	14
68321	2020-05-26 08:01:47	2020-05-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	27083	delivery	5	22
68322	2020-05-26 08:02:36	2020-05-26	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6113	delivery	5	31
68323	2020-05-26 08:04:29	2020-05-26	17	[{"id_menu":4,"count":1}]	22822	delivery	5	22
68324	2020-05-26 08:05:15	2020-05-26	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7118	pick-up	0	25
68325	2020-05-26 08:11:04	2020-05-26	9	[{"id_menu":6,"count":1}]	27049	delivery	5	14
68326	2020-05-26 08:11:21	2020-05-26	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	6231	delivery	5	22
68327	2020-05-26 08:15:33	2020-05-26	8	[{"id_menu":5,"count":1}]	10272	delivery	5	13
68328	2020-05-26 08:27:50	2020-05-26	17	[{"id_menu":4,"count":1}]	26171	delivery	5	22
68329	2020-05-26 08:28:44	2020-05-26	17	[{"id_menu":4,"count":1}]	27025	delivery	5	22
68330	2020-05-26 08:29:14	2020-05-26	12	[{"id_menu":3,"count":1}]	16418	pick-up	0	12
68331	2020-05-26 08:32:45	2020-05-26	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	23356	delivery	5	31
68332	2020-05-26 08:33:30	2020-05-26	9	[{"id_menu":7,"count":1}]	3507	pick-up	0	9
68333	2020-05-26 08:34:03	2020-05-26	14	[{"id_menu":2,"count":1}]	27079	delivery	5	19
68334	2020-05-26 08:38:47	2020-05-26	9	[{"id_menu":6,"count":1}]	16620	delivery	5	14
68335	2020-05-26 08:42:05	2020-05-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	26971	delivery	5	22
68336	2020-05-26 08:44:12	2020-05-26	12	[{"id_menu":3,"count":1}]	7741	delivery	5	17
68337	2020-05-26 08:45:32	2020-05-26	8	[{"id_menu":5,"count":1}]	3960	pick-up	0	8
68338	2020-05-26 08:48:15	2020-05-26	12	[{"id_menu":1,"count":1}]	15873	delivery	5	17
68339	2020-05-26 08:51:01	2020-05-26	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	15679	delivery	5	42
68340	2020-05-26 08:52:44	2020-05-26	9	[{"id_menu":6,"count":1}]	1934	delivery	5	14
68341	2020-05-26 08:53:46	2020-05-26	12	[{"id_menu":1,"count":1}]	3820	pick-up	0	12
68342	2020-05-26 08:56:28	2020-05-26	17	[{"id_menu":4,"count":1}]	12527	delivery	5	22
68343	2020-05-26 09:07:49	2020-05-26	9	[{"id_menu":7,"count":1}]	22813	delivery	5	14
68344	2020-05-26 09:07:50	2020-05-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6233	delivery	5	23
68345	2020-05-26 09:08:55	2020-05-26	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	7934	pick-up	0	21
68346	2020-05-26 09:09:53	2020-05-26	8	[{"id_menu":5,"count":1}]	21147	delivery	5	13
68347	2020-05-26 09:20:36	2020-05-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25003	delivery	5	23
68348	2020-05-26 09:22:04	2020-05-26	14	[{"id_menu":2,"count":1}]	27100	delivery	5	19
68349	2020-05-26 09:23:52	2020-05-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	26984	pick-up	0	21
68350	2020-05-26 09:27:32	2020-05-26	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	2467	delivery	5	26
68351	2020-05-26 09:40:15	2020-05-26	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22633	delivery	5	45
68352	2020-05-26 09:42:42	2020-05-26	9	[{"id_menu":6,"count":1}]	20331	pick-up	0	9
68353	2020-05-26 09:43:15	2020-05-26	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	27085	delivery	5	31
68354	2020-05-26 09:44:47	2020-05-26	14	[{"id_menu":2,"count":1}]	26986	pick-up	0	14
68355	2020-05-26 09:47:10	2020-05-26	9	[{"id_menu":7,"count":1}]	27148	delivery	5	14
68356	2020-05-26 09:48:29	2020-05-26	9	[{"id_menu":6,"count":1}]	153	pick-up	0	9
68357	2020-05-26 09:48:31	2020-05-26	14	[{"id_menu":2,"count":1}]	27039	pick-up	0	14
68358	2020-05-26 09:49:14	2020-05-26	8	[{"id_menu":5,"count":1}]	27090	delivery	5	13
68359	2020-05-26 09:51:44	2020-05-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21867	delivery	5	22
68360	2020-05-26 09:53:40	2020-05-26	8	[{"id_menu":5,"count":1}]	14501	delivery	5	13
68361	2020-05-26 09:55:21	2020-05-26	9	[{"id_menu":6,"count":1}]	26547	delivery	5	14
68362	2020-05-26 09:56:34	2020-05-26	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	14422	delivery	5	43
68363	2020-05-26 09:58:27	2020-05-26	9	[{"id_menu":6,"count":1}]	90	pick-up	0	9
68364	2020-05-26 10:00:01	2020-05-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	27173	delivery	5	26
68365	2020-05-26 10:10:45	2020-05-26	8	[{"id_menu":5,"count":1}]	9703	delivery	5	13
68366	2020-05-26 10:13:07	2020-05-26	17	[{"id_menu":4,"count":1}]	27146	delivery	5	22
68367	2020-05-26 10:13:26	2020-05-26	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	2927	delivery	5	31
68368	2020-05-26 10:17:57	2020-05-26	8	[{"id_menu":5,"count":1}]	27081	delivery	5	13
68369	2020-05-26 10:19:57	2020-05-26	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	5965	pick-up	0	20
68370	2020-05-26 10:23:23	2020-05-26	8	[{"id_menu":5,"count":1}]	19971	delivery	5	13
68371	2020-05-26 10:36:43	2020-05-26	12	[{"id_menu":1,"count":1}]	27041	delivery	5	17
68372	2020-05-26 10:42:00	2020-05-26	17	[{"id_menu":4,"count":1}]	15552	pick-up	0	17
68373	2020-05-26 10:43:21	2020-05-26	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27118	delivery	5	40
68374	2020-05-26 10:51:49	2020-05-26	17	[{"id_menu":4,"count":1}]	11878	pick-up	0	17
68375	2020-05-26 10:54:42	2020-05-26	12	[{"id_menu":3,"count":1}]	22900	delivery	5	17
68376	2020-05-26 10:56:44	2020-05-26	9	[{"id_menu":7,"count":1}]	1571	pick-up	0	9
68377	2020-05-26 10:57:32	2020-05-26	12	[{"id_menu":3,"count":1}]	25463	delivery	5	17
68378	2020-05-26 11:00:45	2020-05-26	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	23772	delivery	5	23
68379	2020-05-26 11:01:32	2020-05-26	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9021	delivery	5	40
68380	2020-05-26 11:04:26	2020-05-26	9	[{"id_menu":7,"count":1}]	13285	delivery	5	14
68381	2020-05-26 11:07:46	2020-05-26	9	[{"id_menu":7,"count":1}]	27029	delivery	5	14
68382	2020-05-26 11:07:58	2020-05-26	12	[{"id_menu":3,"count":1}]	27151	delivery	5	17
68383	2020-05-26 11:08:41	2020-05-26	12	[{"id_menu":3,"count":1}]	26937	pick-up	0	12
68384	2020-05-26 11:08:49	2020-05-26	12	[{"id_menu":1,"count":2}]	27096	delivery	5	17
68385	2020-05-26 11:12:05	2020-05-26	8	[{"id_menu":5,"count":1}]	27077	delivery	5	13
68386	2020-05-26 11:16:17	2020-05-26	9	[{"id_menu":6,"count":3}]	5101	delivery	5	14
68387	2020-05-26 11:16:28	2020-05-26	9	[{"id_menu":7,"count":1}]	13996	pick-up	0	9
68388	2020-05-26 11:21:48	2020-05-26	9	[{"id_menu":6,"count":1}]	18172	delivery	5	14
68389	2020-05-26 11:23:01	2020-05-26	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	27035	delivery	5	40
68390	2020-05-26 11:23:41	2020-05-26	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18321	delivery	5	34
68391	2020-05-26 11:23:58	2020-05-26	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	20783	delivery	5	48
68392	2020-05-26 11:27:14	2020-05-26	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	10780	pick-up	0	26
68393	2020-05-26 11:28:56	2020-05-26	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7342	delivery	5	36
68394	2020-05-26 11:36:22	2020-05-26	9	[{"id_menu":7,"count":1}]	27105	delivery	5	14
68395	2020-05-26 11:49:43	2020-05-26	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	18499	delivery	5	25
68396	2020-05-26 11:52:27	2020-05-26	9	[{"id_menu":6,"count":1}]	4092	delivery	5	14
68397	2020-05-26 11:56:24	2020-05-26	17	[{"id_menu":4,"count":1}]	10021	delivery	5	22
68398	2020-05-26 11:57:58	2020-05-26	9	[{"id_menu":7,"count":1}]	27092	delivery	5	14
68399	2020-05-26 12:01:17	2020-05-26	17	[{"id_menu":4,"count":1}]	10494	delivery	5	22
68400	2020-05-26 12:04:29	2020-05-26	14	[{"id_menu":2,"count":2}]	14982	pick-up	0	14
68401	2020-05-26 12:05:46	2020-05-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	13010	delivery	5	22
68402	2020-05-26 12:08:33	2020-05-26	9	[{"id_menu":6,"count":1}]	17777	pick-up	0	9
68403	2020-05-26 12:12:45	2020-05-26	12	[{"id_menu":3,"count":1}]	21849	pick-up	0	12
68404	2020-05-26 12:13:54	2020-05-26	9	[{"id_menu":7,"count":1}]	22428	delivery	5	14
68405	2020-05-26 12:16:48	2020-05-26	17	[{"id_menu":4,"count":1}]	25907	pick-up	0	17
68406	2020-05-26 12:18:29	2020-05-26	14	[{"id_menu":2,"count":2}]	27066	delivery	5	19
68407	2020-05-26 12:22:02	2020-05-26	17	[{"id_menu":4,"count":1}]	26985	delivery	5	22
68408	2020-05-26 12:22:22	2020-05-26	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1151	delivery	5	47
68409	2020-05-26 12:27:06	2020-05-26	9	[{"id_menu":6,"count":1}]	18149	delivery	5	14
68410	2020-05-26 12:29:01	2020-05-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	23588	pick-up	0	18
68411	2020-05-26 12:35:01	2020-05-26	9	[{"id_menu":7,"count":1}]	13335	delivery	5	14
68412	2020-05-26 12:41:56	2020-05-26	14	[{"id_menu":2,"count":1}]	18253	delivery	5	19
68413	2020-05-26 12:56:05	2020-05-26	9	[{"id_menu":7,"count":1}]	20380	delivery	5	14
68414	2020-05-26 12:56:23	2020-05-26	17	[{"id_menu":4,"count":1}]	27122	delivery	5	22
68415	2020-05-26 12:58:12	2020-05-26	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	23923	delivery	5	42
68416	2020-05-26 12:58:40	2020-05-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	18057	pick-up	0	23
68417	2020-05-26 13:01:07	2020-05-26	9	[{"id_menu":6,"count":1}]	26036	delivery	5	14
68418	2020-05-26 13:06:16	2020-05-26	9	[{"id_menu":6,"count":1}]	27130	delivery	5	14
68419	2020-05-26 13:08:52	2020-05-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	27015	pick-up	0	26
68420	2020-05-26 13:26:26	2020-05-26	17	[{"id_menu":4,"count":1}]	22713	delivery	5	22
68421	2020-05-26 13:32:18	2020-05-26	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	9901	delivery	5	31
68422	2020-05-26 13:32:27	2020-05-26	9	[{"id_menu":6,"count":1}]	27111	delivery	5	14
68423	2020-05-26 13:36:51	2020-05-26	9	[{"id_menu":6,"count":1}]	11569	delivery	5	14
68424	2020-05-26 13:41:15	2020-05-26	8	[{"id_menu":5,"count":1}]	12053	pick-up	0	8
68425	2020-05-26 13:44:31	2020-05-26	14	[{"id_menu":2,"count":1}]	8887	pick-up	0	14
68426	2020-05-26 13:44:45	2020-05-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	27050	delivery	5	26
68427	2020-05-26 13:46:14	2020-05-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27071	delivery	5	22
68428	2020-05-26 13:47:03	2020-05-26	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	14025	pick-up	0	24
68429	2020-05-26 13:48:56	2020-05-26	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1964	pick-up	0	51
68430	2020-05-26 13:50:39	2020-05-26	9	[{"id_menu":6,"count":1}]	16176	delivery	5	14
68431	2020-05-26 13:59:35	2020-05-26	12	[{"id_menu":3,"count":2}]	4644	delivery	5	17
68432	2020-05-26 14:01:24	2020-05-26	14	[{"id_menu":2,"count":1}]	23162	delivery	5	19
68433	2020-05-26 14:01:26	2020-05-26	14	[{"id_menu":2,"count":1}]	27036	delivery	5	19
68434	2020-05-26 14:03:14	2020-05-26	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	27161	pick-up	0	29
68435	2020-05-26 14:05:36	2020-05-26	9	[{"id_menu":7,"count":1}]	27132	delivery	5	14
68436	2020-05-26 14:09:46	2020-05-26	9	[{"id_menu":6,"count":1}]	5619	delivery	5	14
68437	2020-05-26 14:10:52	2020-05-26	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	24125	delivery	5	25
68438	2020-05-26 14:11:16	2020-05-26	9	[{"id_menu":7,"count":1}]	19717	pick-up	0	9
68439	2020-05-26 14:14:46	2020-05-26	14	[{"id_menu":2,"count":1}]	8813	delivery	5	19
68440	2020-05-26 14:15:09	2020-05-26	9	[{"id_menu":6,"count":1}]	2110	pick-up	0	9
68441	2020-05-26 14:17:01	2020-05-26	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	27065	delivery	5	43
68442	2020-05-26 14:21:15	2020-05-26	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	27136	delivery	5	26
68443	2020-05-26 14:22:01	2020-05-26	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	8873	pick-up	0	31
68444	2020-05-26 14:31:03	2020-05-26	12	[{"id_menu":3,"count":1}]	27170	delivery	5	17
68445	2020-05-26 14:36:39	2020-05-26	9	[{"id_menu":7,"count":1}]	6090	pick-up	0	9
68446	2020-05-26 14:38:49	2020-05-26	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	8542	delivery	5	43
68447	2020-05-26 14:45:22	2020-05-26	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27007	delivery	5	34
68448	2020-05-26 14:47:42	2020-05-26	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	27014	delivery	5	36
68449	2020-05-26 14:55:00	2020-05-26	17	[{"id_menu":4,"count":1}]	1569	pick-up	0	17
68450	2020-05-26 15:02:56	2020-05-26	9	[{"id_menu":6,"count":1}]	8159	delivery	5	14
68451	2020-05-26 15:12:44	2020-05-26	9	[{"id_menu":7,"count":1}]	13432	delivery	5	14
68452	2020-05-26 15:14:10	2020-05-26	9	[{"id_menu":7,"count":1}]	27072	delivery	5	14
68453	2020-05-26 15:15:07	2020-05-26	8	[{"id_menu":5,"count":1}]	27043	delivery	5	13
68454	2020-05-26 15:20:37	2020-05-26	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5107	delivery	5	54
68455	2020-05-26 15:20:40	2020-05-26	8	[{"id_menu":5,"count":1}]	18187	delivery	5	13
68456	2020-05-26 15:29:05	2020-05-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17837	delivery	5	31
68457	2020-05-26 15:34:52	2020-05-26	14	[{"id_menu":2,"count":1}]	20579	delivery	5	19
68458	2020-05-26 15:36:55	2020-05-26	17	[{"id_menu":4,"count":1}]	1496	pick-up	0	17
68459	2020-05-26 15:40:45	2020-05-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	27108	delivery	5	26
68460	2020-05-26 15:43:28	2020-05-26	9	[{"id_menu":6,"count":2}]	25637	delivery	5	14
68461	2020-05-26 15:46:30	2020-05-26	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	13218	delivery	5	37
68462	2020-05-26 15:46:46	2020-05-26	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	26990	delivery	5	31
68463	2020-05-26 15:47:55	2020-05-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	27153	delivery	5	22
68464	2020-05-26 15:49:39	2020-05-26	37	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	16903	delivery	5	42
68465	2020-05-26 15:52:38	2020-05-26	12	[{"id_menu":3,"count":1}]	6565	pick-up	0	12
68466	2020-05-26 15:59:30	2020-05-26	12	[{"id_menu":1,"count":1}]	2068	delivery	5	17
68467	2020-05-26 16:03:05	2020-05-26	9	[{"id_menu":7,"count":1}]	27063	delivery	5	14
68468	2020-05-26 16:08:55	2020-05-26	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	16498	delivery	5	31
68469	2020-05-26 16:10:59	2020-05-26	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	26770	delivery	5	39
68470	2020-05-26 16:14:12	2020-05-26	14	[{"id_menu":2,"count":1}]	27091	delivery	5	19
68471	2020-05-26 16:14:17	2020-05-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	27110	delivery	5	22
68472	2020-05-26 16:22:50	2020-05-26	12	[{"id_menu":3,"count":1}]	12346	delivery	5	17
68473	2020-05-26 16:23:12	2020-05-26	8	[{"id_menu":5,"count":1}]	27167	delivery	5	13
68474	2020-05-26 16:29:46	2020-05-26	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	27009	delivery	5	55
68475	2020-05-26 16:31:09	2020-05-26	9	[{"id_menu":7,"count":1}]	26963	delivery	5	14
68476	2020-05-26 16:32:13	2020-05-26	12	[{"id_menu":1,"count":2}]	27140	delivery	5	17
68477	2020-05-26 16:34:24	2020-05-26	14	[{"id_menu":2,"count":1}]	6962	pick-up	0	14
68478	2020-05-26 16:35:32	2020-05-26	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16126	delivery	5	34
68479	2020-05-26 16:42:12	2020-05-26	14	[{"id_menu":2,"count":1}]	2134	pick-up	0	14
68480	2020-05-26 16:46:03	2020-05-26	17	[{"id_menu":4,"count":1}]	27074	delivery	5	22
68481	2020-05-26 16:46:15	2020-05-26	9	[{"id_menu":7,"count":1}]	27158	delivery	5	14
68482	2020-05-26 16:49:54	2020-05-26	9	[{"id_menu":6,"count":1}]	27138	delivery	5	14
68483	2020-05-26 16:50:22	2020-05-26	17	[{"id_menu":4,"count":1}]	20360	delivery	5	22
68484	2020-05-26 16:51:13	2020-05-26	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	4834	pick-up	0	26
68485	2020-05-26 16:57:08	2020-05-26	12	[{"id_menu":3,"count":1}]	15109	pick-up	0	12
68486	2020-05-26 16:57:54	2020-05-26	12	[{"id_menu":3,"count":1}]	26970	pick-up	0	12
68487	2020-05-26 17:03:21	2020-05-26	17	[{"id_menu":4,"count":1}]	27040	delivery	5	22
68488	2020-05-26 17:08:13	2020-05-26	17	[{"id_menu":4,"count":1}]	26981	delivery	5	22
68489	2020-05-26 17:12:30	2020-05-26	8	[{"id_menu":5,"count":1}]	27013	delivery	5	13
68490	2020-05-26 17:16:12	2020-05-26	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	6024	delivery	5	25
68491	2020-05-26 17:16:30	2020-05-26	9	[{"id_menu":7,"count":1}]	27026	delivery	5	14
68492	2020-05-26 17:17:56	2020-05-26	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	21779	delivery	5	25
68493	2020-05-26 17:23:12	2020-05-26	9	[{"id_menu":6,"count":1}]	27150	delivery	5	14
68494	2020-05-26 17:24:14	2020-05-26	12	[{"id_menu":1,"count":1}]	12278	pick-up	0	12
68495	2020-05-26 17:31:18	2020-05-26	14	[{"id_menu":2,"count":1}]	12022	delivery	5	19
68496	2020-05-26 17:37:47	2020-05-26	9	[{"id_menu":7,"count":2}]	18705	delivery	5	14
68497	2020-05-26 17:50:50	2020-05-26	9	[{"id_menu":7,"count":1}]	25416	delivery	5	14
68498	2020-05-26 17:52:31	2020-05-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26997	delivery	5	23
68499	2020-05-26 17:58:38	2020-05-26	9	[{"id_menu":7,"count":1}]	27087	delivery	5	14
68500	2020-05-26 18:00:48	2020-05-26	8	[{"id_menu":5,"count":1}]	1119	delivery	5	13
68501	2020-05-26 18:05:12	2020-05-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	16682	delivery	5	26
68502	2020-05-26 18:07:16	2020-05-26	9	[{"id_menu":6,"count":1}]	5232	pick-up	0	9
68503	2020-05-26 18:07:47	2020-05-26	9	[{"id_menu":7,"count":1}]	3467	delivery	5	14
68504	2020-05-26 18:07:52	2020-05-26	14	[{"id_menu":2,"count":1}]	26260	delivery	5	19
68505	2020-05-26 18:10:06	2020-05-26	14	[{"id_menu":2,"count":2}]	26685	delivery	5	19
68506	2020-05-26 18:27:53	2020-05-26	9	[{"id_menu":6,"count":1}]	27002	delivery	5	14
68507	2020-05-26 18:29:42	2020-05-26	14	[{"id_menu":2,"count":1}]	10356	delivery	5	19
68508	2020-05-26 18:36:50	2020-05-26	12	[{"id_menu":1,"count":1}]	11843	pick-up	0	12
68509	2020-05-26 18:37:56	2020-05-26	9	[{"id_menu":6,"count":2}]	25982	delivery	5	14
68510	2020-05-26 18:50:34	2020-05-26	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	27125	delivery	5	34
68511	2020-05-26 18:52:00	2020-05-26	29	[{"id_menu":3,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4398	delivery	5	34
68512	2020-05-26 18:53:02	2020-05-26	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	27107	delivery	5	38
68513	2020-05-26 18:55:14	2020-05-26	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	23637	delivery	5	36
68514	2020-05-26 19:00:50	2020-05-26	8	[{"id_menu":5,"count":1}]	27010	delivery	5	13
68515	2020-05-26 19:01:01	2020-05-26	14	[{"id_menu":2,"count":1}]	1989	delivery	5	19
68516	2020-05-26 19:03:55	2020-05-26	12	[{"id_menu":1,"count":1}]	27017	delivery	5	17
68517	2020-05-26 19:09:04	2020-05-26	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	338	pick-up	0	31
68518	2020-05-26 19:14:27	2020-05-26	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27022	delivery	5	45
68519	2020-05-26 19:17:36	2020-05-26	8	[{"id_menu":5,"count":1}]	26966	delivery	5	13
68520	2020-05-26 19:19:46	2020-05-26	14	[{"id_menu":2,"count":1}]	4202	pick-up	0	14
68521	2020-05-26 19:27:15	2020-05-26	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	27005	delivery	5	31
68522	2020-05-26 19:29:39	2020-05-26	8	[{"id_menu":5,"count":1}]	6470	pick-up	0	8
68523	2020-05-26 19:29:46	2020-05-26	17	[{"id_menu":4,"count":1}]	26987	delivery	5	22
68524	2020-05-26 19:30:07	2020-05-26	17	[{"id_menu":4,"count":1}]	27124	delivery	5	22
68525	2020-05-26 19:33:28	2020-05-26	12	[{"id_menu":3,"count":1}]	27115	delivery	5	17
68526	2020-05-26 19:34:40	2020-05-26	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	25861	delivery	5	27
68527	2020-05-26 19:35:10	2020-05-26	9	[{"id_menu":7,"count":1}]	27047	delivery	5	14
68528	2020-05-26 19:37:54	2020-05-26	14	[{"id_menu":2,"count":1}]	993	delivery	5	19
68529	2020-05-26 19:41:28	2020-05-26	8	[{"id_menu":5,"count":1}]	2384	pick-up	0	8
68530	2020-05-26 19:42:38	2020-05-26	9	[{"id_menu":6,"count":1}]	17752	delivery	5	14
68531	2020-05-26 19:45:44	2020-05-26	12	[{"id_menu":1,"count":1}]	1104	pick-up	0	12
68532	2020-05-26 19:48:27	2020-05-26	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	18312	delivery	5	44
68533	2020-05-26 19:49:19	2020-05-26	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27068	delivery	5	36
68534	2020-05-26 19:57:59	2020-05-26	17	[{"id_menu":4,"count":2}]	15618	delivery	5	22
68535	2020-05-26 20:00:55	2020-05-26	8	[{"id_menu":5,"count":1}]	27095	delivery	5	13
68536	2020-05-26 20:07:10	2020-05-26	9	[{"id_menu":6,"count":1}]	27037	delivery	5	14
68537	2020-05-26 20:09:48	2020-05-26	17	[{"id_menu":4,"count":1}]	6916	pick-up	0	17
68538	2020-05-26 20:13:28	2020-05-26	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	27159	delivery	5	53
68539	2020-05-26 20:22:12	2020-05-26	14	[{"id_menu":2,"count":1}]	1490	pick-up	0	14
68540	2020-05-26 20:22:24	2020-05-26	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	24275	delivery	5	36
68541	2020-05-26 20:24:24	2020-05-26	14	[{"id_menu":2,"count":1}]	2071	delivery	5	19
68542	2020-05-26 20:37:59	2020-05-26	17	[{"id_menu":4,"count":2}]	9266	pick-up	0	17
68543	2020-05-26 20:42:54	2020-05-26	17	[{"id_menu":4,"count":1}]	9575	pick-up	0	17
68544	2020-05-26 20:53:44	2020-05-26	8	[{"id_menu":5,"count":1}]	26967	pick-up	0	8
68545	2020-05-26 20:54:24	2020-05-26	17	[{"id_menu":4,"count":1}]	27001	pick-up	0	17
68546	2020-05-26 20:55:13	2020-05-26	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	6152	pick-up	0	22
68547	2020-05-26 20:55:26	2020-05-26	9	[{"id_menu":7,"count":1}]	10640	pick-up	0	9
68548	2020-05-26 20:59:39	2020-05-26	12	[{"id_menu":1,"count":1}]	10679	pick-up	0	12
68549	2020-05-26 21:00:28	2020-05-26	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	5152	delivery	5	39
68550	2020-05-26 21:00:58	2020-05-26	9	[{"id_menu":6,"count":1}]	27018	delivery	5	14
68551	2020-05-26 21:01:57	2020-05-26	9	[{"id_menu":6,"count":1}]	9191	pick-up	0	9
68552	2020-05-26 21:03:09	2020-05-26	12	[{"id_menu":1,"count":1}]	27004	delivery	5	17
68553	2020-05-26 21:04:16	2020-05-26	14	[{"id_menu":2,"count":1}]	23760	delivery	5	19
68554	2020-05-26 21:06:07	2020-05-26	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15924	delivery	5	40
68555	2020-05-26 21:08:39	2020-05-26	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	21606	delivery	5	27
68556	2020-05-26 21:20:37	2020-05-26	9	[{"id_menu":6,"count":1}]	12263	delivery	5	14
68557	2020-05-26 21:21:20	2020-05-26	9	[{"id_menu":6,"count":1}]	1596	pick-up	0	9
68558	2020-05-26 21:26:34	2020-05-26	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	27116	delivery	5	45
68559	2020-05-26 21:26:41	2020-05-26	14	[{"id_menu":2,"count":1}]	26968	delivery	5	19
68560	2020-05-26 21:32:26	2020-05-26	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	14146	pick-up	0	40
68561	2020-05-26 21:41:53	2020-05-26	14	[{"id_menu":2,"count":1}]	17614	pick-up	0	14
68562	2020-05-26 21:46:15	2020-05-26	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21079	delivery	5	39
68563	2020-05-26 21:47:04	2020-05-26	9	[{"id_menu":6,"count":1}]	25404	delivery	5	14
68564	2020-05-26 21:48:12	2020-05-26	12	[{"id_menu":3,"count":1}]	12203	delivery	5	17
68565	2020-05-26 21:50:09	2020-05-26	9	[{"id_menu":7,"count":1}]	26982	delivery	5	14
68566	2020-05-26 21:51:21	2020-05-26	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	27162	delivery	5	31
68567	2020-05-26 21:51:34	2020-05-26	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	2690	delivery	5	28
68568	2020-05-26 21:55:49	2020-05-26	9	[{"id_menu":7,"count":1}]	6469	pick-up	0	9
68569	2020-05-26 21:59:39	2020-05-26	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	26625	delivery	5	34
68570	2020-05-26 22:05:33	2020-05-26	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	27078	delivery	5	25
68571	2020-05-26 22:06:12	2020-05-26	12	[{"id_menu":3,"count":2}]	27137	pick-up	0	12
68572	2020-05-26 22:12:24	2020-05-26	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27030	delivery	5	31
68573	2020-05-26 22:12:47	2020-05-26	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4567	delivery	5	45
68574	2020-05-26 22:16:20	2020-05-26	14	[{"id_menu":2,"count":1}]	27181	delivery	5	19
68575	2020-05-26 22:19:00	2020-05-26	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3277	delivery	5	37
68576	2020-05-26 22:19:36	2020-05-26	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	14039	delivery	5	27
68577	2020-05-26 22:22:02	2020-05-26	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	17588	delivery	5	31
68578	2020-05-26 22:22:15	2020-05-26	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	22684	delivery	5	46
68579	2020-05-26 22:26:26	2020-05-26	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1319	delivery	5	31
68580	2020-05-26 22:28:04	2020-05-26	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	6326	delivery	5	38
68581	2020-05-26 22:31:57	2020-05-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5397	delivery	5	22
68582	2020-05-26 22:35:31	2020-05-26	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	27178	delivery	5	31
68583	2020-05-26 22:39:52	2020-05-26	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	23568	delivery	5	42
68584	2020-05-26 22:40:59	2020-05-26	9	[{"id_menu":7,"count":1}]	15694	delivery	5	14
68585	2020-05-26 22:47:18	2020-05-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	26734	delivery	5	26
68586	2020-05-26 22:52:17	2020-05-26	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	25948	pick-up	0	35
68587	2020-05-26 22:55:37	2020-05-26	14	[{"id_menu":2,"count":1}]	9222	delivery	5	19
68588	2020-05-26 22:55:39	2020-05-26	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2507	delivery	5	40
68589	2020-05-26 22:58:13	2020-05-26	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	26998	delivery	5	48
68590	2020-05-26 23:00:28	2020-05-26	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	15617	delivery	5	56
68591	2020-05-26 23:04:34	2020-05-26	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	23314	delivery	5	39
68592	2020-05-26 23:06:02	2020-05-26	8	[{"id_menu":5,"count":1}]	21180	delivery	5	13
68593	2020-05-26 23:07:27	2020-05-26	9	[{"id_menu":7,"count":1}]	3100	delivery	5	14
68594	2020-05-26 23:12:02	2020-05-26	9	[{"id_menu":6,"count":1}]	22979	pick-up	0	9
68595	2020-05-26 23:13:25	2020-05-26	9	[{"id_menu":7,"count":1}]	27032	pick-up	0	9
68596	2020-05-26 23:14:16	2020-05-26	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1956	delivery	5	25
68597	2020-05-26 23:20:29	2020-05-26	17	[{"id_menu":4,"count":1}]	19817	delivery	5	22
68598	2020-05-26 23:24:44	2020-05-26	9	[{"id_menu":6,"count":1}]	23695	pick-up	0	9
68599	2020-05-26 23:33:55	2020-05-26	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	26979	delivery	5	25
68600	2020-05-26 23:39:41	2020-05-26	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27024	delivery	5	36
68601	2020-05-26 23:41:31	2020-05-26	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	26978	delivery	5	31
68602	2020-05-26 23:48:54	2020-05-26	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	27067	delivery	5	36
68603	2020-05-26 23:52:31	2020-05-26	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	26994	delivery	5	31
68604	2020-05-26 23:53:24	2020-05-26	9	[{"id_menu":6,"count":1}]	22721	delivery	5	14
68605	2020-05-27 00:00:03	2020-05-27	8	[{"id_menu":5,"count":1}]	10507	delivery	5	13
68606	2020-05-27 00:03:45	2020-05-27	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	27222	delivery	5	26
68607	2020-05-27 00:04:25	2020-05-27	8	[{"id_menu":5,"count":1}]	27272	delivery	5	13
68608	2020-05-27 00:05:58	2020-05-27	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	4058	delivery	5	34
68609	2020-05-27 00:09:32	2020-05-27	14	[{"id_menu":2,"count":1}]	1209	pick-up	0	14
68610	2020-05-27 00:11:42	2020-05-27	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18493	delivery	5	35
68611	2020-05-27 00:12:14	2020-05-27	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	27216	delivery	5	26
68612	2020-05-27 00:16:05	2020-05-27	17	[{"id_menu":4,"count":1}]	12623	pick-up	0	17
68613	2020-05-27 00:20:28	2020-05-27	9	[{"id_menu":7,"count":1}]	20044	delivery	5	14
68614	2020-05-27 00:22:30	2020-05-27	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5053	delivery	5	48
68615	2020-05-27 00:23:29	2020-05-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	10434	delivery	5	28
68616	2020-05-27 00:29:21	2020-05-27	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":3}]	27237	delivery	5	31
68617	2020-05-27 00:35:08	2020-05-27	12	[{"id_menu":3,"count":1}]	19216	delivery	5	17
68618	2020-05-27 00:35:57	2020-05-27	14	[{"id_menu":2,"count":1}]	13459	pick-up	0	14
68619	2020-05-27 00:37:08	2020-05-27	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	13858	pick-up	0	26
68620	2020-05-27 00:38:51	2020-05-27	9	[{"id_menu":6,"count":1}]	10666	delivery	5	14
68621	2020-05-27 00:39:34	2020-05-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	26931	pick-up	0	23
68622	2020-05-27 00:39:58	2020-05-27	14	[{"id_menu":2,"count":1}]	27221	delivery	5	19
68623	2020-05-27 00:40:09	2020-05-27	8	[{"id_menu":5,"count":1}]	20910	pick-up	0	8
68624	2020-05-27 00:45:04	2020-05-27	8	[{"id_menu":5,"count":1}]	19005	pick-up	0	8
68625	2020-05-27 00:48:35	2020-05-27	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	15321	delivery	5	25
68626	2020-05-27 00:50:16	2020-05-27	14	[{"id_menu":2,"count":1}]	17874	delivery	5	19
68627	2020-05-27 00:53:22	2020-05-27	12	[{"id_menu":3,"count":1}]	6489	pick-up	0	12
68628	2020-05-27 01:07:53	2020-05-27	9	[{"id_menu":7,"count":1}]	26979	delivery	5	14
68629	2020-05-27 01:11:13	2020-05-27	9	[{"id_menu":6,"count":1}]	5667	delivery	5	14
68630	2020-05-27 01:15:47	2020-05-27	12	[{"id_menu":1,"count":1}]	9043	pick-up	0	12
68631	2020-05-27 01:20:05	2020-05-27	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3228	pick-up	0	21
68632	2020-05-27 01:20:29	2020-05-27	9	[{"id_menu":7,"count":1}]	4456	delivery	5	14
68633	2020-05-27 01:21:46	2020-05-27	12	[{"id_menu":1,"count":1}]	17731	pick-up	0	12
68634	2020-05-27 01:28:16	2020-05-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6321	pick-up	0	31
68635	2020-05-27 01:29:26	2020-05-27	9	[{"id_menu":6,"count":1}]	27276	delivery	5	14
68636	2020-05-27 01:29:34	2020-05-27	9	[{"id_menu":7,"count":1}]	213	pick-up	0	9
68637	2020-05-27 01:34:22	2020-05-27	12	[{"id_menu":1,"count":1}]	1548	pick-up	0	12
68638	2020-05-27 01:36:44	2020-05-27	12	[{"id_menu":3,"count":1}]	6046	pick-up	0	12
68639	2020-05-27 01:38:31	2020-05-27	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1541	pick-up	0	20
68640	2020-05-27 01:41:21	2020-05-27	12	[{"id_menu":3,"count":1}]	27376	delivery	5	17
68641	2020-05-27 01:42:09	2020-05-27	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	17335	delivery	5	26
68642	2020-05-27 01:46:26	2020-05-27	9	[{"id_menu":6,"count":1}]	1310	delivery	5	14
68643	2020-05-27 01:49:42	2020-05-27	8	[{"id_menu":5,"count":1}]	22036	delivery	5	13
68644	2020-05-27 01:49:47	2020-05-27	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27291	delivery	5	40
68645	2020-05-27 01:49:50	2020-05-27	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	27355	delivery	5	46
68646	2020-05-27 01:51:19	2020-05-27	9	[{"id_menu":6,"count":1}]	27258	delivery	5	14
68647	2020-05-27 02:01:01	2020-05-27	9	[{"id_menu":6,"count":1}]	21121	pick-up	0	9
68648	2020-05-27 02:02:48	2020-05-27	9	[{"id_menu":7,"count":1}]	23875	delivery	5	14
68649	2020-05-27 02:05:10	2020-05-27	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5886	delivery	5	42
68650	2020-05-27 02:06:08	2020-05-27	8	[{"id_menu":5,"count":1}]	11156	delivery	5	13
68651	2020-05-27 02:06:50	2020-05-27	14	[{"id_menu":2,"count":1}]	27183	delivery	5	19
68652	2020-05-27 02:10:06	2020-05-27	9	[{"id_menu":6,"count":1}]	23976	delivery	5	14
68653	2020-05-27 02:12:07	2020-05-27	14	[{"id_menu":2,"count":1}]	7465	delivery	5	19
68654	2020-05-27 02:12:14	2020-05-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17892	delivery	5	23
68655	2020-05-27 02:16:35	2020-05-27	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	27288	delivery	5	53
68656	2020-05-27 02:20:01	2020-05-27	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25291	delivery	5	35
68657	2020-05-27 02:20:30	2020-05-27	12	[{"id_menu":1,"count":1}]	18430	delivery	5	17
68658	2020-05-27 02:20:34	2020-05-27	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	27294	delivery	5	40
68659	2020-05-27 02:25:05	2020-05-27	9	[{"id_menu":6,"count":1}]	9317	delivery	5	14
68660	2020-05-27 02:29:48	2020-05-27	14	[{"id_menu":2,"count":1}]	27227	delivery	5	19
68661	2020-05-27 02:31:47	2020-05-27	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	27373	delivery	5	26
68662	2020-05-27 02:35:34	2020-05-27	9	[{"id_menu":7,"count":1}]	27393	delivery	5	14
68663	2020-05-27 02:37:24	2020-05-27	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10029	delivery	5	34
68664	2020-05-27 02:38:51	2020-05-27	17	[{"id_menu":4,"count":1}]	2101	pick-up	0	17
68665	2020-05-27 02:40:34	2020-05-27	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21174	delivery	5	22
68666	2020-05-27 02:45:07	2020-05-27	9	[{"id_menu":6,"count":1}]	27351	delivery	5	14
68667	2020-05-27 02:45:33	2020-05-27	9	[{"id_menu":6,"count":1}]	27366	delivery	5	14
68668	2020-05-27 02:48:08	2020-05-27	8	[{"id_menu":5,"count":2}]	9552	delivery	5	13
68669	2020-05-27 02:51:52	2020-05-27	8	[{"id_menu":5,"count":1}]	204	pick-up	0	8
68670	2020-05-27 02:59:15	2020-05-27	12	[{"id_menu":3,"count":1}]	18698	delivery	5	17
68671	2020-05-27 03:00:18	2020-05-27	9	[{"id_menu":7,"count":1}]	18529	delivery	5	14
68672	2020-05-27 03:03:50	2020-05-27	14	[{"id_menu":2,"count":1}]	16854	delivery	5	19
68673	2020-05-27 03:06:01	2020-05-27	9	[{"id_menu":6,"count":1}]	18598	delivery	5	14
68674	2020-05-27 03:06:30	2020-05-27	17	[{"id_menu":4,"count":1}]	27233	delivery	5	22
68675	2020-05-27 03:13:15	2020-05-27	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	27384	delivery	5	28
68676	2020-05-27 03:26:38	2020-05-27	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	27371	delivery	5	40
68677	2020-05-27 03:29:19	2020-05-27	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	20818	delivery	5	31
68678	2020-05-27 03:31:03	2020-05-27	17	[{"id_menu":4,"count":1}]	11380	pick-up	0	17
68679	2020-05-27 03:40:54	2020-05-27	17	[{"id_menu":4,"count":2}]	1080	pick-up	0	17
68680	2020-05-27 03:43:56	2020-05-27	12	[{"id_menu":1,"count":1}]	10844	pick-up	0	12
68681	2020-05-27 03:48:23	2020-05-27	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27335	delivery	5	40
68682	2020-05-27 03:50:48	2020-05-27	9	[{"id_menu":6,"count":1}]	27325	delivery	5	14
68683	2020-05-27 03:53:43	2020-05-27	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27392	delivery	5	39
68684	2020-05-27 03:55:21	2020-05-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20697	pick-up	0	17
68685	2020-05-27 04:01:02	2020-05-27	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15143	delivery	5	43
68686	2020-05-27 04:01:55	2020-05-27	17	[{"id_menu":4,"count":1}]	27219	delivery	5	22
68687	2020-05-27 04:04:52	2020-05-27	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	9787	delivery	5	37
68688	2020-05-27 04:16:46	2020-05-27	14	[{"id_menu":2,"count":1}]	3864	pick-up	0	14
68689	2020-05-27 04:18:15	2020-05-27	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":2}]	289	delivery	5	31
68690	2020-05-27 04:21:04	2020-05-27	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	27374	delivery	5	45
68691	2020-05-27 04:24:37	2020-05-27	9	[{"id_menu":6,"count":1}]	27339	delivery	5	14
68692	2020-05-27 04:28:21	2020-05-27	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	22176	pick-up	0	26
68693	2020-05-27 04:29:12	2020-05-27	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	15786	delivery	5	26
68694	2020-05-27 04:29:51	2020-05-27	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27301	delivery	5	48
68695	2020-05-27 04:30:47	2020-05-27	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5808	delivery	5	31
68696	2020-05-27 04:32:39	2020-05-27	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	541	pick-up	0	31
68697	2020-05-27 04:41:51	2020-05-27	9	[{"id_menu":7,"count":2}]	26783	delivery	5	14
68698	2020-05-27 04:42:41	2020-05-27	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27207	delivery	5	34
68699	2020-05-27 04:44:59	2020-05-27	14	[{"id_menu":2,"count":1}]	5064	pick-up	0	14
68700	2020-05-27 04:46:14	2020-05-27	9	[{"id_menu":6,"count":1}]	27348	delivery	5	14
68701	2020-05-27 04:51:14	2020-05-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	27347	delivery	5	36
68702	2020-05-27 04:54:29	2020-05-27	9	[{"id_menu":6,"count":1}]	8347	pick-up	0	9
68703	2020-05-27 05:01:28	2020-05-27	17	[{"id_menu":4,"count":1}]	12393	pick-up	0	17
68704	2020-05-27 05:06:48	2020-05-27	9	[{"id_menu":7,"count":1}]	27254	delivery	5	14
68705	2020-05-27 05:06:58	2020-05-27	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11118	delivery	5	31
68706	2020-05-27 05:08:09	2020-05-27	9	[{"id_menu":6,"count":1}]	27253	delivery	5	14
68707	2020-05-27 05:09:29	2020-05-27	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	22963	delivery	5	31
68708	2020-05-27 05:13:21	2020-05-27	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	27368	delivery	5	26
68709	2020-05-27 05:13:32	2020-05-27	17	[{"id_menu":4,"count":1}]	19004	delivery	5	22
68710	2020-05-27 05:17:08	2020-05-27	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	14306	delivery	5	31
68711	2020-05-27 05:20:44	2020-05-27	9	[{"id_menu":7,"count":1}]	27330	delivery	5	14
68712	2020-05-27 05:21:15	2020-05-27	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	27204	delivery	5	34
68713	2020-05-27 05:23:12	2020-05-27	12	[{"id_menu":1,"count":2}]	27231	delivery	5	17
68714	2020-05-27 05:32:21	2020-05-27	12	[{"id_menu":1,"count":1}]	12865	delivery	5	17
68715	2020-05-27 05:33:28	2020-05-27	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	27200	delivery	5	22
68716	2020-05-27 05:33:58	2020-05-27	9	[{"id_menu":6,"count":1}]	27195	delivery	5	14
68717	2020-05-27 05:38:40	2020-05-27	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12024	delivery	5	34
68718	2020-05-27 05:41:00	2020-05-27	9	[{"id_menu":6,"count":1}]	27320	delivery	5	14
68719	2020-05-27 05:46:33	2020-05-27	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3024	pick-up	0	26
68720	2020-05-27 05:49:37	2020-05-27	17	[{"id_menu":4,"count":1}]	4786	delivery	5	22
68721	2020-05-27 05:51:08	2020-05-27	12	[{"id_menu":3,"count":1}]	2418	pick-up	0	12
68722	2020-05-27 05:52:42	2020-05-27	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8494	delivery	5	30
68723	2020-05-27 05:54:11	2020-05-27	17	[{"id_menu":4,"count":1}]	2616	pick-up	0	17
68724	2020-05-27 05:54:33	2020-05-27	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	16652	delivery	5	42
68725	2020-05-27 06:09:34	2020-05-27	9	[{"id_menu":6,"count":1}]	6080	delivery	5	14
68726	2020-05-27 06:10:26	2020-05-27	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	27364	delivery	5	27
68727	2020-05-27 06:11:18	2020-05-27	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	27277	delivery	5	44
68728	2020-05-27 06:17:17	2020-05-27	8	[{"id_menu":5,"count":1}]	8311	delivery	5	13
68729	2020-05-27 06:21:10	2020-05-27	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27201	delivery	5	40
68730	2020-05-27 06:23:29	2020-05-27	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	24771	delivery	5	39
68731	2020-05-27 06:26:36	2020-05-27	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":2}]	17304	delivery	5	22
68732	2020-05-27 06:50:27	2020-05-27	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	11352	delivery	5	28
68733	2020-05-27 06:54:29	2020-05-27	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7009	delivery	5	40
68734	2020-05-27 07:06:50	2020-05-27	9	[{"id_menu":7,"count":1}]	11240	delivery	5	14
68735	2020-05-27 07:09:52	2020-05-27	14	[{"id_menu":2,"count":1}]	7726	pick-up	0	14
68736	2020-05-27 07:10:38	2020-05-27	14	[{"id_menu":2,"count":1}]	11276	delivery	5	19
68737	2020-05-27 07:11:49	2020-05-27	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	17534	delivery	5	22
68738	2020-05-27 07:12:15	2020-05-27	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	27385	delivery	5	43
68739	2020-05-27 07:13:08	2020-05-27	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	3372	delivery	5	35
68740	2020-05-27 07:13:29	2020-05-27	9	[{"id_menu":7,"count":1}]	3554	delivery	5	14
68741	2020-05-27 07:20:32	2020-05-27	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	27191	pick-up	0	31
68742	2020-05-27 07:23:41	2020-05-27	9	[{"id_menu":6,"count":1}]	15569	delivery	5	14
68743	2020-05-27 07:28:37	2020-05-27	9	[{"id_menu":6,"count":1}]	27256	delivery	5	14
68744	2020-05-27 07:33:01	2020-05-27	9	[{"id_menu":6,"count":1}]	18758	pick-up	0	9
68745	2020-05-27 07:41:15	2020-05-27	12	[{"id_menu":3,"count":1}]	24755	delivery	5	17
68746	2020-05-27 07:47:59	2020-05-27	17	[{"id_menu":4,"count":1}]	27213	delivery	5	22
68747	2020-05-27 07:51:49	2020-05-27	14	[{"id_menu":2,"count":1}]	7190	pick-up	0	14
68748	2020-05-27 07:53:44	2020-05-27	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	27267	delivery	5	37
68749	2020-05-27 07:56:18	2020-05-27	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	26510	delivery	5	28
68750	2020-05-27 07:58:42	2020-05-27	9	[{"id_menu":7,"count":1}]	27340	delivery	5	14
68751	2020-05-27 08:05:11	2020-05-27	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27341	delivery	5	35
68752	2020-05-27 08:08:26	2020-05-27	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	16423	delivery	5	39
68753	2020-05-27 08:10:45	2020-05-27	8	[{"id_menu":5,"count":1}]	22748	delivery	5	13
68754	2020-05-27 08:12:41	2020-05-27	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	27323	delivery	5	34
68755	2020-05-27 08:14:42	2020-05-27	8	[{"id_menu":5,"count":1}]	11093	delivery	5	13
68756	2020-05-27 08:19:01	2020-05-27	17	[{"id_menu":4,"count":1}]	6020	delivery	5	22
68757	2020-05-27 08:28:38	2020-05-27	14	[{"id_menu":2,"count":1}]	27220	delivery	5	19
68758	2020-05-27 08:31:14	2020-05-27	12	[{"id_menu":3,"count":1}]	26288	delivery	5	17
68759	2020-05-27 08:33:32	2020-05-27	8	[{"id_menu":5,"count":1}]	21522	delivery	5	13
68760	2020-05-27 08:36:44	2020-05-27	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20579	delivery	5	39
68761	2020-05-27 08:37:17	2020-05-27	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	14711	delivery	5	48
68762	2020-05-27 08:39:53	2020-05-27	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1839	delivery	5	26
68763	2020-05-27 08:45:24	2020-05-27	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	9715	delivery	5	31
68764	2020-05-27 08:45:28	2020-05-27	9	[{"id_menu":6,"count":1}]	2182	delivery	5	14
68765	2020-05-27 08:47:19	2020-05-27	9	[{"id_menu":7,"count":1}]	16233	delivery	5	14
68766	2020-05-27 08:48:23	2020-05-27	17	[{"id_menu":4,"count":1}]	23130	delivery	5	22
68767	2020-05-27 08:48:44	2020-05-27	14	[{"id_menu":2,"count":1}]	11946	pick-up	0	14
68768	2020-05-27 08:51:55	2020-05-27	8	[{"id_menu":5,"count":1}]	4724	delivery	5	13
68769	2020-05-27 08:57:46	2020-05-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	27349	delivery	5	22
68770	2020-05-27 08:58:37	2020-05-27	12	[{"id_menu":3,"count":1}]	2206	pick-up	0	12
68771	2020-05-27 09:01:19	2020-05-27	9	[{"id_menu":6,"count":1}]	23310	delivery	5	14
68772	2020-05-27 09:02:35	2020-05-27	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19282	delivery	5	34
68773	2020-05-27 09:09:43	2020-05-27	8	[{"id_menu":5,"count":1}]	27076	delivery	5	13
68774	2020-05-27 09:13:10	2020-05-27	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	27239	delivery	5	26
68775	2020-05-27 09:15:07	2020-05-27	8	[{"id_menu":5,"count":2}]	5281	pick-up	0	8
68776	2020-05-27 09:16:34	2020-05-27	22	[{"id_menu":2,"count":3},{"id_menu":5,"count":1}]	27271	delivery	5	27
68777	2020-05-27 09:17:13	2020-05-27	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9960	delivery	5	31
68778	2020-05-27 09:25:19	2020-05-27	17	[{"id_menu":4,"count":1}]	25831	pick-up	0	17
68779	2020-05-27 09:25:42	2020-05-27	8	[{"id_menu":5,"count":1}]	27186	delivery	5	13
68780	2020-05-27 09:32:09	2020-05-27	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	27274	delivery	5	31
68781	2020-05-27 09:32:27	2020-05-27	17	[{"id_menu":4,"count":1}]	11687	delivery	5	22
68782	2020-05-27 09:33:44	2020-05-27	14	[{"id_menu":2,"count":2}]	27226	delivery	5	19
68783	2020-05-27 09:33:50	2020-05-27	12	[{"id_menu":3,"count":1}]	22179	delivery	5	17
68784	2020-05-27 09:33:58	2020-05-27	17	[{"id_menu":4,"count":1}]	27331	delivery	5	22
68785	2020-05-27 09:36:57	2020-05-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	16091	delivery	5	22
68786	2020-05-27 09:37:31	2020-05-27	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	27308	delivery	5	31
68787	2020-05-27 09:41:16	2020-05-27	9	[{"id_menu":7,"count":1}]	26675	delivery	5	14
68788	2020-05-27 09:43:05	2020-05-27	8	[{"id_menu":5,"count":1}]	12409	delivery	5	13
68789	2020-05-27 09:48:45	2020-05-27	14	[{"id_menu":2,"count":1}]	27315	delivery	5	19
68790	2020-05-27 09:49:39	2020-05-27	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	27337	delivery	5	26
68791	2020-05-27 09:51:28	2020-05-27	8	[{"id_menu":5,"count":1}]	9563	delivery	5	13
68792	2020-05-27 09:51:28	2020-05-27	9	[{"id_menu":6,"count":1}]	4662	delivery	5	14
68793	2020-05-27 09:58:57	2020-05-27	9	[{"id_menu":6,"count":1}]	12155	delivery	5	14
68794	2020-05-27 09:59:33	2020-05-27	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7739	delivery	5	31
68795	2020-05-27 10:01:37	2020-05-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9966	pick-up	0	18
68796	2020-05-27 10:01:38	2020-05-27	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	16162	delivery	5	46
68797	2020-05-27 10:03:07	2020-05-27	12	[{"id_menu":3,"count":1}]	4319	delivery	5	17
68798	2020-05-27 10:06:31	2020-05-27	9	[{"id_menu":6,"count":1}]	17685	pick-up	0	9
68799	2020-05-27 10:08:42	2020-05-27	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	27202	delivery	5	40
68800	2020-05-27 10:14:27	2020-05-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27262	delivery	5	22
68801	2020-05-27 10:21:29	2020-05-27	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	12248	pick-up	0	23
68802	2020-05-27 10:24:05	2020-05-27	12	[{"id_menu":1,"count":1}]	2956	pick-up	0	12
68803	2020-05-27 10:25:00	2020-05-27	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	27362	delivery	5	27
68804	2020-05-27 10:26:08	2020-05-27	9	[{"id_menu":7,"count":1}]	8437	delivery	5	14
68805	2020-05-27 10:26:26	2020-05-27	12	[{"id_menu":1,"count":1}]	27124	delivery	5	17
68806	2020-05-27 10:28:43	2020-05-27	9	[{"id_menu":6,"count":1}]	950	delivery	5	14
68807	2020-05-27 10:28:48	2020-05-27	12	[{"id_menu":1,"count":1}]	18724	delivery	5	17
68808	2020-05-27 10:29:26	2020-05-27	9	[{"id_menu":7,"count":1}]	6100	delivery	5	14
68809	2020-05-27 10:30:02	2020-05-27	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2068	pick-up	0	39
68810	2020-05-27 10:32:15	2020-05-27	9	[{"id_menu":7,"count":1}]	27245	delivery	5	14
68811	2020-05-27 10:32:25	2020-05-27	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	5912	delivery	5	34
68812	2020-05-27 10:32:47	2020-05-27	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	13621	delivery	5	26
68813	2020-05-27 10:35:02	2020-05-27	14	[{"id_menu":2,"count":1}]	27217	delivery	5	19
68814	2020-05-27 10:46:15	2020-05-27	8	[{"id_menu":5,"count":1}]	27244	delivery	5	13
68815	2020-05-27 10:51:39	2020-05-27	8	[{"id_menu":5,"count":1}]	27190	delivery	5	13
68816	2020-05-27 10:53:07	2020-05-27	12	[{"id_menu":1,"count":1}]	11392	delivery	5	17
68817	2020-05-27 10:54:14	2020-05-27	12	[{"id_menu":1,"count":1}]	6818	delivery	5	17
68818	2020-05-27 10:54:47	2020-05-27	9	[{"id_menu":6,"count":1}]	4057	delivery	5	14
68819	2020-05-27 10:55:56	2020-05-27	9	[{"id_menu":7,"count":1}]	2980	pick-up	0	9
68820	2020-05-27 10:56:35	2020-05-27	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	12327	delivery	5	52
68821	2020-05-27 10:57:18	2020-05-27	9	[{"id_menu":6,"count":1}]	22182	delivery	5	14
68822	2020-05-27 10:58:41	2020-05-27	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	5116	pick-up	0	32
68823	2020-05-27 11:01:31	2020-05-27	9	[{"id_menu":7,"count":1}]	27265	delivery	5	14
68824	2020-05-27 11:03:36	2020-05-27	8	[{"id_menu":5,"count":1}]	27266	delivery	5	13
68825	2020-05-27 11:07:13	2020-05-27	9	[{"id_menu":7,"count":2}]	25637	delivery	5	14
68826	2020-05-27 11:11:54	2020-05-27	12	[{"id_menu":3,"count":1}]	23119	delivery	5	17
68827	2020-05-27 11:15:03	2020-05-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3659	pick-up	0	23
68828	2020-05-27 11:18:08	2020-05-27	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	27287	delivery	5	26
68829	2020-05-27 11:18:31	2020-05-27	12	[{"id_menu":1,"count":1}]	3332	pick-up	0	12
68830	2020-05-27 11:20:43	2020-05-27	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	12183	delivery	5	46
68831	2020-05-27 11:21:47	2020-05-27	17	[{"id_menu":4,"count":1}]	2444	delivery	5	22
68832	2020-05-27 11:29:36	2020-05-27	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12242	delivery	5	31
68833	2020-05-27 11:29:53	2020-05-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	13413	delivery	5	36
68834	2020-05-27 11:32:30	2020-05-27	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	9925	delivery	5	25
68835	2020-05-27 11:33:45	2020-05-27	9	[{"id_menu":7,"count":2}]	7804	delivery	5	14
68906	2020-05-27 14:38:20	2020-05-27	9	[{"id_menu":6,"count":1}]	27198	pick-up	0	9
68836	2020-05-27 11:35:23	2020-05-27	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27390	delivery	5	54
68837	2020-05-27 11:36:10	2020-05-27	17	[{"id_menu":4,"count":1}]	27223	delivery	5	22
68838	2020-05-27 11:43:20	2020-05-27	12	[{"id_menu":1,"count":1}]	27318	pick-up	0	12
68839	2020-05-27 11:45:20	2020-05-27	9	[{"id_menu":7,"count":1}]	27260	delivery	5	14
68840	2020-05-27 11:46:44	2020-05-27	9	[{"id_menu":6,"count":1}]	16370	delivery	5	14
68841	2020-05-27 11:46:53	2020-05-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27228	delivery	5	23
68842	2020-05-27 11:53:56	2020-05-27	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	22451	delivery	5	31
68843	2020-05-27 11:58:04	2020-05-27	12	[{"id_menu":1,"count":1}]	14673	delivery	5	17
68844	2020-05-27 11:59:42	2020-05-27	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	27381	delivery	5	27
68845	2020-05-27 12:03:33	2020-05-27	12	[{"id_menu":3,"count":1}]	9234	pick-up	0	12
68846	2020-05-27 12:06:47	2020-05-27	9	[{"id_menu":7,"count":1}]	8230	delivery	5	14
68847	2020-05-27 12:09:40	2020-05-27	17	[{"id_menu":4,"count":1}]	27396	delivery	5	22
68848	2020-05-27 12:14:08	2020-05-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	27197	delivery	5	36
68849	2020-05-27 12:15:01	2020-05-27	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	27342	delivery	5	42
68850	2020-05-27 12:15:53	2020-05-27	8	[{"id_menu":5,"count":1}]	27236	delivery	5	13
68851	2020-05-27 12:19:28	2020-05-27	12	[{"id_menu":1,"count":2}]	8363	delivery	5	17
68852	2020-05-27 12:19:38	2020-05-27	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	6727	delivery	5	25
68853	2020-05-27 12:21:06	2020-05-27	8	[{"id_menu":5,"count":1}]	27375	delivery	5	13
68854	2020-05-27 12:24:19	2020-05-27	14	[{"id_menu":2,"count":1}]	27286	delivery	5	19
68855	2020-05-27 12:24:37	2020-05-27	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	27333	delivery	5	26
68856	2020-05-27 12:25:41	2020-05-27	9	[{"id_menu":6,"count":1}]	27261	delivery	5	14
68857	2020-05-27 12:25:46	2020-05-27	14	[{"id_menu":2,"count":1}]	27369	delivery	5	19
68858	2020-05-27 12:27:34	2020-05-27	12	[{"id_menu":3,"count":1}]	11119	delivery	5	17
68859	2020-05-27 12:27:41	2020-05-27	14	[{"id_menu":2,"count":1}]	27240	delivery	5	19
68860	2020-05-27 12:28:03	2020-05-27	14	[{"id_menu":2,"count":1}]	27250	pick-up	0	14
68861	2020-05-27 12:31:11	2020-05-27	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18386	delivery	5	34
68862	2020-05-27 12:38:08	2020-05-27	9	[{"id_menu":6,"count":1}]	20972	delivery	5	14
68863	2020-05-27 12:42:31	2020-05-27	14	[{"id_menu":2,"count":1}]	27280	delivery	5	19
68864	2020-05-27 12:45:48	2020-05-27	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	4590	pick-up	0	21
68865	2020-05-27 12:49:20	2020-05-27	12	[{"id_menu":1,"count":1}]	27316	pick-up	0	12
68866	2020-05-27 12:50:02	2020-05-27	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	5503	pick-up	0	21
68867	2020-05-27 12:53:09	2020-05-27	12	[{"id_menu":1,"count":1}]	27283	pick-up	0	12
68868	2020-05-27 12:55:15	2020-05-27	9	[{"id_menu":7,"count":1}]	11825	delivery	5	14
68869	2020-05-27 12:55:46	2020-05-27	12	[{"id_menu":1,"count":1}]	7741	pick-up	0	12
68870	2020-05-27 13:03:00	2020-05-27	12	[{"id_menu":3,"count":1}]	17696	delivery	5	17
68871	2020-05-27 13:04:50	2020-05-27	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	27313	delivery	5	43
68872	2020-05-27 13:05:15	2020-05-27	9	[{"id_menu":6,"count":1}]	20378	delivery	5	14
68873	2020-05-27 13:07:20	2020-05-27	9	[{"id_menu":6,"count":1}]	26116	delivery	5	14
68874	2020-05-27 13:10:55	2020-05-27	17	[{"id_menu":4,"count":1}]	2400	pick-up	0	17
68875	2020-05-27 13:13:11	2020-05-27	9	[{"id_menu":6,"count":1}]	6962	pick-up	0	9
68876	2020-05-27 13:15:08	2020-05-27	9	[{"id_menu":7,"count":1}]	5787	delivery	5	14
68877	2020-05-27 13:19:44	2020-05-27	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	314	pick-up	0	29
68878	2020-05-27 13:24:15	2020-05-27	17	[{"id_menu":4,"count":1}]	20295	delivery	5	22
68879	2020-05-27 13:27:46	2020-05-27	9	[{"id_menu":7,"count":1}]	24620	pick-up	0	9
68880	2020-05-27 13:29:26	2020-05-27	12	[{"id_menu":1,"count":1}]	27336	delivery	5	17
68881	2020-05-27 13:29:46	2020-05-27	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	27206	delivery	5	45
68882	2020-05-27 13:34:08	2020-05-27	9	[{"id_menu":6,"count":1}]	5187	delivery	5	14
68883	2020-05-27 13:37:32	2020-05-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27352	delivery	5	23
68884	2020-05-27 13:43:24	2020-05-27	9	[{"id_menu":6,"count":1}]	4577	pick-up	0	9
68885	2020-05-27 13:44:10	2020-05-27	8	[{"id_menu":5,"count":1}]	14402	delivery	5	13
68886	2020-05-27 13:44:43	2020-05-27	14	[{"id_menu":2,"count":1}]	27388	delivery	5	19
68887	2020-05-27 13:46:38	2020-05-27	9	[{"id_menu":7,"count":1}]	17769	delivery	5	14
68888	2020-05-27 13:47:07	2020-05-27	8	[{"id_menu":5,"count":1}]	15888	delivery	5	13
68889	2020-05-27 13:52:41	2020-05-27	14	[{"id_menu":2,"count":1}]	21076	pick-up	0	14
68890	2020-05-27 13:54:34	2020-05-27	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20948	delivery	5	35
68891	2020-05-27 13:56:47	2020-05-27	9	[{"id_menu":6,"count":1}]	27394	delivery	5	14
68892	2020-05-27 13:59:27	2020-05-27	8	[{"id_menu":5,"count":1}]	8402	pick-up	0	8
68893	2020-05-27 14:06:55	2020-05-27	9	[{"id_menu":7,"count":1}]	27249	delivery	5	14
68894	2020-05-27 14:11:49	2020-05-27	9	[{"id_menu":7,"count":1}]	21084	delivery	5	14
68895	2020-05-27 14:15:50	2020-05-27	14	[{"id_menu":2,"count":1}]	25532	pick-up	0	14
68896	2020-05-27 14:17:53	2020-05-27	9	[{"id_menu":7,"count":1}]	20993	delivery	5	14
68897	2020-05-27 14:18:06	2020-05-27	17	[{"id_menu":4,"count":2}]	21759	delivery	5	22
68898	2020-05-27 14:19:24	2020-05-27	17	[{"id_menu":4,"count":1}]	10424	delivery	5	22
68899	2020-05-27 14:21:59	2020-05-27	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	401	pick-up	0	29
68900	2020-05-27 14:24:15	2020-05-27	9	[{"id_menu":6,"count":1}]	27193	delivery	5	14
68901	2020-05-27 14:24:58	2020-05-27	17	[{"id_menu":4,"count":1}]	18425	delivery	5	22
68902	2020-05-27 14:27:09	2020-05-27	14	[{"id_menu":2,"count":1}]	3640	pick-up	0	14
68903	2020-05-27 14:33:35	2020-05-27	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	17691	delivery	5	31
68904	2020-05-27 14:35:01	2020-05-27	9	[{"id_menu":6,"count":1}]	25857	delivery	5	14
68905	2020-05-27 14:37:46	2020-05-27	12	[{"id_menu":1,"count":1}]	27295	delivery	5	17
68907	2020-05-27 14:40:33	2020-05-27	14	[{"id_menu":2,"count":1}]	4836	delivery	5	19
68908	2020-05-27 14:43:05	2020-05-27	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	19365	delivery	5	28
68909	2020-05-27 14:50:42	2020-05-27	9	[{"id_menu":6,"count":1}]	10195	delivery	5	14
68910	2020-05-27 14:50:53	2020-05-27	9	[{"id_menu":7,"count":1}]	26389	delivery	5	14
68911	2020-05-27 14:54:34	2020-05-27	9	[{"id_menu":7,"count":1}]	27309	delivery	5	14
68912	2020-05-27 14:57:28	2020-05-27	8	[{"id_menu":5,"count":1}]	27232	delivery	5	13
68913	2020-05-27 14:58:28	2020-05-27	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	540	delivery	5	23
68914	2020-05-27 14:59:07	2020-05-27	9	[{"id_menu":6,"count":1}]	330	pick-up	0	9
68915	2020-05-27 15:01:46	2020-05-27	9	[{"id_menu":6,"count":1}]	17807	pick-up	0	9
68916	2020-05-27 15:03:35	2020-05-27	14	[{"id_menu":2,"count":1}]	18810	pick-up	0	14
68917	2020-05-27 15:05:29	2020-05-27	17	[{"id_menu":4,"count":1}]	3614	pick-up	0	17
68918	2020-05-27 15:06:52	2020-05-27	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	27293	delivery	5	34
68919	2020-05-27 15:09:12	2020-05-27	9	[{"id_menu":7,"count":1}]	27298	delivery	5	14
68920	2020-05-27 15:12:01	2020-05-27	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	27273	delivery	5	26
68921	2020-05-27 15:13:26	2020-05-27	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	20852	delivery	5	43
68922	2020-05-27 15:14:01	2020-05-27	12	[{"id_menu":1,"count":1}]	23760	pick-up	0	12
68923	2020-05-27 15:15:04	2020-05-27	9	[{"id_menu":7,"count":1}]	27218	delivery	5	14
68924	2020-05-27 15:15:38	2020-05-27	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	27382	delivery	5	34
68925	2020-05-27 15:16:52	2020-05-27	9	[{"id_menu":7,"count":1}]	4060	delivery	5	14
68926	2020-05-27 15:19:58	2020-05-27	9	[{"id_menu":6,"count":1}]	27343	delivery	5	14
68927	2020-05-27 15:22:01	2020-05-27	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	6281	delivery	5	25
68928	2020-05-27 15:23:43	2020-05-27	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1593	pick-up	0	26
68929	2020-05-27 15:27:45	2020-05-27	14	[{"id_menu":2,"count":1}]	23975	delivery	5	19
68930	2020-05-27 15:30:20	2020-05-27	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":2}]	19524	delivery	5	25
68931	2020-05-27 15:32:42	2020-05-27	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	25681	delivery	5	28
68932	2020-05-27 15:34:54	2020-05-27	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	27241	delivery	5	31
68933	2020-05-27 15:36:19	2020-05-27	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	27187	pick-up	0	21
68934	2020-05-27 15:36:56	2020-05-27	14	[{"id_menu":2,"count":1}]	5683	pick-up	0	14
68935	2020-05-27 15:39:59	2020-05-27	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	27311	pick-up	0	26
68936	2020-05-27 15:40:40	2020-05-27	14	[{"id_menu":2,"count":1}]	27209	pick-up	0	14
68937	2020-05-27 15:43:31	2020-05-27	9	[{"id_menu":6,"count":1}]	1825	pick-up	0	9
68938	2020-05-27 15:43:35	2020-05-27	12	[{"id_menu":1,"count":1}]	23521	delivery	5	17
68939	2020-05-27 15:44:15	2020-05-27	9	[{"id_menu":7,"count":1}]	125	delivery	5	14
68940	2020-05-27 15:48:56	2020-05-27	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	3785	pick-up	0	21
68941	2020-05-27 15:50:35	2020-05-27	12	[{"id_menu":1,"count":1}]	27282	delivery	5	17
68942	2020-05-27 15:51:01	2020-05-27	9	[{"id_menu":7,"count":1}]	9608	delivery	5	14
68943	2020-05-27 15:54:44	2020-05-27	14	[{"id_menu":2,"count":2}]	1088	pick-up	0	14
68944	2020-05-27 16:00:33	2020-05-27	17	[{"id_menu":4,"count":1}]	27363	delivery	5	22
68945	2020-05-27 16:06:24	2020-05-27	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	19075	pick-up	0	26
68946	2020-05-27 16:18:58	2020-05-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	13991	delivery	5	36
68947	2020-05-27 16:20:04	2020-05-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2439	pick-up	0	23
68948	2020-05-27 16:24:09	2020-05-27	9	[{"id_menu":7,"count":1}]	293	pick-up	0	9
68949	2020-05-27 16:29:15	2020-05-27	9	[{"id_menu":7,"count":2}]	27327	delivery	5	14
68950	2020-05-27 16:29:35	2020-05-27	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	9861	delivery	5	31
68951	2020-05-27 16:31:34	2020-05-27	12	[{"id_menu":3,"count":1}]	27326	delivery	5	17
68952	2020-05-27 16:32:33	2020-05-27	14	[{"id_menu":2,"count":1}]	21599	pick-up	0	14
68953	2020-05-27 16:33:35	2020-05-27	9	[{"id_menu":7,"count":1}]	27350	delivery	5	14
68954	2020-05-27 16:35:44	2020-05-27	9	[{"id_menu":7,"count":2}]	27361	delivery	5	14
68955	2020-05-27 16:36:24	2020-05-27	14	[{"id_menu":2,"count":1}]	8654	delivery	5	19
68956	2020-05-27 16:40:09	2020-05-27	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27212	delivery	5	35
68957	2020-05-27 16:44:00	2020-05-27	8	[{"id_menu":5,"count":1}]	8142	delivery	5	13
68958	2020-05-27 16:45:07	2020-05-27	12	[{"id_menu":3,"count":1}]	946	pick-up	0	12
68959	2020-05-27 16:45:13	2020-05-27	9	[{"id_menu":6,"count":1}]	19424	delivery	5	14
68960	2020-05-27 16:46:45	2020-05-27	14	[{"id_menu":2,"count":1}]	23111	pick-up	0	14
68961	2020-05-27 16:49:16	2020-05-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12942	delivery	5	23
68962	2020-05-27 16:49:22	2020-05-27	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	27365	delivery	5	27
68963	2020-05-27 16:52:26	2020-05-27	9	[{"id_menu":7,"count":2}]	661	delivery	5	14
68964	2020-05-27 16:55:10	2020-05-27	8	[{"id_menu":5,"count":1}]	16367	delivery	5	13
68965	2020-05-27 16:56:34	2020-05-27	14	[{"id_menu":2,"count":2}]	3115	pick-up	0	14
68966	2020-05-27 16:58:39	2020-05-27	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17908	delivery	5	34
68967	2020-05-27 17:00:25	2020-05-27	17	[{"id_menu":4,"count":1}]	27199	delivery	5	22
68968	2020-05-27 17:00:29	2020-05-27	12	[{"id_menu":3,"count":1}]	3527	delivery	5	17
68969	2020-05-27 17:04:46	2020-05-27	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	18770	pick-up	0	38
68970	2020-05-27 17:06:07	2020-05-27	9	[{"id_menu":6,"count":1}]	27370	delivery	5	14
68971	2020-05-27 17:07:09	2020-05-27	8	[{"id_menu":5,"count":1}]	27257	delivery	5	13
68972	2020-05-27 17:08:14	2020-05-27	17	[{"id_menu":4,"count":1}]	4983	delivery	5	22
68973	2020-05-27 17:08:20	2020-05-27	9	[{"id_menu":6,"count":1}]	22270	delivery	5	14
68974	2020-05-27 17:09:29	2020-05-27	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	27303	delivery	5	27
68975	2020-05-27 17:17:31	2020-05-27	9	[{"id_menu":6,"count":1}]	21474	delivery	5	14
68976	2020-05-27 17:19:54	2020-05-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7318	delivery	5	23
68977	2020-05-27 17:22:33	2020-05-27	8	[{"id_menu":5,"count":1}]	7086	pick-up	0	8
68978	2020-05-27 17:23:46	2020-05-27	9	[{"id_menu":6,"count":1}]	23828	delivery	5	14
68979	2020-05-27 17:24:19	2020-05-27	9	[{"id_menu":6,"count":1}]	4874	pick-up	0	9
68980	2020-05-27 17:30:26	2020-05-27	9	[{"id_menu":6,"count":1}]	11822	delivery	5	14
68981	2020-05-27 17:30:45	2020-05-27	8	[{"id_menu":5,"count":1}]	11464	delivery	5	13
68982	2020-05-27 17:31:11	2020-05-27	9	[{"id_menu":7,"count":1}]	3647	delivery	5	14
68983	2020-05-27 17:31:39	2020-05-27	8	[{"id_menu":5,"count":1}]	27246	delivery	5	13
68984	2020-05-27 17:32:16	2020-05-27	17	[{"id_menu":4,"count":1}]	7240	delivery	5	22
68985	2020-05-27 17:34:07	2020-05-27	12	[{"id_menu":3,"count":1}]	9813	pick-up	0	12
68986	2020-05-27 17:35:44	2020-05-27	17	[{"id_menu":4,"count":1}]	729	delivery	5	22
68987	2020-05-27 17:38:31	2020-05-27	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	25171	delivery	5	28
68988	2020-05-27 17:38:46	2020-05-27	9	[{"id_menu":6,"count":1}]	14165	delivery	5	14
68989	2020-05-27 17:41:22	2020-05-27	9	[{"id_menu":6,"count":1}]	20957	delivery	5	14
68990	2020-05-27 17:46:22	2020-05-27	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	11924	delivery	5	26
68991	2020-05-27 17:48:08	2020-05-27	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	2873	pick-up	0	26
68992	2020-05-27 17:52:40	2020-05-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	8655	delivery	5	28
68993	2020-05-27 17:53:43	2020-05-27	14	[{"id_menu":2,"count":2}]	27251	delivery	5	19
68994	2020-05-27 17:57:31	2020-05-27	14	[{"id_menu":2,"count":1}]	27378	delivery	5	19
68995	2020-05-27 18:00:56	2020-05-27	17	[{"id_menu":4,"count":2}]	27205	delivery	5	22
68996	2020-05-27 18:04:03	2020-05-27	12	[{"id_menu":3,"count":1}]	10153	pick-up	0	12
68997	2020-05-27 18:04:06	2020-05-27	9	[{"id_menu":7,"count":1}]	27297	delivery	5	14
68998	2020-05-27 18:05:26	2020-05-27	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	27184	delivery	5	46
68999	2020-05-27 18:07:01	2020-05-27	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	27268	delivery	5	26
69000	2020-05-27 18:07:40	2020-05-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	8412	delivery	5	28
69001	2020-05-27 18:07:52	2020-05-27	17	[{"id_menu":4,"count":1}]	24165	delivery	5	22
69002	2020-05-27 18:10:16	2020-05-27	9	[{"id_menu":7,"count":1}]	21886	delivery	5	14
69003	2020-05-27 18:13:05	2020-05-27	9	[{"id_menu":7,"count":1}]	3076	delivery	5	14
69004	2020-05-27 18:13:57	2020-05-27	9	[{"id_menu":6,"count":1}]	19387	pick-up	0	9
69005	2020-05-27 18:20:32	2020-05-27	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	27302	delivery	5	23
69006	2020-05-27 18:24:29	2020-05-27	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	18390	delivery	5	31
69007	2020-05-27 18:27:07	2020-05-27	8	[{"id_menu":5,"count":1}]	15528	delivery	5	13
69008	2020-05-27 18:27:27	2020-05-27	9	[{"id_menu":6,"count":1}]	27338	delivery	5	14
69009	2020-05-27 18:33:13	2020-05-27	14	[{"id_menu":2,"count":1}]	24452	pick-up	0	14
69010	2020-05-27 18:33:15	2020-05-27	9	[{"id_menu":7,"count":3}]	19225	delivery	5	14
69011	2020-05-27 18:36:07	2020-05-27	12	[{"id_menu":1,"count":1}]	27290	delivery	5	17
69012	2020-05-27 18:38:21	2020-05-27	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	4652	delivery	5	31
69013	2020-05-27 18:46:49	2020-05-27	12	[{"id_menu":1,"count":1}]	7705	pick-up	0	12
69014	2020-05-27 18:52:38	2020-05-27	8	[{"id_menu":5,"count":1}]	9907	pick-up	0	8
69015	2020-05-27 18:53:07	2020-05-27	9	[{"id_menu":7,"count":1}]	6512	pick-up	0	9
69016	2020-05-27 18:55:44	2020-05-27	8	[{"id_menu":5,"count":1}]	4158	delivery	5	13
69017	2020-05-27 18:56:15	2020-05-27	9	[{"id_menu":7,"count":1}]	17544	pick-up	0	9
69018	2020-05-27 18:59:37	2020-05-27	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10704	delivery	5	36
69019	2020-05-27 19:01:24	2020-05-27	12	[{"id_menu":1,"count":1}]	14947	pick-up	0	12
69020	2020-05-27 19:03:08	2020-05-27	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27324	delivery	5	37
69021	2020-05-27 19:03:38	2020-05-27	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8120	delivery	5	56
69022	2020-05-27 19:04:42	2020-05-27	14	[{"id_menu":2,"count":1}]	17047	delivery	5	19
69023	2020-05-27 19:07:15	2020-05-27	14	[{"id_menu":2,"count":1}]	27281	pick-up	0	14
69024	2020-05-27 19:07:55	2020-05-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	21770	pick-up	0	23
69025	2020-05-27 19:08:00	2020-05-27	12	[{"id_menu":1,"count":1}]	1344	delivery	5	17
69026	2020-05-27 19:13:54	2020-05-27	9	[{"id_menu":6,"count":1}]	27353	delivery	5	14
69027	2020-05-27 19:18:04	2020-05-27	12	[{"id_menu":1,"count":1}]	2	delivery	5	17
69028	2020-05-27 19:19:12	2020-05-27	9	[{"id_menu":7,"count":1}]	27185	delivery	5	14
69029	2020-05-27 19:21:31	2020-05-27	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5788	delivery	5	35
69030	2020-05-27 19:22:56	2020-05-27	17	[{"id_menu":4,"count":1}]	17415	delivery	5	22
69031	2020-05-27 19:28:33	2020-05-27	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	22511	delivery	5	31
69032	2020-05-27 19:29:59	2020-05-27	12	[{"id_menu":3,"count":1}]	1415	delivery	5	17
69033	2020-05-27 19:30:17	2020-05-27	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20985	delivery	5	37
69034	2020-05-27 19:33:30	2020-05-27	9	[{"id_menu":7,"count":1}]	9820	pick-up	0	9
69035	2020-05-27 19:34:01	2020-05-27	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27214	delivery	5	34
69036	2020-05-27 19:34:15	2020-05-27	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	27275	delivery	5	42
69037	2020-05-27 19:35:26	2020-05-27	12	[{"id_menu":3,"count":1}]	5573	delivery	5	17
69038	2020-05-27 19:35:45	2020-05-27	14	[{"id_menu":2,"count":1}]	2457	pick-up	0	14
69039	2020-05-27 19:38:47	2020-05-27	9	[{"id_menu":6,"count":1}]	4347	delivery	5	14
69040	2020-05-27 19:39:40	2020-05-27	8	[{"id_menu":5,"count":1}]	5416	pick-up	0	8
69041	2020-05-27 19:39:45	2020-05-27	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	27230	delivery	5	34
69042	2020-05-27 19:40:24	2020-05-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	21894	delivery	5	36
69043	2020-05-27 19:40:31	2020-05-27	12	[{"id_menu":3,"count":1}]	14848	delivery	5	17
69044	2020-05-27 19:40:45	2020-05-27	17	[{"id_menu":4,"count":1}]	235	pick-up	0	17
69045	2020-05-27 19:42:00	2020-05-27	8	[{"id_menu":5,"count":1}]	27235	delivery	5	13
69046	2020-05-27 19:48:21	2020-05-27	12	[{"id_menu":1,"count":1}]	21513	pick-up	0	12
69047	2020-05-27 19:51:45	2020-05-27	12	[{"id_menu":1,"count":1}]	11073	pick-up	0	12
69048	2020-05-27 19:53:00	2020-05-27	12	[{"id_menu":1,"count":1}]	24802	pick-up	0	12
69049	2020-05-27 19:54:00	2020-05-27	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":3}]	27189	delivery	5	26
69050	2020-05-27 19:56:20	2020-05-27	8	[{"id_menu":5,"count":1}]	27238	delivery	5	13
69051	2020-05-27 19:59:08	2020-05-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5639	pick-up	0	23
69052	2020-05-27 20:01:51	2020-05-27	14	[{"id_menu":2,"count":1}]	19400	delivery	5	19
69053	2020-05-27 20:01:58	2020-05-27	12	[{"id_menu":3,"count":1}]	10798	pick-up	0	12
69054	2020-05-27 20:03:58	2020-05-27	12	[{"id_menu":1,"count":1}]	11616	delivery	5	17
69055	2020-05-27 20:07:58	2020-05-27	8	[{"id_menu":5,"count":1}]	14090	delivery	5	13
69056	2020-05-27 20:18:58	2020-05-27	9	[{"id_menu":7,"count":1}]	18282	delivery	5	14
69057	2020-05-27 20:19:06	2020-05-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	27379	delivery	5	28
69058	2020-05-27 20:27:45	2020-05-27	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	11983	delivery	5	45
69059	2020-05-27 20:29:22	2020-05-27	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	27397	delivery	5	22
69060	2020-05-27 20:30:39	2020-05-27	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	27229	delivery	5	29
69061	2020-05-27 20:31:16	2020-05-27	9	[{"id_menu":7,"count":1}]	8248	delivery	5	14
69062	2020-05-27 20:31:52	2020-05-27	12	[{"id_menu":3,"count":1}]	2228	delivery	5	17
69063	2020-05-27 20:35:30	2020-05-27	12	[{"id_menu":3,"count":1}]	27247	delivery	5	17
69064	2020-05-27 20:38:26	2020-05-27	9	[{"id_menu":6,"count":1}]	27380	delivery	5	14
69065	2020-05-27 20:38:31	2020-05-27	8	[{"id_menu":5,"count":1}]	27243	delivery	5	13
69066	2020-05-27 20:43:34	2020-05-27	14	[{"id_menu":2,"count":1}]	1674	delivery	5	19
69067	2020-05-27 20:43:35	2020-05-27	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7060	delivery	5	45
69068	2020-05-27 20:43:55	2020-05-27	17	[{"id_menu":4,"count":1}]	993	delivery	5	22
69069	2020-05-27 20:44:33	2020-05-27	8	[{"id_menu":5,"count":1}]	27319	delivery	5	13
69070	2020-05-27 20:45:27	2020-05-27	14	[{"id_menu":2,"count":1}]	27225	delivery	5	19
69071	2020-05-27 20:47:33	2020-05-27	9	[{"id_menu":6,"count":1}]	26649	delivery	5	14
69072	2020-05-27 20:49:25	2020-05-27	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	27289	delivery	5	31
69073	2020-05-27 20:49:37	2020-05-27	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	27389	delivery	5	40
69074	2020-05-27 20:53:07	2020-05-27	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	4217	delivery	5	26
69075	2020-05-27 20:54:30	2020-05-27	17	[{"id_menu":4,"count":1}]	1317	pick-up	0	17
69076	2020-05-27 20:54:40	2020-05-27	12	[{"id_menu":3,"count":1}]	18227	delivery	5	17
69077	2020-05-27 20:57:37	2020-05-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	27314	delivery	5	22
69078	2020-05-27 20:59:03	2020-05-27	12	[{"id_menu":3,"count":1}]	27252	delivery	5	17
69079	2020-05-27 20:59:20	2020-05-27	8	[{"id_menu":5,"count":1}]	25317	pick-up	0	8
69080	2020-05-27 20:59:23	2020-05-27	17	[{"id_menu":4,"count":1}]	21850	delivery	5	22
69081	2020-05-27 21:05:04	2020-05-27	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12250	delivery	5	40
69082	2020-05-27 21:09:41	2020-05-27	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1409	pick-up	0	21
69083	2020-05-27 21:09:52	2020-05-27	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27292	delivery	5	39
69084	2020-05-27 21:12:19	2020-05-27	8	[{"id_menu":5,"count":1}]	11683	delivery	5	13
69085	2020-05-27 21:14:49	2020-05-27	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	20506	delivery	5	43
69086	2020-05-27 21:16:06	2020-05-27	9	[{"id_menu":6,"count":1}]	27196	delivery	5	14
69087	2020-05-27 21:19:15	2020-05-27	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	27307	delivery	5	43
69088	2020-05-27 21:25:03	2020-05-27	14	[{"id_menu":2,"count":1}]	12240	delivery	5	19
69089	2020-05-27 21:26:01	2020-05-27	12	[{"id_menu":3,"count":1}]	905	pick-up	0	12
69090	2020-05-27 21:26:06	2020-05-27	9	[{"id_menu":7,"count":1}]	10203	pick-up	0	9
69091	2020-05-27 21:28:21	2020-05-27	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	11148	delivery	5	25
69092	2020-05-27 21:31:48	2020-05-27	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	15229	delivery	5	25
69093	2020-05-27 21:40:48	2020-05-27	9	[{"id_menu":6,"count":1}]	1679	delivery	5	14
69094	2020-05-27 21:46:59	2020-05-27	8	[{"id_menu":5,"count":1}]	4942	delivery	5	13
69095	2020-05-27 21:47:03	2020-05-27	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	14022	delivery	5	28
69096	2020-05-27 21:49:26	2020-05-27	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	27278	pick-up	0	22
69097	2020-05-27 21:51:20	2020-05-27	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	27329	delivery	5	45
69098	2020-05-27 21:52:46	2020-05-27	17	[{"id_menu":4,"count":1}]	12951	pick-up	0	17
69099	2020-05-27 21:54:33	2020-05-27	17	[{"id_menu":4,"count":1}]	9266	pick-up	0	17
69100	2020-05-27 21:55:13	2020-05-27	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	19818	delivery	5	26
69101	2020-05-27 21:55:28	2020-05-27	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3028	delivery	5	31
69102	2020-05-27 21:56:27	2020-05-27	9	[{"id_menu":6,"count":1}]	16271	delivery	5	14
69103	2020-05-27 21:59:39	2020-05-27	8	[{"id_menu":5,"count":1}]	27312	delivery	5	13
69104	2020-05-27 22:02:31	2020-05-27	8	[{"id_menu":5,"count":1}]	1337	pick-up	0	8
69105	2020-05-27 22:04:48	2020-05-27	9	[{"id_menu":6,"count":1}]	7428	delivery	5	14
69106	2020-05-27 22:06:37	2020-05-27	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	27357	delivery	5	31
69107	2020-05-27 22:07:36	2020-05-27	9	[{"id_menu":7,"count":1}]	27259	delivery	5	14
69108	2020-05-27 22:08:42	2020-05-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	18690	delivery	5	28
69109	2020-05-27 22:11:49	2020-05-27	9	[{"id_menu":6,"count":1}]	12589	delivery	5	14
69110	2020-05-27 22:19:13	2020-05-27	12	[{"id_menu":1,"count":1}]	14584	delivery	5	17
69111	2020-05-27 22:23:02	2020-05-27	12	[{"id_menu":1,"count":1}]	27296	delivery	5	17
69112	2020-05-27 22:23:39	2020-05-27	9	[{"id_menu":6,"count":1}]	24789	delivery	5	14
69113	2020-05-27 22:23:57	2020-05-27	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	15361	pick-up	0	29
69114	2020-05-27 22:35:18	2020-05-27	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8170	pick-up	0	26
69115	2020-05-27 22:36:28	2020-05-27	9	[{"id_menu":6,"count":1}]	2957	delivery	5	14
69116	2020-05-27 22:38:12	2020-05-27	9	[{"id_menu":7,"count":1}]	6665	delivery	5	14
69117	2020-05-27 22:39:29	2020-05-27	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	27224	delivery	5	26
69118	2020-05-27 22:39:38	2020-05-27	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	21601	pick-up	0	26
69119	2020-05-27 22:40:24	2020-05-27	14	[{"id_menu":2,"count":1}]	111	pick-up	0	14
69120	2020-05-27 22:41:22	2020-05-27	8	[{"id_menu":5,"count":1}]	4782	pick-up	0	8
69121	2020-05-27 22:46:31	2020-05-27	12	[{"id_menu":1,"count":1}]	27248	delivery	5	17
69122	2020-05-27 22:47:08	2020-05-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18671	delivery	5	22
69123	2020-05-27 22:48:55	2020-05-27	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	17594	delivery	5	25
69124	2020-05-27 22:49:01	2020-05-27	14	[{"id_menu":2,"count":1}]	7143	delivery	5	19
69125	2020-05-27 22:49:15	2020-05-27	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	27360	delivery	5	31
69126	2020-05-27 22:49:18	2020-05-27	14	[{"id_menu":2,"count":1}]	27263	delivery	5	19
69127	2020-05-27 22:49:42	2020-05-27	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	7030	delivery	5	26
69128	2020-05-27 22:53:50	2020-05-27	17	[{"id_menu":4,"count":1}]	27391	pick-up	0	17
69129	2020-05-27 22:55:38	2020-05-27	12	[{"id_menu":3,"count":1}]	8286	delivery	5	17
69130	2020-05-27 22:56:04	2020-05-27	17	[{"id_menu":4,"count":1}]	27328	pick-up	0	17
69131	2020-05-27 22:58:31	2020-05-27	17	[{"id_menu":4,"count":1}]	27304	pick-up	0	17
69132	2020-05-27 23:04:45	2020-05-27	9	[{"id_menu":6,"count":1}]	9052	delivery	5	14
69133	2020-05-27 23:10:38	2020-05-27	14	[{"id_menu":2,"count":1}]	23747	delivery	5	19
69134	2020-05-27 23:17:52	2020-05-27	9	[{"id_menu":6,"count":1}]	1060	pick-up	0	9
69135	2020-05-27 23:19:53	2020-05-27	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27317	delivery	5	31
69136	2020-05-27 23:22:36	2020-05-27	12	[{"id_menu":3,"count":1}]	10694	delivery	5	17
69137	2020-05-27 23:22:36	2020-05-27	9	[{"id_menu":7,"count":1}]	26280	delivery	5	14
69138	2020-05-27 23:26:20	2020-05-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	27188	delivery	5	28
69139	2020-05-27 23:33:41	2020-05-27	9	[{"id_menu":6,"count":2}]	27269	delivery	5	14
69140	2020-05-27 23:34:46	2020-05-27	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	27182	delivery	5	31
69141	2020-05-27 23:54:25	2020-05-27	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24121	delivery	5	31
69142	2020-05-27 23:57:38	2020-05-27	9	[{"id_menu":6,"count":1}]	24344	delivery	5	14
69143	2020-05-28 00:01:15	2020-05-28	12	[{"id_menu":3,"count":1}]	27428	delivery	5	17
69144	2020-05-28 00:02:22	2020-05-28	9	[{"id_menu":7,"count":1}]	10388	delivery	5	14
69145	2020-05-28 00:05:15	2020-05-28	9	[{"id_menu":7,"count":1}]	25736	delivery	5	14
69146	2020-05-28 00:05:56	2020-05-28	14	[{"id_menu":2,"count":1}]	14089	delivery	5	19
69147	2020-05-28 00:22:08	2020-05-28	8	[{"id_menu":5,"count":1}]	27469	delivery	5	13
69148	2020-05-28 00:28:54	2020-05-28	14	[{"id_menu":2,"count":1}]	22237	delivery	5	19
69149	2020-05-28 00:30:18	2020-05-28	8	[{"id_menu":5,"count":1}]	12676	delivery	5	13
69150	2020-05-28 00:30:47	2020-05-28	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9243	pick-up	0	35
69151	2020-05-28 00:36:28	2020-05-28	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5699	delivery	5	31
69152	2020-05-28 00:36:57	2020-05-28	12	[{"id_menu":1,"count":1}]	27479	delivery	5	17
69153	2020-05-28 00:38:29	2020-05-28	12	[{"id_menu":1,"count":1}]	27546	delivery	5	17
69154	2020-05-28 00:40:31	2020-05-28	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	27491	delivery	5	40
69155	2020-05-28 00:40:43	2020-05-28	14	[{"id_menu":2,"count":1}]	27457	delivery	5	19
69156	2020-05-28 00:44:25	2020-05-28	9	[{"id_menu":6,"count":1}]	5706	delivery	5	14
69157	2020-05-28 00:46:00	2020-05-28	12	[{"id_menu":1,"count":1}]	1212	pick-up	0	12
69158	2020-05-28 00:49:01	2020-05-28	8	[{"id_menu":5,"count":1}]	5998	delivery	5	13
69159	2020-05-28 00:49:18	2020-05-28	9	[{"id_menu":6,"count":1}]	27520	delivery	5	14
69160	2020-05-28 00:50:31	2020-05-28	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	9760	delivery	5	43
69161	2020-05-28 00:59:07	2020-05-28	12	[{"id_menu":1,"count":1}]	17873	delivery	5	17
69162	2020-05-28 01:03:42	2020-05-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	27422	delivery	5	31
69163	2020-05-28 01:04:35	2020-05-28	9	[{"id_menu":6,"count":1}]	23875	delivery	5	14
69164	2020-05-28 01:15:00	2020-05-28	9	[{"id_menu":6,"count":1}]	27513	delivery	5	14
69165	2020-05-28 01:21:05	2020-05-28	17	[{"id_menu":4,"count":1}]	27466	delivery	5	22
69166	2020-05-28 01:27:06	2020-05-28	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	5886	delivery	5	34
69167	2020-05-28 01:27:51	2020-05-28	8	[{"id_menu":5,"count":2}]	7365	delivery	5	13
69168	2020-05-28 01:34:53	2020-05-28	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27471	delivery	5	34
69169	2020-05-28 01:36:06	2020-05-28	17	[{"id_menu":4,"count":1}]	12293	delivery	5	22
69170	2020-05-28 01:36:10	2020-05-28	12	[{"id_menu":1,"count":1}]	16996	pick-up	0	12
69171	2020-05-28 01:38:36	2020-05-28	9	[{"id_menu":6,"count":1}]	8138	delivery	5	14
69172	2020-05-28 01:42:01	2020-05-28	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1207	delivery	5	34
69173	2020-05-28 01:54:57	2020-05-28	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	27006	delivery	5	26
69174	2020-05-28 01:55:35	2020-05-28	14	[{"id_menu":2,"count":1}]	8656	pick-up	0	14
69175	2020-05-28 01:56:34	2020-05-28	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	18351	delivery	5	23
69176	2020-05-28 01:57:55	2020-05-28	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	27535	delivery	5	42
69177	2020-05-28 02:00:47	2020-05-28	12	[{"id_menu":3,"count":1}]	20849	delivery	5	17
69178	2020-05-28 02:01:46	2020-05-28	9	[{"id_menu":6,"count":1}]	1501	delivery	5	14
69179	2020-05-28 02:06:24	2020-05-28	9	[{"id_menu":7,"count":1}]	6235	pick-up	0	9
69180	2020-05-28 02:09:17	2020-05-28	12	[{"id_menu":3,"count":1}]	27539	delivery	5	17
69181	2020-05-28 02:13:17	2020-05-28	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	14069	delivery	5	34
69182	2020-05-28 02:18:08	2020-05-28	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11342	delivery	5	37
69183	2020-05-28 02:27:26	2020-05-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	27503	delivery	5	31
69184	2020-05-28 02:31:09	2020-05-28	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	16272	delivery	5	34
69185	2020-05-28 02:45:27	2020-05-28	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	20400	delivery	5	25
69186	2020-05-28 02:46:00	2020-05-28	14	[{"id_menu":2,"count":1}]	9579	delivery	5	19
69187	2020-05-28 02:48:11	2020-05-28	12	[{"id_menu":3,"count":1}]	3808	pick-up	0	12
69188	2020-05-28 02:56:14	2020-05-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24062	delivery	5	23
69189	2020-05-28 02:57:43	2020-05-28	9	[{"id_menu":6,"count":1}]	2672	pick-up	0	9
69190	2020-05-28 02:58:24	2020-05-28	14	[{"id_menu":2,"count":1}]	20910	pick-up	0	14
69191	2020-05-28 02:59:49	2020-05-28	9	[{"id_menu":6,"count":1}]	20387	delivery	5	14
69192	2020-05-28 03:00:29	2020-05-28	14	[{"id_menu":2,"count":1}]	16601	delivery	5	19
69193	2020-05-28 03:06:30	2020-05-28	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	19280	delivery	5	31
69194	2020-05-28 03:06:58	2020-05-28	17	[{"id_menu":4,"count":1}]	11936	delivery	5	22
69195	2020-05-28 03:09:21	2020-05-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	27519	delivery	5	22
69196	2020-05-28 03:16:18	2020-05-28	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	27516	delivery	5	34
69197	2020-05-28 03:17:47	2020-05-28	9	[{"id_menu":7,"count":2}]	27439	delivery	5	14
69198	2020-05-28 03:19:07	2020-05-28	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	26862	delivery	5	42
69199	2020-05-28 03:19:24	2020-05-28	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	27440	delivery	5	26
69200	2020-05-28 03:28:17	2020-05-28	9	[{"id_menu":6,"count":1}]	27534	delivery	5	14
69201	2020-05-28 03:28:17	2020-05-28	9	[{"id_menu":6,"count":1}]	23474	delivery	5	14
69202	2020-05-28 03:30:42	2020-05-28	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	16311	delivery	5	28
69203	2020-05-28 03:31:25	2020-05-28	9	[{"id_menu":6,"count":1}]	27462	delivery	5	14
69204	2020-05-28 03:31:47	2020-05-28	14	[{"id_menu":2,"count":1}]	14919	pick-up	0	14
69205	2020-05-28 03:43:46	2020-05-28	17	[{"id_menu":4,"count":1}]	27404	delivery	5	22
69206	2020-05-28 03:49:18	2020-05-28	12	[{"id_menu":3,"count":1}]	25641	pick-up	0	12
69207	2020-05-28 03:52:34	2020-05-28	9	[{"id_menu":7,"count":2}]	27496	delivery	5	14
69208	2020-05-28 03:55:27	2020-05-28	9	[{"id_menu":6,"count":1}]	12502	delivery	5	14
69209	2020-05-28 03:57:14	2020-05-28	14	[{"id_menu":2,"count":1}]	27541	pick-up	0	14
69210	2020-05-28 04:04:22	2020-05-28	9	[{"id_menu":6,"count":1}]	3818	pick-up	0	9
69211	2020-05-28 04:04:40	2020-05-28	12	[{"id_menu":1,"count":1}]	716	pick-up	0	12
69212	2020-05-28 04:06:53	2020-05-28	9	[{"id_menu":6,"count":1}]	10200	pick-up	0	9
69213	2020-05-28 04:11:45	2020-05-28	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	8018	pick-up	0	29
69214	2020-05-28 04:15:57	2020-05-28	9	[{"id_menu":6,"count":1}]	11713	delivery	5	14
69215	2020-05-28 04:24:45	2020-05-28	8	[{"id_menu":5,"count":1}]	27551	delivery	5	13
69216	2020-05-28 04:27:35	2020-05-28	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	27477	delivery	5	40
69217	2020-05-28 04:29:31	2020-05-28	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	16464	delivery	5	26
69218	2020-05-28 04:30:30	2020-05-28	9	[{"id_menu":6,"count":1}]	16586	delivery	5	14
69219	2020-05-28 04:38:32	2020-05-28	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	17326	delivery	5	40
69220	2020-05-28 04:47:51	2020-05-28	17	[{"id_menu":4,"count":1}]	10876	delivery	5	22
69221	2020-05-28 04:55:02	2020-05-28	12	[{"id_menu":3,"count":1}]	12254	pick-up	0	12
69222	2020-05-28 04:56:29	2020-05-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	26928	delivery	5	22
69223	2020-05-28 04:59:43	2020-05-28	9	[{"id_menu":7,"count":2}]	19583	delivery	5	14
69224	2020-05-28 05:04:55	2020-05-28	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	22901	delivery	5	39
69225	2020-05-28 05:05:15	2020-05-28	9	[{"id_menu":6,"count":1}]	3118	delivery	5	14
69226	2020-05-28 05:09:33	2020-05-28	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8813	delivery	5	42
69227	2020-05-28 05:10:13	2020-05-28	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	8341	pick-up	0	29
69228	2020-05-28 05:12:04	2020-05-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	27560	delivery	5	28
69229	2020-05-28 05:12:58	2020-05-28	14	[{"id_menu":2,"count":1}]	11454	delivery	5	19
69230	2020-05-28 05:24:56	2020-05-28	17	[{"id_menu":4,"count":1}]	2477	delivery	5	22
69231	2020-05-28 05:34:47	2020-05-28	14	[{"id_menu":2,"count":1}]	19564	delivery	5	19
69232	2020-05-28 05:37:22	2020-05-28	9	[{"id_menu":7,"count":1}]	27458	delivery	5	14
69233	2020-05-28 05:41:22	2020-05-28	12	[{"id_menu":1,"count":1}]	27431	delivery	5	17
69234	2020-05-28 05:52:12	2020-05-28	9	[{"id_menu":7,"count":1}]	765	pick-up	0	9
69235	2020-05-28 05:53:31	2020-05-28	12	[{"id_menu":1,"count":1}]	379	pick-up	0	12
69236	2020-05-28 06:02:10	2020-05-28	9	[{"id_menu":6,"count":1}]	19794	delivery	5	14
69237	2020-05-28 06:08:16	2020-05-28	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	5817	delivery	5	22
69238	2020-05-28 06:10:33	2020-05-28	17	[{"id_menu":4,"count":1}]	27410	delivery	5	22
69239	2020-05-28 06:13:08	2020-05-28	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5920	delivery	5	43
69240	2020-05-28 06:13:58	2020-05-28	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	11314	pick-up	0	35
69241	2020-05-28 06:14:55	2020-05-28	17	[{"id_menu":4,"count":1}]	17019	delivery	5	22
69242	2020-05-28 06:15:19	2020-05-28	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	27478	pick-up	0	29
69243	2020-05-28 06:17:01	2020-05-28	9	[{"id_menu":7,"count":1}]	26186	delivery	5	14
69244	2020-05-28 06:21:15	2020-05-28	8	[{"id_menu":5,"count":1}]	3863	pick-up	0	8
69245	2020-05-28 06:22:24	2020-05-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19553	delivery	5	22
69246	2020-05-28 06:24:46	2020-05-28	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10710	delivery	5	36
69247	2020-05-28 06:27:42	2020-05-28	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27306	delivery	5	51
69248	2020-05-28 06:29:16	2020-05-28	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	18445	pick-up	0	26
69249	2020-05-28 06:29:57	2020-05-28	9	[{"id_menu":6,"count":1}]	3662	delivery	5	14
69250	2020-05-28 06:32:01	2020-05-28	14	[{"id_menu":2,"count":1}]	27565	delivery	5	19
69251	2020-05-28 06:32:16	2020-05-28	12	[{"id_menu":3,"count":1}]	27026	delivery	5	17
69252	2020-05-28 06:32:31	2020-05-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2683	delivery	5	31
69253	2020-05-28 06:32:41	2020-05-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27532	delivery	5	23
69254	2020-05-28 06:37:36	2020-05-28	9	[{"id_menu":7,"count":1}]	3883	delivery	5	14
69255	2020-05-28 06:37:42	2020-05-28	8	[{"id_menu":5,"count":1}]	18911	delivery	5	13
69256	2020-05-28 06:39:49	2020-05-28	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27527	delivery	5	34
69257	2020-05-28 06:40:09	2020-05-28	17	[{"id_menu":4,"count":1}]	9356	pick-up	0	17
69258	2020-05-28 06:40:34	2020-05-28	9	[{"id_menu":7,"count":2}]	11686	pick-up	0	9
69259	2020-05-28 06:44:43	2020-05-28	12	[{"id_menu":3,"count":1}]	22283	pick-up	0	12
69260	2020-05-28 06:45:21	2020-05-28	12	[{"id_menu":3,"count":1}]	24604	delivery	5	17
69261	2020-05-28 06:51:50	2020-05-28	12	[{"id_menu":3,"count":1}]	20874	delivery	5	17
69262	2020-05-28 06:54:18	2020-05-28	8	[{"id_menu":5,"count":2}]	20287	delivery	5	13
69263	2020-05-28 06:56:17	2020-05-28	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	27502	delivery	5	45
69264	2020-05-28 07:10:00	2020-05-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	27443	delivery	5	31
69265	2020-05-28 07:10:22	2020-05-28	17	[{"id_menu":4,"count":1}]	27509	pick-up	0	17
69266	2020-05-28 07:12:59	2020-05-28	8	[{"id_menu":5,"count":1}]	27493	delivery	5	13
69267	2020-05-28 07:16:33	2020-05-28	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	17882	delivery	5	34
69268	2020-05-28 07:17:17	2020-05-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24292	delivery	5	22
69269	2020-05-28 07:20:19	2020-05-28	12	[{"id_menu":3,"count":1}]	27567	delivery	5	17
69270	2020-05-28 07:25:15	2020-05-28	14	[{"id_menu":2,"count":1}]	2602	pick-up	0	14
69271	2020-05-28 07:27:47	2020-05-28	14	[{"id_menu":2,"count":2}]	16632	pick-up	0	14
69272	2020-05-28 07:29:29	2020-05-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	27552	delivery	5	31
69273	2020-05-28 07:34:15	2020-05-28	9	[{"id_menu":6,"count":1}]	27432	delivery	5	14
69274	2020-05-28 07:39:21	2020-05-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13303	delivery	5	22
69275	2020-05-28 07:43:37	2020-05-28	17	[{"id_menu":4,"count":1}]	4872	delivery	5	22
69276	2020-05-28 07:46:07	2020-05-28	14	[{"id_menu":2,"count":1}]	17633	delivery	5	19
69277	2020-05-28 07:46:56	2020-05-28	14	[{"id_menu":2,"count":1}]	26644	pick-up	0	14
69278	2020-05-28 07:48:11	2020-05-28	14	[{"id_menu":2,"count":1}]	22124	delivery	5	19
69279	2020-05-28 07:48:30	2020-05-28	9	[{"id_menu":7,"count":1}]	14104	delivery	5	14
69280	2020-05-28 07:48:57	2020-05-28	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	27528	delivery	5	45
69281	2020-05-28 07:56:54	2020-05-28	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19953	delivery	5	53
69282	2020-05-28 07:58:58	2020-05-28	17	[{"id_menu":4,"count":1}]	16327	delivery	5	22
69283	2020-05-28 08:00:00	2020-05-28	9	[{"id_menu":6,"count":1}]	27417	delivery	5	14
69284	2020-05-28 08:05:46	2020-05-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	24547	pick-up	0	26
69285	2020-05-28 08:07:58	2020-05-28	9	[{"id_menu":7,"count":1}]	1085	delivery	5	14
69286	2020-05-28 08:08:35	2020-05-28	17	[{"id_menu":4,"count":1}]	27016	delivery	5	22
69287	2020-05-28 08:12:15	2020-05-28	17	[{"id_menu":4,"count":1}]	11340	pick-up	0	17
69288	2020-05-28 08:14:34	2020-05-28	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6738	delivery	5	36
69289	2020-05-28 08:14:37	2020-05-28	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4682	pick-up	0	21
69290	2020-05-28 08:16:52	2020-05-28	14	[{"id_menu":2,"count":1}]	2458	delivery	5	19
69291	2020-05-28 08:19:38	2020-05-28	17	[{"id_menu":4,"count":2}]	9351	delivery	5	22
69292	2020-05-28 08:19:53	2020-05-28	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	197	pick-up	0	31
69293	2020-05-28 08:21:56	2020-05-28	17	[{"id_menu":4,"count":1}]	26311	pick-up	0	17
69294	2020-05-28 08:22:22	2020-05-28	14	[{"id_menu":2,"count":1}]	21606	pick-up	0	14
69295	2020-05-28 08:23:01	2020-05-28	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	20999	delivery	5	31
69296	2020-05-28 08:26:20	2020-05-28	17	[{"id_menu":4,"count":1}]	23506	delivery	5	22
69297	2020-05-28 08:28:21	2020-05-28	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	314	pick-up	0	29
69298	2020-05-28 08:38:10	2020-05-28	8	[{"id_menu":5,"count":1}]	19375	delivery	5	13
69299	2020-05-28 08:38:53	2020-05-28	9	[{"id_menu":7,"count":1}]	9503	delivery	5	14
69300	2020-05-28 08:42:31	2020-05-28	12	[{"id_menu":3,"count":1}]	13851	delivery	5	17
69301	2020-05-28 08:42:40	2020-05-28	17	[{"id_menu":4,"count":1}]	16961	delivery	5	22
69302	2020-05-28 08:45:30	2020-05-28	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1801	delivery	5	31
69303	2020-05-28 08:46:03	2020-05-28	8	[{"id_menu":5,"count":1}]	27241	delivery	5	13
69304	2020-05-28 08:48:10	2020-05-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1380	delivery	5	23
69305	2020-05-28 08:48:45	2020-05-28	9	[{"id_menu":6,"count":2}]	27412	delivery	5	14
69306	2020-05-28 08:49:19	2020-05-28	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	27411	delivery	5	26
69307	2020-05-28 08:52:32	2020-05-28	8	[{"id_menu":5,"count":1}]	25617	delivery	5	13
69308	2020-05-28 08:55:54	2020-05-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2443	pick-up	0	17
69309	2020-05-28 08:57:45	2020-05-28	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	27547	delivery	5	25
69310	2020-05-28 08:58:22	2020-05-28	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27409	delivery	5	36
69311	2020-05-28 08:59:19	2020-05-28	8	[{"id_menu":5,"count":1}]	15370	pick-up	0	8
69312	2020-05-28 08:59:29	2020-05-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18173	delivery	5	22
69313	2020-05-28 09:00:41	2020-05-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	477	pick-up	0	26
69314	2020-05-28 09:01:49	2020-05-28	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	8616	delivery	5	36
69315	2020-05-28 09:03:55	2020-05-28	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	27498	delivery	5	40
69316	2020-05-28 09:03:59	2020-05-28	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	27455	delivery	5	56
69317	2020-05-28 09:06:53	2020-05-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	27545	delivery	5	28
69318	2020-05-28 09:14:28	2020-05-28	9	[{"id_menu":6,"count":1}]	23593	delivery	5	14
69319	2020-05-28 09:15:59	2020-05-28	9	[{"id_menu":6,"count":2}]	25199	delivery	5	14
69320	2020-05-28 09:17:28	2020-05-28	17	[{"id_menu":4,"count":1}]	4577	pick-up	0	17
69321	2020-05-28 09:18:30	2020-05-28	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1700	delivery	5	28
69322	2020-05-28 09:29:39	2020-05-28	12	[{"id_menu":3,"count":1}]	27430	delivery	5	17
69323	2020-05-28 09:31:21	2020-05-28	9	[{"id_menu":7,"count":1}]	655	pick-up	0	9
69324	2020-05-28 09:32:50	2020-05-28	14	[{"id_menu":2,"count":1}]	10106	pick-up	0	14
69325	2020-05-28 09:38:25	2020-05-28	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10528	delivery	5	36
69326	2020-05-28 09:39:16	2020-05-28	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27425	pick-up	0	31
69327	2020-05-28 09:41:05	2020-05-28	17	[{"id_menu":4,"count":1}]	19490	pick-up	0	17
69328	2020-05-28 09:42:55	2020-05-28	14	[{"id_menu":2,"count":2}]	9128	pick-up	0	14
69329	2020-05-28 09:46:18	2020-05-28	14	[{"id_menu":2,"count":1}]	27419	delivery	5	19
69330	2020-05-28 09:46:20	2020-05-28	17	[{"id_menu":4,"count":1}]	27484	delivery	5	22
69331	2020-05-28 09:51:25	2020-05-28	9	[{"id_menu":7,"count":1}]	14986	pick-up	0	9
69332	2020-05-28 09:53:54	2020-05-28	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13694	delivery	5	45
69333	2020-05-28 09:55:53	2020-05-28	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	27401	delivery	5	45
69334	2020-05-28 09:56:42	2020-05-28	17	[{"id_menu":4,"count":1}]	27448	delivery	5	22
69335	2020-05-28 09:56:44	2020-05-28	9	[{"id_menu":7,"count":1}]	27537	delivery	5	14
69336	2020-05-28 09:58:35	2020-05-28	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9896	delivery	5	36
69337	2020-05-28 10:03:24	2020-05-28	9	[{"id_menu":6,"count":1}]	27415	delivery	5	14
69338	2020-05-28 10:04:44	2020-05-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	27542	delivery	5	22
69339	2020-05-28 10:07:04	2020-05-28	14	[{"id_menu":2,"count":2}]	19432	delivery	5	19
69340	2020-05-28 10:09:46	2020-05-28	12	[{"id_menu":1,"count":1}]	27497	delivery	5	17
69341	2020-05-28 10:13:40	2020-05-28	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9395	delivery	5	40
69342	2020-05-28 10:18:22	2020-05-28	14	[{"id_menu":2,"count":1}]	3677	delivery	5	19
69343	2020-05-28 10:19:24	2020-05-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16891	delivery	5	22
69344	2020-05-28 10:19:53	2020-05-28	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	9942	delivery	5	26
69345	2020-05-28 10:21:04	2020-05-28	9	[{"id_menu":7,"count":1}]	13762	pick-up	0	9
69346	2020-05-28 10:35:23	2020-05-28	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14110	delivery	5	47
69347	2020-05-28 10:39:33	2020-05-28	8	[{"id_menu":5,"count":1}]	27414	delivery	5	13
69348	2020-05-28 10:40:20	2020-05-28	9	[{"id_menu":6,"count":1}]	26630	delivery	5	14
69349	2020-05-28 10:41:52	2020-05-28	12	[{"id_menu":3,"count":1}]	27476	delivery	5	17
69350	2020-05-28 10:42:54	2020-05-28	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	27569	delivery	5	34
69351	2020-05-28 10:45:08	2020-05-28	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	4403	delivery	5	40
69352	2020-05-28 10:53:37	2020-05-28	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	18132	delivery	5	34
69353	2020-05-28 10:53:40	2020-05-28	9	[{"id_menu":6,"count":1}]	6807	pick-up	0	9
69354	2020-05-28 10:55:54	2020-05-28	12	[{"id_menu":1,"count":1}]	6429	delivery	5	17
69355	2020-05-28 11:01:51	2020-05-28	9	[{"id_menu":6,"count":1}]	22200	delivery	5	14
69356	2020-05-28 11:04:25	2020-05-28	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":3}]	13930	pick-up	0	21
69357	2020-05-28 11:06:12	2020-05-28	12	[{"id_menu":3,"count":1}]	8676	delivery	5	17
69358	2020-05-28 11:06:12	2020-05-28	8	[{"id_menu":5,"count":1}]	27549	delivery	5	13
69359	2020-05-28 11:07:07	2020-05-28	9	[{"id_menu":6,"count":2}]	5752	delivery	5	14
69360	2020-05-28 11:07:16	2020-05-28	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15591	delivery	5	36
69361	2020-05-28 11:08:15	2020-05-28	17	[{"id_menu":4,"count":1}]	1753	pick-up	0	17
69362	2020-05-28 11:11:26	2020-05-28	12	[{"id_menu":3,"count":1}]	25064	delivery	5	17
69363	2020-05-28 11:12:02	2020-05-28	9	[{"id_menu":7,"count":1}]	18652	pick-up	0	9
69364	2020-05-28 11:13:25	2020-05-28	17	[{"id_menu":4,"count":2}]	6254	delivery	5	22
69365	2020-05-28 11:14:46	2020-05-28	14	[{"id_menu":2,"count":1}]	17086	delivery	5	19
69366	2020-05-28 11:19:06	2020-05-28	12	[{"id_menu":3,"count":1}]	16924	delivery	5	17
69367	2020-05-28 11:21:25	2020-05-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	11018	delivery	5	31
69368	2020-05-28 11:22:19	2020-05-28	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	12565	delivery	5	31
69369	2020-05-28 11:29:34	2020-05-28	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3198	pick-up	0	26
69370	2020-05-28 11:31:21	2020-05-28	12	[{"id_menu":3,"count":1}]	13147	delivery	5	17
69371	2020-05-28 11:31:59	2020-05-28	17	[{"id_menu":4,"count":1}]	5729	delivery	5	22
69372	2020-05-28 11:35:11	2020-05-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27465	delivery	5	23
69373	2020-05-28 11:36:44	2020-05-28	8	[{"id_menu":5,"count":1}]	27557	delivery	5	13
69374	2020-05-28 11:42:47	2020-05-28	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	19163	delivery	5	30
69375	2020-05-28 11:44:10	2020-05-28	8	[{"id_menu":5,"count":1}]	26742	delivery	5	13
69376	2020-05-28 11:46:06	2020-05-28	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	23697	delivery	5	40
69377	2020-05-28 11:47:03	2020-05-28	9	[{"id_menu":7,"count":1}]	27487	delivery	5	14
69378	2020-05-28 11:48:21	2020-05-28	9	[{"id_menu":6,"count":1}]	27464	delivery	5	14
69379	2020-05-28 11:50:56	2020-05-28	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	27463	delivery	5	36
69380	2020-05-28 11:55:42	2020-05-28	12	[{"id_menu":1,"count":1}]	9734	pick-up	0	12
69381	2020-05-28 11:58:09	2020-05-28	9	[{"id_menu":7,"count":1}]	27435	delivery	5	14
69382	2020-05-28 12:00:23	2020-05-28	12	[{"id_menu":1,"count":1}]	27555	pick-up	0	12
69383	2020-05-28 12:00:35	2020-05-28	9	[{"id_menu":7,"count":2}]	616	delivery	5	14
69384	2020-05-28 12:02:36	2020-05-28	8	[{"id_menu":5,"count":1}]	5481	delivery	5	13
69385	2020-05-28 12:02:55	2020-05-28	12	[{"id_menu":3,"count":1}]	27564	delivery	5	17
69386	2020-05-28 12:11:26	2020-05-28	9	[{"id_menu":7,"count":1}]	17664	delivery	5	14
69387	2020-05-28 12:12:02	2020-05-28	8	[{"id_menu":5,"count":1}]	5668	delivery	5	13
69388	2020-05-28 12:14:54	2020-05-28	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	22477	pick-up	0	40
69389	2020-05-28 12:17:01	2020-05-28	14	[{"id_menu":2,"count":1}]	26502	delivery	5	19
69390	2020-05-28 12:20:28	2020-05-28	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1684	pick-up	0	25
69391	2020-05-28 12:26:28	2020-05-28	17	[{"id_menu":4,"count":1}]	27485	delivery	5	22
69392	2020-05-28 12:29:57	2020-05-28	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	27446	delivery	5	30
69393	2020-05-28 12:36:12	2020-05-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	27400	delivery	5	22
69394	2020-05-28 12:37:33	2020-05-28	12	[{"id_menu":1,"count":1}]	338	delivery	5	17
69395	2020-05-28 12:42:19	2020-05-28	12	[{"id_menu":3,"count":1}]	15817	delivery	5	17
69396	2020-05-28 12:42:54	2020-05-28	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	15104	delivery	5	28
69397	2020-05-28 12:45:50	2020-05-28	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	12836	pick-up	0	39
69398	2020-05-28 12:47:51	2020-05-28	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	19646	delivery	5	44
69399	2020-05-28 12:47:56	2020-05-28	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	27531	delivery	5	25
69400	2020-05-28 12:54:27	2020-05-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14323	delivery	5	23
69401	2020-05-28 12:56:31	2020-05-28	9	[{"id_menu":7,"count":1}]	21550	delivery	5	14
69402	2020-05-28 13:06:38	2020-05-28	8	[{"id_menu":5,"count":1}]	19753	delivery	5	13
69403	2020-05-28 13:12:40	2020-05-28	12	[{"id_menu":3,"count":1}]	8878	delivery	5	17
69404	2020-05-28 13:15:01	2020-05-28	12	[{"id_menu":3,"count":1}]	27459	pick-up	0	12
69405	2020-05-28 13:18:48	2020-05-28	9	[{"id_menu":7,"count":1}]	27566	delivery	5	14
69406	2020-05-28 13:19:53	2020-05-28	8	[{"id_menu":5,"count":1}]	24807	delivery	5	13
69407	2020-05-28 13:24:52	2020-05-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13528	pick-up	0	17
69408	2020-05-28 13:25:12	2020-05-28	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	10058	delivery	5	26
69409	2020-05-28 13:26:07	2020-05-28	17	[{"id_menu":4,"count":1}]	2339	delivery	5	22
69410	2020-05-28 13:30:00	2020-05-28	8	[{"id_menu":5,"count":1}]	26686	delivery	5	13
69411	2020-05-28 13:35:19	2020-05-28	8	[{"id_menu":5,"count":1}]	7077	delivery	5	13
69412	2020-05-28 13:37:45	2020-05-28	8	[{"id_menu":5,"count":1}]	6733	delivery	5	13
69413	2020-05-28 13:41:08	2020-05-28	9	[{"id_menu":7,"count":1}]	16483	pick-up	0	9
69414	2020-05-28 13:45:39	2020-05-28	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	2783	delivery	5	29
69415	2020-05-28 13:46:17	2020-05-28	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	19944	delivery	5	26
69416	2020-05-28 13:48:26	2020-05-28	17	[{"id_menu":4,"count":1}]	14966	delivery	5	22
69417	2020-05-28 13:51:41	2020-05-28	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	7478	pick-up	0	21
69418	2020-05-28 13:53:51	2020-05-28	14	[{"id_menu":2,"count":1}]	12277	delivery	5	19
69419	2020-05-28 13:54:33	2020-05-28	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	19806	delivery	5	40
69420	2020-05-28 13:58:49	2020-05-28	9	[{"id_menu":7,"count":1}]	26621	delivery	5	14
69421	2020-05-28 13:59:53	2020-05-28	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4898	delivery	5	53
69422	2020-05-28 14:05:51	2020-05-28	12	[{"id_menu":1,"count":1}]	27489	delivery	5	17
69423	2020-05-28 14:06:06	2020-05-28	9	[{"id_menu":6,"count":2}]	15042	delivery	5	14
69424	2020-05-28 14:08:00	2020-05-28	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	17805	pick-up	0	21
69425	2020-05-28 14:08:44	2020-05-28	8	[{"id_menu":5,"count":1}]	20899	delivery	5	13
69426	2020-05-28 14:10:27	2020-05-28	9	[{"id_menu":7,"count":1}]	27453	pick-up	0	9
69427	2020-05-28 14:18:28	2020-05-28	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	11518	pick-up	0	25
69428	2020-05-28 14:21:02	2020-05-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	27480	delivery	5	22
69429	2020-05-28 14:22:48	2020-05-28	12	[{"id_menu":3,"count":1}]	27492	delivery	5	17
69430	2020-05-28 14:23:28	2020-05-28	17	[{"id_menu":4,"count":1}]	27505	delivery	5	22
69431	2020-05-28 14:23:42	2020-05-28	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27538	delivery	5	40
69432	2020-05-28 14:25:38	2020-05-28	14	[{"id_menu":2,"count":1}]	23280	delivery	5	19
69433	2020-05-28 14:29:21	2020-05-28	8	[{"id_menu":5,"count":2}]	9370	pick-up	0	8
69434	2020-05-28 14:30:54	2020-05-28	9	[{"id_menu":7,"count":1}]	2227	delivery	5	14
69435	2020-05-28 14:37:05	2020-05-28	12	[{"id_menu":3,"count":1}]	27451	delivery	5	17
69436	2020-05-28 14:41:35	2020-05-28	9	[{"id_menu":7,"count":1}]	27556	delivery	5	14
69437	2020-05-28 14:45:46	2020-05-28	12	[{"id_menu":3,"count":1}]	8905	pick-up	0	12
69438	2020-05-28 14:49:46	2020-05-28	17	[{"id_menu":4,"count":1}]	5350	pick-up	0	17
69439	2020-05-28 14:54:48	2020-05-28	12	[{"id_menu":1,"count":1}]	1860	delivery	5	17
69440	2020-05-28 14:56:15	2020-05-28	12	[{"id_menu":1,"count":2}]	1462	pick-up	0	12
69441	2020-05-28 14:57:24	2020-05-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11083	pick-up	0	26
69442	2020-05-28 14:58:53	2020-05-28	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	11004	delivery	5	34
69443	2020-05-28 14:59:51	2020-05-28	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	27550	delivery	5	31
69444	2020-05-28 15:05:30	2020-05-28	9	[{"id_menu":6,"count":1}]	27561	delivery	5	14
69445	2020-05-28 15:05:58	2020-05-28	14	[{"id_menu":2,"count":2}]	19126	delivery	5	19
69446	2020-05-28 15:08:19	2020-05-28	9	[{"id_menu":7,"count":1}]	820	pick-up	0	9
69447	2020-05-28 15:08:45	2020-05-28	14	[{"id_menu":2,"count":1}]	16853	pick-up	0	14
69448	2020-05-28 15:14:09	2020-05-28	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	9935	delivery	5	38
69449	2020-05-28 15:16:03	2020-05-28	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	27424	delivery	5	45
69450	2020-05-28 15:21:16	2020-05-28	8	[{"id_menu":5,"count":1}]	19547	delivery	5	13
69451	2020-05-28 15:21:26	2020-05-28	8	[{"id_menu":5,"count":2}]	27444	delivery	5	13
69452	2020-05-28 15:22:03	2020-05-28	14	[{"id_menu":2,"count":1}]	18221	delivery	5	19
69453	2020-05-28 15:27:06	2020-05-28	12	[{"id_menu":1,"count":1}]	27399	delivery	5	17
69454	2020-05-28 15:27:34	2020-05-28	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	27445	delivery	5	25
69455	2020-05-28 15:30:06	2020-05-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12484	pick-up	0	18
69456	2020-05-28 15:32:24	2020-05-28	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	27437	delivery	5	34
69457	2020-05-28 15:33:39	2020-05-28	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	19638	delivery	5	37
69458	2020-05-28 15:34:21	2020-05-28	12	[{"id_menu":3,"count":1}]	15350	delivery	5	17
69459	2020-05-28 15:35:17	2020-05-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2504	pick-up	0	23
69460	2020-05-28 15:36:12	2020-05-28	9	[{"id_menu":7,"count":1}]	5194	pick-up	0	9
69461	2020-05-28 15:38:18	2020-05-28	12	[{"id_menu":3,"count":1}]	23539	delivery	5	17
69462	2020-05-28 15:40:05	2020-05-28	9	[{"id_menu":7,"count":1}]	19265	delivery	5	14
69463	2020-05-28 15:41:30	2020-05-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	27449	delivery	5	22
69464	2020-05-28 15:41:52	2020-05-28	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":2}]	21496	delivery	5	31
69465	2020-05-28 15:44:29	2020-05-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1387	pick-up	0	26
69466	2020-05-28 15:44:39	2020-05-28	9	[{"id_menu":6,"count":1}]	18422	pick-up	0	9
69467	2020-05-28 15:45:58	2020-05-28	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	27452	delivery	5	48
69468	2020-05-28 15:48:45	2020-05-28	12	[{"id_menu":1,"count":1}]	25360	pick-up	0	12
69469	2020-05-28 15:52:45	2020-05-28	9	[{"id_menu":6,"count":1}]	14475	delivery	5	14
69470	2020-05-28 15:53:27	2020-05-28	9	[{"id_menu":6,"count":1}]	1119	pick-up	0	9
69471	2020-05-28 15:56:46	2020-05-28	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	22436	delivery	5	37
69472	2020-05-28 15:58:11	2020-05-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23519	delivery	5	22
69473	2020-05-28 15:58:38	2020-05-28	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	27456	delivery	5	31
69474	2020-05-28 15:58:44	2020-05-28	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	23208	delivery	5	31
69475	2020-05-28 15:59:38	2020-05-28	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	7451	delivery	5	23
69476	2020-05-28 15:59:55	2020-05-28	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	27405	delivery	5	26
69477	2020-05-28 16:07:14	2020-05-28	17	[{"id_menu":4,"count":1}]	223	pick-up	0	17
69478	2020-05-28 16:08:28	2020-05-28	14	[{"id_menu":2,"count":1}]	362	delivery	5	19
69479	2020-05-28 16:10:32	2020-05-28	17	[{"id_menu":4,"count":1}]	2894	delivery	5	22
69480	2020-05-28 16:10:43	2020-05-28	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21854	delivery	5	51
69481	2020-05-28 16:14:22	2020-05-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6820	delivery	5	22
69482	2020-05-28 16:20:47	2020-05-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12942	delivery	5	23
69483	2020-05-28 16:21:04	2020-05-28	17	[{"id_menu":4,"count":1}]	6074	delivery	5	22
69484	2020-05-28 16:21:13	2020-05-28	14	[{"id_menu":2,"count":1}]	8765	delivery	5	19
69485	2020-05-28 16:21:43	2020-05-28	9	[{"id_menu":7,"count":1}]	16407	delivery	5	14
69486	2020-05-28 16:23:56	2020-05-28	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	27506	delivery	5	28
69487	2020-05-28 16:24:17	2020-05-28	14	[{"id_menu":2,"count":1}]	27467	delivery	5	19
69488	2020-05-28 16:25:41	2020-05-28	9	[{"id_menu":6,"count":2}]	24425	delivery	5	14
69489	2020-05-28 16:26:03	2020-05-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	992	delivery	5	22
69490	2020-05-28 16:28:18	2020-05-28	14	[{"id_menu":2,"count":1}]	27468	delivery	5	19
69491	2020-05-28 16:30:50	2020-05-28	9	[{"id_menu":7,"count":1}]	27420	pick-up	0	9
69492	2020-05-28 16:58:40	2020-05-28	17	[{"id_menu":4,"count":1}]	14430	delivery	5	22
69493	2020-05-28 17:01:27	2020-05-28	9	[{"id_menu":7,"count":1}]	21046	delivery	5	14
69494	2020-05-28 17:06:59	2020-05-28	9	[{"id_menu":7,"count":1}]	6553	delivery	5	14
69495	2020-05-28 17:09:22	2020-05-28	8	[{"id_menu":5,"count":4}]	27554	delivery	5	13
69496	2020-05-28 17:10:34	2020-05-28	9	[{"id_menu":6,"count":1}]	9976	delivery	5	14
69497	2020-05-28 17:12:44	2020-05-28	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	27421	delivery	5	34
69498	2020-05-28 17:18:10	2020-05-28	14	[{"id_menu":2,"count":1}]	25420	delivery	5	19
69499	2020-05-28 17:18:29	2020-05-28	14	[{"id_menu":2,"count":1}]	265	pick-up	0	14
69500	2020-05-28 17:19:21	2020-05-28	8	[{"id_menu":5,"count":2}]	27522	delivery	5	13
69501	2020-05-28 17:26:40	2020-05-28	9	[{"id_menu":7,"count":1}]	1956	delivery	5	14
69502	2020-05-28 17:38:28	2020-05-28	12	[{"id_menu":1,"count":1}]	16498	delivery	5	17
69503	2020-05-28 17:40:14	2020-05-28	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	20276	delivery	5	34
69504	2020-05-28 17:40:27	2020-05-28	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	19892	delivery	5	26
69505	2020-05-28 17:47:23	2020-05-28	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	27559	delivery	5	26
69506	2020-05-28 17:53:38	2020-05-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	20697	pick-up	0	23
69507	2020-05-28 17:56:57	2020-05-28	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	3343	delivery	5	22
69508	2020-05-28 17:59:28	2020-05-28	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2901	pick-up	0	33
69509	2020-05-28 18:01:27	2020-05-28	17	[{"id_menu":4,"count":1}]	27530	pick-up	0	17
69510	2020-05-28 18:08:19	2020-05-28	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21063	delivery	5	51
69511	2020-05-28 18:08:19	2020-05-28	12	[{"id_menu":3,"count":1}]	15775	delivery	5	17
69512	2020-05-28 18:11:44	2020-05-28	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	25296	delivery	5	34
69513	2020-05-28 18:13:27	2020-05-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	27442	delivery	5	31
69514	2020-05-28 18:13:38	2020-05-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20877	delivery	5	23
69515	2020-05-28 18:13:46	2020-05-28	14	[{"id_menu":2,"count":1}]	27473	delivery	5	19
69516	2020-05-28 18:14:20	2020-05-28	8	[{"id_menu":5,"count":1}]	27429	pick-up	0	8
69517	2020-05-28 18:17:14	2020-05-28	12	[{"id_menu":1,"count":1}]	27434	delivery	5	17
69518	2020-05-28 18:26:51	2020-05-28	9	[{"id_menu":7,"count":1}]	8188	delivery	5	14
69519	2020-05-28 18:27:20	2020-05-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27563	delivery	5	22
69520	2020-05-28 18:35:00	2020-05-28	12	[{"id_menu":1,"count":2}]	27413	delivery	5	17
69521	2020-05-28 18:40:05	2020-05-28	17	[{"id_menu":4,"count":1}]	304	pick-up	0	17
69522	2020-05-28 18:41:28	2020-05-28	14	[{"id_menu":2,"count":1}]	27408	pick-up	0	14
69523	2020-05-28 18:42:42	2020-05-28	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1032	delivery	5	34
69524	2020-05-28 18:42:50	2020-05-28	9	[{"id_menu":6,"count":1}]	27398	delivery	5	14
69525	2020-05-28 18:47:16	2020-05-28	9	[{"id_menu":7,"count":1}]	27319	pick-up	0	9
69526	2020-05-28 18:50:05	2020-05-28	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	24987	delivery	5	34
69527	2020-05-28 18:59:21	2020-05-28	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	27481	delivery	5	43
69528	2020-05-28 18:59:35	2020-05-28	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	378	delivery	5	31
69529	2020-05-28 19:05:30	2020-05-28	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	13906	delivery	5	25
69530	2020-05-28 19:08:23	2020-05-28	9	[{"id_menu":7,"count":1}]	27501	delivery	5	14
69531	2020-05-28 19:08:38	2020-05-28	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	27427	delivery	5	45
69532	2020-05-28 19:08:51	2020-05-28	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25524	delivery	5	35
69533	2020-05-28 19:10:43	2020-05-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	27433	delivery	5	31
69534	2020-05-28 19:11:52	2020-05-28	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	6319	delivery	5	26
69535	2020-05-28 19:12:03	2020-05-28	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":3}]	10519	delivery	5	31
69536	2020-05-28 19:17:55	2020-05-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	19476	pick-up	0	23
69537	2020-05-28 19:22:43	2020-05-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	18850	delivery	5	31
69538	2020-05-28 19:22:53	2020-05-28	14	[{"id_menu":2,"count":1}]	4395	delivery	5	19
69539	2020-05-28 19:24:51	2020-05-28	9	[{"id_menu":7,"count":1}]	27447	delivery	5	14
69540	2020-05-28 19:25:23	2020-05-28	9	[{"id_menu":6,"count":1}]	27450	delivery	5	14
69541	2020-05-28 19:26:41	2020-05-28	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	9051	delivery	5	28
69542	2020-05-28 19:28:04	2020-05-28	8	[{"id_menu":5,"count":1}]	17213	delivery	5	13
69543	2020-05-28 19:29:21	2020-05-28	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	684	pick-up	0	35
69544	2020-05-28 19:30:31	2020-05-28	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	13479	delivery	5	39
69545	2020-05-28 19:31:25	2020-05-28	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	21759	delivery	5	31
69546	2020-05-28 19:35:43	2020-05-28	8	[{"id_menu":5,"count":1}]	21285	delivery	5	13
69547	2020-05-28 19:38:18	2020-05-28	12	[{"id_menu":3,"count":1}]	2926	pick-up	0	12
69548	2020-05-28 19:38:25	2020-05-28	9	[{"id_menu":7,"count":1}]	19987	delivery	5	14
69549	2020-05-28 19:38:51	2020-05-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21600	delivery	5	22
69550	2020-05-28 19:40:34	2020-05-28	9	[{"id_menu":7,"count":1}]	26116	delivery	5	14
69551	2020-05-28 19:40:51	2020-05-28	12	[{"id_menu":1,"count":1}]	12626	delivery	5	17
69552	2020-05-28 19:41:16	2020-05-28	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	27436	delivery	5	30
69553	2020-05-28 19:44:29	2020-05-28	9	[{"id_menu":6,"count":1}]	13257	delivery	5	14
69554	2020-05-28 19:46:31	2020-05-28	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	7431	delivery	5	42
69555	2020-05-28 19:48:03	2020-05-28	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	12935	delivery	5	29
69556	2020-05-28 19:50:46	2020-05-28	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1223	pick-up	0	29
69557	2020-05-28 19:51:02	2020-05-28	8	[{"id_menu":5,"count":1}]	27488	delivery	5	13
69558	2020-05-28 19:52:44	2020-05-28	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3284	delivery	5	45
69559	2020-05-28 19:54:26	2020-05-28	12	[{"id_menu":1,"count":1}]	10121	delivery	5	17
69560	2020-05-28 19:55:26	2020-05-28	12	[{"id_menu":3,"count":1}]	9096	delivery	5	17
69561	2020-05-28 19:58:41	2020-05-28	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	27426	delivery	5	42
69562	2020-05-28 20:00:09	2020-05-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14202	delivery	5	23
69563	2020-05-28 20:02:19	2020-05-28	9	[{"id_menu":7,"count":1}]	5146	delivery	5	14
69564	2020-05-28 20:18:40	2020-05-28	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11618	delivery	5	45
69565	2020-05-28 20:21:33	2020-05-28	17	[{"id_menu":4,"count":1}]	352	pick-up	0	17
69566	2020-05-28 20:25:57	2020-05-28	9	[{"id_menu":6,"count":1}]	17175	delivery	5	14
69567	2020-05-28 20:27:29	2020-05-28	9	[{"id_menu":6,"count":2}]	17941	delivery	5	14
69568	2020-05-28 20:27:41	2020-05-28	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	17823	delivery	5	38
69569	2020-05-28 20:33:01	2020-05-28	9	[{"id_menu":6,"count":1}]	16883	pick-up	0	9
69570	2020-05-28 20:35:02	2020-05-28	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	27418	delivery	5	43
69571	2020-05-28 20:37:41	2020-05-28	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	25228	delivery	5	30
69572	2020-05-28 20:43:57	2020-05-28	8	[{"id_menu":5,"count":1}]	6773	delivery	5	13
69573	2020-05-28 20:46:17	2020-05-28	17	[{"id_menu":4,"count":1}]	11703	delivery	5	22
69574	2020-05-28 20:46:40	2020-05-28	9	[{"id_menu":6,"count":1}]	12886	delivery	5	14
69575	2020-05-28 20:47:20	2020-05-28	9	[{"id_menu":6,"count":1}]	19911	pick-up	0	9
69576	2020-05-28 20:48:49	2020-05-28	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	27504	delivery	5	28
69577	2020-05-28 20:55:15	2020-05-28	9	[{"id_menu":6,"count":1}]	27374	pick-up	0	9
69578	2020-05-28 20:58:04	2020-05-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11857	delivery	5	23
69579	2020-05-28 20:59:19	2020-05-28	9	[{"id_menu":6,"count":1}]	10740	delivery	5	14
69580	2020-05-28 21:10:24	2020-05-28	9	[{"id_menu":6,"count":1}]	19465	delivery	5	14
69581	2020-05-28 21:10:37	2020-05-28	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27403	delivery	5	35
69582	2020-05-28 21:14:22	2020-05-28	17	[{"id_menu":4,"count":1}]	27544	pick-up	0	17
69583	2020-05-28 21:14:36	2020-05-28	9	[{"id_menu":6,"count":1}]	9331	pick-up	0	9
69584	2020-05-28 21:17:41	2020-05-28	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	27482	delivery	5	42
69585	2020-05-28 21:21:32	2020-05-28	9	[{"id_menu":6,"count":3}]	5426	pick-up	0	9
69586	2020-05-28 21:26:09	2020-05-28	14	[{"id_menu":2,"count":1}]	9171	pick-up	0	14
69587	2020-05-28 21:27:11	2020-05-28	12	[{"id_menu":3,"count":1}]	209	delivery	5	17
69588	2020-05-28 21:28:44	2020-05-28	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	27423	pick-up	0	21
69589	2020-05-28 21:30:00	2020-05-28	17	[{"id_menu":4,"count":1}]	19849	delivery	5	22
69590	2020-05-28 21:33:02	2020-05-28	14	[{"id_menu":2,"count":1}]	25786	delivery	5	19
69591	2020-05-28 21:44:56	2020-05-28	14	[{"id_menu":2,"count":1}]	25713	delivery	5	19
69592	2020-05-28 21:45:47	2020-05-28	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3155	pick-up	0	26
69593	2020-05-28 21:49:52	2020-05-28	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1468	pick-up	0	25
69594	2020-05-28 21:54:59	2020-05-28	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3617	pick-up	0	41
69595	2020-05-28 21:55:18	2020-05-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9774	delivery	5	31
69596	2020-05-28 21:57:32	2020-05-28	9	[{"id_menu":7,"count":3}]	27474	delivery	5	14
69597	2020-05-28 21:57:44	2020-05-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27441	delivery	5	23
69598	2020-05-28 21:59:03	2020-05-28	8	[{"id_menu":5,"count":1}]	27518	delivery	5	13
69599	2020-05-28 22:00:26	2020-05-28	14	[{"id_menu":2,"count":1}]	3864	pick-up	0	14
69600	2020-05-28 22:03:04	2020-05-28	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	11921	delivery	5	30
69601	2020-05-28 22:04:38	2020-05-28	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	27507	delivery	5	27
69602	2020-05-28 22:09:47	2020-05-28	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27525	delivery	5	47
69603	2020-05-28 22:09:47	2020-05-28	14	[{"id_menu":2,"count":2}]	3795	delivery	5	19
69604	2020-05-28 22:11:38	2020-05-28	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8801	delivery	5	36
69605	2020-05-28 22:19:03	2020-05-28	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9657	delivery	5	30
69606	2020-05-28 22:28:08	2020-05-28	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	11232	pick-up	0	24
69607	2020-05-28 22:29:58	2020-05-28	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	27490	delivery	5	40
69608	2020-05-28 22:47:23	2020-05-28	14	[{"id_menu":2,"count":1}]	27515	delivery	5	19
69609	2020-05-28 22:51:52	2020-05-28	17	[{"id_menu":4,"count":1}]	9562	pick-up	0	17
69610	2020-05-28 22:53:13	2020-05-28	9	[{"id_menu":7,"count":1}]	10662	delivery	5	14
69611	2020-05-28 22:53:47	2020-05-28	14	[{"id_menu":2,"count":1}]	17983	pick-up	0	14
69612	2020-05-28 22:56:11	2020-05-28	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	17769	delivery	5	30
69613	2020-05-28 22:57:53	2020-05-28	14	[{"id_menu":2,"count":1}]	18133	pick-up	0	14
69614	2020-05-28 22:58:07	2020-05-28	8	[{"id_menu":5,"count":1}]	27500	delivery	5	13
69615	2020-05-28 23:00:41	2020-05-28	17	[{"id_menu":4,"count":1}]	15015	delivery	5	22
69616	2020-05-28 23:01:27	2020-05-28	14	[{"id_menu":2,"count":1}]	24585	pick-up	0	14
69617	2020-05-28 23:03:13	2020-05-28	12	[{"id_menu":1,"count":1}]	13121	delivery	5	17
69618	2020-05-28 23:03:43	2020-05-28	8	[{"id_menu":5,"count":1}]	4287	delivery	5	13
69619	2020-05-28 23:08:35	2020-05-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6080	delivery	5	23
69620	2020-05-28 23:10:47	2020-05-28	17	[{"id_menu":4,"count":1}]	27512	pick-up	0	17
69621	2020-05-28 23:11:47	2020-05-28	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	23318	delivery	5	36
69622	2020-05-28 23:12:07	2020-05-28	9	[{"id_menu":6,"count":1}]	1093	pick-up	0	9
69623	2020-05-28 23:13:20	2020-05-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	24	delivery	5	28
69624	2020-05-28 23:13:25	2020-05-28	8	[{"id_menu":5,"count":1}]	2755	delivery	5	13
69625	2020-05-28 23:14:47	2020-05-28	14	[{"id_menu":2,"count":1}]	8311	delivery	5	19
69626	2020-05-28 23:26:14	2020-05-28	12	[{"id_menu":1,"count":1}]	27406	delivery	5	17
69627	2020-05-28 23:36:12	2020-05-28	9	[{"id_menu":6,"count":1}]	25053	pick-up	0	9
69628	2020-05-28 23:37:34	2020-05-28	9	[{"id_menu":7,"count":1}]	27510	delivery	5	14
69629	2020-05-28 23:40:03	2020-05-28	9	[{"id_menu":7,"count":1}]	18477	delivery	5	14
69630	2020-05-28 23:45:40	2020-05-28	9	[{"id_menu":6,"count":1}]	18304	pick-up	0	9
69631	2020-05-28 23:48:26	2020-05-28	12	[{"id_menu":3,"count":1}]	12685	delivery	5	17
69632	2020-05-28 23:56:24	2020-05-28	9	[{"id_menu":6,"count":1}]	2551	pick-up	0	9
69633	2020-05-29 00:01:05	2020-05-29	9	[{"id_menu":6,"count":1}]	19966	delivery	5	14
69634	2020-05-29 00:03:43	2020-05-29	9	[{"id_menu":7,"count":2}]	27119	delivery	5	14
69635	2020-05-29 00:04:50	2020-05-29	9	[{"id_menu":6,"count":1}]	21359	delivery	5	14
69636	2020-05-29 00:08:49	2020-05-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12098	delivery	5	22
69637	2020-05-29 00:14:37	2020-05-29	14	[{"id_menu":2,"count":1}]	2197	delivery	5	19
69638	2020-05-29 00:22:28	2020-05-29	12	[{"id_menu":1,"count":1}]	18729	pick-up	0	12
69639	2020-05-29 00:25:23	2020-05-29	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14528	pick-up	0	38
69640	2020-05-29 00:33:53	2020-05-29	9	[{"id_menu":6,"count":1}]	27608	delivery	5	14
69641	2020-05-29 00:35:34	2020-05-29	9	[{"id_menu":7,"count":1}]	7154	delivery	5	14
69642	2020-05-29 00:38:48	2020-05-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	22385	delivery	5	26
69643	2020-05-29 00:39:55	2020-05-29	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	26152	delivery	5	34
69644	2020-05-29 00:40:24	2020-05-29	9	[{"id_menu":7,"count":1}]	3600	pick-up	0	9
69645	2020-05-29 00:40:31	2020-05-29	9	[{"id_menu":6,"count":1}]	9193	pick-up	0	9
69646	2020-05-29 00:45:23	2020-05-29	9	[{"id_menu":7,"count":1}]	8378	delivery	5	14
69647	2020-05-29 00:47:16	2020-05-29	14	[{"id_menu":2,"count":1}]	176	pick-up	0	14
69648	2020-05-29 00:52:02	2020-05-29	17	[{"id_menu":4,"count":1}]	3363	pick-up	0	17
69649	2020-05-29 00:53:26	2020-05-29	8	[{"id_menu":5,"count":1}]	10618	delivery	5	13
69650	2020-05-29 00:57:21	2020-05-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	12675	pick-up	0	21
69651	2020-05-29 01:01:34	2020-05-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	799	pick-up	0	26
69652	2020-05-29 01:06:11	2020-05-29	9	[{"id_menu":7,"count":1}]	27572	delivery	5	14
69653	2020-05-29 01:08:25	2020-05-29	12	[{"id_menu":3,"count":1}]	24870	delivery	5	17
69654	2020-05-29 01:12:21	2020-05-29	9	[{"id_menu":7,"count":1}]	6861	delivery	5	14
69655	2020-05-29 01:12:49	2020-05-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	27716	delivery	5	36
69656	2020-05-29 01:18:23	2020-05-29	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	15230	delivery	5	28
69657	2020-05-29 01:23:11	2020-05-29	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	27705	delivery	5	39
69658	2020-05-29 01:23:21	2020-05-29	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	17610	delivery	5	34
69659	2020-05-29 01:26:39	2020-05-29	12	[{"id_menu":1,"count":1}]	27586	delivery	5	17
69660	2020-05-29 01:27:11	2020-05-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	27626	delivery	5	31
69661	2020-05-29 01:31:27	2020-05-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	21372	delivery	5	28
69662	2020-05-29 01:36:44	2020-05-29	17	[{"id_menu":4,"count":1}]	19551	pick-up	0	17
69663	2020-05-29 01:39:38	2020-05-29	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	26361	delivery	5	36
69664	2020-05-29 01:40:32	2020-05-29	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	5156	delivery	5	44
69665	2020-05-29 01:47:26	2020-05-29	8	[{"id_menu":5,"count":1}]	5365	delivery	5	13
69666	2020-05-29 01:53:40	2020-05-29	8	[{"id_menu":5,"count":1}]	27675	pick-up	0	8
69667	2020-05-29 01:58:15	2020-05-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27682	delivery	5	23
69668	2020-05-29 02:03:02	2020-05-29	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19229	delivery	5	39
69669	2020-05-29 02:16:24	2020-05-29	9	[{"id_menu":6,"count":1}]	27698	delivery	5	14
69670	2020-05-29 02:18:36	2020-05-29	17	[{"id_menu":4,"count":1}]	27697	delivery	5	22
69671	2020-05-29 02:20:04	2020-05-29	9	[{"id_menu":7,"count":1}]	9564	delivery	5	14
69672	2020-05-29 02:22:47	2020-05-29	17	[{"id_menu":4,"count":1}]	11170	delivery	5	22
69673	2020-05-29 02:24:42	2020-05-29	55	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2338	delivery	5	60
69674	2020-05-29 02:26:53	2020-05-29	14	[{"id_menu":2,"count":1}]	4737	delivery	5	19
69675	2020-05-29 02:28:57	2020-05-29	8	[{"id_menu":5,"count":1}]	27754	delivery	5	13
69676	2020-05-29 02:41:41	2020-05-29	14	[{"id_menu":2,"count":1}]	27746	pick-up	0	14
69677	2020-05-29 02:47:21	2020-05-29	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	27638	delivery	5	31
69678	2020-05-29 02:48:38	2020-05-29	9	[{"id_menu":7,"count":3}]	27653	delivery	5	14
69679	2020-05-29 02:48:51	2020-05-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	3382	pick-up	0	21
69680	2020-05-29 02:48:56	2020-05-29	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	27656	delivery	5	45
69681	2020-05-29 02:53:27	2020-05-29	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2862	pick-up	0	35
69682	2020-05-29 02:53:43	2020-05-29	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	26247	delivery	5	34
69683	2020-05-29 02:56:20	2020-05-29	9	[{"id_menu":6,"count":1}]	20424	delivery	5	14
69684	2020-05-29 03:00:22	2020-05-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4488	pick-up	0	26
69685	2020-05-29 03:02:04	2020-05-29	9	[{"id_menu":7,"count":1}]	22182	pick-up	0	9
69686	2020-05-29 03:04:41	2020-05-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	22287	delivery	5	31
69687	2020-05-29 03:10:16	2020-05-29	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	482	delivery	5	31
69688	2020-05-29 03:10:26	2020-05-29	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1901	delivery	5	34
69689	2020-05-29 03:11:24	2020-05-29	14	[{"id_menu":2,"count":1}]	27641	delivery	5	19
69690	2020-05-29 03:13:16	2020-05-29	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	27731	delivery	5	31
69691	2020-05-29 03:13:16	2020-05-29	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9184	delivery	5	30
69692	2020-05-29 03:17:38	2020-05-29	9	[{"id_menu":7,"count":1}]	23266	pick-up	0	9
69693	2020-05-29 03:19:14	2020-05-29	17	[{"id_menu":4,"count":1}]	12912	pick-up	0	17
69694	2020-05-29 03:22:47	2020-05-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27619	delivery	5	23
69695	2020-05-29 03:26:30	2020-05-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	27579	delivery	5	22
69696	2020-05-29 03:29:05	2020-05-29	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	9478	delivery	5	35
69697	2020-05-29 03:29:49	2020-05-29	9	[{"id_menu":6,"count":2}]	584	delivery	5	14
69698	2020-05-29 03:37:15	2020-05-29	12	[{"id_menu":3,"count":1}]	22961	delivery	5	17
69699	2020-05-29 03:41:47	2020-05-29	14	[{"id_menu":2,"count":1}]	11676	delivery	5	19
69700	2020-05-29 03:46:48	2020-05-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19502	delivery	5	22
69701	2020-05-29 03:52:24	2020-05-29	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	27637	pick-up	0	22
69702	2020-05-29 04:13:06	2020-05-29	8	[{"id_menu":5,"count":1}]	9761	delivery	5	13
69703	2020-05-29 04:15:49	2020-05-29	12	[{"id_menu":3,"count":1}]	27674	delivery	5	17
69704	2020-05-29 04:18:13	2020-05-29	8	[{"id_menu":5,"count":1}]	27573	delivery	5	13
69705	2020-05-29 04:19:09	2020-05-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27737	pick-up	0	18
69706	2020-05-29 04:20:09	2020-05-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27665	delivery	5	36
69707	2020-05-29 04:26:49	2020-05-29	14	[{"id_menu":2,"count":1}]	5648	pick-up	0	14
69708	2020-05-29 04:33:36	2020-05-29	17	[{"id_menu":4,"count":1}]	27711	delivery	5	22
69709	2020-05-29 04:36:49	2020-05-29	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	15350	delivery	5	30
69710	2020-05-29 04:38:17	2020-05-29	9	[{"id_menu":6,"count":1}]	20906	pick-up	0	9
69711	2020-05-29 04:40:12	2020-05-29	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13042	delivery	5	37
69712	2020-05-29 04:42:45	2020-05-29	9	[{"id_menu":6,"count":1}]	4648	pick-up	0	9
69713	2020-05-29 04:55:54	2020-05-29	9	[{"id_menu":6,"count":1}]	27669	delivery	5	14
69714	2020-05-29 04:59:16	2020-05-29	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	12848	delivery	5	30
69715	2020-05-29 05:00:14	2020-05-29	9	[{"id_menu":6,"count":1}]	27759	delivery	5	14
69716	2020-05-29 05:01:28	2020-05-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	27676	delivery	5	31
69717	2020-05-29 05:02:27	2020-05-29	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":2}]	12993	delivery	5	22
69718	2020-05-29 05:03:25	2020-05-29	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	27612	pick-up	0	29
69719	2020-05-29 05:13:08	2020-05-29	9	[{"id_menu":6,"count":1}]	21983	delivery	5	14
69720	2020-05-29 05:18:29	2020-05-29	8	[{"id_menu":5,"count":1}]	27713	delivery	5	13
69721	2020-05-29 05:21:01	2020-05-29	14	[{"id_menu":2,"count":1}]	12157	delivery	5	19
69722	2020-05-29 05:23:55	2020-05-29	9	[{"id_menu":7,"count":1}]	26255	pick-up	0	9
69723	2020-05-29 05:36:01	2020-05-29	9	[{"id_menu":6,"count":1}]	27764	delivery	5	14
69724	2020-05-29 05:38:40	2020-05-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	23022	delivery	5	31
69725	2020-05-29 05:46:36	2020-05-29	8	[{"id_menu":5,"count":1}]	26868	delivery	5	13
69726	2020-05-29 05:48:09	2020-05-29	14	[{"id_menu":2,"count":1}]	26867	delivery	5	19
69727	2020-05-29 05:50:27	2020-05-29	14	[{"id_menu":2,"count":1}]	27695	delivery	5	19
69728	2020-05-29 05:52:33	2020-05-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7348	pick-up	0	26
69729	2020-05-29 05:55:42	2020-05-29	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	27724	delivery	5	23
69730	2020-05-29 05:56:54	2020-05-29	8	[{"id_menu":5,"count":1}]	27707	delivery	5	13
69731	2020-05-29 05:57:22	2020-05-29	12	[{"id_menu":1,"count":1}]	27681	delivery	5	17
69732	2020-05-29 06:10:45	2020-05-29	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	7164	delivery	5	39
69733	2020-05-29 06:11:29	2020-05-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	25675	delivery	5	36
69734	2020-05-29 06:11:59	2020-05-29	12	[{"id_menu":1,"count":1}]	27588	pick-up	0	12
69735	2020-05-29 06:13:08	2020-05-29	14	[{"id_menu":2,"count":1}]	4411	pick-up	0	14
69736	2020-05-29 06:16:47	2020-05-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	27603	delivery	5	22
69737	2020-05-29 06:24:01	2020-05-29	17	[{"id_menu":4,"count":1}]	2311	delivery	5	22
69738	2020-05-29 06:31:14	2020-05-29	9	[{"id_menu":6,"count":1}]	27722	delivery	5	14
69739	2020-05-29 06:35:41	2020-05-29	9	[{"id_menu":7,"count":1}]	25752	delivery	5	14
69740	2020-05-29 06:36:26	2020-05-29	9	[{"id_menu":7,"count":1}]	3157	delivery	5	14
69741	2020-05-29 06:41:51	2020-05-29	17	[{"id_menu":4,"count":1}]	24453	delivery	5	22
69742	2020-05-29 06:41:57	2020-05-29	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	27749	delivery	5	34
69743	2020-05-29 06:43:51	2020-05-29	12	[{"id_menu":1,"count":1}]	21267	delivery	5	17
69744	2020-05-29 06:45:16	2020-05-29	12	[{"id_menu":3,"count":1}]	3724	pick-up	0	12
69745	2020-05-29 07:00:05	2020-05-29	9	[{"id_menu":6,"count":1}]	27648	delivery	5	14
69746	2020-05-29 07:01:18	2020-05-29	9	[{"id_menu":6,"count":2}]	6661	pick-up	0	9
69747	2020-05-29 07:04:13	2020-05-29	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	23535	delivery	5	39
69748	2020-05-29 07:10:19	2020-05-29	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	1988	pick-up	0	18
69749	2020-05-29 07:12:27	2020-05-29	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7035	delivery	5	40
69750	2020-05-29 07:13:17	2020-05-29	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	446	delivery	5	40
69751	2020-05-29 07:14:20	2020-05-29	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17211	delivery	5	54
69752	2020-05-29 07:16:36	2020-05-29	12	[{"id_menu":3,"count":1}]	27614	delivery	5	17
69753	2020-05-29 07:17:03	2020-05-29	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27709	delivery	5	34
69754	2020-05-29 07:18:51	2020-05-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	8402	delivery	5	27
69755	2020-05-29 07:18:58	2020-05-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":3}]	26959	delivery	5	26
69756	2020-05-29 07:24:51	2020-05-29	17	[{"id_menu":4,"count":1}]	2358	delivery	5	22
69757	2020-05-29 07:35:59	2020-05-29	12	[{"id_menu":3,"count":1}]	27658	delivery	5	17
69758	2020-05-29 07:46:22	2020-05-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3454	delivery	5	23
69759	2020-05-29 07:47:34	2020-05-29	14	[{"id_menu":2,"count":1}]	27742	delivery	5	19
69760	2020-05-29 07:48:30	2020-05-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	24135	delivery	5	31
69761	2020-05-29 07:52:16	2020-05-29	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	27636	delivery	5	29
69762	2020-05-29 07:54:05	2020-05-29	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	27738	delivery	5	22
69763	2020-05-29 08:06:56	2020-05-29	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	21607	pick-up	0	29
69764	2020-05-29 08:10:17	2020-05-29	8	[{"id_menu":5,"count":1}]	23229	delivery	5	13
69765	2020-05-29 08:11:01	2020-05-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	27690	delivery	5	22
69766	2020-05-29 08:12:54	2020-05-29	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	11215	delivery	5	40
69767	2020-05-29 08:21:12	2020-05-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	27652	delivery	5	22
69768	2020-05-29 08:29:46	2020-05-29	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	745	delivery	5	36
69769	2020-05-29 08:30:28	2020-05-29	12	[{"id_menu":3,"count":1}]	1240	pick-up	0	12
69770	2020-05-29 08:34:24	2020-05-29	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27721	delivery	5	51
69771	2020-05-29 08:36:14	2020-05-29	9	[{"id_menu":6,"count":1}]	27664	delivery	5	14
69772	2020-05-29 08:38:34	2020-05-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	27732	delivery	5	31
69773	2020-05-29 08:39:01	2020-05-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	13880	delivery	5	28
69774	2020-05-29 08:39:57	2020-05-29	12	[{"id_menu":3,"count":1}]	27667	delivery	5	17
69775	2020-05-29 08:48:01	2020-05-29	9	[{"id_menu":6,"count":1}]	21910	pick-up	0	9
69776	2020-05-29 08:50:09	2020-05-29	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	27627	delivery	5	25
69777	2020-05-29 08:50:16	2020-05-29	9	[{"id_menu":7,"count":1}]	17226	delivery	5	14
69778	2020-05-29 08:50:40	2020-05-29	14	[{"id_menu":2,"count":1}]	16794	delivery	5	19
69779	2020-05-29 09:07:48	2020-05-29	9	[{"id_menu":7,"count":1}]	27683	delivery	5	14
69780	2020-05-29 09:11:28	2020-05-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2067	delivery	5	23
69781	2020-05-29 09:13:51	2020-05-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	27585	pick-up	0	26
69782	2020-05-29 09:14:34	2020-05-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	20226	delivery	5	26
69783	2020-05-29 09:14:36	2020-05-29	14	[{"id_menu":2,"count":1}]	2953	pick-up	0	14
69784	2020-05-29 09:14:58	2020-05-29	12	[{"id_menu":1,"count":1}]	7032	pick-up	0	12
69785	2020-05-29 09:18:49	2020-05-29	9	[{"id_menu":6,"count":1}]	1012	pick-up	0	9
69786	2020-05-29 09:24:02	2020-05-29	14	[{"id_menu":2,"count":1}]	21121	pick-up	0	14
69787	2020-05-29 09:24:32	2020-05-29	8	[{"id_menu":5,"count":1}]	27570	delivery	5	13
69788	2020-05-29 09:24:36	2020-05-29	9	[{"id_menu":6,"count":1}]	27704	delivery	5	14
69789	2020-05-29 09:25:42	2020-05-29	12	[{"id_menu":3,"count":1}]	14984	delivery	5	17
69790	2020-05-29 09:36:19	2020-05-29	12	[{"id_menu":1,"count":1}]	10590	delivery	5	17
69791	2020-05-29 09:40:07	2020-05-29	14	[{"id_menu":2,"count":1}]	18923	delivery	5	19
69792	2020-05-29 09:40:58	2020-05-29	9	[{"id_menu":7,"count":1}]	1504	delivery	5	14
69793	2020-05-29 09:43:42	2020-05-29	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	11756	delivery	5	25
69794	2020-05-29 09:54:19	2020-05-29	14	[{"id_menu":2,"count":1}]	27662	delivery	5	19
69795	2020-05-29 09:54:49	2020-05-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5141	delivery	5	31
69796	2020-05-29 10:00:05	2020-05-29	9	[{"id_menu":6,"count":1}]	27598	delivery	5	14
69797	2020-05-29 10:06:12	2020-05-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	27672	pick-up	0	23
69798	2020-05-29 10:07:12	2020-05-29	8	[{"id_menu":5,"count":1}]	27033	delivery	5	13
69799	2020-05-29 10:08:56	2020-05-29	17	[{"id_menu":4,"count":1}]	18350	delivery	5	22
69800	2020-05-29 10:16:11	2020-05-29	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	27625	delivery	5	29
69801	2020-05-29 10:18:49	2020-05-29	9	[{"id_menu":7,"count":1}]	27646	delivery	5	14
69802	2020-05-29 10:19:32	2020-05-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	7859	delivery	5	31
69803	2020-05-29 10:22:32	2020-05-29	9	[{"id_menu":7,"count":1}]	2009	pick-up	0	9
69804	2020-05-29 10:31:54	2020-05-29	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	5077	delivery	5	25
69805	2020-05-29 10:33:32	2020-05-29	14	[{"id_menu":2,"count":1}]	27680	delivery	5	19
69806	2020-05-29 10:44:30	2020-05-29	9	[{"id_menu":6,"count":1}]	22767	delivery	5	14
69807	2020-05-29 10:44:58	2020-05-29	12	[{"id_menu":3,"count":1}]	27761	delivery	5	17
69808	2020-05-29 10:48:09	2020-05-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27762	delivery	5	36
69809	2020-05-29 10:51:39	2020-05-29	17	[{"id_menu":4,"count":1}]	22443	delivery	5	22
69810	2020-05-29 10:56:16	2020-05-29	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	26436	delivery	5	23
69811	2020-05-29 10:57:46	2020-05-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	5959	delivery	5	27
69812	2020-05-29 11:02:29	2020-05-29	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27618	delivery	5	48
69813	2020-05-29 11:09:40	2020-05-29	9	[{"id_menu":7,"count":1}]	11779	pick-up	0	9
69814	2020-05-29 11:12:08	2020-05-29	12	[{"id_menu":3,"count":1}]	24105	pick-up	0	12
69815	2020-05-29 11:14:21	2020-05-29	14	[{"id_menu":2,"count":1}]	841	pick-up	0	14
69816	2020-05-29 11:15:38	2020-05-29	8	[{"id_menu":5,"count":1}]	7423	pick-up	0	8
69817	2020-05-29 11:19:11	2020-05-29	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27629	delivery	5	43
69818	2020-05-29 11:23:53	2020-05-29	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	23268	delivery	5	31
69819	2020-05-29 11:24:33	2020-05-29	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11389	delivery	5	55
69820	2020-05-29 11:25:55	2020-05-29	12	[{"id_menu":3,"count":1}]	9277	delivery	5	17
69821	2020-05-29 11:27:37	2020-05-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27663	delivery	5	23
69822	2020-05-29 11:32:25	2020-05-29	14	[{"id_menu":2,"count":1}]	27599	delivery	5	19
69823	2020-05-29 11:34:05	2020-05-29	17	[{"id_menu":4,"count":1}]	21502	pick-up	0	17
69824	2020-05-29 11:35:43	2020-05-29	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	27623	delivery	5	39
69825	2020-05-29 11:36:37	2020-05-29	12	[{"id_menu":3,"count":1}]	27758	delivery	5	17
69826	2020-05-29 11:39:39	2020-05-29	12	[{"id_menu":1,"count":1}]	7727	delivery	5	17
69827	2020-05-29 11:42:38	2020-05-29	17	[{"id_menu":4,"count":1}]	19744	delivery	5	22
69828	2020-05-29 11:42:43	2020-05-29	14	[{"id_menu":2,"count":1}]	1684	pick-up	0	14
69829	2020-05-29 11:43:00	2020-05-29	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	15534	delivery	5	40
69830	2020-05-29 11:43:08	2020-05-29	12	[{"id_menu":1,"count":1}]	527	pick-up	0	12
69831	2020-05-29 11:46:41	2020-05-29	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	27320	delivery	5	34
69832	2020-05-29 11:50:40	2020-05-29	9	[{"id_menu":7,"count":1}]	6733	pick-up	0	9
69833	2020-05-29 11:51:18	2020-05-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	27620	delivery	5	22
69834	2020-05-29 11:51:19	2020-05-29	8	[{"id_menu":5,"count":1}]	16829	pick-up	0	8
69835	2020-05-29 11:53:02	2020-05-29	8	[{"id_menu":5,"count":1}]	5578	delivery	5	13
69836	2020-05-29 11:56:41	2020-05-29	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	7253	delivery	5	31
69837	2020-05-29 11:59:08	2020-05-29	14	[{"id_menu":2,"count":1}]	519	pick-up	0	14
69838	2020-05-29 12:01:35	2020-05-29	9	[{"id_menu":6,"count":1}]	24171	delivery	5	14
69839	2020-05-29 12:03:49	2020-05-29	9	[{"id_menu":6,"count":1}]	27743	delivery	5	14
69840	2020-05-29 12:06:24	2020-05-29	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	3459	pick-up	0	29
69841	2020-05-29 12:07:00	2020-05-29	8	[{"id_menu":5,"count":1}]	27728	pick-up	0	8
69842	2020-05-29 12:09:12	2020-05-29	12	[{"id_menu":1,"count":1}]	27610	delivery	5	17
69843	2020-05-29 12:10:17	2020-05-29	9	[{"id_menu":6,"count":1}]	27661	pick-up	0	9
69844	2020-05-29 12:14:47	2020-05-29	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	6609	pick-up	0	26
69845	2020-05-29 12:17:49	2020-05-29	14	[{"id_menu":2,"count":1}]	27635	delivery	5	19
69846	2020-05-29 12:20:32	2020-05-29	12	[{"id_menu":1,"count":1}]	27700	pick-up	0	12
69847	2020-05-29 12:27:39	2020-05-29	14	[{"id_menu":2,"count":1}]	27602	delivery	5	19
69848	2020-05-29 12:29:28	2020-05-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	25425	delivery	5	28
69849	2020-05-29 12:31:26	2020-05-29	12	[{"id_menu":1,"count":1}]	27701	delivery	5	17
69850	2020-05-29 12:35:20	2020-05-29	8	[{"id_menu":5,"count":1}]	27729	pick-up	0	8
69851	2020-05-29 12:37:10	2020-05-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	27651	delivery	5	22
69852	2020-05-29 12:43:06	2020-05-29	12	[{"id_menu":3,"count":1}]	6944	pick-up	0	12
69853	2020-05-29 12:44:36	2020-05-29	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14354	delivery	5	40
69854	2020-05-29 12:45:40	2020-05-29	9	[{"id_menu":7,"count":1}]	19268	pick-up	0	9
69855	2020-05-29 12:48:09	2020-05-29	9	[{"id_menu":7,"count":1}]	3494	pick-up	0	9
69856	2020-05-29 12:48:30	2020-05-29	12	[{"id_menu":1,"count":1}]	8529	delivery	5	17
69857	2020-05-29 12:51:01	2020-05-29	12	[{"id_menu":3,"count":1}]	8794	delivery	5	17
69858	2020-05-29 12:58:21	2020-05-29	14	[{"id_menu":2,"count":1}]	27745	delivery	5	19
69859	2020-05-29 13:02:16	2020-05-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12132	delivery	5	22
69860	2020-05-29 13:03:38	2020-05-29	9	[{"id_menu":6,"count":1}]	25282	pick-up	0	9
69861	2020-05-29 13:04:04	2020-05-29	9	[{"id_menu":6,"count":1}]	27589	pick-up	0	9
69862	2020-05-29 13:10:43	2020-05-29	12	[{"id_menu":3,"count":1}]	15187	pick-up	0	12
69863	2020-05-29 13:13:32	2020-05-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27581	delivery	5	23
69864	2020-05-29 13:13:43	2020-05-29	9	[{"id_menu":6,"count":1}]	691	pick-up	0	9
69865	2020-05-29 13:18:38	2020-05-29	9	[{"id_menu":7,"count":1}]	11231	delivery	5	14
69866	2020-05-29 13:23:12	2020-05-29	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	10393	delivery	5	43
69867	2020-05-29 13:25:15	2020-05-29	12	[{"id_menu":3,"count":1}]	19516	delivery	5	17
69868	2020-05-29 13:27:04	2020-05-29	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	4644	delivery	5	26
69869	2020-05-29 13:29:29	2020-05-29	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	7963	pick-up	0	29
69870	2020-05-29 13:32:46	2020-05-29	17	[{"id_menu":4,"count":1}]	27590	delivery	5	22
69871	2020-05-29 13:33:33	2020-05-29	14	[{"id_menu":2,"count":1}]	1164	pick-up	0	14
69872	2020-05-29 13:35:55	2020-05-29	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	815	pick-up	0	26
69873	2020-05-29 13:37:13	2020-05-29	12	[{"id_menu":1,"count":1}]	27666	pick-up	0	12
69874	2020-05-29 13:38:54	2020-05-29	8	[{"id_menu":5,"count":1}]	9703	delivery	5	13
69875	2020-05-29 13:43:02	2020-05-29	9	[{"id_menu":6,"count":1}]	27212	delivery	5	14
69876	2020-05-29 13:47:59	2020-05-29	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	6552	delivery	5	26
69877	2020-05-29 13:48:59	2020-05-29	17	[{"id_menu":4,"count":1}]	27660	delivery	5	22
69878	2020-05-29 13:51:04	2020-05-29	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	27689	delivery	5	34
69879	2020-05-29 13:52:36	2020-05-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	27649	delivery	5	31
69880	2020-05-29 13:53:22	2020-05-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4206	pick-up	0	23
69881	2020-05-29 13:53:29	2020-05-29	14	[{"id_menu":2,"count":1}]	27655	pick-up	0	14
69882	2020-05-29 13:57:17	2020-05-29	17	[{"id_menu":4,"count":1}]	13120	pick-up	0	17
69883	2020-05-29 13:58:31	2020-05-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27763	delivery	5	22
69884	2020-05-29 13:59:39	2020-05-29	14	[{"id_menu":2,"count":1}]	17700	pick-up	0	14
69885	2020-05-29 14:04:35	2020-05-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27633	delivery	5	22
69886	2020-05-29 14:07:44	2020-05-29	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	27318	pick-up	0	26
69887	2020-05-29 14:08:54	2020-05-29	12	[{"id_menu":3,"count":1}]	437	delivery	5	17
69888	2020-05-29 14:09:10	2020-05-29	8	[{"id_menu":5,"count":1}]	20746	delivery	5	13
69889	2020-05-29 14:18:22	2020-05-29	8	[{"id_menu":5,"count":1}]	24944	delivery	5	13
69890	2020-05-29 14:18:34	2020-05-29	9	[{"id_menu":7,"count":1}]	27696	delivery	5	14
69891	2020-05-29 14:19:15	2020-05-29	9	[{"id_menu":6,"count":1}]	27725	delivery	5	14
69892	2020-05-29 14:26:50	2020-05-29	9	[{"id_menu":6,"count":1}]	4527	delivery	5	14
69893	2020-05-29 14:26:59	2020-05-29	9	[{"id_menu":7,"count":1}]	24239	delivery	5	14
69894	2020-05-29 14:28:54	2020-05-29	9	[{"id_menu":7,"count":1}]	6894	delivery	5	14
69895	2020-05-29 14:42:08	2020-05-29	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	188	pick-up	0	21
69896	2020-05-29 14:44:47	2020-05-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13213	pick-up	0	26
69897	2020-05-29 14:45:59	2020-05-29	14	[{"id_menu":2,"count":2}]	24325	delivery	5	19
69898	2020-05-29 14:47:19	2020-05-29	8	[{"id_menu":5,"count":1}]	27657	delivery	5	13
69899	2020-05-29 14:47:33	2020-05-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	27765	pick-up	0	22
69900	2020-05-29 14:51:01	2020-05-29	14	[{"id_menu":2,"count":1}]	14867	delivery	5	19
69901	2020-05-29 14:57:54	2020-05-29	8	[{"id_menu":5,"count":1}]	21770	delivery	5	13
69902	2020-05-29 14:58:04	2020-05-29	17	[{"id_menu":4,"count":1}]	27671	delivery	5	22
69903	2020-05-29 15:01:40	2020-05-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17571	delivery	5	22
69904	2020-05-29 15:09:00	2020-05-29	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	15013	delivery	5	31
69905	2020-05-29 15:12:04	2020-05-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27622	delivery	5	22
69906	2020-05-29 15:21:29	2020-05-29	9	[{"id_menu":6,"count":1}]	11277	delivery	5	14
69907	2020-05-29 15:27:10	2020-05-29	9	[{"id_menu":7,"count":1}]	3268	pick-up	0	9
69908	2020-05-29 15:27:43	2020-05-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	27605	delivery	5	28
69909	2020-05-29 15:30:58	2020-05-29	14	[{"id_menu":2,"count":1}]	27647	delivery	5	19
69910	2020-05-29 15:32:30	2020-05-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	24653	delivery	5	26
69911	2020-05-29 15:35:35	2020-05-29	12	[{"id_menu":3,"count":1}]	16749	delivery	5	17
69912	2020-05-29 15:37:59	2020-05-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27583	delivery	5	23
69913	2020-05-29 15:42:01	2020-05-29	8	[{"id_menu":5,"count":1}]	27668	delivery	5	13
69914	2020-05-29 15:42:41	2020-05-29	9	[{"id_menu":6,"count":1}]	12884	delivery	5	14
69915	2020-05-29 15:49:39	2020-05-29	8	[{"id_menu":5,"count":1}]	27677	delivery	5	13
69916	2020-05-29 15:51:19	2020-05-29	8	[{"id_menu":5,"count":1}]	13500	delivery	5	13
69917	2020-05-29 15:53:29	2020-05-29	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	23924	delivery	5	34
69918	2020-05-29 15:53:46	2020-05-29	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	27719	delivery	5	40
69919	2020-05-29 16:00:21	2020-05-29	12	[{"id_menu":1,"count":1}]	20865	delivery	5	17
69920	2020-05-29 16:07:46	2020-05-29	17	[{"id_menu":4,"count":1}]	21651	delivery	5	22
69921	2020-05-29 16:11:54	2020-05-29	12	[{"id_menu":3,"count":1}]	23561	pick-up	0	12
69922	2020-05-29 16:12:00	2020-05-29	12	[{"id_menu":3,"count":1}]	5642	pick-up	0	12
69923	2020-05-29 16:13:05	2020-05-29	9	[{"id_menu":7,"count":1}]	27587	delivery	5	14
69924	2020-05-29 16:18:41	2020-05-29	12	[{"id_menu":1,"count":1}]	13320	pick-up	0	12
69925	2020-05-29 16:27:34	2020-05-29	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27706	delivery	5	34
69926	2020-05-29 16:42:00	2020-05-29	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16957	pick-up	0	40
69927	2020-05-29 16:42:48	2020-05-29	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":2}]	20396	delivery	5	26
69928	2020-05-29 16:42:54	2020-05-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	26072	delivery	5	22
69929	2020-05-29 16:43:11	2020-05-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	10937	delivery	5	27
69930	2020-05-29 16:51:59	2020-05-29	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	1079	delivery	5	34
69931	2020-05-29 16:55:14	2020-05-29	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	10499	delivery	5	48
69932	2020-05-29 16:55:20	2020-05-29	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	12552	pick-up	0	33
69933	2020-05-29 16:56:33	2020-05-29	12	[{"id_menu":1,"count":1}]	27628	delivery	5	17
69934	2020-05-29 17:07:16	2020-05-29	14	[{"id_menu":2,"count":1}]	24508	delivery	5	19
69935	2020-05-29 17:10:20	2020-05-29	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	20573	delivery	5	34
69936	2020-05-29 17:12:46	2020-05-29	14	[{"id_menu":2,"count":1}]	17807	pick-up	0	14
69937	2020-05-29 17:13:12	2020-05-29	9	[{"id_menu":6,"count":1}]	10200	pick-up	0	9
69938	2020-05-29 17:18:37	2020-05-29	12	[{"id_menu":3,"count":1}]	27760	delivery	5	17
69939	2020-05-29 17:22:21	2020-05-29	17	[{"id_menu":4,"count":1}]	73	pick-up	0	17
69940	2020-05-29 17:23:19	2020-05-29	9	[{"id_menu":7,"count":1}]	27616	delivery	5	14
69941	2020-05-29 17:24:02	2020-05-29	8	[{"id_menu":5,"count":1}]	27750	delivery	5	13
69942	2020-05-29 17:29:10	2020-05-29	12	[{"id_menu":1,"count":1}]	25319	delivery	5	17
69943	2020-05-29 17:31:31	2020-05-29	8	[{"id_menu":5,"count":2}]	6435	delivery	5	13
69944	2020-05-29 17:33:50	2020-05-29	12	[{"id_menu":1,"count":2}]	557	pick-up	0	12
69945	2020-05-29 17:38:18	2020-05-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	13767	pick-up	0	23
69946	2020-05-29 17:41:04	2020-05-29	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18692	delivery	5	40
69947	2020-05-29 17:41:06	2020-05-29	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	16679	delivery	5	25
69948	2020-05-29 17:41:56	2020-05-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	27621	delivery	5	28
69949	2020-05-29 17:42:52	2020-05-29	9	[{"id_menu":6,"count":1}]	27753	delivery	5	14
69950	2020-05-29 17:46:07	2020-05-29	9	[{"id_menu":6,"count":1}]	12423	pick-up	0	9
69951	2020-05-29 17:47:37	2020-05-29	9	[{"id_menu":6,"count":1}]	12757	delivery	5	14
69952	2020-05-29 17:48:56	2020-05-29	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7444	delivery	5	53
69953	2020-05-29 17:51:09	2020-05-29	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	6273	delivery	5	25
69954	2020-05-29 17:54:45	2020-05-29	12	[{"id_menu":1,"count":1}]	27575	delivery	5	17
69955	2020-05-29 17:58:40	2020-05-29	14	[{"id_menu":2,"count":1}]	3575	delivery	5	19
69956	2020-05-29 17:59:25	2020-05-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27702	delivery	5	23
69957	2020-05-29 17:59:44	2020-05-29	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	23904	delivery	5	26
69958	2020-05-29 18:00:17	2020-05-29	8	[{"id_menu":5,"count":1}]	389	pick-up	0	8
69959	2020-05-29 18:02:26	2020-05-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	27643	delivery	5	23
69960	2020-05-29 18:03:09	2020-05-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	26911	pick-up	0	17
69961	2020-05-29 18:09:01	2020-05-29	17	[{"id_menu":4,"count":1}]	24534	delivery	5	22
69962	2020-05-29 18:11:19	2020-05-29	17	[{"id_menu":4,"count":1}]	889	delivery	5	22
69963	2020-05-29 18:21:01	2020-05-29	8	[{"id_menu":5,"count":1}]	27644	delivery	5	13
69964	2020-05-29 18:22:43	2020-05-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16914	delivery	5	22
69965	2020-05-29 18:23:27	2020-05-29	14	[{"id_menu":2,"count":1}]	26536	delivery	5	19
69966	2020-05-29 18:23:36	2020-05-29	14	[{"id_menu":2,"count":1}]	6704	pick-up	0	14
69967	2020-05-29 18:23:44	2020-05-29	17	[{"id_menu":4,"count":2}]	27606	delivery	5	22
69968	2020-05-29 18:26:39	2020-05-29	12	[{"id_menu":3,"count":1}]	27693	delivery	5	17
69969	2020-05-29 18:32:46	2020-05-29	8	[{"id_menu":5,"count":1}]	19952	delivery	5	13
69970	2020-05-29 18:35:14	2020-05-29	14	[{"id_menu":2,"count":1}]	21521	delivery	5	19
69971	2020-05-29 18:37:31	2020-05-29	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":2}]	24500	delivery	5	28
69972	2020-05-29 18:39:14	2020-05-29	9	[{"id_menu":7,"count":1}]	27714	delivery	5	14
69973	2020-05-29 18:41:32	2020-05-29	12	[{"id_menu":3,"count":1}]	13185	delivery	5	17
69974	2020-05-29 18:42:17	2020-05-29	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18103	delivery	5	51
69975	2020-05-29 18:48:13	2020-05-29	12	[{"id_menu":3,"count":1}]	2119	delivery	5	17
69976	2020-05-29 18:54:55	2020-05-29	9	[{"id_menu":7,"count":1}]	17209	pick-up	0	9
69977	2020-05-29 18:55:21	2020-05-29	9	[{"id_menu":6,"count":1}]	4078	delivery	5	14
69978	2020-05-29 18:55:33	2020-05-29	8	[{"id_menu":5,"count":1}]	26431	delivery	5	13
69979	2020-05-29 18:57:16	2020-05-29	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27639	pick-up	0	26
69980	2020-05-29 18:57:24	2020-05-29	17	[{"id_menu":4,"count":1}]	12717	pick-up	0	17
69981	2020-05-29 18:58:00	2020-05-29	8	[{"id_menu":5,"count":1}]	12453	delivery	5	13
69982	2020-05-29 18:58:27	2020-05-29	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	5070	pick-up	0	31
69983	2020-05-29 19:02:36	2020-05-29	9	[{"id_menu":6,"count":1}]	16117	delivery	5	14
69984	2020-05-29 19:05:32	2020-05-29	12	[{"id_menu":1,"count":2}]	1148	pick-up	0	12
69985	2020-05-29 19:06:05	2020-05-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	27734	delivery	5	26
69986	2020-05-29 19:06:22	2020-05-29	12	[{"id_menu":3,"count":1}]	27684	delivery	5	17
69987	2020-05-29 19:09:07	2020-05-29	21	[{"id_menu":1,"count":3},{"id_menu":7,"count":1}]	19750	delivery	5	26
69988	2020-05-29 19:09:25	2020-05-29	12	[{"id_menu":1,"count":1}]	27645	pick-up	0	12
69989	2020-05-29 19:12:12	2020-05-29	14	[{"id_menu":2,"count":1}]	1462	pick-up	0	14
69990	2020-05-29 19:22:58	2020-05-29	17	[{"id_menu":4,"count":1}]	27715	delivery	5	22
69991	2020-05-29 19:28:28	2020-05-29	9	[{"id_menu":7,"count":1}]	9780	delivery	5	14
69992	2020-05-29 19:30:29	2020-05-29	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	6722	delivery	5	38
69993	2020-05-29 19:34:57	2020-05-29	8	[{"id_menu":5,"count":1}]	16870	delivery	5	13
69994	2020-05-29 19:36:47	2020-05-29	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	12592	delivery	5	34
69995	2020-05-29 19:39:26	2020-05-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	360	delivery	5	36
69996	2020-05-29 19:40:57	2020-05-29	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23424	pick-up	0	29
69997	2020-05-29 19:44:25	2020-05-29	17	[{"id_menu":4,"count":1}]	75	pick-up	0	17
69998	2020-05-29 19:45:30	2020-05-29	14	[{"id_menu":2,"count":1}]	1820	pick-up	0	14
69999	2020-05-29 19:46:12	2020-05-29	14	[{"id_menu":2,"count":1}]	19889	delivery	5	19
70000	2020-05-29 20:01:43	2020-05-29	9	[{"id_menu":7,"count":1}]	633	pick-up	0	9
70001	2020-05-29 20:06:11	2020-05-29	9	[{"id_menu":6,"count":1}]	27741	delivery	5	14
70002	2020-05-29 20:09:34	2020-05-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	8801	delivery	5	28
70003	2020-05-29 20:16:35	2020-05-29	12	[{"id_menu":1,"count":1}]	19690	delivery	5	17
70004	2020-05-29 20:24:08	2020-05-29	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	24618	delivery	5	40
70005	2020-05-29 20:25:25	2020-05-29	9	[{"id_menu":7,"count":1}]	6092	pick-up	0	9
70006	2020-05-29 20:26:37	2020-05-29	12	[{"id_menu":3,"count":1}]	1456	pick-up	0	12
70007	2020-05-29 20:26:54	2020-05-29	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	22014	delivery	5	31
70008	2020-05-29 20:27:08	2020-05-29	12	[{"id_menu":1,"count":1}]	769	delivery	5	17
70009	2020-05-29 20:29:20	2020-05-29	17	[{"id_menu":4,"count":1}]	27642	pick-up	0	17
70010	2020-05-29 20:36:43	2020-05-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20684	delivery	5	36
70011	2020-05-29 20:37:02	2020-05-29	9	[{"id_menu":7,"count":1}]	5232	pick-up	0	9
70012	2020-05-29 20:46:16	2020-05-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	22022	delivery	5	27
70013	2020-05-29 20:47:17	2020-05-29	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	27691	delivery	5	36
70014	2020-05-29 21:04:27	2020-05-29	8	[{"id_menu":5,"count":1}]	27613	delivery	5	13
70015	2020-05-29 21:10:52	2020-05-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4655	delivery	5	26
70016	2020-05-29 21:12:19	2020-05-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	21600	delivery	5	27
70017	2020-05-29 21:12:37	2020-05-29	12	[{"id_menu":1,"count":1}]	2153	pick-up	0	12
70018	2020-05-29 21:12:51	2020-05-29	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18871	delivery	5	34
70019	2020-05-29 21:13:01	2020-05-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16754	delivery	5	31
70020	2020-05-29 21:16:18	2020-05-29	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	5701	delivery	5	34
70021	2020-05-29 21:18:10	2020-05-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	16608	delivery	5	36
70022	2020-05-29 21:18:12	2020-05-29	9	[{"id_menu":7,"count":1}]	24872	pick-up	0	9
70023	2020-05-29 21:21:16	2020-05-29	14	[{"id_menu":2,"count":1}]	19876	delivery	5	19
70024	2020-05-29 21:21:41	2020-05-29	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	27604	delivery	5	48
70025	2020-05-29 21:21:47	2020-05-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27686	delivery	5	22
70026	2020-05-29 21:22:28	2020-05-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13089	delivery	5	23
70027	2020-05-29 21:25:03	2020-05-29	17	[{"id_menu":4,"count":1}]	22771	delivery	5	22
70028	2020-05-29 21:25:34	2020-05-29	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	27631	delivery	5	45
70029	2020-05-29 21:26:57	2020-05-29	9	[{"id_menu":6,"count":1}]	27679	delivery	5	14
70030	2020-05-29 21:28:07	2020-05-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3463	pick-up	0	18
70031	2020-05-29 21:32:13	2020-05-29	9	[{"id_menu":6,"count":2}]	6549	delivery	5	14
70032	2020-05-29 21:35:18	2020-05-29	8	[{"id_menu":5,"count":1}]	2598	pick-up	0	8
70033	2020-05-29 21:36:59	2020-05-29	17	[{"id_menu":4,"count":1}]	27576	delivery	5	22
70034	2020-05-29 21:40:05	2020-05-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2562	pick-up	0	22
70035	2020-05-29 21:42:28	2020-05-29	9	[{"id_menu":6,"count":1}]	3065	pick-up	0	9
70036	2020-05-29 21:54:11	2020-05-29	12	[{"id_menu":1,"count":1}]	6607	pick-up	0	12
70037	2020-05-29 21:57:07	2020-05-29	12	[{"id_menu":3,"count":1}]	14168	delivery	5	17
70038	2020-05-29 22:07:00	2020-05-29	12	[{"id_menu":1,"count":1}]	27596	delivery	5	17
70039	2020-05-29 22:13:29	2020-05-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11419	delivery	5	36
70040	2020-05-29 22:22:25	2020-05-29	17	[{"id_menu":4,"count":1}]	2540	pick-up	0	17
70041	2020-05-29 22:30:33	2020-05-29	14	[{"id_menu":2,"count":1}]	4722	pick-up	0	14
70042	2020-05-29 22:34:49	2020-05-29	9	[{"id_menu":6,"count":1}]	14358	delivery	5	14
70043	2020-05-29 22:36:27	2020-05-29	17	[{"id_menu":4,"count":1}]	27632	delivery	5	22
70044	2020-05-29 22:36:39	2020-05-29	9	[{"id_menu":7,"count":1}]	27043	delivery	5	14
70045	2020-05-29 22:42:00	2020-05-29	17	[{"id_menu":4,"count":1}]	477	pick-up	0	17
70046	2020-05-29 22:52:03	2020-05-29	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	6070	pick-up	0	21
70047	2020-05-29 22:53:43	2020-05-29	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	13667	delivery	5	23
70048	2020-05-29 22:57:10	2020-05-29	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2443	delivery	5	31
70049	2020-05-29 23:07:47	2020-05-29	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	13975	delivery	5	40
70050	2020-05-29 23:07:53	2020-05-29	8	[{"id_menu":5,"count":2}]	27607	delivery	5	13
70051	2020-05-29 23:13:58	2020-05-29	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27692	delivery	5	34
70052	2020-05-29 23:14:10	2020-05-29	9	[{"id_menu":6,"count":3}]	22128	delivery	5	14
70053	2020-05-29 23:14:11	2020-05-29	17	[{"id_menu":4,"count":1}]	27678	delivery	5	22
70054	2020-05-29 23:17:31	2020-05-29	12	[{"id_menu":1,"count":1}]	4258	delivery	5	17
70055	2020-05-29 23:26:53	2020-05-29	12	[{"id_menu":3,"count":1}]	4051	pick-up	0	12
70056	2020-05-29 23:29:42	2020-05-29	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	27650	delivery	5	45
70057	2020-05-29 23:29:56	2020-05-29	14	[{"id_menu":2,"count":1}]	19662	delivery	5	19
70058	2020-05-29 23:31:11	2020-05-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	13344	delivery	5	26
70059	2020-05-29 23:33:04	2020-05-29	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27571	delivery	5	31
70060	2020-05-29 23:40:01	2020-05-29	17	[{"id_menu":4,"count":1}]	23427	delivery	5	22
70061	2020-05-29 23:40:38	2020-05-29	41	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4155	pick-up	0	41
70062	2020-05-29 23:42:54	2020-05-29	8	[{"id_menu":5,"count":1}]	21978	pick-up	0	8
70063	2020-05-29 23:44:29	2020-05-29	14	[{"id_menu":2,"count":1}]	2185	pick-up	0	14
70064	2020-05-29 23:46:11	2020-05-29	8	[{"id_menu":5,"count":1}]	5496	delivery	5	13
70065	2020-05-29 23:50:49	2020-05-29	8	[{"id_menu":5,"count":1}]	25658	delivery	5	13
70066	2020-05-29 23:51:05	2020-05-29	14	[{"id_menu":2,"count":2}]	20670	pick-up	0	14
70067	2020-05-29 23:53:31	2020-05-29	9	[{"id_menu":6,"count":1}]	27694	delivery	5	14
70068	2020-05-29 23:53:34	2020-05-29	12	[{"id_menu":3,"count":1}]	24558	delivery	5	17
70069	2020-05-29 23:56:24	2020-05-29	9	[{"id_menu":6,"count":1}]	21807	delivery	5	14
70070	2020-05-30 00:01:13	2020-05-30	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25003	delivery	5	35
70071	2020-05-30 00:01:17	2020-05-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	27848	delivery	5	26
70072	2020-05-30 00:02:54	2020-05-30	9	[{"id_menu":6,"count":1}]	25471	delivery	5	14
70073	2020-05-30 00:03:09	2020-05-30	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13522	pick-up	0	41
70074	2020-05-30 00:04:53	2020-05-30	9	[{"id_menu":6,"count":1}]	17808	delivery	5	14
70075	2020-05-30 00:05:31	2020-05-30	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	3688	delivery	5	35
70076	2020-05-30 00:09:47	2020-05-30	9	[{"id_menu":6,"count":1}]	19198	delivery	5	14
70077	2020-05-30 00:10:37	2020-05-30	12	[{"id_menu":1,"count":1}]	1064	pick-up	0	12
70078	2020-05-30 00:12:42	2020-05-30	9	[{"id_menu":6,"count":1}]	3153	pick-up	0	9
70079	2020-05-30 00:14:58	2020-05-30	9	[{"id_menu":6,"count":1}]	18789	delivery	5	14
70080	2020-05-30 00:15:13	2020-05-30	9	[{"id_menu":7,"count":1}]	257	pick-up	0	9
70081	2020-05-30 00:17:31	2020-05-30	9	[{"id_menu":7,"count":1}]	27912	delivery	5	14
70082	2020-05-30 00:17:53	2020-05-30	14	[{"id_menu":2,"count":1}]	7465	pick-up	0	14
70083	2020-05-30 00:21:11	2020-05-30	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27959	delivery	5	39
70084	2020-05-30 00:22:54	2020-05-30	14	[{"id_menu":2,"count":1}]	27859	pick-up	0	14
70085	2020-05-30 00:23:09	2020-05-30	9	[{"id_menu":7,"count":1}]	19103	delivery	5	14
70086	2020-05-30 00:23:40	2020-05-30	9	[{"id_menu":6,"count":1}]	15995	delivery	5	14
70087	2020-05-30 00:28:04	2020-05-30	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2063	delivery	5	34
70088	2020-05-30 00:29:36	2020-05-30	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	27962	delivery	5	40
70089	2020-05-30 00:32:52	2020-05-30	12	[{"id_menu":3,"count":1}]	1582	pick-up	0	12
70090	2020-05-30 00:40:00	2020-05-30	14	[{"id_menu":2,"count":1}]	8887	pick-up	0	14
70091	2020-05-30 00:43:57	2020-05-30	14	[{"id_menu":2,"count":2}]	2311	pick-up	0	14
70092	2020-05-30 00:45:21	2020-05-30	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	11519	delivery	5	43
70093	2020-05-30 00:46:27	2020-05-30	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	27860	delivery	5	43
70094	2020-05-30 00:47:25	2020-05-30	9	[{"id_menu":6,"count":1}]	27908	delivery	5	14
70095	2020-05-30 00:51:53	2020-05-30	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3703	delivery	5	34
70096	2020-05-30 00:52:17	2020-05-30	17	[{"id_menu":4,"count":1}]	27979	delivery	5	22
70097	2020-05-30 00:53:06	2020-05-30	17	[{"id_menu":4,"count":1}]	11394	pick-up	0	17
70098	2020-05-30 00:53:58	2020-05-30	9	[{"id_menu":7,"count":1}]	13465	delivery	5	14
70099	2020-05-30 00:54:44	2020-05-30	9	[{"id_menu":7,"count":2}]	27853	delivery	5	14
70100	2020-05-30 00:57:37	2020-05-30	14	[{"id_menu":2,"count":1}]	15961	pick-up	0	14
70101	2020-05-30 00:59:04	2020-05-30	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	27410	delivery	5	48
70102	2020-05-30 01:02:06	2020-05-30	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	16498	delivery	5	44
70103	2020-05-30 01:07:41	2020-05-30	17	[{"id_menu":4,"count":1}]	20780	delivery	5	22
70104	2020-05-30 01:09:55	2020-05-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	27845	delivery	5	31
70105	2020-05-30 01:14:35	2020-05-30	9	[{"id_menu":7,"count":2}]	424	pick-up	0	9
70106	2020-05-30 01:15:45	2020-05-30	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	27768	delivery	5	34
70107	2020-05-30 01:19:52	2020-05-30	9	[{"id_menu":7,"count":1}]	4495	delivery	5	14
70108	2020-05-30 01:19:54	2020-05-30	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	1021	pick-up	0	21
70109	2020-05-30 01:19:56	2020-05-30	12	[{"id_menu":3,"count":1}]	9707	pick-up	0	12
70110	2020-05-30 01:21:28	2020-05-30	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	14423	delivery	5	26
70111	2020-05-30 01:21:36	2020-05-30	17	[{"id_menu":4,"count":1}]	27810	delivery	5	22
70112	2020-05-30 01:25:25	2020-05-30	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	18714	pick-up	0	20
70113	2020-05-30 01:25:41	2020-05-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27687	delivery	5	22
70114	2020-05-30 01:26:13	2020-05-30	9	[{"id_menu":7,"count":1}]	12212	delivery	5	14
70115	2020-05-30 01:28:40	2020-05-30	12	[{"id_menu":3,"count":1}]	18160	delivery	5	17
70116	2020-05-30 01:30:11	2020-05-30	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	27776	delivery	5	40
70117	2020-05-30 01:34:55	2020-05-30	9	[{"id_menu":6,"count":1}]	27785	delivery	5	14
70118	2020-05-30 01:38:08	2020-05-30	17	[{"id_menu":4,"count":1}]	12642	delivery	5	22
70119	2020-05-30 01:38:24	2020-05-30	17	[{"id_menu":4,"count":1}]	2627	delivery	5	22
70120	2020-05-30 01:38:45	2020-05-30	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5886	delivery	5	53
70121	2020-05-30 01:47:04	2020-05-30	14	[{"id_menu":2,"count":1}]	12303	delivery	5	19
70122	2020-05-30 01:49:47	2020-05-30	9	[{"id_menu":7,"count":1}]	13141	delivery	5	14
70123	2020-05-30 01:50:48	2020-05-30	12	[{"id_menu":3,"count":1}]	20213	delivery	5	17
70124	2020-05-30 01:51:22	2020-05-30	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	27828	delivery	5	25
70125	2020-05-30 01:52:43	2020-05-30	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	27882	delivery	5	22
70126	2020-05-30 01:52:58	2020-05-30	9	[{"id_menu":7,"count":2}]	27831	delivery	5	14
70127	2020-05-30 01:53:11	2020-05-30	9	[{"id_menu":6,"count":1}]	27833	delivery	5	14
70128	2020-05-30 01:54:23	2020-05-30	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5001	delivery	5	34
70129	2020-05-30 01:55:43	2020-05-30	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	24482	delivery	5	36
70130	2020-05-30 01:55:53	2020-05-30	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3227	pick-up	0	21
70131	2020-05-30 01:57:06	2020-05-30	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	13193	delivery	5	31
70132	2020-05-30 01:58:01	2020-05-30	12	[{"id_menu":3,"count":1}]	27796	delivery	5	17
70133	2020-05-30 01:58:44	2020-05-30	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	15020	delivery	5	26
70134	2020-05-30 02:01:40	2020-05-30	14	[{"id_menu":2,"count":1}]	27916	delivery	5	19
70135	2020-05-30 02:02:21	2020-05-30	9	[{"id_menu":7,"count":1}]	1677	pick-up	0	9
70136	2020-05-30 02:09:13	2020-05-30	9	[{"id_menu":7,"count":1}]	1645	pick-up	0	9
70137	2020-05-30 02:09:19	2020-05-30	12	[{"id_menu":3,"count":1}]	16492	pick-up	0	12
70138	2020-05-30 02:13:17	2020-05-30	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	23074	delivery	5	23
70139	2020-05-30 02:20:03	2020-05-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5460	delivery	5	23
70140	2020-05-30 02:26:32	2020-05-30	12	[{"id_menu":3,"count":1}]	27802	delivery	5	17
70141	2020-05-30 02:30:25	2020-05-30	9	[{"id_menu":7,"count":1}]	966	delivery	5	14
70142	2020-05-30 02:32:28	2020-05-30	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	27915	delivery	5	26
70143	2020-05-30 02:33:02	2020-05-30	14	[{"id_menu":2,"count":1}]	13874	delivery	5	19
70144	2020-05-30 02:33:09	2020-05-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	17790	pick-up	0	26
70145	2020-05-30 02:36:31	2020-05-30	14	[{"id_menu":2,"count":1}]	14679	pick-up	0	14
70146	2020-05-30 02:36:56	2020-05-30	29	[{"id_menu":3,"count":3},{"id_menu":4,"count":1}]	27792	delivery	5	34
70147	2020-05-30 02:39:50	2020-05-30	14	[{"id_menu":2,"count":1}]	17217	pick-up	0	14
70148	2020-05-30 02:42:10	2020-05-30	9	[{"id_menu":6,"count":1}]	12950	pick-up	0	9
70149	2020-05-30 02:42:29	2020-05-30	14	[{"id_menu":2,"count":2}]	959	pick-up	0	14
70150	2020-05-30 02:43:04	2020-05-30	17	[{"id_menu":4,"count":1}]	27903	delivery	5	22
70151	2020-05-30 02:43:41	2020-05-30	17	[{"id_menu":4,"count":1}]	27940	delivery	5	22
70152	2020-05-30 02:44:37	2020-05-30	14	[{"id_menu":2,"count":1}]	20815	delivery	5	19
70153	2020-05-30 02:48:38	2020-05-30	9	[{"id_menu":7,"count":1}]	27907	delivery	5	14
70154	2020-05-30 02:56:32	2020-05-30	8	[{"id_menu":5,"count":1}]	9449	delivery	5	13
70155	2020-05-30 03:01:55	2020-05-30	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8616	delivery	5	42
70156	2020-05-30 03:03:39	2020-05-30	9	[{"id_menu":6,"count":1}]	27883	delivery	5	14
70157	2020-05-30 03:04:02	2020-05-30	9	[{"id_menu":7,"count":2}]	7527	delivery	5	14
70158	2020-05-30 03:04:27	2020-05-30	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27814	delivery	5	31
70159	2020-05-30 03:10:20	2020-05-30	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	27857	delivery	5	34
70160	2020-05-30 03:12:17	2020-05-30	9	[{"id_menu":7,"count":1}]	27925	delivery	5	14
70161	2020-05-30 03:12:17	2020-05-30	17	[{"id_menu":4,"count":1}]	991	pick-up	0	17
70162	2020-05-30 03:12:22	2020-05-30	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16867	delivery	5	34
70163	2020-05-30 03:14:29	2020-05-30	9	[{"id_menu":6,"count":1}]	27840	delivery	5	14
70164	2020-05-30 03:14:45	2020-05-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8620	delivery	5	31
70165	2020-05-30 03:15:07	2020-05-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	27196	delivery	5	27
70166	2020-05-30 03:25:25	2020-05-30	14	[{"id_menu":2,"count":1}]	14972	pick-up	0	14
70167	2020-05-30 03:25:57	2020-05-30	12	[{"id_menu":3,"count":1}]	1309	delivery	5	17
70168	2020-05-30 03:26:47	2020-05-30	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	27825	delivery	5	26
70169	2020-05-30 03:29:08	2020-05-30	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	25302	delivery	5	37
70170	2020-05-30 03:32:39	2020-05-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10635	delivery	5	22
70171	2020-05-30 03:33:53	2020-05-30	9	[{"id_menu":7,"count":1}]	11531	pick-up	0	9
70172	2020-05-30 03:33:57	2020-05-30	12	[{"id_menu":3,"count":1}]	11124	pick-up	0	12
70173	2020-05-30 03:34:05	2020-05-30	14	[{"id_menu":2,"count":1}]	27823	delivery	5	19
70174	2020-05-30 03:34:22	2020-05-30	12	[{"id_menu":3,"count":1}]	27900	delivery	5	17
70175	2020-05-30 03:37:11	2020-05-30	9	[{"id_menu":6,"count":1}]	9332	pick-up	0	9
70176	2020-05-30 03:37:34	2020-05-30	12	[{"id_menu":1,"count":1}]	3874	delivery	5	17
70177	2020-05-30 03:45:17	2020-05-30	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	11454	pick-up	0	21
70178	2020-05-30 03:45:46	2020-05-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	16301	pick-up	0	26
70179	2020-05-30 03:46:13	2020-05-30	9	[{"id_menu":7,"count":1}]	27977	delivery	5	14
70180	2020-05-30 03:48:15	2020-05-30	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	27976	delivery	5	40
70181	2020-05-30 03:48:47	2020-05-30	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	27902	delivery	5	34
70182	2020-05-30 03:51:32	2020-05-30	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1794	pick-up	0	25
70183	2020-05-30 03:54:23	2020-05-30	12	[{"id_menu":3,"count":1}]	21257	delivery	5	17
70184	2020-05-30 03:57:25	2020-05-30	12	[{"id_menu":1,"count":1}]	25291	delivery	5	17
70185	2020-05-30 03:57:50	2020-05-30	12	[{"id_menu":3,"count":1}]	27820	pick-up	0	12
70186	2020-05-30 04:00:34	2020-05-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	27116	delivery	5	26
70187	2020-05-30 04:02:31	2020-05-30	9	[{"id_menu":6,"count":1}]	17253	delivery	5	14
70188	2020-05-30 04:05:42	2020-05-30	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	27821	delivery	5	34
70189	2020-05-30 04:09:59	2020-05-30	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	27931	delivery	5	42
70190	2020-05-30 04:10:09	2020-05-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	24745	delivery	5	28
70191	2020-05-30 04:10:47	2020-05-30	9	[{"id_menu":6,"count":1}]	22478	delivery	5	14
70192	2020-05-30 04:11:45	2020-05-30	9	[{"id_menu":7,"count":1}]	9623	delivery	5	14
70193	2020-05-30 04:17:15	2020-05-30	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	4995	pick-up	0	29
70194	2020-05-30 04:17:58	2020-05-30	14	[{"id_menu":2,"count":1}]	27775	pick-up	0	14
70195	2020-05-30 04:21:02	2020-05-30	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13855	delivery	5	34
70196	2020-05-30 04:23:58	2020-05-30	9	[{"id_menu":6,"count":1}]	16330	pick-up	0	9
70197	2020-05-30 04:24:34	2020-05-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27917	delivery	5	22
70198	2020-05-30 04:37:36	2020-05-30	14	[{"id_menu":2,"count":1}]	2262	delivery	5	19
70199	2020-05-30 04:39:22	2020-05-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	27770	delivery	5	28
70200	2020-05-30 04:39:59	2020-05-30	17	[{"id_menu":4,"count":1}]	27844	pick-up	0	17
70201	2020-05-30 04:40:46	2020-05-30	9	[{"id_menu":6,"count":1}]	4054	pick-up	0	9
70202	2020-05-30 04:41:00	2020-05-30	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16752	delivery	5	36
70203	2020-05-30 04:41:09	2020-05-30	9	[{"id_menu":6,"count":1}]	4021	pick-up	0	9
70204	2020-05-30 04:42:05	2020-05-30	9	[{"id_menu":7,"count":1}]	11803	delivery	5	14
70205	2020-05-30 04:44:24	2020-05-30	14	[{"id_menu":2,"count":1}]	8050	delivery	5	19
70206	2020-05-30 04:45:39	2020-05-30	9	[{"id_menu":7,"count":1}]	27855	delivery	5	14
70207	2020-05-30 04:46:39	2020-05-30	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	3364	delivery	5	39
70208	2020-05-30 04:51:01	2020-05-30	14	[{"id_menu":2,"count":1}]	11395	pick-up	0	14
70209	2020-05-30 04:56:11	2020-05-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	23910	delivery	5	28
70210	2020-05-30 04:58:20	2020-05-30	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	27856	delivery	5	40
70211	2020-05-30 04:59:26	2020-05-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	13930	pick-up	0	21
70212	2020-05-30 04:59:57	2020-05-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4450	delivery	5	31
70213	2020-05-30 05:00:21	2020-05-30	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27942	delivery	5	36
70214	2020-05-30 05:12:45	2020-05-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27842	delivery	5	22
70215	2020-05-30 05:17:29	2020-05-30	9	[{"id_menu":7,"count":1}]	19760	delivery	5	14
70216	2020-05-30 05:18:20	2020-05-30	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	27867	delivery	5	34
70217	2020-05-30 05:20:27	2020-05-30	9	[{"id_menu":7,"count":1}]	27868	delivery	5	14
70218	2020-05-30 05:25:35	2020-05-30	8	[{"id_menu":5,"count":1}]	19163	delivery	5	13
70219	2020-05-30 05:26:02	2020-05-30	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4473	delivery	5	40
70220	2020-05-30 05:26:46	2020-05-30	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	11451	delivery	5	40
70221	2020-05-30 05:30:56	2020-05-30	8	[{"id_menu":5,"count":1}]	2397	pick-up	0	8
70222	2020-05-30 05:30:58	2020-05-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27953	delivery	5	23
70223	2020-05-30 05:33:56	2020-05-30	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	10991	delivery	5	45
70224	2020-05-30 05:34:16	2020-05-30	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	4857	delivery	5	27
70225	2020-05-30 05:37:58	2020-05-30	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	11323	pick-up	0	39
70226	2020-05-30 05:47:17	2020-05-30	14	[{"id_menu":2,"count":1}]	25830	delivery	5	19
70227	2020-05-30 05:48:24	2020-05-30	17	[{"id_menu":4,"count":1}]	1278	pick-up	0	17
70228	2020-05-30 05:49:37	2020-05-30	9	[{"id_menu":6,"count":1}]	7566	delivery	5	14
70229	2020-05-30 05:53:50	2020-05-30	8	[{"id_menu":5,"count":1}]	3343	delivery	5	13
70230	2020-05-30 05:55:08	2020-05-30	8	[{"id_menu":5,"count":1}]	4343	delivery	5	13
70231	2020-05-30 05:56:32	2020-05-30	17	[{"id_menu":4,"count":1}]	27905	delivery	5	22
70232	2020-05-30 05:57:23	2020-05-30	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	25446	delivery	5	22
70233	2020-05-30 05:58:36	2020-05-30	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	27879	delivery	5	43
70234	2020-05-30 05:59:31	2020-05-30	9	[{"id_menu":7,"count":1}]	27947	delivery	5	14
70235	2020-05-30 06:02:10	2020-05-30	12	[{"id_menu":1,"count":1}]	27968	delivery	5	17
70236	2020-05-30 06:04:58	2020-05-30	12	[{"id_menu":1,"count":1}]	81	pick-up	0	12
70237	2020-05-30 06:06:47	2020-05-30	14	[{"id_menu":2,"count":1}]	158	pick-up	0	14
70238	2020-05-30 06:11:14	2020-05-30	9	[{"id_menu":7,"count":1}]	24721	delivery	5	14
70239	2020-05-30 06:11:41	2020-05-30	39	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	16831	delivery	5	44
70240	2020-05-30 06:13:19	2020-05-30	12	[{"id_menu":3,"count":1}]	3122	delivery	5	17
70241	2020-05-30 06:14:11	2020-05-30	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17500	pick-up	0	32
70242	2020-05-30 06:17:29	2020-05-30	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27918	delivery	5	48
70243	2020-05-30 06:21:18	2020-05-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	21322	pick-up	0	21
70244	2020-05-30 06:21:25	2020-05-30	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	27781	delivery	5	26
70245	2020-05-30 06:25:35	2020-05-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	6003	delivery	5	27
70246	2020-05-30 06:30:55	2020-05-30	9	[{"id_menu":7,"count":1}]	27932	delivery	5	14
70247	2020-05-30 06:31:00	2020-05-30	9	[{"id_menu":6,"count":1}]	20288	delivery	5	14
70248	2020-05-30 06:32:38	2020-05-30	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	22900	pick-up	0	26
70249	2020-05-30 06:33:36	2020-05-30	8	[{"id_menu":5,"count":1}]	23268	delivery	5	13
70250	2020-05-30 06:34:56	2020-05-30	12	[{"id_menu":3,"count":1}]	20620	pick-up	0	12
70251	2020-05-30 06:37:39	2020-05-30	14	[{"id_menu":2,"count":1}]	13576	delivery	5	19
70252	2020-05-30 06:39:27	2020-05-30	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16346	delivery	5	39
70253	2020-05-30 06:43:38	2020-05-30	9	[{"id_menu":6,"count":1}]	10032	delivery	5	14
70254	2020-05-30 06:49:32	2020-05-30	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":2}]	17405	delivery	5	28
70255	2020-05-30 06:51:14	2020-05-30	9	[{"id_menu":6,"count":2}]	13835	pick-up	0	9
70256	2020-05-30 06:55:00	2020-05-30	9	[{"id_menu":6,"count":1}]	12357	pick-up	0	9
70257	2020-05-30 06:55:38	2020-05-30	8	[{"id_menu":5,"count":1}]	3579	delivery	5	13
70258	2020-05-30 06:56:10	2020-05-30	14	[{"id_menu":2,"count":1}]	1563	pick-up	0	14
70259	2020-05-30 06:56:43	2020-05-30	8	[{"id_menu":5,"count":1}]	13847	delivery	5	13
70260	2020-05-30 07:01:28	2020-05-30	9	[{"id_menu":7,"count":1}]	20040	pick-up	0	9
70261	2020-05-30 07:03:44	2020-05-30	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	20489	delivery	5	23
70262	2020-05-30 07:05:02	2020-05-30	17	[{"id_menu":4,"count":1}]	5701	delivery	5	22
70263	2020-05-30 07:05:21	2020-05-30	9	[{"id_menu":7,"count":1}]	27946	delivery	5	14
70264	2020-05-30 07:25:28	2020-05-30	9	[{"id_menu":7,"count":1}]	27778	delivery	5	14
70265	2020-05-30 07:26:44	2020-05-30	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	26324	delivery	5	31
70266	2020-05-30 07:27:10	2020-05-30	9	[{"id_menu":6,"count":2}]	27960	delivery	5	14
70267	2020-05-30 07:31:12	2020-05-30	9	[{"id_menu":7,"count":1}]	26624	delivery	5	14
70268	2020-05-30 07:35:38	2020-05-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	6641	pick-up	0	21
70269	2020-05-30 07:35:45	2020-05-30	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	9001	delivery	5	25
70270	2020-05-30 07:37:46	2020-05-30	17	[{"id_menu":4,"count":1}]	2540	pick-up	0	17
70271	2020-05-30 07:39:23	2020-05-30	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	27970	delivery	5	44
70272	2020-05-30 07:41:40	2020-05-30	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1651	delivery	5	36
70273	2020-05-30 07:42:38	2020-05-30	9	[{"id_menu":6,"count":1}]	4862	delivery	5	14
70274	2020-05-30 07:52:15	2020-05-30	14	[{"id_menu":2,"count":1}]	2071	pick-up	0	14
70275	2020-05-30 07:53:00	2020-05-30	8	[{"id_menu":5,"count":1}]	18736	delivery	5	13
70276	2020-05-30 07:53:53	2020-05-30	12	[{"id_menu":1,"count":1}]	6930	delivery	5	17
70277	2020-05-30 07:57:09	2020-05-30	9	[{"id_menu":7,"count":1}]	3634	pick-up	0	9
70278	2020-05-30 08:02:35	2020-05-30	9	[{"id_menu":7,"count":1}]	8265	pick-up	0	9
70279	2020-05-30 08:03:24	2020-05-30	17	[{"id_menu":4,"count":1}]	27913	delivery	5	22
70280	2020-05-30 08:08:40	2020-05-30	12	[{"id_menu":3,"count":1}]	27082	pick-up	0	12
70281	2020-05-30 08:15:17	2020-05-30	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	27949	delivery	5	26
70282	2020-05-30 08:22:12	2020-05-30	9	[{"id_menu":7,"count":1}]	27870	pick-up	0	9
70283	2020-05-30 08:23:30	2020-05-30	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8431	delivery	5	36
70284	2020-05-30 08:23:45	2020-05-30	12	[{"id_menu":1,"count":1}]	9031	pick-up	0	12
70285	2020-05-30 08:25:05	2020-05-30	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	27885	delivery	5	28
70286	2020-05-30 08:25:49	2020-05-30	9	[{"id_menu":6,"count":1}]	300	delivery	5	14
70287	2020-05-30 08:27:05	2020-05-30	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	8332	delivery	5	40
70288	2020-05-30 08:29:12	2020-05-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8664	delivery	5	23
70289	2020-05-30 08:32:38	2020-05-30	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	18683	delivery	5	25
70290	2020-05-30 08:35:37	2020-05-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	27881	delivery	5	27
70291	2020-05-30 08:37:15	2020-05-30	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	27967	delivery	5	34
70292	2020-05-30 08:38:17	2020-05-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	23594	delivery	5	31
70293	2020-05-30 08:39:56	2020-05-30	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	27	pick-up	0	25
70294	2020-05-30 08:40:21	2020-05-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	27889	delivery	5	27
70295	2020-05-30 08:41:42	2020-05-30	17	[{"id_menu":4,"count":1}]	27937	delivery	5	22
70296	2020-05-30 08:42:18	2020-05-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	27816	delivery	5	26
70297	2020-05-30 08:44:01	2020-05-30	8	[{"id_menu":5,"count":1}]	26086	delivery	5	13
70298	2020-05-30 08:46:33	2020-05-30	12	[{"id_menu":3,"count":1}]	27941	pick-up	0	12
70299	2020-05-30 08:51:21	2020-05-30	12	[{"id_menu":1,"count":1}]	7590	delivery	5	17
70300	2020-05-30 08:52:01	2020-05-30	14	[{"id_menu":2,"count":1}]	7058	pick-up	0	14
70301	2020-05-30 08:54:32	2020-05-30	14	[{"id_menu":2,"count":2}]	4956	pick-up	0	14
70302	2020-05-30 08:56:28	2020-05-30	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	22678	delivery	5	30
70303	2020-05-30 08:59:19	2020-05-30	12	[{"id_menu":1,"count":1}]	18133	pick-up	0	12
70304	2020-05-30 09:02:37	2020-05-30	17	[{"id_menu":4,"count":1}]	27800	pick-up	0	17
70305	2020-05-30 09:02:54	2020-05-30	12	[{"id_menu":1,"count":1}]	27896	delivery	5	17
70306	2020-05-30 09:04:51	2020-05-30	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	13187	delivery	5	39
70307	2020-05-30 09:06:10	2020-05-30	17	[{"id_menu":4,"count":1}]	3584	delivery	5	22
70308	2020-05-30 09:10:04	2020-05-30	14	[{"id_menu":2,"count":1}]	27835	pick-up	0	14
70309	2020-05-30 09:11:09	2020-05-30	12	[{"id_menu":3,"count":2}]	1720	delivery	5	17
70310	2020-05-30 09:14:35	2020-05-30	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	21089	delivery	5	45
70311	2020-05-30 09:15:17	2020-05-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	27886	delivery	5	22
70312	2020-05-30 09:15:46	2020-05-30	9	[{"id_menu":6,"count":1}]	14946	delivery	5	14
70313	2020-05-30 09:19:26	2020-05-30	9	[{"id_menu":7,"count":1}]	27841	delivery	5	14
70314	2020-05-30 09:20:21	2020-05-30	14	[{"id_menu":2,"count":1}]	24697	pick-up	0	14
70315	2020-05-30 09:20:24	2020-05-30	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23928	delivery	5	22
70316	2020-05-30 09:21:44	2020-05-30	14	[{"id_menu":2,"count":1}]	27812	delivery	5	19
70317	2020-05-30 09:26:15	2020-05-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	23982	delivery	5	31
70318	2020-05-30 09:27:00	2020-05-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17481	delivery	5	31
70319	2020-05-30 09:29:08	2020-05-30	12	[{"id_menu":3,"count":1}]	12058	delivery	5	17
70320	2020-05-30 09:31:40	2020-05-30	14	[{"id_menu":2,"count":1}]	27786	delivery	5	19
70321	2020-05-30 09:33:51	2020-05-30	9	[{"id_menu":6,"count":1}]	14451	pick-up	0	9
70322	2020-05-30 09:33:56	2020-05-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21162	delivery	5	22
70323	2020-05-30 09:37:53	2020-05-30	9	[{"id_menu":6,"count":1}]	27822	delivery	5	14
70324	2020-05-30 09:38:42	2020-05-30	14	[{"id_menu":2,"count":1}]	27863	delivery	5	19
70325	2020-05-30 09:41:22	2020-05-30	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27961	pick-up	0	40
70326	2020-05-30 09:44:48	2020-05-30	17	[{"id_menu":4,"count":1}]	22447	delivery	5	22
70327	2020-05-30 09:47:48	2020-05-30	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	20925	delivery	5	40
70328	2020-05-30 09:50:19	2020-05-30	12	[{"id_menu":1,"count":1}]	8153	pick-up	0	12
70329	2020-05-30 09:52:07	2020-05-30	12	[{"id_menu":1,"count":1}]	27819	delivery	5	17
70330	2020-05-30 09:52:32	2020-05-30	17	[{"id_menu":4,"count":1}]	3313	pick-up	0	17
70331	2020-05-30 09:54:25	2020-05-30	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	27836	delivery	5	45
70332	2020-05-30 09:56:48	2020-05-30	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	27945	delivery	5	25
70333	2020-05-30 09:56:50	2020-05-30	9	[{"id_menu":7,"count":3}]	27769	delivery	5	14
70334	2020-05-30 09:58:30	2020-05-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27818	delivery	5	22
70335	2020-05-30 09:59:02	2020-05-30	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6080	delivery	5	40
70336	2020-05-30 10:02:39	2020-05-30	8	[{"id_menu":5,"count":1}]	22056	delivery	5	13
70337	2020-05-30 10:03:23	2020-05-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5473	delivery	5	22
70338	2020-05-30 10:06:43	2020-05-30	8	[{"id_menu":5,"count":1}]	27957	delivery	5	13
70339	2020-05-30 10:11:07	2020-05-30	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27964	delivery	5	43
70340	2020-05-30 10:12:24	2020-05-30	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	10828	delivery	5	34
70341	2020-05-30 10:13:13	2020-05-30	17	[{"id_menu":4,"count":1}]	22573	delivery	5	22
70342	2020-05-30 10:18:12	2020-05-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7280	delivery	5	28
70343	2020-05-30 10:19:03	2020-05-30	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3507	pick-up	0	35
70344	2020-05-30 10:19:11	2020-05-30	17	[{"id_menu":4,"count":1}]	26621	delivery	5	22
70345	2020-05-30 10:19:12	2020-05-30	9	[{"id_menu":7,"count":1}]	528	delivery	5	14
70346	2020-05-30 10:21:40	2020-05-30	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	26255	delivery	5	29
70347	2020-05-30 10:22:17	2020-05-30	9	[{"id_menu":7,"count":1}]	22402	delivery	5	14
70348	2020-05-30 10:25:45	2020-05-30	9	[{"id_menu":7,"count":1}]	3760	delivery	5	14
70349	2020-05-30 10:26:58	2020-05-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20817	delivery	5	22
70350	2020-05-30 10:28:54	2020-05-30	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27919	delivery	5	37
70351	2020-05-30 10:30:01	2020-05-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17838	delivery	5	31
70352	2020-05-30 10:30:57	2020-05-30	8	[{"id_menu":5,"count":1}]	27922	delivery	5	13
70353	2020-05-30 10:32:37	2020-05-30	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	23528	delivery	5	34
70354	2020-05-30 10:33:18	2020-05-30	9	[{"id_menu":7,"count":1}]	6772	pick-up	0	9
70355	2020-05-30 10:35:05	2020-05-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	20994	delivery	5	23
70356	2020-05-30 10:35:52	2020-05-30	8	[{"id_menu":5,"count":1}]	27858	delivery	5	13
70357	2020-05-30 10:36:06	2020-05-30	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	23338	delivery	5	28
70358	2020-05-30 10:37:18	2020-05-30	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	27787	delivery	5	22
70359	2020-05-30 10:39:08	2020-05-30	9	[{"id_menu":7,"count":1}]	25117	pick-up	0	9
70360	2020-05-30 10:46:27	2020-05-30	14	[{"id_menu":2,"count":1}]	24601	delivery	5	19
70361	2020-05-30 10:52:50	2020-05-30	9	[{"id_menu":7,"count":2}]	27807	delivery	5	14
70362	2020-05-30 10:59:22	2020-05-30	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	23681	delivery	5	29
70363	2020-05-30 11:00:19	2020-05-30	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	27965	pick-up	0	29
70364	2020-05-30 11:02:28	2020-05-30	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	27832	delivery	5	26
70365	2020-05-30 11:02:57	2020-05-30	12	[{"id_menu":3,"count":1}]	27884	delivery	5	17
70366	2020-05-30 11:07:53	2020-05-30	12	[{"id_menu":1,"count":1}]	6377	delivery	5	17
70367	2020-05-30 11:12:51	2020-05-30	9	[{"id_menu":6,"count":1}]	21594	delivery	5	14
70368	2020-05-30 11:12:55	2020-05-30	9	[{"id_menu":7,"count":1}]	15009	delivery	5	14
70369	2020-05-30 11:14:08	2020-05-30	9	[{"id_menu":7,"count":1}]	3010	pick-up	0	9
70370	2020-05-30 11:18:04	2020-05-30	9	[{"id_menu":7,"count":1}]	27898	delivery	5	14
70371	2020-05-30 11:18:50	2020-05-30	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	27852	delivery	5	28
70372	2020-05-30 11:21:09	2020-05-30	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	292	delivery	5	39
70373	2020-05-30 11:22:01	2020-05-30	12	[{"id_menu":1,"count":1}]	2425	pick-up	0	12
70374	2020-05-30 11:27:16	2020-05-30	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11874	delivery	5	36
70375	2020-05-30 11:31:01	2020-05-30	9	[{"id_menu":7,"count":1}]	2470	pick-up	0	9
70376	2020-05-30 11:33:41	2020-05-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	27955	delivery	5	27
70377	2020-05-30 11:34:15	2020-05-30	9	[{"id_menu":6,"count":1}]	20479	delivery	5	14
70378	2020-05-30 11:34:37	2020-05-30	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	16295	pick-up	0	26
70379	2020-05-30 11:40:49	2020-05-30	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3450	delivery	5	26
70380	2020-05-30 11:45:58	2020-05-30	17	[{"id_menu":4,"count":1}]	26311	delivery	5	22
70381	2020-05-30 11:51:19	2020-05-30	14	[{"id_menu":2,"count":1}]	3069	delivery	5	19
70382	2020-05-30 11:53:11	2020-05-30	9	[{"id_menu":6,"count":1}]	25379	delivery	5	14
70383	2020-05-30 11:53:46	2020-05-30	8	[{"id_menu":5,"count":1}]	2264	pick-up	0	8
70384	2020-05-30 11:53:55	2020-05-30	12	[{"id_menu":1,"count":1}]	15686	pick-up	0	12
70385	2020-05-30 11:59:44	2020-05-30	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12935	delivery	5	39
70386	2020-05-30 12:01:09	2020-05-30	17	[{"id_menu":4,"count":1}]	12012	pick-up	0	17
70387	2020-05-30 12:04:11	2020-05-30	9	[{"id_menu":7,"count":1}]	27901	pick-up	0	9
70388	2020-05-30 12:04:35	2020-05-30	14	[{"id_menu":2,"count":1}]	243	delivery	5	19
70389	2020-05-30 12:11:14	2020-05-30	9	[{"id_menu":6,"count":1}]	27927	delivery	5	14
70390	2020-05-30 12:11:26	2020-05-30	12	[{"id_menu":3,"count":1}]	3007	delivery	5	17
70391	2020-05-30 12:12:03	2020-05-30	14	[{"id_menu":2,"count":1}]	26408	pick-up	0	14
70392	2020-05-30 12:12:22	2020-05-30	9	[{"id_menu":6,"count":1}]	18102	delivery	5	14
70393	2020-05-30 12:14:16	2020-05-30	12	[{"id_menu":3,"count":1}]	24350	pick-up	0	12
70394	2020-05-30 12:14:26	2020-05-30	8	[{"id_menu":5,"count":1}]	27873	delivery	5	13
70395	2020-05-30 12:19:08	2020-05-30	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	27869	delivery	5	42
70396	2020-05-30 12:21:23	2020-05-30	14	[{"id_menu":2,"count":1}]	27782	delivery	5	19
70397	2020-05-30 12:24:48	2020-05-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3169	delivery	5	23
70398	2020-05-30 12:27:45	2020-05-30	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	4429	delivery	5	30
70399	2020-05-30 12:27:47	2020-05-30	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	25420	delivery	5	23
70400	2020-05-30 12:28:39	2020-05-30	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	10457	delivery	5	34
70401	2020-05-30 12:30:04	2020-05-30	8	[{"id_menu":5,"count":1}]	25908	delivery	5	13
70402	2020-05-30 12:30:25	2020-05-30	12	[{"id_menu":1,"count":1}]	27139	delivery	5	17
70403	2020-05-30 12:34:38	2020-05-30	17	[{"id_menu":4,"count":1}]	27783	delivery	5	22
70404	2020-05-30 12:35:41	2020-05-30	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	24943	pick-up	0	29
70405	2020-05-30 12:36:32	2020-05-30	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	738	delivery	5	34
70406	2020-05-30 12:39:18	2020-05-30	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27791	delivery	5	39
70407	2020-05-30 12:42:28	2020-05-30	17	[{"id_menu":4,"count":1}]	5534	delivery	5	22
70408	2020-05-30 12:50:31	2020-05-30	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	14775	delivery	5	38
70409	2020-05-30 12:53:20	2020-05-30	9	[{"id_menu":7,"count":1}]	27909	pick-up	0	9
70410	2020-05-30 13:03:59	2020-05-30	17	[{"id_menu":4,"count":1}]	17085	delivery	5	22
70411	2020-05-30 13:08:29	2020-05-30	9	[{"id_menu":6,"count":1}]	23139	delivery	5	14
70412	2020-05-30 13:08:32	2020-05-30	14	[{"id_menu":2,"count":1}]	27939	delivery	5	19
70413	2020-05-30 13:08:42	2020-05-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16749	delivery	5	23
70414	2020-05-30 13:13:00	2020-05-30	17	[{"id_menu":4,"count":1}]	2363	pick-up	0	17
70415	2020-05-30 13:13:04	2020-05-30	12	[{"id_menu":1,"count":1}]	27793	pick-up	0	12
70416	2020-05-30 13:13:14	2020-05-30	8	[{"id_menu":5,"count":1}]	17038	delivery	5	13
70417	2020-05-30 13:22:37	2020-05-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	37	pick-up	0	26
70418	2020-05-30 13:25:42	2020-05-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5379	delivery	5	31
70419	2020-05-30 13:25:56	2020-05-30	9	[{"id_menu":6,"count":1}]	13190	delivery	5	14
70420	2020-05-30 13:30:48	2020-05-30	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16440	delivery	5	45
70421	2020-05-30 13:30:53	2020-05-30	8	[{"id_menu":5,"count":1}]	20724	delivery	5	13
70422	2020-05-30 13:34:05	2020-05-30	14	[{"id_menu":2,"count":1}]	27914	delivery	5	19
70423	2020-05-30 13:35:29	2020-05-30	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	27843	delivery	5	39
70424	2020-05-30 13:36:21	2020-05-30	9	[{"id_menu":6,"count":1}]	27924	delivery	5	14
70425	2020-05-30 13:38:27	2020-05-30	12	[{"id_menu":1,"count":1}]	22209	delivery	5	17
70426	2020-05-30 13:40:57	2020-05-30	33	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	6113	delivery	5	38
70427	2020-05-30 13:41:55	2020-05-30	14	[{"id_menu":2,"count":1}]	2999	delivery	5	19
70428	2020-05-30 13:43:55	2020-05-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	27951	delivery	5	26
70429	2020-05-30 13:45:43	2020-05-30	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	27892	delivery	5	26
70430	2020-05-30 13:51:06	2020-05-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2870	delivery	5	28
70431	2020-05-30 13:57:12	2020-05-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	27788	delivery	5	28
70432	2020-05-30 13:57:21	2020-05-30	9	[{"id_menu":6,"count":1}]	27897	delivery	5	14
70433	2020-05-30 13:57:35	2020-05-30	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	3492	delivery	5	34
70434	2020-05-30 13:57:48	2020-05-30	9	[{"id_menu":7,"count":1}]	27806	delivery	5	14
70435	2020-05-30 14:00:11	2020-05-30	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	7536	delivery	5	31
70436	2020-05-30 14:02:09	2020-05-30	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	17687	delivery	5	26
70437	2020-05-30 14:04:12	2020-05-30	12	[{"id_menu":3,"count":1}]	21786	delivery	5	17
70438	2020-05-30 14:07:29	2020-05-30	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27808	delivery	5	36
70439	2020-05-30 14:07:56	2020-05-30	17	[{"id_menu":4,"count":1}]	14845	delivery	5	22
70440	2020-05-30 14:15:34	2020-05-30	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	24884	delivery	5	31
70441	2020-05-30 14:15:44	2020-05-30	9	[{"id_menu":6,"count":1}]	10394	pick-up	0	9
70442	2020-05-30 14:16:35	2020-05-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	26999	delivery	5	22
70443	2020-05-30 14:21:07	2020-05-30	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	27804	pick-up	0	25
70444	2020-05-30 14:21:14	2020-05-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	27864	delivery	5	27
70445	2020-05-30 14:25:36	2020-05-30	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13936	delivery	5	51
70446	2020-05-30 14:26:48	2020-05-30	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5378	delivery	5	51
70447	2020-05-30 14:30:36	2020-05-30	14	[{"id_menu":2,"count":1}]	27972	delivery	5	19
70448	2020-05-30 14:30:45	2020-05-30	12	[{"id_menu":1,"count":1}]	27875	delivery	5	17
70449	2020-05-30 14:34:01	2020-05-30	9	[{"id_menu":7,"count":1}]	27910	delivery	5	14
70450	2020-05-30 14:34:32	2020-05-30	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	21770	pick-up	0	23
70451	2020-05-30 14:35:18	2020-05-30	12	[{"id_menu":3,"count":1}]	1072	pick-up	0	12
70452	2020-05-30 14:36:37	2020-05-30	14	[{"id_menu":2,"count":1}]	27963	delivery	5	19
70453	2020-05-30 14:42:27	2020-05-30	9	[{"id_menu":6,"count":1}]	14137	delivery	5	14
70454	2020-05-30 14:47:54	2020-05-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5380	delivery	5	23
70455	2020-05-30 14:52:11	2020-05-30	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	8177	delivery	5	26
70456	2020-05-30 14:52:24	2020-05-30	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	27973	delivery	5	26
70457	2020-05-30 14:54:16	2020-05-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	27926	delivery	5	31
70458	2020-05-30 14:55:17	2020-05-30	8	[{"id_menu":5,"count":1}]	27904	delivery	5	13
70459	2020-05-30 14:57:49	2020-05-30	8	[{"id_menu":5,"count":1}]	27950	delivery	5	13
70460	2020-05-30 14:59:18	2020-05-30	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9011	delivery	5	31
70461	2020-05-30 15:00:16	2020-05-30	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	20372	delivery	5	30
70462	2020-05-30 15:02:12	2020-05-30	9	[{"id_menu":7,"count":1}]	1988	pick-up	0	9
70463	2020-05-30 15:02:31	2020-05-30	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	27948	delivery	5	40
70464	2020-05-30 15:05:51	2020-05-30	12	[{"id_menu":3,"count":1}]	5547	delivery	5	17
70465	2020-05-30 15:07:07	2020-05-30	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	1780	pick-up	0	29
70466	2020-05-30 15:07:36	2020-05-30	8	[{"id_menu":5,"count":1}]	27891	delivery	5	13
70467	2020-05-30 15:08:20	2020-05-30	14	[{"id_menu":2,"count":1}]	25276	pick-up	0	14
70468	2020-05-30 15:08:57	2020-05-30	8	[{"id_menu":5,"count":1}]	7268	delivery	5	13
70469	2020-05-30 15:16:29	2020-05-30	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	27872	delivery	5	34
70470	2020-05-30 15:19:05	2020-05-30	8	[{"id_menu":5,"count":2}]	27774	delivery	5	13
70471	2020-05-30 15:19:18	2020-05-30	17	[{"id_menu":4,"count":1}]	9955	delivery	5	22
70472	2020-05-30 15:22:38	2020-05-30	14	[{"id_menu":2,"count":1}]	25367	pick-up	0	14
70473	2020-05-30 15:23:41	2020-05-30	9	[{"id_menu":7,"count":1}]	27790	delivery	5	14
70474	2020-05-30 15:25:34	2020-05-30	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	26567	delivery	5	22
70475	2020-05-30 15:28:04	2020-05-30	17	[{"id_menu":4,"count":1}]	27685	pick-up	0	17
70476	2020-05-30 15:31:11	2020-05-30	17	[{"id_menu":4,"count":1}]	678	delivery	5	22
70477	2020-05-30 15:33:40	2020-05-30	9	[{"id_menu":6,"count":1}]	1647	delivery	5	14
70478	2020-05-30 15:34:33	2020-05-30	9	[{"id_menu":6,"count":1}]	27830	delivery	5	14
70479	2020-05-30 15:36:35	2020-05-30	9	[{"id_menu":7,"count":1}]	1423	pick-up	0	9
70480	2020-05-30 15:40:21	2020-05-30	9	[{"id_menu":7,"count":1}]	5236	delivery	5	14
70481	2020-05-30 15:42:10	2020-05-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	13858	pick-up	0	26
70482	2020-05-30 15:43:10	2020-05-30	14	[{"id_menu":2,"count":1}]	3372	pick-up	0	14
70483	2020-05-30 15:45:20	2020-05-30	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	19006	delivery	5	45
70484	2020-05-30 15:45:34	2020-05-30	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	27846	delivery	5	44
70485	2020-05-30 15:57:51	2020-05-30	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	27851	delivery	5	26
70486	2020-05-30 16:04:38	2020-05-30	8	[{"id_menu":5,"count":1}]	9464	delivery	5	13
70487	2020-05-30 16:06:03	2020-05-30	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19959	delivery	5	45
70488	2020-05-30 16:13:33	2020-05-30	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	27827	delivery	5	56
70489	2020-05-30 16:13:44	2020-05-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	24326	pick-up	0	23
70490	2020-05-30 16:15:37	2020-05-30	12	[{"id_menu":1,"count":1}]	1559	pick-up	0	12
70491	2020-05-30 16:19:18	2020-05-30	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	1684	delivery	5	43
70492	2020-05-30 16:22:17	2020-05-30	9	[{"id_menu":6,"count":1}]	22002	delivery	5	14
70493	2020-05-30 16:27:18	2020-05-30	14	[{"id_menu":2,"count":2}]	5483	pick-up	0	14
70494	2020-05-30 16:28:34	2020-05-30	9	[{"id_menu":7,"count":1}]	27969	delivery	5	14
70495	2020-05-30 16:30:03	2020-05-30	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19380	delivery	5	31
70496	2020-05-30 16:31:01	2020-05-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	27876	delivery	5	28
70497	2020-05-30 16:31:49	2020-05-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6539	pick-up	0	23
70498	2020-05-30 16:32:43	2020-05-30	9	[{"id_menu":6,"count":1}]	27929	pick-up	0	9
70499	2020-05-30 16:43:11	2020-05-30	8	[{"id_menu":5,"count":1}]	1334	pick-up	0	8
70500	2020-05-30 16:46:26	2020-05-30	9	[{"id_menu":7,"count":1}]	26520	delivery	5	14
70501	2020-05-30 16:48:16	2020-05-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7206	pick-up	0	17
70502	2020-05-30 16:49:41	2020-05-30	17	[{"id_menu":4,"count":1}]	11295	delivery	5	22
70503	2020-05-30 17:00:11	2020-05-30	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	27801	delivery	5	25
70504	2020-05-30 17:03:25	2020-05-30	14	[{"id_menu":2,"count":1}]	5596	delivery	5	19
70505	2020-05-30 17:09:38	2020-05-30	12	[{"id_menu":3,"count":1}]	24848	pick-up	0	12
70506	2020-05-30 17:09:41	2020-05-30	12	[{"id_menu":3,"count":1}]	7849	delivery	5	17
70507	2020-05-30 17:13:59	2020-05-30	9	[{"id_menu":7,"count":1}]	25532	delivery	5	14
70508	2020-05-30 17:14:41	2020-05-30	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5478	pick-up	0	43
70509	2020-05-30 17:16:20	2020-05-30	8	[{"id_menu":5,"count":1}]	27888	delivery	5	13
70510	2020-05-30 17:16:49	2020-05-30	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15407	delivery	5	22
70511	2020-05-30 17:17:36	2020-05-30	12	[{"id_menu":1,"count":1}]	11130	delivery	5	17
70512	2020-05-30 17:26:21	2020-05-30	9	[{"id_menu":6,"count":1}]	14817	delivery	5	14
70513	2020-05-30 17:26:23	2020-05-30	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	27930	delivery	5	48
70514	2020-05-30 17:27:00	2020-05-30	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3950	delivery	5	31
70515	2020-05-30 17:27:13	2020-05-30	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21107	delivery	5	37
70516	2020-05-30 17:27:47	2020-05-30	17	[{"id_menu":4,"count":1}]	27936	delivery	5	22
70517	2020-05-30 17:33:39	2020-05-30	8	[{"id_menu":5,"count":1}]	5308	pick-up	0	8
70518	2020-05-30 17:35:32	2020-05-30	12	[{"id_menu":3,"count":1}]	6885	delivery	5	17
70519	2020-05-30 17:36:28	2020-05-30	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	5553	pick-up	0	29
70520	2020-05-30 17:36:31	2020-05-30	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	27871	delivery	5	26
70521	2020-05-30 17:43:10	2020-05-30	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	27944	delivery	5	36
70522	2020-05-30 17:46:11	2020-05-30	14	[{"id_menu":2,"count":1}]	10288	delivery	5	19
70523	2020-05-30 17:48:40	2020-05-30	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	3293	delivery	5	29
70524	2020-05-30 17:48:54	2020-05-30	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	27847	delivery	5	31
70525	2020-05-30 17:51:50	2020-05-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	27849	delivery	5	31
70526	2020-05-30 17:54:29	2020-05-30	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	18050	delivery	5	22
70527	2020-05-30 17:54:32	2020-05-30	14	[{"id_menu":2,"count":1}]	3403	delivery	5	19
70528	2020-05-30 17:54:54	2020-05-30	9	[{"id_menu":7,"count":1}]	27798	delivery	5	14
70529	2020-05-30 17:55:21	2020-05-30	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	10433	delivery	5	31
70530	2020-05-30 17:55:39	2020-05-30	12	[{"id_menu":1,"count":1}]	26090	delivery	5	17
70531	2020-05-30 17:56:21	2020-05-30	14	[{"id_menu":2,"count":1}]	27880	delivery	5	19
70532	2020-05-30 17:57:22	2020-05-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	27817	delivery	5	23
70533	2020-05-30 18:00:42	2020-05-30	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6231	delivery	5	43
70534	2020-05-30 18:01:51	2020-05-30	12	[{"id_menu":1,"count":1}]	27794	delivery	5	17
70535	2020-05-30 18:02:05	2020-05-30	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	4551	pick-up	0	24
70536	2020-05-30 18:03:15	2020-05-30	8	[{"id_menu":5,"count":1}]	13996	pick-up	0	8
70537	2020-05-30 18:03:56	2020-05-30	14	[{"id_menu":2,"count":1}]	27826	pick-up	0	14
70538	2020-05-30 18:06:01	2020-05-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	27923	delivery	5	31
70539	2020-05-30 18:09:37	2020-05-30	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":2}]	27772	delivery	5	31
70540	2020-05-30 18:14:43	2020-05-30	8	[{"id_menu":5,"count":1}]	3570	pick-up	0	8
70541	2020-05-30 18:15:05	2020-05-30	9	[{"id_menu":7,"count":1}]	256	pick-up	0	9
70542	2020-05-30 18:17:05	2020-05-30	17	[{"id_menu":4,"count":1}]	4161	pick-up	0	17
70543	2020-05-30 18:19:37	2020-05-30	9	[{"id_menu":7,"count":1}]	14118	delivery	5	14
70544	2020-05-30 18:23:51	2020-05-30	14	[{"id_menu":2,"count":1}]	22865	delivery	5	19
70545	2020-05-30 18:25:34	2020-05-30	12	[{"id_menu":1,"count":1}]	27975	delivery	5	17
70546	2020-05-30 18:25:35	2020-05-30	12	[{"id_menu":1,"count":1}]	15361	delivery	5	17
70547	2020-05-30 18:27:53	2020-05-30	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2987	delivery	5	26
70548	2020-05-30 18:28:26	2020-05-30	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	3066	pick-up	0	29
70549	2020-05-30 18:31:19	2020-05-30	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24276	delivery	5	43
70550	2020-05-30 18:31:40	2020-05-30	9	[{"id_menu":7,"count":1}]	14535	delivery	5	14
70551	2020-05-30 18:33:44	2020-05-30	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	27780	delivery	5	25
70552	2020-05-30 18:34:34	2020-05-30	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	27850	delivery	5	29
70553	2020-05-30 18:35:41	2020-05-30	9	[{"id_menu":6,"count":1}]	27938	delivery	5	14
70554	2020-05-30 18:38:21	2020-05-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	27771	delivery	5	28
70555	2020-05-30 18:43:37	2020-05-30	8	[{"id_menu":5,"count":1}]	13940	pick-up	0	8
70556	2020-05-30 18:47:06	2020-05-30	9	[{"id_menu":7,"count":1}]	8813	delivery	5	14
70557	2020-05-30 18:51:53	2020-05-30	12	[{"id_menu":1,"count":1}]	27784	delivery	5	17
70558	2020-05-30 18:51:54	2020-05-30	12	[{"id_menu":3,"count":1}]	12028	pick-up	0	12
70559	2020-05-30 18:54:10	2020-05-30	14	[{"id_menu":2,"count":2}]	27865	delivery	5	19
70560	2020-05-30 18:54:50	2020-05-30	14	[{"id_menu":2,"count":1}]	227	delivery	5	19
70561	2020-05-30 18:55:32	2020-05-30	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	17094	delivery	5	35
70562	2020-05-30 18:57:11	2020-05-30	8	[{"id_menu":5,"count":1}]	27895	delivery	5	13
70563	2020-05-30 19:03:05	2020-05-30	9	[{"id_menu":7,"count":1}]	27829	delivery	5	14
70564	2020-05-30 19:08:13	2020-05-30	17	[{"id_menu":4,"count":1}]	24073	delivery	5	22
70565	2020-05-30 19:10:50	2020-05-30	17	[{"id_menu":4,"count":1}]	22306	delivery	5	22
70566	2020-05-30 19:12:04	2020-05-30	9	[{"id_menu":7,"count":1}]	9121	delivery	5	14
70567	2020-05-30 19:16:41	2020-05-30	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	27890	delivery	5	34
70568	2020-05-30 19:18:25	2020-05-30	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	13424	delivery	5	29
70569	2020-05-30 19:20:06	2020-05-30	9	[{"id_menu":6,"count":1}]	17551	delivery	5	14
70570	2020-05-30 19:21:52	2020-05-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	27971	pick-up	0	23
70571	2020-05-30 19:28:20	2020-05-30	17	[{"id_menu":4,"count":2}]	27952	delivery	5	22
70572	2020-05-30 19:29:35	2020-05-30	9	[{"id_menu":7,"count":1}]	23501	delivery	5	14
70573	2020-05-30 19:31:35	2020-05-30	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	26068	delivery	5	42
70574	2020-05-30 19:34:07	2020-05-30	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	22841	delivery	5	31
70575	2020-05-30 19:37:23	2020-05-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27943	delivery	5	22
70576	2020-05-30 19:41:58	2020-05-30	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":2}]	27854	delivery	5	31
70577	2020-05-30 19:42:48	2020-05-30	14	[{"id_menu":2,"count":1}]	1269	pick-up	0	14
70578	2020-05-30 19:42:48	2020-05-30	8	[{"id_menu":5,"count":1}]	27861	pick-up	0	8
70579	2020-05-30 19:42:57	2020-05-30	12	[{"id_menu":1,"count":2}]	18981	pick-up	0	12
70580	2020-05-30 19:43:36	2020-05-30	9	[{"id_menu":7,"count":1}]	25119	delivery	5	14
70581	2020-05-30 19:44:38	2020-05-30	9	[{"id_menu":7,"count":1}]	16826	delivery	5	14
70582	2020-05-30 19:44:39	2020-05-30	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18007	delivery	5	22
70583	2020-05-30 19:44:53	2020-05-30	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	397	delivery	5	36
70584	2020-05-30 19:45:20	2020-05-30	14	[{"id_menu":2,"count":1}]	13748	delivery	5	19
70585	2020-05-30 19:45:45	2020-05-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7125	delivery	5	23
70586	2020-05-30 19:49:23	2020-05-30	14	[{"id_menu":2,"count":1}]	23702	delivery	5	19
70587	2020-05-30 19:49:55	2020-05-30	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23998	delivery	5	22
70588	2020-05-30 19:53:16	2020-05-30	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	27773	delivery	5	22
70589	2020-05-30 19:53:58	2020-05-30	8	[{"id_menu":5,"count":1}]	27834	pick-up	0	8
70590	2020-05-30 19:55:34	2020-05-30	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	15511	delivery	5	40
70591	2020-05-30 20:01:37	2020-05-30	9	[{"id_menu":6,"count":1}]	2623	pick-up	0	9
70592	2020-05-30 20:02:02	2020-05-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	17805	pick-up	0	21
70593	2020-05-30 20:03:45	2020-05-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	23926	delivery	5	27
70594	2020-05-30 20:04:48	2020-05-30	12	[{"id_menu":3,"count":1}]	1159	pick-up	0	12
70595	2020-05-30 20:13:20	2020-05-30	9	[{"id_menu":7,"count":1}]	16058	delivery	5	14
70596	2020-05-30 20:14:31	2020-05-30	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	23978	delivery	5	31
70597	2020-05-30 20:14:53	2020-05-30	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	18688	delivery	5	39
70598	2020-05-30 20:15:33	2020-05-30	9	[{"id_menu":6,"count":1}]	4694	delivery	5	14
70599	2020-05-30 20:17:17	2020-05-30	12	[{"id_menu":1,"count":1}]	9280	pick-up	0	12
70600	2020-05-30 20:18:20	2020-05-30	9	[{"id_menu":7,"count":1}]	1055	pick-up	0	9
70601	2020-05-30 20:20:17	2020-05-30	12	[{"id_menu":3,"count":1}]	24506	pick-up	0	12
70602	2020-05-30 20:22:34	2020-05-30	12	[{"id_menu":3,"count":1}]	27803	delivery	5	17
70603	2020-05-30 20:24:44	2020-05-30	17	[{"id_menu":4,"count":1}]	9399	delivery	5	22
70604	2020-05-30 20:30:25	2020-05-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	53	pick-up	0	21
70605	2020-05-30 20:31:16	2020-05-30	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	13771	pick-up	0	20
70606	2020-05-30 20:32:23	2020-05-30	17	[{"id_menu":4,"count":1}]	27920	pick-up	0	17
70607	2020-05-30 20:37:15	2020-05-30	8	[{"id_menu":5,"count":1}]	27928	delivery	5	13
70608	2020-05-30 20:37:33	2020-05-30	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6714	delivery	5	36
70609	2020-05-30 20:38:39	2020-05-30	9	[{"id_menu":6,"count":1}]	12333	delivery	5	14
70610	2020-05-30 20:43:33	2020-05-30	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	4760	delivery	5	31
70611	2020-05-30 20:45:28	2020-05-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	17678	delivery	5	26
70612	2020-05-30 20:46:23	2020-05-30	12	[{"id_menu":1,"count":1}]	22708	pick-up	0	12
70613	2020-05-30 20:47:16	2020-05-30	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2967	pick-up	0	29
70614	2020-05-30 20:48:19	2020-05-30	8	[{"id_menu":5,"count":1}]	20711	delivery	5	13
70615	2020-05-30 20:49:55	2020-05-30	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	17353	delivery	5	26
70616	2020-05-30 20:54:06	2020-05-30	12	[{"id_menu":1,"count":1}]	7678	pick-up	0	12
70617	2020-05-30 20:54:57	2020-05-30	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	27809	delivery	5	40
70618	2020-05-30 20:56:54	2020-05-30	9	[{"id_menu":7,"count":1}]	16408	delivery	5	14
70619	2020-05-30 20:57:24	2020-05-30	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	27779	delivery	5	26
70620	2020-05-30 21:00:08	2020-05-30	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21620	delivery	5	31
70621	2020-05-30 21:06:38	2020-05-30	12	[{"id_menu":1,"count":1}]	27935	delivery	5	17
70622	2020-05-30 21:06:47	2020-05-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	27799	delivery	5	27
70623	2020-05-30 21:07:24	2020-05-30	8	[{"id_menu":5,"count":1}]	27921	delivery	5	13
70624	2020-05-30 21:07:45	2020-05-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8113	delivery	5	22
70625	2020-05-30 21:13:14	2020-05-30	9	[{"id_menu":6,"count":2}]	11911	delivery	5	14
70626	2020-05-30 21:16:53	2020-05-30	8	[{"id_menu":5,"count":1}]	27862	delivery	5	13
70627	2020-05-30 21:19:32	2020-05-30	14	[{"id_menu":2,"count":1}]	15808	delivery	5	19
70628	2020-05-30 21:23:05	2020-05-30	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18064	delivery	5	43
70629	2020-05-30 21:23:53	2020-05-30	9	[{"id_menu":7,"count":1}]	21158	delivery	5	14
70630	2020-05-30 21:25:34	2020-05-30	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	6470	delivery	5	42
70631	2020-05-30 21:25:47	2020-05-30	12	[{"id_menu":1,"count":1}]	5000	delivery	5	17
70632	2020-05-30 21:26:19	2020-05-30	14	[{"id_menu":2,"count":1}]	3567	pick-up	0	14
70633	2020-05-30 21:28:47	2020-05-30	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	27893	delivery	5	40
70634	2020-05-30 21:29:11	2020-05-30	17	[{"id_menu":4,"count":1}]	3997	delivery	5	22
70635	2020-05-30 21:29:59	2020-05-30	14	[{"id_menu":2,"count":1}]	23411	delivery	5	19
70636	2020-05-30 21:34:49	2020-05-30	9	[{"id_menu":7,"count":1}]	25861	delivery	5	14
70637	2020-05-30 21:36:39	2020-05-30	9	[{"id_menu":7,"count":1}]	7886	pick-up	0	9
70638	2020-05-30 21:37:07	2020-05-30	12	[{"id_menu":1,"count":1}]	20619	delivery	5	17
70639	2020-05-30 21:38:42	2020-05-30	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1885	pick-up	0	26
70640	2020-05-30 21:41:54	2020-05-30	9	[{"id_menu":7,"count":1}]	25287	delivery	5	14
70641	2020-05-30 21:49:15	2020-05-30	12	[{"id_menu":3,"count":1}]	16926	pick-up	0	12
70642	2020-05-30 21:50:45	2020-05-30	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	16839	delivery	5	22
70643	2020-05-30 21:52:04	2020-05-30	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	16239	delivery	5	36
70644	2020-05-30 21:54:05	2020-05-30	9	[{"id_menu":7,"count":1}]	27874	delivery	5	14
70645	2020-05-30 21:54:51	2020-05-30	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	26754	delivery	5	48
70646	2020-05-30 21:57:25	2020-05-30	9	[{"id_menu":7,"count":2}]	27878	delivery	5	14
70647	2020-05-30 21:58:27	2020-05-30	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7798	delivery	5	35
70648	2020-05-30 22:01:08	2020-05-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4248	pick-up	0	22
70649	2020-05-30 22:01:48	2020-05-30	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	27797	delivery	5	45
70650	2020-05-30 22:03:10	2020-05-30	14	[{"id_menu":2,"count":1}]	27978	delivery	5	19
70651	2020-05-30 22:04:32	2020-05-30	9	[{"id_menu":7,"count":1}]	27813	delivery	5	14
70652	2020-05-30 22:06:03	2020-05-30	12	[{"id_menu":1,"count":1}]	27777	pick-up	0	12
70653	2020-05-30 22:09:46	2020-05-30	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2139	pick-up	0	29
70654	2020-05-30 22:13:30	2020-05-30	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	5794	delivery	5	22
70655	2020-05-30 22:15:17	2020-05-30	12	[{"id_menu":3,"count":1}]	16217	delivery	5	17
70656	2020-05-30 22:16:05	2020-05-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	11979	delivery	5	28
70657	2020-05-30 22:18:11	2020-05-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2909	delivery	5	31
70658	2020-05-30 22:18:25	2020-05-30	8	[{"id_menu":5,"count":1}]	5570	delivery	5	13
70659	2020-05-30 22:24:11	2020-05-30	17	[{"id_menu":4,"count":1}]	27811	pick-up	0	17
70660	2020-05-30 22:31:08	2020-05-30	17	[{"id_menu":4,"count":1}]	11232	delivery	5	22
70661	2020-05-30 22:33:48	2020-05-30	8	[{"id_menu":5,"count":1}]	4611	pick-up	0	8
70662	2020-05-30 22:35:06	2020-05-30	8	[{"id_menu":5,"count":1}]	27954	delivery	5	13
70663	2020-05-30 22:35:07	2020-05-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	17027	delivery	5	26
70664	2020-05-30 22:38:50	2020-05-30	9	[{"id_menu":6,"count":1}]	23466	delivery	5	14
70665	2020-05-30 22:39:05	2020-05-30	9	[{"id_menu":7,"count":1}]	16834	delivery	5	14
70666	2020-05-30 22:40:30	2020-05-30	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	20215	delivery	5	36
70667	2020-05-30 22:49:55	2020-05-30	9	[{"id_menu":7,"count":1}]	24510	delivery	5	14
70668	2020-05-30 22:51:35	2020-05-30	12	[{"id_menu":1,"count":1}]	4332	delivery	5	17
70669	2020-05-30 22:52:37	2020-05-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	19056	delivery	5	31
70670	2020-05-30 22:56:19	2020-05-30	9	[{"id_menu":7,"count":2}]	6835	delivery	5	14
70671	2020-05-30 22:59:51	2020-05-30	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	10281	pick-up	0	20
70672	2020-05-30 23:01:46	2020-05-30	9	[{"id_menu":6,"count":1}]	13516	delivery	5	14
70673	2020-05-30 23:02:00	2020-05-30	9	[{"id_menu":7,"count":1}]	3803	delivery	5	14
70674	2020-05-30 23:03:29	2020-05-30	9	[{"id_menu":6,"count":2}]	27877	delivery	5	14
70675	2020-05-30 23:09:12	2020-05-30	12	[{"id_menu":1,"count":1}]	27795	delivery	5	17
70676	2020-05-30 23:09:22	2020-05-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	27660	delivery	5	23
70677	2020-05-30 23:14:07	2020-05-30	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18863	delivery	5	43
70678	2020-05-30 23:14:29	2020-05-30	9	[{"id_menu":7,"count":1}]	16827	delivery	5	14
70679	2020-05-30 23:14:31	2020-05-30	9	[{"id_menu":6,"count":1}]	10650	delivery	5	14
70680	2020-05-30 23:17:49	2020-05-30	17	[{"id_menu":4,"count":2}]	22610	pick-up	0	17
70681	2020-05-30 23:20:25	2020-05-30	8	[{"id_menu":5,"count":1}]	27934	delivery	5	13
70682	2020-05-30 23:22:35	2020-05-30	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1705	delivery	5	48
70683	2020-05-30 23:23:08	2020-05-30	17	[{"id_menu":4,"count":1}]	9214	delivery	5	22
70684	2020-05-30 23:23:26	2020-05-30	12	[{"id_menu":3,"count":1}]	515	delivery	5	17
70685	2020-05-30 23:26:13	2020-05-30	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4097	delivery	5	40
70686	2020-05-30 23:26:42	2020-05-30	9	[{"id_menu":6,"count":1}]	27894	delivery	5	14
70687	2020-05-30 23:26:49	2020-05-30	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	21393	delivery	5	42
70688	2020-05-30 23:29:09	2020-05-30	17	[{"id_menu":4,"count":1}]	9688	pick-up	0	17
70689	2020-05-30 23:30:36	2020-05-30	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	27805	pick-up	0	29
70690	2020-05-30 23:30:39	2020-05-30	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	27839	delivery	5	45
70691	2020-05-30 23:34:06	2020-05-30	12	[{"id_menu":3,"count":1}]	27974	delivery	5	17
70692	2020-05-30 23:34:48	2020-05-30	9	[{"id_menu":6,"count":1}]	19931	pick-up	0	9
70693	2020-05-30 23:38:41	2020-05-30	8	[{"id_menu":5,"count":1}]	14364	pick-up	0	8
70694	2020-05-30 23:39:58	2020-05-30	12	[{"id_menu":1,"count":1}]	27887	delivery	5	17
70695	2020-05-30 23:40:43	2020-05-30	17	[{"id_menu":4,"count":1}]	14284	pick-up	0	17
70696	2020-05-30 23:41:38	2020-05-30	9	[{"id_menu":6,"count":1}]	11666	delivery	5	14
70697	2020-05-30 23:44:52	2020-05-30	8	[{"id_menu":5,"count":1}]	15666	delivery	5	13
70698	2020-05-30 23:47:22	2020-05-30	14	[{"id_menu":2,"count":1}]	27838	delivery	5	19
70699	2020-05-30 23:48:27	2020-05-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	19463	delivery	5	27
70700	2020-05-30 23:49:27	2020-05-30	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	27956	delivery	5	51
70701	2020-05-30 23:50:36	2020-05-30	14	[{"id_menu":2,"count":1}]	2519	pick-up	0	14
70702	2020-05-30 23:51:22	2020-05-30	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	17415	pick-up	0	21
70703	2020-05-30 23:53:47	2020-05-30	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	27097	delivery	5	42
70704	2020-05-30 23:54:43	2020-05-30	12	[{"id_menu":1,"count":1}]	2684	pick-up	0	12
70705	2020-05-30 23:55:20	2020-05-30	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4683	delivery	5	34
70706	2020-05-30 23:59:17	2020-05-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	27911	delivery	5	31
70707	2020-05-31 00:05:28	2020-05-31	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	28136	delivery	5	25
70708	2020-05-31 00:09:02	2020-05-31	8	[{"id_menu":5,"count":1}]	26580	delivery	5	13
70709	2020-05-31 00:18:12	2020-05-31	12	[{"id_menu":3,"count":1}]	1021	pick-up	0	12
70710	2020-05-31 00:18:46	2020-05-31	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	5527	delivery	5	40
70711	2020-05-31 00:20:47	2020-05-31	12	[{"id_menu":1,"count":1}]	1450	pick-up	0	12
70712	2020-05-31 00:22:36	2020-05-31	8	[{"id_menu":5,"count":1}]	28067	delivery	5	13
70713	2020-05-31 00:24:03	2020-05-31	12	[{"id_menu":3,"count":1}]	14396	delivery	5	17
70714	2020-05-31 00:25:08	2020-05-31	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	28121	delivery	5	40
70715	2020-05-31 00:26:40	2020-05-31	8	[{"id_menu":5,"count":1}]	23758	delivery	5	13
70716	2020-05-31 00:30:44	2020-05-31	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	12690	pick-up	0	23
70717	2020-05-31 00:31:21	2020-05-31	12	[{"id_menu":3,"count":1}]	28013	delivery	5	17
70718	2020-05-31 00:33:34	2020-05-31	9	[{"id_menu":6,"count":1}]	18758	pick-up	0	9
70719	2020-05-31 00:33:53	2020-05-31	14	[{"id_menu":2,"count":1}]	1032	pick-up	0	14
70720	2020-05-31 00:35:30	2020-05-31	9	[{"id_menu":7,"count":1}]	7919	pick-up	0	9
70721	2020-05-31 00:37:40	2020-05-31	9	[{"id_menu":7,"count":1}]	21257	delivery	5	14
70722	2020-05-31 00:39:03	2020-05-31	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	27217	delivery	5	36
70723	2020-05-31 00:40:34	2020-05-31	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2748	delivery	5	31
70724	2020-05-31 00:40:56	2020-05-31	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	28055	delivery	5	28
70725	2020-05-31 00:42:41	2020-05-31	14	[{"id_menu":2,"count":1}]	26967	delivery	5	19
70726	2020-05-31 00:45:47	2020-05-31	9	[{"id_menu":6,"count":1}]	25534	delivery	5	14
70727	2020-05-31 00:48:50	2020-05-31	17	[{"id_menu":4,"count":1}]	28080	delivery	5	22
70728	2020-05-31 00:50:15	2020-05-31	17	[{"id_menu":5,"count":3},{"id_menu":6,"count":1}]	28152	delivery	5	22
70729	2020-05-31 00:50:53	2020-05-31	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28085	delivery	5	40
70730	2020-05-31 00:51:31	2020-05-31	9	[{"id_menu":7,"count":1}]	20598	pick-up	0	9
70731	2020-05-31 00:51:56	2020-05-31	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	28009	delivery	5	31
70732	2020-05-31 00:56:27	2020-05-31	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17562	delivery	5	45
70733	2020-05-31 00:58:12	2020-05-31	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	27987	delivery	5	34
70734	2020-05-31 01:00:13	2020-05-31	17	[{"id_menu":4,"count":1}]	4495	delivery	5	22
70735	2020-05-31 01:04:10	2020-05-31	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27980	delivery	5	36
70736	2020-05-31 01:10:27	2020-05-31	8	[{"id_menu":5,"count":3}]	28135	delivery	5	13
70737	2020-05-31 01:14:18	2020-05-31	17	[{"id_menu":4,"count":1}]	23585	pick-up	0	17
70738	2020-05-31 01:16:51	2020-05-31	12	[{"id_menu":1,"count":1}]	171	delivery	5	17
70739	2020-05-31 01:18:49	2020-05-31	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	9716	pick-up	0	38
70740	2020-05-31 01:22:35	2020-05-31	17	[{"id_menu":4,"count":1}]	28036	delivery	5	22
70741	2020-05-31 01:24:57	2020-05-31	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	28131	delivery	5	46
70742	2020-05-31 01:26:34	2020-05-31	9	[{"id_menu":7,"count":1}]	28083	pick-up	0	9
70743	2020-05-31 01:30:52	2020-05-31	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28078	delivery	5	54
70744	2020-05-31 01:31:55	2020-05-31	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28114	pick-up	0	42
70745	2020-05-31 01:31:56	2020-05-31	8	[{"id_menu":5,"count":1}]	7351	delivery	5	13
70746	2020-05-31 01:32:05	2020-05-31	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	28148	delivery	5	40
70747	2020-05-31 01:38:04	2020-05-31	9	[{"id_menu":7,"count":1}]	28057	delivery	5	14
70748	2020-05-31 01:41:55	2020-05-31	12	[{"id_menu":1,"count":1}]	28038	delivery	5	17
70749	2020-05-31 01:42:15	2020-05-31	8	[{"id_menu":5,"count":1}]	26555	delivery	5	13
70750	2020-05-31 01:43:08	2020-05-31	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	28139	delivery	5	40
70751	2020-05-31 01:43:21	2020-05-31	14	[{"id_menu":2,"count":1}]	2662	pick-up	0	14
70752	2020-05-31 01:45:08	2020-05-31	12	[{"id_menu":3,"count":1}]	13100	delivery	5	17
70753	2020-05-31 01:46:26	2020-05-31	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	27589	pick-up	0	21
70754	2020-05-31 01:55:29	2020-05-31	17	[{"id_menu":4,"count":1}]	8706	pick-up	0	17
70755	2020-05-31 01:58:03	2020-05-31	8	[{"id_menu":5,"count":2}]	28094	delivery	5	13
70756	2020-05-31 02:00:13	2020-05-31	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	12185	delivery	5	36
70757	2020-05-31 02:00:27	2020-05-31	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	13455	delivery	5	40
70758	2020-05-31 02:01:46	2020-05-31	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	28102	delivery	5	26
70759	2020-05-31 02:04:09	2020-05-31	14	[{"id_menu":2,"count":1}]	18679	delivery	5	19
70760	2020-05-31 02:05:07	2020-05-31	9	[{"id_menu":7,"count":1}]	28021	delivery	5	14
70761	2020-05-31 02:07:06	2020-05-31	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	7119	pick-up	0	26
70762	2020-05-31 02:07:39	2020-05-31	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	10268	delivery	5	27
70763	2020-05-31 02:09:32	2020-05-31	9	[{"id_menu":7,"count":1}]	24323	delivery	5	14
70764	2020-05-31 02:19:39	2020-05-31	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28112	delivery	5	48
70765	2020-05-31 02:22:57	2020-05-31	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2564	pick-up	0	26
70766	2020-05-31 02:23:01	2020-05-31	9	[{"id_menu":7,"count":1}]	28091	pick-up	0	9
70767	2020-05-31 02:23:13	2020-05-31	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	9523	pick-up	0	26
70768	2020-05-31 02:23:34	2020-05-31	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	28030	pick-up	0	20
70769	2020-05-31 02:26:24	2020-05-31	17	[{"id_menu":4,"count":1}]	11635	delivery	5	22
70770	2020-05-31 02:26:36	2020-05-31	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	10857	delivery	5	52
70771	2020-05-31 02:27:46	2020-05-31	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	28089	delivery	5	36
70772	2020-05-31 02:28:42	2020-05-31	12	[{"id_menu":3,"count":1}]	13674	delivery	5	17
70773	2020-05-31 02:29:25	2020-05-31	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2556	delivery	5	31
70774	2020-05-31 02:31:11	2020-05-31	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23614	delivery	5	39
70775	2020-05-31 02:31:34	2020-05-31	17	[{"id_menu":4,"count":1}]	28090	delivery	5	22
70776	2020-05-31 02:32:39	2020-05-31	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28086	delivery	5	36
70777	2020-05-31 02:32:42	2020-05-31	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22639	delivery	5	36
70778	2020-05-31 02:34:42	2020-05-31	9	[{"id_menu":7,"count":1}]	23279	delivery	5	14
70779	2020-05-31 02:43:19	2020-05-31	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15567	delivery	5	57
70780	2020-05-31 02:43:21	2020-05-31	12	[{"id_menu":3,"count":1}]	27565	delivery	5	17
70781	2020-05-31 02:43:49	2020-05-31	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12815	delivery	5	36
70782	2020-05-31 02:44:04	2020-05-31	17	[{"id_menu":4,"count":1}]	1640	pick-up	0	17
70783	2020-05-31 02:45:03	2020-05-31	8	[{"id_menu":5,"count":1}]	27991	delivery	5	13
70784	2020-05-31 02:50:46	2020-05-31	12	[{"id_menu":1,"count":1}]	28097	pick-up	0	12
70785	2020-05-31 02:51:26	2020-05-31	9	[{"id_menu":7,"count":1}]	28032	delivery	5	14
70786	2020-05-31 02:57:20	2020-05-31	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	24413	delivery	5	28
70787	2020-05-31 03:01:29	2020-05-31	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	1269	pick-up	0	26
70788	2020-05-31 03:05:16	2020-05-31	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16346	delivery	5	23
70789	2020-05-31 03:06:07	2020-05-31	9	[{"id_menu":6,"count":1}]	5729	pick-up	0	9
70790	2020-05-31 03:06:46	2020-05-31	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2695	delivery	5	34
70791	2020-05-31 03:10:36	2020-05-31	17	[{"id_menu":4,"count":2}]	1232	delivery	5	22
70792	2020-05-31 03:10:56	2020-05-31	17	[{"id_menu":4,"count":1}]	28115	delivery	5	22
70793	2020-05-31 03:11:05	2020-05-31	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21201	delivery	5	34
70794	2020-05-31 03:15:02	2020-05-31	9	[{"id_menu":7,"count":1}]	9847	pick-up	0	9
70795	2020-05-31 03:22:30	2020-05-31	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2827	delivery	5	27
70796	2020-05-31 03:25:21	2020-05-31	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23507	delivery	5	37
70797	2020-05-31 03:25:23	2020-05-31	12	[{"id_menu":3,"count":1}]	28111	delivery	5	17
70798	2020-05-31 03:31:48	2020-05-31	17	[{"id_menu":4,"count":1}]	2682	pick-up	0	17
70799	2020-05-31 03:34:32	2020-05-31	9	[{"id_menu":7,"count":1}]	24922	delivery	5	14
70800	2020-05-31 03:36:27	2020-05-31	39	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3971	delivery	5	44
70801	2020-05-31 03:36:30	2020-05-31	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	27114	delivery	5	26
70802	2020-05-31 03:41:08	2020-05-31	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28082	delivery	5	31
70803	2020-05-31 03:45:21	2020-05-31	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28068	delivery	5	34
70804	2020-05-31 03:47:57	2020-05-31	9	[{"id_menu":6,"count":1}]	28028	delivery	5	14
70805	2020-05-31 03:49:05	2020-05-31	14	[{"id_menu":2,"count":1}]	1968	delivery	5	19
70806	2020-05-31 03:49:40	2020-05-31	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	5144	delivery	5	31
70807	2020-05-31 03:56:04	2020-05-31	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5664	delivery	5	23
70808	2020-05-31 03:57:17	2020-05-31	8	[{"id_menu":5,"count":1}]	4356	pick-up	0	8
70809	2020-05-31 04:07:48	2020-05-31	17	[{"id_menu":4,"count":1}]	25827	pick-up	0	17
70810	2020-05-31 04:08:00	2020-05-31	14	[{"id_menu":2,"count":1}]	12483	delivery	5	19
70811	2020-05-31 04:09:01	2020-05-31	14	[{"id_menu":2,"count":1}]	18314	delivery	5	19
70812	2020-05-31 04:11:02	2020-05-31	9	[{"id_menu":7,"count":1}]	28134	delivery	5	14
70813	2020-05-31 04:11:17	2020-05-31	9	[{"id_menu":6,"count":1}]	17243	delivery	5	14
70814	2020-05-31 04:18:58	2020-05-31	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5661	delivery	5	42
70815	2020-05-31 04:22:14	2020-05-31	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	8748	delivery	5	25
70816	2020-05-31 04:22:39	2020-05-31	9	[{"id_menu":6,"count":1}]	26146	delivery	5	14
70817	2020-05-31 04:23:03	2020-05-31	14	[{"id_menu":2,"count":1}]	11220	delivery	5	19
70818	2020-05-31 04:26:24	2020-05-31	9	[{"id_menu":6,"count":1}]	28137	pick-up	0	9
70819	2020-05-31 04:30:39	2020-05-31	14	[{"id_menu":2,"count":1}]	18292	pick-up	0	14
70820	2020-05-31 04:32:01	2020-05-31	14	[{"id_menu":2,"count":1}]	2186	pick-up	0	14
70821	2020-05-31 04:33:14	2020-05-31	9	[{"id_menu":6,"count":1}]	28110	delivery	5	14
70822	2020-05-31 04:39:04	2020-05-31	12	[{"id_menu":1,"count":1}]	11046	delivery	5	17
70823	2020-05-31 04:40:09	2020-05-31	17	[{"id_menu":4,"count":1}]	2082	pick-up	0	17
70824	2020-05-31 04:45:17	2020-05-31	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	14366	delivery	5	25
70825	2020-05-31 04:45:52	2020-05-31	17	[{"id_menu":4,"count":1}]	379	pick-up	0	17
70826	2020-05-31 04:49:49	2020-05-31	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28058	delivery	5	35
70827	2020-05-31 04:50:41	2020-05-31	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27011	delivery	5	48
70828	2020-05-31 04:51:11	2020-05-31	17	[{"id_menu":4,"count":1}]	542	delivery	5	22
70829	2020-05-31 04:51:49	2020-05-31	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1654	pick-up	0	23
70830	2020-05-31 04:54:08	2020-05-31	9	[{"id_menu":6,"count":1}]	16675	delivery	5	14
70831	2020-05-31 04:56:53	2020-05-31	9	[{"id_menu":7,"count":1}]	7854	pick-up	0	9
70832	2020-05-31 05:00:05	2020-05-31	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27951	delivery	5	34
70833	2020-05-31 05:02:28	2020-05-31	9	[{"id_menu":6,"count":1}]	28049	delivery	5	14
70834	2020-05-31 05:03:50	2020-05-31	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	21700	delivery	5	28
70835	2020-05-31 05:04:01	2020-05-31	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	28035	delivery	5	28
70836	2020-05-31 05:05:08	2020-05-31	12	[{"id_menu":1,"count":2}]	1053	delivery	5	17
70837	2020-05-31 05:12:32	2020-05-31	14	[{"id_menu":2,"count":1}]	15253	delivery	5	19
70838	2020-05-31 05:12:57	2020-05-31	12	[{"id_menu":1,"count":1}]	19464	delivery	5	17
70839	2020-05-31 05:13:46	2020-05-31	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	17421	delivery	5	28
70840	2020-05-31 05:13:53	2020-05-31	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	28099	pick-up	0	40
70841	2020-05-31 05:19:15	2020-05-31	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	16754	delivery	5	26
70842	2020-05-31 05:26:04	2020-05-31	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28145	delivery	5	23
70843	2020-05-31 05:27:50	2020-05-31	17	[{"id_menu":4,"count":1}]	3042	delivery	5	22
70844	2020-05-31 05:28:26	2020-05-31	17	[{"id_menu":4,"count":1}]	16679	delivery	5	22
70845	2020-05-31 05:30:33	2020-05-31	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8799	delivery	5	31
70846	2020-05-31 05:37:15	2020-05-31	12	[{"id_menu":1,"count":1}]	4967	pick-up	0	12
70847	2020-05-31 05:38:09	2020-05-31	31	[{"id_menu":2,"count":3},{"id_menu":4,"count":1}]	22534	delivery	5	36
70848	2020-05-31 05:39:05	2020-05-31	17	[{"id_menu":4,"count":1}]	2538	delivery	5	22
70849	2020-05-31 05:40:21	2020-05-31	14	[{"id_menu":2,"count":1}]	5253	pick-up	0	14
70850	2020-05-31 05:41:39	2020-05-31	12	[{"id_menu":3,"count":1}]	28050	delivery	5	17
70851	2020-05-31 05:41:49	2020-05-31	17	[{"id_menu":4,"count":1}]	14935	delivery	5	22
70852	2020-05-31 05:41:56	2020-05-31	9	[{"id_menu":7,"count":1}]	28100	delivery	5	14
70853	2020-05-31 05:46:57	2020-05-31	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27992	pick-up	0	32
70854	2020-05-31 05:48:43	2020-05-31	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	23551	delivery	5	36
70855	2020-05-31 05:49:15	2020-05-31	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16107	delivery	5	35
70856	2020-05-31 05:50:38	2020-05-31	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17288	delivery	5	22
70857	2020-05-31 05:52:07	2020-05-31	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	17446	delivery	5	28
70858	2020-05-31 05:56:40	2020-05-31	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	12502	pick-up	0	23
70859	2020-05-31 05:59:47	2020-05-31	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	28023	delivery	5	28
70860	2020-05-31 06:00:38	2020-05-31	14	[{"id_menu":2,"count":1}]	16501	pick-up	0	14
70861	2020-05-31 06:01:03	2020-05-31	9	[{"id_menu":7,"count":1}]	18633	delivery	5	14
70862	2020-05-31 06:01:18	2020-05-31	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	27970	delivery	5	28
70863	2020-05-31 06:05:06	2020-05-31	8	[{"id_menu":5,"count":1}]	21912	delivery	5	13
70864	2020-05-31 06:06:17	2020-05-31	9	[{"id_menu":7,"count":1}]	23362	delivery	5	14
70865	2020-05-31 06:06:52	2020-05-31	12	[{"id_menu":3,"count":1}]	4863	pick-up	0	12
70866	2020-05-31 06:07:32	2020-05-31	8	[{"id_menu":5,"count":1}]	25741	pick-up	0	8
70867	2020-05-31 06:07:49	2020-05-31	9	[{"id_menu":6,"count":1}]	20595	delivery	5	14
70868	2020-05-31 06:09:03	2020-05-31	9	[{"id_menu":7,"count":3}]	28108	delivery	5	14
70869	2020-05-31 06:11:40	2020-05-31	17	[{"id_menu":4,"count":1}]	21637	delivery	5	22
70870	2020-05-31 06:13:27	2020-05-31	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	7048	delivery	5	26
70871	2020-05-31 06:17:49	2020-05-31	8	[{"id_menu":5,"count":1}]	401	pick-up	0	8
70872	2020-05-31 06:18:33	2020-05-31	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	28018	pick-up	0	21
70873	2020-05-31 06:20:43	2020-05-31	8	[{"id_menu":5,"count":1}]	3820	pick-up	0	8
70874	2020-05-31 06:22:05	2020-05-31	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":3}]	15083	delivery	5	22
70875	2020-05-31 06:23:50	2020-05-31	14	[{"id_menu":2,"count":1}]	25360	pick-up	0	14
70876	2020-05-31 06:26:13	2020-05-31	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8993	delivery	5	22
70877	2020-05-31 06:29:49	2020-05-31	9	[{"id_menu":6,"count":1}]	4972	delivery	5	14
70878	2020-05-31 06:30:12	2020-05-31	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	5817	delivery	5	22
70879	2020-05-31 06:30:46	2020-05-31	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	25018	delivery	5	28
70880	2020-05-31 06:31:09	2020-05-31	17	[{"id_menu":4,"count":1}]	28105	delivery	5	22
70881	2020-05-31 06:36:28	2020-05-31	8	[{"id_menu":5,"count":1}]	27984	delivery	5	13
70882	2020-05-31 06:40:46	2020-05-31	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	28065	pick-up	0	24
70883	2020-05-31 06:53:33	2020-05-31	12	[{"id_menu":1,"count":1}]	11446	pick-up	0	12
70884	2020-05-31 06:58:08	2020-05-31	9	[{"id_menu":6,"count":1}]	28103	delivery	5	14
70885	2020-05-31 06:58:21	2020-05-31	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	8394	pick-up	0	29
70886	2020-05-31 07:00:19	2020-05-31	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	22090	delivery	5	34
70887	2020-05-31 07:01:15	2020-05-31	14	[{"id_menu":2,"count":1}]	4090	delivery	5	19
70888	2020-05-31 07:02:05	2020-05-31	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7491	delivery	5	36
70889	2020-05-31 07:05:47	2020-05-31	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18821	delivery	5	23
70890	2020-05-31 07:06:36	2020-05-31	12	[{"id_menu":1,"count":1}]	1356	delivery	5	17
70891	2020-05-31 07:10:19	2020-05-31	12	[{"id_menu":1,"count":1}]	28015	delivery	5	17
70892	2020-05-31 07:11:56	2020-05-31	9	[{"id_menu":7,"count":1}]	2185	pick-up	0	9
70893	2020-05-31 07:12:46	2020-05-31	8	[{"id_menu":5,"count":1}]	9769	delivery	5	13
70894	2020-05-31 07:13:54	2020-05-31	8	[{"id_menu":5,"count":1}]	28012	delivery	5	13
70895	2020-05-31 07:14:22	2020-05-31	14	[{"id_menu":2,"count":1}]	6687	pick-up	0	14
70896	2020-05-31 07:16:30	2020-05-31	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1215	delivery	5	44
70897	2020-05-31 07:17:22	2020-05-31	9	[{"id_menu":6,"count":1}]	10620	delivery	5	14
70898	2020-05-31 07:18:59	2020-05-31	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	22177	delivery	5	43
70899	2020-05-31 07:21:18	2020-05-31	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13859	delivery	5	39
70900	2020-05-31 07:21:33	2020-05-31	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21175	delivery	5	35
70901	2020-05-31 07:26:48	2020-05-31	9	[{"id_menu":6,"count":1}]	14493	delivery	5	14
70902	2020-05-31 07:28:10	2020-05-31	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17031	delivery	5	40
70903	2020-05-31 07:28:41	2020-05-31	9	[{"id_menu":7,"count":1}]	14947	pick-up	0	9
70904	2020-05-31 07:29:51	2020-05-31	9	[{"id_menu":6,"count":2}]	12198	delivery	5	14
70905	2020-05-31 07:30:21	2020-05-31	8	[{"id_menu":5,"count":1}]	21536	delivery	5	13
70906	2020-05-31 07:34:00	2020-05-31	8	[{"id_menu":5,"count":1}]	13895	delivery	5	13
70907	2020-05-31 07:34:07	2020-05-31	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	28128	delivery	5	25
70908	2020-05-31 07:34:32	2020-05-31	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16732	delivery	5	34
70909	2020-05-31 07:37:10	2020-05-31	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	9206	delivery	5	45
70910	2020-05-31 07:38:10	2020-05-31	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28024	delivery	5	23
70911	2020-05-31 07:38:42	2020-05-31	14	[{"id_menu":2,"count":2}]	2616	pick-up	0	14
70912	2020-05-31 07:38:45	2020-05-31	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	9996	delivery	5	34
70913	2020-05-31 07:39:51	2020-05-31	9	[{"id_menu":6,"count":1}]	28064	delivery	5	14
70914	2020-05-31 07:40:22	2020-05-31	17	[{"id_menu":4,"count":1}]	28037	delivery	5	22
70915	2020-05-31 07:45:01	2020-05-31	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	28022	delivery	5	28
70916	2020-05-31 07:45:25	2020-05-31	14	[{"id_menu":2,"count":1}]	3260	pick-up	0	14
70917	2020-05-31 07:50:08	2020-05-31	8	[{"id_menu":5,"count":1}]	7931	pick-up	0	8
70918	2020-05-31 08:04:20	2020-05-31	9	[{"id_menu":6,"count":1}]	27995	delivery	5	14
70919	2020-05-31 08:10:55	2020-05-31	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	23615	delivery	5	26
70920	2020-05-31 08:11:58	2020-05-31	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	28087	delivery	5	34
70921	2020-05-31 08:14:23	2020-05-31	12	[{"id_menu":3,"count":1}]	13555	delivery	5	17
70922	2020-05-31 08:16:20	2020-05-31	14	[{"id_menu":2,"count":1}]	6173	pick-up	0	14
70923	2020-05-31 08:20:29	2020-05-31	12	[{"id_menu":1,"count":1}]	3479	delivery	5	17
70924	2020-05-31 08:20:49	2020-05-31	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28014	delivery	5	51
70925	2020-05-31 08:25:03	2020-05-31	14	[{"id_menu":2,"count":1}]	12176	delivery	5	19
70926	2020-05-31 08:25:37	2020-05-31	9	[{"id_menu":6,"count":1}]	28046	delivery	5	14
70927	2020-05-31 08:26:57	2020-05-31	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	28138	delivery	5	26
70928	2020-05-31 08:35:23	2020-05-31	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":3}]	27918	delivery	5	31
70929	2020-05-31 08:35:23	2020-05-31	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28122	delivery	5	22
70930	2020-05-31 08:37:34	2020-05-31	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	22680	delivery	5	31
70931	2020-05-31 08:43:06	2020-05-31	12	[{"id_menu":3,"count":1}]	23147	delivery	5	17
70932	2020-05-31 08:43:07	2020-05-31	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2708	pick-up	0	26
70933	2020-05-31 08:43:28	2020-05-31	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14702	delivery	5	43
70934	2020-05-31 08:43:40	2020-05-31	8	[{"id_menu":5,"count":1}]	21600	pick-up	0	8
70935	2020-05-31 08:44:07	2020-05-31	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	7279	delivery	5	34
70936	2020-05-31 08:45:27	2020-05-31	9	[{"id_menu":6,"count":1}]	8320	delivery	5	14
70937	2020-05-31 08:45:51	2020-05-31	9	[{"id_menu":7,"count":1}]	28146	delivery	5	14
70938	2020-05-31 08:51:21	2020-05-31	8	[{"id_menu":5,"count":1}]	8100	delivery	5	13
70939	2020-05-31 08:51:35	2020-05-31	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	17488	delivery	5	45
70940	2020-05-31 08:52:49	2020-05-31	9	[{"id_menu":6,"count":1}]	21358	delivery	5	14
70941	2020-05-31 08:56:15	2020-05-31	12	[{"id_menu":1,"count":1}]	27982	delivery	5	17
70942	2020-05-31 08:56:47	2020-05-31	9	[{"id_menu":7,"count":1}]	4395	pick-up	0	9
70943	2020-05-31 08:59:31	2020-05-31	12	[{"id_menu":3,"count":1}]	11010	delivery	5	17
70944	2020-05-31 09:00:19	2020-05-31	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	28142	delivery	5	26
70945	2020-05-31 09:00:38	2020-05-31	12	[{"id_menu":3,"count":1}]	7601	pick-up	0	12
70946	2020-05-31 09:03:52	2020-05-31	8	[{"id_menu":5,"count":1}]	18522	pick-up	0	8
70947	2020-05-31 09:05:14	2020-05-31	12	[{"id_menu":1,"count":1}]	6156	pick-up	0	12
70948	2020-05-31 09:06:15	2020-05-31	12	[{"id_menu":3,"count":1}]	25085	delivery	5	17
70949	2020-05-31 09:07:28	2020-05-31	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10652	delivery	5	31
70950	2020-05-31 09:08:03	2020-05-31	9	[{"id_menu":7,"count":1}]	28070	delivery	5	14
70951	2020-05-31 09:12:06	2020-05-31	9	[{"id_menu":6,"count":1}]	28019	delivery	5	14
70952	2020-05-31 09:13:00	2020-05-31	14	[{"id_menu":2,"count":1}]	2578	delivery	5	19
70953	2020-05-31 09:14:39	2020-05-31	9	[{"id_menu":7,"count":1}]	5032	delivery	5	14
70954	2020-05-31 09:16:13	2020-05-31	9	[{"id_menu":7,"count":1}]	27994	delivery	5	14
70955	2020-05-31 09:17:30	2020-05-31	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28039	delivery	5	22
70956	2020-05-31 09:20:00	2020-05-31	9	[{"id_menu":6,"count":1}]	10283	pick-up	0	9
70957	2020-05-31 09:20:36	2020-05-31	12	[{"id_menu":1,"count":1}]	7406	delivery	5	17
70958	2020-05-31 09:25:09	2020-05-31	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17734	delivery	5	49
70959	2020-05-31 09:25:42	2020-05-31	8	[{"id_menu":5,"count":1}]	4445	pick-up	0	8
70960	2020-05-31 09:27:17	2020-05-31	9	[{"id_menu":7,"count":1}]	21550	delivery	5	14
70961	2020-05-31 09:29:40	2020-05-31	14	[{"id_menu":2,"count":1}]	28059	pick-up	0	14
70962	2020-05-31 09:29:52	2020-05-31	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	28071	delivery	5	43
70963	2020-05-31 09:30:36	2020-05-31	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	28123	delivery	5	31
70964	2020-05-31 09:31:10	2020-05-31	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	7717	delivery	5	35
70965	2020-05-31 09:40:10	2020-05-31	9	[{"id_menu":6,"count":1}]	28010	pick-up	0	9
70966	2020-05-31 09:40:18	2020-05-31	17	[{"id_menu":4,"count":1}]	27460	delivery	5	22
70967	2020-05-31 09:45:33	2020-05-31	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28107	delivery	5	39
70968	2020-05-31 09:45:57	2020-05-31	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	27289	delivery	5	27
70969	2020-05-31 09:52:14	2020-05-31	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	28075	pick-up	0	43
70970	2020-05-31 09:53:59	2020-05-31	12	[{"id_menu":1,"count":1}]	18658	delivery	5	17
70971	2020-05-31 09:57:36	2020-05-31	9	[{"id_menu":6,"count":1}]	5474	pick-up	0	9
70972	2020-05-31 09:58:01	2020-05-31	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	13634	delivery	5	36
70973	2020-05-31 09:59:15	2020-05-31	9	[{"id_menu":6,"count":1}]	8316	delivery	5	14
70974	2020-05-31 10:02:23	2020-05-31	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	23831	pick-up	0	31
70975	2020-05-31 10:04:24	2020-05-31	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10851	delivery	5	30
70976	2020-05-31 10:04:35	2020-05-31	14	[{"id_menu":2,"count":1}]	25569	delivery	5	19
70977	2020-05-31 10:09:06	2020-05-31	17	[{"id_menu":4,"count":1}]	9160	pick-up	0	17
70978	2020-05-31 10:11:37	2020-05-31	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10670	delivery	5	23
70979	2020-05-31 10:11:51	2020-05-31	14	[{"id_menu":2,"count":1}]	1500	delivery	5	19
70980	2020-05-31 10:15:09	2020-05-31	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	23835	delivery	5	25
70981	2020-05-31 10:18:08	2020-05-31	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	6158	delivery	5	26
70982	2020-05-31 10:18:20	2020-05-31	9	[{"id_menu":6,"count":1}]	12131	delivery	5	14
70983	2020-05-31 10:19:47	2020-05-31	14	[{"id_menu":2,"count":1}]	9783	delivery	5	19
70984	2020-05-31 10:22:03	2020-05-31	9	[{"id_menu":6,"count":1}]	28096	delivery	5	14
70985	2020-05-31 10:22:18	2020-05-31	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28109	delivery	5	39
70986	2020-05-31 10:24:18	2020-05-31	9	[{"id_menu":6,"count":1}]	21489	delivery	5	14
70987	2020-05-31 10:26:43	2020-05-31	17	[{"id_menu":4,"count":1}]	8282	pick-up	0	17
70988	2020-05-31 10:29:16	2020-05-31	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	5520	pick-up	0	41
70989	2020-05-31 10:32:56	2020-05-31	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	28127	delivery	5	43
70990	2020-05-31 10:34:20	2020-05-31	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	18102	delivery	5	36
70991	2020-05-31 10:37:11	2020-05-31	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	25891	delivery	5	28
70992	2020-05-31 10:38:15	2020-05-31	22	[{"id_menu":2,"count":3},{"id_menu":5,"count":1}]	4872	pick-up	0	22
70993	2020-05-31 10:40:29	2020-05-31	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	23244	delivery	5	42
70994	2020-05-31 10:41:06	2020-05-31	9	[{"id_menu":6,"count":2}]	5639	pick-up	0	9
70995	2020-05-31 10:44:41	2020-05-31	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28004	delivery	5	40
70996	2020-05-31 10:47:22	2020-05-31	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	5625	delivery	5	34
70997	2020-05-31 10:49:27	2020-05-31	9	[{"id_menu":7,"count":1}]	28029	delivery	5	14
70998	2020-05-31 10:50:07	2020-05-31	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	28044	delivery	5	30
70999	2020-05-31 10:50:45	2020-05-31	9	[{"id_menu":7,"count":1}]	19868	pick-up	0	9
71000	2020-05-31 10:51:25	2020-05-31	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	24755	delivery	5	57
71001	2020-05-31 10:51:35	2020-05-31	12	[{"id_menu":3,"count":1}]	28074	pick-up	0	12
71002	2020-05-31 10:52:18	2020-05-31	12	[{"id_menu":1,"count":1}]	24964	delivery	5	17
71003	2020-05-31 10:53:11	2020-05-31	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28007	delivery	5	36
71004	2020-05-31 10:54:36	2020-05-31	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28001	delivery	5	48
71005	2020-05-31 10:57:04	2020-05-31	12	[{"id_menu":3,"count":1}]	27567	delivery	5	17
71006	2020-05-31 10:57:39	2020-05-31	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28066	delivery	5	48
71007	2020-05-31 10:57:41	2020-05-31	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3708	delivery	5	31
71008	2020-05-31 10:58:50	2020-05-31	17	[{"id_menu":4,"count":1}]	22822	pick-up	0	17
71009	2020-05-31 11:01:47	2020-05-31	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27997	delivery	5	40
71010	2020-05-31 11:02:53	2020-05-31	8	[{"id_menu":5,"count":1}]	27875	delivery	5	13
71011	2020-05-31 11:12:44	2020-05-31	12	[{"id_menu":3,"count":1}]	299	delivery	5	17
71012	2020-05-31 11:13:43	2020-05-31	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	21188	delivery	5	26
71013	2020-05-31 11:14:40	2020-05-31	12	[{"id_menu":1,"count":1}]	18770	pick-up	0	12
71014	2020-05-31 11:15:42	2020-05-31	9	[{"id_menu":7,"count":2}]	10122	delivery	5	14
71015	2020-05-31 11:16:08	2020-05-31	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	28133	delivery	5	22
71016	2020-05-31 11:16:10	2020-05-31	9	[{"id_menu":7,"count":1}]	28144	pick-up	0	9
71017	2020-05-31 11:16:15	2020-05-31	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	8323	delivery	5	31
71018	2020-05-31 11:17:05	2020-05-31	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":2}]	19862	delivery	5	28
71019	2020-05-31 11:17:13	2020-05-31	9	[{"id_menu":7,"count":1}]	28033	delivery	5	14
71020	2020-05-31 11:18:01	2020-05-31	8	[{"id_menu":5,"count":1}]	5565	delivery	5	13
71021	2020-05-31 11:24:41	2020-05-31	9	[{"id_menu":7,"count":1}]	23217	pick-up	0	9
71022	2020-05-31 11:24:59	2020-05-31	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	28141	delivery	5	26
71023	2020-05-31 11:26:03	2020-05-31	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	210	delivery	5	31
71024	2020-05-31 11:26:05	2020-05-31	9	[{"id_menu":7,"count":1}]	2395	pick-up	0	9
71025	2020-05-31 11:27:54	2020-05-31	9	[{"id_menu":6,"count":1}]	6369	delivery	5	14
71026	2020-05-31 11:28:19	2020-05-31	9	[{"id_menu":7,"count":1}]	28020	delivery	5	14
71027	2020-05-31 11:28:49	2020-05-31	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	13258	delivery	5	29
71028	2020-05-31 11:29:28	2020-05-31	17	[{"id_menu":4,"count":1}]	15515	pick-up	0	17
71029	2020-05-31 11:29:51	2020-05-31	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	28051	delivery	5	29
71030	2020-05-31 11:30:24	2020-05-31	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	5272	delivery	5	26
71031	2020-05-31 11:31:52	2020-05-31	9	[{"id_menu":6,"count":1}]	1810	delivery	5	14
71032	2020-05-31 11:34:01	2020-05-31	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26096	delivery	5	37
71033	2020-05-31 11:34:31	2020-05-31	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18936	delivery	5	31
71034	2020-05-31 11:34:43	2020-05-31	9	[{"id_menu":6,"count":1}]	27650	delivery	5	14
71035	2020-05-31 11:38:52	2020-05-31	14	[{"id_menu":2,"count":1}]	2072	pick-up	0	14
71036	2020-05-31 11:39:26	2020-05-31	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	14812	delivery	5	31
71037	2020-05-31 11:43:06	2020-05-31	9	[{"id_menu":7,"count":1}]	16866	delivery	5	14
71038	2020-05-31 11:43:21	2020-05-31	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5155	delivery	5	48
71039	2020-05-31 11:44:05	2020-05-31	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	25507	delivery	5	29
71040	2020-05-31 11:46:24	2020-05-31	17	[{"id_menu":4,"count":2}]	28031	delivery	5	22
71041	2020-05-31 11:47:00	2020-05-31	17	[{"id_menu":4,"count":1}]	1685	pick-up	0	17
71042	2020-05-31 11:49:43	2020-05-31	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12841	delivery	5	34
71043	2020-05-31 11:54:51	2020-05-31	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	28073	delivery	5	42
71044	2020-05-31 12:00:53	2020-05-31	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7222	delivery	5	28
71045	2020-05-31 12:01:14	2020-05-31	9	[{"id_menu":6,"count":2}]	7060	delivery	5	14
71046	2020-05-31 12:02:06	2020-05-31	12	[{"id_menu":1,"count":1}]	18390	delivery	5	17
71047	2020-05-31 12:06:38	2020-05-31	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7688	pick-up	0	23
71048	2020-05-31 12:07:10	2020-05-31	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28008	delivery	5	48
71049	2020-05-31 12:08:28	2020-05-31	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	12447	delivery	5	28
71050	2020-05-31 12:08:53	2020-05-31	9	[{"id_menu":7,"count":1}]	16835	delivery	5	14
71051	2020-05-31 12:12:15	2020-05-31	12	[{"id_menu":1,"count":1}]	9012	delivery	5	17
71052	2020-05-31 12:13:15	2020-05-31	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	26478	pick-up	0	23
71053	2020-05-31 12:15:32	2020-05-31	8	[{"id_menu":5,"count":1}]	12022	delivery	5	13
71054	2020-05-31 12:22:07	2020-05-31	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	28084	delivery	5	43
71055	2020-05-31 12:22:54	2020-05-31	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	28063	delivery	5	28
71056	2020-05-31 12:24:23	2020-05-31	12	[{"id_menu":1,"count":1}]	28129	delivery	5	17
71057	2020-05-31 12:24:42	2020-05-31	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	10002	delivery	5	26
71058	2020-05-31 12:25:00	2020-05-31	9	[{"id_menu":7,"count":1}]	14109	delivery	5	14
71059	2020-05-31 12:31:23	2020-05-31	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4646	delivery	5	43
71060	2020-05-31 12:34:20	2020-05-31	12	[{"id_menu":1,"count":1}]	11904	pick-up	0	12
71061	2020-05-31 12:35:05	2020-05-31	9	[{"id_menu":6,"count":1}]	19759	delivery	5	14
71062	2020-05-31 12:36:47	2020-05-31	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28003	delivery	5	23
71063	2020-05-31 12:37:46	2020-05-31	9	[{"id_menu":6,"count":1}]	28077	delivery	5	14
71064	2020-05-31 12:43:18	2020-05-31	12	[{"id_menu":3,"count":1}]	743	pick-up	0	12
71065	2020-05-31 12:43:32	2020-05-31	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	24405	delivery	5	40
71066	2020-05-31 12:50:09	2020-05-31	17	[{"id_menu":4,"count":1}]	24171	delivery	5	22
71067	2020-05-31 12:50:31	2020-05-31	9	[{"id_menu":7,"count":1}]	28026	delivery	5	14
71068	2020-05-31 12:51:22	2020-05-31	9	[{"id_menu":6,"count":1}]	27985	delivery	5	14
71069	2020-05-31 12:52:41	2020-05-31	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	3570	pick-up	0	26
71070	2020-05-31 12:53:03	2020-05-31	14	[{"id_menu":2,"count":1}]	28130	delivery	5	19
71071	2020-05-31 12:54:16	2020-05-31	8	[{"id_menu":5,"count":1}]	22242	delivery	5	13
71072	2020-05-31 12:54:59	2020-05-31	12	[{"id_menu":1,"count":1}]	25719	pick-up	0	12
71073	2020-05-31 12:57:46	2020-05-31	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28000	delivery	5	36
71074	2020-05-31 12:57:48	2020-05-31	8	[{"id_menu":5,"count":1}]	8139	delivery	5	13
71075	2020-05-31 13:00:31	2020-05-31	17	[{"id_menu":4,"count":1}]	20964	delivery	5	22
71076	2020-05-31 13:01:33	2020-05-31	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	5110	delivery	5	26
71077	2020-05-31 13:01:45	2020-05-31	9	[{"id_menu":6,"count":1}]	23778	delivery	5	14
71078	2020-05-31 13:02:25	2020-05-31	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	47	pick-up	0	31
71079	2020-05-31 13:05:25	2020-05-31	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	9136	delivery	5	28
71080	2020-05-31 13:05:51	2020-05-31	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	16592	pick-up	0	40
71081	2020-05-31 13:07:14	2020-05-31	9	[{"id_menu":6,"count":1}]	28132	delivery	5	14
71082	2020-05-31 13:13:31	2020-05-31	17	[{"id_menu":4,"count":1}]	25944	pick-up	0	17
71083	2020-05-31 13:17:37	2020-05-31	12	[{"id_menu":1,"count":1}]	8146	pick-up	0	12
71084	2020-05-31 13:18:10	2020-05-31	14	[{"id_menu":2,"count":1}]	20264	delivery	5	19
71085	2020-05-31 13:18:23	2020-05-31	9	[{"id_menu":6,"count":1}]	12853	delivery	5	14
71086	2020-05-31 13:20:10	2020-05-31	14	[{"id_menu":2,"count":1}]	3052	pick-up	0	14
71087	2020-05-31 13:22:05	2020-05-31	9	[{"id_menu":6,"count":1}]	27083	delivery	5	14
71088	2020-05-31 13:24:35	2020-05-31	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15239	delivery	5	45
71089	2020-05-31 13:28:07	2020-05-31	8	[{"id_menu":5,"count":1}]	27148	delivery	5	13
71090	2020-05-31 13:29:20	2020-05-31	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9439	delivery	5	46
71091	2020-05-31 13:31:15	2020-05-31	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	18755	pick-up	0	31
71092	2020-05-31 13:35:57	2020-05-31	14	[{"id_menu":2,"count":1}]	28002	delivery	5	19
71093	2020-05-31 13:36:18	2020-05-31	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28092	delivery	5	22
71094	2020-05-31 13:36:43	2020-05-31	9	[{"id_menu":7,"count":1}]	12579	delivery	5	14
71095	2020-05-31 13:37:50	2020-05-31	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	17189	delivery	5	28
71096	2020-05-31 13:38:20	2020-05-31	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14705	delivery	5	31
71097	2020-05-31 13:40:44	2020-05-31	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	17968	delivery	5	25
71098	2020-05-31 13:46:10	2020-05-31	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25299	delivery	5	48
71099	2020-05-31 13:46:53	2020-05-31	9	[{"id_menu":6,"count":1}]	28104	delivery	5	14
71100	2020-05-31 13:47:24	2020-05-31	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	11183	delivery	5	28
71101	2020-05-31 13:47:43	2020-05-31	9	[{"id_menu":7,"count":3}]	18882	delivery	5	14
71102	2020-05-31 13:50:30	2020-05-31	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28149	delivery	5	40
71103	2020-05-31 13:53:52	2020-05-31	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	28040	delivery	5	48
71104	2020-05-31 13:54:12	2020-05-31	14	[{"id_menu":2,"count":1}]	4342	delivery	5	19
71105	2020-05-31 13:56:17	2020-05-31	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	28120	delivery	5	31
71106	2020-05-31 13:56:44	2020-05-31	8	[{"id_menu":5,"count":1}]	22355	delivery	5	13
71107	2020-05-31 14:01:02	2020-05-31	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	1919	pick-up	0	31
71108	2020-05-31 14:02:28	2020-05-31	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	11543	delivery	5	23
71109	2020-05-31 14:05:45	2020-05-31	14	[{"id_menu":2,"count":1}]	9352	delivery	5	19
71110	2020-05-31 14:06:39	2020-05-31	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28072	delivery	5	23
71111	2020-05-31 14:07:09	2020-05-31	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	23509	pick-up	0	26
71112	2020-05-31 14:09:18	2020-05-31	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14449	pick-up	0	17
71113	2020-05-31 14:13:07	2020-05-31	17	[{"id_menu":4,"count":1}]	26062	delivery	5	22
71114	2020-05-31 14:14:24	2020-05-31	9	[{"id_menu":6,"count":1}]	28011	delivery	5	14
71115	2020-05-31 14:18:20	2020-05-31	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	15159	delivery	5	40
71116	2020-05-31 14:18:42	2020-05-31	12	[{"id_menu":1,"count":1}]	15758	delivery	5	17
71117	2020-05-31 14:21:21	2020-05-31	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	15394	pick-up	0	21
71118	2020-05-31 14:22:52	2020-05-31	17	[{"id_menu":4,"count":1}]	4866	delivery	5	22
71119	2020-05-31 14:28:32	2020-05-31	9	[{"id_menu":6,"count":1}]	27596	delivery	5	14
71120	2020-05-31 14:32:03	2020-05-31	9	[{"id_menu":7,"count":1}]	6550	delivery	5	14
71121	2020-05-31 14:33:38	2020-05-31	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	14290	pick-up	0	23
71122	2020-05-31 14:34:47	2020-05-31	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	3293	delivery	5	34
71123	2020-05-31 14:38:12	2020-05-31	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	12745	delivery	5	27
71124	2020-05-31 14:38:23	2020-05-31	14	[{"id_menu":2,"count":1}]	1155	pick-up	0	14
71125	2020-05-31 14:39:05	2020-05-31	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	2126	delivery	5	29
71126	2020-05-31 14:39:44	2020-05-31	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9139	delivery	5	51
71127	2020-05-31 14:43:00	2020-05-31	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	5683	pick-up	0	21
71128	2020-05-31 14:53:13	2020-05-31	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	9420	pick-up	0	21
71129	2020-05-31 14:54:06	2020-05-31	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	27999	delivery	5	30
71130	2020-05-31 14:55:50	2020-05-31	17	[{"id_menu":4,"count":1}]	25785	delivery	5	22
71131	2020-05-31 14:56:27	2020-05-31	8	[{"id_menu":5,"count":1}]	28048	delivery	5	13
71132	2020-05-31 14:58:47	2020-05-31	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	28027	delivery	5	26
71133	2020-05-31 15:00:01	2020-05-31	9	[{"id_menu":7,"count":2}]	27990	delivery	5	14
71134	2020-05-31 15:06:36	2020-05-31	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25477	delivery	5	31
71135	2020-05-31 15:06:51	2020-05-31	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	26556	delivery	5	31
71136	2020-05-31 15:10:24	2020-05-31	14	[{"id_menu":2,"count":1}]	28079	delivery	5	19
71137	2020-05-31 15:14:47	2020-05-31	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8722	delivery	5	22
71138	2020-05-31 15:17:39	2020-05-31	9	[{"id_menu":7,"count":1}]	28034	delivery	5	14
71139	2020-05-31 15:18:16	2020-05-31	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":3}]	14127	pick-up	0	26
71140	2020-05-31 15:23:25	2020-05-31	9	[{"id_menu":6,"count":1}]	5097	delivery	5	14
71141	2020-05-31 15:24:44	2020-05-31	9	[{"id_menu":7,"count":2}]	28076	pick-up	0	9
71142	2020-05-31 15:27:51	2020-05-31	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	27981	delivery	5	45
71143	2020-05-31 15:30:16	2020-05-31	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	14143	delivery	5	26
71144	2020-05-31 15:32:12	2020-05-31	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	28113	pick-up	0	20
71145	2020-05-31 15:34:15	2020-05-31	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	28081	delivery	5	40
71146	2020-05-31 15:39:15	2020-05-31	17	[{"id_menu":4,"count":1}]	189	delivery	5	22
71147	2020-05-31 15:40:23	2020-05-31	12	[{"id_menu":1,"count":1}]	14713	pick-up	0	12
71148	2020-05-31 15:41:43	2020-05-31	9	[{"id_menu":6,"count":1}]	28098	delivery	5	14
71149	2020-05-31 15:41:55	2020-05-31	8	[{"id_menu":5,"count":1}]	22652	delivery	5	13
71150	2020-05-31 15:42:59	2020-05-31	14	[{"id_menu":2,"count":1}]	2081	delivery	5	19
71151	2020-05-31 15:43:50	2020-05-31	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	10410	delivery	5	25
71152	2020-05-31 15:45:28	2020-05-31	9	[{"id_menu":6,"count":1}]	1754	pick-up	0	9
71153	2020-05-31 15:46:47	2020-05-31	17	[{"id_menu":4,"count":1}]	28140	delivery	5	22
71154	2020-05-31 15:53:14	2020-05-31	12	[{"id_menu":1,"count":1}]	1562	delivery	5	17
71155	2020-05-31 15:56:12	2020-05-31	14	[{"id_menu":2,"count":1}]	14181	delivery	5	19
71156	2020-05-31 15:56:59	2020-05-31	8	[{"id_menu":5,"count":1}]	1029	pick-up	0	8
71157	2020-05-31 15:57:09	2020-05-31	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6916	pick-up	0	52
71158	2020-05-31 15:57:16	2020-05-31	14	[{"id_menu":2,"count":1}]	18243	delivery	5	19
71159	2020-05-31 16:04:16	2020-05-31	9	[{"id_menu":6,"count":1}]	27993	delivery	5	14
71160	2020-05-31 16:06:41	2020-05-31	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1006	delivery	5	23
71161	2020-05-31 16:15:39	2020-05-31	9	[{"id_menu":7,"count":1}]	584	delivery	5	14
71162	2020-05-31 16:19:01	2020-05-31	9	[{"id_menu":7,"count":1}]	28041	delivery	5	14
71163	2020-05-31 16:19:15	2020-05-31	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	28069	delivery	5	31
71164	2020-05-31 16:19:24	2020-05-31	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	3211	delivery	5	29
71165	2020-05-31 16:19:43	2020-05-31	12	[{"id_menu":3,"count":1}]	3123	pick-up	0	12
71166	2020-05-31 16:20:20	2020-05-31	14	[{"id_menu":2,"count":1}]	8347	pick-up	0	14
71167	2020-05-31 16:21:03	2020-05-31	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1379	pick-up	0	20
71168	2020-05-31 16:21:39	2020-05-31	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	14364	pick-up	0	40
71169	2020-05-31 16:24:14	2020-05-31	17	[{"id_menu":4,"count":1}]	7707	pick-up	0	17
71170	2020-05-31 16:24:58	2020-05-31	9	[{"id_menu":6,"count":1}]	15292	pick-up	0	9
71171	2020-05-31 16:27:52	2020-05-31	9	[{"id_menu":7,"count":1}]	28106	delivery	5	14
71172	2020-05-31 16:28:19	2020-05-31	9	[{"id_menu":7,"count":1}]	7985	delivery	5	14
71173	2020-05-31 16:30:42	2020-05-31	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22259	delivery	5	35
71174	2020-05-31 16:31:07	2020-05-31	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2434	pick-up	0	22
71175	2020-05-31 16:37:11	2020-05-31	12	[{"id_menu":1,"count":1}]	3848	delivery	5	17
71176	2020-05-31 16:38:05	2020-05-31	9	[{"id_menu":6,"count":1}]	531	pick-up	0	9
71177	2020-05-31 16:41:48	2020-05-31	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	26178	delivery	5	23
71178	2020-05-31 16:43:51	2020-05-31	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	28118	delivery	5	34
71179	2020-05-31 16:47:55	2020-05-31	12	[{"id_menu":3,"count":1}]	21006	delivery	5	17
71180	2020-05-31 16:48:20	2020-05-31	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	25933	delivery	5	48
71181	2020-05-31 16:52:55	2020-05-31	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	16358	delivery	5	26
71182	2020-05-31 16:53:28	2020-05-31	17	[{"id_menu":4,"count":1}]	28117	delivery	5	22
71183	2020-05-31 16:56:47	2020-05-31	9	[{"id_menu":6,"count":1}]	4896	delivery	5	14
71184	2020-05-31 16:57:16	2020-05-31	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	9151	delivery	5	43
71185	2020-05-31 16:59:01	2020-05-31	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	27986	delivery	5	29
71186	2020-05-31 17:03:59	2020-05-31	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	24869	delivery	5	31
71187	2020-05-31 17:06:58	2020-05-31	14	[{"id_menu":2,"count":2}]	20852	delivery	5	19
71188	2020-05-31 17:13:05	2020-05-31	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3896	pick-up	0	38
71189	2020-05-31 17:16:27	2020-05-31	17	[{"id_menu":4,"count":1}]	6473	pick-up	0	17
71190	2020-05-31 17:18:00	2020-05-31	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28062	delivery	5	23
71191	2020-05-31 17:21:55	2020-05-31	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	19492	delivery	5	31
71192	2020-05-31 17:24:30	2020-05-31	17	[{"id_menu":4,"count":1}]	17749	delivery	5	22
71193	2020-05-31 17:25:18	2020-05-31	17	[{"id_menu":4,"count":2}]	28101	delivery	5	22
71194	2020-05-31 17:26:15	2020-05-31	12	[{"id_menu":3,"count":1}]	28006	delivery	5	17
71195	2020-05-31 17:31:45	2020-05-31	9	[{"id_menu":6,"count":1}]	602	delivery	5	14
71196	2020-05-31 17:32:50	2020-05-31	12	[{"id_menu":1,"count":1}]	12095	pick-up	0	12
71197	2020-05-31 17:35:02	2020-05-31	12	[{"id_menu":1,"count":2}]	2333	pick-up	0	12
71198	2020-05-31 17:36:00	2020-05-31	17	[{"id_menu":4,"count":1}]	26316	delivery	5	22
71199	2020-05-31 17:40:09	2020-05-31	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":3}]	21750	delivery	5	22
71200	2020-05-31 17:46:56	2020-05-31	9	[{"id_menu":6,"count":1}]	28056	pick-up	0	9
71201	2020-05-31 17:47:43	2020-05-31	8	[{"id_menu":5,"count":1}]	11951	pick-up	0	8
71202	2020-05-31 17:48:03	2020-05-31	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	19395	delivery	5	28
71203	2020-05-31 17:50:41	2020-05-31	12	[{"id_menu":1,"count":1}]	27432	delivery	5	17
71204	2020-05-31 17:50:46	2020-05-31	14	[{"id_menu":2,"count":1}]	1305	pick-up	0	14
71205	2020-05-31 17:50:56	2020-05-31	8	[{"id_menu":5,"count":1}]	430	pick-up	0	8
71206	2020-05-31 17:55:03	2020-05-31	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	4008	delivery	5	25
71207	2020-05-31 17:55:36	2020-05-31	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	12166	pick-up	0	20
71208	2020-05-31 18:03:48	2020-05-31	17	[{"id_menu":4,"count":1}]	7211	delivery	5	22
71209	2020-05-31 18:06:23	2020-05-31	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1723	pick-up	0	18
71210	2020-05-31 18:09:50	2020-05-31	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	28151	pick-up	0	26
71211	2020-05-31 18:12:23	2020-05-31	12	[{"id_menu":1,"count":1}]	27699	delivery	5	17
71212	2020-05-31 18:12:31	2020-05-31	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	20972	delivery	5	40
71213	2020-05-31 18:14:56	2020-05-31	14	[{"id_menu":2,"count":2}]	12404	pick-up	0	14
71214	2020-05-31 18:16:35	2020-05-31	9	[{"id_menu":7,"count":1}]	28095	delivery	5	14
71215	2020-05-31 18:18:50	2020-05-31	8	[{"id_menu":5,"count":1}]	23460	delivery	5	13
71216	2020-05-31 18:22:32	2020-05-31	12	[{"id_menu":1,"count":1}]	857	pick-up	0	12
71217	2020-05-31 18:24:27	2020-05-31	9	[{"id_menu":6,"count":1}]	26133	delivery	5	14
71218	2020-05-31 18:25:17	2020-05-31	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16831	delivery	5	43
71219	2020-05-31 18:25:20	2020-05-31	8	[{"id_menu":5,"count":1}]	13287	delivery	5	13
71220	2020-05-31 18:25:30	2020-05-31	9	[{"id_menu":7,"count":1}]	16737	delivery	5	14
71221	2020-05-31 18:38:32	2020-05-31	9	[{"id_menu":7,"count":1}]	23650	delivery	5	14
71222	2020-05-31 18:43:20	2020-05-31	8	[{"id_menu":5,"count":1}]	25066	delivery	5	13
71223	2020-05-31 18:43:58	2020-05-31	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	8229	delivery	5	31
71224	2020-05-31 18:45:36	2020-05-31	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28017	delivery	5	34
71225	2020-05-31 18:51:14	2020-05-31	9	[{"id_menu":7,"count":2}]	12615	delivery	5	14
71226	2020-05-31 18:54:40	2020-05-31	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12602	delivery	5	22
71227	2020-05-31 18:54:52	2020-05-31	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	13172	delivery	5	40
71228	2020-05-31 18:56:06	2020-05-31	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	4800	delivery	5	34
71229	2020-05-31 18:56:22	2020-05-31	17	[{"id_menu":4,"count":1}]	19233	pick-up	0	17
71230	2020-05-31 19:03:21	2020-05-31	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	23271	delivery	5	22
71231	2020-05-31 19:03:44	2020-05-31	9	[{"id_menu":6,"count":2}]	17792	delivery	5	14
71232	2020-05-31 19:06:12	2020-05-31	17	[{"id_menu":4,"count":1}]	28043	delivery	5	22
71233	2020-05-31 19:14:14	2020-05-31	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	10356	delivery	5	34
71234	2020-05-31 19:17:15	2020-05-31	8	[{"id_menu":5,"count":1}]	3380	delivery	5	13
71235	2020-05-31 19:18:03	2020-05-31	17	[{"id_menu":4,"count":1}]	10161	delivery	5	22
71236	2020-05-31 19:25:56	2020-05-31	8	[{"id_menu":5,"count":1}]	8546	pick-up	0	8
71237	2020-05-31 19:28:58	2020-05-31	9	[{"id_menu":6,"count":1}]	21726	delivery	5	14
71238	2020-05-31 19:30:00	2020-05-31	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	27998	delivery	5	34
71239	2020-05-31 19:30:37	2020-05-31	9	[{"id_menu":6,"count":1}]	20402	delivery	5	14
71240	2020-05-31 19:34:00	2020-05-31	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":2}]	28125	delivery	5	26
71241	2020-05-31 19:34:10	2020-05-31	9	[{"id_menu":6,"count":1}]	16526	delivery	5	14
71242	2020-05-31 19:37:21	2020-05-31	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	123	delivery	5	26
71243	2020-05-31 19:37:56	2020-05-31	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2561	delivery	5	23
71244	2020-05-31 19:38:47	2020-05-31	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	9021	delivery	5	27
71245	2020-05-31 19:42:19	2020-05-31	9	[{"id_menu":7,"count":1}]	19456	delivery	5	14
71246	2020-05-31 19:42:40	2020-05-31	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11770	delivery	5	31
71247	2020-05-31 19:44:56	2020-05-31	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	15369	delivery	5	48
71248	2020-05-31 19:45:10	2020-05-31	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	28045	delivery	5	28
71249	2020-05-31 19:47:35	2020-05-31	14	[{"id_menu":2,"count":1}]	20695	delivery	5	19
71250	2020-05-31 19:49:54	2020-05-31	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	28005	pick-up	0	23
71251	2020-05-31 19:50:34	2020-05-31	14	[{"id_menu":2,"count":1}]	16952	delivery	5	19
71252	2020-05-31 19:51:01	2020-05-31	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	13563	delivery	5	31
71253	2020-05-31 19:55:40	2020-05-31	9	[{"id_menu":6,"count":1}]	12138	pick-up	0	9
71254	2020-05-31 19:56:49	2020-05-31	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	11806	delivery	5	31
71255	2020-05-31 19:57:04	2020-05-31	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	24975	delivery	5	36
71256	2020-05-31 19:58:45	2020-05-31	9	[{"id_menu":6,"count":2}]	2717	delivery	5	14
71257	2020-05-31 19:59:16	2020-05-31	9	[{"id_menu":7,"count":1}]	4147	pick-up	0	9
71258	2020-05-31 20:01:16	2020-05-31	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24718	pick-up	0	17
71259	2020-05-31 20:01:24	2020-05-31	12	[{"id_menu":3,"count":1}]	28124	pick-up	0	12
71260	2020-05-31 20:03:35	2020-05-31	17	[{"id_menu":4,"count":1}]	13178	delivery	5	22
71261	2020-05-31 20:07:14	2020-05-31	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5332	pick-up	0	17
71262	2020-05-31 20:11:03	2020-05-31	9	[{"id_menu":6,"count":1}]	6965	pick-up	0	9
71263	2020-05-31 20:14:38	2020-05-31	9	[{"id_menu":7,"count":1}]	359	pick-up	0	9
71264	2020-05-31 20:17:17	2020-05-31	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	12481	delivery	5	26
71265	2020-05-31 20:19:49	2020-05-31	12	[{"id_menu":1,"count":1}]	11549	delivery	5	17
71266	2020-05-31 20:20:19	2020-05-31	8	[{"id_menu":5,"count":2}]	28143	delivery	5	13
71267	2020-05-31 20:20:50	2020-05-31	8	[{"id_menu":5,"count":1}]	1072	pick-up	0	8
71268	2020-05-31 20:21:09	2020-05-31	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	20261	delivery	5	38
71269	2020-05-31 20:21:17	2020-05-31	12	[{"id_menu":1,"count":1}]	22228	pick-up	0	12
71270	2020-05-31 20:21:41	2020-05-31	9	[{"id_menu":7,"count":1}]	612	pick-up	0	9
71271	2020-05-31 20:22:13	2020-05-31	8	[{"id_menu":5,"count":1}]	3752	delivery	5	13
71272	2020-05-31 20:31:42	2020-05-31	12	[{"id_menu":3,"count":1}]	12124	pick-up	0	12
71273	2020-05-31 20:32:27	2020-05-31	17	[{"id_menu":4,"count":1}]	389	pick-up	0	17
71274	2020-05-31 20:32:44	2020-05-31	9	[{"id_menu":7,"count":1}]	25444	delivery	5	14
71275	2020-05-31 20:33:44	2020-05-31	12	[{"id_menu":3,"count":1}]	7192	delivery	5	17
71276	2020-05-31 20:33:58	2020-05-31	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1408	pick-up	0	38
71277	2020-05-31 20:36:50	2020-05-31	9	[{"id_menu":7,"count":1}]	27584	delivery	5	14
71278	2020-05-31 20:37:29	2020-05-31	12	[{"id_menu":1,"count":1}]	18906	pick-up	0	12
71279	2020-05-31 20:38:31	2020-05-31	12	[{"id_menu":1,"count":1}]	9191	pick-up	0	12
71280	2020-05-31 20:38:56	2020-05-31	14	[{"id_menu":2,"count":1}]	11617	pick-up	0	14
71281	2020-05-31 20:38:58	2020-05-31	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17291	delivery	5	35
71282	2020-05-31 20:39:27	2020-05-31	9	[{"id_menu":7,"count":2}]	377	pick-up	0	9
71283	2020-05-31 20:40:18	2020-05-31	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	21657	delivery	5	27
71284	2020-05-31 20:46:21	2020-05-31	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5234	pick-up	0	25
71285	2020-05-31 20:55:05	2020-05-31	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	2352	pick-up	0	20
71286	2020-05-31 20:55:46	2020-05-31	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6780	delivery	5	30
71287	2020-05-31 20:59:06	2020-05-31	9	[{"id_menu":6,"count":1}]	13663	delivery	5	14
71288	2020-05-31 20:59:24	2020-05-31	9	[{"id_menu":6,"count":1}]	10461	delivery	5	14
71289	2020-05-31 21:00:49	2020-05-31	12	[{"id_menu":3,"count":1}]	9673	delivery	5	17
71290	2020-05-31 21:01:02	2020-05-31	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	7388	delivery	5	39
71291	2020-05-31 21:02:05	2020-05-31	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	21492	delivery	5	29
71292	2020-05-31 21:04:41	2020-05-31	12	[{"id_menu":1,"count":1}]	26035	pick-up	0	12
71293	2020-05-31 21:09:16	2020-05-31	14	[{"id_menu":2,"count":1}]	20937	delivery	5	19
71294	2020-05-31 21:14:02	2020-05-31	9	[{"id_menu":6,"count":2}]	28060	delivery	5	14
71295	2020-05-31 21:15:15	2020-05-31	12	[{"id_menu":1,"count":1}]	28061	delivery	5	17
71296	2020-05-31 21:22:45	2020-05-31	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":2}]	28093	delivery	5	27
71297	2020-05-31 21:24:02	2020-05-31	8	[{"id_menu":5,"count":1}]	17387	delivery	5	13
71298	2020-05-31 21:24:29	2020-05-31	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	28047	delivery	5	34
71299	2020-05-31 21:28:19	2020-05-31	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11194	delivery	5	31
71300	2020-05-31 21:29:44	2020-05-31	14	[{"id_menu":2,"count":1}]	6565	delivery	5	19
71301	2020-05-31 21:29:50	2020-05-31	12	[{"id_menu":1,"count":1}]	9636	delivery	5	17
71302	2020-05-31 21:30:15	2020-05-31	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	16958	delivery	5	22
71303	2020-05-31 21:31:37	2020-05-31	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17373	delivery	5	23
71304	2020-05-31 21:32:07	2020-05-31	9	[{"id_menu":6,"count":1}]	28147	delivery	5	14
71305	2020-05-31 21:33:22	2020-05-31	8	[{"id_menu":5,"count":1}]	2838	pick-up	0	8
71306	2020-05-31 21:34:26	2020-05-31	8	[{"id_menu":5,"count":2}]	2868	delivery	5	13
71307	2020-05-31 21:36:27	2020-05-31	9	[{"id_menu":6,"count":1}]	17807	pick-up	0	9
71308	2020-05-31 21:37:02	2020-05-31	9	[{"id_menu":7,"count":1}]	12145	pick-up	0	9
71309	2020-05-31 21:38:06	2020-05-31	17	[{"id_menu":4,"count":1}]	1623	pick-up	0	17
71310	2020-05-31 21:38:26	2020-05-31	8	[{"id_menu":5,"count":1}]	28126	delivery	5	13
71311	2020-05-31 21:41:31	2020-05-31	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9669	delivery	5	22
71312	2020-05-31 21:45:09	2020-05-31	8	[{"id_menu":5,"count":1}]	7304	pick-up	0	8
71313	2020-05-31 21:50:23	2020-05-31	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	28054	pick-up	0	21
71314	2020-05-31 21:55:15	2020-05-31	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8068	pick-up	0	23
71315	2020-05-31 21:55:57	2020-05-31	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	15686	pick-up	0	29
71316	2020-05-31 21:59:50	2020-05-31	17	[{"id_menu":4,"count":1}]	11713	delivery	5	22
71317	2020-05-31 22:01:21	2020-05-31	9	[{"id_menu":6,"count":1}]	26205	delivery	5	14
71318	2020-05-31 22:01:25	2020-05-31	9	[{"id_menu":6,"count":1}]	21020	pick-up	0	9
71319	2020-05-31 22:02:45	2020-05-31	17	[{"id_menu":4,"count":1}]	15604	delivery	5	22
71320	2020-05-31 22:06:45	2020-05-31	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	15187	pick-up	0	29
71321	2020-05-31 22:06:59	2020-05-31	9	[{"id_menu":7,"count":1}]	14854	delivery	5	14
71322	2020-05-31 22:07:08	2020-05-31	17	[{"id_menu":4,"count":3}]	8809	delivery	5	22
71323	2020-05-31 22:07:38	2020-05-31	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	18526	delivery	5	27
71324	2020-05-31 22:09:00	2020-05-31	17	[{"id_menu":4,"count":1}]	28052	delivery	5	22
71325	2020-05-31 22:10:26	2020-05-31	9	[{"id_menu":7,"count":1}]	10589	pick-up	0	9
71326	2020-05-31 22:13:04	2020-05-31	9	[{"id_menu":7,"count":1}]	2600	pick-up	0	9
71327	2020-05-31 22:15:00	2020-05-31	9	[{"id_menu":7,"count":1}]	12181	delivery	5	14
71328	2020-05-31 22:17:52	2020-05-31	12	[{"id_menu":1,"count":1}]	24325	pick-up	0	12
71329	2020-05-31 22:17:54	2020-05-31	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	18859	delivery	5	31
71330	2020-05-31 22:22:50	2020-05-31	9	[{"id_menu":7,"count":1}]	27996	delivery	5	14
71331	2020-05-31 22:22:50	2020-05-31	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	3629	delivery	5	40
71332	2020-05-31 22:23:55	2020-05-31	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	10302	delivery	5	40
71333	2020-05-31 22:24:38	2020-05-31	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	21575	pick-up	0	20
71334	2020-05-31 22:24:57	2020-05-31	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	22319	delivery	5	39
71335	2020-05-31 22:26:08	2020-05-31	9	[{"id_menu":7,"count":1}]	7184	delivery	5	14
71336	2020-05-31 22:26:17	2020-05-31	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":2}]	28025	delivery	5	28
71337	2020-05-31 22:26:25	2020-05-31	14	[{"id_menu":2,"count":1}]	1266	pick-up	0	14
71338	2020-05-31 22:27:43	2020-05-31	17	[{"id_menu":4,"count":1}]	11297	delivery	5	22
71339	2020-05-31 22:29:28	2020-05-31	9	[{"id_menu":7,"count":1}]	12568	delivery	5	14
71340	2020-05-31 22:30:03	2020-05-31	9	[{"id_menu":6,"count":2}]	28053	delivery	5	14
71341	2020-05-31 22:31:39	2020-05-31	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	28116	delivery	5	26
71342	2020-05-31 22:33:38	2020-05-31	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6356	delivery	5	22
71343	2020-05-31 22:34:26	2020-05-31	9	[{"id_menu":6,"count":2}]	5911	delivery	5	14
71344	2020-05-31 22:35:05	2020-05-31	12	[{"id_menu":1,"count":1}]	5947	pick-up	0	12
71345	2020-05-31 22:37:10	2020-05-31	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	25147	delivery	5	28
71346	2020-05-31 22:37:19	2020-05-31	17	[{"id_menu":4,"count":1}]	1016	pick-up	0	17
71347	2020-05-31 22:42:06	2020-05-31	9	[{"id_menu":7,"count":1}]	778	pick-up	0	9
71348	2020-05-31 22:50:53	2020-05-31	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	17931	delivery	5	31
71349	2020-05-31 22:56:34	2020-05-31	17	[{"id_menu":4,"count":1}]	4960	delivery	5	22
71350	2020-05-31 22:58:57	2020-05-31	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	18063	pick-up	0	26
71351	2020-05-31 23:00:57	2020-05-31	9	[{"id_menu":7,"count":1}]	23727	delivery	5	14
71352	2020-05-31 23:04:57	2020-05-31	9	[{"id_menu":7,"count":1}]	6652	delivery	5	14
71353	2020-05-31 23:06:13	2020-05-31	12	[{"id_menu":1,"count":1}]	14622	delivery	5	17
71354	2020-05-31 23:10:40	2020-05-31	9	[{"id_menu":6,"count":1}]	28042	delivery	5	14
71355	2020-05-31 23:12:55	2020-05-31	9	[{"id_menu":7,"count":1}]	12210	pick-up	0	9
71356	2020-05-31 23:14:31	2020-05-31	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	27183	delivery	5	40
71357	2020-05-31 23:15:24	2020-05-31	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	729	pick-up	0	34
71358	2020-05-31 23:17:53	2020-05-31	9	[{"id_menu":7,"count":1}]	24383	delivery	5	14
71359	2020-05-31 23:20:01	2020-05-31	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	24798	delivery	5	57
71360	2020-05-31 23:28:40	2020-05-31	8	[{"id_menu":5,"count":1}]	28088	delivery	5	13
71361	2020-05-31 23:30:00	2020-05-31	17	[{"id_menu":4,"count":1}]	18652	delivery	5	22
71362	2020-05-31 23:31:21	2020-05-31	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	28016	delivery	5	27
71363	2020-05-31 23:31:44	2020-05-31	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25003	delivery	5	36
71364	2020-05-31 23:34:35	2020-05-31	17	[{"id_menu":4,"count":1}]	20504	delivery	5	22
71365	2020-05-31 23:38:14	2020-05-31	9	[{"id_menu":6,"count":1}]	3083	delivery	5	14
71366	2020-05-31 23:39:27	2020-05-31	12	[{"id_menu":1,"count":1}]	20573	delivery	5	17
71431	2020-06-01 03:37:52	2020-06-01	12	[{"id_menu":1,"count":1}]	4137	pick-up	0	12
71367	2020-05-31 23:40:51	2020-05-31	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27989	delivery	5	48
71368	2020-05-31 23:41:11	2020-05-31	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	2961	delivery	5	40
71369	2020-05-31 23:42:07	2020-05-31	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28150	delivery	5	36
71370	2020-05-31 23:48:21	2020-05-31	8	[{"id_menu":5,"count":1}]	18623	delivery	5	13
71371	2020-05-31 23:49:03	2020-05-31	17	[{"id_menu":4,"count":1}]	27983	delivery	5	22
71372	2020-05-31 23:50:08	2020-05-31	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14631	delivery	5	37
71373	2020-05-31 23:58:24	2020-05-31	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	28153	delivery	5	25
71374	2020-05-31 23:58:41	2020-05-31	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	16219	delivery	5	38
71375	2020-05-31 23:58:52	2020-05-31	12	[{"id_menu":1,"count":1}]	8303	delivery	5	17
71376	2020-05-31 23:59:10	2020-05-31	9	[{"id_menu":6,"count":1}]	24632	delivery	5	14
71377	2020-06-01 00:06:05	2020-06-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	28287	delivery	5	28
71378	2020-06-01 00:07:12	2020-06-01	8	[{"id_menu":5,"count":1}]	28346	delivery	5	13
71379	2020-06-01 00:09:58	2020-06-01	9	[{"id_menu":7,"count":1}]	28265	delivery	5	14
71380	2020-06-01 00:13:15	2020-06-01	8	[{"id_menu":5,"count":1}]	18189	pick-up	0	8
71381	2020-06-01 00:14:02	2020-06-01	12	[{"id_menu":1,"count":2}]	23087	delivery	5	17
71382	2020-06-01 00:15:19	2020-06-01	9	[{"id_menu":6,"count":1}]	28202	delivery	5	14
71383	2020-06-01 00:16:23	2020-06-01	14	[{"id_menu":2,"count":1}]	28199	delivery	5	19
71384	2020-06-01 00:18:16	2020-06-01	9	[{"id_menu":6,"count":1}]	13236	delivery	5	14
71385	2020-06-01 00:32:40	2020-06-01	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	28087	delivery	5	39
71386	2020-06-01 00:35:38	2020-06-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	16959	pick-up	0	23
71387	2020-06-01 00:46:59	2020-06-01	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	11254	delivery	5	26
71388	2020-06-01 00:50:01	2020-06-01	8	[{"id_menu":5,"count":1}]	28255	delivery	5	13
71389	2020-06-01 00:51:29	2020-06-01	14	[{"id_menu":2,"count":1}]	28335	delivery	5	19
71390	2020-06-01 00:53:58	2020-06-01	9	[{"id_menu":7,"count":2}]	28159	pick-up	0	9
71391	2020-06-01 00:58:49	2020-06-01	14	[{"id_menu":2,"count":1}]	9728	delivery	5	19
71392	2020-06-01 01:03:40	2020-06-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20729	delivery	5	22
71393	2020-06-01 01:06:35	2020-06-01	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	28239	delivery	5	25
71394	2020-06-01 01:07:19	2020-06-01	9	[{"id_menu":6,"count":1}]	10525	pick-up	0	9
71395	2020-06-01 01:09:44	2020-06-01	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	25547	delivery	5	25
71396	2020-06-01 01:13:19	2020-06-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2301	pick-up	0	23
71397	2020-06-01 01:21:06	2020-06-01	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	22561	delivery	5	31
71398	2020-06-01 01:33:39	2020-06-01	9	[{"id_menu":7,"count":1}]	28261	delivery	5	14
71399	2020-06-01 01:36:06	2020-06-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	28271	delivery	5	26
71400	2020-06-01 01:45:38	2020-06-01	12	[{"id_menu":3,"count":1}]	9846	pick-up	0	12
71401	2020-06-01 01:49:31	2020-06-01	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":3}]	10743	delivery	5	26
71402	2020-06-01 02:00:44	2020-06-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14785	delivery	5	22
71403	2020-06-01 02:01:17	2020-06-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	10590	pick-up	0	31
71404	2020-06-01 02:02:20	2020-06-01	9	[{"id_menu":6,"count":1}]	22532	delivery	5	14
71405	2020-06-01 02:07:06	2020-06-01	12	[{"id_menu":3,"count":1}]	28341	delivery	5	17
71406	2020-06-01 02:08:57	2020-06-01	9	[{"id_menu":7,"count":1}]	26390	delivery	5	14
71407	2020-06-01 02:12:12	2020-06-01	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2646	delivery	5	25
71408	2020-06-01 02:17:36	2020-06-01	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":2}]	28231	delivery	5	22
71409	2020-06-01 02:23:26	2020-06-01	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	28264	delivery	5	37
71410	2020-06-01 02:29:58	2020-06-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12966	delivery	5	22
71411	2020-06-01 02:33:01	2020-06-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28198	delivery	5	22
71412	2020-06-01 02:36:58	2020-06-01	9	[{"id_menu":7,"count":1}]	10541	pick-up	0	9
71413	2020-06-01 02:38:14	2020-06-01	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20062	delivery	5	31
71414	2020-06-01 02:40:10	2020-06-01	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	28318	delivery	5	26
71415	2020-06-01 02:42:34	2020-06-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28332	delivery	5	23
71416	2020-06-01 02:46:03	2020-06-01	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	6361	delivery	5	38
71417	2020-06-01 02:47:34	2020-06-01	8	[{"id_menu":5,"count":1}]	28203	delivery	5	13
71418	2020-06-01 02:48:40	2020-06-01	9	[{"id_menu":7,"count":2}]	11262	pick-up	0	9
71419	2020-06-01 02:54:07	2020-06-01	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	27448	delivery	5	45
71420	2020-06-01 02:54:39	2020-06-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24221	delivery	5	23
71421	2020-06-01 02:55:12	2020-06-01	8	[{"id_menu":5,"count":1}]	13371	delivery	5	13
71422	2020-06-01 02:58:27	2020-06-01	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	28240	delivery	5	22
71423	2020-06-01 03:01:08	2020-06-01	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18772	delivery	5	37
71424	2020-06-01 03:02:14	2020-06-01	14	[{"id_menu":2,"count":1}]	5047	pick-up	0	14
71425	2020-06-01 03:05:21	2020-06-01	17	[{"id_menu":4,"count":1}]	1555	delivery	5	22
71426	2020-06-01 03:14:40	2020-06-01	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	12845	delivery	5	40
71427	2020-06-01 03:16:01	2020-06-01	8	[{"id_menu":5,"count":1}]	5707	delivery	5	13
71428	2020-06-01 03:17:00	2020-06-01	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11817	delivery	5	45
71429	2020-06-01 03:35:34	2020-06-01	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	16464	delivery	5	25
71430	2020-06-01 03:36:22	2020-06-01	17	[{"id_menu":4,"count":1}]	20169	delivery	5	22
71432	2020-06-01 03:39:03	2020-06-01	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	15082	delivery	5	34
71433	2020-06-01 03:39:33	2020-06-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12650	delivery	5	31
71434	2020-06-01 03:50:46	2020-06-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	28236	delivery	5	31
71435	2020-06-01 03:51:52	2020-06-01	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	23783	delivery	5	44
71436	2020-06-01 03:57:09	2020-06-01	12	[{"id_menu":3,"count":1}]	28155	delivery	5	17
71437	2020-06-01 04:04:16	2020-06-01	9	[{"id_menu":6,"count":1}]	17430	pick-up	0	9
71438	2020-06-01 04:04:56	2020-06-01	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	7146	delivery	5	46
71439	2020-06-01 04:10:25	2020-06-01	9	[{"id_menu":7,"count":1}]	1649	pick-up	0	9
71440	2020-06-01 04:11:22	2020-06-01	14	[{"id_menu":2,"count":1}]	28275	delivery	5	19
71441	2020-06-01 04:12:37	2020-06-01	9	[{"id_menu":6,"count":1}]	23394	delivery	5	14
71442	2020-06-01 04:20:52	2020-06-01	12	[{"id_menu":3,"count":1}]	28266	pick-up	0	12
71443	2020-06-01 04:21:32	2020-06-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28273	delivery	5	23
71444	2020-06-01 04:27:22	2020-06-01	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	7025	delivery	5	36
71445	2020-06-01 04:31:09	2020-06-01	9	[{"id_menu":6,"count":1}]	28175	delivery	5	14
71446	2020-06-01 04:34:29	2020-06-01	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14884	pick-up	0	26
71447	2020-06-01 04:38:42	2020-06-01	9	[{"id_menu":7,"count":1}]	14410	pick-up	0	9
71448	2020-06-01 04:50:17	2020-06-01	14	[{"id_menu":2,"count":2}]	13841	pick-up	0	14
71449	2020-06-01 05:01:06	2020-06-01	12	[{"id_menu":1,"count":1}]	28319	delivery	5	17
71450	2020-06-01 05:04:44	2020-06-01	12	[{"id_menu":3,"count":1}]	58	pick-up	0	12
71451	2020-06-01 05:06:33	2020-06-01	14	[{"id_menu":2,"count":1}]	27825	delivery	5	19
71452	2020-06-01 05:12:31	2020-06-01	8	[{"id_menu":5,"count":1}]	28201	delivery	5	13
71453	2020-06-01 05:19:12	2020-06-01	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	28326	delivery	5	31
71454	2020-06-01 05:24:48	2020-06-01	9	[{"id_menu":7,"count":1}]	11760	delivery	5	14
71455	2020-06-01 05:26:37	2020-06-01	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4798	pick-up	0	22
71456	2020-06-01 05:31:45	2020-06-01	9	[{"id_menu":6,"count":2}]	8115	delivery	5	14
71457	2020-06-01 05:32:06	2020-06-01	12	[{"id_menu":3,"count":1}]	24668	pick-up	0	12
71458	2020-06-01 05:32:57	2020-06-01	9	[{"id_menu":7,"count":2}]	25637	delivery	5	14
71459	2020-06-01 05:41:42	2020-06-01	9	[{"id_menu":6,"count":1}]	28298	delivery	5	14
71460	2020-06-01 05:44:16	2020-06-01	12	[{"id_menu":3,"count":1}]	28311	delivery	5	17
71461	2020-06-01 05:47:01	2020-06-01	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	5917	pick-up	0	26
71462	2020-06-01 05:48:46	2020-06-01	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28242	delivery	5	34
71463	2020-06-01 06:00:32	2020-06-01	8	[{"id_menu":5,"count":1}]	15083	delivery	5	13
71464	2020-06-01 06:04:15	2020-06-01	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	28196	delivery	5	43
71465	2020-06-01 06:04:39	2020-06-01	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	2756	pick-up	0	24
71466	2020-06-01 06:26:52	2020-06-01	17	[{"id_menu":4,"count":1}]	340	pick-up	0	17
71467	2020-06-01 06:32:38	2020-06-01	9	[{"id_menu":6,"count":1}]	4746	delivery	5	14
71468	2020-06-01 06:34:06	2020-06-01	9	[{"id_menu":7,"count":1}]	28325	delivery	5	14
71469	2020-06-01 06:35:33	2020-06-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12378	delivery	5	31
71470	2020-06-01 06:43:29	2020-06-01	8	[{"id_menu":5,"count":1}]	26218	delivery	5	13
71471	2020-06-01 06:47:03	2020-06-01	9	[{"id_menu":6,"count":1}]	17010	pick-up	0	9
71472	2020-06-01 06:49:05	2020-06-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	10019	pick-up	0	31
71473	2020-06-01 06:49:10	2020-06-01	8	[{"id_menu":5,"count":1}]	28170	delivery	5	13
71474	2020-06-01 06:54:41	2020-06-01	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1369	pick-up	0	24
71475	2020-06-01 06:55:54	2020-06-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28228	delivery	5	23
71476	2020-06-01 06:57:53	2020-06-01	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	13105	delivery	5	25
71477	2020-06-01 07:05:44	2020-06-01	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28269	delivery	5	46
71478	2020-06-01 07:23:05	2020-06-01	9	[{"id_menu":7,"count":1}]	10335	delivery	5	14
71479	2020-06-01 07:29:27	2020-06-01	9	[{"id_menu":6,"count":1}]	14488	delivery	5	14
71480	2020-06-01 07:30:14	2020-06-01	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28229	delivery	5	52
71481	2020-06-01 07:32:01	2020-06-01	12	[{"id_menu":1,"count":1}]	27499	delivery	5	17
71482	2020-06-01 07:32:25	2020-06-01	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	28187	delivery	5	30
71483	2020-06-01 07:37:34	2020-06-01	9	[{"id_menu":6,"count":1}]	28169	delivery	5	14
71484	2020-06-01 07:38:37	2020-06-01	17	[{"id_menu":4,"count":1}]	18763	delivery	5	22
71485	2020-06-01 07:39:45	2020-06-01	17	[{"id_menu":4,"count":1}]	14	delivery	5	22
71486	2020-06-01 07:45:32	2020-06-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":3}]	28263	delivery	5	22
71487	2020-06-01 07:47:20	2020-06-01	8	[{"id_menu":5,"count":2}]	10706	pick-up	0	8
71488	2020-06-01 07:47:32	2020-06-01	9	[{"id_menu":7,"count":1}]	6596	delivery	5	14
71489	2020-06-01 07:50:13	2020-06-01	14	[{"id_menu":2,"count":1}]	26163	delivery	5	19
71490	2020-06-01 07:53:17	2020-06-01	14	[{"id_menu":2,"count":1}]	27827	delivery	5	19
71491	2020-06-01 07:54:31	2020-06-01	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1929	pick-up	0	24
71492	2020-06-01 07:56:27	2020-06-01	12	[{"id_menu":3,"count":1}]	28249	delivery	5	17
71493	2020-06-01 08:00:18	2020-06-01	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28324	delivery	5	36
71494	2020-06-01 08:01:51	2020-06-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	28168	delivery	5	28
71495	2020-06-01 08:06:56	2020-06-01	9	[{"id_menu":6,"count":1}]	25346	pick-up	0	9
71496	2020-06-01 08:11:32	2020-06-01	9	[{"id_menu":6,"count":1}]	13629	delivery	5	14
71497	2020-06-01 08:15:31	2020-06-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2585	pick-up	0	31
71498	2020-06-01 08:29:37	2020-06-01	17	[{"id_menu":4,"count":1}]	28244	delivery	5	22
71499	2020-06-01 08:31:15	2020-06-01	9	[{"id_menu":7,"count":1}]	2573	pick-up	0	9
71500	2020-06-01 08:32:31	2020-06-01	9	[{"id_menu":7,"count":1}]	15330	delivery	5	14
71501	2020-06-01 08:34:14	2020-06-01	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6953	delivery	5	49
71502	2020-06-01 08:36:25	2020-06-01	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	28177	delivery	5	42
71503	2020-06-01 08:40:10	2020-06-01	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	17270	delivery	5	31
71504	2020-06-01 08:40:39	2020-06-01	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28262	delivery	5	34
71505	2020-06-01 08:48:53	2020-06-01	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	13947	delivery	5	31
71506	2020-06-01 08:50:49	2020-06-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28232	delivery	5	22
71507	2020-06-01 08:54:09	2020-06-01	17	[{"id_menu":4,"count":2}]	27685	pick-up	0	17
71508	2020-06-01 08:55:55	2020-06-01	8	[{"id_menu":5,"count":1}]	28253	delivery	5	13
71509	2020-06-01 09:06:28	2020-06-01	14	[{"id_menu":2,"count":1}]	11104	delivery	5	19
71510	2020-06-01 09:08:53	2020-06-01	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	28182	delivery	5	31
71511	2020-06-01 09:10:13	2020-06-01	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28257	delivery	5	35
71512	2020-06-01 09:12:45	2020-06-01	17	[{"id_menu":4,"count":2}]	5248	pick-up	0	17
71513	2020-06-01 09:21:28	2020-06-01	9	[{"id_menu":7,"count":1}]	28205	delivery	5	14
71514	2020-06-01 09:25:04	2020-06-01	12	[{"id_menu":1,"count":1}]	16301	delivery	5	17
71515	2020-06-01 09:31:43	2020-06-01	14	[{"id_menu":2,"count":1}]	28180	pick-up	0	14
71516	2020-06-01 09:35:08	2020-06-01	12	[{"id_menu":1,"count":1}]	28204	delivery	5	17
71517	2020-06-01 09:41:57	2020-06-01	8	[{"id_menu":5,"count":1}]	28290	delivery	5	13
71518	2020-06-01 09:46:27	2020-06-01	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4287	delivery	5	45
71519	2020-06-01 09:46:54	2020-06-01	17	[{"id_menu":4,"count":1}]	28316	pick-up	0	17
71520	2020-06-01 09:47:36	2020-06-01	12	[{"id_menu":1,"count":1}]	27862	pick-up	0	12
71521	2020-06-01 09:48:23	2020-06-01	8	[{"id_menu":5,"count":1}]	25539	delivery	5	13
71522	2020-06-01 09:52:19	2020-06-01	12	[{"id_menu":1,"count":1}]	28166	delivery	5	17
71523	2020-06-01 09:53:01	2020-06-01	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	28268	delivery	5	36
71524	2020-06-01 09:53:23	2020-06-01	9	[{"id_menu":7,"count":1}]	4490	delivery	5	14
71525	2020-06-01 09:56:18	2020-06-01	9	[{"id_menu":6,"count":1}]	16578	delivery	5	14
71526	2020-06-01 10:00:00	2020-06-01	12	[{"id_menu":1,"count":1}]	28251	delivery	5	17
71527	2020-06-01 10:09:41	2020-06-01	8	[{"id_menu":5,"count":1}]	28336	delivery	5	13
71528	2020-06-01 10:13:17	2020-06-01	14	[{"id_menu":2,"count":1}]	8617	pick-up	0	14
71529	2020-06-01 10:30:14	2020-06-01	8	[{"id_menu":5,"count":1}]	28321	delivery	5	13
71530	2020-06-01 10:31:58	2020-06-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23203	delivery	5	22
71531	2020-06-01 10:32:09	2020-06-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	28252	pick-up	0	23
71532	2020-06-01 10:32:51	2020-06-01	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	28243	pick-up	0	35
71533	2020-06-01 10:41:58	2020-06-01	14	[{"id_menu":2,"count":1}]	25954	pick-up	0	14
71534	2020-06-01 10:45:55	2020-06-01	14	[{"id_menu":2,"count":1}]	21978	pick-up	0	14
71535	2020-06-01 10:54:51	2020-06-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6005	delivery	5	28
71536	2020-06-01 10:57:19	2020-06-01	8	[{"id_menu":5,"count":1}]	8198	delivery	5	13
71537	2020-06-01 11:03:47	2020-06-01	12	[{"id_menu":3,"count":1}]	22202	delivery	5	17
71538	2020-06-01 11:05:13	2020-06-01	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28171	delivery	5	39
71539	2020-06-01 11:08:21	2020-06-01	8	[{"id_menu":5,"count":1}]	28246	delivery	5	13
71540	2020-06-01 11:09:57	2020-06-01	14	[{"id_menu":2,"count":1}]	23602	pick-up	0	14
71541	2020-06-01 11:13:03	2020-06-01	8	[{"id_menu":5,"count":1}]	17064	delivery	5	13
71542	2020-06-01 11:16:32	2020-06-01	17	[{"id_menu":4,"count":1}]	28248	delivery	5	22
71543	2020-06-01 11:20:13	2020-06-01	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	27007	delivery	5	25
71544	2020-06-01 11:24:00	2020-06-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	24411	delivery	5	28
71545	2020-06-01 11:25:39	2020-06-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2116	delivery	5	26
71546	2020-06-01 11:32:44	2020-06-01	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	18542	delivery	5	36
71547	2020-06-01 11:37:14	2020-06-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	23268	delivery	5	28
71548	2020-06-01 11:38:16	2020-06-01	17	[{"id_menu":4,"count":1}]	28328	pick-up	0	17
71549	2020-06-01 11:41:22	2020-06-01	8	[{"id_menu":5,"count":2}]	28200	delivery	5	13
71550	2020-06-01 11:42:50	2020-06-01	9	[{"id_menu":7,"count":1}]	26493	delivery	5	14
71551	2020-06-01 11:49:40	2020-06-01	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	3127	delivery	5	27
71552	2020-06-01 12:01:27	2020-06-01	9	[{"id_menu":7,"count":1}]	18655	delivery	5	14
71553	2020-06-01 12:01:54	2020-06-01	14	[{"id_menu":2,"count":1}]	18149	delivery	5	19
71554	2020-06-01 12:09:45	2020-06-01	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3877	pick-up	0	21
71555	2020-06-01 12:14:01	2020-06-01	9	[{"id_menu":6,"count":1}]	19042	delivery	5	14
71556	2020-06-01 12:15:39	2020-06-01	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	7181	delivery	5	40
71557	2020-06-01 12:19:57	2020-06-01	9	[{"id_menu":6,"count":1}]	28179	delivery	5	14
71558	2020-06-01 12:26:18	2020-06-01	9	[{"id_menu":7,"count":1}]	28300	delivery	5	14
71559	2020-06-01 12:29:20	2020-06-01	14	[{"id_menu":2,"count":1}]	28218	delivery	5	19
71560	2020-06-01 12:29:57	2020-06-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12184	pick-up	0	18
71561	2020-06-01 12:30:17	2020-06-01	17	[{"id_menu":4,"count":1}]	28183	delivery	5	22
71562	2020-06-01 12:34:00	2020-06-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10334	delivery	5	31
71563	2020-06-01 12:35:50	2020-06-01	9	[{"id_menu":6,"count":1}]	6802	delivery	5	14
71564	2020-06-01 12:36:06	2020-06-01	17	[{"id_menu":4,"count":1}]	23030	delivery	5	22
71565	2020-06-01 12:36:35	2020-06-01	9	[{"id_menu":6,"count":1}]	3007	delivery	5	14
71566	2020-06-01 12:38:00	2020-06-01	17	[{"id_menu":4,"count":1}]	16467	delivery	5	22
71567	2020-06-01 12:39:32	2020-06-01	14	[{"id_menu":2,"count":1}]	23986	delivery	5	19
71568	2020-06-01 12:40:42	2020-06-01	12	[{"id_menu":3,"count":1}]	26018	delivery	5	17
71569	2020-06-01 12:53:57	2020-06-01	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	16165	delivery	5	30
71570	2020-06-01 12:54:43	2020-06-01	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	20183	delivery	5	31
71571	2020-06-01 12:59:27	2020-06-01	17	[{"id_menu":4,"count":1}]	19911	pick-up	0	17
71572	2020-06-01 13:05:50	2020-06-01	8	[{"id_menu":5,"count":1}]	14018	pick-up	0	8
71573	2020-06-01 13:07:31	2020-06-01	14	[{"id_menu":2,"count":1}]	5155	delivery	5	19
71574	2020-06-01 13:07:35	2020-06-01	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	14177	delivery	5	44
71575	2020-06-01 13:08:03	2020-06-01	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18090	delivery	5	45
71576	2020-06-01 13:23:45	2020-06-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	24156	pick-up	0	31
71577	2020-06-01 13:26:38	2020-06-01	17	[{"id_menu":4,"count":1}]	19251	delivery	5	22
71578	2020-06-01 13:28:06	2020-06-01	9	[{"id_menu":6,"count":1}]	28226	pick-up	0	9
71579	2020-06-01 13:31:12	2020-06-01	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28291	delivery	5	49
71580	2020-06-01 13:32:16	2020-06-01	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	12282	delivery	5	31
71581	2020-06-01 13:47:04	2020-06-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7622	delivery	5	31
71582	2020-06-01 13:51:12	2020-06-01	9	[{"id_menu":7,"count":1}]	8702	delivery	5	14
71583	2020-06-01 13:57:11	2020-06-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	28207	delivery	5	23
71584	2020-06-01 13:57:29	2020-06-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	28185	delivery	5	36
71585	2020-06-01 14:01:18	2020-06-01	9	[{"id_menu":7,"count":1}]	28305	pick-up	0	9
71586	2020-06-01 14:02:18	2020-06-01	8	[{"id_menu":5,"count":2}]	20713	pick-up	0	8
71587	2020-06-01 14:11:42	2020-06-01	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	28339	delivery	5	26
71588	2020-06-01 14:11:51	2020-06-01	14	[{"id_menu":2,"count":1}]	24650	pick-up	0	14
71589	2020-06-01 14:19:58	2020-06-01	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21915	delivery	5	39
71590	2020-06-01 14:21:44	2020-06-01	8	[{"id_menu":5,"count":1}]	28208	delivery	5	13
71591	2020-06-01 14:24:11	2020-06-01	9	[{"id_menu":7,"count":1}]	21110	delivery	5	14
71592	2020-06-01 14:28:13	2020-06-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	28258	delivery	5	28
71593	2020-06-01 14:30:15	2020-06-01	12	[{"id_menu":3,"count":1}]	17397	pick-up	0	12
71594	2020-06-01 14:35:01	2020-06-01	12	[{"id_menu":1,"count":1}]	623	pick-up	0	12
71595	2020-06-01 14:40:24	2020-06-01	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	28184	delivery	5	43
71596	2020-06-01 14:49:21	2020-06-01	8	[{"id_menu":5,"count":2}]	10561	delivery	5	13
71597	2020-06-01 14:52:46	2020-06-01	12	[{"id_menu":3,"count":1}]	28330	delivery	5	17
71598	2020-06-01 14:58:15	2020-06-01	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17394	delivery	5	31
71599	2020-06-01 15:00:31	2020-06-01	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	17095	delivery	5	25
71600	2020-06-01 15:01:17	2020-06-01	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	28284	delivery	5	25
71601	2020-06-01 15:03:16	2020-06-01	12	[{"id_menu":1,"count":1}]	28331	delivery	5	17
71602	2020-06-01 15:04:42	2020-06-01	8	[{"id_menu":5,"count":1}]	28304	delivery	5	13
71603	2020-06-01 15:13:48	2020-06-01	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15120	pick-up	0	40
71604	2020-06-01 15:19:52	2020-06-01	8	[{"id_menu":5,"count":1}]	8802	pick-up	0	8
71605	2020-06-01 15:21:23	2020-06-01	14	[{"id_menu":2,"count":1}]	28320	delivery	5	19
71606	2020-06-01 15:25:41	2020-06-01	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	18096	delivery	5	31
71607	2020-06-01 15:30:12	2020-06-01	9	[{"id_menu":6,"count":1}]	28345	delivery	5	14
71608	2020-06-01 15:30:20	2020-06-01	14	[{"id_menu":2,"count":1}]	28233	delivery	5	19
71609	2020-06-01 15:32:26	2020-06-01	12	[{"id_menu":1,"count":1}]	28189	delivery	5	17
71610	2020-06-01 15:33:46	2020-06-01	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	28230	delivery	5	25
71611	2020-06-01 15:37:39	2020-06-01	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	23401	delivery	5	23
71612	2020-06-01 15:41:20	2020-06-01	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	23954	delivery	5	30
71613	2020-06-01 15:46:38	2020-06-01	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":2}]	6589	pick-up	0	23
71614	2020-06-01 15:59:05	2020-06-01	22	[{"id_menu":2,"count":3},{"id_menu":5,"count":1}]	28333	delivery	5	27
71615	2020-06-01 16:00:24	2020-06-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	27798	delivery	5	31
71616	2020-06-01 16:02:20	2020-06-01	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	28234	pick-up	0	20
71617	2020-06-01 16:10:25	2020-06-01	12	[{"id_menu":3,"count":1}]	28279	pick-up	0	12
71618	2020-06-01 16:11:45	2020-06-01	9	[{"id_menu":6,"count":1}]	12544	delivery	5	14
71619	2020-06-01 16:12:38	2020-06-01	9	[{"id_menu":7,"count":1}]	6536	delivery	5	14
71620	2020-06-01 16:19:14	2020-06-01	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28285	delivery	5	37
71621	2020-06-01 16:19:49	2020-06-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6322	delivery	5	28
71622	2020-06-01 16:21:48	2020-06-01	8	[{"id_menu":5,"count":1}]	13019	pick-up	0	8
71623	2020-06-01 16:28:24	2020-06-01	8	[{"id_menu":5,"count":1}]	9175	delivery	5	13
71624	2020-06-01 16:34:53	2020-06-01	14	[{"id_menu":2,"count":1}]	19358	delivery	5	19
71625	2020-06-01 16:35:59	2020-06-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	19793	delivery	5	22
71626	2020-06-01 16:36:09	2020-06-01	17	[{"id_menu":4,"count":1}]	28272	delivery	5	22
71627	2020-06-01 16:37:44	2020-06-01	9	[{"id_menu":6,"count":1}]	28193	delivery	5	14
71628	2020-06-01 16:38:01	2020-06-01	9	[{"id_menu":6,"count":1}]	15194	pick-up	0	9
71629	2020-06-01 16:45:19	2020-06-01	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13875	delivery	5	49
71630	2020-06-01 16:45:39	2020-06-01	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	28181	delivery	5	31
71631	2020-06-01 16:48:09	2020-06-01	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	28227	delivery	5	25
71632	2020-06-01 16:52:58	2020-06-01	14	[{"id_menu":2,"count":1}]	15267	pick-up	0	14
71633	2020-06-01 17:03:46	2020-06-01	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19371	delivery	5	34
71634	2020-06-01 17:05:12	2020-06-01	12	[{"id_menu":3,"count":2}]	28215	delivery	5	17
71635	2020-06-01 17:07:25	2020-06-01	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15018	delivery	5	37
71636	2020-06-01 17:09:22	2020-06-01	12	[{"id_menu":1,"count":1}]	5478	pick-up	0	12
71637	2020-06-01 17:13:10	2020-06-01	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	16041	delivery	5	34
71638	2020-06-01 17:14:05	2020-06-01	12	[{"id_menu":3,"count":1}]	2761	delivery	5	17
71639	2020-06-01 17:15:23	2020-06-01	9	[{"id_menu":7,"count":1}]	665	delivery	5	14
71640	2020-06-01 17:22:33	2020-06-01	9	[{"id_menu":7,"count":2}]	19798	pick-up	0	9
71641	2020-06-01 17:33:01	2020-06-01	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	28301	delivery	5	28
71642	2020-06-01 17:49:27	2020-06-01	9	[{"id_menu":7,"count":2}]	5615	delivery	5	14
71643	2020-06-01 17:49:42	2020-06-01	9	[{"id_menu":6,"count":1}]	28313	delivery	5	14
71644	2020-06-01 17:53:01	2020-06-01	14	[{"id_menu":2,"count":1}]	28306	delivery	5	19
71645	2020-06-01 17:53:19	2020-06-01	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	24697	pick-up	0	21
71646	2020-06-01 17:55:07	2020-06-01	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	22338	delivery	5	31
71647	2020-06-01 17:56:44	2020-06-01	12	[{"id_menu":1,"count":1}]	1208	pick-up	0	12
71648	2020-06-01 18:05:47	2020-06-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12949	delivery	5	31
71649	2020-06-01 18:18:20	2020-06-01	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	13662	delivery	5	29
71650	2020-06-01 18:19:43	2020-06-01	9	[{"id_menu":7,"count":1}]	28299	delivery	5	14
71651	2020-06-01 18:22:19	2020-06-01	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	20302	delivery	5	46
71652	2020-06-01 18:30:06	2020-06-01	17	[{"id_menu":4,"count":1}]	28260	delivery	5	22
71653	2020-06-01 18:30:48	2020-06-01	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	14313	delivery	5	34
71654	2020-06-01 18:34:52	2020-06-01	8	[{"id_menu":5,"count":1}]	3527	pick-up	0	8
71655	2020-06-01 18:40:27	2020-06-01	12	[{"id_menu":3,"count":1}]	28206	delivery	5	17
71656	2020-06-01 18:43:49	2020-06-01	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	19172	delivery	5	39
71657	2020-06-01 18:50:27	2020-06-01	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11812	delivery	5	36
71658	2020-06-01 18:53:13	2020-06-01	9	[{"id_menu":6,"count":1}]	24870	delivery	5	14
71659	2020-06-01 18:55:43	2020-06-01	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28274	delivery	5	48
71660	2020-06-01 18:59:29	2020-06-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	5353	delivery	5	36
71661	2020-06-01 19:00:41	2020-06-01	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28323	delivery	5	34
71662	2020-06-01 19:03:03	2020-06-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	26255	pick-up	0	26
71663	2020-06-01 19:09:03	2020-06-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	28217	delivery	5	36
71664	2020-06-01 19:13:33	2020-06-01	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	281	delivery	5	51
71665	2020-06-01 19:14:54	2020-06-01	12	[{"id_menu":3,"count":1}]	5387	pick-up	0	12
71666	2020-06-01 19:18:34	2020-06-01	9	[{"id_menu":6,"count":1}]	28172	pick-up	0	9
71667	2020-06-01 19:19:29	2020-06-01	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	21838	delivery	5	25
71668	2020-06-01 19:20:19	2020-06-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13660	delivery	5	22
71669	2020-06-01 19:22:34	2020-06-01	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5302	pick-up	0	46
71670	2020-06-01 19:23:20	2020-06-01	8	[{"id_menu":5,"count":1}]	12297	delivery	5	13
71671	2020-06-01 19:30:53	2020-06-01	9	[{"id_menu":7,"count":1}]	1493	pick-up	0	9
71672	2020-06-01 19:39:20	2020-06-01	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	28312	delivery	5	39
71673	2020-06-01 19:42:12	2020-06-01	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	28314	delivery	5	30
71674	2020-06-01 19:48:52	2020-06-01	12	[{"id_menu":1,"count":1}]	6928	delivery	5	17
71675	2020-06-01 19:50:36	2020-06-01	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	594	pick-up	0	38
71676	2020-06-01 20:03:16	2020-06-01	9	[{"id_menu":7,"count":1}]	27583	delivery	5	14
71677	2020-06-01 20:04:57	2020-06-01	8	[{"id_menu":5,"count":1}]	1115	delivery	5	13
71678	2020-06-01 20:08:49	2020-06-01	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	26536	delivery	5	43
71679	2020-06-01 20:15:00	2020-06-01	12	[{"id_menu":3,"count":1}]	14066	pick-up	0	12
71680	2020-06-01 20:16:42	2020-06-01	12	[{"id_menu":1,"count":1}]	21770	pick-up	0	12
71681	2020-06-01 20:25:14	2020-06-01	14	[{"id_menu":2,"count":1}]	28190	delivery	5	19
71682	2020-06-01 20:25:16	2020-06-01	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	28281	delivery	5	29
71683	2020-06-01 20:30:04	2020-06-01	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	22443	delivery	5	30
71684	2020-06-01 20:31:34	2020-06-01	17	[{"id_menu":4,"count":1}]	3175	delivery	5	22
71685	2020-06-01 20:37:13	2020-06-01	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	21907	delivery	5	31
71686	2020-06-01 20:40:05	2020-06-01	14	[{"id_menu":2,"count":1}]	71	pick-up	0	14
71687	2020-06-01 20:48:04	2020-06-01	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28307	delivery	5	36
71688	2020-06-01 20:51:39	2020-06-01	9	[{"id_menu":7,"count":1}]	28245	delivery	5	14
71689	2020-06-01 20:54:07	2020-06-01	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	28158	pick-up	0	21
71690	2020-06-01 20:54:55	2020-06-01	9	[{"id_menu":6,"count":1}]	6902	delivery	5	14
71691	2020-06-01 20:55:03	2020-06-01	14	[{"id_menu":2,"count":1}]	28293	delivery	5	19
71692	2020-06-01 20:57:24	2020-06-01	8	[{"id_menu":5,"count":1}]	18789	pick-up	0	8
71693	2020-06-01 20:58:24	2020-06-01	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	16450	delivery	5	25
71694	2020-06-01 21:00:06	2020-06-01	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9296	delivery	5	35
71695	2020-06-01 21:05:11	2020-06-01	12	[{"id_menu":1,"count":1}]	8953	delivery	5	17
71696	2020-06-01 21:08:03	2020-06-01	14	[{"id_menu":2,"count":2}]	440	delivery	5	19
71697	2020-06-01 21:15:50	2020-06-01	8	[{"id_menu":5,"count":1}]	6867	pick-up	0	8
71698	2020-06-01 21:17:41	2020-06-01	9	[{"id_menu":6,"count":2}]	28224	delivery	5	14
71699	2020-06-01 21:18:30	2020-06-01	9	[{"id_menu":6,"count":1}]	28216	delivery	5	14
71700	2020-06-01 21:21:08	2020-06-01	8	[{"id_menu":5,"count":1}]	1390	pick-up	0	8
71701	2020-06-01 21:24:58	2020-06-01	17	[{"id_menu":4,"count":1}]	1269	pick-up	0	17
71702	2020-06-01 21:28:29	2020-06-01	9	[{"id_menu":6,"count":1}]	28167	pick-up	0	9
71703	2020-06-01 21:31:03	2020-06-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28174	delivery	5	22
71704	2020-06-01 21:31:58	2020-06-01	9	[{"id_menu":7,"count":1}]	28309	delivery	5	14
71705	2020-06-01 21:33:30	2020-06-01	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	28277	delivery	5	23
71706	2020-06-01 21:35:37	2020-06-01	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24252	delivery	5	48
71707	2020-06-01 21:38:45	2020-06-01	9	[{"id_menu":6,"count":1}]	13354	delivery	5	14
71708	2020-06-01 21:42:15	2020-06-01	12	[{"id_menu":3,"count":1}]	16367	delivery	5	17
71709	2020-06-01 21:52:09	2020-06-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	356	delivery	5	22
71710	2020-06-01 22:01:46	2020-06-01	9	[{"id_menu":6,"count":1}]	16223	pick-up	0	9
71711	2020-06-01 22:05:15	2020-06-01	12	[{"id_menu":3,"count":1}]	15976	pick-up	0	12
71712	2020-06-01 22:05:55	2020-06-01	9	[{"id_menu":7,"count":1}]	4436	pick-up	0	9
71713	2020-06-01 22:06:26	2020-06-01	12	[{"id_menu":1,"count":1}]	21612	delivery	5	17
71714	2020-06-01 22:07:07	2020-06-01	8	[{"id_menu":5,"count":1}]	12132	delivery	5	13
71715	2020-06-01 22:19:46	2020-06-01	17	[{"id_menu":4,"count":1}]	12978	delivery	5	22
71716	2020-06-01 22:22:02	2020-06-01	14	[{"id_menu":2,"count":1}]	8454	pick-up	0	14
71717	2020-06-01 22:24:13	2020-06-01	14	[{"id_menu":2,"count":1}]	4765	pick-up	0	14
71718	2020-06-01 22:25:20	2020-06-01	9	[{"id_menu":6,"count":1}]	28334	delivery	5	14
71719	2020-06-01 22:27:01	2020-06-01	9	[{"id_menu":6,"count":3}]	20630	delivery	5	14
71720	2020-06-01 22:31:58	2020-06-01	17	[{"id_menu":4,"count":1}]	22564	delivery	5	22
71721	2020-06-01 22:44:52	2020-06-01	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	9696	delivery	5	36
71722	2020-06-01 22:51:19	2020-06-01	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	28267	delivery	5	42
71723	2020-06-01 22:59:27	2020-06-01	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	14637	delivery	5	26
71724	2020-06-01 22:59:45	2020-06-01	14	[{"id_menu":2,"count":1}]	28270	delivery	5	19
71725	2020-06-01 23:03:39	2020-06-01	14	[{"id_menu":2,"count":1}]	15265	pick-up	0	14
71726	2020-06-01 23:04:55	2020-06-01	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18477	delivery	5	39
71727	2020-06-01 23:07:54	2020-06-01	8	[{"id_menu":5,"count":1}]	27011	delivery	5	13
71728	2020-06-01 23:08:08	2020-06-01	9	[{"id_menu":7,"count":2}]	24129	delivery	5	14
71729	2020-06-01 23:09:50	2020-06-01	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	28213	delivery	5	40
71730	2020-06-01 23:10:21	2020-06-01	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	18210	delivery	5	39
71731	2020-06-01 23:10:53	2020-06-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10238	delivery	5	22
71732	2020-06-01 23:12:02	2020-06-01	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	28235	delivery	5	34
71733	2020-06-01 23:16:45	2020-06-01	17	[{"id_menu":4,"count":1}]	2957	pick-up	0	17
71734	2020-06-01 23:23:49	2020-06-01	14	[{"id_menu":2,"count":1}]	28289	pick-up	0	14
71735	2020-06-01 23:31:12	2020-06-01	9	[{"id_menu":7,"count":1}]	6938	delivery	5	14
71736	2020-06-01 23:32:48	2020-06-01	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	24246	delivery	5	39
71737	2020-06-01 23:39:52	2020-06-01	12	[{"id_menu":1,"count":1}]	18746	delivery	5	17
71738	2020-06-01 23:45:32	2020-06-01	9	[{"id_menu":7,"count":1}]	28329	delivery	5	14
71739	2020-06-02 00:04:04	2020-06-02	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1387	delivery	5	52
71740	2020-06-02 00:08:18	2020-06-02	9	[{"id_menu":6,"count":1}]	14764	pick-up	0	9
71741	2020-06-02 00:16:14	2020-06-02	8	[{"id_menu":5,"count":1}]	7714	delivery	5	13
71742	2020-06-02 00:17:34	2020-06-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14025	pick-up	0	17
71743	2020-06-02 00:18:12	2020-06-02	14	[{"id_menu":2,"count":1}]	7219	pick-up	0	14
71744	2020-06-02 00:19:35	2020-06-02	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	28516	delivery	5	44
71745	2020-06-02 00:19:44	2020-06-02	12	[{"id_menu":1,"count":1}]	28503	delivery	5	17
71746	2020-06-02 00:23:27	2020-06-02	12	[{"id_menu":1,"count":1}]	27316	delivery	5	17
71747	2020-06-02 00:34:30	2020-06-02	9	[{"id_menu":7,"count":1}]	4242	delivery	5	14
71748	2020-06-02 00:39:42	2020-06-02	14	[{"id_menu":2,"count":1}]	1321	pick-up	0	14
71749	2020-06-02 00:42:00	2020-06-02	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	28433	delivery	5	31
71750	2020-06-02 00:44:35	2020-06-02	8	[{"id_menu":5,"count":1}]	314	pick-up	0	8
71751	2020-06-02 00:51:33	2020-06-02	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	26333	delivery	5	43
71752	2020-06-02 00:51:54	2020-06-02	9	[{"id_menu":6,"count":1}]	5277	pick-up	0	9
71753	2020-06-02 01:07:46	2020-06-02	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	14689	delivery	5	26
71754	2020-06-02 01:08:05	2020-06-02	14	[{"id_menu":2,"count":1}]	28431	pick-up	0	14
71755	2020-06-02 01:16:00	2020-06-02	12	[{"id_menu":3,"count":1}]	20564	delivery	5	17
71756	2020-06-02 01:23:44	2020-06-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1460	pick-up	0	23
71757	2020-06-02 01:26:43	2020-06-02	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28475	pick-up	0	32
71758	2020-06-02 01:34:12	2020-06-02	9	[{"id_menu":7,"count":1}]	6883	delivery	5	14
71759	2020-06-02 01:42:30	2020-06-02	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	13644	delivery	5	26
71760	2020-06-02 01:44:11	2020-06-02	9	[{"id_menu":6,"count":1}]	19305	delivery	5	14
71761	2020-06-02 01:46:23	2020-06-02	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	28473	delivery	5	45
71762	2020-06-02 01:48:17	2020-06-02	12	[{"id_menu":3,"count":1}]	12474	pick-up	0	12
71763	2020-06-02 01:52:37	2020-06-02	12	[{"id_menu":3,"count":1}]	7703	delivery	5	17
71764	2020-06-02 01:57:10	2020-06-02	9	[{"id_menu":6,"count":1}]	20754	pick-up	0	9
71765	2020-06-02 01:57:15	2020-06-02	9	[{"id_menu":6,"count":1}]	28408	delivery	5	14
71766	2020-06-02 01:57:17	2020-06-02	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	28404	delivery	5	45
71767	2020-06-02 01:58:49	2020-06-02	8	[{"id_menu":5,"count":1}]	7453	delivery	5	13
71768	2020-06-02 02:10:02	2020-06-02	14	[{"id_menu":2,"count":1}]	11239	pick-up	0	14
71769	2020-06-02 02:12:04	2020-06-02	9	[{"id_menu":7,"count":1}]	28523	delivery	5	14
71770	2020-06-02 02:16:36	2020-06-02	12	[{"id_menu":1,"count":1}]	10421	delivery	5	17
71771	2020-06-02 02:18:17	2020-06-02	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	28320	delivery	5	37
71772	2020-06-02 02:20:28	2020-06-02	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28437	delivery	5	35
71773	2020-06-02 02:21:33	2020-06-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8105	delivery	5	23
71774	2020-06-02 02:24:17	2020-06-02	14	[{"id_menu":2,"count":1}]	10692	pick-up	0	14
71775	2020-06-02 02:32:05	2020-06-02	12	[{"id_menu":3,"count":1}]	28448	delivery	5	17
71776	2020-06-02 02:35:20	2020-06-02	17	[{"id_menu":4,"count":1}]	7118	pick-up	0	17
71777	2020-06-02 02:37:32	2020-06-02	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	11074	pick-up	0	21
71778	2020-06-02 02:40:43	2020-06-02	17	[{"id_menu":4,"count":1}]	15048	pick-up	0	17
71779	2020-06-02 02:42:13	2020-06-02	9	[{"id_menu":6,"count":1}]	15127	delivery	5	14
71780	2020-06-02 02:45:06	2020-06-02	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	13858	pick-up	0	26
71781	2020-06-02 02:46:21	2020-06-02	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	15983	delivery	5	34
71782	2020-06-02 02:47:35	2020-06-02	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	1768	delivery	5	26
71783	2020-06-02 02:52:21	2020-06-02	12	[{"id_menu":3,"count":1}]	28416	delivery	5	17
71784	2020-06-02 02:53:05	2020-06-02	14	[{"id_menu":2,"count":1}]	227	delivery	5	19
71785	2020-06-02 02:53:13	2020-06-02	17	[{"id_menu":4,"count":1}]	28467	delivery	5	22
71786	2020-06-02 02:55:34	2020-06-02	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6669	delivery	5	22
71787	2020-06-02 03:00:13	2020-06-02	9	[{"id_menu":7,"count":1}]	28421	delivery	5	14
71788	2020-06-02 03:13:56	2020-06-02	8	[{"id_menu":5,"count":1}]	28397	delivery	5	13
71789	2020-06-02 03:25:02	2020-06-02	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	17378	delivery	5	22
71790	2020-06-02 03:25:50	2020-06-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	28414	delivery	5	31
71791	2020-06-02 03:27:24	2020-06-02	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5528	delivery	5	45
71792	2020-06-02 03:27:48	2020-06-02	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16257	delivery	5	45
71793	2020-06-02 03:44:12	2020-06-02	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5682	delivery	5	35
71794	2020-06-02 03:48:04	2020-06-02	8	[{"id_menu":5,"count":1}]	6906	pick-up	0	8
71795	2020-06-02 03:52:10	2020-06-02	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	28427	delivery	5	31
71796	2020-06-02 03:56:19	2020-06-02	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	17835	delivery	5	39
71797	2020-06-02 04:00:55	2020-06-02	8	[{"id_menu":5,"count":1}]	28407	delivery	5	13
71798	2020-06-02 04:02:04	2020-06-02	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	14824	delivery	5	28
71799	2020-06-02 04:03:05	2020-06-02	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	360	pick-up	0	38
71800	2020-06-02 04:05:27	2020-06-02	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12117	delivery	5	39
71801	2020-06-02 04:11:30	2020-06-02	49	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8145	pick-up	0	49
71802	2020-06-02 04:13:19	2020-06-02	12	[{"id_menu":1,"count":1}]	18879	delivery	5	17
71803	2020-06-02 04:15:39	2020-06-02	14	[{"id_menu":2,"count":1}]	14703	delivery	5	19
71804	2020-06-02 04:16:04	2020-06-02	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2756	pick-up	0	20
71805	2020-06-02 04:22:00	2020-06-02	14	[{"id_menu":2,"count":1}]	857	pick-up	0	14
71806	2020-06-02 04:22:56	2020-06-02	8	[{"id_menu":5,"count":1}]	25182	delivery	5	13
71807	2020-06-02 04:29:15	2020-06-02	12	[{"id_menu":1,"count":1}]	11262	pick-up	0	12
71808	2020-06-02 04:31:43	2020-06-02	9	[{"id_menu":7,"count":1}]	7183	delivery	5	14
71809	2020-06-02 04:36:06	2020-06-02	12	[{"id_menu":3,"count":1}]	15801	delivery	5	17
71810	2020-06-02 04:37:20	2020-06-02	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	4685	pick-up	0	21
71811	2020-06-02 04:43:22	2020-06-02	9	[{"id_menu":7,"count":1}]	12001	pick-up	0	9
71812	2020-06-02 04:52:55	2020-06-02	8	[{"id_menu":5,"count":1}]	28489	delivery	5	13
71813	2020-06-02 04:55:48	2020-06-02	8	[{"id_menu":5,"count":1}]	14696	delivery	5	13
71814	2020-06-02 05:02:39	2020-06-02	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12314	delivery	5	34
71815	2020-06-02 05:27:27	2020-06-02	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	21489	delivery	5	26
71816	2020-06-02 05:28:06	2020-06-02	17	[{"id_menu":4,"count":1}]	11259	delivery	5	22
71817	2020-06-02 05:29:43	2020-06-02	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16959	pick-up	0	26
71818	2020-06-02 05:30:20	2020-06-02	9	[{"id_menu":6,"count":1}]	28488	delivery	5	14
71819	2020-06-02 05:31:25	2020-06-02	14	[{"id_menu":2,"count":1}]	28480	pick-up	0	14
71820	2020-06-02 05:34:57	2020-06-02	12	[{"id_menu":3,"count":1}]	21975	pick-up	0	12
71821	2020-06-02 05:35:35	2020-06-02	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	28486	pick-up	0	26
71822	2020-06-02 05:35:48	2020-06-02	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25331	delivery	5	39
71823	2020-06-02 05:37:26	2020-06-02	12	[{"id_menu":3,"count":1}]	5707	delivery	5	17
71824	2020-06-02 05:44:14	2020-06-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	982	delivery	5	22
71825	2020-06-02 05:46:58	2020-06-02	12	[{"id_menu":3,"count":1}]	1955	delivery	5	17
71826	2020-06-02 05:47:59	2020-06-02	17	[{"id_menu":4,"count":1}]	17691	pick-up	0	17
71827	2020-06-02 05:48:25	2020-06-02	9	[{"id_menu":6,"count":1}]	13112	pick-up	0	9
71828	2020-06-02 05:59:10	2020-06-02	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	24081	delivery	5	30
71829	2020-06-02 05:59:18	2020-06-02	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	9556	delivery	5	35
71830	2020-06-02 06:02:23	2020-06-02	9	[{"id_menu":7,"count":1}]	20379	pick-up	0	9
71831	2020-06-02 06:05:42	2020-06-02	9	[{"id_menu":7,"count":1}]	6894	delivery	5	14
71832	2020-06-02 06:05:59	2020-06-02	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28471	delivery	5	34
71833	2020-06-02 06:06:05	2020-06-02	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	14378	pick-up	0	29
71834	2020-06-02 06:13:30	2020-06-02	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	28484	delivery	5	26
71835	2020-06-02 06:16:13	2020-06-02	12	[{"id_menu":1,"count":1}]	1471	delivery	5	17
71836	2020-06-02 06:17:01	2020-06-02	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	11554	pick-up	0	31
71837	2020-06-02 06:21:48	2020-06-02	12	[{"id_menu":1,"count":1}]	1044	delivery	5	17
71838	2020-06-02 06:27:38	2020-06-02	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28477	delivery	5	48
71839	2020-06-02 06:27:55	2020-06-02	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12596	delivery	5	31
71840	2020-06-02 06:31:37	2020-06-02	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3642	delivery	5	49
71841	2020-06-02 06:33:27	2020-06-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	26199	delivery	5	28
71842	2020-06-02 06:40:02	2020-06-02	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	28424	pick-up	0	33
71843	2020-06-02 06:40:14	2020-06-02	9	[{"id_menu":6,"count":1}]	28494	delivery	5	14
71844	2020-06-02 06:43:49	2020-06-02	9	[{"id_menu":7,"count":1}]	4054	delivery	5	14
71845	2020-06-02 06:49:42	2020-06-02	8	[{"id_menu":5,"count":1}]	2434	pick-up	0	8
71846	2020-06-02 06:53:33	2020-06-02	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	23077	delivery	5	22
71847	2020-06-02 06:55:22	2020-06-02	9	[{"id_menu":7,"count":1}]	9422	delivery	5	14
71848	2020-06-02 07:03:09	2020-06-02	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	15189	delivery	5	26
71849	2020-06-02 07:06:14	2020-06-02	9	[{"id_menu":6,"count":2}]	1529	pick-up	0	9
71850	2020-06-02 07:07:07	2020-06-02	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14679	pick-up	0	34
71851	2020-06-02 07:14:12	2020-06-02	9	[{"id_menu":7,"count":1}]	28530	delivery	5	14
71852	2020-06-02 07:22:01	2020-06-02	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15018	delivery	5	43
71853	2020-06-02 07:26:06	2020-06-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	28526	delivery	5	31
71854	2020-06-02 07:30:01	2020-06-02	8	[{"id_menu":5,"count":1}]	14533	delivery	5	13
71855	2020-06-02 07:40:36	2020-06-02	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	12969	delivery	5	31
71856	2020-06-02 07:45:08	2020-06-02	9	[{"id_menu":6,"count":1}]	28517	delivery	5	14
71857	2020-06-02 07:52:06	2020-06-02	9	[{"id_menu":6,"count":1}]	28366	delivery	5	14
71858	2020-06-02 07:55:40	2020-06-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	22731	delivery	5	31
71859	2020-06-02 07:57:47	2020-06-02	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	806	pick-up	0	26
71860	2020-06-02 08:00:05	2020-06-02	17	[{"id_menu":4,"count":1}]	28447	delivery	5	22
71861	2020-06-02 08:09:21	2020-06-02	14	[{"id_menu":2,"count":2}]	27836	delivery	5	19
71862	2020-06-02 08:10:59	2020-06-02	17	[{"id_menu":4,"count":1}]	2548	delivery	5	22
71863	2020-06-02 08:17:12	2020-06-02	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	28529	delivery	5	30
71864	2020-06-02 08:24:58	2020-06-02	9	[{"id_menu":6,"count":1}]	28490	delivery	5	14
71865	2020-06-02 08:27:21	2020-06-02	14	[{"id_menu":2,"count":1}]	14501	pick-up	0	14
71866	2020-06-02 08:36:49	2020-06-02	14	[{"id_menu":2,"count":1}]	13465	delivery	5	19
71867	2020-06-02 08:39:16	2020-06-02	8	[{"id_menu":5,"count":1}]	9233	delivery	5	13
71868	2020-06-02 08:42:10	2020-06-02	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	25104	delivery	5	30
71869	2020-06-02 08:44:14	2020-06-02	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	23099	delivery	5	40
71870	2020-06-02 08:47:27	2020-06-02	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9706	pick-up	0	38
71871	2020-06-02 08:56:01	2020-06-02	14	[{"id_menu":2,"count":1}]	15062	delivery	5	19
71872	2020-06-02 09:01:42	2020-06-02	9	[{"id_menu":7,"count":1}]	6745	delivery	5	14
71873	2020-06-02 09:05:44	2020-06-02	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	14573	pick-up	0	37
71874	2020-06-02 09:09:08	2020-06-02	12	[{"id_menu":1,"count":1}]	25982	delivery	5	17
71875	2020-06-02 09:09:13	2020-06-02	12	[{"id_menu":1,"count":2}]	11394	pick-up	0	12
71876	2020-06-02 09:10:07	2020-06-02	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	28425	delivery	5	34
71877	2020-06-02 09:10:46	2020-06-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	27931	delivery	5	23
71878	2020-06-02 09:11:18	2020-06-02	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	9613	delivery	5	27
71879	2020-06-02 09:17:39	2020-06-02	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	19061	delivery	5	26
71880	2020-06-02 09:17:44	2020-06-02	9	[{"id_menu":7,"count":1}]	25418	delivery	5	14
71881	2020-06-02 09:23:00	2020-06-02	14	[{"id_menu":2,"count":1}]	18903	delivery	5	19
71882	2020-06-02 09:25:26	2020-06-02	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	13697	pick-up	0	35
71883	2020-06-02 09:26:22	2020-06-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	28401	pick-up	0	26
71884	2020-06-02 09:27:59	2020-06-02	17	[{"id_menu":4,"count":1}]	4192	delivery	5	22
71885	2020-06-02 09:30:17	2020-06-02	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26359	delivery	5	47
71886	2020-06-02 09:33:26	2020-06-02	8	[{"id_menu":5,"count":1}]	1760	delivery	5	13
71887	2020-06-02 09:39:06	2020-06-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1761	pick-up	0	18
71888	2020-06-02 09:41:05	2020-06-02	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	28496	delivery	5	36
71889	2020-06-02 09:41:17	2020-06-02	23	[{"id_menu":2,"count":3},{"id_menu":6,"count":1}]	351	pick-up	0	23
71890	2020-06-02 09:44:42	2020-06-02	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23130	delivery	5	31
71891	2020-06-02 09:47:23	2020-06-02	12	[{"id_menu":3,"count":1}]	845	pick-up	0	12
71892	2020-06-02 09:48:48	2020-06-02	17	[{"id_menu":4,"count":4}]	28499	delivery	5	22
71893	2020-06-02 09:51:20	2020-06-02	8	[{"id_menu":5,"count":1}]	8622	delivery	5	13
71894	2020-06-02 09:53:04	2020-06-02	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	28378	delivery	5	26
71895	2020-06-02 09:54:50	2020-06-02	14	[{"id_menu":2,"count":1}]	21825	pick-up	0	14
71896	2020-06-02 10:00:51	2020-06-02	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	28466	delivery	5	42
71897	2020-06-02 10:05:44	2020-06-02	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28463	delivery	5	34
71898	2020-06-02 10:09:06	2020-06-02	8	[{"id_menu":5,"count":1}]	5137	delivery	5	13
71899	2020-06-02 10:12:07	2020-06-02	9	[{"id_menu":6,"count":1}]	1834	pick-up	0	9
71900	2020-06-02 10:14:50	2020-06-02	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	28527	delivery	5	43
71901	2020-06-02 10:15:26	2020-06-02	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	28249	delivery	5	25
71902	2020-06-02 10:22:46	2020-06-02	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	25651	delivery	5	57
71903	2020-06-02 10:33:29	2020-06-02	12	[{"id_menu":1,"count":2}]	16019	delivery	5	17
71904	2020-06-02 10:36:40	2020-06-02	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15164	delivery	5	36
71905	2020-06-02 10:38:28	2020-06-02	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":2}]	18222	pick-up	0	23
71906	2020-06-02 10:42:54	2020-06-02	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	28410	pick-up	0	26
71907	2020-06-02 10:43:37	2020-06-02	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20524	delivery	5	40
71908	2020-06-02 10:45:04	2020-06-02	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1170	pick-up	0	29
71909	2020-06-02 10:48:44	2020-06-02	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	25862	delivery	5	45
71910	2020-06-02 10:48:53	2020-06-02	12	[{"id_menu":1,"count":1}]	1239	pick-up	0	12
71911	2020-06-02 11:07:10	2020-06-02	9	[{"id_menu":6,"count":1}]	7021	delivery	5	14
71912	2020-06-02 11:07:43	2020-06-02	8	[{"id_menu":5,"count":1}]	28399	delivery	5	13
71913	2020-06-02 11:10:16	2020-06-02	17	[{"id_menu":4,"count":1}]	28434	delivery	5	22
71914	2020-06-02 11:13:30	2020-06-02	14	[{"id_menu":2,"count":1}]	17604	pick-up	0	14
71915	2020-06-02 11:13:51	2020-06-02	12	[{"id_menu":1,"count":1}]	1931	delivery	5	17
71916	2020-06-02 11:19:51	2020-06-02	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	7716	delivery	5	26
71917	2020-06-02 11:23:14	2020-06-02	9	[{"id_menu":6,"count":2}]	27318	pick-up	0	9
71918	2020-06-02 11:27:26	2020-06-02	12	[{"id_menu":3,"count":1}]	17178	delivery	5	17
71919	2020-06-02 11:29:15	2020-06-02	17	[{"id_menu":4,"count":1}]	28406	pick-up	0	17
71920	2020-06-02 11:34:11	2020-06-02	14	[{"id_menu":2,"count":1}]	19064	pick-up	0	14
71921	2020-06-02 11:39:35	2020-06-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	15302	delivery	5	28
71922	2020-06-02 11:40:15	2020-06-02	12	[{"id_menu":1,"count":1}]	1799	delivery	5	17
71923	2020-06-02 11:42:39	2020-06-02	9	[{"id_menu":7,"count":1}]	14427	pick-up	0	9
71924	2020-06-02 11:43:05	2020-06-02	12	[{"id_menu":3,"count":1}]	10535	delivery	5	17
71925	2020-06-02 11:44:20	2020-06-02	9	[{"id_menu":6,"count":1}]	1813	delivery	5	14
71926	2020-06-02 11:46:27	2020-06-02	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	1317	pick-up	0	33
71927	2020-06-02 11:49:59	2020-06-02	9	[{"id_menu":7,"count":1}]	9934	pick-up	0	9
71928	2020-06-02 11:50:16	2020-06-02	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	28445	delivery	5	40
71929	2020-06-02 11:51:55	2020-06-02	23	[{"id_menu":2,"count":3},{"id_menu":7,"count":1}]	28374	delivery	5	28
71930	2020-06-02 11:52:46	2020-06-02	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	28429	delivery	5	25
71931	2020-06-02 11:56:39	2020-06-02	8	[{"id_menu":5,"count":1}]	28446	pick-up	0	8
71932	2020-06-02 11:57:48	2020-06-02	9	[{"id_menu":6,"count":1}]	25676	delivery	5	14
71933	2020-06-02 12:02:04	2020-06-02	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	7137	delivery	5	40
71934	2020-06-02 12:03:08	2020-06-02	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	26351	delivery	5	22
71935	2020-06-02 12:06:34	2020-06-02	14	[{"id_menu":2,"count":1}]	18139	delivery	5	19
71936	2020-06-02 12:11:41	2020-06-02	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27257	pick-up	0	26
71937	2020-06-02 12:15:00	2020-06-02	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	19717	pick-up	0	21
71938	2020-06-02 12:16:38	2020-06-02	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	28464	delivery	5	23
71939	2020-06-02 12:18:37	2020-06-02	9	[{"id_menu":6,"count":1}]	28460	delivery	5	14
71940	2020-06-02 12:19:09	2020-06-02	9	[{"id_menu":7,"count":1}]	21774	delivery	5	14
71941	2020-06-02 12:20:34	2020-06-02	9	[{"id_menu":7,"count":1}]	28492	delivery	5	14
71942	2020-06-02 12:22:04	2020-06-02	9	[{"id_menu":6,"count":2}]	22963	delivery	5	14
71943	2020-06-02 12:22:21	2020-06-02	12	[{"id_menu":3,"count":1}]	2553	delivery	5	17
71944	2020-06-02 12:23:57	2020-06-02	14	[{"id_menu":2,"count":1}]	3324	pick-up	0	14
71945	2020-06-02 12:25:24	2020-06-02	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	28469	delivery	5	31
71946	2020-06-02 12:27:09	2020-06-02	12	[{"id_menu":3,"count":1}]	17570	delivery	5	17
71947	2020-06-02 12:28:21	2020-06-02	12	[{"id_menu":1,"count":1}]	25731	delivery	5	17
71948	2020-06-02 12:30:19	2020-06-02	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	439	pick-up	0	29
71949	2020-06-02 12:31:40	2020-06-02	12	[{"id_menu":3,"count":1}]	4929	pick-up	0	12
71950	2020-06-02 12:36:06	2020-06-02	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	28435	delivery	5	45
71951	2020-06-02 12:45:52	2020-06-02	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	28514	delivery	5	37
71952	2020-06-02 12:48:41	2020-06-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	28376	delivery	5	22
71953	2020-06-02 12:53:05	2020-06-02	8	[{"id_menu":5,"count":1}]	9798	delivery	5	13
71954	2020-06-02 12:53:32	2020-06-02	14	[{"id_menu":2,"count":1}]	28495	delivery	5	19
71955	2020-06-02 13:01:21	2020-06-02	12	[{"id_menu":1,"count":1}]	22227	pick-up	0	12
71956	2020-06-02 13:02:52	2020-06-02	9	[{"id_menu":6,"count":1}]	28426	delivery	5	14
71957	2020-06-02 13:02:53	2020-06-02	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	28458	delivery	5	45
71958	2020-06-02 13:03:15	2020-06-02	14	[{"id_menu":2,"count":1}]	4804	delivery	5	19
71959	2020-06-02 13:03:22	2020-06-02	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	28403	delivery	5	26
71960	2020-06-02 13:03:32	2020-06-02	9	[{"id_menu":6,"count":1}]	6364	delivery	5	14
71961	2020-06-02 13:05:32	2020-06-02	17	[{"id_menu":4,"count":1}]	28388	pick-up	0	17
71962	2020-06-02 13:08:28	2020-06-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8597	delivery	5	23
71963	2020-06-02 13:13:00	2020-06-02	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	5382	delivery	5	26
71964	2020-06-02 13:13:57	2020-06-02	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	15816	delivery	5	25
71965	2020-06-02 13:14:42	2020-06-02	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	511	pick-up	0	22
71966	2020-06-02 13:26:59	2020-06-02	12	[{"id_menu":1,"count":1}]	28364	pick-up	0	12
71967	2020-06-02 13:30:10	2020-06-02	14	[{"id_menu":2,"count":1}]	28502	delivery	5	19
71968	2020-06-02 13:31:38	2020-06-02	9	[{"id_menu":6,"count":1}]	28382	delivery	5	14
71969	2020-06-02 13:32:33	2020-06-02	8	[{"id_menu":5,"count":1}]	28512	delivery	5	13
71970	2020-06-02 13:42:25	2020-06-02	8	[{"id_menu":5,"count":1}]	23819	delivery	5	13
71971	2020-06-02 13:44:18	2020-06-02	17	[{"id_menu":4,"count":1}]	21308	delivery	5	22
71972	2020-06-02 13:47:30	2020-06-02	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	28380	delivery	5	27
71973	2020-06-02 13:49:44	2020-06-02	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	10627	delivery	5	26
71974	2020-06-02 13:49:55	2020-06-02	8	[{"id_menu":5,"count":1}]	27372	delivery	5	13
71975	2020-06-02 13:53:20	2020-06-02	8	[{"id_menu":5,"count":1}]	28525	delivery	5	13
71976	2020-06-02 13:56:01	2020-06-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	19816	pick-up	0	23
71977	2020-06-02 13:57:45	2020-06-02	9	[{"id_menu":7,"count":1}]	28508	delivery	5	14
71978	2020-06-02 14:14:41	2020-06-02	17	[{"id_menu":4,"count":1}]	19370	delivery	5	22
71979	2020-06-02 14:24:58	2020-06-02	12	[{"id_menu":1,"count":1}]	12600	delivery	5	17
71980	2020-06-02 14:26:50	2020-06-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	581	delivery	5	23
71981	2020-06-02 14:33:01	2020-06-02	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	24129	delivery	5	31
71982	2020-06-02 14:35:04	2020-06-02	14	[{"id_menu":2,"count":1}]	4967	pick-up	0	14
71983	2020-06-02 14:36:49	2020-06-02	12	[{"id_menu":3,"count":1}]	10082	delivery	5	17
71984	2020-06-02 14:38:51	2020-06-02	12	[{"id_menu":1,"count":1}]	1306	pick-up	0	12
71985	2020-06-02 14:39:52	2020-06-02	14	[{"id_menu":2,"count":1}]	2662	pick-up	0	14
71986	2020-06-02 14:51:36	2020-06-02	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	4072	delivery	5	25
71987	2020-06-02 14:56:26	2020-06-02	14	[{"id_menu":2,"count":2}]	24401	delivery	5	19
71988	2020-06-02 14:56:41	2020-06-02	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	17026	delivery	5	22
71989	2020-06-02 14:57:49	2020-06-02	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5041	pick-up	0	29
71990	2020-06-02 14:58:11	2020-06-02	9	[{"id_menu":6,"count":1}]	16747	delivery	5	14
71991	2020-06-02 14:59:21	2020-06-02	9	[{"id_menu":7,"count":1}]	7985	delivery	5	14
71992	2020-06-02 15:03:22	2020-06-02	9	[{"id_menu":7,"count":1}]	13320	delivery	5	14
71993	2020-06-02 15:03:29	2020-06-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	20017	delivery	5	28
71994	2020-06-02 15:07:16	2020-06-02	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	19621	delivery	5	25
71995	2020-06-02 15:11:39	2020-06-02	17	[{"id_menu":4,"count":1}]	18004	delivery	5	22
71996	2020-06-02 15:13:29	2020-06-02	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	27618	delivery	5	43
71997	2020-06-02 15:13:36	2020-06-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	19852	delivery	5	28
71998	2020-06-02 15:15:35	2020-06-02	14	[{"id_menu":2,"count":1}]	23112	delivery	5	19
71999	2020-06-02 15:16:06	2020-06-02	9	[{"id_menu":7,"count":2}]	28420	delivery	5	14
72000	2020-06-02 15:16:36	2020-06-02	9	[{"id_menu":6,"count":1}]	3908	delivery	5	14
72001	2020-06-02 15:25:39	2020-06-02	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	7464	delivery	5	25
72002	2020-06-02 15:26:11	2020-06-02	12	[{"id_menu":1,"count":1}]	1970	delivery	5	17
72003	2020-06-02 15:30:43	2020-06-02	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	28474	delivery	5	26
72004	2020-06-02 15:31:37	2020-06-02	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	28501	pick-up	0	20
72005	2020-06-02 15:39:01	2020-06-02	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	464	pick-up	0	26
72006	2020-06-02 15:43:45	2020-06-02	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	28456	pick-up	0	29
72007	2020-06-02 16:13:18	2020-06-02	9	[{"id_menu":6,"count":1}]	28455	delivery	5	14
72008	2020-06-02 16:19:12	2020-06-02	14	[{"id_menu":2,"count":1}]	12532	delivery	5	19
72009	2020-06-02 16:21:28	2020-06-02	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	10563	delivery	5	25
72010	2020-06-02 16:26:01	2020-06-02	55	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4996	delivery	5	60
72011	2020-06-02 16:29:12	2020-06-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20560	delivery	5	23
72012	2020-06-02 16:30:09	2020-06-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8003	pick-up	0	26
72013	2020-06-02 16:37:48	2020-06-02	9	[{"id_menu":7,"count":1}]	28402	delivery	5	14
72014	2020-06-02 16:45:31	2020-06-02	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28306	delivery	5	35
72015	2020-06-02 16:46:12	2020-06-02	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14418	delivery	5	53
72016	2020-06-02 16:52:22	2020-06-02	12	[{"id_menu":1,"count":1}]	22822	delivery	5	17
72017	2020-06-02 16:52:52	2020-06-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10022	delivery	5	23
72018	2020-06-02 16:55:15	2020-06-02	8	[{"id_menu":5,"count":1}]	28413	delivery	5	13
72019	2020-06-02 17:03:26	2020-06-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6958	delivery	5	28
72020	2020-06-02 17:04:18	2020-06-02	14	[{"id_menu":2,"count":1}]	12675	pick-up	0	14
72021	2020-06-02 17:10:25	2020-06-02	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8866	delivery	5	40
72022	2020-06-02 17:17:00	2020-06-02	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28355	delivery	5	35
72023	2020-06-02 17:19:58	2020-06-02	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	3106	delivery	5	26
72024	2020-06-02 17:24:38	2020-06-02	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28498	delivery	5	31
72025	2020-06-02 17:34:07	2020-06-02	9	[{"id_menu":7,"count":1}]	28365	delivery	5	14
72026	2020-06-02 17:34:48	2020-06-02	9	[{"id_menu":6,"count":1}]	14219	delivery	5	14
72027	2020-06-02 17:37:10	2020-06-02	12	[{"id_menu":3,"count":1}]	28362	delivery	5	17
72028	2020-06-02 17:39:32	2020-06-02	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	28507	delivery	5	39
72029	2020-06-02 17:42:03	2020-06-02	12	[{"id_menu":1,"count":1}]	11816	delivery	5	17
72030	2020-06-02 17:43:59	2020-06-02	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	28361	delivery	5	34
72031	2020-06-02 17:54:45	2020-06-02	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	28418	delivery	5	43
72032	2020-06-02 17:58:16	2020-06-02	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	24766	delivery	5	34
72033	2020-06-02 18:00:03	2020-06-02	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	16876	delivery	5	22
72034	2020-06-02 18:03:07	2020-06-02	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13689	delivery	5	40
72035	2020-06-02 18:07:13	2020-06-02	12	[{"id_menu":3,"count":1}]	28506	delivery	5	17
72036	2020-06-02 18:07:48	2020-06-02	12	[{"id_menu":1,"count":1}]	28367	pick-up	0	12
72037	2020-06-02 18:10:17	2020-06-02	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	19202	delivery	5	31
72038	2020-06-02 18:11:03	2020-06-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	25444	delivery	5	28
72039	2020-06-02 18:11:38	2020-06-02	14	[{"id_menu":2,"count":2}]	28389	delivery	5	19
72040	2020-06-02 18:13:23	2020-06-02	9	[{"id_menu":7,"count":1}]	19139	delivery	5	14
72041	2020-06-02 18:14:41	2020-06-02	12	[{"id_menu":1,"count":2}]	23696	delivery	5	17
72042	2020-06-02 18:15:06	2020-06-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11896	pick-up	0	17
72043	2020-06-02 18:16:07	2020-06-02	8	[{"id_menu":5,"count":1}]	22221	delivery	5	13
72044	2020-06-02 18:21:26	2020-06-02	12	[{"id_menu":1,"count":1}]	7156	pick-up	0	12
72045	2020-06-02 18:22:04	2020-06-02	9	[{"id_menu":6,"count":1}]	28497	delivery	5	14
72046	2020-06-02 18:30:46	2020-06-02	9	[{"id_menu":7,"count":1}]	7353	delivery	5	14
72047	2020-06-02 18:37:25	2020-06-02	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	8490	delivery	5	31
72048	2020-06-02 18:41:15	2020-06-02	12	[{"id_menu":1,"count":1}]	17780	delivery	5	17
72049	2020-06-02 18:41:59	2020-06-02	9	[{"id_menu":7,"count":1}]	28472	delivery	5	14
72050	2020-06-02 18:44:39	2020-06-02	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	28377	pick-up	0	29
72051	2020-06-02 18:50:07	2020-06-02	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	28493	delivery	5	25
72052	2020-06-02 18:55:59	2020-06-02	8	[{"id_menu":5,"count":1}]	15129	pick-up	0	8
72053	2020-06-02 18:59:24	2020-06-02	17	[{"id_menu":4,"count":1}]	4193	pick-up	0	17
72054	2020-06-02 19:00:17	2020-06-02	9	[{"id_menu":6,"count":1}]	28461	delivery	5	14
72055	2020-06-02 19:00:35	2020-06-02	12	[{"id_menu":1,"count":1}]	18356	delivery	5	17
72056	2020-06-02 19:01:19	2020-06-02	8	[{"id_menu":5,"count":1}]	2932	pick-up	0	8
72057	2020-06-02 19:04:52	2020-06-02	12	[{"id_menu":1,"count":1}]	28462	delivery	5	17
72058	2020-06-02 19:05:28	2020-06-02	17	[{"id_menu":4,"count":3}]	3007	pick-up	0	17
72059	2020-06-02 19:05:55	2020-06-02	12	[{"id_menu":3,"count":1}]	24842	delivery	5	17
72060	2020-06-02 19:07:32	2020-06-02	8	[{"id_menu":5,"count":1}]	11324	pick-up	0	8
72061	2020-06-02 19:09:28	2020-06-02	12	[{"id_menu":1,"count":1}]	26408	pick-up	0	12
72062	2020-06-02 19:10:47	2020-06-02	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	8583	delivery	5	26
72063	2020-06-02 19:12:27	2020-06-02	14	[{"id_menu":2,"count":1}]	19318	pick-up	0	14
72064	2020-06-02 19:15:58	2020-06-02	14	[{"id_menu":2,"count":1}]	7938	delivery	5	19
72065	2020-06-02 19:27:58	2020-06-02	12	[{"id_menu":3,"count":1}]	13767	delivery	5	17
72066	2020-06-02 19:35:16	2020-06-02	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	28450	delivery	5	35
72067	2020-06-02 19:43:05	2020-06-02	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	28465	delivery	5	28
72068	2020-06-02 19:43:52	2020-06-02	9	[{"id_menu":6,"count":1}]	21978	pick-up	0	9
72069	2020-06-02 19:44:41	2020-06-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	28283	pick-up	0	26
72070	2020-06-02 19:46:52	2020-06-02	8	[{"id_menu":5,"count":1}]	3730	pick-up	0	8
72071	2020-06-02 19:52:42	2020-06-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23154	delivery	5	23
72072	2020-06-02 19:59:40	2020-06-02	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7979	delivery	5	34
72073	2020-06-02 20:01:52	2020-06-02	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	7258	delivery	5	38
72074	2020-06-02 20:04:55	2020-06-02	14	[{"id_menu":2,"count":1}]	1736	pick-up	0	14
72075	2020-06-02 20:07:24	2020-06-02	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	28422	delivery	5	27
72076	2020-06-02 20:13:19	2020-06-02	17	[{"id_menu":4,"count":1}]	18810	pick-up	0	17
72077	2020-06-02 20:20:09	2020-06-02	9	[{"id_menu":6,"count":1}]	28439	delivery	5	14
72078	2020-06-02 20:22:37	2020-06-02	8	[{"id_menu":5,"count":1}]	25892	delivery	5	13
72079	2020-06-02 20:28:00	2020-06-02	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3624	delivery	5	27
72080	2020-06-02 20:28:03	2020-06-02	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	28351	delivery	5	31
72081	2020-06-02 20:35:08	2020-06-02	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4894	delivery	5	34
72082	2020-06-02 20:40:20	2020-06-02	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	11678	delivery	5	29
72083	2020-06-02 20:49:10	2020-06-02	9	[{"id_menu":7,"count":1}]	19798	delivery	5	14
72084	2020-06-02 20:49:25	2020-06-02	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	6650	pick-up	0	26
72085	2020-06-02 20:58:22	2020-06-02	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	4835	delivery	5	26
72086	2020-06-02 20:58:40	2020-06-02	17	[{"id_menu":4,"count":1}]	26957	delivery	5	22
72087	2020-06-02 21:01:22	2020-06-02	14	[{"id_menu":2,"count":1}]	28444	delivery	5	19
72088	2020-06-02 21:02:11	2020-06-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26921	delivery	5	23
72155	2020-06-03 00:23:13	2020-06-03	12	[{"id_menu":1,"count":1}]	18813	delivery	5	17
72089	2020-06-02 21:03:38	2020-06-02	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	28510	delivery	5	36
72090	2020-06-02 21:03:41	2020-06-02	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	20805	pick-up	0	21
72091	2020-06-02 21:05:02	2020-06-02	12	[{"id_menu":1,"count":1}]	28504	delivery	5	17
72092	2020-06-02 21:06:39	2020-06-02	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	28522	pick-up	0	29
72093	2020-06-02 21:11:02	2020-06-02	8	[{"id_menu":5,"count":1}]	28509	delivery	5	13
72094	2020-06-02 21:14:15	2020-06-02	12	[{"id_menu":3,"count":1}]	19042	pick-up	0	12
72095	2020-06-02 21:19:05	2020-06-02	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28415	delivery	5	35
72096	2020-06-02 21:19:26	2020-06-02	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":2}]	28375	delivery	5	31
72097	2020-06-02 21:20:53	2020-06-02	14	[{"id_menu":2,"count":1}]	28130	delivery	5	19
72098	2020-06-02 21:21:25	2020-06-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16834	delivery	5	23
72099	2020-06-02 21:23:25	2020-06-02	9	[{"id_menu":6,"count":1}]	482	delivery	5	14
72100	2020-06-02 21:34:13	2020-06-02	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	9001	delivery	5	31
72101	2020-06-02 21:34:30	2020-06-02	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	28400	delivery	5	34
72102	2020-06-02 21:39:02	2020-06-02	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	16621	delivery	5	39
72103	2020-06-02 21:41:21	2020-06-02	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	20712	delivery	5	27
72104	2020-06-02 21:42:56	2020-06-02	14	[{"id_menu":2,"count":1}]	9562	pick-up	0	14
72105	2020-06-02 21:44:59	2020-06-02	9	[{"id_menu":6,"count":1}]	13275	delivery	5	14
72106	2020-06-02 21:47:21	2020-06-02	8	[{"id_menu":5,"count":1}]	3570	pick-up	0	8
72107	2020-06-02 21:50:03	2020-06-02	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	28482	delivery	5	30
72108	2020-06-02 21:57:46	2020-06-02	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7918	pick-up	0	31
72109	2020-06-02 21:58:01	2020-06-02	12	[{"id_menu":1,"count":1}]	19598	pick-up	0	12
72110	2020-06-02 21:58:56	2020-06-02	9	[{"id_menu":7,"count":1}]	28386	delivery	5	14
72111	2020-06-02 22:00:38	2020-06-02	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	3765	pick-up	0	24
72112	2020-06-02 22:04:04	2020-06-02	12	[{"id_menu":1,"count":1}]	28443	pick-up	0	12
72113	2020-06-02 22:04:17	2020-06-02	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	28442	pick-up	0	26
72114	2020-06-02 22:10:07	2020-06-02	17	[{"id_menu":4,"count":1}]	16869	delivery	5	22
72115	2020-06-02 22:10:19	2020-06-02	9	[{"id_menu":6,"count":1}]	28457	delivery	5	14
72116	2020-06-02 22:12:19	2020-06-02	9	[{"id_menu":6,"count":1}]	5293	pick-up	0	9
72117	2020-06-02 22:13:28	2020-06-02	9	[{"id_menu":6,"count":2}]	8155	delivery	5	14
72118	2020-06-02 22:18:35	2020-06-02	9	[{"id_menu":6,"count":1}]	28394	delivery	5	14
72119	2020-06-02 22:19:31	2020-06-02	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	28432	delivery	5	39
72120	2020-06-02 22:22:15	2020-06-02	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	26954	delivery	5	27
72121	2020-06-02 22:22:21	2020-06-02	12	[{"id_menu":3,"count":1}]	12590	delivery	5	17
72122	2020-06-02 22:27:20	2020-06-02	12	[{"id_menu":1,"count":1}]	3640	pick-up	0	12
72123	2020-06-02 22:30:35	2020-06-02	14	[{"id_menu":2,"count":1}]	3159	delivery	5	19
72124	2020-06-02 22:31:53	2020-06-02	12	[{"id_menu":3,"count":1}]	12118	pick-up	0	12
72125	2020-06-02 22:32:31	2020-06-02	9	[{"id_menu":6,"count":2}]	28483	delivery	5	14
72126	2020-06-02 22:33:29	2020-06-02	9	[{"id_menu":7,"count":1}]	11754	delivery	5	14
72127	2020-06-02 22:51:11	2020-06-02	14	[{"id_menu":2,"count":1}]	21265	delivery	5	19
72128	2020-06-02 22:51:56	2020-06-02	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	1914	pick-up	0	17
72129	2020-06-02 22:52:08	2020-06-02	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11715	delivery	5	31
72130	2020-06-02 22:55:11	2020-06-02	17	[{"id_menu":4,"count":1}]	21155	pick-up	0	17
72131	2020-06-02 22:56:49	2020-06-02	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1208	pick-up	0	22
72132	2020-06-02 22:57:05	2020-06-02	12	[{"id_menu":1,"count":1}]	24041	pick-up	0	12
72133	2020-06-02 22:57:15	2020-06-02	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28372	delivery	5	45
72134	2020-06-02 23:05:22	2020-06-02	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	28520	delivery	5	57
72135	2020-06-02 23:11:32	2020-06-02	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3568	delivery	5	34
72136	2020-06-02 23:21:54	2020-06-02	12	[{"id_menu":3,"count":1}]	11014	delivery	5	17
72137	2020-06-02 23:33:16	2020-06-02	17	[{"id_menu":4,"count":1}]	28371	delivery	5	22
72138	2020-06-02 23:33:30	2020-06-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28468	delivery	5	22
72139	2020-06-02 23:35:08	2020-06-02	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1420	delivery	5	27
72140	2020-06-02 23:36:26	2020-06-02	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	28478	delivery	5	30
72141	2020-06-02 23:39:49	2020-06-02	9	[{"id_menu":7,"count":1}]	18707	delivery	5	14
72142	2020-06-02 23:45:51	2020-06-02	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	22320	delivery	5	31
72143	2020-06-02 23:53:48	2020-06-02	14	[{"id_menu":2,"count":1}]	8561	pick-up	0	14
72144	2020-06-03 00:00:02	2020-06-03	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14682	delivery	5	31
72145	2020-06-03 00:00:25	2020-06-03	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28597	delivery	5	54
72146	2020-06-03 00:00:58	2020-06-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7280	delivery	5	31
72147	2020-06-03 00:02:33	2020-06-03	12	[{"id_menu":3,"count":1}]	3899	pick-up	0	12
72148	2020-06-03 00:03:15	2020-06-03	17	[{"id_menu":4,"count":1}]	4522	delivery	5	22
72149	2020-06-03 00:03:56	2020-06-03	9	[{"id_menu":6,"count":1}]	1229	delivery	5	14
72150	2020-06-03 00:08:39	2020-06-03	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	28678	delivery	5	31
72151	2020-06-03 00:09:33	2020-06-03	9	[{"id_menu":6,"count":1}]	3480	delivery	5	14
72152	2020-06-03 00:12:29	2020-06-03	9	[{"id_menu":7,"count":1}]	28631	delivery	5	14
72153	2020-06-03 00:18:00	2020-06-03	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	22605	pick-up	0	23
72154	2020-06-03 00:19:56	2020-06-03	9	[{"id_menu":7,"count":1}]	19300	pick-up	0	9
72156	2020-06-03 00:24:11	2020-06-03	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1432	pick-up	0	21
72157	2020-06-03 00:27:51	2020-06-03	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	5752	delivery	5	46
72158	2020-06-03 00:28:23	2020-06-03	9	[{"id_menu":7,"count":1}]	15487	pick-up	0	9
72159	2020-06-03 00:28:59	2020-06-03	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	28621	delivery	5	40
72160	2020-06-03 00:30:42	2020-06-03	9	[{"id_menu":6,"count":1}]	9011	delivery	5	14
72161	2020-06-03 00:31:01	2020-06-03	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	28721	delivery	5	23
72162	2020-06-03 00:34:06	2020-06-03	9	[{"id_menu":6,"count":1}]	10685	delivery	5	14
72163	2020-06-03 00:34:23	2020-06-03	9	[{"id_menu":7,"count":1}]	5110	delivery	5	14
72164	2020-06-03 00:34:55	2020-06-03	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8057	delivery	5	36
72165	2020-06-03 00:35:40	2020-06-03	14	[{"id_menu":2,"count":1}]	28700	delivery	5	19
72166	2020-06-03 00:45:39	2020-06-03	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28642	delivery	5	22
72167	2020-06-03 00:47:27	2020-06-03	9	[{"id_menu":6,"count":2}]	5880	delivery	5	14
72168	2020-06-03 00:50:30	2020-06-03	14	[{"id_menu":2,"count":1}]	519	pick-up	0	14
72169	2020-06-03 00:52:36	2020-06-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	28724	delivery	5	28
72170	2020-06-03 00:53:56	2020-06-03	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17851	delivery	5	22
72171	2020-06-03 00:57:57	2020-06-03	17	[{"id_menu":4,"count":1}]	2434	pick-up	0	17
72172	2020-06-03 01:01:22	2020-06-03	12	[{"id_menu":3,"count":1}]	18984	delivery	5	17
72173	2020-06-03 01:04:46	2020-06-03	12	[{"id_menu":3,"count":1}]	28662	delivery	5	17
72174	2020-06-03 01:06:04	2020-06-03	9	[{"id_menu":6,"count":1}]	20670	pick-up	0	9
72175	2020-06-03 01:14:10	2020-06-03	9	[{"id_menu":6,"count":1}]	7418	delivery	5	14
72176	2020-06-03 01:14:29	2020-06-03	8	[{"id_menu":5,"count":1}]	28712	delivery	5	13
72177	2020-06-03 01:16:21	2020-06-03	9	[{"id_menu":7,"count":1}]	28590	delivery	5	14
72178	2020-06-03 01:17:48	2020-06-03	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	2148	delivery	5	39
72179	2020-06-03 01:19:15	2020-06-03	9	[{"id_menu":6,"count":1}]	4584	delivery	5	14
72180	2020-06-03 01:20:29	2020-06-03	9	[{"id_menu":7,"count":1}]	28681	delivery	5	14
72181	2020-06-03 01:23:35	2020-06-03	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3705	delivery	5	37
72182	2020-06-03 01:25:33	2020-06-03	9	[{"id_menu":7,"count":1}]	18770	pick-up	0	9
72183	2020-06-03 01:29:27	2020-06-03	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28619	delivery	5	36
72184	2020-06-03 01:31:50	2020-06-03	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18003	delivery	5	23
72185	2020-06-03 01:40:46	2020-06-03	12	[{"id_menu":1,"count":1}]	24367	delivery	5	17
72186	2020-06-03 01:46:16	2020-06-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	28541	delivery	5	28
72187	2020-06-03 01:48:26	2020-06-03	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	27443	delivery	5	40
72188	2020-06-03 01:59:49	2020-06-03	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	26409	delivery	5	26
72189	2020-06-03 02:00:46	2020-06-03	8	[{"id_menu":5,"count":1}]	28056	delivery	5	13
72190	2020-06-03 02:02:43	2020-06-03	17	[{"id_menu":4,"count":1}]	4997	pick-up	0	17
72191	2020-06-03 02:04:27	2020-06-03	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	28557	delivery	5	28
72192	2020-06-03 02:08:10	2020-06-03	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	14290	pick-up	0	34
72193	2020-06-03 02:12:02	2020-06-03	17	[{"id_menu":4,"count":1}]	28553	delivery	5	22
72194	2020-06-03 02:12:54	2020-06-03	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1280	delivery	5	31
72195	2020-06-03 02:14:29	2020-06-03	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	11766	delivery	5	26
72196	2020-06-03 02:15:56	2020-06-03	17	[{"id_menu":4,"count":1}]	9268	delivery	5	22
72197	2020-06-03 02:28:05	2020-06-03	12	[{"id_menu":1,"count":1}]	28587	delivery	5	17
72198	2020-06-03 02:28:39	2020-06-03	9	[{"id_menu":7,"count":1}]	13797	delivery	5	14
72199	2020-06-03 02:38:27	2020-06-03	9	[{"id_menu":7,"count":1}]	28709	delivery	5	14
72200	2020-06-03 02:40:10	2020-06-03	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	28575	delivery	5	23
72201	2020-06-03 02:40:41	2020-06-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9014	delivery	5	31
72202	2020-06-03 02:40:47	2020-06-03	14	[{"id_menu":2,"count":1}]	19537	pick-up	0	14
72203	2020-06-03 02:41:55	2020-06-03	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	15852	delivery	5	34
72204	2020-06-03 02:42:48	2020-06-03	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8546	pick-up	0	23
72205	2020-06-03 02:43:07	2020-06-03	8	[{"id_menu":5,"count":1}]	28689	delivery	5	13
72206	2020-06-03 02:45:33	2020-06-03	9	[{"id_menu":6,"count":1}]	7138	delivery	5	14
72207	2020-06-03 02:46:29	2020-06-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	27517	delivery	5	31
72208	2020-06-03 02:47:04	2020-06-03	9	[{"id_menu":6,"count":1}]	26407	delivery	5	14
72209	2020-06-03 02:49:00	2020-06-03	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26371	delivery	5	23
72210	2020-06-03 02:55:00	2020-06-03	12	[{"id_menu":1,"count":1}]	14626	delivery	5	17
72211	2020-06-03 02:58:37	2020-06-03	9	[{"id_menu":6,"count":1}]	28716	delivery	5	14
72212	2020-06-03 02:58:48	2020-06-03	8	[{"id_menu":5,"count":1}]	28717	delivery	5	13
72213	2020-06-03 03:02:45	2020-06-03	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19201	delivery	5	23
72214	2020-06-03 03:16:57	2020-06-03	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28685	delivery	5	22
72215	2020-06-03 03:17:34	2020-06-03	14	[{"id_menu":2,"count":1}]	7504	pick-up	0	14
72216	2020-06-03 03:18:10	2020-06-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7333	pick-up	0	23
72217	2020-06-03 03:21:01	2020-06-03	17	[{"id_menu":4,"count":1}]	28533	delivery	5	22
72218	2020-06-03 03:27:11	2020-06-03	43	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	24547	pick-up	0	43
72219	2020-06-03 03:30:21	2020-06-03	9	[{"id_menu":6,"count":1}]	20363	delivery	5	14
72220	2020-06-03 03:32:56	2020-06-03	9	[{"id_menu":7,"count":1}]	324	pick-up	0	9
72221	2020-06-03 03:36:51	2020-06-03	8	[{"id_menu":5,"count":1}]	28582	delivery	5	13
72222	2020-06-03 03:37:59	2020-06-03	17	[{"id_menu":4,"count":1}]	19143	delivery	5	22
72223	2020-06-03 03:38:49	2020-06-03	12	[{"id_menu":1,"count":1}]	19183	delivery	5	17
72224	2020-06-03 03:39:47	2020-06-03	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	11603	delivery	5	35
72225	2020-06-03 03:40:13	2020-06-03	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	17948	delivery	5	31
72226	2020-06-03 03:50:32	2020-06-03	9	[{"id_menu":7,"count":1}]	28632	delivery	5	14
72227	2020-06-03 03:52:01	2020-06-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17056	delivery	5	31
72228	2020-06-03 03:53:05	2020-06-03	9	[{"id_menu":7,"count":1}]	18409	pick-up	0	9
72229	2020-06-03 03:54:47	2020-06-03	9	[{"id_menu":6,"count":1}]	28622	delivery	5	14
72230	2020-06-03 03:55:40	2020-06-03	9	[{"id_menu":6,"count":1}]	28539	delivery	5	14
72231	2020-06-03 04:00:21	2020-06-03	14	[{"id_menu":2,"count":1}]	12828	pick-up	0	14
72232	2020-06-03 04:01:32	2020-06-03	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28583	delivery	5	31
72233	2020-06-03 04:05:52	2020-06-03	14	[{"id_menu":2,"count":2}]	5897	delivery	5	19
72234	2020-06-03 04:06:28	2020-06-03	9	[{"id_menu":7,"count":1}]	13394	delivery	5	14
72235	2020-06-03 04:06:42	2020-06-03	9	[{"id_menu":7,"count":1}]	28672	delivery	5	14
72236	2020-06-03 04:12:33	2020-06-03	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	10500	delivery	5	38
72237	2020-06-03 04:17:00	2020-06-03	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28710	delivery	5	35
72238	2020-06-03 04:18:01	2020-06-03	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1322	pick-up	0	26
72239	2020-06-03 04:19:33	2020-06-03	9	[{"id_menu":6,"count":1}]	18222	delivery	5	14
72240	2020-06-03 04:21:28	2020-06-03	9	[{"id_menu":6,"count":1}]	28562	delivery	5	14
72241	2020-06-03 04:25:01	2020-06-03	14	[{"id_menu":2,"count":1}]	17015	pick-up	0	14
72242	2020-06-03 04:28:35	2020-06-03	14	[{"id_menu":2,"count":1}]	11093	delivery	5	19
72243	2020-06-03 04:28:44	2020-06-03	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	25580	pick-up	0	20
72244	2020-06-03 04:29:25	2020-06-03	14	[{"id_menu":2,"count":1}]	28645	delivery	5	19
72245	2020-06-03 04:33:03	2020-06-03	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	5898	delivery	5	31
72246	2020-06-03 04:33:37	2020-06-03	12	[{"id_menu":3,"count":1}]	14404	pick-up	0	12
72247	2020-06-03 04:38:27	2020-06-03	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	26642	delivery	5	31
72248	2020-06-03 04:44:17	2020-06-03	17	[{"id_menu":4,"count":1}]	16549	pick-up	0	17
72249	2020-06-03 04:49:25	2020-06-03	14	[{"id_menu":2,"count":1}]	28701	pick-up	0	14
72250	2020-06-03 04:58:32	2020-06-03	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	6233	delivery	5	31
72251	2020-06-03 05:03:01	2020-06-03	9	[{"id_menu":7,"count":1}]	28535	delivery	5	14
72252	2020-06-03 05:04:41	2020-06-03	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	28629	pick-up	0	21
72253	2020-06-03 05:05:08	2020-06-03	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	16336	delivery	5	22
72254	2020-06-03 05:06:48	2020-06-03	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7130	delivery	5	34
72255	2020-06-03 05:09:57	2020-06-03	9	[{"id_menu":6,"count":1}]	26628	pick-up	0	9
72256	2020-06-03 05:11:55	2020-06-03	12	[{"id_menu":1,"count":1}]	28556	delivery	5	17
72257	2020-06-03 05:12:29	2020-06-03	8	[{"id_menu":5,"count":1}]	28702	delivery	5	13
72258	2020-06-03 05:12:56	2020-06-03	9	[{"id_menu":7,"count":1}]	4206	pick-up	0	9
72259	2020-06-03 05:19:42	2020-06-03	8	[{"id_menu":5,"count":1}]	623	pick-up	0	8
72260	2020-06-03 05:19:51	2020-06-03	8	[{"id_menu":5,"count":1}]	15152	delivery	5	13
72261	2020-06-03 05:28:12	2020-06-03	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	28571	delivery	5	31
72262	2020-06-03 05:29:28	2020-06-03	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	17398	delivery	5	48
72263	2020-06-03 05:30:53	2020-06-03	8	[{"id_menu":5,"count":1}]	11911	delivery	5	13
72264	2020-06-03 05:32:36	2020-06-03	9	[{"id_menu":6,"count":1}]	28605	pick-up	0	9
72265	2020-06-03 05:33:01	2020-06-03	8	[{"id_menu":5,"count":1}]	9495	delivery	5	13
72266	2020-06-03 05:44:49	2020-06-03	8	[{"id_menu":5,"count":1}]	28532	pick-up	0	8
72267	2020-06-03 05:49:42	2020-06-03	9	[{"id_menu":6,"count":1}]	348	pick-up	0	9
72268	2020-06-03 05:52:49	2020-06-03	14	[{"id_menu":2,"count":1}]	15250	delivery	5	19
72269	2020-06-03 05:54:24	2020-06-03	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28706	delivery	5	40
72270	2020-06-03 05:55:01	2020-06-03	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	23126	delivery	5	34
72271	2020-06-03 05:59:57	2020-06-03	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28663	delivery	5	35
72272	2020-06-03 06:01:58	2020-06-03	8	[{"id_menu":5,"count":1}]	26208	pick-up	0	8
72273	2020-06-03 06:03:50	2020-06-03	12	[{"id_menu":1,"count":1}]	28693	delivery	5	17
72274	2020-06-03 06:04:56	2020-06-03	9	[{"id_menu":7,"count":1}]	11408	delivery	5	14
72275	2020-06-03 06:07:21	2020-06-03	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	28677	delivery	5	40
72276	2020-06-03 06:11:30	2020-06-03	9	[{"id_menu":7,"count":1}]	28730	delivery	5	14
72277	2020-06-03 06:15:31	2020-06-03	9	[{"id_menu":6,"count":1}]	28686	delivery	5	14
72278	2020-06-03 06:16:25	2020-06-03	9	[{"id_menu":6,"count":1}]	28569	delivery	5	14
72279	2020-06-03 06:18:57	2020-06-03	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	21794	delivery	5	36
72280	2020-06-03 06:19:12	2020-06-03	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	7591	pick-up	0	26
72281	2020-06-03 06:20:20	2020-06-03	9	[{"id_menu":6,"count":1}]	21655	delivery	5	14
72282	2020-06-03 06:23:08	2020-06-03	17	[{"id_menu":4,"count":1}]	28729	delivery	5	22
72283	2020-06-03 06:24:04	2020-06-03	8	[{"id_menu":5,"count":1}]	11297	delivery	5	13
72284	2020-06-03 06:26:59	2020-06-03	9	[{"id_menu":6,"count":1}]	16956	delivery	5	14
72285	2020-06-03 06:33:34	2020-06-03	12	[{"id_menu":1,"count":1}]	17501	delivery	5	17
72286	2020-06-03 06:34:04	2020-06-03	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	18983	delivery	5	42
72287	2020-06-03 06:35:48	2020-06-03	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	126	pick-up	0	21
72288	2020-06-03 06:36:17	2020-06-03	9	[{"id_menu":6,"count":1}]	28568	delivery	5	14
72289	2020-06-03 06:36:32	2020-06-03	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	17085	delivery	5	40
72290	2020-06-03 06:40:13	2020-06-03	17	[{"id_menu":4,"count":1}]	3652	pick-up	0	17
72291	2020-06-03 06:41:02	2020-06-03	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	28594	delivery	5	27
72292	2020-06-03 06:41:36	2020-06-03	14	[{"id_menu":2,"count":1}]	28574	delivery	5	19
72293	2020-06-03 06:45:33	2020-06-03	9	[{"id_menu":7,"count":1}]	1754	pick-up	0	9
72294	2020-06-03 06:45:38	2020-06-03	9	[{"id_menu":6,"count":1}]	28601	delivery	5	14
72295	2020-06-03 06:46:08	2020-06-03	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	28628	pick-up	0	24
72296	2020-06-03 06:50:10	2020-06-03	14	[{"id_menu":2,"count":1}]	25141	pick-up	0	14
72297	2020-06-03 06:52:33	2020-06-03	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	28650	delivery	5	30
72298	2020-06-03 06:54:31	2020-06-03	9	[{"id_menu":6,"count":1}]	233	pick-up	0	9
72299	2020-06-03 06:57:32	2020-06-03	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	3297	delivery	5	26
72300	2020-06-03 06:58:35	2020-06-03	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	28565	delivery	5	40
72301	2020-06-03 07:00:18	2020-06-03	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28589	delivery	5	34
72302	2020-06-03 07:15:59	2020-06-03	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27790	delivery	5	34
72303	2020-06-03 07:21:29	2020-06-03	9	[{"id_menu":7,"count":1}]	9923	delivery	5	14
72304	2020-06-03 07:21:35	2020-06-03	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28666	delivery	5	48
72305	2020-06-03 07:22:47	2020-06-03	9	[{"id_menu":6,"count":1}]	28607	delivery	5	14
72306	2020-06-03 07:22:55	2020-06-03	17	[{"id_menu":4,"count":1}]	24917	delivery	5	22
72307	2020-06-03 07:23:14	2020-06-03	8	[{"id_menu":5,"count":1}]	12298	delivery	5	13
72308	2020-06-03 07:24:00	2020-06-03	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21537	delivery	5	22
72309	2020-06-03 07:24:16	2020-06-03	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	28707	delivery	5	25
72310	2020-06-03 07:33:28	2020-06-03	14	[{"id_menu":2,"count":1}]	28559	delivery	5	19
72311	2020-06-03 07:36:50	2020-06-03	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6027	delivery	5	54
72312	2020-06-03 07:39:40	2020-06-03	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26603	pick-up	0	42
72313	2020-06-03 07:41:50	2020-06-03	12	[{"id_menu":3,"count":1}]	28652	delivery	5	17
72314	2020-06-03 07:43:23	2020-06-03	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	347	delivery	5	28
72315	2020-06-03 07:43:36	2020-06-03	9	[{"id_menu":6,"count":1}]	3916	pick-up	0	9
72316	2020-06-03 07:48:19	2020-06-03	12	[{"id_menu":1,"count":1}]	26075	delivery	5	17
72317	2020-06-03 07:49:24	2020-06-03	8	[{"id_menu":5,"count":1}]	17304	delivery	5	13
72318	2020-06-03 07:50:28	2020-06-03	14	[{"id_menu":2,"count":1}]	14559	delivery	5	19
72319	2020-06-03 07:53:50	2020-06-03	9	[{"id_menu":7,"count":1}]	12057	delivery	5	14
72320	2020-06-03 07:54:58	2020-06-03	8	[{"id_menu":5,"count":1}]	12685	delivery	5	13
72321	2020-06-03 07:56:04	2020-06-03	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	11700	delivery	5	40
72322	2020-06-03 07:56:11	2020-06-03	9	[{"id_menu":6,"count":1}]	16080	delivery	5	14
72323	2020-06-03 08:00:25	2020-06-03	14	[{"id_menu":2,"count":1}]	11534	pick-up	0	14
72324	2020-06-03 08:00:26	2020-06-03	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	1591	pick-up	0	21
72325	2020-06-03 08:04:09	2020-06-03	9	[{"id_menu":7,"count":1}]	28718	delivery	5	14
72326	2020-06-03 08:04:47	2020-06-03	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2191	pick-up	0	35
72327	2020-06-03 08:06:37	2020-06-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	28643	delivery	5	31
72328	2020-06-03 08:10:25	2020-06-03	8	[{"id_menu":5,"count":1}]	18133	delivery	5	13
72329	2020-06-03 08:13:13	2020-06-03	9	[{"id_menu":6,"count":1}]	27202	delivery	5	14
72330	2020-06-03 08:16:07	2020-06-03	12	[{"id_menu":1,"count":1}]	27378	delivery	5	17
72331	2020-06-03 08:18:22	2020-06-03	8	[{"id_menu":5,"count":1}]	2265	pick-up	0	8
72332	2020-06-03 08:18:50	2020-06-03	9	[{"id_menu":7,"count":1}]	12040	delivery	5	14
72333	2020-06-03 08:21:44	2020-06-03	17	[{"id_menu":4,"count":1}]	28595	delivery	5	22
72334	2020-06-03 08:22:25	2020-06-03	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	23705	delivery	5	27
72335	2020-06-03 08:23:45	2020-06-03	8	[{"id_menu":5,"count":1}]	1810	pick-up	0	8
72336	2020-06-03 08:29:25	2020-06-03	9	[{"id_menu":7,"count":1}]	4018	delivery	5	14
72337	2020-06-03 08:29:31	2020-06-03	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10931	delivery	5	31
72338	2020-06-03 08:36:35	2020-06-03	14	[{"id_menu":2,"count":1}]	28698	delivery	5	19
72339	2020-06-03 08:39:29	2020-06-03	12	[{"id_menu":3,"count":1}]	28608	pick-up	0	12
72340	2020-06-03 08:41:37	2020-06-03	8	[{"id_menu":5,"count":1}]	3567	delivery	5	13
72341	2020-06-03 08:42:47	2020-06-03	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28726	delivery	5	35
72342	2020-06-03 08:43:35	2020-06-03	14	[{"id_menu":2,"count":1}]	7233	delivery	5	19
72343	2020-06-03 08:48:51	2020-06-03	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	28660	delivery	5	31
72344	2020-06-03 08:49:24	2020-06-03	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	25086	delivery	5	26
72345	2020-06-03 08:49:30	2020-06-03	9	[{"id_menu":7,"count":1}]	2232	delivery	5	14
72346	2020-06-03 08:50:38	2020-06-03	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13821	pick-up	0	49
72347	2020-06-03 08:52:22	2020-06-03	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	28606	delivery	5	34
72348	2020-06-03 08:52:42	2020-06-03	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	4062	pick-up	0	38
72349	2020-06-03 08:54:59	2020-06-03	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":3}]	28697	delivery	5	22
72350	2020-06-03 08:55:26	2020-06-03	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":3}]	28626	delivery	5	26
72351	2020-06-03 08:57:31	2020-06-03	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	20246	delivery	5	31
72352	2020-06-03 09:06:03	2020-06-03	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8574	pick-up	0	17
72353	2020-06-03 09:14:13	2020-06-03	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":3}]	18045	delivery	5	22
72354	2020-06-03 09:22:45	2020-06-03	14	[{"id_menu":2,"count":1}]	16755	delivery	5	19
72355	2020-06-03 09:27:00	2020-06-03	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	28584	delivery	5	26
72356	2020-06-03 09:27:38	2020-06-03	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	28561	delivery	5	26
72357	2020-06-03 09:31:15	2020-06-03	12	[{"id_menu":1,"count":1}]	699	delivery	5	17
72358	2020-06-03 09:33:00	2020-06-03	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	11858	delivery	5	26
72359	2020-06-03 09:33:23	2020-06-03	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20517	delivery	5	22
72360	2020-06-03 09:45:11	2020-06-03	9	[{"id_menu":7,"count":1}]	5775	delivery	5	14
72361	2020-06-03 09:49:15	2020-06-03	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1442	delivery	5	31
72362	2020-06-03 09:51:08	2020-06-03	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	24807	delivery	5	35
72363	2020-06-03 09:59:33	2020-06-03	9	[{"id_menu":7,"count":1}]	26619	delivery	5	14
72364	2020-06-03 10:00:20	2020-06-03	9	[{"id_menu":7,"count":1}]	27595	delivery	5	14
72365	2020-06-03 10:01:39	2020-06-03	8	[{"id_menu":5,"count":1}]	21220	delivery	5	13
72366	2020-06-03 10:04:32	2020-06-03	8	[{"id_menu":5,"count":1}]	22255	delivery	5	13
72367	2020-06-03 10:06:05	2020-06-03	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	14725	delivery	5	44
72368	2020-06-03 10:08:13	2020-06-03	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	11469	delivery	5	27
72369	2020-06-03 10:09:07	2020-06-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	377	delivery	5	28
72370	2020-06-03 10:09:20	2020-06-03	8	[{"id_menu":5,"count":1}]	23232	delivery	5	13
72371	2020-06-03 10:11:10	2020-06-03	12	[{"id_menu":1,"count":1}]	314	pick-up	0	12
72372	2020-06-03 10:11:59	2020-06-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	21600	pick-up	0	26
72373	2020-06-03 10:15:31	2020-06-03	8	[{"id_menu":5,"count":1}]	1600	pick-up	0	8
72374	2020-06-03 10:16:08	2020-06-03	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14422	delivery	5	43
72375	2020-06-03 10:19:53	2020-06-03	17	[{"id_menu":4,"count":1}]	8862	delivery	5	22
72376	2020-06-03 10:24:18	2020-06-03	8	[{"id_menu":5,"count":1}]	28570	delivery	5	13
72377	2020-06-03 10:26:06	2020-06-03	9	[{"id_menu":7,"count":1}]	19637	pick-up	0	9
72378	2020-06-03 10:27:43	2020-06-03	9	[{"id_menu":7,"count":1}]	24603	pick-up	0	9
72379	2020-06-03 10:29:31	2020-06-03	9	[{"id_menu":7,"count":1}]	28679	delivery	5	14
72380	2020-06-03 10:32:32	2020-06-03	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14262	delivery	5	22
72381	2020-06-03 10:36:40	2020-06-03	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28545	delivery	5	34
72382	2020-06-03 10:37:37	2020-06-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	28564	delivery	5	28
72383	2020-06-03 10:38:20	2020-06-03	9	[{"id_menu":6,"count":1}]	28614	delivery	5	14
72384	2020-06-03 10:40:38	2020-06-03	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	12482	delivery	5	26
72385	2020-06-03 10:42:12	2020-06-03	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8594	delivery	5	30
72386	2020-06-03 10:48:58	2020-06-03	12	[{"id_menu":1,"count":1}]	15390	delivery	5	17
72387	2020-06-03 10:49:27	2020-06-03	8	[{"id_menu":5,"count":1}]	26427	delivery	5	13
72388	2020-06-03 10:49:58	2020-06-03	9	[{"id_menu":6,"count":1}]	28708	delivery	5	14
72389	2020-06-03 11:03:32	2020-06-03	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	27114	delivery	5	34
72390	2020-06-03 11:04:07	2020-06-03	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	4594	delivery	5	25
72391	2020-06-03 11:07:39	2020-06-03	12	[{"id_menu":3,"count":1}]	28593	delivery	5	17
72392	2020-06-03 11:09:03	2020-06-03	12	[{"id_menu":1,"count":1}]	332	delivery	5	17
72393	2020-06-03 11:10:15	2020-06-03	8	[{"id_menu":5,"count":1}]	3198	pick-up	0	8
72394	2020-06-03 11:11:30	2020-06-03	14	[{"id_menu":2,"count":1}]	23986	delivery	5	19
72395	2020-06-03 11:12:16	2020-06-03	12	[{"id_menu":3,"count":1}]	25975	pick-up	0	12
72396	2020-06-03 11:13:28	2020-06-03	9	[{"id_menu":7,"count":1}]	28576	pick-up	0	9
72397	2020-06-03 11:14:34	2020-06-03	9	[{"id_menu":7,"count":1}]	28687	delivery	5	14
72398	2020-06-03 11:18:53	2020-06-03	12	[{"id_menu":3,"count":1}]	16829	pick-up	0	12
72399	2020-06-03 11:20:09	2020-06-03	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	28579	delivery	5	26
72400	2020-06-03 11:25:13	2020-06-03	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9459	delivery	5	36
72401	2020-06-03 11:25:26	2020-06-03	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10297	delivery	5	22
72402	2020-06-03 11:25:34	2020-06-03	12	[{"id_menu":3,"count":1}]	11839	delivery	5	17
72403	2020-06-03 11:25:35	2020-06-03	17	[{"id_menu":4,"count":1}]	5963	delivery	5	22
72404	2020-06-03 11:27:14	2020-06-03	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	13636	delivery	5	26
72405	2020-06-03 11:42:33	2020-06-03	12	[{"id_menu":3,"count":1}]	1813	pick-up	0	12
72406	2020-06-03 11:42:41	2020-06-03	55	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3869	delivery	5	60
72407	2020-06-03 11:42:43	2020-06-03	12	[{"id_menu":3,"count":1}]	28731	delivery	5	17
72408	2020-06-03 11:43:52	2020-06-03	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2517	pick-up	0	25
72409	2020-06-03 11:45:51	2020-06-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	18227	pick-up	0	26
72410	2020-06-03 11:48:05	2020-06-03	9	[{"id_menu":6,"count":1}]	28538	delivery	5	14
72411	2020-06-03 11:50:58	2020-06-03	12	[{"id_menu":1,"count":1}]	2954	pick-up	0	12
72412	2020-06-03 11:51:18	2020-06-03	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8987	delivery	5	45
72413	2020-06-03 11:51:40	2020-06-03	12	[{"id_menu":1,"count":1}]	23191	delivery	5	17
72414	2020-06-03 11:52:34	2020-06-03	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6693	delivery	5	22
72415	2020-06-03 11:53:59	2020-06-03	14	[{"id_menu":2,"count":2}]	7428	delivery	5	19
72416	2020-06-03 12:02:33	2020-06-03	9	[{"id_menu":7,"count":1}]	10442	delivery	5	14
72417	2020-06-03 12:03:40	2020-06-03	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	18343	delivery	5	56
72418	2020-06-03 12:06:21	2020-06-03	12	[{"id_menu":3,"count":1}]	23241	pick-up	0	12
72419	2020-06-03 12:07:06	2020-06-03	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	11585	delivery	5	27
72420	2020-06-03 12:08:46	2020-06-03	12	[{"id_menu":1,"count":1}]	17086	delivery	5	17
72421	2020-06-03 12:14:45	2020-06-03	12	[{"id_menu":1,"count":1}]	2007	delivery	5	17
72422	2020-06-03 12:24:26	2020-06-03	8	[{"id_menu":5,"count":1}]	23300	delivery	5	13
72423	2020-06-03 12:26:08	2020-06-03	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	28630	delivery	5	30
72424	2020-06-03 12:26:48	2020-06-03	12	[{"id_menu":3,"count":1}]	10033	delivery	5	17
72425	2020-06-03 12:31:54	2020-06-03	9	[{"id_menu":6,"count":1}]	9519	delivery	5	14
72426	2020-06-03 12:33:21	2020-06-03	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	17548	pick-up	0	21
72427	2020-06-03 12:34:08	2020-06-03	8	[{"id_menu":5,"count":1}]	3898	delivery	5	13
72428	2020-06-03 12:36:56	2020-06-03	9	[{"id_menu":6,"count":1}]	28585	delivery	5	14
72429	2020-06-03 12:44:33	2020-06-03	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27137	delivery	5	34
72430	2020-06-03 12:47:36	2020-06-03	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28661	delivery	5	34
72431	2020-06-03 12:51:15	2020-06-03	17	[{"id_menu":4,"count":1}]	2228	pick-up	0	17
72432	2020-06-03 12:53:00	2020-06-03	9	[{"id_menu":7,"count":1}]	11979	delivery	5	14
72433	2020-06-03 12:56:35	2020-06-03	12	[{"id_menu":1,"count":1}]	25464	pick-up	0	12
72434	2020-06-03 12:59:31	2020-06-03	14	[{"id_menu":2,"count":1}]	9531	delivery	5	19
72435	2020-06-03 13:01:24	2020-06-03	8	[{"id_menu":5,"count":1}]	6144	delivery	5	13
72436	2020-06-03 13:05:19	2020-06-03	9	[{"id_menu":7,"count":1}]	12035	pick-up	0	9
72437	2020-06-03 13:09:00	2020-06-03	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17347	delivery	5	37
72438	2020-06-03 13:27:31	2020-06-03	9	[{"id_menu":6,"count":1}]	23813	delivery	5	14
72439	2020-06-03 13:29:46	2020-06-03	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	25071	delivery	5	26
72440	2020-06-03 13:30:18	2020-06-03	12	[{"id_menu":1,"count":1}]	8598	pick-up	0	12
72441	2020-06-03 13:31:08	2020-06-03	12	[{"id_menu":3,"count":1}]	9305	delivery	5	17
72442	2020-06-03 13:33:08	2020-06-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	11386	delivery	5	31
72443	2020-06-03 13:39:01	2020-06-03	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	23061	delivery	5	31
72444	2020-06-03 13:39:48	2020-06-03	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	26700	delivery	5	51
72445	2020-06-03 13:43:00	2020-06-03	12	[{"id_menu":3,"count":1}]	18418	delivery	5	17
72446	2020-06-03 13:44:04	2020-06-03	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	12565	delivery	5	26
72447	2020-06-03 13:45:32	2020-06-03	17	[{"id_menu":4,"count":1}]	20091	delivery	5	22
72448	2020-06-03 13:54:23	2020-06-03	14	[{"id_menu":2,"count":1}]	23338	delivery	5	19
72449	2020-06-03 13:55:02	2020-06-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	18981	pick-up	0	26
72450	2020-06-03 13:55:59	2020-06-03	12	[{"id_menu":1,"count":1}]	28536	pick-up	0	12
72451	2020-06-03 14:00:21	2020-06-03	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	28713	delivery	5	26
72452	2020-06-03 14:01:13	2020-06-03	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	14662	pick-up	0	31
72453	2020-06-03 14:01:52	2020-06-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	12650	delivery	5	28
72454	2020-06-03 14:03:19	2020-06-03	9	[{"id_menu":6,"count":1}]	101	pick-up	0	9
72455	2020-06-03 14:03:23	2020-06-03	9	[{"id_menu":7,"count":1}]	6046	delivery	5	14
72456	2020-06-03 14:06:00	2020-06-03	8	[{"id_menu":5,"count":1}]	28543	delivery	5	13
72457	2020-06-03 14:09:23	2020-06-03	8	[{"id_menu":5,"count":1}]	28580	delivery	5	13
72458	2020-06-03 14:21:31	2020-06-03	8	[{"id_menu":5,"count":1}]	28618	delivery	5	13
72459	2020-06-03 14:23:02	2020-06-03	17	[{"id_menu":4,"count":1}]	10675	delivery	5	22
72460	2020-06-03 14:26:51	2020-06-03	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28690	delivery	5	45
72461	2020-06-03 14:28:10	2020-06-03	9	[{"id_menu":7,"count":1}]	28604	delivery	5	14
72462	2020-06-03 14:33:53	2020-06-03	9	[{"id_menu":6,"count":1}]	16337	pick-up	0	9
72463	2020-06-03 14:35:15	2020-06-03	14	[{"id_menu":2,"count":1}]	2081	delivery	5	19
72464	2020-06-03 14:36:36	2020-06-03	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":2}]	6664	delivery	5	22
72465	2020-06-03 14:40:17	2020-06-03	9	[{"id_menu":7,"count":1}]	26299	delivery	5	14
72466	2020-06-03 14:41:43	2020-06-03	9	[{"id_menu":7,"count":1}]	28540	delivery	5	14
72467	2020-06-03 14:42:31	2020-06-03	34	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	23316	delivery	5	39
72468	2020-06-03 14:44:38	2020-06-03	14	[{"id_menu":2,"count":1}]	24989	pick-up	0	14
72469	2020-06-03 14:45:30	2020-06-03	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	14349	delivery	5	36
72470	2020-06-03 14:49:12	2020-06-03	14	[{"id_menu":2,"count":1}]	4295	pick-up	0	14
72471	2020-06-03 14:51:40	2020-06-03	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28624	delivery	5	40
72472	2020-06-03 14:53:39	2020-06-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	28676	delivery	5	28
72473	2020-06-03 14:54:18	2020-06-03	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20126	delivery	5	22
72474	2020-06-03 14:54:27	2020-06-03	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2264	pick-up	0	20
72475	2020-06-03 15:09:24	2020-06-03	12	[{"id_menu":3,"count":1}]	28657	delivery	5	17
72476	2020-06-03 15:28:27	2020-06-03	9	[{"id_menu":7,"count":1}]	4774	delivery	5	14
72477	2020-06-03 15:31:54	2020-06-03	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	23037	delivery	5	25
72478	2020-06-03 15:34:42	2020-06-03	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	20511	delivery	5	36
72479	2020-06-03 15:44:39	2020-06-03	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25625	delivery	5	35
72480	2020-06-03 15:45:17	2020-06-03	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	8305	delivery	5	34
72481	2020-06-03 15:45:51	2020-06-03	9	[{"id_menu":6,"count":1}]	28720	delivery	5	14
72482	2020-06-03 15:47:21	2020-06-03	9	[{"id_menu":7,"count":1}]	28531	delivery	5	14
72483	2020-06-03 15:52:09	2020-06-03	9	[{"id_menu":7,"count":1}]	17131	delivery	5	14
72484	2020-06-03 15:53:14	2020-06-03	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	12552	pick-up	0	24
72485	2020-06-03 15:54:47	2020-06-03	9	[{"id_menu":7,"count":1}]	7691	pick-up	0	9
72486	2020-06-03 15:59:33	2020-06-03	9	[{"id_menu":6,"count":2}]	20771	delivery	5	14
72487	2020-06-03 16:04:15	2020-06-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	28649	delivery	5	31
72488	2020-06-03 16:04:54	2020-06-03	9	[{"id_menu":7,"count":1}]	28671	delivery	5	14
72489	2020-06-03 16:10:27	2020-06-03	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	20814	delivery	5	57
72490	2020-06-03 16:12:34	2020-06-03	17	[{"id_menu":4,"count":1}]	3711	pick-up	0	17
72491	2020-06-03 16:16:10	2020-06-03	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	23994	delivery	5	38
72492	2020-06-03 16:17:29	2020-06-03	14	[{"id_menu":2,"count":1}]	2450	delivery	5	19
72493	2020-06-03 16:18:57	2020-06-03	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3156	pick-up	0	22
72494	2020-06-03 16:20:06	2020-06-03	9	[{"id_menu":7,"count":1}]	25933	delivery	5	14
72495	2020-06-03 16:20:22	2020-06-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2052	pick-up	0	26
72496	2020-06-03 16:22:36	2020-06-03	9	[{"id_menu":7,"count":1}]	2829	delivery	5	14
72497	2020-06-03 16:25:51	2020-06-03	8	[{"id_menu":5,"count":1}]	28638	delivery	5	13
72498	2020-06-03 16:32:07	2020-06-03	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	9603	pick-up	0	29
72499	2020-06-03 16:34:53	2020-06-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17229	delivery	5	31
72500	2020-06-03 16:36:12	2020-06-03	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	16324	delivery	5	27
72501	2020-06-03 16:38:27	2020-06-03	8	[{"id_menu":5,"count":1}]	28728	delivery	5	13
72502	2020-06-03 16:38:43	2020-06-03	17	[{"id_menu":4,"count":1}]	1541	pick-up	0	17
72503	2020-06-03 16:40:31	2020-06-03	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	27201	delivery	5	40
72504	2020-06-03 16:40:48	2020-06-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	28577	delivery	5	31
72505	2020-06-03 16:44:47	2020-06-03	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	2413	delivery	5	34
72506	2020-06-03 16:48:13	2020-06-03	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	18896	delivery	5	26
72507	2020-06-03 16:48:26	2020-06-03	12	[{"id_menu":1,"count":1}]	18424	pick-up	0	12
72508	2020-06-03 16:54:10	2020-06-03	9	[{"id_menu":6,"count":2}]	28633	delivery	5	14
72509	2020-06-03 16:54:44	2020-06-03	8	[{"id_menu":5,"count":1}]	28567	delivery	5	13
72510	2020-06-03 16:56:57	2020-06-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	11586	delivery	5	31
72511	2020-06-03 17:03:47	2020-06-03	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8467	delivery	5	35
72512	2020-06-03 17:05:00	2020-06-03	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	22311	delivery	5	43
72513	2020-06-03 17:11:33	2020-06-03	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28542	delivery	5	22
72514	2020-06-03 17:14:22	2020-06-03	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":3}]	26195	delivery	5	22
72515	2020-06-03 17:15:33	2020-06-03	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16264	pick-up	0	29
72516	2020-06-03 17:15:59	2020-06-03	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13165	delivery	5	22
72517	2020-06-03 17:20:53	2020-06-03	12	[{"id_menu":1,"count":1}]	28586	pick-up	0	12
72518	2020-06-03 17:23:54	2020-06-03	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	11298	delivery	5	34
72519	2020-06-03 17:25:41	2020-06-03	17	[{"id_menu":4,"count":1}]	20618	delivery	5	22
72520	2020-06-03 17:29:35	2020-06-03	9	[{"id_menu":6,"count":1}]	1947	pick-up	0	9
72521	2020-06-03 17:31:34	2020-06-03	12	[{"id_menu":1,"count":1}]	22294	pick-up	0	12
72522	2020-06-03 17:35:08	2020-06-03	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	28647	delivery	5	29
72523	2020-06-03 17:47:14	2020-06-03	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	28537	delivery	5	26
72524	2020-06-03 17:50:37	2020-06-03	8	[{"id_menu":5,"count":1}]	28616	delivery	5	13
72525	2020-06-03 17:52:19	2020-06-03	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	19747	delivery	5	40
72526	2020-06-03 17:54:37	2020-06-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	28563	delivery	5	28
72527	2020-06-03 17:56:57	2020-06-03	9	[{"id_menu":6,"count":3}]	17833	delivery	5	14
72528	2020-06-03 17:57:57	2020-06-03	12	[{"id_menu":1,"count":1}]	11904	pick-up	0	12
72529	2020-06-03 17:58:13	2020-06-03	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	28648	pick-up	0	26
72530	2020-06-03 17:59:37	2020-06-03	17	[{"id_menu":4,"count":1}]	3003	pick-up	0	17
72531	2020-06-03 18:00:02	2020-06-03	17	[{"id_menu":4,"count":1}]	5311	pick-up	0	17
72532	2020-06-03 18:05:57	2020-06-03	14	[{"id_menu":2,"count":1}]	28572	delivery	5	19
72533	2020-06-03 18:08:40	2020-06-03	9	[{"id_menu":7,"count":1}]	7123	delivery	5	14
72534	2020-06-03 18:10:44	2020-06-03	9	[{"id_menu":6,"count":1}]	5729	pick-up	0	9
72535	2020-06-03 18:12:59	2020-06-03	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	17550	delivery	5	30
72536	2020-06-03 18:14:26	2020-06-03	12	[{"id_menu":1,"count":1}]	24583	delivery	5	17
72537	2020-06-03 18:15:02	2020-06-03	14	[{"id_menu":2,"count":1}]	28673	delivery	5	19
72538	2020-06-03 18:16:05	2020-06-03	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4982	delivery	5	38
72539	2020-06-03 18:16:40	2020-06-03	8	[{"id_menu":5,"count":1}]	25784	delivery	5	13
72540	2020-06-03 18:18:07	2020-06-03	12	[{"id_menu":3,"count":1}]	2349	delivery	5	17
72541	2020-06-03 18:26:08	2020-06-03	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	9489	delivery	5	40
72542	2020-06-03 18:27:55	2020-06-03	9	[{"id_menu":6,"count":1}]	24449	delivery	5	14
72543	2020-06-03 18:28:47	2020-06-03	9	[{"id_menu":7,"count":1}]	9133	delivery	5	14
72544	2020-06-03 18:30:51	2020-06-03	8	[{"id_menu":5,"count":1}]	13257	delivery	5	13
72545	2020-06-03 18:34:59	2020-06-03	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28617	delivery	5	54
72546	2020-06-03 18:38:44	2020-06-03	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28715	delivery	5	34
72547	2020-06-03 18:40:02	2020-06-03	12	[{"id_menu":3,"count":1}]	15964	delivery	5	17
72548	2020-06-03 18:45:26	2020-06-03	8	[{"id_menu":5,"count":1}]	28610	delivery	5	13
72549	2020-06-03 18:47:18	2020-06-03	12	[{"id_menu":3,"count":1}]	16792	pick-up	0	12
72550	2020-06-03 18:47:28	2020-06-03	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	28705	pick-up	0	29
72551	2020-06-03 18:47:48	2020-06-03	12	[{"id_menu":3,"count":1}]	20709	delivery	5	17
72552	2020-06-03 18:49:51	2020-06-03	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4321	delivery	5	48
72553	2020-06-03 18:51:35	2020-06-03	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	12305	pick-up	0	25
72554	2020-06-03 18:51:46	2020-06-03	12	[{"id_menu":1,"count":1}]	609	delivery	5	17
72555	2020-06-03 18:54:17	2020-06-03	14	[{"id_menu":2,"count":1}]	13634	delivery	5	19
72556	2020-06-03 18:54:54	2020-06-03	9	[{"id_menu":6,"count":1}]	19172	delivery	5	14
72557	2020-06-03 19:00:20	2020-06-03	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	2695	delivery	5	34
72558	2020-06-03 19:03:13	2020-06-03	14	[{"id_menu":2,"count":1}]	21224	delivery	5	19
72559	2020-06-03 19:09:44	2020-06-03	12	[{"id_menu":3,"count":1}]	12833	delivery	5	17
72560	2020-06-03 19:09:49	2020-06-03	14	[{"id_menu":2,"count":1}]	28603	delivery	5	19
72561	2020-06-03 19:27:44	2020-06-03	14	[{"id_menu":2,"count":1}]	21308	pick-up	0	14
72562	2020-06-03 19:28:15	2020-06-03	8	[{"id_menu":5,"count":1}]	5188	delivery	5	13
72563	2020-06-03 19:29:28	2020-06-03	17	[{"id_menu":4,"count":1}]	28656	delivery	5	22
72564	2020-06-03 19:31:35	2020-06-03	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	28704	delivery	5	26
72565	2020-06-03 19:32:09	2020-06-03	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	15595	delivery	5	31
72566	2020-06-03 19:32:48	2020-06-03	9	[{"id_menu":7,"count":1}]	9981	delivery	5	14
72567	2020-06-03 19:36:27	2020-06-03	9	[{"id_menu":6,"count":1}]	22147	delivery	5	14
72568	2020-06-03 19:40:37	2020-06-03	17	[{"id_menu":4,"count":1}]	6396	pick-up	0	17
72569	2020-06-03 19:41:39	2020-06-03	12	[{"id_menu":3,"count":1}]	28725	delivery	5	17
72570	2020-06-03 19:42:45	2020-06-03	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	23585	pick-up	0	40
72571	2020-06-03 19:43:30	2020-06-03	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	28684	delivery	5	43
72572	2020-06-03 19:48:39	2020-06-03	14	[{"id_menu":2,"count":1}]	4052	delivery	5	19
72573	2020-06-03 19:49:16	2020-06-03	9	[{"id_menu":7,"count":1}]	1233	pick-up	0	9
72574	2020-06-03 19:49:58	2020-06-03	12	[{"id_menu":1,"count":1}]	28551	delivery	5	17
72575	2020-06-03 19:50:13	2020-06-03	9	[{"id_menu":6,"count":1}]	7909	delivery	5	14
72576	2020-06-03 20:05:58	2020-06-03	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":2}]	28555	delivery	5	31
72577	2020-06-03 20:14:25	2020-06-03	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2741	delivery	5	40
72578	2020-06-03 20:16:34	2020-06-03	17	[{"id_menu":4,"count":1}]	9241	pick-up	0	17
72579	2020-06-03 20:19:02	2020-06-03	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28548	delivery	5	35
72580	2020-06-03 20:19:19	2020-06-03	9	[{"id_menu":7,"count":1}]	17557	delivery	5	14
72581	2020-06-03 20:19:22	2020-06-03	14	[{"id_menu":2,"count":1}]	28534	delivery	5	19
72582	2020-06-03 20:19:53	2020-06-03	8	[{"id_menu":5,"count":1}]	28722	delivery	5	13
72583	2020-06-03 20:21:22	2020-06-03	12	[{"id_menu":1,"count":1}]	5377	delivery	5	17
72584	2020-06-03 20:21:49	2020-06-03	17	[{"id_menu":4,"count":1}]	13187	delivery	5	22
72585	2020-06-03 20:23:08	2020-06-03	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	27403	delivery	5	40
72586	2020-06-03 20:24:36	2020-06-03	14	[{"id_menu":2,"count":1}]	22430	delivery	5	19
72587	2020-06-03 20:25:15	2020-06-03	12	[{"id_menu":3,"count":1}]	28644	delivery	5	17
72588	2020-06-03 20:25:41	2020-06-03	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	11635	delivery	5	42
72589	2020-06-03 20:26:04	2020-06-03	9	[{"id_menu":7,"count":1}]	6701	delivery	5	14
72590	2020-06-03 20:26:59	2020-06-03	8	[{"id_menu":5,"count":2}]	28714	delivery	5	13
72591	2020-06-03 20:32:40	2020-06-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	11214	delivery	5	28
72592	2020-06-03 20:33:00	2020-06-03	9	[{"id_menu":6,"count":1}]	19216	delivery	5	14
72593	2020-06-03 20:33:03	2020-06-03	17	[{"id_menu":4,"count":1}]	1639	delivery	5	22
72594	2020-06-03 20:34:01	2020-06-03	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28641	delivery	5	31
72595	2020-06-03 20:35:39	2020-06-03	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	16556	delivery	5	34
72596	2020-06-03 20:37:23	2020-06-03	9	[{"id_menu":6,"count":1}]	14010	pick-up	0	9
72597	2020-06-03 20:37:57	2020-06-03	9	[{"id_menu":7,"count":2}]	15456	pick-up	0	9
72598	2020-06-03 20:44:38	2020-06-03	8	[{"id_menu":5,"count":1}]	11992	pick-up	0	8
72599	2020-06-03 20:51:40	2020-06-03	17	[{"id_menu":4,"count":1}]	6298	delivery	5	22
72600	2020-06-03 20:51:58	2020-06-03	8	[{"id_menu":5,"count":1}]	10386	delivery	5	13
72601	2020-06-03 20:57:00	2020-06-03	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	28669	delivery	5	40
72602	2020-06-03 20:57:57	2020-06-03	12	[{"id_menu":3,"count":1}]	28592	delivery	5	17
72603	2020-06-03 21:00:51	2020-06-03	9	[{"id_menu":6,"count":2}]	19521	delivery	5	14
72604	2020-06-03 21:01:46	2020-06-03	14	[{"id_menu":2,"count":1}]	3904	pick-up	0	14
72605	2020-06-03 21:01:49	2020-06-03	12	[{"id_menu":1,"count":1}]	5223	delivery	5	17
72606	2020-06-03 21:02:16	2020-06-03	9	[{"id_menu":6,"count":1}]	28612	delivery	5	14
72607	2020-06-03 21:02:50	2020-06-03	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	5343	pick-up	0	43
72608	2020-06-03 21:17:22	2020-06-03	17	[{"id_menu":4,"count":1}]	28727	delivery	5	22
72609	2020-06-03 21:18:21	2020-06-03	8	[{"id_menu":5,"count":1}]	28611	pick-up	0	8
72610	2020-06-03 21:18:47	2020-06-03	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20920	delivery	5	34
72611	2020-06-03 21:26:45	2020-06-03	9	[{"id_menu":6,"count":1}]	28554	delivery	5	14
72612	2020-06-03 21:28:04	2020-06-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	28670	delivery	5	31
72613	2020-06-03 21:28:16	2020-06-03	14	[{"id_menu":2,"count":1}]	5306	pick-up	0	14
72614	2020-06-03 21:28:29	2020-06-03	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	28651	delivery	5	22
72615	2020-06-03 21:32:05	2020-06-03	14	[{"id_menu":2,"count":1}]	28550	pick-up	0	14
72616	2020-06-03 21:33:07	2020-06-03	12	[{"id_menu":3,"count":1}]	16108	delivery	5	17
72617	2020-06-03 21:41:27	2020-06-03	14	[{"id_menu":2,"count":1}]	6711	pick-up	0	14
72618	2020-06-03 21:45:07	2020-06-03	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	28703	delivery	5	29
72619	2020-06-03 21:45:08	2020-06-03	9	[{"id_menu":7,"count":1}]	28573	delivery	5	14
72620	2020-06-03 21:47:30	2020-06-03	12	[{"id_menu":3,"count":1}]	18501	pick-up	0	12
72621	2020-06-03 21:49:24	2020-06-03	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	8201	delivery	5	37
72622	2020-06-03 21:52:58	2020-06-03	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7760	delivery	5	22
72623	2020-06-03 21:53:12	2020-06-03	8	[{"id_menu":5,"count":1}]	28591	delivery	5	13
72624	2020-06-03 21:57:49	2020-06-03	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":3}]	28588	delivery	5	22
72625	2020-06-03 22:00:31	2020-06-03	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6894	delivery	5	40
72626	2020-06-03 22:00:35	2020-06-03	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":2}]	5888	delivery	5	31
72627	2020-06-03 22:01:40	2020-06-03	12	[{"id_menu":1,"count":1}]	28609	delivery	5	17
72628	2020-06-03 22:04:48	2020-06-03	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	28600	delivery	5	25
72629	2020-06-03 22:04:50	2020-06-03	9	[{"id_menu":6,"count":2}]	20196	delivery	5	14
72630	2020-06-03 22:07:33	2020-06-03	12	[{"id_menu":1,"count":1}]	57	delivery	5	17
72631	2020-06-03 22:11:28	2020-06-03	9	[{"id_menu":6,"count":1}]	28620	delivery	5	14
72632	2020-06-03 22:16:37	2020-06-03	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28667	delivery	5	34
72633	2020-06-03 22:18:38	2020-06-03	8	[{"id_menu":5,"count":1}]	28636	delivery	5	13
72634	2020-06-03 22:19:00	2020-06-03	9	[{"id_menu":6,"count":1}]	21614	delivery	5	14
72635	2020-06-03 22:24:42	2020-06-03	9	[{"id_menu":6,"count":1}]	6631	pick-up	0	9
72636	2020-06-03 22:33:43	2020-06-03	9	[{"id_menu":7,"count":1}]	27714	delivery	5	14
72637	2020-06-03 22:43:19	2020-06-03	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	10690	delivery	5	29
72638	2020-06-03 22:45:21	2020-06-03	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	28615	pick-up	0	26
72639	2020-06-03 22:50:44	2020-06-03	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	28558	delivery	5	23
72640	2020-06-03 22:51:34	2020-06-03	9	[{"id_menu":7,"count":1}]	2161	pick-up	0	9
72641	2020-06-03 22:53:46	2020-06-03	12	[{"id_menu":1,"count":1}]	28695	delivery	5	17
72642	2020-06-03 22:56:14	2020-06-03	9	[{"id_menu":7,"count":1}]	4080	delivery	5	14
72643	2020-06-03 22:57:17	2020-06-03	9	[{"id_menu":6,"count":1}]	28530	delivery	5	14
72644	2020-06-03 22:58:22	2020-06-03	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	6883	delivery	5	26
72645	2020-06-03 22:59:50	2020-06-03	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28680	delivery	5	34
72646	2020-06-03 23:00:31	2020-06-03	8	[{"id_menu":5,"count":2}]	15864	pick-up	0	8
72647	2020-06-03 23:02:43	2020-06-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	24368	delivery	5	28
72648	2020-06-03 23:04:08	2020-06-03	14	[{"id_menu":2,"count":1}]	18214	delivery	5	19
72649	2020-06-03 23:05:10	2020-06-03	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	28169	delivery	5	34
72650	2020-06-03 23:06:58	2020-06-03	9	[{"id_menu":7,"count":1}]	15479	delivery	5	14
72651	2020-06-03 23:08:37	2020-06-03	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15109	delivery	5	43
72652	2020-06-03 23:11:28	2020-06-03	8	[{"id_menu":5,"count":1}]	28581	delivery	5	13
72653	2020-06-03 23:13:31	2020-06-03	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28613	delivery	5	39
72654	2020-06-03 23:14:57	2020-06-03	8	[{"id_menu":5,"count":1}]	3512	delivery	5	13
72655	2020-06-03 23:16:36	2020-06-03	12	[{"id_menu":1,"count":1}]	28674	delivery	5	17
72656	2020-06-03 23:17:04	2020-06-03	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	28691	delivery	5	34
72657	2020-06-03 23:19:31	2020-06-03	12	[{"id_menu":1,"count":1}]	7150	pick-up	0	12
72658	2020-06-03 23:22:38	2020-06-03	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	28552	pick-up	0	23
72659	2020-06-03 23:27:09	2020-06-03	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28699	delivery	5	34
72660	2020-06-03 23:29:59	2020-06-03	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28682	delivery	5	35
72661	2020-06-03 23:32:12	2020-06-03	14	[{"id_menu":2,"count":1}]	881	pick-up	0	14
72662	2020-06-03 23:32:34	2020-06-03	9	[{"id_menu":7,"count":1}]	28599	delivery	5	14
72663	2020-06-03 23:35:32	2020-06-03	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11983	delivery	5	43
72664	2020-06-03 23:36:08	2020-06-03	8	[{"id_menu":5,"count":1}]	22396	delivery	5	13
72665	2020-06-03 23:37:02	2020-06-03	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	9573	pick-up	0	21
72666	2020-06-03 23:37:43	2020-06-03	12	[{"id_menu":1,"count":1}]	28694	delivery	5	17
72667	2020-06-03 23:42:31	2020-06-03	17	[{"id_menu":4,"count":1}]	20554	delivery	5	22
72668	2020-06-03 23:42:34	2020-06-03	12	[{"id_menu":1,"count":1}]	2850	delivery	5	17
72669	2020-06-03 23:46:02	2020-06-03	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	9023	delivery	5	29
72670	2020-06-03 23:51:20	2020-06-03	8	[{"id_menu":5,"count":1}]	28640	delivery	5	13
72671	2020-06-03 23:51:26	2020-06-03	9	[{"id_menu":6,"count":1}]	17432	delivery	5	14
72672	2020-06-03 23:51:37	2020-06-03	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	26689	delivery	5	22
72673	2020-06-03 23:52:01	2020-06-03	8	[{"id_menu":5,"count":1}]	28733	pick-up	0	8
72674	2020-06-03 23:52:39	2020-06-03	14	[{"id_menu":2,"count":1}]	28578	delivery	5	19
72675	2020-06-03 23:56:07	2020-06-03	17	[{"id_menu":4,"count":1}]	28658	delivery	5	22
72676	2020-06-04 00:01:12	2020-06-04	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13477	delivery	5	22
72677	2020-06-04 00:04:04	2020-06-04	9	[{"id_menu":6,"count":2}]	9682	pick-up	0	9
72678	2020-06-04 00:04:31	2020-06-04	12	[{"id_menu":1,"count":1}]	28769	delivery	5	17
72679	2020-06-04 00:06:02	2020-06-04	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1537	pick-up	0	30
72680	2020-06-04 00:14:07	2020-06-04	9	[{"id_menu":6,"count":1}]	6434	delivery	5	14
72681	2020-06-04 00:18:26	2020-06-04	8	[{"id_menu":5,"count":1}]	2089	delivery	5	13
72682	2020-06-04 00:21:48	2020-06-04	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	2605	delivery	5	22
72683	2020-06-04 00:23:52	2020-06-04	8	[{"id_menu":5,"count":1}]	26166	delivery	5	13
72684	2020-06-04 00:25:29	2020-06-04	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	21795	delivery	5	31
72685	2020-06-04 00:26:13	2020-06-04	14	[{"id_menu":2,"count":1}]	8114	delivery	5	19
72686	2020-06-04 00:29:15	2020-06-04	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	22747	delivery	5	29
72687	2020-06-04 00:30:46	2020-06-04	17	[{"id_menu":4,"count":1}]	996	delivery	5	22
72688	2020-06-04 00:32:29	2020-06-04	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6871	delivery	5	23
72689	2020-06-04 00:36:54	2020-06-04	8	[{"id_menu":5,"count":1}]	28815	delivery	5	13
72690	2020-06-04 00:38:22	2020-06-04	9	[{"id_menu":6,"count":2}]	28909	delivery	5	14
72691	2020-06-04 00:38:54	2020-06-04	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	28518	delivery	5	27
72692	2020-06-04 00:39:29	2020-06-04	9	[{"id_menu":7,"count":1}]	28785	delivery	5	14
72693	2020-06-04 00:40:04	2020-06-04	12	[{"id_menu":1,"count":1}]	27137	delivery	5	17
72694	2020-06-04 00:52:53	2020-06-04	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	28888	delivery	5	34
72695	2020-06-04 00:53:32	2020-06-04	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	20953	delivery	5	31
72696	2020-06-04 00:54:30	2020-06-04	12	[{"id_menu":1,"count":1}]	13844	delivery	5	17
72697	2020-06-04 00:57:07	2020-06-04	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	17652	delivery	5	40
72698	2020-06-04 01:02:49	2020-06-04	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	14566	delivery	5	25
72699	2020-06-04 01:06:15	2020-06-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3127	delivery	5	28
72700	2020-06-04 01:08:14	2020-06-04	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28908	delivery	5	36
72701	2020-06-04 01:08:52	2020-06-04	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3454	delivery	5	48
72702	2020-06-04 01:10:07	2020-06-04	12	[{"id_menu":3,"count":1}]	19859	delivery	5	17
72703	2020-06-04 01:13:14	2020-06-04	12	[{"id_menu":1,"count":1}]	28915	delivery	5	17
72704	2020-06-04 01:13:19	2020-06-04	9	[{"id_menu":7,"count":1}]	27828	delivery	5	14
72705	2020-06-04 01:19:20	2020-06-04	17	[{"id_menu":4,"count":1}]	20300	pick-up	0	17
72706	2020-06-04 01:20:38	2020-06-04	12	[{"id_menu":3,"count":1}]	19613	delivery	5	17
72707	2020-06-04 01:21:24	2020-06-04	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14411	delivery	5	40
72708	2020-06-04 01:22:23	2020-06-04	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19953	delivery	5	36
72709	2020-06-04 01:23:06	2020-06-04	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	28790	delivery	5	40
72710	2020-06-04 01:23:15	2020-06-04	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28890	delivery	5	22
72711	2020-06-04 01:26:08	2020-06-04	12	[{"id_menu":3,"count":1}]	5574	delivery	5	17
72712	2020-06-04 01:31:21	2020-06-04	17	[{"id_menu":4,"count":1}]	19598	pick-up	0	17
72713	2020-06-04 01:44:46	2020-06-04	12	[{"id_menu":1,"count":1}]	771	delivery	5	17
72714	2020-06-04 01:49:42	2020-06-04	9	[{"id_menu":7,"count":1}]	28849	delivery	5	14
72715	2020-06-04 01:55:42	2020-06-04	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	28886	delivery	5	36
72716	2020-06-04 02:01:08	2020-06-04	9	[{"id_menu":6,"count":1}]	28807	delivery	5	14
72717	2020-06-04 02:01:31	2020-06-04	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6190	delivery	5	45
72718	2020-06-04 02:03:17	2020-06-04	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28833	delivery	5	49
72719	2020-06-04 02:08:57	2020-06-04	17	[{"id_menu":4,"count":1}]	11822	delivery	5	22
72720	2020-06-04 02:10:33	2020-06-04	8	[{"id_menu":5,"count":2}]	2542	pick-up	0	8
72721	2020-06-04 02:11:58	2020-06-04	9	[{"id_menu":6,"count":1}]	28857	delivery	5	14
72722	2020-06-04 02:12:25	2020-06-04	17	[{"id_menu":4,"count":1}]	7572	pick-up	0	17
72723	2020-06-04 02:17:15	2020-06-04	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	21659	delivery	5	26
72724	2020-06-04 02:21:14	2020-06-04	12	[{"id_menu":1,"count":1}]	21458	delivery	5	17
72725	2020-06-04 02:23:59	2020-06-04	8	[{"id_menu":5,"count":1}]	6321	pick-up	0	8
72726	2020-06-04 02:26:15	2020-06-04	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28167	pick-up	0	30
72727	2020-06-04 02:29:24	2020-06-04	17	[{"id_menu":4,"count":1}]	28816	delivery	5	22
72728	2020-06-04 02:29:58	2020-06-04	9	[{"id_menu":6,"count":1}]	12224	delivery	5	14
72729	2020-06-04 02:30:36	2020-06-04	9	[{"id_menu":6,"count":1}]	21072	delivery	5	14
72730	2020-06-04 02:41:02	2020-06-04	12	[{"id_menu":1,"count":1}]	28901	delivery	5	17
72731	2020-06-04 02:41:30	2020-06-04	17	[{"id_menu":4,"count":1}]	17606	delivery	5	22
72732	2020-06-04 02:45:18	2020-06-04	12	[{"id_menu":3,"count":1}]	26815	delivery	5	17
72733	2020-06-04 02:45:59	2020-06-04	14	[{"id_menu":2,"count":1}]	122	pick-up	0	14
72734	2020-06-04 02:47:23	2020-06-04	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28871	pick-up	0	32
72735	2020-06-04 02:47:44	2020-06-04	8	[{"id_menu":5,"count":1}]	18652	pick-up	0	8
72736	2020-06-04 02:49:42	2020-06-04	12	[{"id_menu":3,"count":1}]	10117	pick-up	0	12
72737	2020-06-04 02:54:04	2020-06-04	9	[{"id_menu":6,"count":1}]	9600	delivery	5	14
72738	2020-06-04 02:55:47	2020-06-04	17	[{"id_menu":4,"count":1}]	22199	delivery	5	22
72739	2020-06-04 02:56:48	2020-06-04	8	[{"id_menu":5,"count":1}]	28879	delivery	5	13
72740	2020-06-04 02:58:41	2020-06-04	8	[{"id_menu":5,"count":1}]	26994	delivery	5	13
72741	2020-06-04 03:00:40	2020-06-04	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	28808	delivery	5	39
72742	2020-06-04 03:02:36	2020-06-04	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1309	pick-up	0	23
72743	2020-06-04 03:03:00	2020-06-04	14	[{"id_menu":2,"count":1}]	15728	delivery	5	19
72744	2020-06-04 03:04:07	2020-06-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	23890	pick-up	0	23
72745	2020-06-04 03:04:32	2020-06-04	9	[{"id_menu":7,"count":1}]	1905	pick-up	0	9
72746	2020-06-04 03:04:47	2020-06-04	17	[{"id_menu":4,"count":1}]	732	pick-up	0	17
72747	2020-06-04 03:07:21	2020-06-04	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28902	delivery	5	34
72748	2020-06-04 03:08:41	2020-06-04	12	[{"id_menu":1,"count":1}]	660	pick-up	0	12
72749	2020-06-04 03:10:26	2020-06-04	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4989	delivery	5	22
72750	2020-06-04 03:12:52	2020-06-04	14	[{"id_menu":2,"count":1}]	6811	delivery	5	19
72751	2020-06-04 03:13:34	2020-06-04	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	14309	delivery	5	45
72752	2020-06-04 03:17:06	2020-06-04	17	[{"id_menu":4,"count":1}]	21690	delivery	5	22
72753	2020-06-04 03:18:05	2020-06-04	14	[{"id_menu":2,"count":1}]	360	delivery	5	19
72754	2020-06-04 03:20:44	2020-06-04	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28791	delivery	5	40
72755	2020-06-04 03:26:07	2020-06-04	14	[{"id_menu":2,"count":1}]	8642	delivery	5	19
72756	2020-06-04 03:26:21	2020-06-04	12	[{"id_menu":3,"count":1}]	28780	delivery	5	17
72757	2020-06-04 03:26:56	2020-06-04	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	18326	delivery	5	34
72758	2020-06-04 03:33:01	2020-06-04	17	[{"id_menu":4,"count":1}]	11195	pick-up	0	17
72759	2020-06-04 03:34:42	2020-06-04	8	[{"id_menu":5,"count":2}]	1580	delivery	5	13
72760	2020-06-04 03:36:55	2020-06-04	9	[{"id_menu":6,"count":1}]	7782	pick-up	0	9
72761	2020-06-04 03:40:23	2020-06-04	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	28924	delivery	5	39
72762	2020-06-04 03:42:40	2020-06-04	14	[{"id_menu":2,"count":1}]	1746	pick-up	0	14
72763	2020-06-04 03:43:38	2020-06-04	14	[{"id_menu":2,"count":1}]	25793	pick-up	0	14
72764	2020-06-04 03:44:38	2020-06-04	12	[{"id_menu":3,"count":2}]	28854	pick-up	0	12
72765	2020-06-04 03:45:44	2020-06-04	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	931	pick-up	0	40
72766	2020-06-04 03:46:50	2020-06-04	9	[{"id_menu":6,"count":1}]	19313	pick-up	0	9
72767	2020-06-04 03:49:20	2020-06-04	8	[{"id_menu":5,"count":1}]	28033	delivery	5	13
72768	2020-06-04 03:50:53	2020-06-04	9	[{"id_menu":7,"count":1}]	15580	delivery	5	14
72769	2020-06-04 03:53:49	2020-06-04	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3931	delivery	5	26
72770	2020-06-04 03:58:09	2020-06-04	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	7758	pick-up	0	21
72771	2020-06-04 03:58:55	2020-06-04	8	[{"id_menu":5,"count":1}]	11083	delivery	5	13
72772	2020-06-04 04:01:22	2020-06-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	13449	delivery	5	28
72773	2020-06-04 04:03:30	2020-06-04	12	[{"id_menu":3,"count":1}]	18734	delivery	5	17
72774	2020-06-04 04:04:34	2020-06-04	9	[{"id_menu":7,"count":1}]	9513	delivery	5	14
72775	2020-06-04 04:06:25	2020-06-04	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	16829	pick-up	0	29
72776	2020-06-04 04:13:19	2020-06-04	12	[{"id_menu":1,"count":1}]	964	delivery	5	17
72777	2020-06-04 04:13:20	2020-06-04	9	[{"id_menu":6,"count":1}]	28757	delivery	5	14
72778	2020-06-04 04:17:27	2020-06-04	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	28776	delivery	5	45
72779	2020-06-04 04:22:35	2020-06-04	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21148	delivery	5	43
72780	2020-06-04 04:22:47	2020-06-04	9	[{"id_menu":7,"count":1}]	22320	pick-up	0	9
72781	2020-06-04 04:23:15	2020-06-04	9	[{"id_menu":6,"count":1}]	2352	pick-up	0	9
72782	2020-06-04 04:23:57	2020-06-04	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	12855	delivery	5	26
72783	2020-06-04 04:24:53	2020-06-04	9	[{"id_menu":7,"count":1}]	5768	delivery	5	14
72784	2020-06-04 04:25:26	2020-06-04	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	8521	delivery	5	34
72785	2020-06-04 04:25:45	2020-06-04	8	[{"id_menu":5,"count":1}]	12993	delivery	5	13
72786	2020-06-04 04:32:23	2020-06-04	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	28910	delivery	5	31
72787	2020-06-04 04:32:52	2020-06-04	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	6563	delivery	5	22
72788	2020-06-04 04:37:53	2020-06-04	12	[{"id_menu":3,"count":1}]	4578	pick-up	0	12
72789	2020-06-04 04:39:00	2020-06-04	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	19783	delivery	5	28
72790	2020-06-04 04:40:00	2020-06-04	8	[{"id_menu":5,"count":1}]	28817	delivery	5	13
72791	2020-06-04 04:41:07	2020-06-04	14	[{"id_menu":2,"count":1}]	15163	delivery	5	19
72792	2020-06-04 04:47:19	2020-06-04	8	[{"id_menu":5,"count":1}]	28735	delivery	5	13
72793	2020-06-04 04:51:54	2020-06-04	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10003	delivery	5	31
72794	2020-06-04 04:52:23	2020-06-04	9	[{"id_menu":6,"count":1}]	10980	delivery	5	14
72795	2020-06-04 04:52:47	2020-06-04	12	[{"id_menu":3,"count":1}]	16111	pick-up	0	12
72796	2020-06-04 04:54:12	2020-06-04	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	324	pick-up	0	26
72797	2020-06-04 04:54:19	2020-06-04	9	[{"id_menu":7,"count":2}]	28917	delivery	5	14
72798	2020-06-04 04:55:41	2020-06-04	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	4393	delivery	5	26
72799	2020-06-04 04:59:10	2020-06-04	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28821	delivery	5	39
72800	2020-06-04 04:59:24	2020-06-04	9	[{"id_menu":6,"count":1}]	1684	pick-up	0	9
72801	2020-06-04 05:01:29	2020-06-04	12	[{"id_menu":1,"count":1}]	6806	delivery	5	17
72802	2020-06-04 05:05:18	2020-06-04	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	26163	delivery	5	26
72803	2020-06-04 05:06:22	2020-06-04	8	[{"id_menu":5,"count":1}]	24939	delivery	5	13
72804	2020-06-04 05:06:30	2020-06-04	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	8546	pick-up	0	38
72805	2020-06-04 05:08:23	2020-06-04	9	[{"id_menu":7,"count":1}]	19569	delivery	5	14
72806	2020-06-04 05:09:07	2020-06-04	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17245	pick-up	0	30
72807	2020-06-04 05:11:14	2020-06-04	9	[{"id_menu":6,"count":1}]	8372	pick-up	0	9
72808	2020-06-04 05:14:09	2020-06-04	34	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	28862	delivery	5	39
72809	2020-06-04 05:14:33	2020-06-04	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23921	delivery	5	23
72810	2020-06-04 05:14:41	2020-06-04	12	[{"id_menu":1,"count":1}]	2140	pick-up	0	12
72811	2020-06-04 05:17:31	2020-06-04	17	[{"id_menu":4,"count":1}]	28823	delivery	5	22
72812	2020-06-04 05:18:52	2020-06-04	12	[{"id_menu":3,"count":2}]	14480	pick-up	0	12
72813	2020-06-04 05:24:08	2020-06-04	9	[{"id_menu":6,"count":1}]	8929	delivery	5	14
72814	2020-06-04 05:25:52	2020-06-04	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	25585	delivery	5	27
72815	2020-06-04 05:26:21	2020-06-04	9	[{"id_menu":7,"count":1}]	28819	delivery	5	14
72816	2020-06-04 05:27:35	2020-06-04	17	[{"id_menu":4,"count":1}]	28788	delivery	5	22
72817	2020-06-04 05:30:13	2020-06-04	17	[{"id_menu":4,"count":1}]	28775	delivery	5	22
72818	2020-06-04 05:36:22	2020-06-04	9	[{"id_menu":7,"count":1}]	28753	delivery	5	14
72819	2020-06-04 05:37:19	2020-06-04	12	[{"id_menu":1,"count":1}]	28878	delivery	5	17
72820	2020-06-04 05:38:12	2020-06-04	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	7023	delivery	5	22
72821	2020-06-04 05:39:17	2020-06-04	14	[{"id_menu":2,"count":1}]	22847	pick-up	0	14
72822	2020-06-04 05:39:30	2020-06-04	8	[{"id_menu":5,"count":1}]	1773	delivery	5	13
72823	2020-06-04 05:45:51	2020-06-04	14	[{"id_menu":2,"count":1}]	28829	delivery	5	19
72824	2020-06-04 05:50:02	2020-06-04	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17743	delivery	5	35
72825	2020-06-04 05:58:42	2020-06-04	17	[{"id_menu":4,"count":1}]	28792	delivery	5	22
72826	2020-06-04 05:59:14	2020-06-04	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14612	delivery	5	22
72827	2020-06-04 06:00:14	2020-06-04	9	[{"id_menu":6,"count":1}]	20811	delivery	5	14
72828	2020-06-04 06:00:30	2020-06-04	9	[{"id_menu":6,"count":1}]	28806	delivery	5	14
72829	2020-06-04 06:02:45	2020-06-04	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	9386	delivery	5	40
72830	2020-06-04 06:02:47	2020-06-04	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	13504	pick-up	0	43
72831	2020-06-04 06:02:57	2020-06-04	14	[{"id_menu":2,"count":1}]	19256	delivery	5	19
72832	2020-06-04 06:06:24	2020-06-04	17	[{"id_menu":4,"count":1}]	11205	delivery	5	22
72833	2020-06-04 06:07:45	2020-06-04	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3999	delivery	5	40
72834	2020-06-04 06:11:20	2020-06-04	17	[{"id_menu":4,"count":1}]	28741	delivery	5	22
72835	2020-06-04 06:13:05	2020-06-04	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	28912	delivery	5	22
72836	2020-06-04 06:13:45	2020-06-04	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	23558	delivery	5	36
72837	2020-06-04 06:14:34	2020-06-04	9	[{"id_menu":6,"count":1}]	15236	delivery	5	14
72838	2020-06-04 06:16:20	2020-06-04	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	12240	pick-up	0	29
72839	2020-06-04 06:16:55	2020-06-04	8	[{"id_menu":5,"count":1}]	1604	pick-up	0	8
72840	2020-06-04 06:19:48	2020-06-04	12	[{"id_menu":3,"count":1}]	18852	delivery	5	17
72841	2020-06-04 06:20:43	2020-06-04	17	[{"id_menu":4,"count":1}]	26555	delivery	5	22
72842	2020-06-04 06:26:16	2020-06-04	8	[{"id_menu":5,"count":1}]	28898	delivery	5	13
72843	2020-06-04 06:29:18	2020-06-04	8	[{"id_menu":5,"count":2}]	26974	delivery	5	13
72844	2020-06-04 06:29:38	2020-06-04	17	[{"id_menu":4,"count":1}]	22080	delivery	5	22
72845	2020-06-04 06:34:35	2020-06-04	9	[{"id_menu":7,"count":1}]	28743	delivery	5	14
72846	2020-06-04 06:35:39	2020-06-04	12	[{"id_menu":3,"count":1}]	28836	delivery	5	17
72847	2020-06-04 06:37:08	2020-06-04	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	17654	delivery	5	40
72848	2020-06-04 06:38:16	2020-06-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7051	pick-up	0	23
72849	2020-06-04 06:38:55	2020-06-04	14	[{"id_menu":2,"count":1}]	9296	delivery	5	19
72850	2020-06-04 06:47:06	2020-06-04	8	[{"id_menu":5,"count":1}]	28925	delivery	5	13
72851	2020-06-04 06:49:41	2020-06-04	8	[{"id_menu":5,"count":1}]	18101	delivery	5	13
72852	2020-06-04 06:55:33	2020-06-04	9	[{"id_menu":7,"count":1}]	213	delivery	5	14
72853	2020-06-04 06:57:48	2020-06-04	9	[{"id_menu":6,"count":1}]	28742	delivery	5	14
72854	2020-06-04 06:58:34	2020-06-04	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	17352	pick-up	0	29
72855	2020-06-04 06:58:48	2020-06-04	14	[{"id_menu":2,"count":1}]	28824	pick-up	0	14
72856	2020-06-04 06:58:48	2020-06-04	12	[{"id_menu":3,"count":1}]	9859	delivery	5	17
72857	2020-06-04 07:08:50	2020-06-04	9	[{"id_menu":7,"count":1}]	3135	delivery	5	14
72858	2020-06-04 07:14:58	2020-06-04	12	[{"id_menu":1,"count":1}]	28920	delivery	5	17
72859	2020-06-04 07:15:52	2020-06-04	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	10007	pick-up	0	31
72860	2020-06-04 07:16:41	2020-06-04	8	[{"id_menu":5,"count":1}]	1244	delivery	5	13
72861	2020-06-04 07:17:07	2020-06-04	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	10436	pick-up	0	34
72862	2020-06-04 07:19:08	2020-06-04	14	[{"id_menu":2,"count":1}]	11289	delivery	5	19
72863	2020-06-04 07:19:46	2020-06-04	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28831	delivery	5	22
72864	2020-06-04 07:24:04	2020-06-04	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	654	pick-up	0	17
72865	2020-06-04 07:25:11	2020-06-04	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	18597	delivery	5	28
72866	2020-06-04 07:31:30	2020-06-04	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	15927	delivery	5	34
72867	2020-06-04 07:32:06	2020-06-04	9	[{"id_menu":7,"count":1}]	16518	delivery	5	14
72868	2020-06-04 07:32:06	2020-06-04	9	[{"id_menu":6,"count":1}]	28825	delivery	5	14
72869	2020-06-04 07:32:11	2020-06-04	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	20134	pick-up	0	31
72870	2020-06-04 07:33:12	2020-06-04	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	3417	delivery	5	27
72871	2020-06-04 07:35:55	2020-06-04	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3600	delivery	5	30
72872	2020-06-04 07:36:44	2020-06-04	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	28814	delivery	5	31
72873	2020-06-04 07:40:43	2020-06-04	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25293	delivery	5	40
72874	2020-06-04 07:40:55	2020-06-04	12	[{"id_menu":1,"count":1}]	28861	delivery	5	17
72875	2020-06-04 07:42:07	2020-06-04	17	[{"id_menu":4,"count":1}]	2291	pick-up	0	17
72876	2020-06-04 07:42:35	2020-06-04	12	[{"id_menu":1,"count":1}]	18309	delivery	5	17
72877	2020-06-04 07:44:03	2020-06-04	9	[{"id_menu":6,"count":1}]	4333	delivery	5	14
72878	2020-06-04 07:50:21	2020-06-04	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	28922	delivery	5	27
72879	2020-06-04 07:50:27	2020-06-04	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8139	delivery	5	31
72880	2020-06-04 07:51:45	2020-06-04	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	28830	delivery	5	28
72881	2020-06-04 07:53:26	2020-06-04	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	28852	delivery	5	28
72882	2020-06-04 07:53:53	2020-06-04	12	[{"id_menu":1,"count":1}]	1484	pick-up	0	12
72883	2020-06-04 07:54:04	2020-06-04	9	[{"id_menu":7,"count":2}]	28760	pick-up	0	9
72884	2020-06-04 07:54:56	2020-06-04	14	[{"id_menu":2,"count":1}]	24221	delivery	5	19
72885	2020-06-04 08:00:18	2020-06-04	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2959	pick-up	0	26
72886	2020-06-04 08:00:19	2020-06-04	17	[{"id_menu":4,"count":1}]	18607	delivery	5	22
72887	2020-06-04 08:00:28	2020-06-04	17	[{"id_menu":4,"count":1}]	17435	delivery	5	22
72888	2020-06-04 08:09:09	2020-06-04	8	[{"id_menu":5,"count":1}]	2252	pick-up	0	8
72889	2020-06-04 08:11:04	2020-06-04	14	[{"id_menu":2,"count":1}]	1266	pick-up	0	14
72890	2020-06-04 08:18:39	2020-06-04	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	19554	pick-up	0	26
72891	2020-06-04 08:20:31	2020-06-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	26127	delivery	5	28
72892	2020-06-04 08:23:48	2020-06-04	9	[{"id_menu":6,"count":1}]	16339	delivery	5	14
72893	2020-06-04 08:23:51	2020-06-04	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	28770	delivery	5	38
72894	2020-06-04 08:25:16	2020-06-04	12	[{"id_menu":3,"count":1}]	20429	delivery	5	17
72895	2020-06-04 08:27:40	2020-06-04	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2320	pick-up	0	23
72896	2020-06-04 08:31:59	2020-06-04	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	9191	pick-up	0	40
72897	2020-06-04 08:35:13	2020-06-04	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	5494	delivery	5	26
72898	2020-06-04 08:35:58	2020-06-04	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2570	pick-up	0	29
72899	2020-06-04 08:40:57	2020-06-04	8	[{"id_menu":5,"count":1}]	19786	delivery	5	13
72900	2020-06-04 08:43:24	2020-06-04	9	[{"id_menu":6,"count":1}]	5643	pick-up	0	9
72901	2020-06-04 08:48:02	2020-06-04	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18612	delivery	5	23
72902	2020-06-04 08:53:01	2020-06-04	9	[{"id_menu":7,"count":1}]	10945	delivery	5	14
72903	2020-06-04 08:53:08	2020-06-04	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	19432	delivery	5	44
72904	2020-06-04 08:59:19	2020-06-04	17	[{"id_menu":4,"count":1}]	376	pick-up	0	17
72905	2020-06-04 08:59:32	2020-06-04	9	[{"id_menu":7,"count":1}]	28795	pick-up	0	9
72906	2020-06-04 08:59:44	2020-06-04	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	5412	delivery	5	26
72907	2020-06-04 09:13:05	2020-06-04	9	[{"id_menu":7,"count":1}]	12775	delivery	5	14
72908	2020-06-04 09:14:54	2020-06-04	9	[{"id_menu":6,"count":1}]	28872	delivery	5	14
72909	2020-06-04 09:15:19	2020-06-04	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	11182	delivery	5	36
72910	2020-06-04 09:21:06	2020-06-04	14	[{"id_menu":2,"count":1}]	22218	delivery	5	19
72911	2020-06-04 09:22:56	2020-06-04	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	28869	delivery	5	34
72912	2020-06-04 09:27:05	2020-06-04	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	24899	delivery	5	34
72913	2020-06-04 09:28:02	2020-06-04	9	[{"id_menu":7,"count":1}]	27723	delivery	5	14
72914	2020-06-04 09:30:45	2020-06-04	8	[{"id_menu":5,"count":1}]	24946	delivery	5	13
72915	2020-06-04 09:32:25	2020-06-04	14	[{"id_menu":2,"count":1}]	25280	delivery	5	19
72916	2020-06-04 09:33:22	2020-06-04	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	28225	pick-up	0	34
72917	2020-06-04 09:39:35	2020-06-04	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2122	pick-up	0	41
72918	2020-06-04 09:43:11	2020-06-04	9	[{"id_menu":6,"count":1}]	28870	delivery	5	14
72919	2020-06-04 09:46:44	2020-06-04	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7769	pick-up	0	51
72920	2020-06-04 09:47:05	2020-06-04	14	[{"id_menu":2,"count":1}]	14601	pick-up	0	14
72921	2020-06-04 09:53:21	2020-06-04	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28866	delivery	5	22
72922	2020-06-04 09:54:55	2020-06-04	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	28876	pick-up	0	21
72923	2020-06-04 09:55:25	2020-06-04	14	[{"id_menu":2,"count":1}]	2153	pick-up	0	14
72924	2020-06-04 09:55:53	2020-06-04	14	[{"id_menu":2,"count":1}]	24739	delivery	5	19
72925	2020-06-04 09:57:43	2020-06-04	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	16569	delivery	5	34
72926	2020-06-04 10:01:42	2020-06-04	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	4378	delivery	5	34
72927	2020-06-04 10:03:29	2020-06-04	12	[{"id_menu":3,"count":1}]	14984	delivery	5	17
72928	2020-06-04 10:03:47	2020-06-04	9	[{"id_menu":7,"count":1}]	13226	delivery	5	14
72929	2020-06-04 10:06:15	2020-06-04	17	[{"id_menu":4,"count":1}]	17511	delivery	5	22
72930	2020-06-04 10:09:00	2020-06-04	12	[{"id_menu":1,"count":1}]	28858	delivery	5	17
72931	2020-06-04 10:15:55	2020-06-04	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	28761	delivery	5	30
72932	2020-06-04 10:17:14	2020-06-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	28895	pick-up	0	23
72933	2020-06-04 10:17:42	2020-06-04	17	[{"id_menu":4,"count":1}]	2065	delivery	5	22
72934	2020-06-04 10:21:15	2020-06-04	9	[{"id_menu":6,"count":1}]	6612	delivery	5	14
72935	2020-06-04 10:21:43	2020-06-04	14	[{"id_menu":2,"count":1}]	22014	delivery	5	19
72936	2020-06-04 10:24:29	2020-06-04	12	[{"id_menu":3,"count":1}]	28747	delivery	5	17
72937	2020-06-04 10:25:17	2020-06-04	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	28736	delivery	5	35
72938	2020-06-04 10:25:32	2020-06-04	9	[{"id_menu":6,"count":1}]	28799	delivery	5	14
72939	2020-06-04 10:25:58	2020-06-04	9	[{"id_menu":6,"count":1}]	17733	delivery	5	14
72940	2020-06-04 10:26:43	2020-06-04	14	[{"id_menu":2,"count":1}]	17091	delivery	5	19
72941	2020-06-04 10:29:04	2020-06-04	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	11750	delivery	5	44
72942	2020-06-04 10:29:16	2020-06-04	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3331	delivery	5	31
72943	2020-06-04 10:31:42	2020-06-04	9	[{"id_menu":6,"count":1}]	9005	delivery	5	14
72944	2020-06-04 10:36:49	2020-06-04	12	[{"id_menu":1,"count":1}]	18633	delivery	5	17
72945	2020-06-04 10:45:00	2020-06-04	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1343	pick-up	0	26
72946	2020-06-04 10:47:08	2020-06-04	8	[{"id_menu":5,"count":1}]	28882	delivery	5	13
72947	2020-06-04 10:47:34	2020-06-04	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	14103	delivery	5	31
72948	2020-06-04 10:49:34	2020-06-04	14	[{"id_menu":2,"count":1}]	28783	pick-up	0	14
72949	2020-06-04 10:50:13	2020-06-04	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	28892	delivery	5	40
72950	2020-06-04 10:52:18	2020-06-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8716	pick-up	0	23
72951	2020-06-04 10:54:55	2020-06-04	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	28906	delivery	5	40
72952	2020-06-04 10:55:27	2020-06-04	9	[{"id_menu":7,"count":1}]	28087	delivery	5	14
72953	2020-06-04 10:56:31	2020-06-04	9	[{"id_menu":7,"count":1}]	28793	delivery	5	14
72954	2020-06-04 10:56:58	2020-06-04	12	[{"id_menu":3,"count":1}]	28903	pick-up	0	12
72955	2020-06-04 10:58:07	2020-06-04	8	[{"id_menu":5,"count":1}]	11732	pick-up	0	8
72956	2020-06-04 11:04:57	2020-06-04	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	28756	delivery	5	26
72957	2020-06-04 11:05:01	2020-06-04	12	[{"id_menu":1,"count":1}]	28853	delivery	5	17
72958	2020-06-04 11:06:05	2020-06-04	12	[{"id_menu":3,"count":1}]	10087	delivery	5	17
72959	2020-06-04 11:08:40	2020-06-04	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	28805	delivery	5	30
72960	2020-06-04 11:09:50	2020-06-04	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6135	delivery	5	22
72961	2020-06-04 11:10:11	2020-06-04	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	28860	delivery	5	45
72962	2020-06-04 11:17:45	2020-06-04	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	28344	delivery	5	40
72963	2020-06-04 11:29:12	2020-06-04	14	[{"id_menu":2,"count":1}]	28375	delivery	5	19
72964	2020-06-04 11:29:24	2020-06-04	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	28845	delivery	5	31
72965	2020-06-04 11:33:22	2020-06-04	14	[{"id_menu":2,"count":1}]	1155	delivery	5	19
72966	2020-06-04 11:35:49	2020-06-04	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1317	delivery	5	27
72967	2020-06-04 11:36:26	2020-06-04	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	6900	delivery	5	23
72968	2020-06-04 11:43:54	2020-06-04	12	[{"id_menu":3,"count":1}]	21386	pick-up	0	12
72969	2020-06-04 11:44:23	2020-06-04	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	27724	delivery	5	26
72970	2020-06-04 11:44:31	2020-06-04	37	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	16784	delivery	5	42
72971	2020-06-04 11:45:42	2020-06-04	14	[{"id_menu":2,"count":1}]	9429	delivery	5	19
72972	2020-06-04 11:47:19	2020-06-04	17	[{"id_menu":4,"count":1}]	7460	delivery	5	22
72973	2020-06-04 12:02:25	2020-06-04	9	[{"id_menu":6,"count":1}]	6436	delivery	5	14
72974	2020-06-04 12:07:15	2020-06-04	9	[{"id_menu":7,"count":1}]	28834	delivery	5	14
72975	2020-06-04 12:12:56	2020-06-04	9	[{"id_menu":6,"count":1}]	25532	delivery	5	14
72976	2020-06-04 12:14:15	2020-06-04	12	[{"id_menu":3,"count":1}]	2561	pick-up	0	12
72977	2020-06-04 12:15:49	2020-06-04	14	[{"id_menu":2,"count":1}]	28767	delivery	5	19
72978	2020-06-04 12:15:50	2020-06-04	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28873	delivery	5	54
72979	2020-06-04 12:16:36	2020-06-04	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	28839	delivery	5	26
72980	2020-06-04 12:24:32	2020-06-04	17	[{"id_menu":4,"count":1}]	9597	delivery	5	22
72981	2020-06-04 12:25:11	2020-06-04	14	[{"id_menu":2,"count":1}]	28837	delivery	5	19
72982	2020-06-04 12:26:34	2020-06-04	12	[{"id_menu":1,"count":1}]	28896	pick-up	0	12
72983	2020-06-04 12:28:52	2020-06-04	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28738	delivery	5	23
72984	2020-06-04 12:37:19	2020-06-04	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2923	delivery	5	22
72985	2020-06-04 12:48:52	2020-06-04	12	[{"id_menu":1,"count":1}]	28889	delivery	5	17
72986	2020-06-04 12:51:13	2020-06-04	9	[{"id_menu":6,"count":3}]	25159	delivery	5	14
72987	2020-06-04 12:54:41	2020-06-04	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13843	delivery	5	34
72988	2020-06-04 12:55:34	2020-06-04	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	21825	pick-up	0	21
72989	2020-06-04 12:56:36	2020-06-04	8	[{"id_menu":5,"count":1}]	19929	delivery	5	13
72990	2020-06-04 12:57:04	2020-06-04	8	[{"id_menu":5,"count":1}]	28774	delivery	5	13
72991	2020-06-04 12:57:55	2020-06-04	12	[{"id_menu":1,"count":1}]	28827	pick-up	0	12
72992	2020-06-04 13:00:31	2020-06-04	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	6124	delivery	5	25
72993	2020-06-04 13:00:51	2020-06-04	9	[{"id_menu":6,"count":1}]	28907	pick-up	0	9
72994	2020-06-04 13:06:41	2020-06-04	17	[{"id_menu":4,"count":1}]	1255	pick-up	0	17
72995	2020-06-04 13:06:52	2020-06-04	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21499	delivery	5	22
72996	2020-06-04 13:10:34	2020-06-04	9	[{"id_menu":6,"count":1}]	1153	delivery	5	14
72997	2020-06-04 13:11:03	2020-06-04	8	[{"id_menu":5,"count":1}]	23337	delivery	5	13
72998	2020-06-04 13:11:37	2020-06-04	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	28884	delivery	5	31
72999	2020-06-04 13:12:39	2020-06-04	9	[{"id_menu":6,"count":1}]	9743	delivery	5	14
73000	2020-06-04 13:16:45	2020-06-04	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	19946	delivery	5	23
73001	2020-06-04 13:16:46	2020-06-04	17	[{"id_menu":4,"count":1}]	3730	pick-up	0	17
73002	2020-06-04 13:20:38	2020-06-04	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15750	delivery	5	48
73003	2020-06-04 13:25:52	2020-06-04	12	[{"id_menu":1,"count":1}]	2805	delivery	5	17
73004	2020-06-04 13:28:15	2020-06-04	17	[{"id_menu":4,"count":2}]	2903	pick-up	0	17
73005	2020-06-04 13:28:31	2020-06-04	9	[{"id_menu":6,"count":1}]	6162	delivery	5	14
73006	2020-06-04 13:29:09	2020-06-04	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	25895	delivery	5	45
73007	2020-06-04 13:29:29	2020-06-04	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	28828	delivery	5	25
73008	2020-06-04 13:30:42	2020-06-04	17	[{"id_menu":4,"count":1}]	22039	delivery	5	22
73009	2020-06-04 13:32:38	2020-06-04	9	[{"id_menu":7,"count":1}]	23605	delivery	5	14
73010	2020-06-04 13:40:56	2020-06-04	9	[{"id_menu":7,"count":2}]	28868	delivery	5	14
73011	2020-06-04 13:43:50	2020-06-04	12	[{"id_menu":1,"count":1}]	9571	delivery	5	17
73012	2020-06-04 13:45:09	2020-06-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	28914	delivery	5	28
73013	2020-06-04 13:47:05	2020-06-04	17	[{"id_menu":4,"count":1}]	21198	delivery	5	22
73014	2020-06-04 13:47:35	2020-06-04	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28905	delivery	5	31
73015	2020-06-04 13:52:04	2020-06-04	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28754	delivery	5	22
73016	2020-06-04 13:53:51	2020-06-04	17	[{"id_menu":4,"count":1}]	5518	delivery	5	22
73017	2020-06-04 13:54:21	2020-06-04	12	[{"id_menu":3,"count":1}]	256	pick-up	0	12
73018	2020-06-04 13:58:27	2020-06-04	9	[{"id_menu":7,"count":1}]	22720	delivery	5	14
73019	2020-06-04 14:02:15	2020-06-04	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	28748	delivery	5	25
73020	2020-06-04 14:08:43	2020-06-04	12	[{"id_menu":3,"count":1}]	10984	pick-up	0	12
73021	2020-06-04 14:13:04	2020-06-04	12	[{"id_menu":3,"count":2}]	14856	delivery	5	17
73022	2020-06-04 14:22:07	2020-06-04	9	[{"id_menu":6,"count":1}]	11631	delivery	5	14
73023	2020-06-04 14:22:43	2020-06-04	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2076	pick-up	0	29
73024	2020-06-04 14:23:52	2020-06-04	12	[{"id_menu":1,"count":1}]	14002	pick-up	0	12
73025	2020-06-04 14:24:11	2020-06-04	14	[{"id_menu":2,"count":1}]	28749	delivery	5	19
73026	2020-06-04 14:27:12	2020-06-04	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	22523	delivery	5	40
73027	2020-06-04 14:27:22	2020-06-04	8	[{"id_menu":5,"count":1}]	14606	delivery	5	13
73028	2020-06-04 14:27:39	2020-06-04	9	[{"id_menu":6,"count":1}]	2160	pick-up	0	9
73029	2020-06-04 14:28:47	2020-06-04	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	28766	delivery	5	28
73030	2020-06-04 14:29:32	2020-06-04	12	[{"id_menu":3,"count":1}]	14306	pick-up	0	12
73031	2020-06-04 14:32:21	2020-06-04	14	[{"id_menu":2,"count":1}]	20595	delivery	5	19
73032	2020-06-04 14:32:23	2020-06-04	17	[{"id_menu":4,"count":1}]	10828	pick-up	0	17
73033	2020-06-04 14:33:45	2020-06-04	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12992	delivery	5	31
73034	2020-06-04 14:34:38	2020-06-04	9	[{"id_menu":6,"count":1}]	11602	delivery	5	14
73035	2020-06-04 14:36:37	2020-06-04	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7582	pick-up	0	23
73036	2020-06-04 14:39:22	2020-06-04	8	[{"id_menu":5,"count":1}]	20553	delivery	5	13
73037	2020-06-04 14:41:47	2020-06-04	9	[{"id_menu":7,"count":1}]	28786	delivery	5	14
73038	2020-06-04 14:43:45	2020-06-04	12	[{"id_menu":1,"count":1}]	23356	delivery	5	17
73039	2020-06-04 14:53:13	2020-06-04	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	3645	delivery	5	22
73040	2020-06-04 14:54:08	2020-06-04	8	[{"id_menu":5,"count":1}]	28874	delivery	5	13
73041	2020-06-04 14:54:45	2020-06-04	9	[{"id_menu":6,"count":1}]	15022	delivery	5	14
73042	2020-06-04 14:58:11	2020-06-04	12	[{"id_menu":3,"count":1}]	28773	delivery	5	17
73043	2020-06-04 15:05:02	2020-06-04	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	28913	delivery	5	40
73044	2020-06-04 15:05:29	2020-06-04	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	28737	delivery	5	40
73045	2020-06-04 15:11:25	2020-06-04	9	[{"id_menu":6,"count":1}]	4634	delivery	5	14
73046	2020-06-04 15:12:57	2020-06-04	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1509	pick-up	0	29
73047	2020-06-04 15:14:25	2020-06-04	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	28074	pick-up	0	26
73048	2020-06-04 15:15:44	2020-06-04	17	[{"id_menu":4,"count":1}]	9873	delivery	5	22
73049	2020-06-04 15:17:06	2020-06-04	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	13529	pick-up	0	43
73050	2020-06-04 15:18:08	2020-06-04	12	[{"id_menu":1,"count":1}]	27332	pick-up	0	12
73051	2020-06-04 15:27:11	2020-06-04	17	[{"id_menu":4,"count":1}]	14028	delivery	5	22
73052	2020-06-04 15:27:14	2020-06-04	8	[{"id_menu":5,"count":1}]	28818	delivery	5	13
73053	2020-06-04 15:32:09	2020-06-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	5678	delivery	5	28
73054	2020-06-04 15:34:58	2020-06-04	17	[{"id_menu":4,"count":1}]	18758	pick-up	0	17
73055	2020-06-04 15:36:38	2020-06-04	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	757	delivery	5	31
73056	2020-06-04 15:38:06	2020-06-04	14	[{"id_menu":2,"count":1}]	136	delivery	5	19
73057	2020-06-04 15:39:03	2020-06-04	9	[{"id_menu":7,"count":1}]	28755	delivery	5	14
73058	2020-06-04 15:41:46	2020-06-04	12	[{"id_menu":3,"count":1}]	28911	delivery	5	17
73059	2020-06-04 15:43:38	2020-06-04	9	[{"id_menu":7,"count":1}]	1618	pick-up	0	9
73060	2020-06-04 15:43:39	2020-06-04	12	[{"id_menu":1,"count":1}]	19907	delivery	5	17
73061	2020-06-04 15:47:18	2020-06-04	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	21019	delivery	5	45
73062	2020-06-04 15:49:20	2020-06-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6020	delivery	5	28
73063	2020-06-04 15:49:54	2020-06-04	9	[{"id_menu":7,"count":1}]	16088	delivery	5	14
73064	2020-06-04 15:54:08	2020-06-04	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	17534	delivery	5	28
73065	2020-06-04 15:54:13	2020-06-04	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":3}]	8524	delivery	5	26
73066	2020-06-04 16:06:44	2020-06-04	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	28899	delivery	5	48
73067	2020-06-04 16:07:12	2020-06-04	9	[{"id_menu":6,"count":1}]	17630	delivery	5	14
73068	2020-06-04 16:07:41	2020-06-04	12	[{"id_menu":3,"count":1}]	8188	delivery	5	17
73069	2020-06-04 16:07:51	2020-06-04	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	11684	delivery	5	28
73070	2020-06-04 16:08:24	2020-06-04	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	23856	delivery	5	22
73071	2020-06-04 16:09:38	2020-06-04	39	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10120	delivery	5	44
73072	2020-06-04 16:11:58	2020-06-04	14	[{"id_menu":2,"count":1}]	28820	pick-up	0	14
73073	2020-06-04 16:13:16	2020-06-04	9	[{"id_menu":7,"count":1}]	28900	delivery	5	14
73074	2020-06-04 16:13:56	2020-06-04	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	28752	pick-up	0	26
73075	2020-06-04 16:18:37	2020-06-04	9	[{"id_menu":6,"count":1}]	10474	delivery	5	14
73076	2020-06-04 16:19:32	2020-06-04	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1293	delivery	5	48
73077	2020-06-04 16:23:41	2020-06-04	14	[{"id_menu":2,"count":1}]	15027	delivery	5	19
73078	2020-06-04 16:26:07	2020-06-04	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28800	delivery	5	35
73079	2020-06-04 16:29:11	2020-06-04	12	[{"id_menu":3,"count":2}]	11752	pick-up	0	12
73080	2020-06-04 16:30:29	2020-06-04	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	28768	delivery	5	27
73081	2020-06-04 16:30:38	2020-06-04	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	11969	pick-up	0	21
73082	2020-06-04 16:32:56	2020-06-04	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	8762	delivery	5	38
73083	2020-06-04 16:42:23	2020-06-04	9	[{"id_menu":7,"count":1}]	28802	delivery	5	14
73084	2020-06-04 16:42:53	2020-06-04	14	[{"id_menu":2,"count":1}]	3207	pick-up	0	14
73085	2020-06-04 16:44:49	2020-06-04	9	[{"id_menu":7,"count":1}]	17409	delivery	5	14
73086	2020-06-04 16:45:19	2020-06-04	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	27695	pick-up	0	18
73087	2020-06-04 16:46:48	2020-06-04	12	[{"id_menu":1,"count":1}]	7019	pick-up	0	12
73088	2020-06-04 16:47:29	2020-06-04	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	28838	delivery	5	26
73089	2020-06-04 16:49:25	2020-06-04	14	[{"id_menu":2,"count":1}]	28822	delivery	5	19
73090	2020-06-04 16:55:29	2020-06-04	12	[{"id_menu":1,"count":1}]	1000	pick-up	0	12
73091	2020-06-04 17:02:04	2020-06-04	9	[{"id_menu":7,"count":1}]	601	delivery	5	14
73092	2020-06-04 17:07:19	2020-06-04	14	[{"id_menu":2,"count":1}]	655	pick-up	0	14
73093	2020-06-04 17:08:18	2020-06-04	8	[{"id_menu":5,"count":1}]	12854	delivery	5	13
73094	2020-06-04 17:13:16	2020-06-04	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6140	delivery	5	22
73095	2020-06-04 17:13:51	2020-06-04	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	13874	pick-up	0	31
73096	2020-06-04 17:18:07	2020-06-04	9	[{"id_menu":7,"count":1}]	1376	pick-up	0	9
73097	2020-06-04 17:23:05	2020-06-04	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	14881	delivery	5	36
73098	2020-06-04 17:24:34	2020-06-04	8	[{"id_menu":5,"count":1}]	28894	delivery	5	13
73099	2020-06-04 17:26:55	2020-06-04	17	[{"id_menu":4,"count":1}]	28844	pick-up	0	17
73100	2020-06-04 17:29:58	2020-06-04	9	[{"id_menu":7,"count":1}]	1830	delivery	5	14
73101	2020-06-04 17:31:18	2020-06-04	12	[{"id_menu":3,"count":1}]	28921	delivery	5	17
73102	2020-06-04 17:35:12	2020-06-04	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	28734	delivery	5	27
73103	2020-06-04 17:36:15	2020-06-04	12	[{"id_menu":3,"count":1}]	28739	delivery	5	17
73104	2020-06-04 17:39:42	2020-06-04	9	[{"id_menu":6,"count":1}]	28048	delivery	5	14
73105	2020-06-04 17:49:15	2020-06-04	9	[{"id_menu":7,"count":1}]	16864	pick-up	0	9
73106	2020-06-04 17:50:13	2020-06-04	17	[{"id_menu":4,"count":1}]	2575	pick-up	0	17
73107	2020-06-04 17:50:19	2020-06-04	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	6684	delivery	5	27
73108	2020-06-04 17:50:24	2020-06-04	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8101	delivery	5	39
73109	2020-06-04 17:54:16	2020-06-04	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	28893	delivery	5	43
73110	2020-06-04 17:56:54	2020-06-04	9	[{"id_menu":6,"count":1}]	28315	delivery	5	14
73111	2020-06-04 17:57:04	2020-06-04	14	[{"id_menu":2,"count":1}]	8900	pick-up	0	14
73112	2020-06-04 17:58:30	2020-06-04	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":2}]	13987	delivery	5	22
73113	2020-06-04 18:00:00	2020-06-04	12	[{"id_menu":3,"count":1}]	4876	delivery	5	17
73114	2020-06-04 18:03:39	2020-06-04	8	[{"id_menu":5,"count":1}]	28885	delivery	5	13
73115	2020-06-04 18:05:36	2020-06-04	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	28840	delivery	5	26
73116	2020-06-04 18:07:41	2020-06-04	8	[{"id_menu":5,"count":1}]	26741	delivery	5	13
73117	2020-06-04 18:07:45	2020-06-04	9	[{"id_menu":7,"count":1}]	2434	pick-up	0	9
73118	2020-06-04 18:09:08	2020-06-04	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	9040	pick-up	0	26
73119	2020-06-04 18:11:19	2020-06-04	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	19502	delivery	5	39
73120	2020-06-04 18:13:31	2020-06-04	17	[{"id_menu":4,"count":1}]	28923	delivery	5	22
73121	2020-06-04 18:22:50	2020-06-04	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11038	delivery	5	22
73122	2020-06-04 18:23:17	2020-06-04	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2485	pick-up	0	23
73123	2020-06-04 18:23:32	2020-06-04	9	[{"id_menu":6,"count":2}]	28745	delivery	5	14
73124	2020-06-04 18:27:33	2020-06-04	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	28759	delivery	5	38
73125	2020-06-04 18:28:09	2020-06-04	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28848	delivery	5	37
73126	2020-06-04 18:28:22	2020-06-04	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	28832	delivery	5	38
73127	2020-06-04 18:37:31	2020-06-04	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	26101	delivery	5	26
73128	2020-06-04 18:41:48	2020-06-04	14	[{"id_menu":2,"count":1}]	11624	delivery	5	19
73129	2020-06-04 18:42:43	2020-06-04	9	[{"id_menu":7,"count":1}]	28881	delivery	5	14
73130	2020-06-04 18:44:05	2020-06-04	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	28777	pick-up	0	21
73131	2020-06-04 18:44:43	2020-06-04	14	[{"id_menu":2,"count":1}]	5503	pick-up	0	14
73132	2020-06-04 18:49:08	2020-06-04	9	[{"id_menu":6,"count":1}]	28798	delivery	5	14
73133	2020-06-04 18:52:59	2020-06-04	14	[{"id_menu":2,"count":1}]	8471	pick-up	0	14
73134	2020-06-04 18:55:47	2020-06-04	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28746	delivery	5	35
73135	2020-06-04 19:00:24	2020-06-04	12	[{"id_menu":1,"count":1}]	24089	delivery	5	17
73136	2020-06-04 19:02:04	2020-06-04	12	[{"id_menu":3,"count":1}]	54	pick-up	0	12
73137	2020-06-04 19:03:44	2020-06-04	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	23610	delivery	5	26
73138	2020-06-04 19:06:35	2020-06-04	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	9277	delivery	5	23
73139	2020-06-04 19:09:22	2020-06-04	9	[{"id_menu":6,"count":1}]	16224	delivery	5	14
73140	2020-06-04 19:13:08	2020-06-04	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	23939	pick-up	0	26
73141	2020-06-04 19:13:26	2020-06-04	12	[{"id_menu":1,"count":2}]	8963	delivery	5	17
73142	2020-06-04 19:15:49	2020-06-04	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	11495	delivery	5	27
73143	2020-06-04 19:17:21	2020-06-04	12	[{"id_menu":3,"count":1}]	7388	delivery	5	17
73144	2020-06-04 19:17:28	2020-06-04	8	[{"id_menu":5,"count":1}]	28797	delivery	5	13
73145	2020-06-04 19:24:24	2020-06-04	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	310	pick-up	0	30
73146	2020-06-04 19:27:55	2020-06-04	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	12210	delivery	5	23
73147	2020-06-04 19:29:18	2020-06-04	12	[{"id_menu":3,"count":1}]	28835	pick-up	0	12
73148	2020-06-04 19:30:09	2020-06-04	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17656	delivery	5	36
73149	2020-06-04 19:32:24	2020-06-04	9	[{"id_menu":6,"count":1}]	28803	delivery	5	14
73150	2020-06-04 19:34:36	2020-06-04	8	[{"id_menu":5,"count":1}]	6179	delivery	5	13
73151	2020-06-04 19:39:37	2020-06-04	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	28784	delivery	5	38
73152	2020-06-04 19:39:39	2020-06-04	14	[{"id_menu":2,"count":1}]	15683	pick-up	0	14
73153	2020-06-04 19:39:59	2020-06-04	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	28801	delivery	5	34
73154	2020-06-04 19:40:29	2020-06-04	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3444	delivery	5	36
73155	2020-06-04 19:46:00	2020-06-04	8	[{"id_menu":5,"count":1}]	7361	pick-up	0	8
73156	2020-06-04 19:50:14	2020-06-04	8	[{"id_menu":5,"count":1}]	12282	delivery	5	13
73157	2020-06-04 19:58:19	2020-06-04	12	[{"id_menu":3,"count":1}]	16792	delivery	5	17
73158	2020-06-04 20:02:21	2020-06-04	8	[{"id_menu":5,"count":1}]	28919	delivery	5	13
73159	2020-06-04 20:03:57	2020-06-04	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11373	delivery	5	37
73160	2020-06-04 20:04:24	2020-06-04	9	[{"id_menu":6,"count":2}]	16091	delivery	5	14
73161	2020-06-04 20:06:23	2020-06-04	12	[{"id_menu":3,"count":1}]	10153	pick-up	0	12
73162	2020-06-04 20:07:18	2020-06-04	9	[{"id_menu":6,"count":1}]	17342	delivery	5	14
73163	2020-06-04 20:12:42	2020-06-04	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	12236	delivery	5	31
73164	2020-06-04 20:14:59	2020-06-04	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	236	pick-up	0	26
73165	2020-06-04 20:15:26	2020-06-04	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	6232	delivery	5	26
73166	2020-06-04 20:20:02	2020-06-04	14	[{"id_menu":2,"count":1}]	3161	delivery	5	19
73167	2020-06-04 20:21:54	2020-06-04	9	[{"id_menu":7,"count":1}]	6399	pick-up	0	9
73168	2020-06-04 20:24:50	2020-06-04	17	[{"id_menu":4,"count":2}]	4120	delivery	5	22
73169	2020-06-04 20:25:37	2020-06-04	9	[{"id_menu":6,"count":1}]	6695	delivery	5	14
73170	2020-06-04 20:25:49	2020-06-04	9	[{"id_menu":6,"count":1}]	14449	delivery	5	14
73171	2020-06-04 20:25:54	2020-06-04	12	[{"id_menu":1,"count":1}]	22840	delivery	5	17
73172	2020-06-04 20:25:59	2020-06-04	8	[{"id_menu":5,"count":1}]	10676	delivery	5	13
73173	2020-06-04 20:26:17	2020-06-04	14	[{"id_menu":2,"count":1}]	832	pick-up	0	14
73174	2020-06-04 20:28:17	2020-06-04	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	21831	delivery	5	27
73175	2020-06-04 20:29:20	2020-06-04	9	[{"id_menu":7,"count":1}]	10045	delivery	5	14
73176	2020-06-04 20:38:05	2020-06-04	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	227	pick-up	0	29
73177	2020-06-04 20:42:18	2020-06-04	9	[{"id_menu":6,"count":1}]	28851	delivery	5	14
73178	2020-06-04 20:42:42	2020-06-04	9	[{"id_menu":6,"count":1}]	20671	delivery	5	14
73179	2020-06-04 20:48:59	2020-06-04	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23805	delivery	5	31
73180	2020-06-04 20:49:40	2020-06-04	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5047	pick-up	0	23
73181	2020-06-04 21:04:42	2020-06-04	9	[{"id_menu":7,"count":1}]	13613	pick-up	0	9
73182	2020-06-04 21:06:58	2020-06-04	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22156	delivery	5	31
73183	2020-06-04 21:19:08	2020-06-04	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	28789	delivery	5	43
73184	2020-06-04 21:20:40	2020-06-04	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	28856	delivery	5	27
73185	2020-06-04 21:20:42	2020-06-04	8	[{"id_menu":5,"count":1}]	26428	pick-up	0	8
73186	2020-06-04 21:22:01	2020-06-04	8	[{"id_menu":5,"count":1}]	28764	delivery	5	13
73187	2020-06-04 21:30:08	2020-06-04	14	[{"id_menu":2,"count":1}]	2080	pick-up	0	14
73188	2020-06-04 21:30:46	2020-06-04	9	[{"id_menu":6,"count":1}]	28779	delivery	5	14
73189	2020-06-04 21:34:09	2020-06-04	8	[{"id_menu":5,"count":1}]	11115	delivery	5	13
73190	2020-06-04 21:37:41	2020-06-04	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	26217	delivery	5	45
73191	2020-06-04 21:40:17	2020-06-04	12	[{"id_menu":3,"count":1}]	10576	delivery	5	17
73192	2020-06-04 21:42:18	2020-06-04	14	[{"id_menu":2,"count":1}]	28771	delivery	5	19
73193	2020-06-04 21:45:51	2020-06-04	12	[{"id_menu":3,"count":1}]	6006	delivery	5	17
73194	2020-06-04 21:46:25	2020-06-04	9	[{"id_menu":6,"count":1}]	8363	pick-up	0	9
73195	2020-06-04 21:52:33	2020-06-04	12	[{"id_menu":1,"count":1}]	28170	delivery	5	17
73196	2020-06-04 21:54:52	2020-06-04	9	[{"id_menu":6,"count":1}]	15025	delivery	5	14
73197	2020-06-04 21:55:36	2020-06-04	14	[{"id_menu":2,"count":1}]	1431	delivery	5	19
73198	2020-06-04 22:04:19	2020-06-04	17	[{"id_menu":4,"count":1}]	28787	pick-up	0	17
73199	2020-06-04 22:04:37	2020-06-04	9	[{"id_menu":6,"count":1}]	12104	delivery	5	14
73200	2020-06-04 22:06:19	2020-06-04	17	[{"id_menu":4,"count":1}]	28883	delivery	5	22
73201	2020-06-04 22:09:24	2020-06-04	17	[{"id_menu":4,"count":1}]	28887	pick-up	0	17
73202	2020-06-04 22:09:51	2020-06-04	14	[{"id_menu":2,"count":1}]	11527	delivery	5	19
73203	2020-06-04 22:11:41	2020-06-04	12	[{"id_menu":1,"count":1}]	498	delivery	5	17
73204	2020-06-04 22:11:55	2020-06-04	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24301	delivery	5	34
73205	2020-06-04 22:12:39	2020-06-04	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	18078	delivery	5	40
73206	2020-06-04 22:13:30	2020-06-04	9	[{"id_menu":6,"count":1}]	3273	delivery	5	14
73207	2020-06-04 22:30:22	2020-06-04	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28765	delivery	5	35
73208	2020-06-04 22:31:06	2020-06-04	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10281	pick-up	0	49
73209	2020-06-04 22:34:14	2020-06-04	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	20894	delivery	5	31
73210	2020-06-04 22:40:53	2020-06-04	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8385	delivery	5	34
73211	2020-06-04 22:42:59	2020-06-04	12	[{"id_menu":3,"count":1}]	2207	pick-up	0	12
73212	2020-06-04 22:47:18	2020-06-04	17	[{"id_menu":4,"count":1}]	8098	pick-up	0	17
73213	2020-06-04 22:48:48	2020-06-04	9	[{"id_menu":7,"count":1}]	25507	delivery	5	14
73214	2020-06-04 22:49:15	2020-06-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	9232	delivery	5	28
73215	2020-06-04 22:49:33	2020-06-04	12	[{"id_menu":3,"count":1}]	1727	pick-up	0	12
73216	2020-06-04 22:50:25	2020-06-04	9	[{"id_menu":6,"count":1}]	5423	delivery	5	14
73217	2020-06-04 22:53:15	2020-06-04	9	[{"id_menu":7,"count":1}]	6919	delivery	5	14
73218	2020-06-04 22:54:57	2020-06-04	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	9554	delivery	5	26
73219	2020-06-04 22:56:00	2020-06-04	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	28918	delivery	5	30
73220	2020-06-04 22:58:19	2020-06-04	8	[{"id_menu":5,"count":1}]	3102	pick-up	0	8
73221	2020-06-04 23:03:15	2020-06-04	9	[{"id_menu":7,"count":1}]	20485	delivery	5	14
73222	2020-06-04 23:05:07	2020-06-04	14	[{"id_menu":2,"count":1}]	7200	pick-up	0	14
73223	2020-06-04 23:05:59	2020-06-04	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	28812	delivery	5	40
73224	2020-06-04 23:06:56	2020-06-04	12	[{"id_menu":3,"count":1}]	28781	delivery	5	17
73225	2020-06-04 23:08:12	2020-06-04	12	[{"id_menu":3,"count":1}]	24122	pick-up	0	12
73226	2020-06-04 23:10:33	2020-06-04	9	[{"id_menu":7,"count":2}]	14015	delivery	5	14
73227	2020-06-04 23:13:46	2020-06-04	17	[{"id_menu":4,"count":1}]	26373	pick-up	0	17
73228	2020-06-04 23:22:27	2020-06-04	12	[{"id_menu":3,"count":1}]	19287	pick-up	0	12
73229	2020-06-04 23:32:37	2020-06-04	9	[{"id_menu":6,"count":1}]	28850	pick-up	0	9
73230	2020-06-04 23:35:30	2020-06-04	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2055	pick-up	0	26
73231	2020-06-04 23:39:23	2020-06-04	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	7217	delivery	5	26
73232	2020-06-04 23:40:09	2020-06-04	9	[{"id_menu":7,"count":1}]	19523	delivery	5	14
73233	2020-06-04 23:42:53	2020-06-04	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	21273	pick-up	0	20
73234	2020-06-04 23:44:07	2020-06-04	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10002	delivery	5	37
73235	2020-06-04 23:47:04	2020-06-04	9	[{"id_menu":6,"count":1}]	24900	delivery	5	14
73236	2020-06-04 23:48:06	2020-06-04	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	28865	delivery	5	34
73237	2020-06-04 23:49:23	2020-06-04	17	[{"id_menu":4,"count":1}]	28811	delivery	5	22
73238	2020-06-04 23:52:02	2020-06-04	14	[{"id_menu":2,"count":1}]	28842	delivery	5	19
73239	2020-06-04 23:53:49	2020-06-04	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10519	delivery	5	31
73240	2020-06-04 23:56:07	2020-06-04	17	[{"id_menu":4,"count":1}]	12952	delivery	5	22
73241	2020-06-04 23:59:23	2020-06-04	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	28751	delivery	5	36
73242	2020-06-05 00:02:17	2020-06-05	9	[{"id_menu":6,"count":1}]	29056	delivery	5	14
73243	2020-06-05 00:05:47	2020-06-05	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	29073	delivery	5	26
73244	2020-06-05 00:06:00	2020-06-05	9	[{"id_menu":6,"count":1}]	29085	delivery	5	14
73245	2020-06-05 00:08:08	2020-06-05	9	[{"id_menu":6,"count":1}]	27248	delivery	5	14
73246	2020-06-05 00:13:12	2020-06-05	12	[{"id_menu":1,"count":2}]	8717	delivery	5	17
73247	2020-06-05 00:24:12	2020-06-05	17	[{"id_menu":4,"count":1}]	28990	delivery	5	22
73248	2020-06-05 00:26:48	2020-06-05	9	[{"id_menu":6,"count":1}]	28967	delivery	5	14
73249	2020-06-05 00:32:32	2020-06-05	14	[{"id_menu":2,"count":1}]	28994	delivery	5	19
73250	2020-06-05 00:34:14	2020-06-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20846	delivery	5	22
73251	2020-06-05 00:50:06	2020-06-05	9	[{"id_menu":7,"count":1}]	19657	delivery	5	14
73252	2020-06-05 00:52:59	2020-06-05	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	29156	delivery	5	30
73253	2020-06-05 00:53:10	2020-06-05	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	28947	delivery	5	22
73254	2020-06-05 00:55:47	2020-06-05	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29121	delivery	5	45
73255	2020-06-05 00:57:40	2020-06-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29071	delivery	5	23
73256	2020-06-05 01:03:13	2020-06-05	17	[{"id_menu":4,"count":1}]	23491	delivery	5	22
73257	2020-06-05 01:06:28	2020-06-05	9	[{"id_menu":7,"count":1}]	14578	pick-up	0	9
73258	2020-06-05 01:14:33	2020-06-05	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29114	delivery	5	43
73259	2020-06-05 01:17:41	2020-06-05	14	[{"id_menu":2,"count":2}]	10273	delivery	5	19
73260	2020-06-05 01:20:20	2020-06-05	14	[{"id_menu":2,"count":1}]	27664	delivery	5	19
73261	2020-06-05 01:21:24	2020-06-05	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	29028	delivery	5	30
73262	2020-06-05 01:25:12	2020-06-05	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	29103	delivery	5	34
73263	2020-06-05 01:25:15	2020-06-05	9	[{"id_menu":6,"count":1}]	17589	delivery	5	14
73264	2020-06-05 01:30:48	2020-06-05	17	[{"id_menu":4,"count":1}]	3230	delivery	5	22
73265	2020-06-05 01:30:48	2020-06-05	9	[{"id_menu":7,"count":1}]	3085	pick-up	0	9
73266	2020-06-05 01:36:48	2020-06-05	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":2}]	20138	delivery	5	22
73267	2020-06-05 01:42:16	2020-06-05	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	837	pick-up	0	40
73268	2020-06-05 01:44:22	2020-06-05	9	[{"id_menu":6,"count":1}]	18597	delivery	5	14
73269	2020-06-05 02:00:36	2020-06-05	8	[{"id_menu":5,"count":1}]	12838	delivery	5	13
73270	2020-06-05 02:01:30	2020-06-05	9	[{"id_menu":7,"count":1}]	15829	pick-up	0	9
73271	2020-06-05 02:02:18	2020-06-05	9	[{"id_menu":6,"count":1}]	3388	delivery	5	14
73272	2020-06-05 02:03:45	2020-06-05	9	[{"id_menu":7,"count":1}]	2980	delivery	5	14
73273	2020-06-05 02:04:16	2020-06-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28962	delivery	5	22
73274	2020-06-05 02:04:21	2020-06-05	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	9480	delivery	5	26
73275	2020-06-05 02:08:35	2020-06-05	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	18211	delivery	5	40
73276	2020-06-05 02:13:17	2020-06-05	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	29067	delivery	5	26
73277	2020-06-05 02:16:25	2020-06-05	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28986	delivery	5	35
73278	2020-06-05 02:16:35	2020-06-05	17	[{"id_menu":4,"count":1}]	3385	pick-up	0	17
73279	2020-06-05 02:17:45	2020-06-05	17	[{"id_menu":4,"count":1}]	12183	pick-up	0	17
73280	2020-06-05 02:17:47	2020-06-05	9	[{"id_menu":7,"count":1}]	19971	delivery	5	14
73281	2020-06-05 02:21:25	2020-06-05	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	16550	pick-up	0	23
73282	2020-06-05 02:22:58	2020-06-05	12	[{"id_menu":1,"count":1}]	13582	delivery	5	17
73283	2020-06-05 02:25:41	2020-06-05	9	[{"id_menu":6,"count":1}]	11921	delivery	5	14
73284	2020-06-05 02:35:08	2020-06-05	17	[{"id_menu":4,"count":1}]	28929	pick-up	0	17
73285	2020-06-05 02:49:35	2020-06-05	9	[{"id_menu":6,"count":1}]	17353	delivery	5	14
73286	2020-06-05 02:49:39	2020-06-05	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28984	delivery	5	36
73287	2020-06-05 02:53:12	2020-06-05	8	[{"id_menu":5,"count":1}]	13707	delivery	5	13
73288	2020-06-05 02:55:14	2020-06-05	9	[{"id_menu":6,"count":1}]	23185	pick-up	0	9
73289	2020-06-05 02:57:35	2020-06-05	12	[{"id_menu":3,"count":1}]	6208	delivery	5	17
73290	2020-06-05 02:58:16	2020-06-05	9	[{"id_menu":7,"count":1}]	14067	delivery	5	14
73291	2020-06-05 02:59:20	2020-06-05	17	[{"id_menu":4,"count":1}]	16270	pick-up	0	17
73292	2020-06-05 03:01:57	2020-06-05	8	[{"id_menu":5,"count":1}]	6898	delivery	5	13
73293	2020-06-05 03:02:04	2020-06-05	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	27567	delivery	5	26
73294	2020-06-05 03:04:38	2020-06-05	12	[{"id_menu":3,"count":1}]	4486	pick-up	0	12
73295	2020-06-05 03:10:09	2020-06-05	12	[{"id_menu":3,"count":1}]	1765	pick-up	0	12
73296	2020-06-05 03:14:11	2020-06-05	9	[{"id_menu":6,"count":3}]	15790	delivery	5	14
73297	2020-06-05 03:18:53	2020-06-05	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29026	delivery	5	37
73298	2020-06-05 03:24:29	2020-06-05	8	[{"id_menu":5,"count":1}]	12724	delivery	5	13
73299	2020-06-05 03:25:23	2020-06-05	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	29117	delivery	5	36
73300	2020-06-05 03:28:39	2020-06-05	9	[{"id_menu":6,"count":1}]	3634	pick-up	0	9
73301	2020-06-05 03:28:45	2020-06-05	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	10191	delivery	5	28
73302	2020-06-05 03:29:10	2020-06-05	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	5255	pick-up	0	17
73303	2020-06-05 03:34:58	2020-06-05	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	26993	delivery	5	43
73304	2020-06-05 03:35:31	2020-06-05	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11903	delivery	5	36
73305	2020-06-05 03:37:18	2020-06-05	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3842	pick-up	0	26
73306	2020-06-05 03:51:35	2020-06-05	9	[{"id_menu":6,"count":1}]	29129	delivery	5	14
73307	2020-06-05 03:56:06	2020-06-05	9	[{"id_menu":7,"count":1}]	27557	pick-up	0	9
73308	2020-06-05 03:57:25	2020-06-05	17	[{"id_menu":4,"count":1}]	28948	delivery	5	22
73309	2020-06-05 03:58:52	2020-06-05	8	[{"id_menu":5,"count":1}]	11849	delivery	5	13
73310	2020-06-05 04:03:31	2020-06-05	9	[{"id_menu":6,"count":1}]	5319	delivery	5	14
73311	2020-06-05 04:03:44	2020-06-05	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3260	pick-up	0	31
73312	2020-06-05 04:05:20	2020-06-05	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	29042	pick-up	0	40
73313	2020-06-05 04:06:15	2020-06-05	9	[{"id_menu":7,"count":1}]	29093	pick-up	0	9
73314	2020-06-05 04:07:14	2020-06-05	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	28998	delivery	5	31
73315	2020-06-05 04:09:51	2020-06-05	9	[{"id_menu":7,"count":1}]	29015	delivery	5	14
73316	2020-06-05 04:13:15	2020-06-05	17	[{"id_menu":4,"count":1}]	6091	pick-up	0	17
73317	2020-06-05 04:17:43	2020-06-05	12	[{"id_menu":1,"count":1}]	996	pick-up	0	12
73318	2020-06-05 04:18:30	2020-06-05	9	[{"id_menu":6,"count":1}]	6369	pick-up	0	9
73319	2020-06-05 04:20:10	2020-06-05	12	[{"id_menu":1,"count":1}]	12167	delivery	5	17
73320	2020-06-05 04:21:49	2020-06-05	9	[{"id_menu":6,"count":1}]	3366	pick-up	0	9
73321	2020-06-05 04:23:13	2020-06-05	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	7576	delivery	5	31
73322	2020-06-05 04:24:07	2020-06-05	8	[{"id_menu":5,"count":1}]	29118	delivery	5	13
73323	2020-06-05 04:26:11	2020-06-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16574	pick-up	0	17
73324	2020-06-05 04:34:38	2020-06-05	9	[{"id_menu":6,"count":1}]	28927	pick-up	0	9
73325	2020-06-05 04:35:07	2020-06-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3072	pick-up	0	18
73326	2020-06-05 04:42:05	2020-06-05	17	[{"id_menu":4,"count":1}]	15613	delivery	5	22
73327	2020-06-05 04:43:53	2020-06-05	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	28952	pick-up	0	35
73328	2020-06-05 04:47:01	2020-06-05	9	[{"id_menu":7,"count":1}]	28601	delivery	5	14
73329	2020-06-05 04:48:32	2020-06-05	9	[{"id_menu":7,"count":1}]	29170	delivery	5	14
73330	2020-06-05 04:50:13	2020-06-05	55	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	28931	delivery	5	60
73331	2020-06-05 04:50:54	2020-06-05	17	[{"id_menu":4,"count":1}]	19277	pick-up	0	17
73332	2020-06-05 04:54:05	2020-06-05	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	5507	delivery	5	37
73333	2020-06-05 04:56:30	2020-06-05	8	[{"id_menu":5,"count":3}]	23875	delivery	5	13
73334	2020-06-05 04:58:46	2020-06-05	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28939	delivery	5	39
73335	2020-06-05 04:59:16	2020-06-05	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5149	pick-up	0	38
73336	2020-06-05 05:01:42	2020-06-05	12	[{"id_menu":1,"count":1}]	14695	delivery	5	17
73337	2020-06-05 05:03:35	2020-06-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28936	delivery	5	23
73338	2020-06-05 05:07:21	2020-06-05	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	14178	delivery	5	26
73339	2020-06-05 05:08:00	2020-06-05	8	[{"id_menu":5,"count":1}]	1409	pick-up	0	8
73340	2020-06-05 05:14:17	2020-06-05	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	23268	delivery	5	40
73341	2020-06-05 05:16:26	2020-06-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	29167	delivery	5	28
73342	2020-06-05 05:18:43	2020-06-05	17	[{"id_menu":4,"count":1}]	28973	pick-up	0	17
73343	2020-06-05 05:19:02	2020-06-05	9	[{"id_menu":6,"count":1}]	29020	delivery	5	14
73344	2020-06-05 05:19:04	2020-06-05	9	[{"id_menu":6,"count":1}]	24647	delivery	5	14
73345	2020-06-05 05:31:57	2020-06-05	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28970	delivery	5	48
73346	2020-06-05 05:32:25	2020-06-05	8	[{"id_menu":5,"count":1}]	2799	pick-up	0	8
73347	2020-06-05 05:35:57	2020-06-05	9	[{"id_menu":7,"count":1}]	29165	delivery	5	14
73348	2020-06-05 05:40:57	2020-06-05	14	[{"id_menu":2,"count":1}]	8234	delivery	5	19
73349	2020-06-05 05:41:35	2020-06-05	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	29060	delivery	5	26
73350	2020-06-05 05:42:32	2020-06-05	9	[{"id_menu":6,"count":1}]	19806	pick-up	0	9
73351	2020-06-05 05:48:02	2020-06-05	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	27870	pick-up	0	29
73352	2020-06-05 05:50:49	2020-06-05	9	[{"id_menu":6,"count":1}]	28995	delivery	5	14
73353	2020-06-05 05:51:06	2020-06-05	17	[{"id_menu":4,"count":1}]	22314	delivery	5	22
73354	2020-06-05 05:52:11	2020-06-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	28933	delivery	5	31
73355	2020-06-05 05:53:24	2020-06-05	14	[{"id_menu":2,"count":1}]	5933	delivery	5	19
73356	2020-06-05 06:02:03	2020-06-05	9	[{"id_menu":6,"count":1}]	2000	delivery	5	14
73357	2020-06-05 06:06:59	2020-06-05	17	[{"id_menu":4,"count":1}]	9376	delivery	5	22
73358	2020-06-05 06:07:17	2020-06-05	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	14566	delivery	5	28
73359	2020-06-05 06:08:46	2020-06-05	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	13148	pick-up	0	29
73360	2020-06-05 06:12:52	2020-06-05	12	[{"id_menu":3,"count":1}]	20494	delivery	5	17
73361	2020-06-05 06:13:47	2020-06-05	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	29107	delivery	5	45
73362	2020-06-05 06:14:40	2020-06-05	9	[{"id_menu":6,"count":1}]	27761	delivery	5	14
73363	2020-06-05 06:22:20	2020-06-05	12	[{"id_menu":1,"count":1}]	17500	pick-up	0	12
73364	2020-06-05 06:23:39	2020-06-05	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	10840	pick-up	0	31
73365	2020-06-05 06:25:24	2020-06-05	12	[{"id_menu":1,"count":1}]	16426	delivery	5	17
73366	2020-06-05 06:30:30	2020-06-05	17	[{"id_menu":4,"count":1}]	29127	pick-up	0	17
73367	2020-06-05 06:31:42	2020-06-05	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11181	delivery	5	22
73368	2020-06-05 06:31:49	2020-06-05	17	[{"id_menu":4,"count":1}]	1993	delivery	5	22
73369	2020-06-05 06:32:53	2020-06-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	29120	delivery	5	28
73370	2020-06-05 06:34:40	2020-06-05	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	28942	delivery	5	28
73371	2020-06-05 06:36:31	2020-06-05	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	28946	delivery	5	45
73372	2020-06-05 06:39:10	2020-06-05	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	26573	delivery	5	45
73373	2020-06-05 06:39:32	2020-06-05	9	[{"id_menu":6,"count":1}]	29069	delivery	5	14
73374	2020-06-05 06:39:41	2020-06-05	12	[{"id_menu":3,"count":1}]	29034	delivery	5	17
73375	2020-06-05 06:40:12	2020-06-05	9	[{"id_menu":6,"count":1}]	3997	delivery	5	14
73376	2020-06-05 06:40:22	2020-06-05	9	[{"id_menu":7,"count":1}]	7284	pick-up	0	9
73377	2020-06-05 06:43:46	2020-06-05	9	[{"id_menu":7,"count":1}]	17831	delivery	5	14
73378	2020-06-05 06:44:31	2020-06-05	9	[{"id_menu":7,"count":1}]	19181	pick-up	0	9
73379	2020-06-05 06:50:23	2020-06-05	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5886	delivery	5	39
73380	2020-06-05 06:51:26	2020-06-05	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28988	pick-up	0	29
73381	2020-06-05 06:52:53	2020-06-05	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	25839	delivery	5	31
73382	2020-06-05 06:54:10	2020-06-05	9	[{"id_menu":6,"count":1}]	29132	delivery	5	14
73383	2020-06-05 06:54:43	2020-06-05	17	[{"id_menu":4,"count":1}]	29088	delivery	5	22
73384	2020-06-05 06:55:48	2020-06-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14227	delivery	5	22
73385	2020-06-05 06:56:25	2020-06-05	8	[{"id_menu":5,"count":1}]	21715	delivery	5	13
73386	2020-06-05 07:03:08	2020-06-05	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	28963	pick-up	0	29
73387	2020-06-05 07:08:24	2020-06-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22233	delivery	5	23
73388	2020-06-05 07:10:47	2020-06-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	23633	delivery	5	22
73389	2020-06-05 07:20:11	2020-06-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	19127	delivery	5	22
73390	2020-06-05 07:30:37	2020-06-05	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29083	delivery	5	48
73391	2020-06-05 07:36:01	2020-06-05	9	[{"id_menu":7,"count":1}]	2913	delivery	5	14
73392	2020-06-05 07:37:19	2020-06-05	14	[{"id_menu":2,"count":1}]	25716	delivery	5	19
73393	2020-06-05 07:37:51	2020-06-05	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2189	pick-up	0	31
73394	2020-06-05 07:39:37	2020-06-05	8	[{"id_menu":5,"count":1}]	2161	pick-up	0	8
73395	2020-06-05 07:40:59	2020-06-05	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	8404	delivery	5	36
73396	2020-06-05 07:43:59	2020-06-05	8	[{"id_menu":5,"count":1}]	29100	delivery	5	13
73397	2020-06-05 07:45:56	2020-06-05	9	[{"id_menu":7,"count":1}]	14636	delivery	5	14
73398	2020-06-05 07:46:20	2020-06-05	17	[{"id_menu":4,"count":1}]	28964	delivery	5	22
73399	2020-06-05 07:51:03	2020-06-05	14	[{"id_menu":2,"count":1}]	28992	delivery	5	19
73400	2020-06-05 07:51:28	2020-06-05	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	28941	delivery	5	34
73401	2020-06-05 07:54:08	2020-06-05	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22259	delivery	5	35
73402	2020-06-05 07:54:09	2020-06-05	14	[{"id_menu":2,"count":1}]	7007	delivery	5	19
73403	2020-06-05 07:55:07	2020-06-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29145	delivery	5	23
73404	2020-06-05 07:55:44	2020-06-05	17	[{"id_menu":4,"count":1}]	28959	pick-up	0	17
73405	2020-06-05 07:55:58	2020-06-05	8	[{"id_menu":5,"count":1}]	7398	pick-up	0	8
73406	2020-06-05 08:03:58	2020-06-05	12	[{"id_menu":1,"count":1}]	29157	delivery	5	17
73407	2020-06-05 08:04:47	2020-06-05	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12024	delivery	5	57
73408	2020-06-05 08:05:03	2020-06-05	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	29005	delivery	5	31
73409	2020-06-05 08:06:08	2020-06-05	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22143	delivery	5	31
73410	2020-06-05 08:06:27	2020-06-05	9	[{"id_menu":6,"count":1}]	19840	delivery	5	14
73411	2020-06-05 08:11:14	2020-06-05	14	[{"id_menu":2,"count":1}]	27660	delivery	5	19
73412	2020-06-05 08:11:45	2020-06-05	9	[{"id_menu":7,"count":1}]	15119	delivery	5	14
73413	2020-06-05 08:13:55	2020-06-05	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	22952	pick-up	0	25
73414	2020-06-05 08:14:03	2020-06-05	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	29152	delivery	5	40
73415	2020-06-05 08:24:28	2020-06-05	14	[{"id_menu":2,"count":1}]	27034	delivery	5	19
73416	2020-06-05 08:26:34	2020-06-05	8	[{"id_menu":5,"count":1}]	29159	delivery	5	13
73417	2020-06-05 08:31:26	2020-06-05	8	[{"id_menu":5,"count":1}]	22485	delivery	5	13
73418	2020-06-05 08:31:36	2020-06-05	9	[{"id_menu":6,"count":1}]	29035	delivery	5	14
73419	2020-06-05 08:39:52	2020-06-05	17	[{"id_menu":4,"count":1}]	81	delivery	5	22
73420	2020-06-05 08:40:33	2020-06-05	14	[{"id_menu":2,"count":1}]	28971	pick-up	0	14
73421	2020-06-05 08:42:23	2020-06-05	9	[{"id_menu":7,"count":1}]	7332	delivery	5	14
73422	2020-06-05 08:44:09	2020-06-05	9	[{"id_menu":6,"count":1}]	29068	delivery	5	14
73423	2020-06-05 08:44:50	2020-06-05	9	[{"id_menu":6,"count":1}]	22255	delivery	5	14
73424	2020-06-05 08:44:57	2020-06-05	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	29048	delivery	5	27
73425	2020-06-05 08:47:13	2020-06-05	14	[{"id_menu":2,"count":1}]	3180	pick-up	0	14
73426	2020-06-05 08:58:33	2020-06-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10802	delivery	5	23
73427	2020-06-05 08:59:35	2020-06-05	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	29079	delivery	5	27
73428	2020-06-05 09:02:21	2020-06-05	9	[{"id_menu":6,"count":1}]	9696	delivery	5	14
73429	2020-06-05 09:02:41	2020-06-05	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	20815	delivery	5	28
73430	2020-06-05 09:07:08	2020-06-05	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	13679	delivery	5	45
73431	2020-06-05 09:09:14	2020-06-05	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	6900	delivery	5	34
73432	2020-06-05 09:12:31	2020-06-05	12	[{"id_menu":3,"count":2}]	1996	pick-up	0	12
73433	2020-06-05 09:19:04	2020-06-05	17	[{"id_menu":4,"count":1}]	2562	pick-up	0	17
73434	2020-06-05 09:21:32	2020-06-05	17	[{"id_menu":4,"count":1}]	4960	pick-up	0	17
73435	2020-06-05 09:21:35	2020-06-05	14	[{"id_menu":2,"count":1}]	26408	pick-up	0	14
73436	2020-06-05 09:24:59	2020-06-05	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	885	pick-up	0	24
73437	2020-06-05 09:34:56	2020-06-05	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	29022	delivery	5	31
73438	2020-06-05 09:36:29	2020-06-05	17	[{"id_menu":4,"count":1}]	29017	delivery	5	22
73439	2020-06-05 09:45:04	2020-06-05	9	[{"id_menu":7,"count":1}]	15162	delivery	5	14
73440	2020-06-05 09:47:50	2020-06-05	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	28979	delivery	5	31
73441	2020-06-05 09:49:56	2020-06-05	9	[{"id_menu":7,"count":1}]	16681	delivery	5	14
73442	2020-06-05 09:52:08	2020-06-05	9	[{"id_menu":6,"count":1}]	5846	delivery	5	14
73443	2020-06-05 09:52:59	2020-06-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28756	delivery	5	23
73444	2020-06-05 09:54:56	2020-06-05	12	[{"id_menu":3,"count":1}]	8397	delivery	5	17
73445	2020-06-05 09:55:13	2020-06-05	9	[{"id_menu":7,"count":1}]	25287	delivery	5	14
73446	2020-06-05 09:55:19	2020-06-05	9	[{"id_menu":7,"count":1}]	12274	pick-up	0	9
73447	2020-06-05 09:55:53	2020-06-05	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2633	pick-up	0	26
73448	2020-06-05 09:56:27	2020-06-05	17	[{"id_menu":4,"count":1}]	29021	pick-up	0	17
73449	2020-06-05 10:00:23	2020-06-05	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	6069	delivery	5	36
73450	2020-06-05 10:03:41	2020-06-05	12	[{"id_menu":3,"count":1}]	7369	delivery	5	17
73451	2020-06-05 10:11:14	2020-06-05	9	[{"id_menu":6,"count":1}]	16548	delivery	5	14
73452	2020-06-05 10:15:31	2020-06-05	8	[{"id_menu":5,"count":1}]	10116	delivery	5	13
73453	2020-06-05 10:17:02	2020-06-05	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4453	pick-up	0	26
73454	2020-06-05 10:17:59	2020-06-05	9	[{"id_menu":7,"count":2}]	22283	delivery	5	14
73455	2020-06-05 10:18:02	2020-06-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28790	delivery	5	22
73456	2020-06-05 10:20:26	2020-06-05	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	6752	delivery	5	25
73457	2020-06-05 10:23:45	2020-06-05	14	[{"id_menu":2,"count":1}]	28956	delivery	5	19
73458	2020-06-05 10:23:57	2020-06-05	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	29111	delivery	5	43
73459	2020-06-05 10:31:04	2020-06-05	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	11342	delivery	5	28
73460	2020-06-05 10:33:01	2020-06-05	12	[{"id_menu":1,"count":1}]	2464	delivery	5	17
73461	2020-06-05 10:41:14	2020-06-05	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	29095	delivery	5	43
73462	2020-06-05 10:41:54	2020-06-05	9	[{"id_menu":7,"count":1}]	26945	delivery	5	14
73463	2020-06-05 10:53:18	2020-06-05	12	[{"id_menu":1,"count":2}]	29013	pick-up	0	12
73464	2020-06-05 10:55:49	2020-06-05	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29125	delivery	5	40
73465	2020-06-05 10:57:26	2020-06-05	12	[{"id_menu":1,"count":1}]	29140	pick-up	0	12
73466	2020-06-05 11:00:45	2020-06-05	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	16453	delivery	5	34
73467	2020-06-05 11:00:54	2020-06-05	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2082	pick-up	0	21
73468	2020-06-05 11:02:42	2020-06-05	12	[{"id_menu":1,"count":1}]	9348	delivery	5	17
73469	2020-06-05 11:03:29	2020-06-05	8	[{"id_menu":5,"count":1}]	29081	delivery	5	13
73470	2020-06-05 11:07:26	2020-06-05	9	[{"id_menu":6,"count":1}]	7066	delivery	5	14
73471	2020-06-05 11:07:32	2020-06-05	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	13200	delivery	5	31
73472	2020-06-05 11:11:53	2020-06-05	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29023	delivery	5	35
73473	2020-06-05 11:12:07	2020-06-05	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	29097	delivery	5	28
73474	2020-06-05 11:16:36	2020-06-05	9	[{"id_menu":6,"count":1}]	29168	pick-up	0	9
73475	2020-06-05 11:19:36	2020-06-05	9	[{"id_menu":7,"count":1}]	29030	delivery	5	14
73476	2020-06-05 11:19:55	2020-06-05	12	[{"id_menu":1,"count":1}]	7150	pick-up	0	12
73477	2020-06-05 11:25:02	2020-06-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":3}]	28935	delivery	5	28
73478	2020-06-05 11:28:34	2020-06-05	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	29104	delivery	5	26
73479	2020-06-05 11:31:32	2020-06-05	9	[{"id_menu":7,"count":1}]	29090	delivery	5	14
73480	2020-06-05 11:38:26	2020-06-05	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	16459	delivery	5	34
73481	2020-06-05 11:39:49	2020-06-05	9	[{"id_menu":7,"count":1}]	13120	delivery	5	14
73482	2020-06-05 11:43:21	2020-06-05	17	[{"id_menu":4,"count":1}]	24513	pick-up	0	17
73483	2020-06-05 11:45:38	2020-06-05	12	[{"id_menu":1,"count":2}]	1756	delivery	5	17
73484	2020-06-05 11:50:10	2020-06-05	17	[{"id_menu":4,"count":1}]	29153	pick-up	0	17
73485	2020-06-05 11:50:27	2020-06-05	14	[{"id_menu":2,"count":2}]	15247	delivery	5	19
73486	2020-06-05 11:53:04	2020-06-05	14	[{"id_menu":2,"count":1}]	11045	delivery	5	19
73487	2020-06-05 11:56:01	2020-06-05	8	[{"id_menu":5,"count":1}]	16452	delivery	5	13
73488	2020-06-05 12:02:40	2020-06-05	17	[{"id_menu":4,"count":1}]	784	pick-up	0	17
73489	2020-06-05 12:05:20	2020-06-05	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	4445	delivery	5	26
73490	2020-06-05 12:07:19	2020-06-05	14	[{"id_menu":2,"count":1}]	26739	pick-up	0	14
73491	2020-06-05 12:08:35	2020-06-05	8	[{"id_menu":5,"count":1}]	28987	delivery	5	13
73492	2020-06-05 12:12:17	2020-06-05	9	[{"id_menu":7,"count":1}]	24603	delivery	5	14
73493	2020-06-05 12:13:05	2020-06-05	12	[{"id_menu":3,"count":1}]	13256	pick-up	0	12
73494	2020-06-05 12:15:29	2020-06-05	12	[{"id_menu":1,"count":1}]	8118	delivery	5	17
73495	2020-06-05 12:21:17	2020-06-05	8	[{"id_menu":5,"count":1}]	6825	pick-up	0	8
73496	2020-06-05 12:22:30	2020-06-05	12	[{"id_menu":1,"count":1}]	29003	delivery	5	17
73497	2020-06-05 12:24:11	2020-06-05	9	[{"id_menu":6,"count":2}]	29055	delivery	5	14
73498	2020-06-05 12:31:03	2020-06-05	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	13568	delivery	5	30
73499	2020-06-05 12:32:39	2020-06-05	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	29109	delivery	5	26
73500	2020-06-05 12:32:59	2020-06-05	21	[{"id_menu":1,"count":3},{"id_menu":7,"count":1}]	29108	delivery	5	26
73501	2020-06-05 12:35:51	2020-06-05	14	[{"id_menu":2,"count":1}]	29123	delivery	5	19
73502	2020-06-05 12:40:02	2020-06-05	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	28593	delivery	5	57
73503	2020-06-05 12:46:06	2020-06-05	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24628	delivery	5	48
73504	2020-06-05 12:53:19	2020-06-05	12	[{"id_menu":3,"count":1}]	29080	delivery	5	17
73505	2020-06-05 12:55:31	2020-06-05	12	[{"id_menu":1,"count":2}]	970	pick-up	0	12
73506	2020-06-05 12:57:14	2020-06-05	17	[{"id_menu":4,"count":1}]	29070	delivery	5	22
73507	2020-06-05 13:00:31	2020-06-05	9	[{"id_menu":6,"count":2}]	29131	pick-up	0	9
73508	2020-06-05 13:00:32	2020-06-05	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	22331	delivery	5	23
73509	2020-06-05 13:00:36	2020-06-05	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	11187	delivery	5	48
73510	2020-06-05 13:09:16	2020-06-05	12	[{"id_menu":3,"count":1}]	15480	delivery	5	17
73511	2020-06-05 13:10:23	2020-06-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	29113	delivery	5	22
73512	2020-06-05 13:12:08	2020-06-05	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	10339	delivery	5	46
73513	2020-06-05 13:13:00	2020-06-05	9	[{"id_menu":7,"count":1}]	25036	delivery	5	14
73514	2020-06-05 13:15:08	2020-06-05	8	[{"id_menu":5,"count":1}]	28937	delivery	5	13
73515	2020-06-05 13:15:55	2020-06-05	12	[{"id_menu":1,"count":1}]	29091	delivery	5	17
73516	2020-06-05 13:16:28	2020-06-05	14	[{"id_menu":2,"count":1}]	3382	delivery	5	19
73517	2020-06-05 13:18:53	2020-06-05	14	[{"id_menu":2,"count":1}]	27936	delivery	5	19
73518	2020-06-05 13:19:35	2020-06-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	29110	delivery	5	28
73519	2020-06-05 13:20:29	2020-06-05	8	[{"id_menu":5,"count":1}]	2470	pick-up	0	8
73520	2020-06-05 13:21:03	2020-06-05	9	[{"id_menu":7,"count":1}]	29004	delivery	5	14
73521	2020-06-05 13:22:25	2020-06-05	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	24473	delivery	5	43
73522	2020-06-05 13:22:45	2020-06-05	9	[{"id_menu":7,"count":1}]	28945	delivery	5	14
73523	2020-06-05 13:22:57	2020-06-05	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28965	delivery	5	48
73524	2020-06-05 13:23:34	2020-06-05	9	[{"id_menu":7,"count":1}]	213	pick-up	0	9
73525	2020-06-05 13:29:19	2020-06-05	12	[{"id_menu":1,"count":1}]	28960	pick-up	0	12
73526	2020-06-05 13:31:08	2020-06-05	9	[{"id_menu":7,"count":1}]	29144	delivery	5	14
73527	2020-06-05 13:31:56	2020-06-05	8	[{"id_menu":5,"count":1}]	29061	delivery	5	13
73528	2020-06-05 13:32:34	2020-06-05	9	[{"id_menu":6,"count":1}]	12666	delivery	5	14
73529	2020-06-05 13:33:47	2020-06-05	9	[{"id_menu":6,"count":1}]	28993	delivery	5	14
73530	2020-06-05 13:34:12	2020-06-05	9	[{"id_menu":7,"count":1}]	29086	delivery	5	14
73531	2020-06-05 13:35:15	2020-06-05	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	19953	delivery	5	42
73532	2020-06-05 13:39:43	2020-06-05	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	29000	delivery	5	42
73533	2020-06-05 13:41:54	2020-06-05	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29146	delivery	5	40
73534	2020-06-05 13:42:02	2020-06-05	17	[{"id_menu":4,"count":1}]	24547	pick-up	0	17
73535	2020-06-05 13:43:52	2020-06-05	17	[{"id_menu":4,"count":1}]	28977	delivery	5	22
73536	2020-06-05 13:45:10	2020-06-05	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	29112	delivery	5	27
73537	2020-06-05 13:48:00	2020-06-05	14	[{"id_menu":2,"count":1}]	9449	delivery	5	19
73538	2020-06-05 13:48:28	2020-06-05	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27931	delivery	5	45
73539	2020-06-05 13:50:49	2020-06-05	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	11638	delivery	5	36
73540	2020-06-05 14:10:59	2020-06-05	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	29033	delivery	5	35
73541	2020-06-05 14:17:04	2020-06-05	12	[{"id_menu":3,"count":1}]	29059	delivery	5	17
73542	2020-06-05 14:22:27	2020-06-05	9	[{"id_menu":6,"count":1}]	10480	pick-up	0	9
73543	2020-06-05 14:33:45	2020-06-05	14	[{"id_menu":2,"count":1}]	29050	delivery	5	19
73544	2020-06-05 14:37:11	2020-06-05	14	[{"id_menu":2,"count":1}]	13136	delivery	5	19
73545	2020-06-05 14:49:09	2020-06-05	12	[{"id_menu":1,"count":1}]	29171	pick-up	0	12
73546	2020-06-05 14:56:10	2020-06-05	12	[{"id_menu":1,"count":1}]	24120	delivery	5	17
73547	2020-06-05 15:07:13	2020-06-05	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	29150	delivery	5	31
73548	2020-06-05 15:09:55	2020-06-05	8	[{"id_menu":5,"count":1}]	3309	delivery	5	13
73549	2020-06-05 15:11:58	2020-06-05	17	[{"id_menu":4,"count":1}]	506	delivery	5	22
73550	2020-06-05 15:12:45	2020-06-05	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	28997	delivery	5	30
73551	2020-06-05 15:14:01	2020-06-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	28954	delivery	5	22
73552	2020-06-05 15:20:07	2020-06-05	9	[{"id_menu":7,"count":1}]	151	pick-up	0	9
73553	2020-06-05 15:20:21	2020-06-05	9	[{"id_menu":6,"count":1}]	29134	pick-up	0	9
73554	2020-06-05 15:20:30	2020-06-05	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	13183	delivery	5	26
73555	2020-06-05 15:24:54	2020-06-05	8	[{"id_menu":5,"count":1}]	12123	delivery	5	13
73556	2020-06-05 15:26:48	2020-06-05	8	[{"id_menu":5,"count":1}]	16342	delivery	5	13
73557	2020-06-05 15:32:24	2020-06-05	9	[{"id_menu":6,"count":2}]	28943	delivery	5	14
73558	2020-06-05 15:39:01	2020-06-05	9	[{"id_menu":6,"count":1}]	9345	delivery	5	14
73559	2020-06-05 15:39:13	2020-06-05	9	[{"id_menu":6,"count":1}]	26097	delivery	5	14
73560	2020-06-05 15:40:06	2020-06-05	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	29038	delivery	5	31
73561	2020-06-05 15:40:50	2020-06-05	9	[{"id_menu":7,"count":1}]	29019	delivery	5	14
73562	2020-06-05 15:43:04	2020-06-05	9	[{"id_menu":7,"count":1}]	22608	pick-up	0	9
73563	2020-06-05 15:45:52	2020-06-05	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29002	delivery	5	22
73564	2020-06-05 15:46:13	2020-06-05	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	19321	pick-up	0	31
73565	2020-06-05 15:47:00	2020-06-05	9	[{"id_menu":6,"count":1}]	18506	delivery	5	14
73566	2020-06-05 15:48:48	2020-06-05	17	[{"id_menu":4,"count":1}]	29137	delivery	5	22
73567	2020-06-05 15:49:33	2020-06-05	12	[{"id_menu":3,"count":1}]	16571	delivery	5	17
73568	2020-06-05 15:55:12	2020-06-05	12	[{"id_menu":1,"count":1}]	29172	delivery	5	17
73569	2020-06-05 15:55:45	2020-06-05	17	[{"id_menu":4,"count":1}]	29106	delivery	5	22
73570	2020-06-05 15:57:22	2020-06-05	9	[{"id_menu":6,"count":1}]	5011	delivery	5	14
73571	2020-06-05 15:58:33	2020-06-05	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13149	delivery	5	43
73572	2020-06-05 15:59:39	2020-06-05	9	[{"id_menu":6,"count":1}]	12908	delivery	5	14
73573	2020-06-05 16:04:03	2020-06-05	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29047	delivery	5	35
73574	2020-06-05 16:07:52	2020-06-05	8	[{"id_menu":5,"count":1}]	10471	delivery	5	13
73575	2020-06-05 16:08:44	2020-06-05	8	[{"id_menu":5,"count":1}]	19818	delivery	5	13
73576	2020-06-05 16:08:48	2020-06-05	14	[{"id_menu":2,"count":1}]	29014	delivery	5	19
73577	2020-06-05 16:15:06	2020-06-05	9	[{"id_menu":6,"count":1}]	23437	delivery	5	14
73578	2020-06-05 16:15:16	2020-06-05	14	[{"id_menu":2,"count":2}]	19964	delivery	5	19
73579	2020-06-05 16:15:50	2020-06-05	17	[{"id_menu":4,"count":1}]	8947	delivery	5	22
73580	2020-06-05 16:17:23	2020-06-05	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	28091	pick-up	0	31
73581	2020-06-05 16:21:49	2020-06-05	49	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7958	delivery	5	54
73582	2020-06-05 16:23:07	2020-06-05	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	29164	delivery	5	31
73583	2020-06-05 16:23:20	2020-06-05	12	[{"id_menu":3,"count":1}]	10144	delivery	5	17
73584	2020-06-05 16:29:37	2020-06-05	8	[{"id_menu":5,"count":1}]	29037	delivery	5	13
73585	2020-06-05 16:29:56	2020-06-05	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3451	pick-up	0	29
73586	2020-06-05 16:31:27	2020-06-05	17	[{"id_menu":4,"count":1}]	28983	delivery	5	22
73587	2020-06-05 16:32:38	2020-06-05	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	29031	delivery	5	36
73588	2020-06-05 16:33:54	2020-06-05	12	[{"id_menu":3,"count":1}]	3830	pick-up	0	12
73589	2020-06-05 16:36:11	2020-06-05	9	[{"id_menu":6,"count":1}]	9621	delivery	5	14
73590	2020-06-05 16:39:21	2020-06-05	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	29128	delivery	5	29
73591	2020-06-05 16:40:19	2020-06-05	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	432	pick-up	0	31
73592	2020-06-05 16:42:56	2020-06-05	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	29147	delivery	5	34
73593	2020-06-05 16:44:41	2020-06-05	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	22230	delivery	5	34
73594	2020-06-05 16:46:30	2020-06-05	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11006	delivery	5	51
73595	2020-06-05 16:48:36	2020-06-05	9	[{"id_menu":6,"count":2}]	29041	delivery	5	14
73596	2020-06-05 16:48:46	2020-06-05	14	[{"id_menu":2,"count":1}]	29089	delivery	5	19
73597	2020-06-05 16:52:22	2020-06-05	8	[{"id_menu":5,"count":1}]	25296	delivery	5	13
73598	2020-06-05 16:59:04	2020-06-05	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	21452	delivery	5	27
73599	2020-06-05 17:00:02	2020-06-05	17	[{"id_menu":4,"count":1}]	29136	pick-up	0	17
73600	2020-06-05 17:02:08	2020-06-05	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	14954	delivery	5	26
73601	2020-06-05 17:08:07	2020-06-05	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	29138	delivery	5	23
73602	2020-06-05 17:10:34	2020-06-05	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	28928	delivery	5	31
73603	2020-06-05 17:15:13	2020-06-05	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	23405	delivery	5	26
73604	2020-06-05 17:19:43	2020-06-05	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	28976	delivery	5	31
73605	2020-06-05 17:20:27	2020-06-05	14	[{"id_menu":2,"count":1}]	21357	pick-up	0	14
73606	2020-06-05 17:24:18	2020-06-05	9	[{"id_menu":7,"count":1}]	29016	delivery	5	14
73607	2020-06-05 17:25:41	2020-06-05	12	[{"id_menu":1,"count":1}]	29036	pick-up	0	12
73608	2020-06-05 17:30:31	2020-06-05	14	[{"id_menu":2,"count":1}]	12760	delivery	5	19
73609	2020-06-05 17:33:27	2020-06-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	24018	delivery	5	28
73610	2020-06-05 17:36:49	2020-06-05	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	26860	pick-up	0	52
73611	2020-06-05 17:49:44	2020-06-05	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	28930	delivery	5	48
73612	2020-06-05 17:50:19	2020-06-05	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	23111	pick-up	0	23
73613	2020-06-05 17:54:12	2020-06-05	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	14133	delivery	5	34
73614	2020-06-05 17:59:27	2020-06-05	12	[{"id_menu":1,"count":1}]	23939	pick-up	0	12
73615	2020-06-05 18:04:08	2020-06-05	12	[{"id_menu":1,"count":1}]	2567	pick-up	0	12
73616	2020-06-05 18:04:25	2020-06-05	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	20757	delivery	5	31
73617	2020-06-05 18:04:38	2020-06-05	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	5701	pick-up	0	21
73618	2020-06-05 18:08:20	2020-06-05	12	[{"id_menu":3,"count":1}]	13225	delivery	5	17
73619	2020-06-05 18:11:43	2020-06-05	12	[{"id_menu":1,"count":1}]	21720	delivery	5	17
73620	2020-06-05 18:14:47	2020-06-05	9	[{"id_menu":7,"count":1}]	2021	pick-up	0	9
73621	2020-06-05 18:20:30	2020-06-05	9	[{"id_menu":7,"count":1}]	25556	delivery	5	14
73622	2020-06-05 18:22:24	2020-06-05	14	[{"id_menu":2,"count":1}]	5981	delivery	5	19
73623	2020-06-05 18:22:50	2020-06-05	9	[{"id_menu":6,"count":1}]	11510	delivery	5	14
73624	2020-06-05 18:24:47	2020-06-05	9	[{"id_menu":6,"count":1}]	29135	delivery	5	14
73625	2020-06-05 18:27:08	2020-06-05	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28974	delivery	5	37
73626	2020-06-05 18:27:16	2020-06-05	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	20852	delivery	5	30
73627	2020-06-05 18:27:20	2020-06-05	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	21971	delivery	5	34
73628	2020-06-05 18:28:09	2020-06-05	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	27023	delivery	5	40
73629	2020-06-05 18:34:13	2020-06-05	12	[{"id_menu":3,"count":1}]	25021	delivery	5	17
73630	2020-06-05 18:40:39	2020-06-05	9	[{"id_menu":7,"count":1}]	29044	delivery	5	14
73631	2020-06-05 18:42:49	2020-06-05	17	[{"id_menu":4,"count":1}]	3868	delivery	5	22
73632	2020-06-05 18:47:02	2020-06-05	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	28961	delivery	5	43
73633	2020-06-05 18:47:24	2020-06-05	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4793	pick-up	0	31
73634	2020-06-05 18:49:46	2020-06-05	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2909	delivery	5	38
73635	2020-06-05 18:54:27	2020-06-05	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	16206	delivery	5	36
73636	2020-06-05 18:54:28	2020-06-05	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	29130	delivery	5	31
73637	2020-06-05 18:56:19	2020-06-05	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	366	delivery	5	28
73638	2020-06-05 18:57:14	2020-06-05	14	[{"id_menu":2,"count":1}]	11043	pick-up	0	14
73639	2020-06-05 18:57:21	2020-06-05	12	[{"id_menu":3,"count":1}]	16288	delivery	5	17
73640	2020-06-05 19:02:06	2020-06-05	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20390	delivery	5	22
73641	2020-06-05 19:03:24	2020-06-05	9	[{"id_menu":6,"count":2}]	6846	delivery	5	14
73642	2020-06-05 19:08:19	2020-06-05	8	[{"id_menu":5,"count":1}]	28518	delivery	5	13
73643	2020-06-05 19:14:46	2020-06-05	14	[{"id_menu":2,"count":2}]	22556	delivery	5	19
73644	2020-06-05 19:15:33	2020-06-05	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	3851	delivery	5	28
73645	2020-06-05 19:19:42	2020-06-05	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28978	delivery	5	51
73646	2020-06-05 19:19:52	2020-06-05	17	[{"id_menu":4,"count":1}]	10706	pick-up	0	17
73647	2020-06-05 19:22:29	2020-06-05	8	[{"id_menu":5,"count":1}]	28999	pick-up	0	8
73648	2020-06-05 19:24:09	2020-06-05	9	[{"id_menu":6,"count":1}]	15456	delivery	5	14
73649	2020-06-05 19:24:13	2020-06-05	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	16060	delivery	5	31
73650	2020-06-05 19:24:35	2020-06-05	30	[{"id_menu":3,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29094	delivery	5	35
73651	2020-06-05 19:28:28	2020-06-05	14	[{"id_menu":2,"count":1}]	26361	delivery	5	19
73652	2020-06-05 19:33:12	2020-06-05	9	[{"id_menu":7,"count":1}]	605	pick-up	0	9
73653	2020-06-05 19:36:19	2020-06-05	14	[{"id_menu":2,"count":1}]	29046	delivery	5	19
73654	2020-06-05 19:40:54	2020-06-05	12	[{"id_menu":1,"count":1}]	19722	delivery	5	17
73655	2020-06-05 19:43:43	2020-06-05	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	29076	delivery	5	35
73656	2020-06-05 19:46:03	2020-06-05	8	[{"id_menu":5,"count":1}]	22295	delivery	5	13
73657	2020-06-05 19:54:47	2020-06-05	17	[{"id_menu":4,"count":1}]	29155	delivery	5	22
73658	2020-06-05 19:59:12	2020-06-05	9	[{"id_menu":6,"count":1}]	21748	delivery	5	14
73659	2020-06-05 20:03:37	2020-06-05	8	[{"id_menu":5,"count":1}]	28940	delivery	5	13
73660	2020-06-05 20:08:12	2020-06-05	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	7279	delivery	5	27
73661	2020-06-05 20:09:34	2020-06-05	12	[{"id_menu":1,"count":1}]	29115	delivery	5	17
73662	2020-06-05 20:09:41	2020-06-05	17	[{"id_menu":4,"count":1}]	1349	pick-up	0	17
73663	2020-06-05 20:14:59	2020-06-05	14	[{"id_menu":2,"count":1}]	29045	delivery	5	19
73664	2020-06-05 20:26:18	2020-06-05	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28981	delivery	5	45
73665	2020-06-05 20:37:22	2020-06-05	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	28951	delivery	5	34
73666	2020-06-05 20:44:17	2020-06-05	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1957	pick-up	0	29
73667	2020-06-05 20:45:59	2020-06-05	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20739	delivery	5	34
73668	2020-06-05 20:53:07	2020-06-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13065	delivery	5	23
73669	2020-06-05 20:59:30	2020-06-05	8	[{"id_menu":5,"count":1}]	29049	pick-up	0	8
73670	2020-06-05 21:05:46	2020-06-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":3}]	6062	pick-up	0	23
73671	2020-06-05 21:05:52	2020-06-05	9	[{"id_menu":7,"count":1}]	8146	pick-up	0	9
73672	2020-06-05 21:12:11	2020-06-05	9	[{"id_menu":7,"count":1}]	18413	delivery	5	14
73673	2020-06-05 21:16:09	2020-06-05	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	14905	delivery	5	26
73674	2020-06-05 21:17:31	2020-06-05	9	[{"id_menu":7,"count":1}]	21793	delivery	5	14
73675	2020-06-05 21:22:49	2020-06-05	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	10578	delivery	5	43
73676	2020-06-05 21:23:18	2020-06-05	9	[{"id_menu":6,"count":1}]	28955	delivery	5	14
73677	2020-06-05 21:25:37	2020-06-05	9	[{"id_menu":7,"count":1}]	12841	delivery	5	14
73678	2020-06-05 21:27:19	2020-06-05	8	[{"id_menu":5,"count":1}]	29163	delivery	5	13
73679	2020-06-05 21:27:34	2020-06-05	9	[{"id_menu":7,"count":1}]	13537	pick-up	0	9
73680	2020-06-05 21:27:50	2020-06-05	17	[{"id_menu":4,"count":1}]	9356	pick-up	0	17
73681	2020-06-05 21:27:57	2020-06-05	12	[{"id_menu":1,"count":1}]	28932	delivery	5	17
73682	2020-06-05 21:28:53	2020-06-05	14	[{"id_menu":2,"count":1}]	16018	delivery	5	19
73683	2020-06-05 21:32:59	2020-06-05	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	28996	delivery	5	34
73684	2020-06-05 21:33:40	2020-06-05	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	14751	pick-up	0	26
73685	2020-06-05 21:33:49	2020-06-05	12	[{"id_menu":1,"count":1}]	29158	delivery	5	17
73686	2020-06-05 21:34:20	2020-06-05	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	29116	delivery	5	26
73687	2020-06-05 21:35:45	2020-06-05	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	3136	delivery	5	40
73688	2020-06-05 21:37:37	2020-06-05	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	20901	delivery	5	36
73689	2020-06-05 21:43:50	2020-06-05	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1309	pick-up	0	25
73690	2020-06-05 21:47:09	2020-06-05	14	[{"id_menu":2,"count":1}]	4013	pick-up	0	14
73691	2020-06-05 21:57:09	2020-06-05	9	[{"id_menu":6,"count":1}]	19104	delivery	5	14
73692	2020-06-05 21:57:13	2020-06-05	17	[{"id_menu":4,"count":1}]	29032	delivery	5	22
73693	2020-06-05 22:00:46	2020-06-05	12	[{"id_menu":3,"count":1}]	28966	pick-up	0	12
73694	2020-06-05 22:02:01	2020-06-05	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	28953	delivery	5	26
73695	2020-06-05 22:03:43	2020-06-05	12	[{"id_menu":1,"count":1}]	17094	delivery	5	17
73696	2020-06-05 22:04:48	2020-06-05	12	[{"id_menu":3,"count":1}]	2313	pick-up	0	12
73697	2020-06-05 22:06:18	2020-06-05	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	29099	delivery	5	34
73698	2020-06-05 22:08:02	2020-06-05	12	[{"id_menu":1,"count":1}]	20231	pick-up	0	12
73699	2020-06-05 22:12:10	2020-06-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5293	pick-up	0	17
73700	2020-06-05 22:32:41	2020-06-05	12	[{"id_menu":3,"count":3}]	29149	delivery	5	17
73701	2020-06-05 22:39:59	2020-06-05	9	[{"id_menu":7,"count":1}]	29027	delivery	5	14
73702	2020-06-05 22:41:36	2020-06-05	14	[{"id_menu":2,"count":1}]	1820	pick-up	0	14
73703	2020-06-05 22:54:34	2020-06-05	9	[{"id_menu":7,"count":1}]	19201	delivery	5	14
73704	2020-06-05 22:56:27	2020-06-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	25160	delivery	5	31
73705	2020-06-05 22:59:21	2020-06-05	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2897	pick-up	0	21
73706	2020-06-05 22:59:30	2020-06-05	12	[{"id_menu":1,"count":1}]	12083	delivery	5	17
73707	2020-06-05 22:59:43	2020-06-05	9	[{"id_menu":6,"count":1}]	27577	delivery	5	14
73708	2020-06-05 23:04:30	2020-06-05	9	[{"id_menu":6,"count":1}]	18228	pick-up	0	9
73709	2020-06-05 23:05:07	2020-06-05	17	[{"id_menu":4,"count":1}]	29029	pick-up	0	17
73710	2020-06-05 23:11:59	2020-06-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":3}]	29072	delivery	5	28
73711	2020-06-05 23:22:19	2020-06-05	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4120	delivery	5	27
73712	2020-06-05 23:23:05	2020-06-05	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25799	delivery	5	40
73713	2020-06-05 23:23:39	2020-06-05	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	29139	delivery	5	28
73714	2020-06-05 23:25:03	2020-06-05	12	[{"id_menu":3,"count":1}]	8270	delivery	5	17
73715	2020-06-05 23:28:19	2020-06-05	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	24356	delivery	5	46
73716	2020-06-05 23:28:54	2020-06-05	14	[{"id_menu":2,"count":2}]	21009	pick-up	0	14
73717	2020-06-05 23:30:23	2020-06-05	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8388	pick-up	0	29
73718	2020-06-05 23:32:18	2020-06-05	12	[{"id_menu":3,"count":1}]	68	pick-up	0	12
73719	2020-06-05 23:38:51	2020-06-05	17	[{"id_menu":4,"count":1}]	25954	pick-up	0	17
73720	2020-06-05 23:38:52	2020-06-05	9	[{"id_menu":7,"count":1}]	8706	delivery	5	14
73721	2020-06-05 23:39:08	2020-06-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	22878	delivery	5	31
73722	2020-06-05 23:42:01	2020-06-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8634	delivery	5	31
73723	2020-06-05 23:43:57	2020-06-05	14	[{"id_menu":2,"count":1}]	28982	delivery	5	19
73724	2020-06-05 23:44:55	2020-06-05	8	[{"id_menu":5,"count":1}]	9399	delivery	5	13
73725	2020-06-05 23:47:02	2020-06-05	9	[{"id_menu":6,"count":1}]	28985	delivery	5	14
73726	2020-06-06 00:01:14	2020-06-06	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2640	delivery	5	57
73727	2020-06-06 00:01:42	2020-06-06	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6809	delivery	5	34
73728	2020-06-06 00:02:04	2020-06-06	12	[{"id_menu":1,"count":1}]	1198	delivery	5	17
73729	2020-06-06 00:08:50	2020-06-06	9	[{"id_menu":6,"count":1}]	11393	delivery	5	14
73730	2020-06-06 00:12:36	2020-06-06	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	27664	delivery	5	23
73731	2020-06-06 00:17:11	2020-06-06	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	29304	delivery	5	26
73732	2020-06-06 00:22:37	2020-06-06	12	[{"id_menu":3,"count":1}]	23833	delivery	5	17
73733	2020-06-06 00:24:44	2020-06-06	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3629	delivery	5	26
73734	2020-06-06 00:29:16	2020-06-06	9	[{"id_menu":7,"count":1}]	5001	delivery	5	14
73735	2020-06-06 00:32:47	2020-06-06	9	[{"id_menu":7,"count":1}]	29189	delivery	5	14
73736	2020-06-06 00:35:26	2020-06-06	9	[{"id_menu":7,"count":1}]	722	pick-up	0	9
73737	2020-06-06 00:37:37	2020-06-06	8	[{"id_menu":5,"count":1}]	10159	delivery	5	13
73738	2020-06-06 00:39:14	2020-06-06	8	[{"id_menu":5,"count":1}]	17353	pick-up	0	8
73739	2020-06-06 00:39:25	2020-06-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2801	pick-up	0	23
73740	2020-06-06 00:44:35	2020-06-06	9	[{"id_menu":7,"count":1}]	6282	pick-up	0	9
73741	2020-06-06 00:46:13	2020-06-06	9	[{"id_menu":7,"count":1}]	29179	pick-up	0	9
73742	2020-06-06 00:46:30	2020-06-06	8	[{"id_menu":5,"count":1}]	7415	pick-up	0	8
73743	2020-06-06 00:46:30	2020-06-06	14	[{"id_menu":2,"count":1}]	13441	delivery	5	19
73744	2020-06-06 00:50:09	2020-06-06	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21572	delivery	5	22
73745	2020-06-06 00:52:17	2020-06-06	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	26359	delivery	5	22
73746	2020-06-06 00:58:26	2020-06-06	8	[{"id_menu":5,"count":1}]	15257	delivery	5	13
73747	2020-06-06 00:59:22	2020-06-06	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	29278	delivery	5	34
73748	2020-06-06 00:59:29	2020-06-06	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10337	delivery	5	43
73749	2020-06-06 01:02:24	2020-06-06	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	29206	delivery	5	28
73750	2020-06-06 01:03:18	2020-06-06	14	[{"id_menu":2,"count":1}]	19776	pick-up	0	14
73751	2020-06-06 01:04:37	2020-06-06	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	29339	delivery	5	31
73752	2020-06-06 01:06:56	2020-06-06	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12338	delivery	5	43
73753	2020-06-06 01:07:28	2020-06-06	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	28755	delivery	5	38
73754	2020-06-06 01:08:34	2020-06-06	12	[{"id_menu":1,"count":1}]	29238	delivery	5	17
73755	2020-06-06 01:10:11	2020-06-06	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	26571	delivery	5	36
73756	2020-06-06 01:10:28	2020-06-06	9	[{"id_menu":7,"count":1}]	28633	delivery	5	14
73757	2020-06-06 01:11:28	2020-06-06	14	[{"id_menu":2,"count":1}]	6355	pick-up	0	14
73758	2020-06-06 01:16:16	2020-06-06	9	[{"id_menu":7,"count":1}]	16404	delivery	5	14
73759	2020-06-06 01:17:46	2020-06-06	9	[{"id_menu":6,"count":2}]	29272	delivery	5	14
73760	2020-06-06 01:19:39	2020-06-06	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	24513	delivery	5	25
73761	2020-06-06 01:22:15	2020-06-06	17	[{"id_menu":4,"count":1}]	29365	delivery	5	22
73762	2020-06-06 01:25:28	2020-06-06	9	[{"id_menu":7,"count":1}]	23666	delivery	5	14
73763	2020-06-06 01:28:24	2020-06-06	14	[{"id_menu":2,"count":1}]	29303	delivery	5	19
73764	2020-06-06 01:32:05	2020-06-06	49	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	29362	delivery	5	54
73765	2020-06-06 01:33:23	2020-06-06	12	[{"id_menu":3,"count":1}]	3966	pick-up	0	12
73766	2020-06-06 01:36:00	2020-06-06	9	[{"id_menu":6,"count":1}]	10611	delivery	5	14
73767	2020-06-06 01:37:34	2020-06-06	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":2}]	8726	delivery	5	28
73768	2020-06-06 01:38:11	2020-06-06	9	[{"id_menu":7,"count":1}]	29337	delivery	5	14
73769	2020-06-06 01:43:34	2020-06-06	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	29173	delivery	5	31
73770	2020-06-06 01:48:29	2020-06-06	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	7200	pick-up	0	29
73771	2020-06-06 01:49:41	2020-06-06	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29371	delivery	5	35
73772	2020-06-06 01:50:26	2020-06-06	9	[{"id_menu":6,"count":1}]	27987	delivery	5	14
73773	2020-06-06 01:51:55	2020-06-06	9	[{"id_menu":7,"count":1}]	29343	delivery	5	14
73774	2020-06-06 01:52:18	2020-06-06	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	29281	delivery	5	39
73775	2020-06-06 01:53:25	2020-06-06	9	[{"id_menu":6,"count":1}]	29305	delivery	5	14
73776	2020-06-06 02:01:29	2020-06-06	12	[{"id_menu":1,"count":1}]	18260	delivery	5	17
73777	2020-06-06 02:14:22	2020-06-06	12	[{"id_menu":3,"count":1}]	18374	pick-up	0	12
73778	2020-06-06 02:16:41	2020-06-06	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	22204	delivery	5	25
73779	2020-06-06 02:17:12	2020-06-06	9	[{"id_menu":7,"count":1}]	11338	pick-up	0	9
73780	2020-06-06 02:19:10	2020-06-06	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4728	delivery	5	27
73781	2020-06-06 02:19:30	2020-06-06	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	21370	delivery	5	26
73782	2020-06-06 02:21:06	2020-06-06	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	17530	delivery	5	31
73783	2020-06-06 02:22:30	2020-06-06	12	[{"id_menu":1,"count":1}]	24331	pick-up	0	12
73784	2020-06-06 02:23:03	2020-06-06	9	[{"id_menu":7,"count":1}]	1924	delivery	5	14
73785	2020-06-06 02:23:58	2020-06-06	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	24052	delivery	5	23
73786	2020-06-06 02:27:18	2020-06-06	12	[{"id_menu":3,"count":1}]	4902	delivery	5	17
73787	2020-06-06 02:30:43	2020-06-06	9	[{"id_menu":7,"count":1}]	17982	delivery	5	14
73788	2020-06-06 02:31:08	2020-06-06	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	16434	pick-up	0	21
73789	2020-06-06 02:36:39	2020-06-06	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29274	delivery	5	48
73790	2020-06-06 02:38:53	2020-06-06	12	[{"id_menu":1,"count":1}]	29319	delivery	5	17
73791	2020-06-06 02:38:59	2020-06-06	8	[{"id_menu":5,"count":2}]	23197	delivery	5	13
73792	2020-06-06 02:40:17	2020-06-06	17	[{"id_menu":4,"count":1}]	29283	pick-up	0	17
73793	2020-06-06 02:42:13	2020-06-06	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2291	delivery	5	22
73794	2020-06-06 02:48:50	2020-06-06	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2561	pick-up	0	23
73795	2020-06-06 02:53:39	2020-06-06	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14495	delivery	5	23
73796	2020-06-06 02:58:57	2020-06-06	38	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17467	delivery	5	43
73797	2020-06-06 02:59:58	2020-06-06	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	7740	delivery	5	36
73798	2020-06-06 03:00:55	2020-06-06	9	[{"id_menu":6,"count":1}]	29226	pick-up	0	9
73799	2020-06-06 03:08:30	2020-06-06	17	[{"id_menu":4,"count":2}]	11241	delivery	5	22
73800	2020-06-06 03:10:30	2020-06-06	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29315	delivery	5	22
73801	2020-06-06 03:11:28	2020-06-06	17	[{"id_menu":4,"count":2}]	1742	pick-up	0	17
73802	2020-06-06 03:12:47	2020-06-06	17	[{"id_menu":4,"count":1}]	29348	delivery	5	22
73803	2020-06-06 03:13:56	2020-06-06	12	[{"id_menu":3,"count":1}]	7040	pick-up	0	12
73804	2020-06-06 03:15:55	2020-06-06	8	[{"id_menu":5,"count":2}]	29340	delivery	5	13
73805	2020-06-06 03:19:31	2020-06-06	9	[{"id_menu":7,"count":1}]	29209	delivery	5	14
73806	2020-06-06 03:20:57	2020-06-06	9	[{"id_menu":6,"count":1}]	29271	delivery	5	14
73807	2020-06-06 03:25:02	2020-06-06	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	24668	delivery	5	48
73808	2020-06-06 03:30:09	2020-06-06	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16175	delivery	5	37
73809	2020-06-06 03:32:46	2020-06-06	9	[{"id_menu":6,"count":1}]	29326	delivery	5	14
73810	2020-06-06 03:33:06	2020-06-06	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	25794	delivery	5	45
73811	2020-06-06 03:33:32	2020-06-06	9	[{"id_menu":7,"count":1}]	18870	delivery	5	14
73812	2020-06-06 03:33:59	2020-06-06	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	29328	delivery	5	26
73813	2020-06-06 03:35:29	2020-06-06	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	138	delivery	5	23
73814	2020-06-06 03:36:23	2020-06-06	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	16489	delivery	5	31
73815	2020-06-06 03:38:52	2020-06-06	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	19503	delivery	5	26
73816	2020-06-06 03:39:07	2020-06-06	12	[{"id_menu":3,"count":1}]	10589	pick-up	0	12
73817	2020-06-06 03:40:10	2020-06-06	8	[{"id_menu":5,"count":1}]	9169	delivery	5	13
73818	2020-06-06 03:43:38	2020-06-06	9	[{"id_menu":7,"count":1}]	29310	delivery	5	14
73819	2020-06-06 03:44:18	2020-06-06	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	971	delivery	5	40
73820	2020-06-06 03:45:19	2020-06-06	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	23688	delivery	5	30
73821	2020-06-06 03:46:39	2020-06-06	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29215	delivery	5	40
73822	2020-06-06 03:48:38	2020-06-06	12	[{"id_menu":1,"count":1}]	13863	delivery	5	17
73823	2020-06-06 03:49:01	2020-06-06	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8054	pick-up	0	17
73824	2020-06-06 03:50:37	2020-06-06	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	28357	pick-up	0	26
73825	2020-06-06 03:52:36	2020-06-06	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20313	delivery	5	34
73826	2020-06-06 03:53:50	2020-06-06	14	[{"id_menu":2,"count":1}]	28012	delivery	5	19
73827	2020-06-06 03:59:06	2020-06-06	9	[{"id_menu":6,"count":1}]	12807	delivery	5	14
73828	2020-06-06 03:59:37	2020-06-06	14	[{"id_menu":2,"count":1}]	9972	delivery	5	19
73829	2020-06-06 04:01:58	2020-06-06	9	[{"id_menu":7,"count":1}]	17244	delivery	5	14
73830	2020-06-06 04:04:01	2020-06-06	17	[{"id_menu":4,"count":1}]	9061	delivery	5	22
73831	2020-06-06 04:06:12	2020-06-06	9	[{"id_menu":6,"count":1}]	23771	delivery	5	14
73832	2020-06-06 04:07:12	2020-06-06	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6026	delivery	5	40
73833	2020-06-06 04:08:39	2020-06-06	8	[{"id_menu":5,"count":1}]	7330	pick-up	0	8
73834	2020-06-06 04:11:52	2020-06-06	8	[{"id_menu":5,"count":1}]	29306	delivery	5	13
73835	2020-06-06 04:19:54	2020-06-06	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	22356	delivery	5	22
73836	2020-06-06 04:22:01	2020-06-06	9	[{"id_menu":6,"count":1}]	15009	delivery	5	14
73837	2020-06-06 04:27:51	2020-06-06	9	[{"id_menu":6,"count":1}]	29253	delivery	5	14
73838	2020-06-06 04:28:20	2020-06-06	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	29267	delivery	5	36
73839	2020-06-06 04:30:44	2020-06-06	9	[{"id_menu":6,"count":1}]	24277	delivery	5	14
73840	2020-06-06 04:31:44	2020-06-06	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15535	delivery	5	31
73841	2020-06-06 04:32:46	2020-06-06	9	[{"id_menu":7,"count":1}]	18268	delivery	5	14
73842	2020-06-06 04:33:14	2020-06-06	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	29336	delivery	5	48
73843	2020-06-06 04:35:23	2020-06-06	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22389	delivery	5	22
73844	2020-06-06 04:36:51	2020-06-06	9	[{"id_menu":7,"count":1}]	13429	pick-up	0	9
73845	2020-06-06 04:41:19	2020-06-06	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	29197	delivery	5	39
73846	2020-06-06 04:44:13	2020-06-06	12	[{"id_menu":1,"count":1}]	25954	pick-up	0	12
73847	2020-06-06 04:45:07	2020-06-06	9	[{"id_menu":6,"count":1}]	29323	delivery	5	14
73848	2020-06-06 04:51:25	2020-06-06	9	[{"id_menu":7,"count":1}]	27790	delivery	5	14
73849	2020-06-06 04:51:54	2020-06-06	9	[{"id_menu":7,"count":1}]	12139	pick-up	0	9
73850	2020-06-06 04:55:05	2020-06-06	9	[{"id_menu":7,"count":1}]	26208	pick-up	0	9
73851	2020-06-06 04:56:02	2020-06-06	9	[{"id_menu":7,"count":1}]	13987	delivery	5	14
73852	2020-06-06 04:59:33	2020-06-06	17	[{"id_menu":4,"count":1}]	29177	delivery	5	22
73853	2020-06-06 05:03:26	2020-06-06	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	20210	delivery	5	28
73854	2020-06-06 05:03:36	2020-06-06	14	[{"id_menu":2,"count":1}]	29288	pick-up	0	14
73855	2020-06-06 05:04:34	2020-06-06	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	8720	pick-up	0	29
73856	2020-06-06 05:07:56	2020-06-06	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	29232	delivery	5	22
73857	2020-06-06 05:10:02	2020-06-06	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	27650	delivery	5	36
73858	2020-06-06 05:14:44	2020-06-06	9	[{"id_menu":6,"count":2}]	29312	delivery	5	14
73859	2020-06-06 05:18:38	2020-06-06	9	[{"id_menu":7,"count":1}]	28897	delivery	5	14
73860	2020-06-06 05:20:34	2020-06-06	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	16744	delivery	5	26
73861	2020-06-06 05:22:27	2020-06-06	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2292	pick-up	0	26
73862	2020-06-06 05:23:42	2020-06-06	17	[{"id_menu":4,"count":1}]	3412	delivery	5	22
73863	2020-06-06 05:24:18	2020-06-06	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3977	delivery	5	37
73864	2020-06-06 05:24:50	2020-06-06	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8757	pick-up	0	18
73865	2020-06-06 05:25:32	2020-06-06	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29178	delivery	5	35
73866	2020-06-06 05:25:42	2020-06-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	29231	pick-up	0	23
73867	2020-06-06 05:29:45	2020-06-06	9	[{"id_menu":6,"count":1}]	16425	delivery	5	14
73868	2020-06-06 05:33:45	2020-06-06	12	[{"id_menu":3,"count":1}]	20615	delivery	5	17
73869	2020-06-06 05:34:26	2020-06-06	12	[{"id_menu":1,"count":1}]	3007	pick-up	0	12
73870	2020-06-06 05:34:48	2020-06-06	9	[{"id_menu":6,"count":1}]	5689	delivery	5	14
73871	2020-06-06 05:37:16	2020-06-06	8	[{"id_menu":5,"count":1}]	19293	delivery	5	13
73872	2020-06-06 05:40:36	2020-06-06	17	[{"id_menu":4,"count":1}]	29069	delivery	5	22
73873	2020-06-06 05:40:54	2020-06-06	17	[{"id_menu":4,"count":1}]	1725	delivery	5	22
73874	2020-06-06 05:45:28	2020-06-06	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	23780	delivery	5	31
73875	2020-06-06 05:48:54	2020-06-06	14	[{"id_menu":2,"count":1}]	16603	delivery	5	19
73876	2020-06-06 05:49:05	2020-06-06	12	[{"id_menu":3,"count":1}]	6975	pick-up	0	12
73877	2020-06-06 05:51:54	2020-06-06	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	29280	pick-up	0	35
73878	2020-06-06 06:00:06	2020-06-06	12	[{"id_menu":3,"count":1}]	20329	delivery	5	17
73879	2020-06-06 06:01:00	2020-06-06	12	[{"id_menu":1,"count":1}]	10433	delivery	5	17
73880	2020-06-06 06:03:15	2020-06-06	17	[{"id_menu":4,"count":1}]	13765	delivery	5	22
73881	2020-06-06 06:06:20	2020-06-06	9	[{"id_menu":7,"count":1}]	7843	delivery	5	14
73882	2020-06-06 06:07:02	2020-06-06	8	[{"id_menu":5,"count":1}]	29332	delivery	5	13
73883	2020-06-06 06:08:50	2020-06-06	9	[{"id_menu":7,"count":1}]	28320	delivery	5	14
73884	2020-06-06 06:11:31	2020-06-06	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	29222	delivery	5	31
73885	2020-06-06 06:11:36	2020-06-06	9	[{"id_menu":6,"count":1}]	26791	delivery	5	14
73886	2020-06-06 06:15:56	2020-06-06	9	[{"id_menu":6,"count":1}]	10729	delivery	5	14
73887	2020-06-06 06:18:13	2020-06-06	17	[{"id_menu":4,"count":1}]	16093	delivery	5	22
73888	2020-06-06 06:18:15	2020-06-06	9	[{"id_menu":6,"count":2}]	29244	delivery	5	14
73889	2020-06-06 06:21:34	2020-06-06	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	3507	delivery	5	28
73890	2020-06-06 06:22:07	2020-06-06	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	10613	delivery	5	48
73891	2020-06-06 06:24:09	2020-06-06	9	[{"id_menu":7,"count":1}]	29211	pick-up	0	9
73892	2020-06-06 06:24:31	2020-06-06	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	23963	pick-up	0	26
73893	2020-06-06 06:25:44	2020-06-06	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	29219	delivery	5	37
73894	2020-06-06 06:28:38	2020-06-06	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	29269	delivery	5	38
73895	2020-06-06 06:29:36	2020-06-06	9	[{"id_menu":6,"count":1}]	23570	delivery	5	14
73896	2020-06-06 06:31:37	2020-06-06	12	[{"id_menu":1,"count":1}]	18238	delivery	5	17
73897	2020-06-06 06:31:41	2020-06-06	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	12019	pick-up	0	29
73898	2020-06-06 06:33:45	2020-06-06	9	[{"id_menu":6,"count":1}]	16703	delivery	5	14
73899	2020-06-06 06:38:35	2020-06-06	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14068	delivery	5	22
73900	2020-06-06 06:40:37	2020-06-06	8	[{"id_menu":5,"count":1}]	8235	delivery	5	13
73901	2020-06-06 06:42:46	2020-06-06	9	[{"id_menu":7,"count":1}]	8441	delivery	5	14
73902	2020-06-06 06:44:51	2020-06-06	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2691	delivery	5	26
73903	2020-06-06 06:46:15	2020-06-06	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	7578	delivery	5	31
73904	2020-06-06 06:46:20	2020-06-06	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	9454	delivery	5	34
73905	2020-06-06 06:50:52	2020-06-06	9	[{"id_menu":6,"count":1}]	29361	delivery	5	14
73906	2020-06-06 06:53:07	2020-06-06	9	[{"id_menu":6,"count":1}]	29263	delivery	5	14
73907	2020-06-06 06:54:53	2020-06-06	9	[{"id_menu":6,"count":1}]	27238	delivery	5	14
73908	2020-06-06 06:54:58	2020-06-06	8	[{"id_menu":5,"count":1}]	29291	delivery	5	13
73909	2020-06-06 06:56:15	2020-06-06	9	[{"id_menu":6,"count":1}]	29236	delivery	5	14
73910	2020-06-06 06:58:12	2020-06-06	14	[{"id_menu":2,"count":1}]	29208	delivery	5	19
73911	2020-06-06 06:58:27	2020-06-06	14	[{"id_menu":2,"count":1}]	28558	delivery	5	19
73912	2020-06-06 07:01:05	2020-06-06	17	[{"id_menu":4,"count":1}]	8900	delivery	5	22
73913	2020-06-06 07:02:01	2020-06-06	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6280	pick-up	0	40
73914	2020-06-06 07:08:36	2020-06-06	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4110	delivery	5	34
73915	2020-06-06 07:08:53	2020-06-06	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29200	delivery	5	35
73916	2020-06-06 07:15:48	2020-06-06	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6593	delivery	5	45
73917	2020-06-06 07:16:30	2020-06-06	9	[{"id_menu":6,"count":1}]	32	pick-up	0	9
73918	2020-06-06 07:17:00	2020-06-06	12	[{"id_menu":3,"count":1}]	29359	delivery	5	17
73919	2020-06-06 07:17:34	2020-06-06	9	[{"id_menu":7,"count":1}]	12976	delivery	5	14
73920	2020-06-06 07:21:01	2020-06-06	9	[{"id_menu":6,"count":1}]	18085	delivery	5	14
73921	2020-06-06 07:21:02	2020-06-06	12	[{"id_menu":1,"count":1}]	270	pick-up	0	12
73922	2020-06-06 07:28:02	2020-06-06	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	14015	delivery	5	36
73923	2020-06-06 07:35:50	2020-06-06	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	29292	pick-up	0	22
73924	2020-06-06 07:36:09	2020-06-06	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	29349	delivery	5	25
73925	2020-06-06 07:37:14	2020-06-06	8	[{"id_menu":5,"count":1}]	27044	pick-up	0	8
73926	2020-06-06 07:37:49	2020-06-06	12	[{"id_menu":1,"count":1}]	17269	delivery	5	17
73927	2020-06-06 07:37:51	2020-06-06	14	[{"id_menu":2,"count":1}]	29243	pick-up	0	14
73928	2020-06-06 07:39:02	2020-06-06	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22379	delivery	5	34
73929	2020-06-06 07:39:41	2020-06-06	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25579	delivery	5	40
73930	2020-06-06 07:42:04	2020-06-06	17	[{"id_menu":4,"count":1}]	1259	pick-up	0	17
73931	2020-06-06 07:45:38	2020-06-06	12	[{"id_menu":3,"count":1}]	29355	delivery	5	17
73932	2020-06-06 07:49:57	2020-06-06	14	[{"id_menu":2,"count":1}]	29174	delivery	5	19
73933	2020-06-06 07:50:27	2020-06-06	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	18707	delivery	5	36
73934	2020-06-06 07:53:31	2020-06-06	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8650	delivery	5	45
73935	2020-06-06 07:55:57	2020-06-06	12	[{"id_menu":1,"count":1}]	29237	delivery	5	17
73936	2020-06-06 07:56:29	2020-06-06	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	20189	delivery	5	43
73937	2020-06-06 07:58:14	2020-06-06	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	29301	delivery	5	43
73938	2020-06-06 07:58:17	2020-06-06	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	636	pick-up	0	23
73939	2020-06-06 08:04:50	2020-06-06	17	[{"id_menu":4,"count":1}]	13376	delivery	5	22
73940	2020-06-06 08:06:36	2020-06-06	8	[{"id_menu":5,"count":1}]	24948	delivery	5	13
73941	2020-06-06 08:08:26	2020-06-06	12	[{"id_menu":1,"count":1}]	543	pick-up	0	12
73942	2020-06-06 08:10:23	2020-06-06	9	[{"id_menu":6,"count":1}]	26304	delivery	5	14
73943	2020-06-06 08:12:06	2020-06-06	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	23226	delivery	5	22
73944	2020-06-06 08:13:58	2020-06-06	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	15563	delivery	5	34
73945	2020-06-06 08:15:10	2020-06-06	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	26456	delivery	5	43
73946	2020-06-06 08:18:57	2020-06-06	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	29317	delivery	5	29
73947	2020-06-06 08:19:03	2020-06-06	9	[{"id_menu":7,"count":1}]	3806	delivery	5	14
73948	2020-06-06 08:20:33	2020-06-06	9	[{"id_menu":6,"count":1}]	29216	delivery	5	14
73949	2020-06-06 08:22:52	2020-06-06	12	[{"id_menu":1,"count":1}]	29346	delivery	5	17
73950	2020-06-06 08:25:13	2020-06-06	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8961	delivery	5	39
73951	2020-06-06 08:25:45	2020-06-06	12	[{"id_menu":3,"count":1}]	29327	delivery	5	17
73952	2020-06-06 08:26:49	2020-06-06	8	[{"id_menu":5,"count":1}]	12473	pick-up	0	8
73953	2020-06-06 08:31:14	2020-06-06	12	[{"id_menu":3,"count":1}]	17500	pick-up	0	12
73954	2020-06-06 08:32:13	2020-06-06	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24975	delivery	5	47
73955	2020-06-06 08:32:45	2020-06-06	12	[{"id_menu":1,"count":1}]	787	pick-up	0	12
73956	2020-06-06 08:38:41	2020-06-06	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	11590	delivery	5	31
73957	2020-06-06 08:38:57	2020-06-06	9	[{"id_menu":6,"count":1}]	29307	delivery	5	14
73958	2020-06-06 08:44:38	2020-06-06	8	[{"id_menu":5,"count":1}]	23470	delivery	5	13
73959	2020-06-06 08:47:15	2020-06-06	9	[{"id_menu":7,"count":1}]	29351	delivery	5	14
73960	2020-06-06 08:47:15	2020-06-06	9	[{"id_menu":6,"count":1}]	7992	pick-up	0	9
73961	2020-06-06 08:47:34	2020-06-06	17	[{"id_menu":4,"count":1}]	6214	delivery	5	22
73962	2020-06-06 08:47:57	2020-06-06	12	[{"id_menu":1,"count":1}]	27969	delivery	5	17
73963	2020-06-06 08:53:36	2020-06-06	8	[{"id_menu":5,"count":1}]	29268	pick-up	0	8
73964	2020-06-06 09:01:57	2020-06-06	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	13687	delivery	5	43
73965	2020-06-06 09:03:43	2020-06-06	9	[{"id_menu":6,"count":1}]	29318	delivery	5	14
73966	2020-06-06 09:08:03	2020-06-06	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29194	delivery	5	46
73967	2020-06-06 09:22:45	2020-06-06	14	[{"id_menu":2,"count":2}]	27777	delivery	5	19
73968	2020-06-06 09:30:54	2020-06-06	9	[{"id_menu":7,"count":1}]	18305	delivery	5	14
73969	2020-06-06 09:36:58	2020-06-06	9	[{"id_menu":7,"count":1}]	26352	delivery	5	14
73970	2020-06-06 09:39:00	2020-06-06	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	29224	delivery	5	22
73971	2020-06-06 09:39:05	2020-06-06	14	[{"id_menu":2,"count":1}]	170	pick-up	0	14
73972	2020-06-06 09:41:24	2020-06-06	9	[{"id_menu":6,"count":1}]	29290	delivery	5	14
73973	2020-06-06 09:42:03	2020-06-06	9	[{"id_menu":7,"count":1}]	29295	pick-up	0	9
73974	2020-06-06 09:44:06	2020-06-06	17	[{"id_menu":4,"count":1}]	743	pick-up	0	17
73975	2020-06-06 09:48:04	2020-06-06	9	[{"id_menu":6,"count":1}]	10122	delivery	5	14
73976	2020-06-06 09:49:00	2020-06-06	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17025	delivery	5	23
73977	2020-06-06 09:50:57	2020-06-06	12	[{"id_menu":3,"count":1}]	25651	delivery	5	17
73978	2020-06-06 09:54:32	2020-06-06	14	[{"id_menu":2,"count":1}]	20811	delivery	5	19
73979	2020-06-06 09:55:30	2020-06-06	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	11415	delivery	5	22
73980	2020-06-06 10:00:39	2020-06-06	9	[{"id_menu":6,"count":1}]	29196	pick-up	0	9
73981	2020-06-06 10:02:14	2020-06-06	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	29360	delivery	5	23
73982	2020-06-06 10:02:34	2020-06-06	14	[{"id_menu":2,"count":1}]	14227	delivery	5	19
73983	2020-06-06 10:04:50	2020-06-06	9	[{"id_menu":6,"count":1}]	8568	delivery	5	14
73984	2020-06-06 10:05:14	2020-06-06	9	[{"id_menu":6,"count":1}]	29363	delivery	5	14
73985	2020-06-06 10:08:24	2020-06-06	9	[{"id_menu":6,"count":1}]	29199	pick-up	0	9
73986	2020-06-06 10:12:13	2020-06-06	9	[{"id_menu":7,"count":1}]	9301	delivery	5	14
73987	2020-06-06 10:14:27	2020-06-06	8	[{"id_menu":5,"count":1}]	4973	delivery	5	13
73988	2020-06-06 10:16:38	2020-06-06	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	29293	pick-up	0	31
73989	2020-06-06 10:17:11	2020-06-06	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	169	pick-up	0	29
73990	2020-06-06 10:17:47	2020-06-06	8	[{"id_menu":5,"count":1}]	9173	delivery	5	13
73991	2020-06-06 10:21:20	2020-06-06	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	26739	delivery	5	39
73992	2020-06-06 10:22:19	2020-06-06	9	[{"id_menu":6,"count":1}]	18967	delivery	5	14
73993	2020-06-06 10:28:18	2020-06-06	9	[{"id_menu":6,"count":1}]	5942	delivery	5	14
73994	2020-06-06 10:36:52	2020-06-06	9	[{"id_menu":6,"count":1}]	8407	delivery	5	14
73995	2020-06-06 10:37:35	2020-06-06	9	[{"id_menu":6,"count":1}]	17471	delivery	5	14
73996	2020-06-06 10:37:55	2020-06-06	12	[{"id_menu":1,"count":1}]	10277	delivery	5	17
73997	2020-06-06 10:38:57	2020-06-06	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	28167	delivery	5	30
73998	2020-06-06 10:41:28	2020-06-06	9	[{"id_menu":6,"count":1}]	29220	delivery	5	14
73999	2020-06-06 10:42:55	2020-06-06	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	8365	delivery	5	23
74000	2020-06-06 10:42:56	2020-06-06	8	[{"id_menu":5,"count":2}]	6247	pick-up	0	8
74001	2020-06-06 10:43:01	2020-06-06	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8984	delivery	5	40
74002	2020-06-06 10:43:14	2020-06-06	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	26556	delivery	5	38
74003	2020-06-06 10:50:09	2020-06-06	9	[{"id_menu":7,"count":1}]	29190	delivery	5	14
74004	2020-06-06 10:54:40	2020-06-06	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	27629	delivery	5	44
74005	2020-06-06 10:59:35	2020-06-06	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	21503	pick-up	0	24
74006	2020-06-06 11:02:04	2020-06-06	9	[{"id_menu":6,"count":1}]	23914	delivery	5	14
74007	2020-06-06 11:02:22	2020-06-06	9	[{"id_menu":7,"count":1}]	29282	delivery	5	14
74008	2020-06-06 11:06:00	2020-06-06	8	[{"id_menu":5,"count":1}]	29345	delivery	5	13
74009	2020-06-06 11:09:53	2020-06-06	12	[{"id_menu":3,"count":1}]	29260	delivery	5	17
74010	2020-06-06 11:14:02	2020-06-06	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	29229	delivery	5	40
74011	2020-06-06 11:15:42	2020-06-06	8	[{"id_menu":5,"count":1}]	29366	delivery	5	13
74012	2020-06-06 11:15:47	2020-06-06	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2631	pick-up	0	29
74013	2020-06-06 11:18:29	2020-06-06	9	[{"id_menu":6,"count":1}]	10765	delivery	5	14
74014	2020-06-06 11:19:05	2020-06-06	9	[{"id_menu":6,"count":1}]	18392	pick-up	0	9
74015	2020-06-06 11:21:05	2020-06-06	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2056	delivery	5	34
74016	2020-06-06 11:25:31	2020-06-06	14	[{"id_menu":2,"count":1}]	29370	pick-up	0	14
74017	2020-06-06 11:26:01	2020-06-06	9	[{"id_menu":6,"count":2}]	4003	delivery	5	14
74018	2020-06-06 11:28:56	2020-06-06	14	[{"id_menu":2,"count":1}]	29329	delivery	5	19
74019	2020-06-06 11:30:13	2020-06-06	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	29325	delivery	5	22
74020	2020-06-06 11:30:38	2020-06-06	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	27144	delivery	5	31
74021	2020-06-06 11:34:33	2020-06-06	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	29262	delivery	5	31
74022	2020-06-06 11:35:24	2020-06-06	14	[{"id_menu":2,"count":1}]	7994	delivery	5	19
74023	2020-06-06 11:41:31	2020-06-06	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	2101	delivery	5	40
74024	2020-06-06 11:41:45	2020-06-06	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	25890	delivery	5	43
74025	2020-06-06 11:41:58	2020-06-06	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	27385	delivery	5	51
74026	2020-06-06 11:42:14	2020-06-06	9	[{"id_menu":6,"count":1}]	29302	delivery	5	14
74027	2020-06-06 11:43:17	2020-06-06	12	[{"id_menu":1,"count":1}]	14183	delivery	5	17
74028	2020-06-06 11:44:45	2020-06-06	17	[{"id_menu":4,"count":1}]	8873	pick-up	0	17
74029	2020-06-06 11:45:25	2020-06-06	14	[{"id_menu":2,"count":1}]	12952	delivery	5	19
74030	2020-06-06 11:46:43	2020-06-06	12	[{"id_menu":3,"count":1}]	6046	pick-up	0	12
74031	2020-06-06 11:52:48	2020-06-06	8	[{"id_menu":5,"count":1}]	29275	delivery	5	13
74032	2020-06-06 11:53:34	2020-06-06	12	[{"id_menu":3,"count":1}]	3363	pick-up	0	12
74033	2020-06-06 11:57:25	2020-06-06	12	[{"id_menu":3,"count":1}]	29247	delivery	5	17
74034	2020-06-06 11:58:10	2020-06-06	8	[{"id_menu":5,"count":1}]	5803	delivery	5	13
74035	2020-06-06 12:00:56	2020-06-06	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	29212	delivery	5	22
74036	2020-06-06 12:01:35	2020-06-06	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	29187	pick-up	0	31
74037	2020-06-06 12:01:39	2020-06-06	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	15425	delivery	5	34
74038	2020-06-06 12:03:41	2020-06-06	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20099	delivery	5	23
74039	2020-06-06 12:09:10	2020-06-06	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	29233	delivery	5	34
74040	2020-06-06 12:10:35	2020-06-06	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28827	delivery	5	36
74041	2020-06-06 12:11:02	2020-06-06	14	[{"id_menu":2,"count":1}]	23667	delivery	5	19
74042	2020-06-06 12:12:45	2020-06-06	8	[{"id_menu":5,"count":1}]	11650	delivery	5	13
74043	2020-06-06 12:12:57	2020-06-06	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	29256	delivery	5	28
74044	2020-06-06 12:15:42	2020-06-06	9	[{"id_menu":7,"count":1}]	2244	delivery	5	14
74045	2020-06-06 12:19:17	2020-06-06	9	[{"id_menu":6,"count":2}]	20334	delivery	5	14
74046	2020-06-06 12:19:32	2020-06-06	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27583	delivery	5	36
74047	2020-06-06 12:20:35	2020-06-06	9	[{"id_menu":7,"count":1}]	29314	delivery	5	14
74048	2020-06-06 12:20:39	2020-06-06	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	21733	pick-up	0	31
74049	2020-06-06 12:20:45	2020-06-06	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	18522	pick-up	0	20
74050	2020-06-06 12:22:41	2020-06-06	14	[{"id_menu":2,"count":1}]	29239	delivery	5	19
74051	2020-06-06 12:22:47	2020-06-06	9	[{"id_menu":7,"count":1}]	12990	pick-up	0	9
74052	2020-06-06 12:23:07	2020-06-06	9	[{"id_menu":7,"count":1}]	5189	pick-up	0	9
74053	2020-06-06 12:27:23	2020-06-06	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6954	delivery	5	31
74054	2020-06-06 12:31:18	2020-06-06	9	[{"id_menu":6,"count":1}]	14855	delivery	5	14
74055	2020-06-06 12:32:36	2020-06-06	8	[{"id_menu":5,"count":1}]	2704	delivery	5	13
74056	2020-06-06 12:32:41	2020-06-06	12	[{"id_menu":3,"count":1}]	15154	delivery	5	17
74057	2020-06-06 12:36:52	2020-06-06	9	[{"id_menu":7,"count":1}]	27311	delivery	5	14
74058	2020-06-06 12:38:49	2020-06-06	14	[{"id_menu":2,"count":1}]	29354	delivery	5	19
74059	2020-06-06 12:39:24	2020-06-06	8	[{"id_menu":5,"count":1}]	29369	delivery	5	13
74060	2020-06-06 12:43:48	2020-06-06	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	29331	delivery	5	26
74061	2020-06-06 12:45:28	2020-06-06	9	[{"id_menu":7,"count":2}]	18227	pick-up	0	9
74062	2020-06-06 12:47:03	2020-06-06	9	[{"id_menu":6,"count":1}]	29183	delivery	5	14
74063	2020-06-06 12:49:36	2020-06-06	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	29289	delivery	5	38
74064	2020-06-06 12:54:12	2020-06-06	9	[{"id_menu":6,"count":1}]	29201	delivery	5	14
74065	2020-06-06 12:57:08	2020-06-06	8	[{"id_menu":5,"count":1}]	3840	pick-up	0	8
74066	2020-06-06 13:00:53	2020-06-06	46	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	7771	pick-up	0	46
74067	2020-06-06 13:00:54	2020-06-06	8	[{"id_menu":5,"count":1}]	2625	pick-up	0	8
74068	2020-06-06 13:00:59	2020-06-06	8	[{"id_menu":5,"count":1}]	10494	delivery	5	13
74069	2020-06-06 13:06:24	2020-06-06	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	28361	pick-up	0	24
74070	2020-06-06 13:12:08	2020-06-06	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	1393	delivery	5	28
74071	2020-06-06 13:17:12	2020-06-06	12	[{"id_menu":1,"count":1}]	17846	pick-up	0	12
74072	2020-06-06 13:17:39	2020-06-06	12	[{"id_menu":3,"count":1}]	14027	pick-up	0	12
74073	2020-06-06 13:18:51	2020-06-06	17	[{"id_menu":4,"count":1}]	29358	delivery	5	22
74074	2020-06-06 13:19:15	2020-06-06	17	[{"id_menu":4,"count":1}]	13062	pick-up	0	17
74075	2020-06-06 13:19:42	2020-06-06	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	226	pick-up	0	29
74076	2020-06-06 13:20:16	2020-06-06	9	[{"id_menu":6,"count":1}]	9684	delivery	5	14
74077	2020-06-06 13:22:43	2020-06-06	14	[{"id_menu":2,"count":1}]	29266	delivery	5	19
74078	2020-06-06 13:24:45	2020-06-06	14	[{"id_menu":2,"count":1}]	5945	pick-up	0	14
74079	2020-06-06 13:27:05	2020-06-06	12	[{"id_menu":3,"count":1}]	2590	delivery	5	17
74080	2020-06-06 13:27:27	2020-06-06	9	[{"id_menu":6,"count":1}]	7710	pick-up	0	9
74081	2020-06-06 13:28:49	2020-06-06	12	[{"id_menu":1,"count":1}]	21469	delivery	5	17
74082	2020-06-06 13:30:28	2020-06-06	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	9304	pick-up	0	29
74083	2020-06-06 13:31:51	2020-06-06	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	19125	pick-up	0	26
74084	2020-06-06 13:35:37	2020-06-06	9	[{"id_menu":7,"count":1}]	29248	delivery	5	14
74085	2020-06-06 13:37:06	2020-06-06	12	[{"id_menu":1,"count":1}]	23405	delivery	5	17
74086	2020-06-06 13:46:12	2020-06-06	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	29218	delivery	5	31
74087	2020-06-06 13:48:25	2020-06-06	12	[{"id_menu":1,"count":1}]	19923	delivery	5	17
74088	2020-06-06 13:49:00	2020-06-06	14	[{"id_menu":2,"count":1}]	29250	delivery	5	19
74089	2020-06-06 13:51:06	2020-06-06	12	[{"id_menu":3,"count":1}]	27489	delivery	5	17
74090	2020-06-06 13:52:39	2020-06-06	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	29241	delivery	5	34
74091	2020-06-06 13:54:09	2020-06-06	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	28041	delivery	5	40
74092	2020-06-06 13:55:47	2020-06-06	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	530	pick-up	0	34
74093	2020-06-06 14:01:35	2020-06-06	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16978	delivery	5	31
74094	2020-06-06 14:04:05	2020-06-06	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	18307	delivery	5	25
74095	2020-06-06 14:06:34	2020-06-06	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29344	delivery	5	23
74096	2020-06-06 14:08:43	2020-06-06	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	16793	delivery	5	31
74097	2020-06-06 14:11:25	2020-06-06	8	[{"id_menu":5,"count":1}]	29251	delivery	5	13
74098	2020-06-06 14:13:16	2020-06-06	9	[{"id_menu":6,"count":1}]	27763	delivery	5	14
74099	2020-06-06 14:16:10	2020-06-06	14	[{"id_menu":2,"count":1}]	13274	pick-up	0	14
74100	2020-06-06 14:18:09	2020-06-06	12	[{"id_menu":3,"count":1}]	22140	delivery	5	17
74101	2020-06-06 14:18:23	2020-06-06	9	[{"id_menu":7,"count":3}]	26410	delivery	5	14
74102	2020-06-06 14:18:26	2020-06-06	17	[{"id_menu":4,"count":1}]	5808	pick-up	0	17
74103	2020-06-06 14:18:53	2020-06-06	9	[{"id_menu":7,"count":1}]	29175	delivery	5	14
74104	2020-06-06 14:19:30	2020-06-06	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8683	delivery	5	22
74105	2020-06-06 14:21:12	2020-06-06	9	[{"id_menu":6,"count":1}]	17885	delivery	5	14
74106	2020-06-06 14:22:44	2020-06-06	17	[{"id_menu":4,"count":1}]	6015	delivery	5	22
74107	2020-06-06 14:22:54	2020-06-06	12	[{"id_menu":1,"count":1}]	13613	pick-up	0	12
74108	2020-06-06 14:23:54	2020-06-06	8	[{"id_menu":5,"count":1}]	29347	pick-up	0	8
74109	2020-06-06 14:24:14	2020-06-06	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	15930	delivery	5	28
74110	2020-06-06 14:27:03	2020-06-06	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	29342	delivery	5	25
74111	2020-06-06 14:28:21	2020-06-06	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	1073	pick-up	0	40
74112	2020-06-06 14:30:33	2020-06-06	8	[{"id_menu":5,"count":1}]	29273	delivery	5	13
74113	2020-06-06 14:31:16	2020-06-06	8	[{"id_menu":5,"count":1}]	22485	delivery	5	13
74114	2020-06-06 14:33:22	2020-06-06	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	20999	delivery	5	28
74115	2020-06-06 14:35:51	2020-06-06	9	[{"id_menu":6,"count":1}]	29192	delivery	5	14
74116	2020-06-06 14:36:51	2020-06-06	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	29242	delivery	5	34
74117	2020-06-06 14:37:01	2020-06-06	12	[{"id_menu":3,"count":1}]	10328	delivery	5	17
74118	2020-06-06 14:37:39	2020-06-06	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":2}]	23670	delivery	5	28
74119	2020-06-06 14:38:46	2020-06-06	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1460	delivery	5	31
74120	2020-06-06 14:47:31	2020-06-06	12	[{"id_menu":3,"count":1}]	29227	delivery	5	17
74121	2020-06-06 14:47:41	2020-06-06	30	[{"id_menu":1,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23877	delivery	5	35
74122	2020-06-06 14:48:34	2020-06-06	14	[{"id_menu":2,"count":1}]	26290	delivery	5	19
74123	2020-06-06 14:50:07	2020-06-06	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	14002	delivery	5	26
74124	2020-06-06 14:50:46	2020-06-06	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	19523	delivery	5	30
74125	2020-06-06 14:51:17	2020-06-06	14	[{"id_menu":2,"count":2}]	8145	pick-up	0	14
74126	2020-06-06 14:52:25	2020-06-06	9	[{"id_menu":6,"count":1}]	16011	delivery	5	14
74127	2020-06-06 14:53:09	2020-06-06	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	26850	delivery	5	34
74128	2020-06-06 14:54:58	2020-06-06	9	[{"id_menu":6,"count":1}]	10117	pick-up	0	9
74129	2020-06-06 14:56:04	2020-06-06	17	[{"id_menu":4,"count":1}]	29311	pick-up	0	17
74130	2020-06-06 14:57:08	2020-06-06	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":2}]	3540	delivery	5	25
74131	2020-06-06 14:57:14	2020-06-06	9	[{"id_menu":6,"count":1}]	27257	pick-up	0	9
74132	2020-06-06 14:59:45	2020-06-06	12	[{"id_menu":3,"count":1}]	3722	delivery	5	17
74133	2020-06-06 15:00:02	2020-06-06	9	[{"id_menu":7,"count":1}]	29230	delivery	5	14
74134	2020-06-06 15:04:28	2020-06-06	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	4511	delivery	5	43
74135	2020-06-06 15:05:05	2020-06-06	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	29353	delivery	5	34
74136	2020-06-06 15:06:49	2020-06-06	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18690	delivery	5	35
74137	2020-06-06 15:11:12	2020-06-06	9	[{"id_menu":6,"count":1}]	29277	delivery	5	14
74138	2020-06-06 15:12:09	2020-06-06	17	[{"id_menu":4,"count":1}]	22828	delivery	5	22
74139	2020-06-06 15:13:53	2020-06-06	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	19894	pick-up	0	26
74140	2020-06-06 15:13:56	2020-06-06	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	18840	delivery	5	26
74141	2020-06-06 15:16:30	2020-06-06	14	[{"id_menu":2,"count":1}]	5761	pick-up	0	14
74142	2020-06-06 15:16:57	2020-06-06	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	29322	delivery	5	34
74143	2020-06-06 15:18:01	2020-06-06	12	[{"id_menu":3,"count":1}]	5484	delivery	5	17
74144	2020-06-06 15:19:30	2020-06-06	9	[{"id_menu":7,"count":1}]	25141	pick-up	0	9
74145	2020-06-06 15:21:10	2020-06-06	9	[{"id_menu":7,"count":1}]	22923	delivery	5	14
74146	2020-06-06 15:21:15	2020-06-06	9	[{"id_menu":6,"count":1}]	1825	pick-up	0	9
74147	2020-06-06 15:25:34	2020-06-06	9	[{"id_menu":7,"count":1}]	1838	pick-up	0	9
74148	2020-06-06 15:25:44	2020-06-06	17	[{"id_menu":4,"count":1}]	20737	delivery	5	22
74149	2020-06-06 15:29:29	2020-06-06	8	[{"id_menu":5,"count":1}]	29214	delivery	5	13
74150	2020-06-06 15:31:19	2020-06-06	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14273	delivery	5	22
74151	2020-06-06 15:39:29	2020-06-06	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29313	delivery	5	23
74152	2020-06-06 15:44:31	2020-06-06	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	29180	delivery	5	31
74153	2020-06-06 15:46:12	2020-06-06	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	29240	delivery	5	57
74154	2020-06-06 15:46:26	2020-06-06	14	[{"id_menu":2,"count":1}]	29221	delivery	5	19
74155	2020-06-06 16:00:18	2020-06-06	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	13081	delivery	5	26
74156	2020-06-06 16:01:30	2020-06-06	8	[{"id_menu":5,"count":1}]	20974	delivery	5	13
74157	2020-06-06 16:03:19	2020-06-06	17	[{"id_menu":4,"count":1}]	8748	pick-up	0	17
74158	2020-06-06 16:11:14	2020-06-06	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29207	delivery	5	46
74159	2020-06-06 16:14:35	2020-06-06	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	11586	delivery	5	38
74160	2020-06-06 16:16:15	2020-06-06	12	[{"id_menu":1,"count":1}]	16094	delivery	5	17
74161	2020-06-06 16:17:39	2020-06-06	12	[{"id_menu":3,"count":1}]	6200	delivery	5	17
74162	2020-06-06 16:20:08	2020-06-06	8	[{"id_menu":5,"count":1}]	29202	delivery	5	13
74163	2020-06-06 16:22:55	2020-06-06	8	[{"id_menu":5,"count":1}]	29193	delivery	5	13
74164	2020-06-06 16:24:07	2020-06-06	12	[{"id_menu":3,"count":1}]	13139	delivery	5	17
74165	2020-06-06 16:25:57	2020-06-06	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	29223	delivery	5	26
74166	2020-06-06 16:34:56	2020-06-06	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27054	delivery	5	43
74167	2020-06-06 16:35:40	2020-06-06	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	22126	delivery	5	36
74168	2020-06-06 16:40:34	2020-06-06	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	25032	delivery	5	43
74169	2020-06-06 16:41:01	2020-06-06	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	10111	delivery	5	26
74170	2020-06-06 16:42:14	2020-06-06	14	[{"id_menu":2,"count":1}]	18890	pick-up	0	14
74171	2020-06-06 16:43:27	2020-06-06	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	18887	delivery	5	31
74172	2020-06-06 16:47:42	2020-06-06	17	[{"id_menu":4,"count":1}]	28798	delivery	5	22
74173	2020-06-06 16:51:51	2020-06-06	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13414	delivery	5	34
74174	2020-06-06 17:00:30	2020-06-06	9	[{"id_menu":7,"count":1}]	7924	delivery	5	14
74175	2020-06-06 17:01:03	2020-06-06	9	[{"id_menu":7,"count":1}]	27936	delivery	5	14
74176	2020-06-06 17:02:30	2020-06-06	14	[{"id_menu":2,"count":1}]	29333	delivery	5	19
74177	2020-06-06 17:03:46	2020-06-06	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	16296	delivery	5	34
74178	2020-06-06 17:12:13	2020-06-06	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28650	delivery	5	53
74179	2020-06-06 17:16:29	2020-06-06	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	12204	delivery	5	27
74180	2020-06-06 17:17:04	2020-06-06	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	13498	pick-up	0	43
74181	2020-06-06 17:18:12	2020-06-06	14	[{"id_menu":2,"count":1}]	10553	pick-up	0	14
74182	2020-06-06 17:27:35	2020-06-06	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	29245	delivery	5	23
74183	2020-06-06 17:32:36	2020-06-06	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	29210	delivery	5	28
74184	2020-06-06 17:34:05	2020-06-06	9	[{"id_menu":6,"count":1}]	26557	delivery	5	14
74185	2020-06-06 17:34:15	2020-06-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	24422	delivery	5	28
74186	2020-06-06 17:35:48	2020-06-06	12	[{"id_menu":1,"count":1}]	5497	delivery	5	17
74187	2020-06-06 17:37:03	2020-06-06	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	29276	delivery	5	26
74188	2020-06-06 17:37:34	2020-06-06	17	[{"id_menu":4,"count":1}]	4049	delivery	5	22
74189	2020-06-06 17:42:27	2020-06-06	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	18940	delivery	5	22
74190	2020-06-06 17:42:46	2020-06-06	12	[{"id_menu":3,"count":1}]	5032	delivery	5	17
74191	2020-06-06 17:46:38	2020-06-06	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	27538	pick-up	0	26
74192	2020-06-06 17:49:50	2020-06-06	12	[{"id_menu":3,"count":1}]	6377	delivery	5	17
74193	2020-06-06 17:52:23	2020-06-06	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1708	delivery	5	31
74194	2020-06-06 17:52:44	2020-06-06	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19674	delivery	5	36
74195	2020-06-06 17:54:03	2020-06-06	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	29252	pick-up	0	23
74196	2020-06-06 18:02:38	2020-06-06	9	[{"id_menu":7,"count":1}]	24615	pick-up	0	9
74197	2020-06-06 18:03:31	2020-06-06	9	[{"id_menu":7,"count":1}]	2573	pick-up	0	9
74198	2020-06-06 18:03:55	2020-06-06	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	29234	delivery	5	31
74199	2020-06-06 18:04:53	2020-06-06	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	29264	delivery	5	26
74200	2020-06-06 18:06:56	2020-06-06	29	[{"id_menu":3,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29368	delivery	5	34
74201	2020-06-06 18:07:26	2020-06-06	9	[{"id_menu":7,"count":1}]	29176	delivery	5	14
74202	2020-06-06 18:12:57	2020-06-06	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	27602	delivery	5	31
74203	2020-06-06 18:13:19	2020-06-06	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	24351	delivery	5	27
74204	2020-06-06 18:13:30	2020-06-06	9	[{"id_menu":7,"count":1}]	29356	delivery	5	14
74205	2020-06-06 18:13:34	2020-06-06	12	[{"id_menu":3,"count":1}]	2068	delivery	5	17
74206	2020-06-06 18:14:52	2020-06-06	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12346	delivery	5	23
74207	2020-06-06 18:15:19	2020-06-06	9	[{"id_menu":7,"count":1}]	29294	delivery	5	14
74208	2020-06-06 18:15:46	2020-06-06	8	[{"id_menu":5,"count":1}]	29284	delivery	5	13
74209	2020-06-06 18:16:19	2020-06-06	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15146	delivery	5	35
74210	2020-06-06 18:17:23	2020-06-06	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	29296	delivery	5	26
74211	2020-06-06 18:18:52	2020-06-06	8	[{"id_menu":5,"count":1}]	6869	delivery	5	13
74212	2020-06-06 18:20:26	2020-06-06	9	[{"id_menu":6,"count":1}]	10461	delivery	5	14
74213	2020-06-06 18:21:44	2020-06-06	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	12109	delivery	5	26
74214	2020-06-06 18:22:44	2020-06-06	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5665	delivery	5	42
74215	2020-06-06 18:24:09	2020-06-06	9	[{"id_menu":6,"count":1}]	5427	pick-up	0	9
74216	2020-06-06 18:24:40	2020-06-06	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1344	pick-up	0	21
74217	2020-06-06 18:25:04	2020-06-06	9	[{"id_menu":7,"count":1}]	29185	pick-up	0	9
74218	2020-06-06 18:29:20	2020-06-06	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2025	delivery	5	22
74219	2020-06-06 18:32:14	2020-06-06	8	[{"id_menu":5,"count":1}]	28307	delivery	5	13
74220	2020-06-06 18:32:19	2020-06-06	8	[{"id_menu":5,"count":2}]	7530	delivery	5	13
74221	2020-06-06 18:36:15	2020-06-06	17	[{"id_menu":4,"count":1}]	29182	delivery	5	22
74222	2020-06-06 18:37:32	2020-06-06	9	[{"id_menu":7,"count":1}]	9084	delivery	5	14
74223	2020-06-06 18:37:38	2020-06-06	14	[{"id_menu":2,"count":1}]	14128	delivery	5	19
74224	2020-06-06 18:37:43	2020-06-06	9	[{"id_menu":6,"count":1}]	29235	delivery	5	14
74225	2020-06-06 18:38:55	2020-06-06	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	29261	delivery	5	22
74226	2020-06-06 18:47:15	2020-06-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	21456	delivery	5	28
74227	2020-06-06 18:51:24	2020-06-06	14	[{"id_menu":2,"count":1}]	26928	delivery	5	19
74228	2020-06-06 18:57:32	2020-06-06	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	9941	delivery	5	31
74229	2020-06-06 19:01:36	2020-06-06	12	[{"id_menu":3,"count":1}]	13477	pick-up	0	12
74230	2020-06-06 19:02:58	2020-06-06	9	[{"id_menu":7,"count":1}]	29265	delivery	5	14
74231	2020-06-06 19:03:09	2020-06-06	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21779	delivery	5	40
74232	2020-06-06 19:04:44	2020-06-06	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	29367	pick-up	0	40
74233	2020-06-06 19:05:22	2020-06-06	9	[{"id_menu":6,"count":2}]	4535	delivery	5	14
74234	2020-06-06 19:07:50	2020-06-06	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	7608	delivery	5	31
74235	2020-06-06 19:08:53	2020-06-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	10306	delivery	5	28
74236	2020-06-06 19:09:07	2020-06-06	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29297	delivery	5	49
74237	2020-06-06 19:11:22	2020-06-06	8	[{"id_menu":5,"count":1}]	29287	delivery	5	13
74238	2020-06-06 19:12:31	2020-06-06	12	[{"id_menu":1,"count":1}]	29213	delivery	5	17
74239	2020-06-06 19:15:44	2020-06-06	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	29270	delivery	5	39
74240	2020-06-06 19:22:56	2020-06-06	8	[{"id_menu":5,"count":1}]	10142	pick-up	0	8
74241	2020-06-06 19:23:27	2020-06-06	9	[{"id_menu":6,"count":1}]	21488	delivery	5	14
74242	2020-06-06 19:26:23	2020-06-06	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":3}]	29334	delivery	5	23
74243	2020-06-06 19:28:08	2020-06-06	17	[{"id_menu":4,"count":2}]	29249	delivery	5	22
74244	2020-06-06 19:29:35	2020-06-06	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	6989	delivery	5	27
74245	2020-06-06 19:29:59	2020-06-06	14	[{"id_menu":2,"count":1}]	29299	delivery	5	19
74246	2020-06-06 19:30:52	2020-06-06	17	[{"id_menu":4,"count":1}]	16114	pick-up	0	17
74247	2020-06-06 19:47:52	2020-06-06	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29309	delivery	5	35
74248	2020-06-06 19:48:03	2020-06-06	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	13137	delivery	5	29
74249	2020-06-06 19:50:27	2020-06-06	14	[{"id_menu":2,"count":1}]	20408	delivery	5	19
74250	2020-06-06 19:50:36	2020-06-06	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29258	delivery	5	35
74251	2020-06-06 19:52:16	2020-06-06	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2564	delivery	5	30
74252	2020-06-06 19:56:27	2020-06-06	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	9783	delivery	5	43
74253	2020-06-06 19:57:43	2020-06-06	14	[{"id_menu":2,"count":1}]	16514	delivery	5	19
74254	2020-06-06 19:59:23	2020-06-06	9	[{"id_menu":7,"count":1}]	14754	delivery	5	14
74255	2020-06-06 20:00:17	2020-06-06	9	[{"id_menu":6,"count":1}]	7097	pick-up	0	9
74256	2020-06-06 20:04:41	2020-06-06	17	[{"id_menu":4,"count":1}]	8348	delivery	5	22
74257	2020-06-06 20:05:09	2020-06-06	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	29330	delivery	5	34
74258	2020-06-06 20:09:44	2020-06-06	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	29308	delivery	5	31
74259	2020-06-06 20:10:02	2020-06-06	12	[{"id_menu":3,"count":1}]	24988	delivery	5	17
74260	2020-06-06 20:10:34	2020-06-06	12	[{"id_menu":1,"count":1}]	14871	pick-up	0	12
74261	2020-06-06 20:11:02	2020-06-06	17	[{"id_menu":4,"count":1}]	1713	delivery	5	22
74262	2020-06-06 20:11:04	2020-06-06	8	[{"id_menu":5,"count":4}]	4245	pick-up	0	8
74263	2020-06-06 20:15:07	2020-06-06	9	[{"id_menu":6,"count":1}]	13001	delivery	5	14
74264	2020-06-06 20:16:01	2020-06-06	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1582	pick-up	0	26
74265	2020-06-06 20:20:43	2020-06-06	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	6840	delivery	5	23
74266	2020-06-06 20:23:12	2020-06-06	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5786	delivery	5	22
74267	2020-06-06 20:23:28	2020-06-06	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4195	pick-up	0	22
74268	2020-06-06 20:23:49	2020-06-06	12	[{"id_menu":3,"count":1}]	3372	delivery	5	17
74269	2020-06-06 20:25:44	2020-06-06	9	[{"id_menu":7,"count":1}]	11144	delivery	5	14
74270	2020-06-06 20:27:31	2020-06-06	14	[{"id_menu":2,"count":1}]	29195	delivery	5	19
74271	2020-06-06 20:28:08	2020-06-06	14	[{"id_menu":2,"count":1}]	24110	delivery	5	19
74272	2020-06-06 20:30:22	2020-06-06	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	22795	delivery	5	31
74273	2020-06-06 20:30:26	2020-06-06	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21203	pick-up	0	18
74274	2020-06-06 20:30:48	2020-06-06	17	[{"id_menu":4,"count":1}]	8384	pick-up	0	17
74275	2020-06-06 20:38:50	2020-06-06	38	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	29341	delivery	5	43
74276	2020-06-06 20:41:26	2020-06-06	8	[{"id_menu":5,"count":1}]	29279	delivery	5	13
74277	2020-06-06 20:43:11	2020-06-06	12	[{"id_menu":1,"count":1}]	135	pick-up	0	12
74278	2020-06-06 20:50:58	2020-06-06	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	21474	delivery	5	43
74279	2020-06-06 20:56:56	2020-06-06	12	[{"id_menu":1,"count":1}]	1992	pick-up	0	12
74280	2020-06-06 20:59:25	2020-06-06	8	[{"id_menu":5,"count":1}]	4492	delivery	5	13
74281	2020-06-06 20:59:59	2020-06-06	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1588	delivery	5	39
74282	2020-06-06 21:03:06	2020-06-06	9	[{"id_menu":6,"count":1}]	784	delivery	5	14
74283	2020-06-06 21:22:28	2020-06-06	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11560	delivery	5	23
74284	2020-06-06 21:22:31	2020-06-06	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	29352	delivery	5	31
74285	2020-06-06 21:23:08	2020-06-06	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	23925	delivery	5	36
74286	2020-06-06 21:24:43	2020-06-06	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	29254	delivery	5	25
74287	2020-06-06 21:29:57	2020-06-06	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18312	delivery	5	31
74288	2020-06-06 21:31:33	2020-06-06	12	[{"id_menu":1,"count":1}]	11928	delivery	5	17
74289	2020-06-06 21:36:06	2020-06-06	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29285	delivery	5	34
74290	2020-06-06 21:40:31	2020-06-06	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	18125	delivery	5	40
74291	2020-06-06 21:42:46	2020-06-06	17	[{"id_menu":4,"count":1}]	7983	pick-up	0	17
74292	2020-06-06 21:44:42	2020-06-06	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	25071	delivery	5	40
74293	2020-06-06 21:44:55	2020-06-06	12	[{"id_menu":1,"count":1}]	29228	delivery	5	17
74294	2020-06-06 21:45:09	2020-06-06	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	27188	delivery	5	36
74295	2020-06-06 21:46:43	2020-06-06	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	4436	pick-up	0	24
74296	2020-06-06 21:48:19	2020-06-06	14	[{"id_menu":2,"count":1}]	23563	delivery	5	19
74297	2020-06-06 21:50:37	2020-06-06	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29255	delivery	5	22
74298	2020-06-06 21:50:45	2020-06-06	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20157	delivery	5	39
74299	2020-06-06 21:51:26	2020-06-06	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4655	delivery	5	51
74300	2020-06-06 21:52:53	2020-06-06	9	[{"id_menu":6,"count":1}]	29338	pick-up	0	9
74301	2020-06-06 21:58:42	2020-06-06	9	[{"id_menu":6,"count":1}]	10499	delivery	5	14
74302	2020-06-06 22:00:26	2020-06-06	9	[{"id_menu":7,"count":1}]	29286	delivery	5	14
74303	2020-06-06 22:00:43	2020-06-06	9	[{"id_menu":6,"count":1}]	29203	delivery	5	14
74304	2020-06-06 22:03:52	2020-06-06	9	[{"id_menu":7,"count":1}]	13042	delivery	5	14
74305	2020-06-06 22:06:12	2020-06-06	14	[{"id_menu":2,"count":1}]	19596	delivery	5	19
74306	2020-06-06 22:08:53	2020-06-06	12	[{"id_menu":1,"count":1}]	6019	delivery	5	17
74307	2020-06-06 22:12:50	2020-06-06	12	[{"id_menu":3,"count":1}]	25975	delivery	5	17
74308	2020-06-06 22:15:29	2020-06-06	8	[{"id_menu":5,"count":1}]	21460	pick-up	0	8
74309	2020-06-06 22:15:58	2020-06-06	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4242	pick-up	0	35
74310	2020-06-06 22:19:53	2020-06-06	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	9626	delivery	5	22
74311	2020-06-06 22:21:22	2020-06-06	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	29217	delivery	5	31
74312	2020-06-06 22:23:00	2020-06-06	9	[{"id_menu":7,"count":1}]	29246	delivery	5	14
74313	2020-06-06 22:26:16	2020-06-06	8	[{"id_menu":5,"count":1}]	11093	delivery	5	13
74314	2020-06-06 22:31:43	2020-06-06	17	[{"id_menu":4,"count":1}]	29186	delivery	5	22
74315	2020-06-06 22:34:55	2020-06-06	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	10436	delivery	5	45
74316	2020-06-06 22:45:13	2020-06-06	9	[{"id_menu":7,"count":1}]	20216	pick-up	0	9
74317	2020-06-06 22:50:59	2020-06-06	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	29204	delivery	5	48
74318	2020-06-06 22:53:05	2020-06-06	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	29188	delivery	5	31
74319	2020-06-06 22:53:26	2020-06-06	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	25453	delivery	5	30
74320	2020-06-06 22:58:50	2020-06-06	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	16512	delivery	5	26
74321	2020-06-06 23:00:28	2020-06-06	8	[{"id_menu":5,"count":2}]	12129	pick-up	0	8
74322	2020-06-06 23:02:10	2020-06-06	14	[{"id_menu":2,"count":1}]	26274	delivery	5	19
74323	2020-06-06 23:20:30	2020-06-06	9	[{"id_menu":6,"count":1}]	5232	pick-up	0	9
74324	2020-06-06 23:23:26	2020-06-06	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29364	pick-up	0	31
74325	2020-06-06 23:30:35	2020-06-06	17	[{"id_menu":4,"count":1}]	28974	delivery	5	22
74326	2020-06-06 23:33:43	2020-06-06	12	[{"id_menu":3,"count":1}]	19442	pick-up	0	12
74327	2020-06-06 23:33:47	2020-06-06	8	[{"id_menu":5,"count":1}]	29357	pick-up	0	8
74328	2020-06-06 23:34:05	2020-06-06	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	437	delivery	5	48
74329	2020-06-06 23:37:04	2020-06-06	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	24359	delivery	5	46
74330	2020-06-06 23:39:38	2020-06-06	8	[{"id_menu":5,"count":1}]	24547	pick-up	0	8
74331	2020-06-06 23:41:25	2020-06-06	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	29181	delivery	5	34
74332	2020-06-06 23:47:17	2020-06-06	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	29321	delivery	5	45
74333	2020-06-06 23:51:59	2020-06-06	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	29257	delivery	5	22
74334	2020-06-06 23:53:09	2020-06-06	8	[{"id_menu":5,"count":1}]	29316	delivery	5	13
74335	2020-06-06 23:55:08	2020-06-06	12	[{"id_menu":3,"count":1}]	826	delivery	5	17
74336	2020-06-07 00:03:06	2020-06-07	17	[{"id_menu":4,"count":2}]	9814	delivery	5	22
74337	2020-06-07 00:03:13	2020-06-07	9	[{"id_menu":6,"count":1}]	27937	delivery	5	14
74338	2020-06-07 00:06:53	2020-06-07	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	29546	delivery	5	31
74339	2020-06-07 00:09:29	2020-06-07	9	[{"id_menu":6,"count":1}]	22680	delivery	5	14
74340	2020-06-07 00:11:33	2020-06-07	8	[{"id_menu":5,"count":1}]	29512	delivery	5	13
74341	2020-06-07 00:13:57	2020-06-07	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	2965	delivery	5	31
74342	2020-06-07 00:19:33	2020-06-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	24585	pick-up	0	23
74343	2020-06-07 00:20:02	2020-06-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	29483	delivery	5	28
74344	2020-06-07 00:21:58	2020-06-07	12	[{"id_menu":1,"count":1}]	20379	pick-up	0	12
74345	2020-06-07 00:25:18	2020-06-07	14	[{"id_menu":2,"count":1}]	29386	delivery	5	19
74346	2020-06-07 00:25:31	2020-06-07	9	[{"id_menu":6,"count":1}]	7374	delivery	5	14
74347	2020-06-07 00:34:29	2020-06-07	9	[{"id_menu":6,"count":1}]	27781	delivery	5	14
74348	2020-06-07 00:35:13	2020-06-07	14	[{"id_menu":2,"count":1}]	10772	delivery	5	19
74349	2020-06-07 00:38:30	2020-06-07	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	29430	delivery	5	34
74350	2020-06-07 00:39:08	2020-06-07	12	[{"id_menu":1,"count":1}]	29527	delivery	5	17
74351	2020-06-07 00:39:28	2020-06-07	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	26150	pick-up	0	26
74352	2020-06-07 00:39:36	2020-06-07	8	[{"id_menu":5,"count":1}]	9071	delivery	5	13
74353	2020-06-07 00:41:43	2020-06-07	12	[{"id_menu":1,"count":1}]	29433	delivery	5	17
74354	2020-06-07 00:44:58	2020-06-07	9	[{"id_menu":7,"count":1}]	7119	delivery	5	14
74355	2020-06-07 00:48:29	2020-06-07	9	[{"id_menu":7,"count":1}]	11665	delivery	5	14
74356	2020-06-07 00:52:12	2020-06-07	12	[{"id_menu":1,"count":1}]	9305	delivery	5	17
74357	2020-06-07 00:52:17	2020-06-07	17	[{"id_menu":4,"count":1}]	12018	delivery	5	22
74358	2020-06-07 00:56:38	2020-06-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	29439	delivery	5	28
74359	2020-06-07 01:03:22	2020-06-07	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	6623	delivery	5	43
74360	2020-06-07 01:07:37	2020-06-07	8	[{"id_menu":5,"count":1}]	16384	delivery	5	13
74361	2020-06-07 01:07:39	2020-06-07	9	[{"id_menu":7,"count":1}]	29381	delivery	5	14
74362	2020-06-07 01:08:54	2020-06-07	9	[{"id_menu":6,"count":1}]	29392	delivery	5	14
74363	2020-06-07 01:10:11	2020-06-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3755	pick-up	0	17
74364	2020-06-07 01:10:16	2020-06-07	12	[{"id_menu":1,"count":1}]	27671	delivery	5	17
74365	2020-06-07 01:11:15	2020-06-07	9	[{"id_menu":6,"count":1}]	11005	delivery	5	14
74366	2020-06-07 01:15:19	2020-06-07	17	[{"id_menu":4,"count":1}]	29419	pick-up	0	17
74367	2020-06-07 01:17:27	2020-06-07	17	[{"id_menu":4,"count":1}]	13707	pick-up	0	17
74368	2020-06-07 01:19:00	2020-06-07	9	[{"id_menu":7,"count":1}]	13970	delivery	5	14
74369	2020-06-07 01:19:09	2020-06-07	12	[{"id_menu":1,"count":1}]	29415	delivery	5	17
74370	2020-06-07 01:23:09	2020-06-07	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	8167	delivery	5	36
74371	2020-06-07 01:28:53	2020-06-07	9	[{"id_menu":6,"count":1}]	14127	pick-up	0	9
74372	2020-06-07 01:32:34	2020-06-07	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	29552	delivery	5	39
74373	2020-06-07 01:35:03	2020-06-07	8	[{"id_menu":5,"count":1}]	22518	pick-up	0	8
74374	2020-06-07 01:35:22	2020-06-07	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":3}]	12464	delivery	5	34
74375	2020-06-07 01:38:32	2020-06-07	9	[{"id_menu":7,"count":1}]	29534	delivery	5	14
74376	2020-06-07 01:39:28	2020-06-07	14	[{"id_menu":2,"count":1}]	13806	pick-up	0	14
74377	2020-06-07 01:43:01	2020-06-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13940	delivery	5	23
74378	2020-06-07 01:43:11	2020-06-07	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	7768	delivery	5	34
74379	2020-06-07 01:43:13	2020-06-07	9	[{"id_menu":6,"count":1}]	823	delivery	5	14
74380	2020-06-07 01:44:39	2020-06-07	8	[{"id_menu":5,"count":1}]	7642	delivery	5	13
74381	2020-06-07 01:47:58	2020-06-07	14	[{"id_menu":2,"count":1}]	29407	delivery	5	19
74382	2020-06-07 01:52:34	2020-06-07	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7806	pick-up	0	31
74383	2020-06-07 01:52:46	2020-06-07	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	26324	delivery	5	40
74384	2020-06-07 01:54:25	2020-06-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29444	delivery	5	23
74385	2020-06-07 01:55:43	2020-06-07	12	[{"id_menu":1,"count":1}]	688	delivery	5	17
74386	2020-06-07 02:00:33	2020-06-07	9	[{"id_menu":6,"count":1}]	7496	delivery	5	14
74387	2020-06-07 02:00:55	2020-06-07	14	[{"id_menu":2,"count":1}]	10945	delivery	5	19
74388	2020-06-07 02:03:16	2020-06-07	9	[{"id_menu":6,"count":1}]	4379	delivery	5	14
74389	2020-06-07 02:06:10	2020-06-07	9	[{"id_menu":7,"count":1}]	3049	delivery	5	14
74390	2020-06-07 02:10:02	2020-06-07	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	11576	delivery	5	46
74391	2020-06-07 02:12:07	2020-06-07	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25533	delivery	5	39
74392	2020-06-07 02:14:20	2020-06-07	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29380	delivery	5	31
74393	2020-06-07 02:17:39	2020-06-07	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	20216	pick-up	0	24
74394	2020-06-07 02:20:57	2020-06-07	8	[{"id_menu":5,"count":1}]	29498	delivery	5	13
74395	2020-06-07 02:21:13	2020-06-07	12	[{"id_menu":3,"count":1}]	3526	delivery	5	17
74396	2020-06-07 02:22:50	2020-06-07	9	[{"id_menu":6,"count":1}]	29420	delivery	5	14
74397	2020-06-07 02:24:26	2020-06-07	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	29517	delivery	5	22
74398	2020-06-07 02:24:43	2020-06-07	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	25259	delivery	5	25
74399	2020-06-07 02:25:06	2020-06-07	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	29468	delivery	5	25
74400	2020-06-07 02:26:16	2020-06-07	8	[{"id_menu":5,"count":1}]	6314	delivery	5	13
74401	2020-06-07 02:30:55	2020-06-07	14	[{"id_menu":2,"count":1}]	7941	pick-up	0	14
74402	2020-06-07 02:31:05	2020-06-07	9	[{"id_menu":6,"count":1}]	1588	delivery	5	14
74403	2020-06-07 02:32:09	2020-06-07	9	[{"id_menu":7,"count":1}]	16831	delivery	5	14
74404	2020-06-07 02:34:13	2020-06-07	17	[{"id_menu":4,"count":1}]	12338	pick-up	0	17
74405	2020-06-07 02:37:51	2020-06-07	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	17672	delivery	5	36
74406	2020-06-07 02:38:15	2020-06-07	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7876	delivery	5	43
74407	2020-06-07 02:39:22	2020-06-07	9	[{"id_menu":6,"count":1}]	23451	delivery	5	14
74408	2020-06-07 02:40:38	2020-06-07	17	[{"id_menu":4,"count":1}]	29452	pick-up	0	17
74409	2020-06-07 02:40:46	2020-06-07	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2511	pick-up	0	26
74410	2020-06-07 02:43:02	2020-06-07	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	10151	pick-up	0	21
74411	2020-06-07 02:43:09	2020-06-07	12	[{"id_menu":3,"count":1}]	2637	delivery	5	17
74412	2020-06-07 02:43:31	2020-06-07	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26588	delivery	5	40
74413	2020-06-07 02:44:46	2020-06-07	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	20819	delivery	5	31
74414	2020-06-07 02:45:21	2020-06-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1654	pick-up	0	21
74415	2020-06-07 02:47:24	2020-06-07	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	28109	delivery	5	36
74416	2020-06-07 02:48:40	2020-06-07	17	[{"id_menu":4,"count":1}]	22240	delivery	5	22
74417	2020-06-07 02:49:16	2020-06-07	17	[{"id_menu":4,"count":1}]	1010	pick-up	0	17
74418	2020-06-07 02:49:52	2020-06-07	12	[{"id_menu":3,"count":1}]	20704	delivery	5	17
74419	2020-06-07 02:51:08	2020-06-07	12	[{"id_menu":3,"count":1}]	12670	delivery	5	17
74420	2020-06-07 02:51:59	2020-06-07	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1156	pick-up	0	25
74421	2020-06-07 02:54:34	2020-06-07	14	[{"id_menu":2,"count":1}]	15202	delivery	5	19
74422	2020-06-07 03:01:34	2020-06-07	9	[{"id_menu":7,"count":1}]	18151	delivery	5	14
74423	2020-06-07 03:07:05	2020-06-07	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	29382	delivery	5	30
74424	2020-06-07 03:08:31	2020-06-07	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	27082	pick-up	0	43
74425	2020-06-07 03:09:07	2020-06-07	8	[{"id_menu":5,"count":1}]	3473	delivery	5	13
74426	2020-06-07 03:15:20	2020-06-07	14	[{"id_menu":2,"count":1}]	21791	delivery	5	19
74427	2020-06-07 03:15:43	2020-06-07	12	[{"id_menu":1,"count":1}]	29478	delivery	5	17
74428	2020-06-07 03:21:23	2020-06-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	13899	delivery	5	26
74429	2020-06-07 03:29:57	2020-06-07	14	[{"id_menu":2,"count":1}]	16677	pick-up	0	14
74430	2020-06-07 03:32:19	2020-06-07	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	25086	delivery	5	43
74431	2020-06-07 03:33:13	2020-06-07	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7338	delivery	5	31
74432	2020-06-07 03:36:01	2020-06-07	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	20914	delivery	5	36
74433	2020-06-07 03:36:53	2020-06-07	17	[{"id_menu":4,"count":1}]	12053	pick-up	0	17
74434	2020-06-07 03:39:02	2020-06-07	9	[{"id_menu":7,"count":1}]	26603	delivery	5	14
74435	2020-06-07 03:39:32	2020-06-07	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1352	pick-up	0	25
74436	2020-06-07 03:41:10	2020-06-07	12	[{"id_menu":1,"count":1}]	17232	delivery	5	17
74437	2020-06-07 03:42:32	2020-06-07	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3189	pick-up	0	40
74438	2020-06-07 03:43:13	2020-06-07	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":3}]	29428	delivery	5	29
74439	2020-06-07 03:45:01	2020-06-07	9	[{"id_menu":6,"count":1}]	16226	pick-up	0	9
74440	2020-06-07 03:45:42	2020-06-07	14	[{"id_menu":2,"count":1}]	25209	delivery	5	19
74441	2020-06-07 03:46:36	2020-06-07	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	5758	delivery	5	25
74442	2020-06-07 03:50:23	2020-06-07	9	[{"id_menu":6,"count":1}]	29438	delivery	5	14
74443	2020-06-07 03:50:59	2020-06-07	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24295	delivery	5	22
74444	2020-06-07 03:54:09	2020-06-07	8	[{"id_menu":5,"count":1}]	29540	pick-up	0	8
74445	2020-06-07 03:59:06	2020-06-07	8	[{"id_menu":5,"count":1}]	22186	delivery	5	13
74446	2020-06-07 04:04:23	2020-06-07	8	[{"id_menu":5,"count":1}]	26385	delivery	5	13
74447	2020-06-07 04:09:27	2020-06-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	138	pick-up	0	23
74448	2020-06-07 04:11:08	2020-06-07	9	[{"id_menu":6,"count":1}]	12952	delivery	5	14
74449	2020-06-07 04:11:23	2020-06-07	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	29537	delivery	5	36
74450	2020-06-07 04:17:18	2020-06-07	12	[{"id_menu":3,"count":1}]	807	pick-up	0	12
74451	2020-06-07 04:20:03	2020-06-07	9	[{"id_menu":7,"count":1}]	29389	pick-up	0	9
74452	2020-06-07 04:22:11	2020-06-07	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	21983	delivery	5	23
74453	2020-06-07 04:22:11	2020-06-07	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29408	delivery	5	45
74454	2020-06-07 04:25:21	2020-06-07	12	[{"id_menu":1,"count":1}]	1819	pick-up	0	12
74455	2020-06-07 04:30:28	2020-06-07	9	[{"id_menu":6,"count":1}]	29503	delivery	5	14
74456	2020-06-07 04:30:52	2020-06-07	9	[{"id_menu":7,"count":1}]	14843	pick-up	0	9
74457	2020-06-07 04:31:52	2020-06-07	17	[{"id_menu":4,"count":1}]	14736	delivery	5	22
74458	2020-06-07 04:32:11	2020-06-07	17	[{"id_menu":4,"count":2}]	10421	delivery	5	22
74459	2020-06-07 04:35:03	2020-06-07	9	[{"id_menu":7,"count":1}]	10311	delivery	5	14
74460	2020-06-07 04:35:36	2020-06-07	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14103	delivery	5	36
74461	2020-06-07 04:35:49	2020-06-07	9	[{"id_menu":6,"count":1}]	18567	delivery	5	14
74462	2020-06-07 04:39:08	2020-06-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29536	delivery	5	23
74463	2020-06-07 04:44:23	2020-06-07	14	[{"id_menu":2,"count":1}]	8407	pick-up	0	14
74464	2020-06-07 04:45:18	2020-06-07	9	[{"id_menu":7,"count":2}]	16876	delivery	5	14
74465	2020-06-07 04:45:50	2020-06-07	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	13493	delivery	5	26
74466	2020-06-07 04:49:15	2020-06-07	17	[{"id_menu":4,"count":2}]	4654	pick-up	0	17
74467	2020-06-07 04:55:04	2020-06-07	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	20189	delivery	5	57
74468	2020-06-07 04:55:43	2020-06-07	8	[{"id_menu":5,"count":1}]	18166	delivery	5	13
74469	2020-06-07 05:01:36	2020-06-07	9	[{"id_menu":7,"count":1}]	3971	pick-up	0	9
74470	2020-06-07 05:05:00	2020-06-07	9	[{"id_menu":6,"count":1}]	29406	pick-up	0	9
74471	2020-06-07 05:05:04	2020-06-07	9	[{"id_menu":7,"count":1}]	29523	pick-up	0	9
74472	2020-06-07 05:06:03	2020-06-07	12	[{"id_menu":3,"count":1}]	9716	pick-up	0	12
74473	2020-06-07 05:12:22	2020-06-07	12	[{"id_menu":1,"count":1}]	28827	delivery	5	17
74474	2020-06-07 05:14:53	2020-06-07	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	5215	delivery	5	27
74475	2020-06-07 05:17:35	2020-06-07	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	26149	delivery	5	34
74476	2020-06-07 05:19:20	2020-06-07	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29432	delivery	5	31
74477	2020-06-07 05:26:31	2020-06-07	14	[{"id_menu":2,"count":1}]	9035	pick-up	0	14
74478	2020-06-07 05:27:21	2020-06-07	14	[{"id_menu":2,"count":1}]	4462	pick-up	0	14
74479	2020-06-07 05:32:38	2020-06-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	29437	delivery	5	22
74480	2020-06-07 05:35:46	2020-06-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29482	delivery	5	22
74481	2020-06-07 05:39:41	2020-06-07	12	[{"id_menu":1,"count":1}]	29529	delivery	5	17
74482	2020-06-07 05:40:16	2020-06-07	17	[{"id_menu":4,"count":1}]	4592	delivery	5	22
74483	2020-06-07 05:46:06	2020-06-07	12	[{"id_menu":1,"count":1}]	29440	delivery	5	17
74484	2020-06-07 05:46:35	2020-06-07	9	[{"id_menu":7,"count":1}]	16752	delivery	5	14
74485	2020-06-07 05:46:53	2020-06-07	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	21644	pick-up	0	39
74486	2020-06-07 05:48:21	2020-06-07	9	[{"id_menu":7,"count":1}]	15437	delivery	5	14
74487	2020-06-07 05:58:43	2020-06-07	8	[{"id_menu":5,"count":1}]	29554	delivery	5	13
74488	2020-06-07 05:59:40	2020-06-07	14	[{"id_menu":2,"count":1}]	6205	delivery	5	19
74489	2020-06-07 05:59:41	2020-06-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	29455	delivery	5	28
74490	2020-06-07 05:59:46	2020-06-07	17	[{"id_menu":4,"count":1}]	5780	pick-up	0	17
74491	2020-06-07 06:02:44	2020-06-07	17	[{"id_menu":4,"count":1}]	29505	delivery	5	22
74492	2020-06-07 06:08:42	2020-06-07	9	[{"id_menu":7,"count":1}]	29372	delivery	5	14
74493	2020-06-07 06:10:12	2020-06-07	9	[{"id_menu":6,"count":2}]	23099	delivery	5	14
74494	2020-06-07 06:10:35	2020-06-07	14	[{"id_menu":2,"count":1}]	8466	delivery	5	19
74495	2020-06-07 06:11:36	2020-06-07	14	[{"id_menu":2,"count":1}]	4870	pick-up	0	14
74496	2020-06-07 06:18:08	2020-06-07	14	[{"id_menu":2,"count":1}]	29506	delivery	5	19
74497	2020-06-07 06:18:37	2020-06-07	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10283	pick-up	0	26
74498	2020-06-07 06:21:27	2020-06-07	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24716	delivery	5	39
74499	2020-06-07 06:23:16	2020-06-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2560	pick-up	0	18
74500	2020-06-07 06:26:26	2020-06-07	12	[{"id_menu":3,"count":1}]	27863	pick-up	0	12
74501	2020-06-07 06:27:00	2020-06-07	14	[{"id_menu":2,"count":1}]	29560	delivery	5	19
74502	2020-06-07 06:27:09	2020-06-07	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	2050	pick-up	0	23
74503	2020-06-07 06:35:01	2020-06-07	17	[{"id_menu":4,"count":1}]	12230	delivery	5	22
74504	2020-06-07 06:35:27	2020-06-07	8	[{"id_menu":5,"count":1}]	29404	delivery	5	13
74505	2020-06-07 06:37:08	2020-06-07	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	25841	delivery	5	38
74506	2020-06-07 06:37:56	2020-06-07	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13328	delivery	5	22
74507	2020-06-07 06:39:41	2020-06-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	9763	delivery	5	28
74508	2020-06-07 06:40:40	2020-06-07	9	[{"id_menu":7,"count":1}]	20816	delivery	5	14
74509	2020-06-07 06:43:37	2020-06-07	8	[{"id_menu":5,"count":1}]	29376	delivery	5	13
74510	2020-06-07 06:44:16	2020-06-07	8	[{"id_menu":5,"count":1}]	22235	delivery	5	13
74511	2020-06-07 06:46:55	2020-06-07	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	29467	delivery	5	27
74512	2020-06-07 06:47:37	2020-06-07	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1541	delivery	5	25
74513	2020-06-07 06:48:02	2020-06-07	12	[{"id_menu":1,"count":1}]	271	pick-up	0	12
74514	2020-06-07 06:48:22	2020-06-07	9	[{"id_menu":7,"count":1}]	27240	delivery	5	14
74515	2020-06-07 06:48:26	2020-06-07	17	[{"id_menu":4,"count":1}]	13858	pick-up	0	17
74516	2020-06-07 06:50:59	2020-06-07	17	[{"id_menu":4,"count":1}]	21785	delivery	5	22
74517	2020-06-07 06:55:35	2020-06-07	9	[{"id_menu":6,"count":1}]	18988	delivery	5	14
74518	2020-06-07 06:58:24	2020-06-07	14	[{"id_menu":2,"count":1}]	2561	pick-up	0	14
74519	2020-06-07 06:59:51	2020-06-07	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	16496	delivery	5	28
74520	2020-06-07 07:02:16	2020-06-07	9	[{"id_menu":6,"count":1}]	20139	delivery	5	14
74521	2020-06-07 07:04:40	2020-06-07	9	[{"id_menu":7,"count":1}]	29472	delivery	5	14
74522	2020-06-07 07:04:50	2020-06-07	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3224	pick-up	0	34
74523	2020-06-07 07:05:35	2020-06-07	9	[{"id_menu":7,"count":1}]	7983	pick-up	0	9
74524	2020-06-07 07:05:59	2020-06-07	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	29451	delivery	5	26
74525	2020-06-07 07:06:43	2020-06-07	8	[{"id_menu":5,"count":1}]	29497	delivery	5	13
74526	2020-06-07 07:14:42	2020-06-07	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8864	delivery	5	37
74527	2020-06-07 07:17:51	2020-06-07	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	8050	delivery	5	40
74528	2020-06-07 07:19:43	2020-06-07	9	[{"id_menu":6,"count":1}]	6331	delivery	5	14
74529	2020-06-07 07:21:41	2020-06-07	14	[{"id_menu":2,"count":1}]	29508	delivery	5	19
74530	2020-06-07 07:22:24	2020-06-07	12	[{"id_menu":3,"count":1}]	2078	pick-up	0	12
74531	2020-06-07 07:22:36	2020-06-07	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	2825	delivery	5	28
74532	2020-06-07 07:22:42	2020-06-07	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12180	delivery	5	35
74533	2020-06-07 07:22:42	2020-06-07	9	[{"id_menu":6,"count":1}]	29473	delivery	5	14
74534	2020-06-07 07:23:20	2020-06-07	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	21570	delivery	5	36
74535	2020-06-07 07:23:31	2020-06-07	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	29486	pick-up	0	26
74536	2020-06-07 07:24:51	2020-06-07	8	[{"id_menu":5,"count":1}]	1318	delivery	5	13
74537	2020-06-07 07:26:37	2020-06-07	8	[{"id_menu":5,"count":1}]	29403	delivery	5	13
74538	2020-06-07 07:27:12	2020-06-07	9	[{"id_menu":7,"count":1}]	29378	delivery	5	14
74539	2020-06-07 07:27:21	2020-06-07	12	[{"id_menu":3,"count":1}]	29535	delivery	5	17
74540	2020-06-07 07:31:14	2020-06-07	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1656	delivery	5	40
74541	2020-06-07 07:35:39	2020-06-07	17	[{"id_menu":4,"count":1}]	5027	pick-up	0	17
74542	2020-06-07 07:37:32	2020-06-07	21	[{"id_menu":3,"count":3},{"id_menu":6,"count":1}]	722	pick-up	0	21
74543	2020-06-07 07:42:52	2020-06-07	12	[{"id_menu":1,"count":1}]	12210	delivery	5	17
74544	2020-06-07 07:45:57	2020-06-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29558	delivery	5	22
74545	2020-06-07 07:47:00	2020-06-07	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	18617	delivery	5	26
74546	2020-06-07 07:47:03	2020-06-07	12	[{"id_menu":3,"count":1}]	2523	pick-up	0	12
74547	2020-06-07 07:48:40	2020-06-07	14	[{"id_menu":2,"count":1}]	3333	delivery	5	19
74548	2020-06-07 07:48:44	2020-06-07	9	[{"id_menu":7,"count":1}]	29212	delivery	5	14
74549	2020-06-07 07:49:47	2020-06-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	25827	pick-up	0	23
74550	2020-06-07 07:52:59	2020-06-07	8	[{"id_menu":5,"count":1}]	29412	delivery	5	13
74551	2020-06-07 07:56:06	2020-06-07	12	[{"id_menu":3,"count":1}]	29458	pick-up	0	12
74552	2020-06-07 07:56:30	2020-06-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6826	delivery	5	23
74553	2020-06-07 07:57:14	2020-06-07	12	[{"id_menu":1,"count":1}]	11552	delivery	5	17
74554	2020-06-07 07:57:15	2020-06-07	8	[{"id_menu":5,"count":1}]	19911	delivery	5	13
74555	2020-06-07 07:57:56	2020-06-07	9	[{"id_menu":7,"count":1}]	18773	delivery	5	14
74556	2020-06-07 08:01:58	2020-06-07	14	[{"id_menu":2,"count":1}]	12909	delivery	5	19
74557	2020-06-07 08:02:20	2020-06-07	8	[{"id_menu":5,"count":1}]	9266	delivery	5	13
74558	2020-06-07 08:03:18	2020-06-07	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29434	delivery	5	37
74559	2020-06-07 08:04:50	2020-06-07	12	[{"id_menu":3,"count":1}]	29379	delivery	5	17
74560	2020-06-07 08:05:06	2020-06-07	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	20026	delivery	5	34
74561	2020-06-07 08:05:41	2020-06-07	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	25318	pick-up	0	35
74562	2020-06-07 08:08:36	2020-06-07	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	26304	delivery	5	25
74563	2020-06-07 08:08:55	2020-06-07	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	14870	delivery	5	42
74564	2020-06-07 08:09:16	2020-06-07	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8876	delivery	5	44
74565	2020-06-07 08:09:20	2020-06-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	1142	delivery	5	22
74566	2020-06-07 08:13:59	2020-06-07	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	29489	delivery	5	26
74567	2020-06-07 08:16:06	2020-06-07	9	[{"id_menu":6,"count":1}]	20014	delivery	5	14
74568	2020-06-07 08:17:44	2020-06-07	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3053	pick-up	0	22
74569	2020-06-07 08:20:27	2020-06-07	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	16813	delivery	5	26
74570	2020-06-07 08:22:21	2020-06-07	12	[{"id_menu":3,"count":1}]	21316	delivery	5	17
74571	2020-06-07 08:26:57	2020-06-07	9	[{"id_menu":7,"count":1}]	29484	delivery	5	14
74572	2020-06-07 08:31:19	2020-06-07	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	25077	delivery	5	26
74573	2020-06-07 08:32:20	2020-06-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24419	delivery	5	23
74574	2020-06-07 08:33:24	2020-06-07	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	20692	delivery	5	26
74575	2020-06-07 08:33:32	2020-06-07	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	29463	delivery	5	34
74576	2020-06-07 08:33:54	2020-06-07	14	[{"id_menu":2,"count":1}]	29429	pick-up	0	14
74577	2020-06-07 08:34:18	2020-06-07	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	23393	delivery	5	36
74578	2020-06-07 08:35:39	2020-06-07	46	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	25693	delivery	5	51
74579	2020-06-07 08:38:11	2020-06-07	14	[{"id_menu":2,"count":1}]	22443	delivery	5	19
74580	2020-06-07 08:38:14	2020-06-07	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	11044	delivery	5	30
74581	2020-06-07 08:38:41	2020-06-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17739	delivery	5	22
74582	2020-06-07 08:39:41	2020-06-07	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	9010	delivery	5	36
74583	2020-06-07 08:40:54	2020-06-07	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29488	delivery	5	51
74584	2020-06-07 08:43:28	2020-06-07	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11896	pick-up	0	38
74585	2020-06-07 08:49:09	2020-06-07	14	[{"id_menu":2,"count":1}]	500	pick-up	0	14
74586	2020-06-07 08:49:21	2020-06-07	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	14267	delivery	5	48
74587	2020-06-07 08:50:17	2020-06-07	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	29466	delivery	5	30
74588	2020-06-07 08:56:38	2020-06-07	12	[{"id_menu":1,"count":1}]	9633	delivery	5	17
74589	2020-06-07 08:57:37	2020-06-07	9	[{"id_menu":6,"count":2}]	27244	delivery	5	14
74590	2020-06-07 09:03:15	2020-06-07	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18564	delivery	5	48
74591	2020-06-07 09:03:27	2020-06-07	17	[{"id_menu":4,"count":1}]	29496	delivery	5	22
74592	2020-06-07 09:03:29	2020-06-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	20815	delivery	5	28
74593	2020-06-07 09:08:28	2020-06-07	12	[{"id_menu":3,"count":1}]	12704	delivery	5	17
74594	2020-06-07 09:13:07	2020-06-07	14	[{"id_menu":2,"count":1}]	13267	delivery	5	19
74595	2020-06-07 09:14:41	2020-06-07	9	[{"id_menu":7,"count":1}]	29447	delivery	5	14
74596	2020-06-07 09:15:42	2020-06-07	9	[{"id_menu":6,"count":1}]	1688	pick-up	0	9
74597	2020-06-07 09:20:37	2020-06-07	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	1709	delivery	5	26
74598	2020-06-07 09:23:12	2020-06-07	9	[{"id_menu":7,"count":1}]	29399	delivery	5	14
74599	2020-06-07 09:24:14	2020-06-07	17	[{"id_menu":4,"count":1}]	29049	pick-up	0	17
74600	2020-06-07 09:24:43	2020-06-07	12	[{"id_menu":3,"count":1}]	4719	delivery	5	17
74601	2020-06-07 09:25:38	2020-06-07	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	6410	pick-up	0	20
74602	2020-06-07 09:26:21	2020-06-07	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	5872	delivery	5	25
74603	2020-06-07 09:27:11	2020-06-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29524	delivery	5	22
74604	2020-06-07 09:27:49	2020-06-07	17	[{"id_menu":4,"count":1}]	29477	delivery	5	22
74605	2020-06-07 09:28:04	2020-06-07	17	[{"id_menu":4,"count":1}]	10444	delivery	5	22
74606	2020-06-07 09:32:20	2020-06-07	9	[{"id_menu":6,"count":1}]	29474	delivery	5	14
74607	2020-06-07 09:34:44	2020-06-07	9	[{"id_menu":6,"count":1}]	27946	delivery	5	14
74608	2020-06-07 09:34:47	2020-06-07	12	[{"id_menu":3,"count":1}]	10353	delivery	5	17
74609	2020-06-07 09:37:01	2020-06-07	14	[{"id_menu":2,"count":1}]	3827	pick-up	0	14
74610	2020-06-07 09:38:06	2020-06-07	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	12361	delivery	5	26
74611	2020-06-07 09:39:27	2020-06-07	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15930	delivery	5	48
74612	2020-06-07 09:39:55	2020-06-07	12	[{"id_menu":3,"count":1}]	4161	pick-up	0	12
74613	2020-06-07 09:45:22	2020-06-07	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	29347	pick-up	0	29
74614	2020-06-07 09:47:06	2020-06-07	9	[{"id_menu":7,"count":2}]	8424	delivery	5	14
74615	2020-06-07 09:47:07	2020-06-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2054	delivery	5	28
74616	2020-06-07 09:47:58	2020-06-07	9	[{"id_menu":7,"count":1}]	26384	pick-up	0	9
74617	2020-06-07 09:49:27	2020-06-07	14	[{"id_menu":2,"count":1}]	29561	delivery	5	19
74618	2020-06-07 09:58:08	2020-06-07	9	[{"id_menu":6,"count":1}]	17867	delivery	5	14
74619	2020-06-07 09:58:35	2020-06-07	9	[{"id_menu":6,"count":1}]	29550	delivery	5	14
74620	2020-06-07 10:05:44	2020-06-07	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27721	delivery	5	34
74621	2020-06-07 10:06:02	2020-06-07	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	12287	delivery	5	26
74622	2020-06-07 10:07:07	2020-06-07	14	[{"id_menu":2,"count":1}]	29410	pick-up	0	14
74623	2020-06-07 10:07:43	2020-06-07	12	[{"id_menu":1,"count":2}]	3969	delivery	5	17
74624	2020-06-07 10:07:56	2020-06-07	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10694	pick-up	0	26
74625	2020-06-07 10:09:28	2020-06-07	12	[{"id_menu":3,"count":1}]	21002	delivery	5	17
74626	2020-06-07 10:11:12	2020-06-07	9	[{"id_menu":6,"count":1}]	29518	pick-up	0	9
74627	2020-06-07 10:12:20	2020-06-07	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	956	pick-up	0	29
74628	2020-06-07 10:12:29	2020-06-07	12	[{"id_menu":3,"count":2}]	3135	pick-up	0	12
74629	2020-06-07 10:16:36	2020-06-07	8	[{"id_menu":5,"count":3}]	11220	delivery	5	13
74630	2020-06-07 10:17:08	2020-06-07	17	[{"id_menu":4,"count":1}]	21334	pick-up	0	17
74631	2020-06-07 10:17:43	2020-06-07	17	[{"id_menu":4,"count":1}]	1659	delivery	5	22
74632	2020-06-07 10:19:35	2020-06-07	12	[{"id_menu":3,"count":1}]	19042	pick-up	0	12
74633	2020-06-07 10:19:41	2020-06-07	9	[{"id_menu":7,"count":1}]	8873	delivery	5	14
74634	2020-06-07 10:23:03	2020-06-07	12	[{"id_menu":1,"count":1}]	274	pick-up	0	12
74635	2020-06-07 10:23:24	2020-06-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7446	delivery	5	23
74636	2020-06-07 10:23:29	2020-06-07	17	[{"id_menu":4,"count":1}]	11182	delivery	5	22
74637	2020-06-07 10:25:30	2020-06-07	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6080	delivery	5	35
74638	2020-06-07 10:29:37	2020-06-07	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	23786	delivery	5	25
74639	2020-06-07 10:30:22	2020-06-07	14	[{"id_menu":2,"count":1}]	29450	delivery	5	19
74640	2020-06-07 10:30:53	2020-06-07	9	[{"id_menu":7,"count":1}]	29418	delivery	5	14
74641	2020-06-07 10:32:03	2020-06-07	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2217	delivery	5	26
74642	2020-06-07 10:32:06	2020-06-07	17	[{"id_menu":4,"count":1}]	14077	delivery	5	22
74643	2020-06-07 10:32:07	2020-06-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29562	delivery	5	22
74644	2020-06-07 10:36:52	2020-06-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	29547	delivery	5	26
74645	2020-06-07 10:37:13	2020-06-07	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8760	delivery	5	22
74646	2020-06-07 10:37:49	2020-06-07	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":2}]	3190	pick-up	0	21
74647	2020-06-07 10:41:50	2020-06-07	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16512	delivery	5	39
74648	2020-06-07 10:47:31	2020-06-07	12	[{"id_menu":1,"count":1}]	2562	pick-up	0	12
74649	2020-06-07 10:49:03	2020-06-07	9	[{"id_menu":7,"count":1}]	2440	delivery	5	14
74650	2020-06-07 10:49:22	2020-06-07	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	5996	delivery	5	25
74651	2020-06-07 10:50:10	2020-06-07	14	[{"id_menu":2,"count":2}]	29501	delivery	5	19
74652	2020-06-07 10:55:32	2020-06-07	12	[{"id_menu":1,"count":1}]	8394	delivery	5	17
74653	2020-06-07 10:56:17	2020-06-07	9	[{"id_menu":7,"count":1}]	12172	delivery	5	14
74654	2020-06-07 10:58:11	2020-06-07	9	[{"id_menu":6,"count":1}]	26154	delivery	5	14
74655	2020-06-07 10:58:52	2020-06-07	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	29398	delivery	5	43
74656	2020-06-07 10:59:09	2020-06-07	14	[{"id_menu":2,"count":1}]	1667	pick-up	0	14
74657	2020-06-07 10:59:49	2020-06-07	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	29416	delivery	5	36
74658	2020-06-07 11:00:40	2020-06-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28363	delivery	5	22
74659	2020-06-07 11:01:00	2020-06-07	34	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	20126	delivery	5	39
74660	2020-06-07 11:01:31	2020-06-07	17	[{"id_menu":4,"count":1}]	9562	pick-up	0	17
74661	2020-06-07 11:02:27	2020-06-07	9	[{"id_menu":6,"count":1}]	29519	delivery	5	14
74662	2020-06-07 11:03:22	2020-06-07	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	29397	delivery	5	30
74663	2020-06-07 11:03:49	2020-06-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	29448	delivery	5	26
74664	2020-06-07 11:05:54	2020-06-07	9	[{"id_menu":7,"count":1}]	5073	delivery	5	14
74665	2020-06-07 11:06:33	2020-06-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	8795	delivery	5	28
74666	2020-06-07 11:08:22	2020-06-07	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1079	delivery	5	22
74667	2020-06-07 11:10:03	2020-06-07	8	[{"id_menu":5,"count":1}]	4248	delivery	5	13
74668	2020-06-07 11:13:12	2020-06-07	8	[{"id_menu":5,"count":1}]	11901	delivery	5	13
74669	2020-06-07 11:14:51	2020-06-07	8	[{"id_menu":5,"count":1}]	17799	delivery	5	13
74670	2020-06-07 11:19:20	2020-06-07	12	[{"id_menu":1,"count":1}]	28197	delivery	5	17
74671	2020-06-07 11:20:18	2020-06-07	14	[{"id_menu":2,"count":1}]	6825	pick-up	0	14
74672	2020-06-07 11:22:11	2020-06-07	9	[{"id_menu":7,"count":1}]	29395	pick-up	0	9
74673	2020-06-07 11:28:10	2020-06-07	9	[{"id_menu":6,"count":1}]	12011	pick-up	0	9
74674	2020-06-07 11:28:15	2020-06-07	9	[{"id_menu":7,"count":1}]	11378	delivery	5	14
74675	2020-06-07 11:29:19	2020-06-07	9	[{"id_menu":7,"count":1}]	3390	pick-up	0	9
74676	2020-06-07 11:29:26	2020-06-07	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2613	pick-up	0	38
74677	2020-06-07 11:30:13	2020-06-07	8	[{"id_menu":5,"count":1}]	27624	pick-up	0	8
74678	2020-06-07 11:32:49	2020-06-07	9	[{"id_menu":6,"count":1}]	16843	pick-up	0	9
74679	2020-06-07 11:35:29	2020-06-07	12	[{"id_menu":3,"count":1}]	12312	delivery	5	17
74680	2020-06-07 11:37:19	2020-06-07	12	[{"id_menu":1,"count":1}]	29299	delivery	5	17
74681	2020-06-07 11:38:14	2020-06-07	12	[{"id_menu":1,"count":1}]	19991	pick-up	0	12
74682	2020-06-07 11:38:39	2020-06-07	9	[{"id_menu":6,"count":1}]	6393	delivery	5	14
74683	2020-06-07 11:41:48	2020-06-07	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	13896	delivery	5	28
74684	2020-06-07 11:42:22	2020-06-07	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	4779	delivery	5	39
74685	2020-06-07 11:43:28	2020-06-07	8	[{"id_menu":5,"count":1}]	26209	pick-up	0	8
74686	2020-06-07 11:44:50	2020-06-07	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	12476	delivery	5	34
74687	2020-06-07 11:48:22	2020-06-07	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	27432	delivery	5	42
74688	2020-06-07 11:49:59	2020-06-07	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16068	delivery	5	31
74689	2020-06-07 11:50:36	2020-06-07	8	[{"id_menu":5,"count":1}]	29487	delivery	5	13
74690	2020-06-07 11:51:46	2020-06-07	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	10679	pick-up	0	26
74691	2020-06-07 11:53:14	2020-06-07	17	[{"id_menu":4,"count":1}]	2	pick-up	0	17
74692	2020-06-07 11:53:19	2020-06-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23140	delivery	5	22
74693	2020-06-07 11:53:24	2020-06-07	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	29525	delivery	5	39
74694	2020-06-07 11:53:57	2020-06-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	14284	pick-up	0	21
74695	2020-06-07 11:57:27	2020-06-07	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10211	delivery	5	35
74696	2020-06-07 11:57:56	2020-06-07	14	[{"id_menu":2,"count":1}]	6135	delivery	5	19
74697	2020-06-07 12:04:54	2020-06-07	8	[{"id_menu":5,"count":1}]	3385	delivery	5	13
74698	2020-06-07 12:07:16	2020-06-07	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29393	delivery	5	34
74699	2020-06-07 12:07:44	2020-06-07	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	26556	delivery	5	36
74700	2020-06-07 12:11:02	2020-06-07	14	[{"id_menu":2,"count":1}]	4640	pick-up	0	14
74701	2020-06-07 12:13:38	2020-06-07	12	[{"id_menu":3,"count":1}]	18663	delivery	5	17
74702	2020-06-07 12:17:35	2020-06-07	12	[{"id_menu":3,"count":1}]	905	pick-up	0	12
74703	2020-06-07 12:18:47	2020-06-07	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	13575	pick-up	0	31
74704	2020-06-07 12:19:05	2020-06-07	9	[{"id_menu":6,"count":1}]	13400	pick-up	0	9
74705	2020-06-07 12:20:34	2020-06-07	9	[{"id_menu":7,"count":1}]	20989	delivery	5	14
74706	2020-06-07 12:22:57	2020-06-07	9	[{"id_menu":6,"count":1}]	2190	pick-up	0	9
74707	2020-06-07 12:23:57	2020-06-07	17	[{"id_menu":4,"count":1}]	8780	delivery	5	22
74708	2020-06-07 12:24:47	2020-06-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	228	delivery	5	22
74709	2020-06-07 12:25:09	2020-06-07	14	[{"id_menu":2,"count":1}]	29494	delivery	5	19
74710	2020-06-07 12:28:54	2020-06-07	14	[{"id_menu":2,"count":1}]	29427	pick-up	0	14
74711	2020-06-07 12:29:17	2020-06-07	8	[{"id_menu":5,"count":1}]	13615	delivery	5	13
74712	2020-06-07 12:31:18	2020-06-07	17	[{"id_menu":4,"count":1}]	21860	pick-up	0	17
74713	2020-06-07 12:34:19	2020-06-07	17	[{"id_menu":4,"count":1}]	24943	pick-up	0	17
74714	2020-06-07 12:34:20	2020-06-07	24	[{"id_menu":1,"count":3},{"id_menu":3,"count":1}]	13379	delivery	5	29
74715	2020-06-07 12:35:27	2020-06-07	17	[{"id_menu":4,"count":1}]	25954	pick-up	0	17
74716	2020-06-07 12:35:33	2020-06-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	29414	delivery	5	23
74717	2020-06-07 12:35:47	2020-06-07	17	[{"id_menu":4,"count":1}]	29509	delivery	5	22
74718	2020-06-07 12:35:56	2020-06-07	14	[{"id_menu":2,"count":1}]	29559	delivery	5	19
74719	2020-06-07 12:37:05	2020-06-07	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	5538	pick-up	0	22
74720	2020-06-07 12:41:45	2020-06-07	17	[{"id_menu":4,"count":1}]	16231	delivery	5	22
74721	2020-06-07 12:44:57	2020-06-07	9	[{"id_menu":7,"count":1}]	1481	pick-up	0	9
74722	2020-06-07 12:47:52	2020-06-07	14	[{"id_menu":2,"count":1}]	17069	delivery	5	19
74723	2020-06-07 12:48:04	2020-06-07	8	[{"id_menu":5,"count":1}]	24573	delivery	5	13
74724	2020-06-07 12:48:28	2020-06-07	9	[{"id_menu":6,"count":1}]	6641	pick-up	0	9
74725	2020-06-07 12:49:00	2020-06-07	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1476	delivery	5	27
74726	2020-06-07 12:50:05	2020-06-07	14	[{"id_menu":2,"count":2}]	16967	pick-up	0	14
74727	2020-06-07 12:51:03	2020-06-07	9	[{"id_menu":7,"count":1}]	29507	delivery	5	14
74728	2020-06-07 12:51:46	2020-06-07	12	[{"id_menu":1,"count":1}]	24843	delivery	5	17
74729	2020-06-07 12:54:49	2020-06-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4072	pick-up	0	23
74730	2020-06-07 12:57:11	2020-06-07	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	10438	delivery	5	37
74731	2020-06-07 13:02:57	2020-06-07	14	[{"id_menu":2,"count":1}]	17325	delivery	5	19
74732	2020-06-07 13:06:08	2020-06-07	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	15585	delivery	5	40
74733	2020-06-07 13:08:05	2020-06-07	9	[{"id_menu":7,"count":3}]	29442	delivery	5	14
74734	2020-06-07 13:10:28	2020-06-07	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21003	delivery	5	40
74735	2020-06-07 13:10:54	2020-06-07	9	[{"id_menu":6,"count":1}]	15870	delivery	5	14
74736	2020-06-07 13:11:21	2020-06-07	8	[{"id_menu":5,"count":1}]	10203	pick-up	0	8
74737	2020-06-07 13:13:44	2020-06-07	14	[{"id_menu":2,"count":1}]	14480	pick-up	0	14
74738	2020-06-07 13:15:37	2020-06-07	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	20931	delivery	5	27
74739	2020-06-07 13:23:20	2020-06-07	8	[{"id_menu":5,"count":1}]	26250	delivery	5	13
74740	2020-06-07 13:23:49	2020-06-07	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29377	delivery	5	40
74741	2020-06-07 13:24:04	2020-06-07	17	[{"id_menu":4,"count":1}]	12198	delivery	5	22
74742	2020-06-07 13:24:15	2020-06-07	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4628	pick-up	0	21
74743	2020-06-07 13:25:34	2020-06-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	29553	delivery	5	26
74744	2020-06-07 13:26:22	2020-06-07	14	[{"id_menu":2,"count":1}]	691	pick-up	0	14
74745	2020-06-07 13:29:53	2020-06-07	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	26952	delivery	5	25
74746	2020-06-07 13:30:26	2020-06-07	14	[{"id_menu":2,"count":3}]	29480	delivery	5	19
74747	2020-06-07 13:31:35	2020-06-07	9	[{"id_menu":7,"count":1}]	29402	pick-up	0	9
74748	2020-06-07 13:35:02	2020-06-07	8	[{"id_menu":5,"count":1}]	29504	delivery	5	13
74749	2020-06-07 13:35:17	2020-06-07	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2331	pick-up	0	29
74750	2020-06-07 13:35:41	2020-06-07	12	[{"id_menu":1,"count":1}]	9807	delivery	5	17
74751	2020-06-07 13:39:06	2020-06-07	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	29475	delivery	5	26
74752	2020-06-07 13:41:25	2020-06-07	14	[{"id_menu":2,"count":1}]	29383	delivery	5	19
74753	2020-06-07 13:41:39	2020-06-07	17	[{"id_menu":4,"count":1}]	1839	delivery	5	22
74754	2020-06-07 13:45:06	2020-06-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	3629	delivery	5	22
74755	2020-06-07 13:46:46	2020-06-07	9	[{"id_menu":7,"count":1}]	18071	delivery	5	14
74756	2020-06-07 13:49:10	2020-06-07	14	[{"id_menu":2,"count":1}]	29545	delivery	5	19
74757	2020-06-07 13:51:20	2020-06-07	9	[{"id_menu":7,"count":2}]	29476	delivery	5	14
74758	2020-06-07 13:53:40	2020-06-07	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	29493	delivery	5	31
74759	2020-06-07 13:54:40	2020-06-07	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	27237	delivery	5	26
74760	2020-06-07 13:55:44	2020-06-07	14	[{"id_menu":2,"count":1}]	14454	delivery	5	19
74761	2020-06-07 13:56:12	2020-06-07	8	[{"id_menu":5,"count":1}]	24668	pick-up	0	8
74762	2020-06-07 13:57:19	2020-06-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11454	pick-up	0	18
74763	2020-06-07 13:58:17	2020-06-07	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	29460	delivery	5	26
74764	2020-06-07 13:58:40	2020-06-07	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	754	delivery	5	36
74765	2020-06-07 14:02:32	2020-06-07	9	[{"id_menu":6,"count":1}]	29516	delivery	5	14
74766	2020-06-07 14:03:41	2020-06-07	9	[{"id_menu":6,"count":1}]	29457	delivery	5	14
74767	2020-06-07 14:04:03	2020-06-07	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	29491	delivery	5	31
74768	2020-06-07 14:04:22	2020-06-07	14	[{"id_menu":2,"count":1}]	11553	pick-up	0	14
74769	2020-06-07 14:05:03	2020-06-07	9	[{"id_menu":6,"count":1}]	29542	delivery	5	14
74770	2020-06-07 14:05:20	2020-06-07	9	[{"id_menu":6,"count":1}]	29531	delivery	5	14
74771	2020-06-07 14:11:02	2020-06-07	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	20712	delivery	5	37
74772	2020-06-07 14:15:27	2020-06-07	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	19795	delivery	5	40
74773	2020-06-07 14:15:42	2020-06-07	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	20202	delivery	5	31
74774	2020-06-07 14:17:01	2020-06-07	9	[{"id_menu":6,"count":1}]	29391	delivery	5	14
74775	2020-06-07 14:17:32	2020-06-07	9	[{"id_menu":7,"count":1}]	13720	delivery	5	14
74776	2020-06-07 14:19:04	2020-06-07	9	[{"id_menu":6,"count":3}]	17116	delivery	5	14
74777	2020-06-07 14:20:36	2020-06-07	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	27469	delivery	5	34
74778	2020-06-07 14:23:34	2020-06-07	9	[{"id_menu":7,"count":1}]	15176	delivery	5	14
74779	2020-06-07 14:24:06	2020-06-07	8	[{"id_menu":5,"count":1}]	19457	delivery	5	13
74780	2020-06-07 14:25:03	2020-06-07	9	[{"id_menu":7,"count":1}]	27488	delivery	5	14
74781	2020-06-07 14:25:18	2020-06-07	9	[{"id_menu":7,"count":1}]	5642	pick-up	0	9
74782	2020-06-07 14:28:16	2020-06-07	8	[{"id_menu":5,"count":3}]	29421	delivery	5	13
74783	2020-06-07 14:33:41	2020-06-07	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	18936	delivery	5	31
74784	2020-06-07 14:36:18	2020-06-07	9	[{"id_menu":6,"count":1}]	7802	delivery	5	14
74785	2020-06-07 14:36:23	2020-06-07	9	[{"id_menu":6,"count":1}]	25138	delivery	5	14
74786	2020-06-07 14:36:24	2020-06-07	9	[{"id_menu":7,"count":1}]	29481	delivery	5	14
74787	2020-06-07 14:38:05	2020-06-07	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29469	delivery	5	53
74788	2020-06-07 14:38:49	2020-06-07	14	[{"id_menu":2,"count":1}]	29543	delivery	5	19
74789	2020-06-07 14:39:34	2020-06-07	14	[{"id_menu":2,"count":1}]	29422	delivery	5	19
74790	2020-06-07 14:42:19	2020-06-07	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	29521	delivery	5	23
74791	2020-06-07 14:42:45	2020-06-07	9	[{"id_menu":6,"count":1}]	21567	delivery	5	14
74792	2020-06-07 14:43:45	2020-06-07	9	[{"id_menu":7,"count":1}]	22212	delivery	5	14
74793	2020-06-07 14:44:42	2020-06-07	9	[{"id_menu":6,"count":1}]	123	pick-up	0	9
74794	2020-06-07 14:45:15	2020-06-07	9	[{"id_menu":7,"count":1}]	12990	pick-up	0	9
74795	2020-06-07 14:46:20	2020-06-07	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":3}]	28750	delivery	5	25
74796	2020-06-07 14:47:23	2020-06-07	14	[{"id_menu":2,"count":1}]	24534	pick-up	0	14
74797	2020-06-07 14:48:15	2020-06-07	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	2081	delivery	5	25
74798	2020-06-07 14:48:47	2020-06-07	12	[{"id_menu":3,"count":1}]	29555	delivery	5	17
74799	2020-06-07 14:50:16	2020-06-07	9	[{"id_menu":6,"count":1}]	10876	delivery	5	14
74800	2020-06-07 14:52:38	2020-06-07	9	[{"id_menu":6,"count":1}]	22088	delivery	5	14
74801	2020-06-07 14:55:14	2020-06-07	14	[{"id_menu":2,"count":1}]	4644	delivery	5	19
74802	2020-06-07 14:56:48	2020-06-07	9	[{"id_menu":6,"count":1}]	1855	pick-up	0	9
74803	2020-06-07 14:57:48	2020-06-07	9	[{"id_menu":6,"count":1}]	5760	delivery	5	14
74804	2020-06-07 14:58:09	2020-06-07	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	16445	delivery	5	31
74805	2020-06-07 14:59:15	2020-06-07	9	[{"id_menu":7,"count":1}]	28602	pick-up	0	9
74806	2020-06-07 14:59:58	2020-06-07	9	[{"id_menu":6,"count":1}]	20355	delivery	5	14
74807	2020-06-07 15:03:15	2020-06-07	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	13054	pick-up	0	43
74808	2020-06-07 15:04:34	2020-06-07	9	[{"id_menu":7,"count":1}]	29492	delivery	5	14
74809	2020-06-07 15:05:53	2020-06-07	14	[{"id_menu":2,"count":1}]	29443	delivery	5	19
74810	2020-06-07 15:07:00	2020-06-07	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16844	pick-up	0	31
74811	2020-06-07 15:12:46	2020-06-07	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3119	delivery	5	27
74812	2020-06-07 15:13:40	2020-06-07	17	[{"id_menu":4,"count":1}]	27312	delivery	5	22
74813	2020-06-07 15:15:19	2020-06-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29424	delivery	5	22
74814	2020-06-07 15:15:34	2020-06-07	9	[{"id_menu":7,"count":1}]	29530	delivery	5	14
74815	2020-06-07 15:16:01	2020-06-07	14	[{"id_menu":2,"count":1}]	15811	delivery	5	19
74816	2020-06-07 15:16:44	2020-06-07	12	[{"id_menu":1,"count":1}]	25643	delivery	5	17
74817	2020-06-07 15:17:37	2020-06-07	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	29387	delivery	5	22
74818	2020-06-07 15:20:28	2020-06-07	9	[{"id_menu":6,"count":1}]	22731	delivery	5	14
74819	2020-06-07 15:20:32	2020-06-07	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	26	pick-up	0	31
74820	2020-06-07 15:20:37	2020-06-07	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29405	delivery	5	52
74821	2020-06-07 15:27:48	2020-06-07	8	[{"id_menu":5,"count":1}]	13483	delivery	5	13
74822	2020-06-07 15:32:40	2020-06-07	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29459	delivery	5	31
74823	2020-06-07 15:34:49	2020-06-07	12	[{"id_menu":3,"count":1}]	29374	delivery	5	17
74824	2020-06-07 15:36:34	2020-06-07	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	15242	delivery	5	40
74825	2020-06-07 15:37:54	2020-06-07	9	[{"id_menu":6,"count":1}]	11405	delivery	5	14
74826	2020-06-07 15:39:42	2020-06-07	12	[{"id_menu":3,"count":2}]	2788	delivery	5	17
74827	2020-06-07 15:40:21	2020-06-07	8	[{"id_menu":5,"count":1}]	29490	delivery	5	13
74828	2020-06-07 15:42:10	2020-06-07	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	29511	pick-up	0	47
74829	2020-06-07 15:47:24	2020-06-07	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24277	delivery	5	40
74830	2020-06-07 15:47:32	2020-06-07	9	[{"id_menu":6,"count":1}]	8154	delivery	5	14
74831	2020-06-07 15:49:09	2020-06-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17795	delivery	5	22
74832	2020-06-07 15:49:37	2020-06-07	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29236	delivery	5	35
74833	2020-06-07 15:52:24	2020-06-07	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	29024	pick-up	0	24
74834	2020-06-07 15:53:09	2020-06-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18542	delivery	5	23
74835	2020-06-07 15:54:56	2020-06-07	9	[{"id_menu":7,"count":1}]	26734	delivery	5	14
74836	2020-06-07 15:55:49	2020-06-07	12	[{"id_menu":3,"count":2}]	1684	pick-up	0	12
74837	2020-06-07 15:57:50	2020-06-07	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6997	delivery	5	30
74838	2020-06-07 15:58:40	2020-06-07	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	20479	delivery	5	36
74839	2020-06-07 15:58:58	2020-06-07	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	13128	delivery	5	40
74840	2020-06-07 15:59:52	2020-06-07	14	[{"id_menu":2,"count":1}]	9420	pick-up	0	14
74841	2020-06-07 16:00:35	2020-06-07	14	[{"id_menu":2,"count":1}]	259	pick-up	0	14
74842	2020-06-07 16:06:06	2020-06-07	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	24025	delivery	5	30
74843	2020-06-07 16:09:29	2020-06-07	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9576	delivery	5	34
74844	2020-06-07 16:12:47	2020-06-07	9	[{"id_menu":7,"count":1}]	4793	pick-up	0	9
74845	2020-06-07 16:13:08	2020-06-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	6619	delivery	5	23
74846	2020-06-07 16:18:12	2020-06-07	12	[{"id_menu":3,"count":1}]	29435	delivery	5	17
74847	2020-06-07 16:18:31	2020-06-07	17	[{"id_menu":4,"count":1}]	29401	delivery	5	22
74848	2020-06-07 16:20:02	2020-06-07	9	[{"id_menu":6,"count":1}]	29502	delivery	5	14
74849	2020-06-07 16:26:59	2020-06-07	9	[{"id_menu":6,"count":2}]	11004	delivery	5	14
74850	2020-06-07 16:27:44	2020-06-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":3}]	14648	delivery	5	28
74851	2020-06-07 16:28:23	2020-06-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	14113	delivery	5	28
74852	2020-06-07 16:32:18	2020-06-07	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	10122	delivery	5	48
74853	2020-06-07 16:36:01	2020-06-07	17	[{"id_menu":4,"count":1}]	9623	delivery	5	22
74854	2020-06-07 16:41:25	2020-06-07	8	[{"id_menu":5,"count":1}]	29464	delivery	5	13
74855	2020-06-07 16:41:28	2020-06-07	9	[{"id_menu":6,"count":1}]	24466	delivery	5	14
74856	2020-06-07 16:41:39	2020-06-07	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29396	delivery	5	40
74857	2020-06-07 16:41:46	2020-06-07	9	[{"id_menu":7,"count":1}]	9804	pick-up	0	9
74858	2020-06-07 16:43:31	2020-06-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	26929	delivery	5	26
74859	2020-06-07 16:43:55	2020-06-07	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8135	delivery	5	45
74860	2020-06-07 16:47:53	2020-06-07	8	[{"id_menu":5,"count":1}]	822	pick-up	0	8
74861	2020-06-07 16:49:50	2020-06-07	9	[{"id_menu":6,"count":1}]	5416	delivery	5	14
74862	2020-06-07 16:50:34	2020-06-07	9	[{"id_menu":6,"count":1}]	23274	delivery	5	14
74863	2020-06-07 16:52:19	2020-06-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	29522	delivery	5	28
74864	2020-06-07 17:00:02	2020-06-07	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	16963	delivery	5	40
74865	2020-06-07 17:00:38	2020-06-07	9	[{"id_menu":7,"count":1}]	29471	delivery	5	14
74866	2020-06-07 17:00:48	2020-06-07	12	[{"id_menu":1,"count":1}]	15449	pick-up	0	12
74867	2020-06-07 17:01:57	2020-06-07	14	[{"id_menu":2,"count":1}]	29318	delivery	5	19
74868	2020-06-07 17:02:20	2020-06-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	29549	delivery	5	22
74869	2020-06-07 17:08:11	2020-06-07	17	[{"id_menu":4,"count":1}]	29479	delivery	5	22
74870	2020-06-07 17:11:28	2020-06-07	9	[{"id_menu":7,"count":1}]	3740	delivery	5	14
74871	2020-06-07 17:14:21	2020-06-07	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	12602	pick-up	0	33
74872	2020-06-07 17:17:37	2020-06-07	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	29538	delivery	5	27
74873	2020-06-07 17:21:16	2020-06-07	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	29426	delivery	5	25
74874	2020-06-07 17:22:01	2020-06-07	9	[{"id_menu":6,"count":1}]	4472	delivery	5	14
74875	2020-06-07 17:24:06	2020-06-07	12	[{"id_menu":3,"count":1}]	29461	delivery	5	17
74876	2020-06-07 17:26:28	2020-06-07	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10525	pick-up	0	41
74877	2020-06-07 17:27:36	2020-06-07	9	[{"id_menu":7,"count":1}]	16857	delivery	5	14
74878	2020-06-07 17:28:56	2020-06-07	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	29441	delivery	5	34
74879	2020-06-07 17:29:35	2020-06-07	9	[{"id_menu":6,"count":1}]	24980	pick-up	0	9
74880	2020-06-07 17:29:43	2020-06-07	9	[{"id_menu":7,"count":1}]	1085	pick-up	0	9
74881	2020-06-07 17:34:11	2020-06-07	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18168	pick-up	0	17
74882	2020-06-07 17:34:42	2020-06-07	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	20780	delivery	5	31
74883	2020-06-07 17:40:04	2020-06-07	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4595	pick-up	0	26
74884	2020-06-07 17:40:15	2020-06-07	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	11964	delivery	5	27
74885	2020-06-07 17:41:55	2020-06-07	8	[{"id_menu":5,"count":1}]	14010	pick-up	0	8
74886	2020-06-07 17:42:36	2020-06-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	29446	delivery	5	26
74887	2020-06-07 17:45:09	2020-06-07	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	29445	delivery	5	30
74888	2020-06-07 17:45:22	2020-06-07	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23709	pick-up	0	29
74889	2020-06-07 17:47:05	2020-06-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4309	delivery	5	28
74890	2020-06-07 17:47:20	2020-06-07	17	[{"id_menu":4,"count":1}]	79	delivery	5	22
74891	2020-06-07 17:47:30	2020-06-07	9	[{"id_menu":6,"count":1}]	3174	delivery	5	14
74892	2020-06-07 17:51:11	2020-06-07	14	[{"id_menu":2,"count":2}]	14358	delivery	5	19
74893	2020-06-07 17:51:32	2020-06-07	9	[{"id_menu":6,"count":1}]	8090	pick-up	0	9
74894	2020-06-07 17:54:42	2020-06-07	8	[{"id_menu":5,"count":1}]	3679	delivery	5	13
74895	2020-06-07 17:56:08	2020-06-07	8	[{"id_menu":5,"count":1}]	13907	delivery	5	13
74896	2020-06-07 17:59:09	2020-06-07	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5975	delivery	5	53
74897	2020-06-07 17:59:10	2020-06-07	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29388	delivery	5	35
74898	2020-06-07 17:59:18	2020-06-07	9	[{"id_menu":7,"count":1}]	11880	delivery	5	14
74899	2020-06-07 18:02:20	2020-06-07	12	[{"id_menu":1,"count":1}]	826	pick-up	0	12
74900	2020-06-07 18:03:15	2020-06-07	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6276	delivery	5	36
74901	2020-06-07 18:10:07	2020-06-07	14	[{"id_menu":2,"count":1}]	28538	delivery	5	19
74902	2020-06-07 18:10:38	2020-06-07	31	[{"id_menu":2,"count":3},{"id_menu":4,"count":1}]	203	pick-up	0	31
74903	2020-06-07 18:11:30	2020-06-07	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	24160	delivery	5	38
74904	2020-06-07 18:11:53	2020-06-07	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5303	delivery	5	31
74905	2020-06-07 18:13:31	2020-06-07	8	[{"id_menu":5,"count":1}]	29400	delivery	5	13
74906	2020-06-07 18:13:42	2020-06-07	17	[{"id_menu":4,"count":1}]	29551	delivery	5	22
74907	2020-06-07 18:16:23	2020-06-07	12	[{"id_menu":3,"count":1}]	15329	delivery	5	17
74908	2020-06-07 18:17:13	2020-06-07	17	[{"id_menu":4,"count":1}]	7814	pick-up	0	17
74909	2020-06-07 18:18:38	2020-06-07	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	29510	delivery	5	43
74910	2020-06-07 18:18:44	2020-06-07	12	[{"id_menu":3,"count":1}]	27242	delivery	5	17
74911	2020-06-07 18:30:16	2020-06-07	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	20360	delivery	5	40
74912	2020-06-07 18:30:43	2020-06-07	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	29436	delivery	5	26
74913	2020-06-07 18:32:22	2020-06-07	8	[{"id_menu":5,"count":1}]	7205	pick-up	0	8
74914	2020-06-07 18:34:19	2020-06-07	12	[{"id_menu":1,"count":1}]	5338	pick-up	0	12
74915	2020-06-07 18:34:27	2020-06-07	9	[{"id_menu":6,"count":1}]	27660	delivery	5	14
74916	2020-06-07 18:37:02	2020-06-07	9	[{"id_menu":7,"count":1}]	8229	pick-up	0	9
74917	2020-06-07 18:37:52	2020-06-07	8	[{"id_menu":5,"count":1}]	29528	delivery	5	13
74918	2020-06-07 18:39:21	2020-06-07	12	[{"id_menu":3,"count":1}]	26962	delivery	5	17
74919	2020-06-07 18:39:28	2020-06-07	14	[{"id_menu":2,"count":2}]	13898	delivery	5	19
74920	2020-06-07 18:40:18	2020-06-07	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	28633	delivery	5	45
74921	2020-06-07 18:40:21	2020-06-07	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	17588	delivery	5	31
74922	2020-06-07 18:40:29	2020-06-07	12	[{"id_menu":3,"count":1}]	12553	delivery	5	17
74923	2020-06-07 18:43:49	2020-06-07	17	[{"id_menu":4,"count":1}]	29533	delivery	5	22
74924	2020-06-07 18:46:19	2020-06-07	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	22273	delivery	5	25
74925	2020-06-07 18:47:36	2020-06-07	12	[{"id_menu":1,"count":2}]	21664	delivery	5	17
74926	2020-06-07 18:48:22	2020-06-07	9	[{"id_menu":6,"count":1}]	17351	delivery	5	14
74927	2020-06-07 18:49:37	2020-06-07	12	[{"id_menu":1,"count":1}]	12957	pick-up	0	12
74928	2020-06-07 18:49:54	2020-06-07	14	[{"id_menu":2,"count":1}]	1460	delivery	5	19
74929	2020-06-07 18:50:29	2020-06-07	17	[{"id_menu":4,"count":2}]	24875	pick-up	0	17
74930	2020-06-07 18:51:36	2020-06-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	10526	delivery	5	28
74931	2020-06-07 18:53:03	2020-06-07	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	29453	delivery	5	25
74932	2020-06-07 18:53:31	2020-06-07	9	[{"id_menu":7,"count":2}]	29499	pick-up	0	9
74933	2020-06-07 19:01:17	2020-06-07	12	[{"id_menu":1,"count":1}]	7017	pick-up	0	12
74934	2020-06-07 19:03:00	2020-06-07	8	[{"id_menu":5,"count":1}]	6970	delivery	5	13
74935	2020-06-07 19:04:27	2020-06-07	17	[{"id_menu":4,"count":1}]	2083	delivery	5	22
74936	2020-06-07 19:05:37	2020-06-07	9	[{"id_menu":6,"count":1}]	29375	delivery	5	14
74937	2020-06-07 19:06:57	2020-06-07	8	[{"id_menu":5,"count":1}]	10994	delivery	5	13
74938	2020-06-07 19:06:57	2020-06-07	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	19497	delivery	5	34
74939	2020-06-07 19:07:22	2020-06-07	8	[{"id_menu":5,"count":1}]	5159	delivery	5	13
74940	2020-06-07 19:09:59	2020-06-07	9	[{"id_menu":6,"count":2}]	17933	delivery	5	14
74941	2020-06-07 19:14:29	2020-06-07	9	[{"id_menu":7,"count":1}]	29541	delivery	5	14
74942	2020-06-07 19:16:03	2020-06-07	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	17541	delivery	5	36
74943	2020-06-07 19:17:25	2020-06-07	14	[{"id_menu":2,"count":1}]	29385	pick-up	0	14
74944	2020-06-07 19:18:26	2020-06-07	17	[{"id_menu":4,"count":1}]	638	delivery	5	22
74945	2020-06-07 19:20:59	2020-06-07	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	171	pick-up	0	24
74946	2020-06-07 19:24:04	2020-06-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11709	delivery	5	23
74947	2020-06-07 19:25:44	2020-06-07	9	[{"id_menu":7,"count":1}]	20406	delivery	5	14
74948	2020-06-07 19:27:43	2020-06-07	9	[{"id_menu":7,"count":1}]	3163	delivery	5	14
74949	2020-06-07 19:28:54	2020-06-07	14	[{"id_menu":2,"count":1}]	7591	pick-up	0	14
74950	2020-06-07 19:32:03	2020-06-07	14	[{"id_menu":2,"count":1}]	2319	pick-up	0	14
74951	2020-06-07 19:35:13	2020-06-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27340	delivery	5	23
74952	2020-06-07 19:35:52	2020-06-07	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14288	delivery	5	49
74953	2020-06-07 19:39:41	2020-06-07	14	[{"id_menu":2,"count":1}]	16838	delivery	5	19
74954	2020-06-07 19:40:07	2020-06-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14380	delivery	5	22
74955	2020-06-07 19:44:36	2020-06-07	9	[{"id_menu":6,"count":1}]	5958	pick-up	0	9
74956	2020-06-07 19:44:57	2020-06-07	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	29417	delivery	5	28
74957	2020-06-07 19:46:21	2020-06-07	12	[{"id_menu":3,"count":1}]	13930	pick-up	0	12
74958	2020-06-07 19:47:15	2020-06-07	9	[{"id_menu":7,"count":1}]	25675	delivery	5	14
74959	2020-06-07 19:47:25	2020-06-07	9	[{"id_menu":6,"count":1}]	26428	pick-up	0	9
74960	2020-06-07 19:49:28	2020-06-07	12	[{"id_menu":3,"count":1}]	7834	delivery	5	17
74961	2020-06-07 19:49:43	2020-06-07	12	[{"id_menu":3,"count":1}]	8471	delivery	5	17
74962	2020-06-07 19:50:57	2020-06-07	8	[{"id_menu":5,"count":1}]	66	pick-up	0	8
74963	2020-06-07 19:53:42	2020-06-07	8	[{"id_menu":5,"count":1}]	29425	delivery	5	13
74964	2020-06-07 19:56:29	2020-06-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	19486	delivery	5	28
74965	2020-06-07 19:59:24	2020-06-07	12	[{"id_menu":3,"count":1}]	27986	delivery	5	17
74966	2020-06-07 20:00:04	2020-06-07	9	[{"id_menu":6,"count":2}]	21703	delivery	5	14
74967	2020-06-07 20:01:40	2020-06-07	12	[{"id_menu":3,"count":1}]	29515	pick-up	0	12
74968	2020-06-07 20:02:57	2020-06-07	14	[{"id_menu":2,"count":1}]	29539	delivery	5	19
74969	2020-06-07 20:05:32	2020-06-07	12	[{"id_menu":3,"count":1}]	26587	delivery	5	17
74970	2020-06-07 20:07:58	2020-06-07	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	29556	delivery	5	26
74971	2020-06-07 20:08:38	2020-06-07	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29470	delivery	5	37
74972	2020-06-07 20:09:47	2020-06-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	15525	delivery	5	28
74973	2020-06-07 20:10:14	2020-06-07	9	[{"id_menu":7,"count":1}]	29270	delivery	5	14
74974	2020-06-07 20:11:29	2020-06-07	14	[{"id_menu":2,"count":3}]	29423	pick-up	0	14
74975	2020-06-07 20:11:44	2020-06-07	14	[{"id_menu":2,"count":1}]	4872	pick-up	0	14
74976	2020-06-07 20:15:08	2020-06-07	14	[{"id_menu":2,"count":1}]	29485	delivery	5	19
74977	2020-06-07 20:16:52	2020-06-07	9	[{"id_menu":7,"count":1}]	5683	pick-up	0	9
74978	2020-06-07 20:18:26	2020-06-07	8	[{"id_menu":5,"count":1}]	14364	pick-up	0	8
74979	2020-06-07 20:20:30	2020-06-07	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	29514	pick-up	0	26
74980	2020-06-07 20:20:30	2020-06-07	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10412	pick-up	0	26
74981	2020-06-07 20:21:02	2020-06-07	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	6385	delivery	5	34
74982	2020-06-07 20:22:41	2020-06-07	12	[{"id_menu":1,"count":1}]	29394	pick-up	0	12
74983	2020-06-07 20:30:43	2020-06-07	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3712	delivery	5	30
74984	2020-06-07 20:34:59	2020-06-07	8	[{"id_menu":5,"count":1}]	23989	delivery	5	13
74985	2020-06-07 20:35:07	2020-06-07	17	[{"id_menu":4,"count":1}]	10200	delivery	5	22
74986	2020-06-07 20:36:57	2020-06-07	9	[{"id_menu":7,"count":1}]	3126	pick-up	0	9
74987	2020-06-07 20:39:48	2020-06-07	14	[{"id_menu":2,"count":1}]	12378	delivery	5	19
74988	2020-06-07 20:40:19	2020-06-07	9	[{"id_menu":7,"count":1}]	23751	delivery	5	14
74989	2020-06-07 20:42:32	2020-06-07	9	[{"id_menu":6,"count":1}]	23293	delivery	5	14
74990	2020-06-07 20:46:52	2020-06-07	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	29411	delivery	5	31
74991	2020-06-07 20:47:43	2020-06-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14593	delivery	5	22
74992	2020-06-07 20:49:09	2020-06-07	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	6099	delivery	5	25
74993	2020-06-07 20:52:34	2020-06-07	9	[{"id_menu":7,"count":1}]	20329	delivery	5	14
74994	2020-06-07 20:54:35	2020-06-07	17	[{"id_menu":4,"count":1}]	5649	delivery	5	22
74995	2020-06-07 20:56:34	2020-06-07	9	[{"id_menu":7,"count":1}]	29462	delivery	5	14
74996	2020-06-07 20:57:46	2020-06-07	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	15380	delivery	5	42
74997	2020-06-07 21:00:52	2020-06-07	12	[{"id_menu":3,"count":1}]	29065	pick-up	0	12
74998	2020-06-07 21:01:27	2020-06-07	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12390	delivery	5	45
74999	2020-06-07 21:02:17	2020-06-07	9	[{"id_menu":7,"count":1}]	8980	delivery	5	14
75000	2020-06-07 21:02:51	2020-06-07	8	[{"id_menu":5,"count":1}]	11778	delivery	5	13
75001	2020-06-07 21:03:15	2020-06-07	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":2}]	12819	delivery	5	31
75002	2020-06-07 21:04:17	2020-06-07	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	29544	delivery	5	39
75003	2020-06-07 21:07:33	2020-06-07	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	15780	pick-up	0	29
75004	2020-06-07 21:10:52	2020-06-07	12	[{"id_menu":1,"count":1}]	29548	delivery	5	17
75005	2020-06-07 21:11:48	2020-06-07	9	[{"id_menu":7,"count":1}]	2590	pick-up	0	9
75006	2020-06-07 21:12:33	2020-06-07	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	29373	delivery	5	34
75007	2020-06-07 21:18:22	2020-06-07	8	[{"id_menu":5,"count":1}]	4453	delivery	5	13
75008	2020-06-07 21:19:54	2020-06-07	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15026	pick-up	0	32
75009	2020-06-07 21:20:34	2020-06-07	12	[{"id_menu":1,"count":1}]	3517	delivery	5	17
75010	2020-06-07 21:22:06	2020-06-07	17	[{"id_menu":4,"count":1}]	6787	delivery	5	22
75011	2020-06-07 21:24:28	2020-06-07	9	[{"id_menu":7,"count":1}]	15423	delivery	5	14
75012	2020-06-07 21:27:10	2020-06-07	9	[{"id_menu":6,"count":1}]	9820	delivery	5	14
75013	2020-06-07 21:30:23	2020-06-07	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	17005	delivery	5	22
75014	2020-06-07 21:30:31	2020-06-07	12	[{"id_menu":3,"count":1}]	26343	delivery	5	17
75015	2020-06-07 21:31:03	2020-06-07	14	[{"id_menu":2,"count":1}]	17594	pick-up	0	14
75016	2020-06-07 21:31:57	2020-06-07	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	19141	delivery	5	25
75017	2020-06-07 21:37:13	2020-06-07	8	[{"id_menu":5,"count":1}]	1533	pick-up	0	8
75018	2020-06-07 21:37:26	2020-06-07	9	[{"id_menu":6,"count":1}]	15266	delivery	5	14
75019	2020-06-07 21:40:39	2020-06-07	14	[{"id_menu":2,"count":1}]	207	pick-up	0	14
75020	2020-06-07 21:43:31	2020-06-07	8	[{"id_menu":5,"count":1}]	26968	delivery	5	13
75021	2020-06-07 21:46:37	2020-06-07	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	29456	delivery	5	31
75022	2020-06-07 21:48:20	2020-06-07	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19971	delivery	5	48
75023	2020-06-07 21:48:22	2020-06-07	8	[{"id_menu":5,"count":1}]	20511	delivery	5	13
75024	2020-06-07 21:49:27	2020-06-07	9	[{"id_menu":6,"count":1}]	23311	delivery	5	14
75025	2020-06-07 21:52:37	2020-06-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13597	delivery	5	22
75026	2020-06-07 21:53:37	2020-06-07	14	[{"id_menu":2,"count":1}]	7774	delivery	5	19
75027	2020-06-07 21:54:43	2020-06-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	29526	delivery	5	28
75028	2020-06-07 21:55:08	2020-06-07	9	[{"id_menu":6,"count":1}]	19159	pick-up	0	9
75029	2020-06-07 21:58:21	2020-06-07	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12910	delivery	5	47
75030	2020-06-07 21:58:45	2020-06-07	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	14962	delivery	5	40
75031	2020-06-07 21:59:00	2020-06-07	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	29465	delivery	5	36
75032	2020-06-07 21:59:43	2020-06-07	8	[{"id_menu":5,"count":1}]	29557	delivery	5	13
75033	2020-06-07 21:59:57	2020-06-07	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	6987	pick-up	0	24
75034	2020-06-07 22:00:15	2020-06-07	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	29495	delivery	5	45
75035	2020-06-07 22:00:39	2020-06-07	9	[{"id_menu":6,"count":1}]	22200	delivery	5	14
75036	2020-06-07 22:02:31	2020-06-07	8	[{"id_menu":5,"count":1}]	10729	delivery	5	13
75037	2020-06-07 22:02:43	2020-06-07	17	[{"id_menu":4,"count":1}]	1538	delivery	5	22
75038	2020-06-07 22:07:53	2020-06-07	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	17100	delivery	5	37
75039	2020-06-07 22:08:03	2020-06-07	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	23074	delivery	5	45
75040	2020-06-07 22:11:24	2020-06-07	9	[{"id_menu":6,"count":1}]	27228	delivery	5	14
75041	2020-06-07 22:11:25	2020-06-07	8	[{"id_menu":5,"count":1}]	3351	delivery	5	13
75042	2020-06-07 22:13:55	2020-06-07	17	[{"id_menu":4,"count":1}]	29390	delivery	5	22
75043	2020-06-07 22:15:07	2020-06-07	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	15965	delivery	5	29
75044	2020-06-07 22:16:34	2020-06-07	9	[{"id_menu":7,"count":1}]	5039	pick-up	0	9
75045	2020-06-07 22:19:07	2020-06-07	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	18652	delivery	5	31
75046	2020-06-07 22:21:09	2020-06-07	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11785	delivery	5	45
75047	2020-06-07 22:22:42	2020-06-07	12	[{"id_menu":3,"count":1}]	285	pick-up	0	12
75048	2020-06-07 22:23:57	2020-06-07	9	[{"id_menu":6,"count":3}]	14263	delivery	5	14
75049	2020-06-07 22:24:13	2020-06-07	9	[{"id_menu":6,"count":1}]	547	pick-up	0	9
75050	2020-06-07 22:24:32	2020-06-07	17	[{"id_menu":4,"count":1}]	13757	delivery	5	22
75051	2020-06-07 22:28:05	2020-06-07	9	[{"id_menu":7,"count":1}]	5574	delivery	5	14
75052	2020-06-07 22:30:09	2020-06-07	12	[{"id_menu":3,"count":1}]	17037	delivery	5	17
75053	2020-06-07 22:31:05	2020-06-07	8	[{"id_menu":5,"count":1}]	29413	delivery	5	13
75054	2020-06-07 22:33:07	2020-06-07	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10868	delivery	5	48
75055	2020-06-07 22:34:52	2020-06-07	9	[{"id_menu":7,"count":1}]	12236	delivery	5	14
75056	2020-06-07 22:40:09	2020-06-07	9	[{"id_menu":7,"count":1}]	29384	delivery	5	14
75057	2020-06-07 22:41:06	2020-06-07	12	[{"id_menu":3,"count":1}]	10105	delivery	5	17
75058	2020-06-07 22:45:03	2020-06-07	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2735	pick-up	0	38
75059	2020-06-07 22:46:02	2020-06-07	9	[{"id_menu":7,"count":1}]	29520	delivery	5	14
75060	2020-06-07 22:47:54	2020-06-07	9	[{"id_menu":6,"count":1}]	29431	delivery	5	14
75061	2020-06-07 22:51:40	2020-06-07	8	[{"id_menu":5,"count":1}]	20060	pick-up	0	8
75062	2020-06-07 22:54:44	2020-06-07	17	[{"id_menu":4,"count":1}]	2575	pick-up	0	17
75063	2020-06-07 22:55:12	2020-06-07	12	[{"id_menu":3,"count":1}]	3065	pick-up	0	12
75064	2020-06-07 23:02:16	2020-06-07	17	[{"id_menu":4,"count":1}]	29532	delivery	5	22
75065	2020-06-07 23:05:04	2020-06-07	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	25173	pick-up	0	26
75066	2020-06-07 23:05:19	2020-06-07	9	[{"id_menu":6,"count":1}]	6642	delivery	5	14
75067	2020-06-07 23:06:14	2020-06-07	14	[{"id_menu":2,"count":1}]	14582	delivery	5	19
75068	2020-06-07 23:08:21	2020-06-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13373	delivery	5	22
75069	2020-06-07 23:10:37	2020-06-07	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	643	pick-up	0	26
75070	2020-06-07 23:10:51	2020-06-07	9	[{"id_menu":6,"count":1}]	18465	delivery	5	14
75071	2020-06-07 23:13:30	2020-06-07	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	28120	delivery	5	31
75072	2020-06-07 23:14:13	2020-06-07	8	[{"id_menu":5,"count":1}]	22207	pick-up	0	8
75073	2020-06-07 23:17:13	2020-06-07	9	[{"id_menu":7,"count":1}]	12593	pick-up	0	9
75074	2020-06-07 23:17:56	2020-06-07	9	[{"id_menu":7,"count":1}]	29409	delivery	5	14
75075	2020-06-07 23:18:59	2020-06-07	12	[{"id_menu":3,"count":1}]	12444	pick-up	0	12
75076	2020-06-07 23:23:58	2020-06-07	9	[{"id_menu":7,"count":2}]	23427	delivery	5	14
75077	2020-06-07 23:24:13	2020-06-07	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	4912	delivery	5	22
75078	2020-06-07 23:25:55	2020-06-07	12	[{"id_menu":3,"count":1}]	20624	delivery	5	17
75079	2020-06-07 23:27:10	2020-06-07	9	[{"id_menu":6,"count":1}]	2197	pick-up	0	9
75080	2020-06-07 23:28:11	2020-06-07	17	[{"id_menu":4,"count":1}]	19130	delivery	5	22
75081	2020-06-07 23:28:19	2020-06-07	9	[{"id_menu":6,"count":1}]	18683	delivery	5	14
75082	2020-06-07 23:34:35	2020-06-07	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	5110	delivery	5	31
75083	2020-06-07 23:38:55	2020-06-07	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	18190	delivery	5	31
75084	2020-06-07 23:38:57	2020-06-07	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24787	delivery	5	46
75085	2020-06-07 23:42:15	2020-06-07	12	[{"id_menu":1,"count":2}]	4929	pick-up	0	12
75086	2020-06-07 23:43:26	2020-06-07	9	[{"id_menu":6,"count":1}]	6957	pick-up	0	9
75087	2020-06-07 23:43:59	2020-06-07	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	28173	delivery	5	27
75088	2020-06-07 23:45:07	2020-06-07	14	[{"id_menu":2,"count":1}]	29500	delivery	5	19
75089	2020-06-07 23:46:00	2020-06-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	27725	delivery	5	26
75090	2020-06-07 23:47:18	2020-06-07	9	[{"id_menu":6,"count":3}]	27717	delivery	5	14
75091	2020-06-07 23:51:37	2020-06-07	17	[{"id_menu":4,"count":1}]	18425	pick-up	0	17
75092	2020-06-07 23:52:56	2020-06-07	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	16916	delivery	5	42
75093	2020-06-07 23:53:37	2020-06-07	12	[{"id_menu":1,"count":1}]	21982	pick-up	0	12
75094	2020-06-07 23:55:30	2020-06-07	14	[{"id_menu":2,"count":1}]	18128	delivery	5	19
75095	2020-06-07 23:55:53	2020-06-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	16501	pick-up	0	23
75096	2020-06-07 23:56:39	2020-06-07	12	[{"id_menu":3,"count":1}]	18396	pick-up	0	12
75097	2020-06-07 23:58:03	2020-06-07	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	29513	delivery	5	26
75098	2020-06-07 23:59:46	2020-06-07	12	[{"id_menu":1,"count":1}]	2358	pick-up	0	12
75099	2020-06-08 00:11:41	2020-06-08	8	[{"id_menu":5,"count":1}]	29654	delivery	5	13
75100	2020-06-08 00:14:02	2020-06-08	14	[{"id_menu":2,"count":2}]	13937	delivery	5	19
75101	2020-06-08 00:16:55	2020-06-08	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	5181	delivery	5	39
75102	2020-06-08 00:20:05	2020-06-08	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	8561	pick-up	0	26
75103	2020-06-08 00:32:01	2020-06-08	9	[{"id_menu":6,"count":1}]	4937	pick-up	0	9
75104	2020-06-08 00:32:05	2020-06-08	9	[{"id_menu":6,"count":1}]	29608	delivery	5	14
75105	2020-06-08 00:32:54	2020-06-08	14	[{"id_menu":2,"count":2}]	5876	delivery	5	19
75106	2020-06-08 00:36:39	2020-06-08	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	22573	delivery	5	43
75107	2020-06-08 00:43:09	2020-06-08	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	26154	delivery	5	23
75108	2020-06-08 00:45:23	2020-06-08	12	[{"id_menu":3,"count":1}]	11225	pick-up	0	12
75109	2020-06-08 00:48:10	2020-06-08	12	[{"id_menu":1,"count":1}]	29587	delivery	5	17
75110	2020-06-08 01:02:23	2020-06-08	8	[{"id_menu":5,"count":1}]	20387	delivery	5	13
75111	2020-06-08 01:03:02	2020-06-08	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":2}]	25685	delivery	5	26
75112	2020-06-08 01:03:33	2020-06-08	9	[{"id_menu":6,"count":1}]	22197	delivery	5	14
75113	2020-06-08 01:04:32	2020-06-08	9	[{"id_menu":7,"count":1}]	29582	delivery	5	14
75114	2020-06-08 01:07:22	2020-06-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	22149	delivery	5	23
75115	2020-06-08 01:07:22	2020-06-08	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5494	delivery	5	31
75116	2020-06-08 01:11:53	2020-06-08	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	18445	delivery	5	39
75117	2020-06-08 01:17:05	2020-06-08	17	[{"id_menu":4,"count":1}]	21608	delivery	5	22
75118	2020-06-08 01:18:47	2020-06-08	12	[{"id_menu":1,"count":1}]	24018	delivery	5	17
75119	2020-06-08 01:36:14	2020-06-08	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29698	delivery	5	36
75120	2020-06-08 01:41:37	2020-06-08	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	14897	delivery	5	30
75121	2020-06-08 01:46:35	2020-06-08	9	[{"id_menu":6,"count":1}]	1820	pick-up	0	9
75122	2020-06-08 01:52:25	2020-06-08	17	[{"id_menu":4,"count":1}]	29604	delivery	5	22
75123	2020-06-08 01:53:23	2020-06-08	17	[{"id_menu":4,"count":1}]	19798	pick-up	0	17
75124	2020-06-08 01:54:06	2020-06-08	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	22531	delivery	5	26
75125	2020-06-08 01:54:08	2020-06-08	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29737	delivery	5	31
75126	2020-06-08 01:56:39	2020-06-08	17	[{"id_menu":4,"count":1}]	29573	delivery	5	22
75127	2020-06-08 01:57:42	2020-06-08	9	[{"id_menu":6,"count":1}]	6644	pick-up	0	9
75128	2020-06-08 01:58:31	2020-06-08	9	[{"id_menu":7,"count":1}]	13550	delivery	5	14
75129	2020-06-08 01:58:40	2020-06-08	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	12401	delivery	5	26
75130	2020-06-08 02:01:08	2020-06-08	14	[{"id_menu":2,"count":1}]	25444	delivery	5	19
75131	2020-06-08 02:05:46	2020-06-08	14	[{"id_menu":2,"count":1}]	21870	delivery	5	19
75132	2020-06-08 02:05:57	2020-06-08	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29598	delivery	5	31
75133	2020-06-08 02:17:50	2020-06-08	9	[{"id_menu":6,"count":1}]	13441	delivery	5	14
75134	2020-06-08 02:22:46	2020-06-08	14	[{"id_menu":2,"count":1}]	7479	delivery	5	19
75135	2020-06-08 02:25:31	2020-06-08	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	19230	delivery	5	25
75136	2020-06-08 02:32:09	2020-06-08	17	[{"id_menu":4,"count":1}]	14190	pick-up	0	17
75137	2020-06-08 02:32:27	2020-06-08	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	25535	delivery	5	31
75138	2020-06-08 02:47:29	2020-06-08	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	15916	delivery	5	36
75139	2020-06-08 02:49:02	2020-06-08	9	[{"id_menu":6,"count":1}]	315	delivery	5	14
75140	2020-06-08 03:05:13	2020-06-08	12	[{"id_menu":3,"count":1}]	721	pick-up	0	12
75141	2020-06-08 03:06:37	2020-06-08	12	[{"id_menu":1,"count":1}]	29695	delivery	5	17
75142	2020-06-08 03:09:43	2020-06-08	12	[{"id_menu":1,"count":1}]	29572	delivery	5	17
75143	2020-06-08 03:10:00	2020-06-08	9	[{"id_menu":7,"count":1}]	29647	delivery	5	14
75144	2020-06-08 03:10:16	2020-06-08	9	[{"id_menu":7,"count":1}]	29667	delivery	5	14
75145	2020-06-08 03:11:01	2020-06-08	9	[{"id_menu":6,"count":1}]	2964	pick-up	0	9
75146	2020-06-08 03:14:42	2020-06-08	8	[{"id_menu":5,"count":2}]	2878	delivery	5	13
75147	2020-06-08 03:19:04	2020-06-08	14	[{"id_menu":2,"count":1}]	22208	delivery	5	19
75148	2020-06-08 03:27:52	2020-06-08	8	[{"id_menu":5,"count":1}]	26708	delivery	5	13
75149	2020-06-08 03:28:20	2020-06-08	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15079	delivery	5	34
75150	2020-06-08 03:32:55	2020-06-08	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2908	delivery	5	44
75151	2020-06-08 03:34:59	2020-06-08	12	[{"id_menu":3,"count":1}]	22196	delivery	5	17
75152	2020-06-08 03:35:39	2020-06-08	30	[{"id_menu":1,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23947	delivery	5	35
75153	2020-06-08 03:37:14	2020-06-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	28255	delivery	5	28
75154	2020-06-08 03:38:08	2020-06-08	17	[{"id_menu":4,"count":1}]	24452	pick-up	0	17
75155	2020-06-08 03:38:15	2020-06-08	8	[{"id_menu":5,"count":1}]	27639	pick-up	0	8
75156	2020-06-08 03:40:51	2020-06-08	17	[{"id_menu":4,"count":1}]	2928	delivery	5	22
75157	2020-06-08 03:42:14	2020-06-08	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	20816	delivery	5	31
75158	2020-06-08 03:42:21	2020-06-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	11759	delivery	5	28
75159	2020-06-08 03:42:25	2020-06-08	14	[{"id_menu":2,"count":1}]	20789	delivery	5	19
75160	2020-06-08 03:43:26	2020-06-08	14	[{"id_menu":2,"count":2}]	29680	delivery	5	19
75161	2020-06-08 03:43:30	2020-06-08	12	[{"id_menu":1,"count":1}]	22865	delivery	5	17
75162	2020-06-08 03:49:24	2020-06-08	12	[{"id_menu":3,"count":1}]	14712	delivery	5	17
75163	2020-06-08 03:55:40	2020-06-08	9	[{"id_menu":6,"count":1}]	10803	delivery	5	14
75164	2020-06-08 03:55:47	2020-06-08	14	[{"id_menu":2,"count":1}]	11334	delivery	5	19
75165	2020-06-08 03:59:28	2020-06-08	9	[{"id_menu":6,"count":1}]	18839	delivery	5	14
75166	2020-06-08 04:03:24	2020-06-08	9	[{"id_menu":6,"count":1}]	14930	delivery	5	14
75167	2020-06-08 04:07:56	2020-06-08	17	[{"id_menu":4,"count":1}]	25908	delivery	5	22
75168	2020-06-08 04:09:32	2020-06-08	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10920	delivery	5	48
75169	2020-06-08 04:10:18	2020-06-08	9	[{"id_menu":7,"count":1}]	7247	pick-up	0	9
75170	2020-06-08 04:13:43	2020-06-08	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	24788	delivery	5	31
75171	2020-06-08 04:16:17	2020-06-08	17	[{"id_menu":4,"count":1}]	29713	delivery	5	22
75172	2020-06-08 04:19:46	2020-06-08	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1140	pick-up	0	26
75173	2020-06-08 04:21:55	2020-06-08	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	552	pick-up	0	34
75174	2020-06-08 04:28:09	2020-06-08	17	[{"id_menu":4,"count":1}]	8826	pick-up	0	17
75175	2020-06-08 04:28:29	2020-06-08	8	[{"id_menu":5,"count":1}]	29226	pick-up	0	8
75176	2020-06-08 04:31:41	2020-06-08	8	[{"id_menu":5,"count":1}]	16232	delivery	5	13
75177	2020-06-08 04:31:43	2020-06-08	17	[{"id_menu":4,"count":1}]	6687	pick-up	0	17
75178	2020-06-08 04:34:15	2020-06-08	12	[{"id_menu":3,"count":1}]	4636	pick-up	0	12
75179	2020-06-08 04:36:24	2020-06-08	12	[{"id_menu":1,"count":1}]	25190	pick-up	0	12
75180	2020-06-08 04:43:05	2020-06-08	8	[{"id_menu":5,"count":1}]	1715	pick-up	0	8
75181	2020-06-08 04:50:17	2020-06-08	9	[{"id_menu":6,"count":1}]	18165	delivery	5	14
75182	2020-06-08 05:04:04	2020-06-08	9	[{"id_menu":7,"count":1}]	593	pick-up	0	9
75183	2020-06-08 05:15:13	2020-06-08	8	[{"id_menu":5,"count":1}]	29665	delivery	5	13
75184	2020-06-08 05:21:10	2020-06-08	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	29614	delivery	5	26
75185	2020-06-08 05:25:45	2020-06-08	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	17874	delivery	5	40
75186	2020-06-08 05:25:59	2020-06-08	12	[{"id_menu":1,"count":1}]	2065	delivery	5	17
75187	2020-06-08 05:30:03	2020-06-08	9	[{"id_menu":6,"count":1}]	21757	delivery	5	14
75188	2020-06-08 05:30:11	2020-06-08	9	[{"id_menu":7,"count":1}]	29715	delivery	5	14
75189	2020-06-08 05:54:37	2020-06-08	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19909	delivery	5	39
75190	2020-06-08 05:57:44	2020-06-08	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	1450	delivery	5	26
75191	2020-06-08 05:58:28	2020-06-08	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	29586	delivery	5	26
75192	2020-06-08 06:00:24	2020-06-08	9	[{"id_menu":7,"count":1}]	28846	delivery	5	14
75193	2020-06-08 06:00:26	2020-06-08	12	[{"id_menu":3,"count":1}]	2510	delivery	5	17
75194	2020-06-08 06:02:30	2020-06-08	9	[{"id_menu":6,"count":1}]	24109	delivery	5	14
75195	2020-06-08 06:02:49	2020-06-08	12	[{"id_menu":3,"count":1}]	18733	pick-up	0	12
75196	2020-06-08 06:11:40	2020-06-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14498	delivery	5	23
75197	2020-06-08 06:12:41	2020-06-08	9	[{"id_menu":6,"count":1}]	1983	pick-up	0	9
75198	2020-06-08 06:15:10	2020-06-08	14	[{"id_menu":2,"count":1}]	5179	delivery	5	19
75199	2020-06-08 06:21:08	2020-06-08	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29659	delivery	5	37
75200	2020-06-08 06:21:21	2020-06-08	14	[{"id_menu":2,"count":1}]	10570	delivery	5	19
75201	2020-06-08 06:23:00	2020-06-08	9	[{"id_menu":7,"count":1}]	19075	pick-up	0	9
75202	2020-06-08 06:24:56	2020-06-08	8	[{"id_menu":5,"count":3}]	24231	delivery	5	13
75203	2020-06-08 06:28:49	2020-06-08	9	[{"id_menu":7,"count":1}]	29703	pick-up	0	9
75204	2020-06-08 06:30:41	2020-06-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	24485	delivery	5	28
75205	2020-06-08 06:31:11	2020-06-08	8	[{"id_menu":5,"count":1}]	23696	pick-up	0	8
75206	2020-06-08 06:34:43	2020-06-08	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	29731	delivery	5	38
75207	2020-06-08 06:46:39	2020-06-08	17	[{"id_menu":4,"count":1}]	12591	delivery	5	22
75208	2020-06-08 06:46:44	2020-06-08	9	[{"id_menu":6,"count":1}]	10047	delivery	5	14
75209	2020-06-08 06:50:31	2020-06-08	12	[{"id_menu":1,"count":1}]	29672	delivery	5	17
75210	2020-06-08 06:51:28	2020-06-08	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	6256	delivery	5	26
75211	2020-06-08 06:56:20	2020-06-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	16219	delivery	5	28
75212	2020-06-08 07:02:14	2020-06-08	12	[{"id_menu":1,"count":1}]	29681	delivery	5	17
75213	2020-06-08 07:08:03	2020-06-08	14	[{"id_menu":2,"count":1}]	1101	delivery	5	19
75214	2020-06-08 07:08:46	2020-06-08	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	10523	pick-up	0	29
75215	2020-06-08 07:15:16	2020-06-08	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	29666	delivery	5	34
75216	2020-06-08 07:17:22	2020-06-08	14	[{"id_menu":2,"count":1}]	29636	delivery	5	19
75217	2020-06-08 07:19:23	2020-06-08	9	[{"id_menu":7,"count":1}]	1986	delivery	5	14
75218	2020-06-08 07:25:04	2020-06-08	8	[{"id_menu":5,"count":1}]	2613	pick-up	0	8
75219	2020-06-08 07:36:15	2020-06-08	14	[{"id_menu":2,"count":1}]	29638	pick-up	0	14
75220	2020-06-08 07:36:54	2020-06-08	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6773	delivery	5	35
75221	2020-06-08 07:39:32	2020-06-08	12	[{"id_menu":3,"count":1}]	29603	delivery	5	17
75222	2020-06-08 07:41:51	2020-06-08	8	[{"id_menu":5,"count":1}]	21253	delivery	5	13
75223	2020-06-08 07:42:49	2020-06-08	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	29718	delivery	5	27
75224	2020-06-08 07:48:27	2020-06-08	12	[{"id_menu":1,"count":1}]	29710	delivery	5	17
75225	2020-06-08 07:50:06	2020-06-08	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2320	delivery	5	30
75226	2020-06-08 07:50:17	2020-06-08	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	5945	delivery	5	27
75227	2020-06-08 07:51:23	2020-06-08	14	[{"id_menu":2,"count":1}]	10306	delivery	5	19
75228	2020-06-08 07:53:15	2020-06-08	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	29708	delivery	5	26
75229	2020-06-08 07:56:40	2020-06-08	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	4001	delivery	5	31
75230	2020-06-08 08:08:47	2020-06-08	8	[{"id_menu":5,"count":2}]	10526	pick-up	0	8
75231	2020-06-08 08:15:30	2020-06-08	14	[{"id_menu":2,"count":1}]	29669	delivery	5	19
75232	2020-06-08 08:25:02	2020-06-08	12	[{"id_menu":1,"count":1}]	29704	pick-up	0	12
75233	2020-06-08 08:25:04	2020-06-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	29676	delivery	5	22
75234	2020-06-08 08:25:25	2020-06-08	17	[{"id_menu":4,"count":1}]	27148	pick-up	0	17
75235	2020-06-08 08:28:44	2020-06-08	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	29689	delivery	5	40
75236	2020-06-08 08:39:24	2020-06-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	16765	pick-up	0	23
75237	2020-06-08 08:43:18	2020-06-08	9	[{"id_menu":6,"count":1}]	3539	pick-up	0	9
75238	2020-06-08 08:45:14	2020-06-08	14	[{"id_menu":2,"count":1}]	4869	pick-up	0	14
75239	2020-06-08 09:04:01	2020-06-08	9	[{"id_menu":7,"count":1}]	6213	delivery	5	14
75240	2020-06-08 09:25:11	2020-06-08	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	29640	delivery	5	40
75241	2020-06-08 09:25:14	2020-06-08	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	29605	delivery	5	25
75242	2020-06-08 09:27:24	2020-06-08	14	[{"id_menu":2,"count":2}]	29658	delivery	5	19
75243	2020-06-08 09:32:47	2020-06-08	12	[{"id_menu":1,"count":1}]	25695	delivery	5	17
75244	2020-06-08 09:39:35	2020-06-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	21866	delivery	5	28
75245	2020-06-08 09:54:15	2020-06-08	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	28181	delivery	5	43
75246	2020-06-08 09:57:27	2020-06-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28517	delivery	5	22
75247	2020-06-08 10:05:21	2020-06-08	12	[{"id_menu":1,"count":1}]	29685	delivery	5	17
75248	2020-06-08 10:08:54	2020-06-08	9	[{"id_menu":7,"count":1}]	24818	delivery	5	14
75249	2020-06-08 10:10:23	2020-06-08	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	11779	pick-up	0	31
75250	2020-06-08 10:12:20	2020-06-08	14	[{"id_menu":2,"count":1}]	29564	delivery	5	19
75251	2020-06-08 10:20:19	2020-06-08	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":2}]	18900	delivery	5	22
75252	2020-06-08 10:37:03	2020-06-08	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	19444	delivery	5	26
75253	2020-06-08 10:37:22	2020-06-08	9	[{"id_menu":7,"count":1}]	15827	delivery	5	14
75254	2020-06-08 10:54:07	2020-06-08	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	22832	delivery	5	45
75255	2020-06-08 11:03:46	2020-06-08	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	29592	delivery	5	36
75256	2020-06-08 11:04:32	2020-06-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29714	delivery	5	23
75257	2020-06-08 11:08:01	2020-06-08	12	[{"id_menu":1,"count":1}]	27577	pick-up	0	12
75258	2020-06-08 11:09:27	2020-06-08	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	29650	delivery	5	36
75259	2020-06-08 11:14:38	2020-06-08	8	[{"id_menu":5,"count":1}]	20064	delivery	5	13
75260	2020-06-08 11:15:13	2020-06-08	12	[{"id_menu":1,"count":1}]	11480	delivery	5	17
75261	2020-06-08 11:15:38	2020-06-08	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	29597	delivery	5	28
75262	2020-06-08 11:16:42	2020-06-08	17	[{"id_menu":4,"count":1}]	29662	pick-up	0	17
75263	2020-06-08 11:18:15	2020-06-08	9	[{"id_menu":7,"count":1}]	8481	delivery	5	14
75264	2020-06-08 11:24:18	2020-06-08	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	4595	pick-up	0	26
75265	2020-06-08 11:26:15	2020-06-08	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29569	delivery	5	34
75266	2020-06-08 11:28:30	2020-06-08	9	[{"id_menu":6,"count":1}]	29607	pick-up	0	9
75267	2020-06-08 11:29:46	2020-06-08	12	[{"id_menu":1,"count":1}]	2743	delivery	5	17
75268	2020-06-08 11:29:50	2020-06-08	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	29618	delivery	5	43
75269	2020-06-08 11:35:05	2020-06-08	12	[{"id_menu":1,"count":1}]	13886	delivery	5	17
75270	2020-06-08 11:35:39	2020-06-08	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	3052	pick-up	0	26
75271	2020-06-08 11:39:54	2020-06-08	12	[{"id_menu":1,"count":1}]	6399	pick-up	0	12
75272	2020-06-08 11:40:14	2020-06-08	9	[{"id_menu":6,"count":2}]	29635	delivery	5	14
75273	2020-06-08 11:41:19	2020-06-08	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	29593	delivery	5	34
75274	2020-06-08 11:50:04	2020-06-08	14	[{"id_menu":2,"count":1}]	29633	delivery	5	19
75275	2020-06-08 11:53:59	2020-06-08	8	[{"id_menu":5,"count":1}]	3511	pick-up	0	8
75276	2020-06-08 11:54:13	2020-06-08	9	[{"id_menu":7,"count":2}]	29738	delivery	5	14
75277	2020-06-08 11:56:06	2020-06-08	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16101	delivery	5	40
75278	2020-06-08 12:05:11	2020-06-08	17	[{"id_menu":4,"count":1}]	9260	delivery	5	22
75279	2020-06-08 12:06:39	2020-06-08	9	[{"id_menu":6,"count":1}]	9586	delivery	5	14
75280	2020-06-08 12:11:29	2020-06-08	8	[{"id_menu":5,"count":1}]	13761	delivery	5	13
75281	2020-06-08 12:11:51	2020-06-08	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	29677	delivery	5	34
75282	2020-06-08 12:13:57	2020-06-08	9	[{"id_menu":7,"count":2}]	18409	pick-up	0	9
75283	2020-06-08 12:20:59	2020-06-08	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	20684	delivery	5	22
75284	2020-06-08 12:33:52	2020-06-08	9	[{"id_menu":6,"count":1}]	20993	delivery	5	14
75285	2020-06-08 12:34:25	2020-06-08	9	[{"id_menu":6,"count":1}]	29606	delivery	5	14
75286	2020-06-08 12:42:54	2020-06-08	9	[{"id_menu":7,"count":1}]	15590	pick-up	0	9
75287	2020-06-08 12:50:02	2020-06-08	9	[{"id_menu":7,"count":1}]	17081	delivery	5	14
75288	2020-06-08 12:54:12	2020-06-08	9	[{"id_menu":7,"count":1}]	27638	delivery	5	14
75289	2020-06-08 13:01:16	2020-06-08	9	[{"id_menu":6,"count":1}]	801	delivery	5	14
75290	2020-06-08 13:02:08	2020-06-08	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	11554	pick-up	0	29
75291	2020-06-08 13:02:18	2020-06-08	12	[{"id_menu":1,"count":1}]	24306	pick-up	0	12
75292	2020-06-08 13:04:04	2020-06-08	17	[{"id_menu":4,"count":1}]	4445	delivery	5	22
75293	2020-06-08 13:09:17	2020-06-08	12	[{"id_menu":1,"count":1}]	11183	pick-up	0	12
75294	2020-06-08 13:17:25	2020-06-08	14	[{"id_menu":2,"count":1}]	21576	delivery	5	19
75295	2020-06-08 13:19:34	2020-06-08	12	[{"id_menu":1,"count":1}]	29629	delivery	5	17
75296	2020-06-08 13:21:17	2020-06-08	9	[{"id_menu":7,"count":1}]	22908	delivery	5	14
75297	2020-06-08 13:27:05	2020-06-08	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29691	delivery	5	35
75298	2020-06-08 13:28:01	2020-06-08	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18793	delivery	5	39
75299	2020-06-08 13:33:55	2020-06-08	12	[{"id_menu":3,"count":1}]	20301	delivery	5	17
75300	2020-06-08 13:35:08	2020-06-08	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	16681	delivery	5	26
75301	2020-06-08 13:39:05	2020-06-08	14	[{"id_menu":2,"count":1}]	16549	delivery	5	19
75302	2020-06-08 13:40:42	2020-06-08	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28244	delivery	5	22
75303	2020-06-08 13:51:49	2020-06-08	12	[{"id_menu":1,"count":1}]	2116	pick-up	0	12
75304	2020-06-08 13:51:50	2020-06-08	9	[{"id_menu":7,"count":1}]	29732	delivery	5	14
75305	2020-06-08 13:57:09	2020-06-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	29690	delivery	5	22
75306	2020-06-08 14:16:32	2020-06-08	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	9224	delivery	5	31
75307	2020-06-08 14:20:54	2020-06-08	14	[{"id_menu":2,"count":1}]	7446	delivery	5	19
75308	2020-06-08 14:22:59	2020-06-08	14	[{"id_menu":2,"count":1}]	29670	delivery	5	19
75309	2020-06-08 14:28:30	2020-06-08	12	[{"id_menu":1,"count":1}]	22183	delivery	5	17
75310	2020-06-08 14:29:15	2020-06-08	12	[{"id_menu":1,"count":1}]	29700	delivery	5	17
75311	2020-06-08 14:30:37	2020-06-08	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	16774	delivery	5	37
75312	2020-06-08 14:37:02	2020-06-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27964	delivery	5	23
75313	2020-06-08 14:39:58	2020-06-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15872	delivery	5	23
75314	2020-06-08 14:44:22	2020-06-08	12	[{"id_menu":3,"count":1}]	17005	delivery	5	17
75315	2020-06-08 14:49:35	2020-06-08	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	22638	delivery	5	31
75316	2020-06-08 14:53:02	2020-06-08	9	[{"id_menu":7,"count":1}]	29648	delivery	5	14
75317	2020-06-08 14:58:11	2020-06-08	8	[{"id_menu":5,"count":1}]	2099	pick-up	0	8
75318	2020-06-08 15:05:13	2020-06-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	21848	delivery	5	28
75319	2020-06-08 15:10:50	2020-06-08	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12193	delivery	5	31
75320	2020-06-08 15:16:28	2020-06-08	17	[{"id_menu":4,"count":1}]	29626	delivery	5	22
75321	2020-06-08 15:19:47	2020-06-08	12	[{"id_menu":3,"count":1}]	27850	delivery	5	17
75322	2020-06-08 15:20:26	2020-06-08	9	[{"id_menu":7,"count":1}]	34	pick-up	0	9
75323	2020-06-08 15:20:59	2020-06-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29566	delivery	5	23
75324	2020-06-08 15:26:20	2020-06-08	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	5150	delivery	5	26
75325	2020-06-08 15:26:59	2020-06-08	9	[{"id_menu":6,"count":1}]	23149	delivery	5	14
75326	2020-06-08 15:40:23	2020-06-08	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	29632	delivery	5	43
75327	2020-06-08 15:45:03	2020-06-08	17	[{"id_menu":4,"count":1}]	23593	delivery	5	22
75328	2020-06-08 15:46:09	2020-06-08	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	23147	pick-up	0	29
75329	2020-06-08 15:46:51	2020-06-08	12	[{"id_menu":1,"count":1}]	29595	delivery	5	17
75330	2020-06-08 15:51:39	2020-06-08	8	[{"id_menu":5,"count":1}]	27827	delivery	5	13
75331	2020-06-08 15:55:38	2020-06-08	14	[{"id_menu":2,"count":2}]	1940	pick-up	0	14
75332	2020-06-08 16:00:02	2020-06-08	14	[{"id_menu":2,"count":1}]	28283	pick-up	0	14
75333	2020-06-08 16:02:37	2020-06-08	8	[{"id_menu":5,"count":1}]	26311	pick-up	0	8
75334	2020-06-08 16:06:44	2020-06-08	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	29644	delivery	5	42
75335	2020-06-08 16:07:58	2020-06-08	12	[{"id_menu":1,"count":1}]	29699	pick-up	0	12
75336	2020-06-08 16:09:59	2020-06-08	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	14970	delivery	5	26
75337	2020-06-08 16:14:13	2020-06-08	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3761	delivery	5	40
75338	2020-06-08 16:26:12	2020-06-08	9	[{"id_menu":7,"count":1}]	29623	delivery	5	14
75339	2020-06-08 16:30:14	2020-06-08	14	[{"id_menu":2,"count":1}]	13179	delivery	5	19
75340	2020-06-08 16:30:48	2020-06-08	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	664	delivery	5	52
75341	2020-06-08 16:31:23	2020-06-08	14	[{"id_menu":2,"count":1}]	11454	pick-up	0	14
75342	2020-06-08 16:35:09	2020-06-08	12	[{"id_menu":1,"count":1}]	204	delivery	5	17
75343	2020-06-08 16:39:36	2020-06-08	9	[{"id_menu":7,"count":1}]	27432	delivery	5	14
75344	2020-06-08 16:42:37	2020-06-08	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28576	pick-up	0	26
75345	2020-06-08 16:44:30	2020-06-08	9	[{"id_menu":6,"count":1}]	12078	delivery	5	14
75346	2020-06-08 16:44:50	2020-06-08	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	29576	delivery	5	42
75347	2020-06-08 16:45:56	2020-06-08	9	[{"id_menu":7,"count":1}]	17211	delivery	5	14
75348	2020-06-08 16:53:33	2020-06-08	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	18612	delivery	5	22
75349	2020-06-08 17:05:52	2020-06-08	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	22319	delivery	5	43
75350	2020-06-08 17:07:05	2020-06-08	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	28543	delivery	5	25
75351	2020-06-08 17:14:14	2020-06-08	14	[{"id_menu":2,"count":1}]	15182	delivery	5	19
75352	2020-06-08 17:21:26	2020-06-08	8	[{"id_menu":5,"count":2}]	7741	delivery	5	13
75353	2020-06-08 17:21:28	2020-06-08	12	[{"id_menu":3,"count":1}]	17366	delivery	5	17
75354	2020-06-08 17:24:13	2020-06-08	9	[{"id_menu":7,"count":1}]	24948	delivery	5	14
75355	2020-06-08 17:30:25	2020-06-08	14	[{"id_menu":2,"count":1}]	7654	delivery	5	19
75356	2020-06-08 17:36:32	2020-06-08	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	29671	delivery	5	36
75357	2020-06-08 17:37:43	2020-06-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26694	pick-up	0	18
75358	2020-06-08 17:43:12	2020-06-08	8	[{"id_menu":5,"count":1}]	29724	delivery	5	13
75359	2020-06-08 17:46:36	2020-06-08	14	[{"id_menu":2,"count":1}]	936	delivery	5	19
75360	2020-06-08 17:49:07	2020-06-08	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	24074	pick-up	0	40
75361	2020-06-08 17:50:20	2020-06-08	9	[{"id_menu":7,"count":1}]	29634	pick-up	0	9
75362	2020-06-08 18:03:05	2020-06-08	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1368	pick-up	0	20
75363	2020-06-08 18:04:29	2020-06-08	8	[{"id_menu":5,"count":1}]	3890	delivery	5	13
75364	2020-06-08 18:05:04	2020-06-08	9	[{"id_menu":7,"count":1}]	29540	delivery	5	14
75365	2020-06-08 18:06:30	2020-06-08	12	[{"id_menu":1,"count":1}]	5380	delivery	5	17
75366	2020-06-08 18:08:26	2020-06-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1529	pick-up	0	23
75367	2020-06-08 18:11:19	2020-06-08	9	[{"id_menu":7,"count":2}]	4113	delivery	5	14
75368	2020-06-08 18:18:00	2020-06-08	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	11146	pick-up	0	26
75369	2020-06-08 18:26:16	2020-06-08	9	[{"id_menu":6,"count":1}]	29620	delivery	5	14
75370	2020-06-08 18:27:56	2020-06-08	14	[{"id_menu":2,"count":1}]	9549	delivery	5	19
75371	2020-06-08 18:32:23	2020-06-08	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10547	delivery	5	42
75372	2020-06-08 18:35:59	2020-06-08	14	[{"id_menu":2,"count":1}]	12945	delivery	5	19
75373	2020-06-08 18:39:42	2020-06-08	14	[{"id_menu":2,"count":1}]	12053	pick-up	0	14
75374	2020-06-08 18:41:30	2020-06-08	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	7726	pick-up	0	35
75375	2020-06-08 18:46:00	2020-06-08	12	[{"id_menu":3,"count":1}]	4577	pick-up	0	12
75376	2020-06-08 18:46:01	2020-06-08	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	9021	delivery	5	31
75377	2020-06-08 18:49:40	2020-06-08	12	[{"id_menu":3,"count":1}]	29716	pick-up	0	12
75378	2020-06-08 18:51:46	2020-06-08	8	[{"id_menu":5,"count":1}]	7499	delivery	5	13
75379	2020-06-08 18:53:16	2020-06-08	17	[{"id_menu":4,"count":1}]	12949	delivery	5	22
75380	2020-06-08 19:03:29	2020-06-08	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29725	delivery	5	52
75381	2020-06-08 19:03:39	2020-06-08	12	[{"id_menu":3,"count":1}]	15087	delivery	5	17
75382	2020-06-08 19:13:09	2020-06-08	14	[{"id_menu":2,"count":1}]	20814	delivery	5	19
75383	2020-06-08 19:15:41	2020-06-08	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	17582	pick-up	0	29
75384	2020-06-08 19:22:20	2020-06-08	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29590	delivery	5	22
75385	2020-06-08 19:22:50	2020-06-08	9	[{"id_menu":7,"count":1}]	28728	delivery	5	14
75386	2020-06-08 19:24:36	2020-06-08	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	21601	pick-up	0	21
75387	2020-06-08 19:34:11	2020-06-08	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	1869	delivery	5	34
75388	2020-06-08 19:37:54	2020-06-08	12	[{"id_menu":1,"count":1}]	14362	pick-up	0	12
75389	2020-06-08 19:40:31	2020-06-08	9	[{"id_menu":7,"count":1}]	4321	delivery	5	14
75390	2020-06-08 19:48:03	2020-06-08	12	[{"id_menu":3,"count":1}]	29717	delivery	5	17
75391	2020-06-08 19:56:49	2020-06-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	20984	delivery	5	28
75392	2020-06-08 20:02:50	2020-06-08	8	[{"id_menu":5,"count":1}]	29615	delivery	5	13
75393	2020-06-08 20:12:51	2020-06-08	8	[{"id_menu":5,"count":1}]	7686	delivery	5	13
75394	2020-06-08 20:13:19	2020-06-08	12	[{"id_menu":3,"count":1}]	8298	pick-up	0	12
75395	2020-06-08 20:15:54	2020-06-08	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	19506	pick-up	0	34
75396	2020-06-08 20:20:58	2020-06-08	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10739	delivery	5	22
75397	2020-06-08 20:24:37	2020-06-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27657	delivery	5	23
75398	2020-06-08 20:34:51	2020-06-08	17	[{"id_menu":4,"count":1}]	12474	pick-up	0	17
75399	2020-06-08 20:44:50	2020-06-08	12	[{"id_menu":3,"count":1}]	3040	delivery	5	17
75400	2020-06-08 20:48:11	2020-06-08	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	29643	delivery	5	34
75401	2020-06-08 21:01:00	2020-06-08	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	29591	delivery	5	45
75402	2020-06-08 21:07:01	2020-06-08	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	17864	delivery	5	40
75403	2020-06-08 21:15:43	2020-06-08	8	[{"id_menu":5,"count":1}]	16246	pick-up	0	8
75404	2020-06-08 21:21:22	2020-06-08	8	[{"id_menu":5,"count":1}]	13027	delivery	5	13
75405	2020-06-08 21:36:00	2020-06-08	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	811	delivery	5	26
75406	2020-06-08 21:38:18	2020-06-08	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	20408	delivery	5	44
75407	2020-06-08 21:47:20	2020-06-08	9	[{"id_menu":7,"count":1}]	20111	delivery	5	14
75408	2020-06-08 21:47:56	2020-06-08	17	[{"id_menu":4,"count":1}]	14722	pick-up	0	17
75409	2020-06-08 21:48:24	2020-06-08	17	[{"id_menu":4,"count":1}]	15961	pick-up	0	17
75410	2020-06-08 21:50:29	2020-06-08	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	29711	delivery	5	31
75411	2020-06-08 21:53:24	2020-06-08	9	[{"id_menu":6,"count":1}]	14592	delivery	5	14
75412	2020-06-08 22:00:40	2020-06-08	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2552	pick-up	0	29
75413	2020-06-08 22:03:04	2020-06-08	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	22431	delivery	5	26
75414	2020-06-08 22:10:11	2020-06-08	14	[{"id_menu":2,"count":1}]	176	pick-up	0	14
75415	2020-06-08 22:12:47	2020-06-08	9	[{"id_menu":7,"count":1}]	4663	delivery	5	14
75416	2020-06-08 22:14:51	2020-06-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2415	delivery	5	28
75417	2020-06-08 22:18:22	2020-06-08	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	21433	delivery	5	31
75418	2020-06-08 22:26:03	2020-06-08	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	29656	delivery	5	26
75419	2020-06-08 22:27:58	2020-06-08	9	[{"id_menu":6,"count":1}]	15497	delivery	5	14
75420	2020-06-08 22:33:54	2020-06-08	14	[{"id_menu":2,"count":1}]	18069	delivery	5	19
75421	2020-06-08 22:39:14	2020-06-08	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6496	delivery	5	36
75422	2020-06-08 22:41:48	2020-06-08	12	[{"id_menu":1,"count":1}]	6147	pick-up	0	12
75423	2020-06-08 22:41:58	2020-06-08	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	13766	delivery	5	34
75424	2020-06-08 23:00:24	2020-06-08	26	[{"id_menu":4,"count":3},{"id_menu":7,"count":1}]	1357	delivery	5	31
75425	2020-06-08 23:02:14	2020-06-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29622	delivery	5	23
75426	2020-06-08 23:04:11	2020-06-08	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16970	delivery	5	36
75427	2020-06-08 23:04:45	2020-06-08	17	[{"id_menu":4,"count":2}]	13400	pick-up	0	17
75428	2020-06-08 23:08:56	2020-06-08	14	[{"id_menu":2,"count":1}]	19270	delivery	5	19
75429	2020-06-08 23:11:00	2020-06-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	16788	delivery	5	28
75430	2020-06-08 23:17:25	2020-06-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25642	delivery	5	23
75431	2020-06-08 23:17:49	2020-06-08	12	[{"id_menu":3,"count":1}]	7835	delivery	5	17
75432	2020-06-08 23:20:16	2020-06-08	8	[{"id_menu":5,"count":1}]	13137	delivery	5	13
75433	2020-06-08 23:20:28	2020-06-08	9	[{"id_menu":6,"count":1}]	16018	delivery	5	14
75434	2020-06-08 23:24:50	2020-06-08	17	[{"id_menu":4,"count":1}]	9251	delivery	5	22
75435	2020-06-08 23:34:14	2020-06-08	12	[{"id_menu":3,"count":1}]	21076	pick-up	0	12
75436	2020-06-08 23:35:23	2020-06-08	9	[{"id_menu":7,"count":1}]	29612	delivery	5	14
75437	2020-06-08 23:41:38	2020-06-08	9	[{"id_menu":7,"count":1}]	9625	delivery	5	14
75438	2020-06-08 23:42:58	2020-06-08	14	[{"id_menu":2,"count":1}]	5736	pick-up	0	14
75439	2020-06-08 23:46:28	2020-06-08	12	[{"id_menu":3,"count":1}]	10640	pick-up	0	12
75440	2020-06-08 23:56:08	2020-06-08	12	[{"id_menu":1,"count":1}]	23804	delivery	5	17
75441	2020-06-09 00:03:20	2020-06-09	12	[{"id_menu":1,"count":1}]	29921	delivery	5	17
75442	2020-06-09 00:08:21	2020-06-09	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	13314	delivery	5	40
75443	2020-06-09 00:13:23	2020-06-09	9	[{"id_menu":7,"count":1}]	14361	delivery	5	14
75444	2020-06-09 00:15:56	2020-06-09	9	[{"id_menu":6,"count":1}]	20699	delivery	5	14
75445	2020-06-09 00:15:57	2020-06-09	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29762	delivery	5	35
75446	2020-06-09 00:19:02	2020-06-09	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13799	delivery	5	31
75447	2020-06-09 00:23:28	2020-06-09	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29868	delivery	5	35
75448	2020-06-09 00:26:36	2020-06-09	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	26361	delivery	5	43
75449	2020-06-09 00:28:27	2020-06-09	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15578	delivery	5	40
75450	2020-06-09 00:28:29	2020-06-09	8	[{"id_menu":5,"count":1}]	9537	delivery	5	13
75451	2020-06-09 00:28:40	2020-06-09	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	21643	delivery	5	28
75452	2020-06-09 00:34:22	2020-06-09	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	11189	pick-up	0	26
75453	2020-06-09 00:43:36	2020-06-09	14	[{"id_menu":2,"count":1}]	18114	pick-up	0	14
75454	2020-06-09 00:55:29	2020-06-09	9	[{"id_menu":6,"count":1}]	1300	pick-up	0	9
75455	2020-06-09 00:59:15	2020-06-09	8	[{"id_menu":5,"count":1}]	29907	delivery	5	13
75456	2020-06-09 01:00:05	2020-06-09	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	29881	pick-up	0	31
75457	2020-06-09 01:00:06	2020-06-09	14	[{"id_menu":2,"count":1}]	27488	delivery	5	19
75458	2020-06-09 01:03:17	2020-06-09	9	[{"id_menu":7,"count":1}]	3689	delivery	5	14
75459	2020-06-09 01:04:12	2020-06-09	9	[{"id_menu":7,"count":1}]	29771	delivery	5	14
75460	2020-06-09 01:04:27	2020-06-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3125	delivery	5	28
75461	2020-06-09 01:05:22	2020-06-09	9	[{"id_menu":7,"count":1}]	22829	delivery	5	14
75462	2020-06-09 01:14:23	2020-06-09	14	[{"id_menu":2,"count":1}]	29924	delivery	5	19
75463	2020-06-09 01:17:12	2020-06-09	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	27557	delivery	5	26
75464	2020-06-09 01:27:06	2020-06-09	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	29914	delivery	5	36
75465	2020-06-09 01:27:11	2020-06-09	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29820	delivery	5	49
75466	2020-06-09 01:28:43	2020-06-09	9	[{"id_menu":6,"count":1}]	546	delivery	5	14
75467	2020-06-09 01:38:41	2020-06-09	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	29744	delivery	5	26
75468	2020-06-09 01:39:27	2020-06-09	9	[{"id_menu":6,"count":1}]	19270	delivery	5	14
75469	2020-06-09 01:40:04	2020-06-09	8	[{"id_menu":5,"count":1}]	29765	delivery	5	13
75470	2020-06-09 01:47:40	2020-06-09	9	[{"id_menu":7,"count":1}]	29902	delivery	5	14
75471	2020-06-09 01:50:30	2020-06-09	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	29916	delivery	5	45
75472	2020-06-09 01:53:00	2020-06-09	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	29760	pick-up	0	26
75473	2020-06-09 02:00:56	2020-06-09	17	[{"id_menu":4,"count":1}]	8785	delivery	5	22
75474	2020-06-09 02:01:54	2020-06-09	9	[{"id_menu":7,"count":1}]	29767	delivery	5	14
75475	2020-06-09 02:13:58	2020-06-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	8171	delivery	5	28
75476	2020-06-09 02:14:39	2020-06-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	21388	delivery	5	28
75477	2020-06-09 02:18:04	2020-06-09	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15679	delivery	5	34
75478	2020-06-09 02:24:35	2020-06-09	17	[{"id_menu":4,"count":1}]	29825	delivery	5	22
75479	2020-06-09 02:29:40	2020-06-09	9	[{"id_menu":7,"count":1}]	14043	delivery	5	14
75480	2020-06-09 02:39:18	2020-06-09	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	29922	delivery	5	25
75481	2020-06-09 02:40:03	2020-06-09	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	74	delivery	5	43
75482	2020-06-09 02:42:10	2020-06-09	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	29873	delivery	5	45
75483	2020-06-09 02:47:53	2020-06-09	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19678	delivery	5	37
75484	2020-06-09 02:50:31	2020-06-09	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27763	delivery	5	35
75485	2020-06-09 02:53:00	2020-06-09	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	20230	delivery	5	39
75486	2020-06-09 02:56:10	2020-06-09	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	1934	delivery	5	34
75487	2020-06-09 02:57:05	2020-06-09	14	[{"id_menu":2,"count":1}]	7053	delivery	5	19
75488	2020-06-09 02:57:13	2020-06-09	8	[{"id_menu":5,"count":1}]	4997	pick-up	0	8
75489	2020-06-09 03:01:16	2020-06-09	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29793	delivery	5	22
75490	2020-06-09 03:05:36	2020-06-09	9	[{"id_menu":6,"count":1}]	19891	delivery	5	14
75491	2020-06-09 03:08:45	2020-06-09	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	29814	delivery	5	26
75492	2020-06-09 03:09:38	2020-06-09	8	[{"id_menu":5,"count":1}]	19341	delivery	5	13
75493	2020-06-09 03:17:45	2020-06-09	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1871	pick-up	0	43
75494	2020-06-09 03:26:41	2020-06-09	17	[{"id_menu":4,"count":1}]	372	pick-up	0	17
75495	2020-06-09 03:31:16	2020-06-09	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	28634	pick-up	0	21
75496	2020-06-09 03:33:22	2020-06-09	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15855	delivery	5	31
75497	2020-06-09 03:38:09	2020-06-09	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29899	delivery	5	45
75498	2020-06-09 03:39:17	2020-06-09	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	23656	delivery	5	26
75499	2020-06-09 03:39:18	2020-06-09	9	[{"id_menu":6,"count":1}]	5430	pick-up	0	9
75500	2020-06-09 03:42:12	2020-06-09	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	29773	delivery	5	34
75501	2020-06-09 03:45:38	2020-06-09	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	28943	delivery	5	31
75502	2020-06-09 03:45:48	2020-06-09	9	[{"id_menu":6,"count":1}]	5609	delivery	5	14
75503	2020-06-09 03:53:53	2020-06-09	17	[{"id_menu":4,"count":1}]	29848	delivery	5	22
75504	2020-06-09 04:07:51	2020-06-09	8	[{"id_menu":5,"count":1}]	29759	delivery	5	13
75505	2020-06-09 04:08:26	2020-06-09	17	[{"id_menu":4,"count":1}]	6421	delivery	5	22
75506	2020-06-09 04:19:57	2020-06-09	12	[{"id_menu":3,"count":1}]	29885	delivery	5	17
75507	2020-06-09 04:21:20	2020-06-09	8	[{"id_menu":5,"count":1}]	6499	delivery	5	13
75508	2020-06-09 04:27:14	2020-06-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	29797	delivery	5	23
75509	2020-06-09 04:30:39	2020-06-09	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	13081	delivery	5	55
75510	2020-06-09 04:36:10	2020-06-09	9	[{"id_menu":6,"count":1}]	29764	delivery	5	14
75511	2020-06-09 04:54:43	2020-06-09	9	[{"id_menu":6,"count":1}]	10200	pick-up	0	9
75512	2020-06-09 04:54:44	2020-06-09	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	398	delivery	5	31
75513	2020-06-09 04:58:28	2020-06-09	17	[{"id_menu":4,"count":1}]	3444	pick-up	0	17
75514	2020-06-09 05:00:53	2020-06-09	9	[{"id_menu":6,"count":1}]	2850	pick-up	0	9
75515	2020-06-09 05:01:51	2020-06-09	17	[{"id_menu":4,"count":1}]	8703	delivery	5	22
75516	2020-06-09 05:03:43	2020-06-09	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9631	delivery	5	34
75517	2020-06-09 05:04:52	2020-06-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5556	delivery	5	28
75518	2020-06-09 05:05:02	2020-06-09	12	[{"id_menu":1,"count":1}]	4257	pick-up	0	12
75519	2020-06-09 05:05:25	2020-06-09	8	[{"id_menu":5,"count":1}]	28030	pick-up	0	8
75520	2020-06-09 05:05:46	2020-06-09	17	[{"id_menu":4,"count":1}]	10576	delivery	5	22
75521	2020-06-09 05:07:33	2020-06-09	8	[{"id_menu":5,"count":1}]	29822	delivery	5	13
75522	2020-06-09 05:10:43	2020-06-09	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	29860	delivery	5	40
75523	2020-06-09 05:14:49	2020-06-09	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	19605	delivery	5	22
75524	2020-06-09 05:19:32	2020-06-09	9	[{"id_menu":6,"count":1}]	16496	pick-up	0	9
75525	2020-06-09 05:23:54	2020-06-09	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3230	pick-up	0	25
75526	2020-06-09 05:24:55	2020-06-09	12	[{"id_menu":1,"count":1}]	23312	pick-up	0	12
75527	2020-06-09 05:25:07	2020-06-09	9	[{"id_menu":7,"count":1}]	29827	delivery	5	14
75528	2020-06-09 05:26:54	2020-06-09	12	[{"id_menu":1,"count":1}]	9941	pick-up	0	12
75529	2020-06-09 05:30:08	2020-06-09	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14947	pick-up	0	30
75530	2020-06-09 05:31:15	2020-06-09	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1348	delivery	5	43
75531	2020-06-09 05:38:09	2020-06-09	8	[{"id_menu":5,"count":1}]	4114	delivery	5	13
75532	2020-06-09 05:44:33	2020-06-09	14	[{"id_menu":2,"count":1}]	2076	delivery	5	19
75533	2020-06-09 05:49:41	2020-06-09	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	29800	pick-up	0	21
75534	2020-06-09 05:59:59	2020-06-09	8	[{"id_menu":5,"count":3}]	29865	delivery	5	13
75535	2020-06-09 06:02:12	2020-06-09	8	[{"id_menu":5,"count":1}]	29758	delivery	5	13
75536	2020-06-09 06:18:45	2020-06-09	9	[{"id_menu":6,"count":1}]	15976	delivery	5	14
75537	2020-06-09 06:24:40	2020-06-09	9	[{"id_menu":7,"count":1}]	7338	delivery	5	14
75538	2020-06-09 06:27:22	2020-06-09	17	[{"id_menu":4,"count":1}]	14622	pick-up	0	17
75539	2020-06-09 06:29:49	2020-06-09	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	29830	pick-up	0	21
75540	2020-06-09 06:31:43	2020-06-09	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	638	pick-up	0	38
75541	2020-06-09 06:32:45	2020-06-09	12	[{"id_menu":1,"count":1}]	1584	pick-up	0	12
75542	2020-06-09 06:35:26	2020-06-09	9	[{"id_menu":6,"count":1}]	29805	delivery	5	14
75543	2020-06-09 06:37:11	2020-06-09	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	15084	delivery	5	39
75544	2020-06-09 06:53:08	2020-06-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7122	delivery	5	22
75545	2020-06-09 06:54:04	2020-06-09	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24538	delivery	5	35
75546	2020-06-09 06:55:09	2020-06-09	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2052	pick-up	0	21
75547	2020-06-09 06:55:19	2020-06-09	9	[{"id_menu":6,"count":1}]	4190	delivery	5	14
75548	2020-06-09 06:56:30	2020-06-09	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12712	delivery	5	31
75549	2020-06-09 06:59:01	2020-06-09	9	[{"id_menu":6,"count":1}]	29821	delivery	5	14
75550	2020-06-09 06:59:59	2020-06-09	8	[{"id_menu":5,"count":1}]	6250	pick-up	0	8
75551	2020-06-09 07:03:57	2020-06-09	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	29857	delivery	5	31
75552	2020-06-09 07:12:14	2020-06-09	8	[{"id_menu":5,"count":1}]	17660	delivery	5	13
75553	2020-06-09 07:12:19	2020-06-09	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	15565	pick-up	0	24
75554	2020-06-09 07:12:47	2020-06-09	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	29749	delivery	5	23
75555	2020-06-09 07:16:16	2020-06-09	9	[{"id_menu":6,"count":1}]	29768	delivery	5	14
75556	2020-06-09 07:18:02	2020-06-09	9	[{"id_menu":6,"count":1}]	16839	delivery	5	14
75557	2020-06-09 07:20:56	2020-06-09	9	[{"id_menu":6,"count":1}]	22359	pick-up	0	9
75558	2020-06-09 07:21:37	2020-06-09	14	[{"id_menu":2,"count":1}]	29365	pick-up	0	14
75559	2020-06-09 07:26:50	2020-06-09	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	29836	delivery	5	26
75560	2020-06-09 07:32:54	2020-06-09	17	[{"id_menu":4,"count":1}]	29913	pick-up	0	17
75561	2020-06-09 07:33:11	2020-06-09	8	[{"id_menu":5,"count":2}]	6429	delivery	5	13
75562	2020-06-09 07:35:45	2020-06-09	17	[{"id_menu":4,"count":1}]	25444	delivery	5	22
75563	2020-06-09 07:39:23	2020-06-09	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	29763	delivery	5	26
75564	2020-06-09 07:42:11	2020-06-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	22313	pick-up	0	23
75565	2020-06-09 07:42:56	2020-06-09	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	29832	pick-up	0	26
75566	2020-06-09 07:45:48	2020-06-09	9	[{"id_menu":6,"count":1}]	8123	pick-up	0	9
75567	2020-06-09 07:47:31	2020-06-09	17	[{"id_menu":4,"count":1}]	10151	pick-up	0	17
75568	2020-06-09 07:57:26	2020-06-09	9	[{"id_menu":6,"count":1}]	2414	delivery	5	14
75569	2020-06-09 07:58:17	2020-06-09	9	[{"id_menu":7,"count":1}]	1808	delivery	5	14
75570	2020-06-09 08:01:04	2020-06-09	9	[{"id_menu":6,"count":1}]	4054	delivery	5	14
75571	2020-06-09 08:01:36	2020-06-09	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	29890	delivery	5	34
75572	2020-06-09 08:03:36	2020-06-09	12	[{"id_menu":3,"count":1}]	29755	delivery	5	17
75573	2020-06-09 08:05:25	2020-06-09	12	[{"id_menu":1,"count":1}]	22456	delivery	5	17
75574	2020-06-09 08:11:48	2020-06-09	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	27100	delivery	5	39
75575	2020-06-09 08:17:45	2020-06-09	12	[{"id_menu":1,"count":1}]	29844	pick-up	0	12
75576	2020-06-09 08:23:27	2020-06-09	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	4836	delivery	5	25
75577	2020-06-09 08:29:14	2020-06-09	12	[{"id_menu":3,"count":1}]	11818	pick-up	0	12
75578	2020-06-09 08:30:28	2020-06-09	12	[{"id_menu":1,"count":1}]	16958	delivery	5	17
75579	2020-06-09 08:31:38	2020-06-09	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	29842	delivery	5	36
75580	2020-06-09 08:32:35	2020-06-09	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15219	pick-up	0	26
75581	2020-06-09 08:35:54	2020-06-09	9	[{"id_menu":6,"count":1}]	18936	delivery	5	14
75582	2020-06-09 08:37:56	2020-06-09	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29093	delivery	5	22
75583	2020-06-09 08:39:45	2020-06-09	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	6856	delivery	5	40
75584	2020-06-09 08:40:26	2020-06-09	8	[{"id_menu":5,"count":1}]	2870	pick-up	0	8
75585	2020-06-09 08:47:37	2020-06-09	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	21257	delivery	5	37
75586	2020-06-09 08:50:52	2020-06-09	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	29782	delivery	5	45
75587	2020-06-09 08:56:15	2020-06-09	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19016	delivery	5	22
75588	2020-06-09 08:58:43	2020-06-09	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	29794	delivery	5	34
75589	2020-06-09 09:02:59	2020-06-09	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7666	delivery	5	31
75590	2020-06-09 09:06:45	2020-06-09	12	[{"id_menu":3,"count":1}]	29835	delivery	5	17
75591	2020-06-09 09:09:37	2020-06-09	14	[{"id_menu":2,"count":1}]	24553	delivery	5	19
75592	2020-06-09 09:16:36	2020-06-09	9	[{"id_menu":7,"count":1}]	29783	delivery	5	14
75593	2020-06-09 09:18:59	2020-06-09	8	[{"id_menu":5,"count":1}]	29780	delivery	5	13
75594	2020-06-09 09:21:46	2020-06-09	9	[{"id_menu":6,"count":1}]	24145	delivery	5	14
75595	2020-06-09 09:22:41	2020-06-09	8	[{"id_menu":5,"count":1}]	316	delivery	5	13
75596	2020-06-09 09:28:31	2020-06-09	9	[{"id_menu":6,"count":1}]	25925	delivery	5	14
75597	2020-06-09 09:39:48	2020-06-09	9	[{"id_menu":7,"count":1}]	486	pick-up	0	9
75598	2020-06-09 09:42:17	2020-06-09	9	[{"id_menu":6,"count":1}]	435	delivery	5	14
75599	2020-06-09 09:43:01	2020-06-09	14	[{"id_menu":2,"count":1}]	6825	delivery	5	19
75600	2020-06-09 09:44:02	2020-06-09	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15120	pick-up	0	17
75601	2020-06-09 09:47:08	2020-06-09	12	[{"id_menu":1,"count":1}]	29833	delivery	5	17
75602	2020-06-09 09:49:27	2020-06-09	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	4202	pick-up	0	21
75603	2020-06-09 09:53:03	2020-06-09	14	[{"id_menu":2,"count":1}]	17152	delivery	5	19
75604	2020-06-09 09:56:35	2020-06-09	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	29861	delivery	5	42
75605	2020-06-09 09:58:30	2020-06-09	8	[{"id_menu":5,"count":1}]	29905	delivery	5	13
75606	2020-06-09 10:02:10	2020-06-09	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7388	delivery	5	43
75607	2020-06-09 10:03:27	2020-06-09	12	[{"id_menu":1,"count":1}]	21387	pick-up	0	12
75608	2020-06-09 10:06:22	2020-06-09	9	[{"id_menu":7,"count":2}]	3153	delivery	5	14
75609	2020-06-09 10:07:24	2020-06-09	9	[{"id_menu":6,"count":1}]	29778	delivery	5	14
75610	2020-06-09 10:12:48	2020-06-09	9	[{"id_menu":7,"count":1}]	15768	delivery	5	14
75611	2020-06-09 10:16:25	2020-06-09	12	[{"id_menu":3,"count":1}]	29849	delivery	5	17
75612	2020-06-09 10:16:51	2020-06-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	29920	delivery	5	28
75613	2020-06-09 10:20:34	2020-06-09	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29863	delivery	5	22
75614	2020-06-09 10:24:46	2020-06-09	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	22547	delivery	5	39
75615	2020-06-09 10:26:58	2020-06-09	14	[{"id_menu":2,"count":1}]	3790	pick-up	0	14
75616	2020-06-09 10:27:41	2020-06-09	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29871	delivery	5	34
75617	2020-06-09 10:28:03	2020-06-09	12	[{"id_menu":1,"count":1}]	28985	delivery	5	17
75618	2020-06-09 10:30:25	2020-06-09	9	[{"id_menu":6,"count":3}]	24693	delivery	5	14
75619	2020-06-09 10:34:09	2020-06-09	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	12602	delivery	5	36
75620	2020-06-09 10:34:19	2020-06-09	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	6245	delivery	5	26
75621	2020-06-09 10:36:26	2020-06-09	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8821	delivery	5	22
75622	2020-06-09 10:40:25	2020-06-09	14	[{"id_menu":2,"count":2}]	29879	delivery	5	19
75623	2020-06-09 10:42:48	2020-06-09	17	[{"id_menu":4,"count":1}]	13082	delivery	5	22
75624	2020-06-09 10:43:52	2020-06-09	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	29816	delivery	5	39
75625	2020-06-09 10:46:41	2020-06-09	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	11681	pick-up	0	34
75626	2020-06-09 10:51:43	2020-06-09	8	[{"id_menu":5,"count":1}]	29187	pick-up	0	8
75627	2020-06-09 10:51:53	2020-06-09	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	23150	delivery	5	28
75628	2020-06-09 10:52:24	2020-06-09	12	[{"id_menu":3,"count":1}]	20558	delivery	5	17
75629	2020-06-09 11:11:47	2020-06-09	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13843	delivery	5	45
75630	2020-06-09 11:12:27	2020-06-09	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	19817	delivery	5	38
75631	2020-06-09 11:17:12	2020-06-09	9	[{"id_menu":6,"count":1}]	5822	delivery	5	14
75632	2020-06-09 11:17:57	2020-06-09	9	[{"id_menu":6,"count":1}]	718	delivery	5	14
75633	2020-06-09 11:19:27	2020-06-09	14	[{"id_menu":2,"count":1}]	23381	delivery	5	19
75634	2020-06-09 11:21:07	2020-06-09	9	[{"id_menu":7,"count":1}]	29815	delivery	5	14
75635	2020-06-09 11:24:56	2020-06-09	12	[{"id_menu":1,"count":1}]	29798	delivery	5	17
75636	2020-06-09 11:39:11	2020-06-09	14	[{"id_menu":2,"count":1}]	26732	delivery	5	19
75637	2020-06-09 11:40:39	2020-06-09	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10367	delivery	5	34
75638	2020-06-09 11:41:51	2020-06-09	9	[{"id_menu":6,"count":1}]	25071	delivery	5	14
75639	2020-06-09 11:43:10	2020-06-09	9	[{"id_menu":6,"count":1}]	29925	delivery	5	14
75640	2020-06-09 11:43:11	2020-06-09	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	743	delivery	5	26
75641	2020-06-09 11:55:01	2020-06-09	8	[{"id_menu":5,"count":1}]	29895	delivery	5	13
75642	2020-06-09 11:58:26	2020-06-09	14	[{"id_menu":2,"count":1}]	17998	delivery	5	19
75643	2020-06-09 12:02:22	2020-06-09	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	29745	delivery	5	23
75644	2020-06-09 12:05:19	2020-06-09	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	6039	pick-up	0	22
75645	2020-06-09 12:05:38	2020-06-09	9	[{"id_menu":6,"count":1}]	11436	delivery	5	14
75646	2020-06-09 12:09:48	2020-06-09	12	[{"id_menu":3,"count":1}]	29775	delivery	5	17
75647	2020-06-09 12:10:06	2020-06-09	12	[{"id_menu":1,"count":1}]	7189	delivery	5	17
75648	2020-06-09 12:12:07	2020-06-09	9	[{"id_menu":7,"count":1}]	8883	pick-up	0	9
75649	2020-06-09 12:13:58	2020-06-09	9	[{"id_menu":7,"count":1}]	18112	delivery	5	14
75650	2020-06-09 12:16:49	2020-06-09	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	29906	delivery	5	34
75651	2020-06-09 12:17:00	2020-06-09	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15360	delivery	5	31
75652	2020-06-09 12:19:49	2020-06-09	8	[{"id_menu":5,"count":1}]	3886	delivery	5	13
75653	2020-06-09 12:22:56	2020-06-09	17	[{"id_menu":4,"count":1}]	5945	delivery	5	22
75654	2020-06-09 12:24:52	2020-06-09	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3831	delivery	5	43
75655	2020-06-09 12:27:22	2020-06-09	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	27181	delivery	5	31
75656	2020-06-09 12:31:59	2020-06-09	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21454	delivery	5	39
75657	2020-06-09 12:35:40	2020-06-09	12	[{"id_menu":1,"count":1}]	29883	delivery	5	17
75658	2020-06-09 12:40:01	2020-06-09	9	[{"id_menu":6,"count":1}]	29856	delivery	5	14
75659	2020-06-09 12:45:15	2020-06-09	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24107	delivery	5	37
75660	2020-06-09 12:45:39	2020-06-09	17	[{"id_menu":4,"count":1}]	754	pick-up	0	17
75661	2020-06-09 12:54:46	2020-06-09	8	[{"id_menu":5,"count":2}]	25280	delivery	5	13
75662	2020-06-09 12:55:23	2020-06-09	9	[{"id_menu":6,"count":1}]	26785	delivery	5	14
75663	2020-06-09 12:58:22	2020-06-09	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5112	pick-up	0	26
75664	2020-06-09 13:02:27	2020-06-09	9	[{"id_menu":6,"count":1}]	18598	delivery	5	14
75665	2020-06-09 13:02:54	2020-06-09	12	[{"id_menu":1,"count":1}]	5910	delivery	5	17
75666	2020-06-09 13:06:07	2020-06-09	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4459	delivery	5	27
75667	2020-06-09 13:10:52	2020-06-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9614	delivery	5	22
75668	2020-06-09 13:12:02	2020-06-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1299	delivery	5	22
75669	2020-06-09 13:13:41	2020-06-09	9	[{"id_menu":7,"count":1}]	15448	delivery	5	14
75670	2020-06-09 13:17:09	2020-06-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6883	delivery	5	28
75671	2020-06-09 13:17:21	2020-06-09	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	7102	delivery	5	26
75672	2020-06-09 13:19:17	2020-06-09	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7751	delivery	5	31
75673	2020-06-09 13:22:07	2020-06-09	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	29897	delivery	5	43
75674	2020-06-09 13:31:25	2020-06-09	12	[{"id_menu":3,"count":1}]	29823	pick-up	0	12
75675	2020-06-09 13:33:32	2020-06-09	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	14081	pick-up	0	21
75676	2020-06-09 13:34:20	2020-06-09	9	[{"id_menu":6,"count":1}]	29458	pick-up	0	9
75677	2020-06-09 13:34:25	2020-06-09	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29867	delivery	5	54
75678	2020-06-09 13:35:22	2020-06-09	12	[{"id_menu":3,"count":1}]	29896	delivery	5	17
75679	2020-06-09 13:36:02	2020-06-09	9	[{"id_menu":7,"count":1}]	29828	delivery	5	14
75680	2020-06-09 13:37:12	2020-06-09	9	[{"id_menu":6,"count":1}]	1581	pick-up	0	9
75681	2020-06-09 13:40:47	2020-06-09	9	[{"id_menu":6,"count":1}]	25115	delivery	5	14
75682	2020-06-09 13:41:41	2020-06-09	9	[{"id_menu":7,"count":1}]	29855	pick-up	0	9
75683	2020-06-09 13:42:41	2020-06-09	12	[{"id_menu":1,"count":1}]	27710	delivery	5	17
75684	2020-06-09 13:42:58	2020-06-09	14	[{"id_menu":2,"count":1}]	8604	delivery	5	19
75685	2020-06-09 13:44:27	2020-06-09	12	[{"id_menu":1,"count":1}]	26974	pick-up	0	12
75686	2020-06-09 13:44:48	2020-06-09	9	[{"id_menu":6,"count":3}]	29894	delivery	5	14
75687	2020-06-09 13:47:30	2020-06-09	12	[{"id_menu":1,"count":1}]	1344	delivery	5	17
75688	2020-06-09 13:51:29	2020-06-09	9	[{"id_menu":7,"count":2}]	29852	pick-up	0	9
75689	2020-06-09 14:01:44	2020-06-09	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12031	delivery	5	57
75690	2020-06-09 14:07:43	2020-06-09	9	[{"id_menu":7,"count":1}]	11334	pick-up	0	9
75691	2020-06-09 14:09:28	2020-06-09	30	[{"id_menu":1,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21779	delivery	5	35
75692	2020-06-09 14:19:23	2020-06-09	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	29756	delivery	5	26
75693	2020-06-09 14:21:13	2020-06-09	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2964	delivery	5	48
75694	2020-06-09 14:22:58	2020-06-09	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	8177	delivery	5	40
75695	2020-06-09 14:24:44	2020-06-09	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	24534	pick-up	0	40
75696	2020-06-09 14:30:10	2020-06-09	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	11223	pick-up	0	29
75697	2020-06-09 14:40:52	2020-06-09	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	628	delivery	5	34
75698	2020-06-09 14:43:57	2020-06-09	9	[{"id_menu":7,"count":1}]	22182	delivery	5	14
75699	2020-06-09 14:45:48	2020-06-09	14	[{"id_menu":2,"count":1}]	29869	delivery	5	19
75700	2020-06-09 14:47:46	2020-06-09	9	[{"id_menu":6,"count":2}]	15566	pick-up	0	9
75701	2020-06-09 14:48:25	2020-06-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28773	delivery	5	23
75702	2020-06-09 14:49:18	2020-06-09	12	[{"id_menu":3,"count":1}]	14558	pick-up	0	12
75703	2020-06-09 14:49:37	2020-06-09	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3654	delivery	5	35
75704	2020-06-09 15:00:46	2020-06-09	9	[{"id_menu":6,"count":1}]	6097	delivery	5	14
75705	2020-06-09 15:05:37	2020-06-09	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3069	pick-up	0	26
75706	2020-06-09 15:07:03	2020-06-09	12	[{"id_menu":3,"count":1}]	13484	delivery	5	17
75707	2020-06-09 15:09:39	2020-06-09	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20739	delivery	5	31
75708	2020-06-09 15:14:59	2020-06-09	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	29837	delivery	5	28
75709	2020-06-09 15:18:26	2020-06-09	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19052	pick-up	0	29
75710	2020-06-09 15:23:34	2020-06-09	8	[{"id_menu":5,"count":1}]	29898	delivery	5	13
75711	2020-06-09 15:25:18	2020-06-09	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3711	pick-up	0	22
75712	2020-06-09 15:25:50	2020-06-09	17	[{"id_menu":4,"count":1}]	28035	delivery	5	22
75713	2020-06-09 15:28:16	2020-06-09	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	20205	delivery	5	57
75714	2020-06-09 15:28:17	2020-06-09	17	[{"id_menu":4,"count":1}]	13951	pick-up	0	17
75715	2020-06-09 15:28:35	2020-06-09	9	[{"id_menu":7,"count":1}]	5991	delivery	5	14
75716	2020-06-09 15:29:54	2020-06-09	17	[{"id_menu":4,"count":1}]	367	delivery	5	22
75717	2020-06-09 15:32:38	2020-06-09	12	[{"id_menu":1,"count":1}]	24630	delivery	5	17
75718	2020-06-09 15:33:42	2020-06-09	12	[{"id_menu":3,"count":1}]	19559	delivery	5	17
75719	2020-06-09 15:37:26	2020-06-09	14	[{"id_menu":2,"count":1}]	29854	delivery	5	19
75720	2020-06-09 15:38:50	2020-06-09	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	24449	delivery	5	43
75721	2020-06-09 15:47:43	2020-06-09	9	[{"id_menu":7,"count":2}]	29776	delivery	5	14
75722	2020-06-09 15:48:02	2020-06-09	9	[{"id_menu":7,"count":2}]	29923	delivery	5	14
75723	2020-06-09 15:48:18	2020-06-09	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	29809	delivery	5	26
75724	2020-06-09 15:48:20	2020-06-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20423	delivery	5	23
75725	2020-06-09 15:54:49	2020-06-09	9	[{"id_menu":6,"count":1}]	14734	pick-up	0	9
75726	2020-06-09 15:55:17	2020-06-09	12	[{"id_menu":1,"count":3}]	26416	delivery	5	17
75727	2020-06-09 15:56:12	2020-06-09	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29810	delivery	5	51
75728	2020-06-09 16:01:52	2020-06-09	12	[{"id_menu":1,"count":1}]	4914	pick-up	0	12
75729	2020-06-09 16:06:30	2020-06-09	17	[{"id_menu":4,"count":1}]	26093	delivery	5	22
75730	2020-06-09 16:15:29	2020-06-09	12	[{"id_menu":1,"count":1}]	1568	pick-up	0	12
75731	2020-06-09 16:21:15	2020-06-09	9	[{"id_menu":7,"count":1}]	8546	pick-up	0	9
75732	2020-06-09 16:22:33	2020-06-09	14	[{"id_menu":2,"count":1}]	29788	delivery	5	19
75733	2020-06-09 16:25:35	2020-06-09	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	29811	delivery	5	29
75734	2020-06-09 16:28:43	2020-06-09	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3883	delivery	5	34
75735	2020-06-09 16:32:15	2020-06-09	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	13213	pick-up	0	26
75736	2020-06-09 16:40:24	2020-06-09	9	[{"id_menu":7,"count":1}]	4116	delivery	5	14
75737	2020-06-09 16:51:33	2020-06-09	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	18758	pick-up	0	26
75738	2020-06-09 16:52:10	2020-06-09	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6847	delivery	5	31
75739	2020-06-09 16:54:47	2020-06-09	12	[{"id_menu":1,"count":1}]	14578	delivery	5	17
75740	2020-06-09 16:58:16	2020-06-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18194	delivery	5	22
75741	2020-06-09 16:59:02	2020-06-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	29841	delivery	5	28
75742	2020-06-09 17:01:17	2020-06-09	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29908	delivery	5	34
75743	2020-06-09 17:02:27	2020-06-09	12	[{"id_menu":1,"count":2}]	18320	delivery	5	17
75744	2020-06-09 17:05:20	2020-06-09	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	22784	delivery	5	31
75745	2020-06-09 17:09:52	2020-06-09	14	[{"id_menu":2,"count":1}]	29761	delivery	5	19
75746	2020-06-09 17:21:59	2020-06-09	17	[{"id_menu":4,"count":1}]	29752	delivery	5	22
75747	2020-06-09 17:24:48	2020-06-09	12	[{"id_menu":1,"count":1}]	11644	pick-up	0	12
75748	2020-06-09 17:25:28	2020-06-09	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	28293	delivery	5	40
75749	2020-06-09 17:27:04	2020-06-09	14	[{"id_menu":2,"count":1}]	29007	delivery	5	19
75750	2020-06-09 17:31:20	2020-06-09	8	[{"id_menu":5,"count":1}]	29747	delivery	5	13
75751	2020-06-09 17:31:45	2020-06-09	9	[{"id_menu":6,"count":1}]	8657	pick-up	0	9
75752	2020-06-09 17:31:50	2020-06-09	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	29757	delivery	5	34
75753	2020-06-09 17:33:41	2020-06-09	12	[{"id_menu":1,"count":1}]	15292	delivery	5	17
75754	2020-06-09 17:34:48	2020-06-09	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	29911	delivery	5	36
75755	2020-06-09 17:37:42	2020-06-09	14	[{"id_menu":2,"count":1}]	29882	delivery	5	19
75756	2020-06-09 17:45:31	2020-06-09	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3117	delivery	5	30
75757	2020-06-09 17:50:47	2020-06-09	14	[{"id_menu":2,"count":1}]	29796	delivery	5	19
75758	2020-06-09 17:54:15	2020-06-09	12	[{"id_menu":3,"count":1}]	29819	delivery	5	17
75759	2020-06-09 17:55:47	2020-06-09	17	[{"id_menu":4,"count":1}]	26024	delivery	5	22
75760	2020-06-09 17:57:16	2020-06-09	9	[{"id_menu":7,"count":1}]	29807	delivery	5	14
75761	2020-06-09 18:02:52	2020-06-09	14	[{"id_menu":2,"count":1}]	3812	pick-up	0	14
75762	2020-06-09 18:03:39	2020-06-09	9	[{"id_menu":7,"count":1}]	20723	delivery	5	14
75763	2020-06-09 18:12:24	2020-06-09	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	9347	delivery	5	36
75764	2020-06-09 18:22:54	2020-06-09	9	[{"id_menu":6,"count":2}]	3802	pick-up	0	9
75765	2020-06-09 18:23:46	2020-06-09	14	[{"id_menu":2,"count":1}]	25792	delivery	5	19
75766	2020-06-09 18:26:37	2020-06-09	12	[{"id_menu":1,"count":1}]	17744	delivery	5	17
75767	2020-06-09 18:34:40	2020-06-09	14	[{"id_menu":2,"count":1}]	16330	pick-up	0	14
75768	2020-06-09 18:37:08	2020-06-09	8	[{"id_menu":5,"count":2}]	20379	pick-up	0	8
75769	2020-06-09 18:41:20	2020-06-09	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12287	delivery	5	31
75770	2020-06-09 18:46:12	2020-06-09	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	29770	delivery	5	26
75771	2020-06-09 18:47:48	2020-06-09	14	[{"id_menu":2,"count":1}]	29750	delivery	5	19
75772	2020-06-09 18:57:52	2020-06-09	8	[{"id_menu":5,"count":1}]	23721	delivery	5	13
75773	2020-06-09 19:02:02	2020-06-09	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4152	delivery	5	40
75774	2020-06-09 19:02:05	2020-06-09	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	29904	delivery	5	34
75775	2020-06-09 19:04:50	2020-06-09	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	15602	delivery	5	31
75776	2020-06-09 19:06:27	2020-06-09	14	[{"id_menu":2,"count":2}]	6687	pick-up	0	14
75777	2020-06-09 19:07:32	2020-06-09	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	8214	delivery	5	48
75778	2020-06-09 19:09:31	2020-06-09	17	[{"id_menu":4,"count":1}]	10281	pick-up	0	17
75779	2020-06-09 19:13:39	2020-06-09	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	26206	delivery	5	40
75780	2020-06-09 19:16:04	2020-06-09	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	1040	pick-up	0	31
75781	2020-06-09 19:18:09	2020-06-09	9	[{"id_menu":6,"count":1}]	21867	delivery	5	14
75782	2020-06-09 19:18:11	2020-06-09	12	[{"id_menu":3,"count":1}]	29918	pick-up	0	12
75783	2020-06-09 19:21:21	2020-06-09	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8492	delivery	5	36
75784	2020-06-09 19:24:16	2020-06-09	17	[{"id_menu":4,"count":1}]	15833	delivery	5	22
75785	2020-06-09 19:24:51	2020-06-09	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	10676	delivery	5	36
75786	2020-06-09 19:26:43	2020-06-09	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	14207	delivery	5	37
75787	2020-06-09 19:27:17	2020-06-09	17	[{"id_menu":4,"count":1}]	136	pick-up	0	17
75788	2020-06-09 19:32:19	2020-06-09	8	[{"id_menu":5,"count":3}]	15007	delivery	5	13
75789	2020-06-09 19:44:05	2020-06-09	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	29889	delivery	5	30
75790	2020-06-09 19:46:35	2020-06-09	14	[{"id_menu":2,"count":1}]	5223	pick-up	0	14
75791	2020-06-09 19:55:11	2020-06-09	12	[{"id_menu":3,"count":1}]	10971	pick-up	0	12
75792	2020-06-09 19:59:25	2020-06-09	12	[{"id_menu":1,"count":1}]	29870	pick-up	0	12
75793	2020-06-09 20:15:53	2020-06-09	8	[{"id_menu":5,"count":1}]	29926	delivery	5	13
75794	2020-06-09 20:17:38	2020-06-09	9	[{"id_menu":7,"count":1}]	29787	delivery	5	14
75795	2020-06-09 20:24:25	2020-06-09	17	[{"id_menu":4,"count":1}]	1819	pick-up	0	17
75796	2020-06-09 20:24:31	2020-06-09	8	[{"id_menu":5,"count":1}]	29817	delivery	5	13
75797	2020-06-09 20:34:24	2020-06-09	9	[{"id_menu":7,"count":1}]	6589	pick-up	0	9
75798	2020-06-09 20:34:57	2020-06-09	8	[{"id_menu":5,"count":1}]	29834	delivery	5	13
75799	2020-06-09 20:42:07	2020-06-09	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	16371	delivery	5	31
75800	2020-06-09 20:43:07	2020-06-09	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	29927	delivery	5	26
75801	2020-06-09 20:43:18	2020-06-09	12	[{"id_menu":3,"count":1}]	14022	delivery	5	17
75802	2020-06-09 20:47:46	2020-06-09	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	29791	delivery	5	40
75803	2020-06-09 20:50:12	2020-06-09	9	[{"id_menu":6,"count":1}]	3447	delivery	5	14
75804	2020-06-09 20:52:08	2020-06-09	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	6655	delivery	5	27
75805	2020-06-09 20:53:34	2020-06-09	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22755	delivery	5	22
75806	2020-06-09 20:57:36	2020-06-09	14	[{"id_menu":2,"count":1}]	2164	delivery	5	19
75807	2020-06-09 21:00:44	2020-06-09	17	[{"id_menu":4,"count":1}]	16109	delivery	5	22
75808	2020-06-09 21:01:07	2020-06-09	12	[{"id_menu":1,"count":1}]	14519	pick-up	0	12
75809	2020-06-09 21:01:09	2020-06-09	9	[{"id_menu":7,"count":1}]	11137	delivery	5	14
75810	2020-06-09 21:02:43	2020-06-09	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	29888	delivery	5	31
75811	2020-06-09 21:08:53	2020-06-09	14	[{"id_menu":2,"count":1}]	14455	pick-up	0	14
75812	2020-06-09 21:12:22	2020-06-09	14	[{"id_menu":2,"count":1}]	18161	delivery	5	19
75813	2020-06-09 21:13:18	2020-06-09	17	[{"id_menu":4,"count":1}]	9106	pick-up	0	17
75814	2020-06-09 21:15:35	2020-06-09	12	[{"id_menu":3,"count":1}]	29812	delivery	5	17
75815	2020-06-09 21:18:47	2020-06-09	9	[{"id_menu":6,"count":1}]	7693	delivery	5	14
75816	2020-06-09 21:23:59	2020-06-09	9	[{"id_menu":7,"count":1}]	5729	pick-up	0	9
75817	2020-06-09 21:24:47	2020-06-09	12	[{"id_menu":1,"count":1}]	8976	delivery	5	17
75818	2020-06-09 21:25:32	2020-06-09	9	[{"id_menu":7,"count":1}]	25297	delivery	5	14
75819	2020-06-09 21:27:22	2020-06-09	9	[{"id_menu":6,"count":1}]	29843	delivery	5	14
75820	2020-06-09 21:33:39	2020-06-09	9	[{"id_menu":6,"count":1}]	1369	delivery	5	14
75821	2020-06-09 21:33:43	2020-06-09	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	12912	pick-up	0	38
75822	2020-06-09 21:35:39	2020-06-09	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	9383	delivery	5	36
75823	2020-06-09 21:43:21	2020-06-09	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	29903	delivery	5	31
75824	2020-06-09 21:46:01	2020-06-09	9	[{"id_menu":7,"count":1}]	10442	delivery	5	14
75825	2020-06-09 21:47:55	2020-06-09	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6382	delivery	5	43
75826	2020-06-09 21:48:45	2020-06-09	9	[{"id_menu":6,"count":1}]	6168	delivery	5	14
75827	2020-06-09 21:53:36	2020-06-09	9	[{"id_menu":7,"count":1}]	19215	delivery	5	14
75828	2020-06-09 21:58:22	2020-06-09	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18754	delivery	5	48
75829	2020-06-09 22:00:07	2020-06-09	17	[{"id_menu":4,"count":1}]	21420	delivery	5	22
75830	2020-06-09 22:07:23	2020-06-09	12	[{"id_menu":3,"count":1}]	29790	delivery	5	17
75831	2020-06-09 22:14:34	2020-06-09	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	11559	delivery	5	40
75832	2020-06-09 22:15:14	2020-06-09	9	[{"id_menu":7,"count":1}]	1398	pick-up	0	9
75833	2020-06-09 22:17:49	2020-06-09	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	29803	delivery	5	23
75834	2020-06-09 22:20:12	2020-06-09	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	29838	delivery	5	25
75835	2020-06-09 22:25:47	2020-06-09	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	29785	delivery	5	26
75836	2020-06-09 22:29:29	2020-06-09	17	[{"id_menu":4,"count":1}]	23203	delivery	5	22
75837	2020-06-09 22:31:25	2020-06-09	14	[{"id_menu":2,"count":1}]	13012	delivery	5	19
75838	2020-06-09 22:32:23	2020-06-09	17	[{"id_menu":4,"count":1}]	11083	pick-up	0	17
75839	2020-06-09 22:35:19	2020-06-09	12	[{"id_menu":1,"count":1}]	2291	pick-up	0	12
75840	2020-06-09 22:37:55	2020-06-09	12	[{"id_menu":3,"count":1}]	23669	delivery	5	17
75841	2020-06-09 22:39:04	2020-06-09	12	[{"id_menu":1,"count":1}]	29839	delivery	5	17
75842	2020-06-09 22:45:31	2020-06-09	14	[{"id_menu":2,"count":1}]	29766	pick-up	0	14
75843	2020-06-09 22:53:32	2020-06-09	9	[{"id_menu":6,"count":1}]	28136	delivery	5	14
75844	2020-06-09 22:55:23	2020-06-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	21432	delivery	5	28
75845	2020-06-09 22:56:50	2020-06-09	17	[{"id_menu":4,"count":1}]	22362	delivery	5	22
75846	2020-06-09 22:57:52	2020-06-09	9	[{"id_menu":7,"count":1}]	26290	delivery	5	14
75847	2020-06-09 22:58:12	2020-06-09	8	[{"id_menu":5,"count":1}]	27785	delivery	5	13
75848	2020-06-09 22:58:21	2020-06-09	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	29748	delivery	5	39
75849	2020-06-09 23:03:43	2020-06-09	14	[{"id_menu":2,"count":1}]	19211	delivery	5	19
75850	2020-06-09 23:04:15	2020-06-09	8	[{"id_menu":5,"count":1}]	1373	delivery	5	13
75851	2020-06-09 23:13:12	2020-06-09	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	29229	delivery	5	31
75852	2020-06-09 23:13:19	2020-06-09	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	4772	delivery	5	52
75853	2020-06-09 23:16:56	2020-06-09	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	832	pick-up	0	21
75854	2020-06-09 23:17:57	2020-06-09	12	[{"id_menu":3,"count":1}]	23301	delivery	5	17
75855	2020-06-09 23:20:27	2020-06-09	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	27938	delivery	5	48
75856	2020-06-09 23:21:18	2020-06-09	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	29831	delivery	5	36
75857	2020-06-09 23:22:05	2020-06-09	12	[{"id_menu":1,"count":1}]	13851	pick-up	0	12
75858	2020-06-09 23:37:37	2020-06-09	17	[{"id_menu":4,"count":1}]	1076	pick-up	0	17
75859	2020-06-09 23:42:02	2020-06-09	9	[{"id_menu":7,"count":1}]	2232	pick-up	0	9
75860	2020-06-09 23:43:34	2020-06-09	8	[{"id_menu":5,"count":1}]	4505	delivery	5	13
75861	2020-06-09 23:46:33	2020-06-09	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	9182	delivery	5	22
75862	2020-06-09 23:55:04	2020-06-09	8	[{"id_menu":5,"count":1}]	29919	delivery	5	13
75863	2020-06-09 23:56:07	2020-06-09	8	[{"id_menu":5,"count":1}]	29872	delivery	5	13
75864	2020-06-09 23:59:04	2020-06-09	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6518	delivery	5	48
75865	2020-06-10 00:05:08	2020-06-10	8	[{"id_menu":5,"count":1}]	7407	pick-up	0	8
75866	2020-06-10 00:05:17	2020-06-10	9	[{"id_menu":6,"count":1}]	7766	delivery	5	14
75867	2020-06-10 00:12:49	2020-06-10	8	[{"id_menu":5,"count":1}]	10876	delivery	5	13
75868	2020-06-10 00:14:58	2020-06-10	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29702	pick-up	0	17
75869	2020-06-10 00:18:14	2020-06-10	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	16501	pick-up	0	40
75870	2020-06-10 00:20:44	2020-06-10	9	[{"id_menu":7,"count":1}]	26653	delivery	5	14
75871	2020-06-10 00:26:04	2020-06-10	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	16678	pick-up	0	22
75872	2020-06-10 00:26:39	2020-06-10	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	3320	pick-up	0	21
75873	2020-06-10 00:27:56	2020-06-10	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	30058	delivery	5	36
75874	2020-06-10 00:29:11	2020-06-10	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3940	pick-up	0	38
75875	2020-06-10 00:35:00	2020-06-10	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	12064	delivery	5	36
75876	2020-06-10 00:35:33	2020-06-10	9	[{"id_menu":7,"count":1}]	21363	delivery	5	14
75877	2020-06-10 00:38:34	2020-06-10	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	30079	delivery	5	44
75878	2020-06-10 00:43:57	2020-06-10	9	[{"id_menu":7,"count":1}]	12183	delivery	5	14
75879	2020-06-10 00:44:34	2020-06-10	9	[{"id_menu":7,"count":1}]	14403	delivery	5	14
75880	2020-06-10 00:45:41	2020-06-10	8	[{"id_menu":5,"count":1}]	17193	delivery	5	13
75881	2020-06-10 00:47:21	2020-06-10	46	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	29970	delivery	5	51
75882	2020-06-10 00:53:54	2020-06-10	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	30118	delivery	5	31
75883	2020-06-10 00:55:43	2020-06-10	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	30024	delivery	5	22
75884	2020-06-10 00:55:43	2020-06-10	8	[{"id_menu":5,"count":2}]	12473	delivery	5	13
75885	2020-06-10 00:56:05	2020-06-10	14	[{"id_menu":2,"count":3}]	26386	delivery	5	19
75886	2020-06-10 00:57:09	2020-06-10	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	20987	delivery	5	27
75887	2020-06-10 00:58:51	2020-06-10	17	[{"id_menu":4,"count":1}]	18810	delivery	5	22
75888	2020-06-10 01:00:44	2020-06-10	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	16330	delivery	5	28
75889	2020-06-10 01:09:26	2020-06-10	17	[{"id_menu":4,"count":1}]	24547	pick-up	0	17
75890	2020-06-10 01:11:21	2020-06-10	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	11183	pick-up	0	26
75891	2020-06-10 01:14:47	2020-06-10	17	[{"id_menu":4,"count":1}]	17441	delivery	5	22
75892	2020-06-10 01:14:52	2020-06-10	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29997	delivery	5	49
75893	2020-06-10 01:16:52	2020-06-10	12	[{"id_menu":3,"count":1}]	15470	delivery	5	17
75894	2020-06-10 01:17:25	2020-06-10	8	[{"id_menu":5,"count":1}]	30103	delivery	5	13
75895	2020-06-10 01:22:01	2020-06-10	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26698	delivery	5	37
75896	2020-06-10 01:25:45	2020-06-10	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	28283	delivery	5	36
75897	2020-06-10 01:32:57	2020-06-10	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	29975	delivery	5	26
75898	2020-06-10 01:34:03	2020-06-10	9	[{"id_menu":7,"count":1}]	4648	pick-up	0	9
75899	2020-06-10 01:35:26	2020-06-10	14	[{"id_menu":2,"count":1}]	2000	pick-up	0	14
75900	2020-06-10 01:37:11	2020-06-10	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1406	pick-up	0	26
75901	2020-06-10 01:37:21	2020-06-10	9	[{"id_menu":6,"count":1}]	16592	pick-up	0	9
75902	2020-06-10 01:41:25	2020-06-10	9	[{"id_menu":7,"count":1}]	29979	delivery	5	14
75903	2020-06-10 01:46:19	2020-06-10	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2602	delivery	5	26
75904	2020-06-10 01:47:15	2020-06-10	17	[{"id_menu":4,"count":1}]	25930	delivery	5	22
75905	2020-06-10 01:50:22	2020-06-10	9	[{"id_menu":6,"count":1}]	20237	delivery	5	14
75906	2020-06-10 01:50:36	2020-06-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29966	delivery	5	23
75907	2020-06-10 01:54:29	2020-06-10	17	[{"id_menu":4,"count":1}]	30040	pick-up	0	17
75908	2020-06-10 01:57:31	2020-06-10	17	[{"id_menu":4,"count":1}]	10273	delivery	5	22
75909	2020-06-10 01:58:20	2020-06-10	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	30067	delivery	5	34
75910	2020-06-10 02:00:59	2020-06-10	8	[{"id_menu":5,"count":1}]	22584	delivery	5	13
75911	2020-06-10 02:03:53	2020-06-10	14	[{"id_menu":2,"count":1}]	30070	delivery	5	19
75912	2020-06-10 02:10:09	2020-06-10	9	[{"id_menu":7,"count":1}]	29984	delivery	5	14
75913	2020-06-10 02:11:29	2020-06-10	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	30109	delivery	5	43
75914	2020-06-10 02:18:07	2020-06-10	12	[{"id_menu":1,"count":1}]	15385	delivery	5	17
75915	2020-06-10 02:26:51	2020-06-10	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	10442	delivery	5	25
75916	2020-06-10 02:28:24	2020-06-10	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7211	delivery	5	40
75917	2020-06-10 02:35:01	2020-06-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	17673	delivery	5	22
75918	2020-06-10 02:38:39	2020-06-10	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	27685	pick-up	0	31
75919	2020-06-10 02:41:03	2020-06-10	9	[{"id_menu":6,"count":1}]	29956	delivery	5	14
75920	2020-06-10 02:44:58	2020-06-10	9	[{"id_menu":6,"count":1}]	30108	pick-up	0	9
75921	2020-06-10 02:47:25	2020-06-10	9	[{"id_menu":6,"count":1}]	6000	delivery	5	14
75922	2020-06-10 02:47:45	2020-06-10	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	4100	delivery	5	23
75923	2020-06-10 02:49:05	2020-06-10	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	17700	pick-up	0	29
75924	2020-06-10 02:52:10	2020-06-10	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	30094	delivery	5	22
75925	2020-06-10 02:57:50	2020-06-10	9	[{"id_menu":7,"count":1}]	20119	delivery	5	14
75926	2020-06-10 02:58:35	2020-06-10	9	[{"id_menu":7,"count":1}]	4824	delivery	5	14
75927	2020-06-10 02:58:39	2020-06-10	12	[{"id_menu":1,"count":1}]	30014	delivery	5	17
75928	2020-06-10 02:59:27	2020-06-10	14	[{"id_menu":2,"count":1}]	29948	delivery	5	19
75929	2020-06-10 03:00:07	2020-06-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7387	delivery	5	22
75930	2020-06-10 03:00:19	2020-06-10	14	[{"id_menu":2,"count":2}]	18976	delivery	5	19
75931	2020-06-10 03:00:55	2020-06-10	9	[{"id_menu":7,"count":1}]	4957	delivery	5	14
75932	2020-06-10 03:05:31	2020-06-10	12	[{"id_menu":3,"count":1}]	29968	delivery	5	17
75933	2020-06-10 03:07:50	2020-06-10	14	[{"id_menu":2,"count":1}]	30113	delivery	5	19
75934	2020-06-10 03:10:26	2020-06-10	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	25348	delivery	5	42
75935	2020-06-10 03:13:47	2020-06-10	9	[{"id_menu":7,"count":1}]	1776	delivery	5	14
75936	2020-06-10 03:18:14	2020-06-10	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	25189	delivery	5	31
75937	2020-06-10 03:19:19	2020-06-10	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	7688	delivery	5	25
75938	2020-06-10 03:21:08	2020-06-10	14	[{"id_menu":2,"count":1}]	18222	delivery	5	19
75939	2020-06-10 03:23:13	2020-06-10	9	[{"id_menu":6,"count":1}]	274	pick-up	0	9
75940	2020-06-10 03:24:13	2020-06-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5056	delivery	5	22
75941	2020-06-10 03:26:13	2020-06-10	14	[{"id_menu":2,"count":1}]	9167	delivery	5	19
75942	2020-06-10 03:28:56	2020-06-10	8	[{"id_menu":5,"count":2}]	8230	delivery	5	13
75943	2020-06-10 03:33:33	2020-06-10	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	30029	delivery	5	43
75944	2020-06-10 03:37:52	2020-06-10	17	[{"id_menu":4,"count":1}]	26739	delivery	5	22
75945	2020-06-10 03:38:01	2020-06-10	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	26945	delivery	5	39
75946	2020-06-10 03:44:21	2020-06-10	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6399	pick-up	0	26
75947	2020-06-10 03:48:08	2020-06-10	14	[{"id_menu":2,"count":1}]	29993	pick-up	0	14
75948	2020-06-10 03:50:51	2020-06-10	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12308	delivery	5	52
75949	2020-06-10 03:52:27	2020-06-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	30018	delivery	5	23
75950	2020-06-10 03:53:17	2020-06-10	8	[{"id_menu":5,"count":1}]	21476	delivery	5	13
75951	2020-06-10 03:53:21	2020-06-10	9	[{"id_menu":6,"count":1}]	14068	delivery	5	14
75952	2020-06-10 03:54:53	2020-06-10	9	[{"id_menu":6,"count":1}]	29976	delivery	5	14
75953	2020-06-10 03:55:53	2020-06-10	17	[{"id_menu":4,"count":1}]	14306	delivery	5	22
75954	2020-06-10 03:57:12	2020-06-10	9	[{"id_menu":6,"count":1}]	29957	delivery	5	14
75955	2020-06-10 04:04:44	2020-06-10	8	[{"id_menu":5,"count":1}]	30111	delivery	5	13
75956	2020-06-10 04:05:01	2020-06-10	12	[{"id_menu":1,"count":1}]	30042	delivery	5	17
75957	2020-06-10 04:08:09	2020-06-10	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	21980	pick-up	0	31
75958	2020-06-10 04:08:23	2020-06-10	12	[{"id_menu":1,"count":1}]	17040	delivery	5	17
75959	2020-06-10 04:11:39	2020-06-10	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	30012	delivery	5	43
75960	2020-06-10 04:11:53	2020-06-10	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	23788	delivery	5	31
75961	2020-06-10 04:13:52	2020-06-10	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30115	delivery	5	35
75962	2020-06-10 04:14:34	2020-06-10	12	[{"id_menu":1,"count":1}]	29974	pick-up	0	12
75963	2020-06-10 04:16:12	2020-06-10	9	[{"id_menu":6,"count":1}]	30023	delivery	5	14
75964	2020-06-10 04:22:07	2020-06-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	16680	delivery	5	28
75965	2020-06-10 04:26:34	2020-06-10	9	[{"id_menu":6,"count":1}]	24792	delivery	5	14
75966	2020-06-10 04:40:20	2020-06-10	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	30105	pick-up	0	26
75967	2020-06-10 04:42:01	2020-06-10	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	16850	delivery	5	36
75968	2020-06-10 04:44:46	2020-06-10	17	[{"id_menu":4,"count":1}]	1681	delivery	5	22
75969	2020-06-10 04:45:41	2020-06-10	17	[{"id_menu":4,"count":1}]	7433	pick-up	0	17
75970	2020-06-10 04:46:03	2020-06-10	8	[{"id_menu":5,"count":1}]	28391	delivery	5	13
75971	2020-06-10 04:59:30	2020-06-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15735	delivery	5	23
75972	2020-06-10 05:00:51	2020-06-10	14	[{"id_menu":2,"count":1}]	18970	delivery	5	19
75973	2020-06-10 05:03:09	2020-06-10	17	[{"id_menu":4,"count":1}]	1760	pick-up	0	17
75974	2020-06-10 05:03:11	2020-06-10	14	[{"id_menu":2,"count":1}]	3848	delivery	5	19
75975	2020-06-10 05:11:19	2020-06-10	17	[{"id_menu":4,"count":1}]	3113	delivery	5	22
75976	2020-06-10 05:14:13	2020-06-10	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	30107	delivery	5	34
75977	2020-06-10 05:19:16	2020-06-10	8	[{"id_menu":5,"count":1}]	20391	delivery	5	13
75978	2020-06-10 05:19:46	2020-06-10	14	[{"id_menu":2,"count":1}]	6249	delivery	5	19
75979	2020-06-10 05:21:04	2020-06-10	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	802	delivery	5	49
75980	2020-06-10 05:23:26	2020-06-10	9	[{"id_menu":6,"count":1}]	623	pick-up	0	9
75981	2020-06-10 05:24:33	2020-06-10	17	[{"id_menu":4,"count":1}]	2442	pick-up	0	17
75982	2020-06-10 05:30:38	2020-06-10	8	[{"id_menu":5,"count":1}]	25815	delivery	5	13
75983	2020-06-10 05:34:10	2020-06-10	8	[{"id_menu":5,"count":1}]	11478	delivery	5	13
75984	2020-06-10 05:36:46	2020-06-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13569	delivery	5	23
75985	2020-06-10 05:40:15	2020-06-10	14	[{"id_menu":2,"count":1}]	30031	delivery	5	19
75986	2020-06-10 05:47:15	2020-06-10	14	[{"id_menu":2,"count":1}]	23749	delivery	5	19
75987	2020-06-10 05:50:15	2020-06-10	17	[{"id_menu":4,"count":1}]	29395	delivery	5	22
75988	2020-06-10 05:53:15	2020-06-10	12	[{"id_menu":1,"count":1}]	24594	delivery	5	17
75989	2020-06-10 05:54:25	2020-06-10	8	[{"id_menu":5,"count":1}]	3477	delivery	5	13
75990	2020-06-10 05:55:21	2020-06-10	9	[{"id_menu":6,"count":1}]	17574	pick-up	0	9
75991	2020-06-10 05:57:42	2020-06-10	14	[{"id_menu":2,"count":1}]	5169	delivery	5	19
75992	2020-06-10 05:57:54	2020-06-10	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2838	pick-up	0	21
75993	2020-06-10 06:12:50	2020-06-10	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	4356	pick-up	0	20
75994	2020-06-10 06:13:04	2020-06-10	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	24578	delivery	5	30
75995	2020-06-10 06:14:08	2020-06-10	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	30047	delivery	5	27
75996	2020-06-10 06:14:12	2020-06-10	12	[{"id_menu":3,"count":1}]	29945	delivery	5	17
75997	2020-06-10 06:15:09	2020-06-10	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24536	delivery	5	43
75998	2020-06-10 06:16:43	2020-06-10	14	[{"id_menu":2,"count":1}]	5846	delivery	5	19
75999	2020-06-10 06:19:01	2020-06-10	12	[{"id_menu":3,"count":1}]	17056	delivery	5	17
76000	2020-06-10 06:22:25	2020-06-10	17	[{"id_menu":4,"count":1}]	1687	delivery	5	22
76001	2020-06-10 06:23:21	2020-06-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	30075	delivery	5	28
76002	2020-06-10 06:27:01	2020-06-10	12	[{"id_menu":3,"count":1}]	8289	delivery	5	17
76003	2020-06-10 06:29:58	2020-06-10	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	583	delivery	5	26
76004	2020-06-10 06:32:30	2020-06-10	8	[{"id_menu":5,"count":1}]	29973	delivery	5	13
76005	2020-06-10 06:33:55	2020-06-10	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	30087	delivery	5	34
76006	2020-06-10 06:35:42	2020-06-10	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3306	delivery	5	39
76007	2020-06-10 06:41:42	2020-06-10	9	[{"id_menu":7,"count":2}]	2018	delivery	5	14
76008	2020-06-10 06:49:38	2020-06-10	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	29939	delivery	5	26
76009	2020-06-10 06:51:53	2020-06-10	14	[{"id_menu":2,"count":1}]	30059	delivery	5	19
76010	2020-06-10 06:54:37	2020-06-10	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	24048	delivery	5	31
76011	2020-06-10 06:54:43	2020-06-10	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3536	delivery	5	57
76012	2020-06-10 06:55:00	2020-06-10	9	[{"id_menu":6,"count":1}]	23461	pick-up	0	9
76013	2020-06-10 06:55:13	2020-06-10	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19423	delivery	5	34
76014	2020-06-10 06:56:42	2020-06-10	9	[{"id_menu":6,"count":1}]	30114	delivery	5	14
76015	2020-06-10 06:59:53	2020-06-10	9	[{"id_menu":6,"count":1}]	11552	delivery	5	14
76016	2020-06-10 07:01:39	2020-06-10	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	11818	delivery	5	34
76017	2020-06-10 07:02:08	2020-06-10	9	[{"id_menu":6,"count":1}]	28431	pick-up	0	9
76018	2020-06-10 07:02:37	2020-06-10	9	[{"id_menu":6,"count":1}]	9891	delivery	5	14
76019	2020-06-10 07:03:37	2020-06-10	9	[{"id_menu":6,"count":1}]	12657	delivery	5	14
76020	2020-06-10 07:05:32	2020-06-10	9	[{"id_menu":7,"count":1}]	17295	delivery	5	14
76021	2020-06-10 07:07:08	2020-06-10	33	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	6987	pick-up	0	33
76022	2020-06-10 07:15:39	2020-06-10	9	[{"id_menu":7,"count":1}]	7782	pick-up	0	9
76023	2020-06-10 07:17:24	2020-06-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	29961	delivery	5	28
76024	2020-06-10 07:22:02	2020-06-10	12	[{"id_menu":1,"count":1}]	26001	pick-up	0	12
76025	2020-06-10 07:30:53	2020-06-10	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	29965	delivery	5	31
76026	2020-06-10 07:32:14	2020-06-10	14	[{"id_menu":2,"count":1}]	29998	delivery	5	19
76027	2020-06-10 07:32:34	2020-06-10	12	[{"id_menu":1,"count":1}]	6110	pick-up	0	12
76028	2020-06-10 07:41:06	2020-06-10	17	[{"id_menu":4,"count":1}]	28320	delivery	5	22
76029	2020-06-10 07:56:35	2020-06-10	8	[{"id_menu":5,"count":1}]	30072	delivery	5	13
76030	2020-06-10 07:56:38	2020-06-10	9	[{"id_menu":6,"count":1}]	10961	delivery	5	14
76031	2020-06-10 07:59:11	2020-06-10	12	[{"id_menu":3,"count":1}]	993	pick-up	0	12
76032	2020-06-10 08:00:27	2020-06-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	30026	delivery	5	28
76033	2020-06-10 08:01:43	2020-06-10	17	[{"id_menu":4,"count":1}]	30055	delivery	5	22
76034	2020-06-10 08:11:29	2020-06-10	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1934	pick-up	0	24
76035	2020-06-10 08:14:28	2020-06-10	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	29977	delivery	5	45
76036	2020-06-10 08:14:55	2020-06-10	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	30085	delivery	5	34
76037	2020-06-10 08:16:01	2020-06-10	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	30022	delivery	5	34
76038	2020-06-10 08:32:03	2020-06-10	17	[{"id_menu":4,"count":1}]	3172	pick-up	0	17
76039	2020-06-10 08:32:37	2020-06-10	14	[{"id_menu":2,"count":1}]	4590	pick-up	0	14
76040	2020-06-10 08:39:43	2020-06-10	12	[{"id_menu":1,"count":1}]	30082	pick-up	0	12
76041	2020-06-10 08:44:31	2020-06-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2426	pick-up	0	17
76042	2020-06-10 08:45:18	2020-06-10	17	[{"id_menu":4,"count":1}]	29995	delivery	5	22
76043	2020-06-10 08:57:17	2020-06-10	14	[{"id_menu":2,"count":1}]	14841	pick-up	0	14
76044	2020-06-10 08:58:11	2020-06-10	14	[{"id_menu":2,"count":1}]	30102	delivery	5	19
76045	2020-06-10 09:07:27	2020-06-10	14	[{"id_menu":2,"count":1}]	1352	delivery	5	19
76046	2020-06-10 09:07:53	2020-06-10	8	[{"id_menu":5,"count":1}]	29971	delivery	5	13
76047	2020-06-10 09:10:09	2020-06-10	12	[{"id_menu":1,"count":1}]	22899	delivery	5	17
76048	2020-06-10 09:16:49	2020-06-10	17	[{"id_menu":4,"count":1}]	9562	pick-up	0	17
76049	2020-06-10 09:18:18	2020-06-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	28357	delivery	5	28
76050	2020-06-10 09:20:29	2020-06-10	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	27639	pick-up	0	17
76051	2020-06-10 09:24:17	2020-06-10	8	[{"id_menu":5,"count":1}]	30104	delivery	5	13
76052	2020-06-10 09:27:48	2020-06-10	9	[{"id_menu":6,"count":1}]	29955	delivery	5	14
76053	2020-06-10 09:29:45	2020-06-10	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	678	delivery	5	49
76054	2020-06-10 09:30:50	2020-06-10	14	[{"id_menu":2,"count":1}]	30091	delivery	5	19
76055	2020-06-10 09:32:30	2020-06-10	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5110	delivery	5	36
76056	2020-06-10 09:34:39	2020-06-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	8521	pick-up	0	23
76057	2020-06-10 09:37:13	2020-06-10	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	21251	delivery	5	31
76058	2020-06-10 09:41:13	2020-06-10	8	[{"id_menu":5,"count":1}]	146	pick-up	0	8
76059	2020-06-10 09:44:05	2020-06-10	14	[{"id_menu":2,"count":1}]	27512	delivery	5	19
76060	2020-06-10 09:45:24	2020-06-10	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13725	delivery	5	22
76061	2020-06-10 09:46:50	2020-06-10	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14776	delivery	5	22
76062	2020-06-10 09:54:03	2020-06-10	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29927	delivery	5	36
76063	2020-06-10 09:54:33	2020-06-10	12	[{"id_menu":1,"count":1}]	30030	delivery	5	17
76064	2020-06-10 09:56:57	2020-06-10	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	30074	delivery	5	43
76065	2020-06-10 10:01:05	2020-06-10	12	[{"id_menu":1,"count":1}]	30112	delivery	5	17
76066	2020-06-10 10:02:55	2020-06-10	12	[{"id_menu":3,"count":1}]	29830	pick-up	0	12
76067	2020-06-10 10:03:28	2020-06-10	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	9657	delivery	5	26
76068	2020-06-10 10:04:56	2020-06-10	9	[{"id_menu":6,"count":1}]	30002	delivery	5	14
76069	2020-06-10 10:07:54	2020-06-10	8	[{"id_menu":5,"count":1}]	19011	pick-up	0	8
76070	2020-06-10 10:12:36	2020-06-10	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28116	delivery	5	40
76071	2020-06-10 10:16:17	2020-06-10	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	1002	delivery	5	22
76072	2020-06-10 10:17:41	2020-06-10	8	[{"id_menu":5,"count":1}]	5503	pick-up	0	8
76073	2020-06-10 10:21:33	2020-06-10	12	[{"id_menu":3,"count":1}]	4436	pick-up	0	12
76074	2020-06-10 10:21:42	2020-06-10	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	29950	delivery	5	26
76075	2020-06-10 10:26:00	2020-06-10	9	[{"id_menu":6,"count":1}]	30117	delivery	5	14
76076	2020-06-10 10:26:12	2020-06-10	9	[{"id_menu":7,"count":1}]	12154	delivery	5	14
76077	2020-06-10 10:29:40	2020-06-10	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	20754	pick-up	0	31
76078	2020-06-10 10:31:46	2020-06-10	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	24018	delivery	5	26
76079	2020-06-10 10:32:48	2020-06-10	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	26793	delivery	5	31
76080	2020-06-10 10:33:00	2020-06-10	12	[{"id_menu":1,"count":1}]	21307	delivery	5	17
76081	2020-06-10 10:42:01	2020-06-10	12	[{"id_menu":3,"count":1}]	8371	pick-up	0	12
76082	2020-06-10 10:42:32	2020-06-10	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	30088	delivery	5	26
76083	2020-06-10 10:48:50	2020-06-10	9	[{"id_menu":6,"count":1}]	25284	delivery	5	14
76084	2020-06-10 10:52:01	2020-06-10	9	[{"id_menu":6,"count":1}]	30060	delivery	5	14
76085	2020-06-10 10:54:25	2020-06-10	8	[{"id_menu":5,"count":1}]	12385	delivery	5	13
76086	2020-06-10 10:55:09	2020-06-10	9	[{"id_menu":7,"count":1}]	9162	delivery	5	14
76087	2020-06-10 11:06:19	2020-06-10	9	[{"id_menu":6,"count":1}]	3587	delivery	5	14
76088	2020-06-10 11:08:54	2020-06-10	9	[{"id_menu":7,"count":1}]	29958	delivery	5	14
76089	2020-06-10 11:10:08	2020-06-10	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	26613	delivery	5	22
76090	2020-06-10 11:10:51	2020-06-10	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	15855	delivery	5	37
76091	2020-06-10 11:19:45	2020-06-10	17	[{"id_menu":4,"count":1}]	30005	pick-up	0	17
76092	2020-06-10 11:21:17	2020-06-10	14	[{"id_menu":2,"count":1}]	3788	pick-up	0	14
76093	2020-06-10 11:23:04	2020-06-10	14	[{"id_menu":2,"count":1}]	19674	delivery	5	19
76094	2020-06-10 11:25:25	2020-06-10	9	[{"id_menu":7,"count":1}]	30044	delivery	5	14
76095	2020-06-10 11:27:47	2020-06-10	14	[{"id_menu":2,"count":1}]	9394	pick-up	0	14
76096	2020-06-10 11:30:26	2020-06-10	9	[{"id_menu":6,"count":1}]	30099	delivery	5	14
76097	2020-06-10 11:31:16	2020-06-10	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13193	delivery	5	51
76098	2020-06-10 11:35:26	2020-06-10	9	[{"id_menu":6,"count":1}]	30017	delivery	5	14
76099	2020-06-10 11:38:54	2020-06-10	14	[{"id_menu":2,"count":2}]	28515	pick-up	0	14
76100	2020-06-10 11:38:56	2020-06-10	8	[{"id_menu":5,"count":2}]	20340	delivery	5	13
76101	2020-06-10 11:43:30	2020-06-10	9	[{"id_menu":6,"count":1}]	26116	delivery	5	14
76102	2020-06-10 11:46:57	2020-06-10	9	[{"id_menu":7,"count":1}]	1148	pick-up	0	9
76103	2020-06-10 11:49:38	2020-06-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3478	delivery	5	22
76104	2020-06-10 11:51:23	2020-06-10	12	[{"id_menu":1,"count":1}]	16170	delivery	5	17
76105	2020-06-10 11:51:55	2020-06-10	14	[{"id_menu":2,"count":1}]	432	pick-up	0	14
76106	2020-06-10 11:53:37	2020-06-10	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	13996	pick-up	0	24
76107	2020-06-10 11:54:10	2020-06-10	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	16545	delivery	5	27
76108	2020-06-10 11:55:52	2020-06-10	9	[{"id_menu":6,"count":2}]	30010	delivery	5	14
76109	2020-06-10 11:56:46	2020-06-10	12	[{"id_menu":1,"count":1}]	30004	pick-up	0	12
76110	2020-06-10 11:57:10	2020-06-10	12	[{"id_menu":1,"count":1}]	7451	delivery	5	17
76111	2020-06-10 11:58:37	2020-06-10	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	30101	delivery	5	27
76112	2020-06-10 11:58:57	2020-06-10	12	[{"id_menu":1,"count":1}]	30077	delivery	5	17
76113	2020-06-10 12:00:55	2020-06-10	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	30095	delivery	5	45
76114	2020-06-10 12:01:53	2020-06-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5881	pick-up	0	18
76115	2020-06-10 12:03:37	2020-06-10	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	14881	delivery	5	26
76116	2020-06-10 12:12:30	2020-06-10	12	[{"id_menu":3,"count":1}]	117	pick-up	0	12
76117	2020-06-10 12:14:20	2020-06-10	12	[{"id_menu":1,"count":1}]	22866	delivery	5	17
76118	2020-06-10 12:14:51	2020-06-10	17	[{"id_menu":4,"count":1}]	19452	pick-up	0	17
76119	2020-06-10 12:21:37	2020-06-10	8	[{"id_menu":5,"count":1}]	30061	delivery	5	13
76120	2020-06-10 12:24:08	2020-06-10	9	[{"id_menu":6,"count":1}]	11334	pick-up	0	9
76121	2020-06-10 12:25:00	2020-06-10	9	[{"id_menu":6,"count":1}]	13831	delivery	5	14
76122	2020-06-10 12:28:50	2020-06-10	17	[{"id_menu":4,"count":1}]	22283	pick-up	0	17
76123	2020-06-10 12:31:35	2020-06-10	17	[{"id_menu":4,"count":1}]	2535	delivery	5	22
76124	2020-06-10 12:43:57	2020-06-10	17	[{"id_menu":4,"count":1}]	18207	pick-up	0	17
76125	2020-06-10 12:44:28	2020-06-10	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	1265	delivery	5	40
76126	2020-06-10 12:51:16	2020-06-10	17	[{"id_menu":4,"count":1}]	2413	pick-up	0	17
76127	2020-06-10 12:52:23	2020-06-10	12	[{"id_menu":1,"count":1}]	821	pick-up	0	12
76128	2020-06-10 12:56:23	2020-06-10	14	[{"id_menu":2,"count":2}]	4917	delivery	5	19
76129	2020-06-10 12:56:35	2020-06-10	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15532	delivery	5	31
76130	2020-06-10 12:57:31	2020-06-10	9	[{"id_menu":6,"count":1}]	30120	delivery	5	14
76131	2020-06-10 12:57:33	2020-06-10	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2085	pick-up	0	26
76132	2020-06-10 12:58:09	2020-06-10	12	[{"id_menu":3,"count":1}]	9687	pick-up	0	12
76133	2020-06-10 12:59:28	2020-06-10	17	[{"id_menu":4,"count":1}]	30100	pick-up	0	17
76134	2020-06-10 13:06:35	2020-06-10	9	[{"id_menu":6,"count":1}]	18552	delivery	5	14
76135	2020-06-10 13:07:34	2020-06-10	8	[{"id_menu":5,"count":1}]	30084	delivery	5	13
76136	2020-06-10 13:14:52	2020-06-10	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	24632	delivery	5	27
76137	2020-06-10 13:16:43	2020-06-10	9	[{"id_menu":7,"count":1}]	2433	pick-up	0	9
76138	2020-06-10 13:17:56	2020-06-10	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30011	delivery	5	35
76139	2020-06-10 13:24:05	2020-06-10	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	29980	delivery	5	26
76140	2020-06-10 13:24:50	2020-06-10	12	[{"id_menu":3,"count":1}]	719	pick-up	0	12
76141	2020-06-10 13:26:51	2020-06-10	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3257	delivery	5	27
76142	2020-06-10 13:32:22	2020-06-10	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28093	delivery	5	46
76143	2020-06-10 13:34:27	2020-06-10	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	11466	delivery	5	43
76144	2020-06-10 13:35:44	2020-06-10	9	[{"id_menu":6,"count":1}]	30032	delivery	5	14
76145	2020-06-10 13:38:47	2020-06-10	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	30015	delivery	5	26
76146	2020-06-10 13:42:02	2020-06-10	9	[{"id_menu":7,"count":1}]	19944	delivery	5	14
76147	2020-06-10 13:42:32	2020-06-10	17	[{"id_menu":4,"count":1}]	768	delivery	5	22
76148	2020-06-10 13:46:08	2020-06-10	14	[{"id_menu":2,"count":1}]	9107	delivery	5	19
76149	2020-06-10 13:47:53	2020-06-10	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	21814	delivery	5	26
76150	2020-06-10 13:49:36	2020-06-10	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	18123	delivery	5	31
76151	2020-06-10 13:58:40	2020-06-10	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	29936	delivery	5	22
76152	2020-06-10 14:01:16	2020-06-10	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	30036	delivery	5	36
76153	2020-06-10 14:03:46	2020-06-10	14	[{"id_menu":2,"count":1}]	30046	delivery	5	19
76154	2020-06-10 14:06:56	2020-06-10	14	[{"id_menu":2,"count":1}]	19667	delivery	5	19
76155	2020-06-10 14:07:34	2020-06-10	9	[{"id_menu":6,"count":1}]	19442	pick-up	0	9
76156	2020-06-10 14:08:17	2020-06-10	14	[{"id_menu":2,"count":1}]	30106	delivery	5	19
76157	2020-06-10 14:10:27	2020-06-10	14	[{"id_menu":2,"count":1}]	27768	delivery	5	19
76158	2020-06-10 14:10:58	2020-06-10	9	[{"id_menu":6,"count":1}]	18312	delivery	5	14
76159	2020-06-10 14:12:24	2020-06-10	8	[{"id_menu":5,"count":1}]	13098	delivery	5	13
76160	2020-06-10 14:14:05	2020-06-10	12	[{"id_menu":3,"count":1}]	29900	delivery	5	17
76161	2020-06-10 14:19:53	2020-06-10	12	[{"id_menu":3,"count":1}]	17653	delivery	5	17
76162	2020-06-10 14:21:48	2020-06-10	17	[{"id_menu":4,"count":1}]	30086	pick-up	0	17
76163	2020-06-10 14:23:50	2020-06-10	9	[{"id_menu":7,"count":1}]	27885	delivery	5	14
76164	2020-06-10 14:31:21	2020-06-10	9	[{"id_menu":6,"count":1}]	1965	pick-up	0	9
76165	2020-06-10 14:31:38	2020-06-10	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	29938	delivery	5	45
76166	2020-06-10 14:33:35	2020-06-10	14	[{"id_menu":2,"count":1}]	883	pick-up	0	14
76167	2020-06-10 14:35:50	2020-06-10	9	[{"id_menu":7,"count":1}]	4215	delivery	5	14
76168	2020-06-10 14:37:29	2020-06-10	17	[{"id_menu":4,"count":1}]	5536	pick-up	0	17
76169	2020-06-10 14:38:55	2020-06-10	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25790	delivery	5	43
76170	2020-06-10 14:50:56	2020-06-10	8	[{"id_menu":5,"count":1}]	3534	delivery	5	13
76171	2020-06-10 14:53:15	2020-06-10	12	[{"id_menu":1,"count":1}]	13105	delivery	5	17
76172	2020-06-10 14:54:11	2020-06-10	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28177	delivery	5	31
76173	2020-06-10 14:54:53	2020-06-10	9	[{"id_menu":6,"count":1}]	30110	delivery	5	14
76174	2020-06-10 14:55:25	2020-06-10	9	[{"id_menu":6,"count":1}]	23551	delivery	5	14
76175	2020-06-10 15:01:57	2020-06-10	14	[{"id_menu":2,"count":1}]	29093	pick-up	0	14
76176	2020-06-10 15:02:59	2020-06-10	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12297	delivery	5	34
76177	2020-06-10 15:07:43	2020-06-10	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	29987	delivery	5	26
76178	2020-06-10 15:13:41	2020-06-10	14	[{"id_menu":2,"count":1}]	3628	pick-up	0	14
76179	2020-06-10 15:13:53	2020-06-10	12	[{"id_menu":1,"count":1}]	4295	pick-up	0	12
76180	2020-06-10 15:18:53	2020-06-10	8	[{"id_menu":5,"count":1}]	13661	delivery	5	13
76181	2020-06-10 15:22:07	2020-06-10	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2753	delivery	5	31
76182	2020-06-10 15:25:44	2020-06-10	9	[{"id_menu":7,"count":1}]	13083	delivery	5	14
76183	2020-06-10 15:33:41	2020-06-10	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	23529	delivery	5	31
76184	2020-06-10 15:34:42	2020-06-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4687	delivery	5	28
76185	2020-06-10 15:35:06	2020-06-10	8	[{"id_menu":5,"count":1}]	3574	delivery	5	13
76186	2020-06-10 15:37:52	2020-06-10	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	19742	delivery	5	31
76187	2020-06-10 15:40:01	2020-06-10	9	[{"id_menu":7,"count":1}]	3687	delivery	5	14
76188	2020-06-10 15:41:32	2020-06-10	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	29377	delivery	5	25
76189	2020-06-10 15:42:54	2020-06-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9927	delivery	5	28
76190	2020-06-10 15:44:17	2020-06-10	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23457	delivery	5	37
76191	2020-06-10 15:47:37	2020-06-10	9	[{"id_menu":7,"count":1}]	24124	delivery	5	14
76192	2020-06-10 15:51:55	2020-06-10	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4279	delivery	5	48
76193	2020-06-10 15:52:14	2020-06-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18086	delivery	5	23
76194	2020-06-10 15:55:36	2020-06-10	9	[{"id_menu":6,"count":1}]	11157	delivery	5	14
76195	2020-06-10 15:55:54	2020-06-10	14	[{"id_menu":2,"count":2}]	29949	delivery	5	19
76196	2020-06-10 16:00:33	2020-06-10	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	30009	delivery	5	31
76197	2020-06-10 16:05:09	2020-06-10	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30078	delivery	5	52
76198	2020-06-10 16:09:35	2020-06-10	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	29989	delivery	5	35
76199	2020-06-10 16:15:29	2020-06-10	12	[{"id_menu":3,"count":1}]	18468	delivery	5	17
76200	2020-06-10 16:17:30	2020-06-10	17	[{"id_menu":4,"count":1}]	30116	delivery	5	22
76201	2020-06-10 16:19:20	2020-06-10	12	[{"id_menu":1,"count":1}]	24023	pick-up	0	12
76202	2020-06-10 16:20:18	2020-06-10	8	[{"id_menu":5,"count":1}]	14362	pick-up	0	8
76203	2020-06-10 16:21:08	2020-06-10	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	29959	delivery	5	25
76204	2020-06-10 16:21:41	2020-06-10	9	[{"id_menu":6,"count":1}]	29972	delivery	5	14
76205	2020-06-10 16:22:47	2020-06-10	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	29080	delivery	5	40
76206	2020-06-10 16:24:36	2020-06-10	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	22894	delivery	5	44
76207	2020-06-10 16:24:40	2020-06-10	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	29991	delivery	5	31
76208	2020-06-10 16:27:30	2020-06-10	12	[{"id_menu":3,"count":1}]	19072	delivery	5	17
76209	2020-06-10 16:27:40	2020-06-10	14	[{"id_menu":2,"count":1}]	10213	pick-up	0	14
76210	2020-06-10 16:32:07	2020-06-10	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	30097	delivery	5	43
76211	2020-06-10 16:36:01	2020-06-10	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	29941	delivery	5	45
76212	2020-06-10 16:39:34	2020-06-10	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	30063	delivery	5	22
76213	2020-06-10 16:40:07	2020-06-10	12	[{"id_menu":1,"count":1}]	378	pick-up	0	12
76214	2020-06-10 16:40:44	2020-06-10	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	30043	delivery	5	26
76215	2020-06-10 16:44:08	2020-06-10	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	21038	delivery	5	26
76216	2020-06-10 16:46:15	2020-06-10	17	[{"id_menu":4,"count":1}]	24485	pick-up	0	17
76217	2020-06-10 16:47:20	2020-06-10	12	[{"id_menu":1,"count":1}]	19909	delivery	5	17
76218	2020-06-10 16:49:55	2020-06-10	9	[{"id_menu":6,"count":1}]	26989	delivery	5	14
76219	2020-06-10 16:51:03	2020-06-10	8	[{"id_menu":5,"count":1}]	26841	delivery	5	13
76220	2020-06-10 16:52:08	2020-06-10	9	[{"id_menu":6,"count":1}]	24573	delivery	5	14
76221	2020-06-10 16:52:38	2020-06-10	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	30119	delivery	5	39
76222	2020-06-10 17:02:12	2020-06-10	14	[{"id_menu":2,"count":1}]	3802	delivery	5	19
76223	2020-06-10 17:02:40	2020-06-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28607	delivery	5	23
76224	2020-06-10 17:02:57	2020-06-10	14	[{"id_menu":2,"count":1}]	27365	delivery	5	19
76225	2020-06-10 17:06:11	2020-06-10	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	30034	delivery	5	45
76226	2020-06-10 17:07:27	2020-06-10	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	15363	delivery	5	43
76227	2020-06-10 17:09:29	2020-06-10	14	[{"id_menu":2,"count":1}]	9546	delivery	5	19
76228	2020-06-10 17:12:30	2020-06-10	17	[{"id_menu":4,"count":1}]	29990	pick-up	0	17
76229	2020-06-10 17:12:40	2020-06-10	12	[{"id_menu":3,"count":1}]	12427	pick-up	0	12
76230	2020-06-10 17:13:08	2020-06-10	14	[{"id_menu":2,"count":1}]	3684	delivery	5	19
76231	2020-06-10 17:13:26	2020-06-10	12	[{"id_menu":3,"count":1}]	18227	delivery	5	17
76232	2020-06-10 17:16:38	2020-06-10	49	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3123	delivery	5	54
76233	2020-06-10 17:18:43	2020-06-10	14	[{"id_menu":2,"count":1}]	30019	delivery	5	19
76234	2020-06-10 17:20:15	2020-06-10	9	[{"id_menu":6,"count":1}]	30090	delivery	5	14
76235	2020-06-10 17:22:16	2020-06-10	17	[{"id_menu":4,"count":1}]	30050	delivery	5	22
76236	2020-06-10 17:23:13	2020-06-10	17	[{"id_menu":4,"count":1}]	15091	delivery	5	22
76237	2020-06-10 17:25:02	2020-06-10	9	[{"id_menu":6,"count":1}]	29992	delivery	5	14
76238	2020-06-10 17:27:58	2020-06-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3168	pick-up	0	23
76239	2020-06-10 17:32:30	2020-06-10	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	24082	pick-up	0	33
76240	2020-06-10 17:33:46	2020-06-10	14	[{"id_menu":2,"count":1}]	10194	delivery	5	19
76241	2020-06-10 17:34:05	2020-06-10	12	[{"id_menu":1,"count":1}]	29951	delivery	5	17
76242	2020-06-10 17:38:19	2020-06-10	9	[{"id_menu":7,"count":1}]	13576	delivery	5	14
76243	2020-06-10 17:39:16	2020-06-10	17	[{"id_menu":4,"count":1}]	10532	delivery	5	22
76244	2020-06-10 17:40:55	2020-06-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	29934	delivery	5	28
76245	2020-06-10 17:47:00	2020-06-10	12	[{"id_menu":3,"count":1}]	27275	delivery	5	17
76246	2020-06-10 17:48:00	2020-06-10	9	[{"id_menu":7,"count":1}]	30057	delivery	5	14
76247	2020-06-10 17:48:17	2020-06-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	14046	delivery	5	28
76248	2020-06-10 17:52:39	2020-06-10	8	[{"id_menu":5,"count":1}]	17500	pick-up	0	8
76249	2020-06-10 17:55:44	2020-06-10	8	[{"id_menu":5,"count":1}]	26630	delivery	5	13
76250	2020-06-10 17:58:06	2020-06-10	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	29978	delivery	5	31
76251	2020-06-10 18:01:35	2020-06-10	9	[{"id_menu":6,"count":1}]	1548	pick-up	0	9
76252	2020-06-10 18:02:26	2020-06-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7899	delivery	5	28
76253	2020-06-10 18:03:36	2020-06-10	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	29999	delivery	5	34
76254	2020-06-10 18:05:15	2020-06-10	9	[{"id_menu":6,"count":1}]	2960	pick-up	0	9
76255	2020-06-10 18:07:13	2020-06-10	14	[{"id_menu":2,"count":1}]	15262	delivery	5	19
76256	2020-06-10 18:11:14	2020-06-10	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	21552	delivery	5	45
76257	2020-06-10 18:11:27	2020-06-10	9	[{"id_menu":6,"count":1}]	8609	pick-up	0	9
76258	2020-06-10 18:11:40	2020-06-10	8	[{"id_menu":5,"count":1}]	30049	delivery	5	13
76259	2020-06-10 18:13:06	2020-06-10	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	30071	delivery	5	43
76260	2020-06-10 18:19:09	2020-06-10	12	[{"id_menu":3,"count":1}]	439	delivery	5	17
76261	2020-06-10 18:22:18	2020-06-10	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	3863	pick-up	0	29
76262	2020-06-10 18:23:16	2020-06-10	14	[{"id_menu":2,"count":1}]	16967	pick-up	0	14
76263	2020-06-10 18:28:01	2020-06-10	17	[{"id_menu":4,"count":1}]	1215	pick-up	0	17
76264	2020-06-10 18:28:16	2020-06-10	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	13673	delivery	5	31
76265	2020-06-10 18:32:27	2020-06-10	14	[{"id_menu":2,"count":1}]	9765	delivery	5	19
76266	2020-06-10 18:33:45	2020-06-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15595	delivery	5	23
76267	2020-06-10 18:37:08	2020-06-10	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	30066	delivery	5	31
76268	2020-06-10 18:39:59	2020-06-10	17	[{"id_menu":4,"count":1}]	1044	pick-up	0	17
76269	2020-06-10 18:40:41	2020-06-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	17402	pick-up	0	23
76270	2020-06-10 18:44:21	2020-06-10	9	[{"id_menu":7,"count":1}]	12204	delivery	5	14
76271	2020-06-10 18:44:21	2020-06-10	17	[{"id_menu":4,"count":1}]	29293	pick-up	0	17
76272	2020-06-10 18:54:47	2020-06-10	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	30083	pick-up	0	24
76273	2020-06-10 18:55:42	2020-06-10	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	27720	delivery	5	29
76274	2020-06-10 18:56:49	2020-06-10	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28925	delivery	5	35
76275	2020-06-10 18:58:02	2020-06-10	12	[{"id_menu":3,"count":1}]	15976	pick-up	0	12
76276	2020-06-10 19:01:51	2020-06-10	17	[{"id_menu":4,"count":1}]	29933	delivery	5	22
76277	2020-06-10 19:08:13	2020-06-10	9	[{"id_menu":6,"count":1}]	27148	pick-up	0	9
76278	2020-06-10 19:09:24	2020-06-10	12	[{"id_menu":1,"count":1}]	29935	delivery	5	17
76279	2020-06-10 19:10:30	2020-06-10	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	29940	delivery	5	25
76280	2020-06-10 19:10:48	2020-06-10	9	[{"id_menu":7,"count":1}]	15720	pick-up	0	9
76281	2020-06-10 19:14:14	2020-06-10	12	[{"id_menu":1,"count":1}]	29944	delivery	5	17
76282	2020-06-10 19:14:57	2020-06-10	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	9771	delivery	5	34
76283	2020-06-10 19:17:34	2020-06-10	9	[{"id_menu":6,"count":1}]	30080	delivery	5	14
76284	2020-06-10 19:17:54	2020-06-10	8	[{"id_menu":5,"count":1}]	22408	delivery	5	13
76285	2020-06-10 19:19:23	2020-06-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27886	delivery	5	22
76286	2020-06-10 19:21:17	2020-06-10	9	[{"id_menu":7,"count":2}]	3293	delivery	5	14
76287	2020-06-10 19:21:44	2020-06-10	9	[{"id_menu":6,"count":1}]	21910	pick-up	0	9
76288	2020-06-10 19:21:57	2020-06-10	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	30016	delivery	5	34
76289	2020-06-10 19:22:28	2020-06-10	8	[{"id_menu":5,"count":1}]	22443	delivery	5	13
76290	2020-06-10 19:23:33	2020-06-10	9	[{"id_menu":6,"count":1}]	30008	delivery	5	14
76291	2020-06-10 19:25:05	2020-06-10	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	29996	delivery	5	34
76292	2020-06-10 19:25:41	2020-06-10	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	20390	delivery	5	43
76293	2020-06-10 19:25:56	2020-06-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	30093	delivery	5	22
76294	2020-06-10 19:27:07	2020-06-10	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20324	delivery	5	48
76295	2020-06-10 19:32:31	2020-06-10	12	[{"id_menu":3,"count":1}]	30062	delivery	5	17
76296	2020-06-10 19:38:44	2020-06-10	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6678	delivery	5	35
76297	2020-06-10 19:43:01	2020-06-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	21606	pick-up	0	23
76298	2020-06-10 19:55:59	2020-06-10	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6184	pick-up	0	26
76299	2020-06-10 19:59:39	2020-06-10	17	[{"id_menu":4,"count":1}]	26733	delivery	5	22
76300	2020-06-10 20:08:48	2020-06-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	30052	delivery	5	28
76301	2020-06-10 20:10:16	2020-06-10	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	27925	delivery	5	26
76302	2020-06-10 20:20:18	2020-06-10	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	26040	delivery	5	22
76303	2020-06-10 20:20:22	2020-06-10	14	[{"id_menu":2,"count":1}]	4395	delivery	5	19
76304	2020-06-10 20:22:37	2020-06-10	9	[{"id_menu":6,"count":1}]	9574	delivery	5	14
76305	2020-06-10 20:25:14	2020-06-10	17	[{"id_menu":4,"count":1}]	29477	delivery	5	22
76306	2020-06-10 20:27:32	2020-06-10	12	[{"id_menu":3,"count":1}]	30089	delivery	5	17
76307	2020-06-10 20:27:45	2020-06-10	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13466	delivery	5	35
76308	2020-06-10 20:29:27	2020-06-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23594	delivery	5	22
76309	2020-06-10 20:32:07	2020-06-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	18755	pick-up	0	23
76310	2020-06-10 20:33:05	2020-06-10	17	[{"id_menu":4,"count":1}]	29942	delivery	5	22
76311	2020-06-10 20:34:33	2020-06-10	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	29954	pick-up	0	20
76312	2020-06-10 20:35:54	2020-06-10	12	[{"id_menu":1,"count":1}]	30021	delivery	5	17
76313	2020-06-10 20:37:54	2020-06-10	12	[{"id_menu":1,"count":1}]	5392	pick-up	0	12
76314	2020-06-10 20:42:49	2020-06-10	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	23411	delivery	5	44
76315	2020-06-10 20:44:13	2020-06-10	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9377	delivery	5	22
76316	2020-06-10 20:52:47	2020-06-10	12	[{"id_menu":3,"count":1}]	9191	pick-up	0	12
76317	2020-06-10 20:53:50	2020-06-10	12	[{"id_menu":1,"count":1}]	30033	delivery	5	17
76318	2020-06-10 20:55:37	2020-06-10	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	27965	pick-up	0	29
76319	2020-06-10 20:56:57	2020-06-10	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	29988	pick-up	0	24
76320	2020-06-10 21:02:59	2020-06-10	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	30056	delivery	5	39
76321	2020-06-10 21:04:55	2020-06-10	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	9103	delivery	5	26
76322	2020-06-10 21:06:38	2020-06-10	9	[{"id_menu":7,"count":1}]	3148	pick-up	0	9
76323	2020-06-10 21:07:25	2020-06-10	12	[{"id_menu":1,"count":1}]	30037	delivery	5	17
76324	2020-06-10 21:09:36	2020-06-10	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1183	pick-up	0	20
76325	2020-06-10 21:09:52	2020-06-10	9	[{"id_menu":7,"count":1}]	30081	delivery	5	14
76326	2020-06-10 21:10:42	2020-06-10	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	30048	delivery	5	34
76327	2020-06-10 21:13:00	2020-06-10	8	[{"id_menu":5,"count":1}]	29963	delivery	5	13
76328	2020-06-10 21:14:31	2020-06-10	8	[{"id_menu":5,"count":1}]	26204	delivery	5	13
76329	2020-06-10 21:17:35	2020-06-10	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8145	pick-up	0	25
76330	2020-06-10 21:21:39	2020-06-10	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	19506	delivery	5	34
76331	2020-06-10 21:32:22	2020-06-10	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	30064	delivery	5	23
76332	2020-06-10 21:35:20	2020-06-10	17	[{"id_menu":4,"count":1}]	10257	delivery	5	22
76333	2020-06-10 21:36:59	2020-06-10	8	[{"id_menu":5,"count":1}]	30007	delivery	5	13
76334	2020-06-10 21:46:47	2020-06-10	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	601	pick-up	0	26
76335	2020-06-10 21:50:11	2020-06-10	9	[{"id_menu":6,"count":2}]	5416	pick-up	0	9
76336	2020-06-10 21:50:12	2020-06-10	14	[{"id_menu":2,"count":1}]	2868	delivery	5	19
76337	2020-06-10 21:54:48	2020-06-10	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	11067	delivery	5	48
76338	2020-06-10 21:56:41	2020-06-10	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	30028	delivery	5	27
76339	2020-06-10 22:02:12	2020-06-10	9	[{"id_menu":7,"count":1}]	29952	pick-up	0	9
76340	2020-06-10 22:05:37	2020-06-10	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	29946	delivery	5	43
76341	2020-06-10 22:10:49	2020-06-10	17	[{"id_menu":4,"count":2}]	25097	delivery	5	22
76342	2020-06-10 22:11:38	2020-06-10	14	[{"id_menu":2,"count":1}]	2993	delivery	5	19
76343	2020-06-10 22:18:42	2020-06-10	9	[{"id_menu":6,"count":1}]	9453	delivery	5	14
76344	2020-06-10 22:19:52	2020-06-10	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14391	pick-up	0	44
76345	2020-06-10 22:23:31	2020-06-10	9	[{"id_menu":6,"count":1}]	30092	delivery	5	14
76346	2020-06-10 22:24:42	2020-06-10	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	29311	delivery	5	48
76347	2020-06-10 22:25:46	2020-06-10	17	[{"id_menu":4,"count":1}]	2125	pick-up	0	17
76348	2020-06-10 22:28:06	2020-06-10	14	[{"id_menu":2,"count":2}]	9018	delivery	5	19
76349	2020-06-10 22:30:15	2020-06-10	8	[{"id_menu":5,"count":2}]	24896	delivery	5	13
76350	2020-06-10 22:33:08	2020-06-10	9	[{"id_menu":7,"count":1}]	974	delivery	5	14
76351	2020-06-10 22:37:07	2020-06-10	9	[{"id_menu":7,"count":1}]	6080	delivery	5	14
76352	2020-06-10 22:38:26	2020-06-10	8	[{"id_menu":5,"count":1}]	13859	pick-up	0	8
76353	2020-06-10 22:38:44	2020-06-10	17	[{"id_menu":4,"count":1}]	30069	delivery	5	22
76354	2020-06-10 22:39:28	2020-06-10	8	[{"id_menu":5,"count":1}]	29433	delivery	5	13
76355	2020-06-10 22:41:10	2020-06-10	9	[{"id_menu":7,"count":1}]	2116	delivery	5	14
76356	2020-06-10 22:43:59	2020-06-10	12	[{"id_menu":3,"count":1}]	2573	pick-up	0	12
76357	2020-06-10 22:47:42	2020-06-10	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	29947	delivery	5	27
76358	2020-06-10 22:52:10	2020-06-10	12	[{"id_menu":3,"count":1}]	30039	delivery	5	17
76359	2020-06-10 22:59:09	2020-06-10	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29981	delivery	5	48
76360	2020-06-10 23:01:08	2020-06-10	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	820	pick-up	0	20
76361	2020-06-10 23:06:19	2020-06-10	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	30038	delivery	5	46
76362	2020-06-10 23:07:07	2020-06-10	9	[{"id_menu":6,"count":1}]	8367	delivery	5	14
76363	2020-06-10 23:12:43	2020-06-10	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	8436	delivery	5	22
76364	2020-06-10 23:12:57	2020-06-10	17	[{"id_menu":4,"count":1}]	13697	pick-up	0	17
76365	2020-06-10 23:14:44	2020-06-10	12	[{"id_menu":1,"count":1}]	18548	pick-up	0	12
76366	2020-06-10 23:17:21	2020-06-10	8	[{"id_menu":5,"count":1}]	21232	delivery	5	13
76367	2020-06-10 23:22:34	2020-06-10	12	[{"id_menu":3,"count":1}]	22126	delivery	5	17
76368	2020-06-10 23:29:21	2020-06-10	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	7586	delivery	5	35
76369	2020-06-10 23:38:44	2020-06-10	17	[{"id_menu":4,"count":1}]	1070	pick-up	0	17
76370	2020-06-10 23:40:09	2020-06-10	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	30001	pick-up	0	26
76371	2020-06-10 23:41:36	2020-06-10	9	[{"id_menu":6,"count":1}]	9303	delivery	5	14
76372	2020-06-10 23:45:28	2020-06-10	8	[{"id_menu":5,"count":1}]	30025	delivery	5	13
76373	2020-06-10 23:47:17	2020-06-10	17	[{"id_menu":4,"count":1}]	696	pick-up	0	17
76374	2020-06-10 23:47:31	2020-06-10	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	30065	delivery	5	34
76375	2020-06-10 23:51:19	2020-06-10	9	[{"id_menu":7,"count":1}]	13762	pick-up	0	9
76376	2020-06-10 23:54:31	2020-06-10	12	[{"id_menu":1,"count":1}]	29846	delivery	5	17
76377	2020-06-10 23:54:41	2020-06-10	14	[{"id_menu":2,"count":1}]	26339	delivery	5	19
76378	2020-06-10 23:55:05	2020-06-10	17	[{"id_menu":4,"count":1}]	20911	delivery	5	22
76379	2020-06-10 23:56:39	2020-06-10	12	[{"id_menu":3,"count":1}]	30068	delivery	5	17
76380	2020-06-10 23:59:25	2020-06-10	9	[{"id_menu":6,"count":1}]	23561	pick-up	0	9
76381	2020-06-11 00:00:09	2020-06-11	9	[{"id_menu":7,"count":1}]	8704	delivery	5	14
76382	2020-06-11 00:00:35	2020-06-11	12	[{"id_menu":1,"count":1}]	30191	delivery	5	17
76383	2020-06-11 00:02:16	2020-06-11	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	10129	delivery	5	26
76384	2020-06-11 00:02:27	2020-06-11	9	[{"id_menu":6,"count":1}]	30279	delivery	5	14
76385	2020-06-11 00:05:09	2020-06-11	9	[{"id_menu":7,"count":1}]	30155	delivery	5	14
76386	2020-06-11 00:10:54	2020-06-11	8	[{"id_menu":5,"count":1}]	25089	pick-up	0	8
76387	2020-06-11 00:11:01	2020-06-11	14	[{"id_menu":2,"count":1}]	11183	pick-up	0	14
76388	2020-06-11 00:18:59	2020-06-11	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11756	delivery	5	31
76389	2020-06-11 00:19:38	2020-06-11	14	[{"id_menu":2,"count":1}]	1710	delivery	5	19
76390	2020-06-11 00:21:24	2020-06-11	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18627	delivery	5	43
76391	2020-06-11 00:22:50	2020-06-11	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13939	pick-up	0	26
76392	2020-06-11 00:23:43	2020-06-11	9	[{"id_menu":6,"count":1}]	10360	delivery	5	14
76393	2020-06-11 00:24:16	2020-06-11	9	[{"id_menu":6,"count":1}]	30255	delivery	5	14
76394	2020-06-11 00:26:06	2020-06-11	9	[{"id_menu":7,"count":1}]	12231	delivery	5	14
76395	2020-06-11 00:29:00	2020-06-11	14	[{"id_menu":2,"count":1}]	23350	delivery	5	19
76396	2020-06-11 00:31:16	2020-06-11	12	[{"id_menu":1,"count":1}]	17668	pick-up	0	12
76397	2020-06-11 00:32:13	2020-06-11	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	12952	delivery	5	23
76398	2020-06-11 00:34:48	2020-06-11	9	[{"id_menu":6,"count":1}]	20182	delivery	5	14
76399	2020-06-11 00:35:10	2020-06-11	12	[{"id_menu":1,"count":1}]	5466	pick-up	0	12
76400	2020-06-11 00:39:04	2020-06-11	9	[{"id_menu":7,"count":1}]	19775	delivery	5	14
76401	2020-06-11 00:39:35	2020-06-11	9	[{"id_menu":7,"count":1}]	5949	delivery	5	14
76402	2020-06-11 00:39:51	2020-06-11	14	[{"id_menu":2,"count":1}]	6301	pick-up	0	14
76403	2020-06-11 00:46:19	2020-06-11	14	[{"id_menu":2,"count":2}]	21887	delivery	5	19
76404	2020-06-11 00:51:43	2020-06-11	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22222	delivery	5	22
76405	2020-06-11 00:51:56	2020-06-11	14	[{"id_menu":2,"count":1}]	3659	pick-up	0	14
76406	2020-06-11 00:52:46	2020-06-11	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5952	delivery	5	43
76407	2020-06-11 00:54:12	2020-06-11	17	[{"id_menu":4,"count":1}]	30186	delivery	5	22
76408	2020-06-11 00:56:24	2020-06-11	12	[{"id_menu":1,"count":1}]	29823	delivery	5	17
76409	2020-06-11 00:59:35	2020-06-11	17	[{"id_menu":4,"count":1}]	1922	pick-up	0	17
76410	2020-06-11 00:59:58	2020-06-11	9	[{"id_menu":7,"count":1}]	4820	delivery	5	14
76411	2020-06-11 01:00:01	2020-06-11	8	[{"id_menu":5,"count":1}]	30283	delivery	5	13
76412	2020-06-11 01:04:06	2020-06-11	9	[{"id_menu":6,"count":1}]	12040	delivery	5	14
76413	2020-06-11 01:14:26	2020-06-11	9	[{"id_menu":6,"count":3}]	30136	delivery	5	14
76414	2020-06-11 01:17:39	2020-06-11	12	[{"id_menu":3,"count":1}]	8123	delivery	5	17
76415	2020-06-11 01:18:45	2020-06-11	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23466	delivery	5	31
76416	2020-06-11 01:18:55	2020-06-11	17	[{"id_menu":4,"count":1}]	7664	delivery	5	22
76417	2020-06-11 01:27:49	2020-06-11	9	[{"id_menu":7,"count":1}]	7396	delivery	5	14
76418	2020-06-11 01:27:58	2020-06-11	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	4066	delivery	5	36
76419	2020-06-11 01:29:34	2020-06-11	14	[{"id_menu":2,"count":1}]	8372	pick-up	0	14
76420	2020-06-11 01:33:08	2020-06-11	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	30072	delivery	5	23
76421	2020-06-11 01:35:59	2020-06-11	14	[{"id_menu":2,"count":1}]	6777	pick-up	0	14
76422	2020-06-11 01:36:31	2020-06-11	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	30194	delivery	5	43
76423	2020-06-11 01:36:34	2020-06-11	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30122	delivery	5	35
76424	2020-06-11 01:45:49	2020-06-11	17	[{"id_menu":4,"count":1}]	12393	pick-up	0	17
76425	2020-06-11 01:46:03	2020-06-11	9	[{"id_menu":6,"count":1}]	12484	pick-up	0	9
76426	2020-06-11 01:47:43	2020-06-11	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16409	delivery	5	40
76427	2020-06-11 02:00:37	2020-06-11	9	[{"id_menu":7,"count":1}]	29198	pick-up	0	9
76428	2020-06-11 02:03:11	2020-06-11	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18102	delivery	5	51
76429	2020-06-11 02:06:46	2020-06-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	8597	delivery	5	28
76430	2020-06-11 02:07:03	2020-06-11	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	20957	delivery	5	34
76431	2020-06-11 02:12:30	2020-06-11	9	[{"id_menu":7,"count":1}]	19598	pick-up	0	9
76432	2020-06-11 02:16:34	2020-06-11	12	[{"id_menu":1,"count":1}]	1829	pick-up	0	12
76433	2020-06-11 02:18:31	2020-06-11	14	[{"id_menu":2,"count":1}]	14491	delivery	5	19
76434	2020-06-11 02:22:23	2020-06-11	17	[{"id_menu":4,"count":1}]	1379	pick-up	0	17
76435	2020-06-11 02:22:41	2020-06-11	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	30217	pick-up	0	31
76436	2020-06-11 02:22:58	2020-06-11	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	30170	delivery	5	40
76437	2020-06-11 02:23:00	2020-06-11	17	[{"id_menu":4,"count":1}]	30263	pick-up	0	17
76438	2020-06-11 02:23:33	2020-06-11	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12667	delivery	5	43
76439	2020-06-11 02:25:37	2020-06-11	17	[{"id_menu":4,"count":1}]	1223	pick-up	0	17
76440	2020-06-11 02:28:02	2020-06-11	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	9647	delivery	5	26
76441	2020-06-11 02:28:33	2020-06-11	9	[{"id_menu":7,"count":1}]	30245	delivery	5	14
76442	2020-06-11 02:29:24	2020-06-11	9	[{"id_menu":7,"count":1}]	24892	delivery	5	14
76443	2020-06-11 02:32:30	2020-06-11	14	[{"id_menu":2,"count":1}]	30249	delivery	5	19
76444	2020-06-11 02:32:56	2020-06-11	9	[{"id_menu":7,"count":1}]	18011	delivery	5	14
76445	2020-06-11 02:33:00	2020-06-11	9	[{"id_menu":6,"count":1}]	30125	delivery	5	14
76446	2020-06-11 02:33:06	2020-06-11	8	[{"id_menu":5,"count":1}]	2556	pick-up	0	8
76447	2020-06-11 02:34:45	2020-06-11	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	4737	delivery	5	27
76448	2020-06-11 02:34:59	2020-06-11	9	[{"id_menu":7,"count":1}]	21188	delivery	5	14
76449	2020-06-11 02:36:44	2020-06-11	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	28629	delivery	5	26
76450	2020-06-11 02:36:49	2020-06-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30297	delivery	5	23
76451	2020-06-11 02:38:04	2020-06-11	12	[{"id_menu":1,"count":1}]	557	pick-up	0	12
76452	2020-06-11 02:44:48	2020-06-11	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	30195	delivery	5	40
76453	2020-06-11 02:45:20	2020-06-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30214	delivery	5	23
76454	2020-06-11 02:46:16	2020-06-11	9	[{"id_menu":6,"count":3}]	13968	delivery	5	14
76455	2020-06-11 02:54:36	2020-06-11	9	[{"id_menu":7,"count":1}]	29659	delivery	5	14
76456	2020-06-11 02:58:59	2020-06-11	9	[{"id_menu":6,"count":1}]	30230	delivery	5	14
76457	2020-06-11 02:59:35	2020-06-11	14	[{"id_menu":2,"count":1}]	2525	delivery	5	19
76458	2020-06-11 03:00:03	2020-06-11	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7770	delivery	5	43
76459	2020-06-11 03:04:28	2020-06-11	9	[{"id_menu":7,"count":1}]	30239	delivery	5	14
76460	2020-06-11 03:05:46	2020-06-11	14	[{"id_menu":2,"count":1}]	24407	pick-up	0	14
76461	2020-06-11 03:07:52	2020-06-11	14	[{"id_menu":2,"count":1}]	11732	pick-up	0	14
76462	2020-06-11 03:15:59	2020-06-11	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30287	delivery	5	31
76463	2020-06-11 03:20:55	2020-06-11	9	[{"id_menu":6,"count":1}]	30148	delivery	5	14
76464	2020-06-11 03:22:19	2020-06-11	17	[{"id_menu":4,"count":1}]	30156	delivery	5	22
76465	2020-06-11 03:24:55	2020-06-11	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	20410	delivery	5	27
76466	2020-06-11 03:26:01	2020-06-11	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11245	delivery	5	22
76467	2020-06-11 03:27:14	2020-06-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	30256	delivery	5	28
76468	2020-06-11 03:28:35	2020-06-11	9	[{"id_menu":7,"count":1}]	6547	delivery	5	14
76469	2020-06-11 03:37:04	2020-06-11	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	16124	delivery	5	28
76470	2020-06-11 03:37:40	2020-06-11	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	26396	delivery	5	26
76471	2020-06-11 03:39:52	2020-06-11	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	26520	delivery	5	38
76472	2020-06-11 03:40:06	2020-06-11	12	[{"id_menu":1,"count":1}]	13371	delivery	5	17
76473	2020-06-11 03:43:09	2020-06-11	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	25313	delivery	5	36
76474	2020-06-11 03:46:07	2020-06-11	17	[{"id_menu":4,"count":1}]	12057	delivery	5	22
76475	2020-06-11 03:46:13	2020-06-11	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	25545	delivery	5	36
76476	2020-06-11 03:51:18	2020-06-11	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17750	delivery	5	34
76477	2020-06-11 03:51:26	2020-06-11	12	[{"id_menu":1,"count":1}]	25685	delivery	5	17
76478	2020-06-11 03:51:28	2020-06-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	30227	delivery	5	28
76479	2020-06-11 03:52:01	2020-06-11	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	29849	delivery	5	31
76480	2020-06-11 03:56:13	2020-06-11	9	[{"id_menu":6,"count":1}]	23667	delivery	5	14
76481	2020-06-11 04:00:23	2020-06-11	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	12467	delivery	5	48
76482	2020-06-11 04:02:02	2020-06-11	12	[{"id_menu":3,"count":1}]	5413	delivery	5	17
76483	2020-06-11 04:02:18	2020-06-11	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	13172	delivery	5	25
76484	2020-06-11 04:05:25	2020-06-11	12	[{"id_menu":1,"count":1}]	30237	delivery	5	17
76485	2020-06-11 04:08:37	2020-06-11	12	[{"id_menu":1,"count":1}]	7953	delivery	5	17
76486	2020-06-11 04:08:44	2020-06-11	14	[{"id_menu":2,"count":1}]	2826	delivery	5	19
76487	2020-06-11 04:08:47	2020-06-11	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30251	delivery	5	31
76488	2020-06-11 04:11:10	2020-06-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1517	pick-up	0	23
76489	2020-06-11 04:11:22	2020-06-11	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	13942	delivery	5	26
76490	2020-06-11 04:12:17	2020-06-11	9	[{"id_menu":7,"count":1}]	2585	delivery	5	14
76491	2020-06-11 04:15:12	2020-06-11	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20568	delivery	5	35
76492	2020-06-11 04:17:06	2020-06-11	12	[{"id_menu":3,"count":1}]	2185	delivery	5	17
76493	2020-06-11 04:17:06	2020-06-11	9	[{"id_menu":6,"count":1}]	15902	delivery	5	14
76494	2020-06-11 04:17:45	2020-06-11	12	[{"id_menu":3,"count":1}]	30157	delivery	5	17
76495	2020-06-11 04:21:35	2020-06-11	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1132	delivery	5	25
76496	2020-06-11 04:24:34	2020-06-11	12	[{"id_menu":1,"count":1}]	30304	delivery	5	17
76497	2020-06-11 04:25:27	2020-06-11	9	[{"id_menu":6,"count":1}]	30264	pick-up	0	9
76498	2020-06-11 04:30:55	2020-06-11	12	[{"id_menu":3,"count":2}]	73	delivery	5	17
76499	2020-06-11 04:30:58	2020-06-11	12	[{"id_menu":1,"count":1}]	9809	pick-up	0	12
76500	2020-06-11 04:31:06	2020-06-11	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	24303	delivery	5	44
76501	2020-06-11 04:33:41	2020-06-11	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	14023	delivery	5	40
76502	2020-06-11 04:41:48	2020-06-11	17	[{"id_menu":4,"count":2}]	12699	pick-up	0	17
76503	2020-06-11 04:42:12	2020-06-11	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	30211	delivery	5	36
76504	2020-06-11 04:44:12	2020-06-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16596	delivery	5	23
76505	2020-06-11 04:46:47	2020-06-11	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	15329	pick-up	0	21
76506	2020-06-11 04:47:25	2020-06-11	8	[{"id_menu":5,"count":1}]	6707	delivery	5	13
76507	2020-06-11 04:51:03	2020-06-11	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	30124	delivery	5	40
76508	2020-06-11 04:52:47	2020-06-11	37	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3177	pick-up	0	37
76509	2020-06-11 04:53:16	2020-06-11	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	26963	delivery	5	34
76510	2020-06-11 05:00:10	2020-06-11	17	[{"id_menu":4,"count":2}]	30218	pick-up	0	17
76511	2020-06-11 05:02:32	2020-06-11	14	[{"id_menu":2,"count":1}]	5236	delivery	5	19
76512	2020-06-11 05:04:28	2020-06-11	9	[{"id_menu":7,"count":1}]	20351	delivery	5	14
76513	2020-06-11 05:04:45	2020-06-11	9	[{"id_menu":7,"count":1}]	30127	delivery	5	14
76514	2020-06-11 05:19:08	2020-06-11	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12261	delivery	5	31
76515	2020-06-11 05:20:05	2020-06-11	9	[{"id_menu":7,"count":1}]	15690	delivery	5	14
76516	2020-06-11 05:23:52	2020-06-11	17	[{"id_menu":4,"count":1}]	497	pick-up	0	17
76517	2020-06-11 05:25:44	2020-06-11	12	[{"id_menu":3,"count":2}]	9787	delivery	5	17
76518	2020-06-11 05:30:41	2020-06-11	8	[{"id_menu":5,"count":1}]	1053	pick-up	0	8
76519	2020-06-11 05:31:02	2020-06-11	14	[{"id_menu":2,"count":1}]	11922	delivery	5	19
76520	2020-06-11 05:33:55	2020-06-11	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	26326	pick-up	0	29
76521	2020-06-11 05:42:01	2020-06-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9840	delivery	5	22
76522	2020-06-11 05:43:46	2020-06-11	9	[{"id_menu":7,"count":1}]	4349	delivery	5	14
76523	2020-06-11 05:44:14	2020-06-11	14	[{"id_menu":2,"count":1}]	30257	delivery	5	19
76524	2020-06-11 05:47:12	2020-06-11	17	[{"id_menu":4,"count":1}]	14116	pick-up	0	17
76525	2020-06-11 05:49:55	2020-06-11	9	[{"id_menu":7,"count":1}]	20969	delivery	5	14
76526	2020-06-11 05:52:01	2020-06-11	14	[{"id_menu":2,"count":2}]	22960	pick-up	0	14
76527	2020-06-11 05:52:43	2020-06-11	9	[{"id_menu":6,"count":1}]	30243	pick-up	0	9
76528	2020-06-11 05:53:54	2020-06-11	14	[{"id_menu":2,"count":1}]	15776	delivery	5	19
76529	2020-06-11 05:57:10	2020-06-11	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	22871	delivery	5	45
76530	2020-06-11 05:57:35	2020-06-11	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2631	delivery	5	30
76531	2020-06-11 05:58:12	2020-06-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	1814	delivery	5	23
76532	2020-06-11 06:00:00	2020-06-11	9	[{"id_menu":7,"count":1}]	29428	delivery	5	14
76533	2020-06-11 06:01:49	2020-06-11	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	16012	delivery	5	31
76534	2020-06-11 06:02:38	2020-06-11	17	[{"id_menu":4,"count":1}]	30132	delivery	5	22
76535	2020-06-11 06:02:42	2020-06-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27025	delivery	5	22
76536	2020-06-11 06:11:40	2020-06-11	8	[{"id_menu":5,"count":1}]	30128	delivery	5	13
76537	2020-06-11 06:11:40	2020-06-11	12	[{"id_menu":1,"count":3}]	18431	delivery	5	17
76538	2020-06-11 06:15:54	2020-06-11	12	[{"id_menu":1,"count":1}]	7074	pick-up	0	12
76539	2020-06-11 06:16:07	2020-06-11	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	30285	delivery	5	37
76540	2020-06-11 06:20:28	2020-06-11	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	29810	delivery	5	31
76541	2020-06-11 06:22:11	2020-06-11	14	[{"id_menu":2,"count":1}]	3148	delivery	5	19
76542	2020-06-11 06:22:35	2020-06-11	8	[{"id_menu":5,"count":1}]	7085	delivery	5	13
76543	2020-06-11 06:23:16	2020-06-11	9	[{"id_menu":7,"count":1}]	414	delivery	5	14
76544	2020-06-11 06:23:42	2020-06-11	12	[{"id_menu":1,"count":1}]	30176	pick-up	0	12
76545	2020-06-11 06:25:56	2020-06-11	9	[{"id_menu":6,"count":1}]	28164	delivery	5	14
76546	2020-06-11 06:29:51	2020-06-11	9	[{"id_menu":6,"count":1}]	6665	delivery	5	14
76547	2020-06-11 06:30:00	2020-06-11	9	[{"id_menu":7,"count":1}]	2329	pick-up	0	9
76548	2020-06-11 06:33:14	2020-06-11	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28288	delivery	5	53
76549	2020-06-11 06:38:54	2020-06-11	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	30274	delivery	5	26
76550	2020-06-11 06:44:45	2020-06-11	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30225	delivery	5	54
76551	2020-06-11 06:45:11	2020-06-11	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	14845	pick-up	0	21
76552	2020-06-11 06:46:21	2020-06-11	9	[{"id_menu":6,"count":1}]	24684	pick-up	0	9
76553	2020-06-11 06:47:35	2020-06-11	17	[{"id_menu":4,"count":1}]	431	pick-up	0	17
76554	2020-06-11 06:56:17	2020-06-11	9	[{"id_menu":7,"count":1}]	30296	delivery	5	14
76555	2020-06-11 06:58:12	2020-06-11	17	[{"id_menu":4,"count":1}]	4644	delivery	5	22
76556	2020-06-11 07:00:01	2020-06-11	9	[{"id_menu":7,"count":1}]	30267	pick-up	0	9
76557	2020-06-11 07:05:21	2020-06-11	17	[{"id_menu":4,"count":1}]	12361	delivery	5	22
76558	2020-06-11 07:11:04	2020-06-11	14	[{"id_menu":2,"count":1}]	15023	pick-up	0	14
76559	2020-06-11 07:13:43	2020-06-11	9	[{"id_menu":6,"count":1}]	2691	pick-up	0	9
76560	2020-06-11 07:20:55	2020-06-11	9	[{"id_menu":6,"count":1}]	26874	delivery	5	14
76561	2020-06-11 07:23:42	2020-06-11	12	[{"id_menu":3,"count":1}]	22014	delivery	5	17
76562	2020-06-11 07:23:57	2020-06-11	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4020	delivery	5	39
76563	2020-06-11 07:26:51	2020-06-11	12	[{"id_menu":1,"count":1}]	30159	delivery	5	17
76564	2020-06-11 07:32:09	2020-06-11	9	[{"id_menu":6,"count":1}]	30266	delivery	5	14
76565	2020-06-11 07:44:56	2020-06-11	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7204	delivery	5	30
76566	2020-06-11 07:50:35	2020-06-11	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2570	pick-up	0	26
76567	2020-06-11 07:53:37	2020-06-11	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	30140	pick-up	0	29
76568	2020-06-11 07:54:10	2020-06-11	8	[{"id_menu":5,"count":1}]	2386	delivery	5	13
76569	2020-06-11 07:59:05	2020-06-11	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	17794	delivery	5	40
76570	2020-06-11 08:03:04	2020-06-11	17	[{"id_menu":4,"count":1}]	30133	delivery	5	22
76571	2020-06-11 08:04:15	2020-06-11	8	[{"id_menu":5,"count":1}]	11507	delivery	5	13
76572	2020-06-11 08:08:25	2020-06-11	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10190	delivery	5	34
76573	2020-06-11 08:10:42	2020-06-11	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10179	delivery	5	36
76574	2020-06-11 08:11:52	2020-06-11	12	[{"id_menu":1,"count":1}]	27721	delivery	5	17
76575	2020-06-11 08:13:05	2020-06-11	9	[{"id_menu":7,"count":1}]	14908	delivery	5	14
76576	2020-06-11 08:16:33	2020-06-11	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	30213	delivery	5	46
76577	2020-06-11 08:24:13	2020-06-11	9	[{"id_menu":7,"count":1}]	22788	delivery	5	14
76578	2020-06-11 08:25:38	2020-06-11	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	7139	pick-up	0	24
76579	2020-06-11 08:31:16	2020-06-11	9	[{"id_menu":6,"count":1}]	16342	pick-up	0	9
76580	2020-06-11 08:34:40	2020-06-11	9	[{"id_menu":7,"count":1}]	30259	delivery	5	14
76581	2020-06-11 08:35:37	2020-06-11	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17244	delivery	5	34
76582	2020-06-11 08:37:29	2020-06-11	9	[{"id_menu":6,"count":1}]	30282	delivery	5	14
76583	2020-06-11 08:38:17	2020-06-11	14	[{"id_menu":2,"count":1}]	7994	delivery	5	19
76584	2020-06-11 08:39:20	2020-06-11	12	[{"id_menu":3,"count":1}]	30185	delivery	5	17
76585	2020-06-11 08:43:35	2020-06-11	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1445	pick-up	0	22
76586	2020-06-11 08:45:16	2020-06-11	9	[{"id_menu":6,"count":1}]	30303	delivery	5	14
76587	2020-06-11 08:51:24	2020-06-11	17	[{"id_menu":4,"count":1}]	28765	delivery	5	22
76588	2020-06-11 08:52:39	2020-06-11	9	[{"id_menu":7,"count":1}]	17725	delivery	5	14
76589	2020-06-11 08:55:21	2020-06-11	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	30130	pick-up	0	26
76590	2020-06-11 08:57:17	2020-06-11	8	[{"id_menu":5,"count":1}]	5138	pick-up	0	8
76591	2020-06-11 09:00:08	2020-06-11	17	[{"id_menu":4,"count":1}]	30246	delivery	5	22
76592	2020-06-11 09:03:00	2020-06-11	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	30242	delivery	5	26
76593	2020-06-11 09:03:26	2020-06-11	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2342	delivery	5	31
76594	2020-06-11 09:04:10	2020-06-11	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	30232	delivery	5	40
76595	2020-06-11 09:06:20	2020-06-11	12	[{"id_menu":1,"count":1}]	8757	pick-up	0	12
76596	2020-06-11 09:06:29	2020-06-11	12	[{"id_menu":3,"count":1}]	9565	delivery	5	17
76597	2020-06-11 09:14:59	2020-06-11	12	[{"id_menu":1,"count":2}]	30299	delivery	5	17
76598	2020-06-11 09:20:57	2020-06-11	9	[{"id_menu":7,"count":1}]	30289	delivery	5	14
76599	2020-06-11 09:22:18	2020-06-11	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	30229	delivery	5	31
76600	2020-06-11 09:23:03	2020-06-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30164	delivery	5	23
76601	2020-06-11 09:27:41	2020-06-11	12	[{"id_menu":3,"count":1}]	30188	delivery	5	17
76602	2020-06-11 09:34:54	2020-06-11	17	[{"id_menu":4,"count":1}]	28333	delivery	5	22
76603	2020-06-11 09:36:35	2020-06-11	9	[{"id_menu":7,"count":1}]	21600	delivery	5	14
76604	2020-06-11 09:39:20	2020-06-11	14	[{"id_menu":2,"count":1}]	1736	delivery	5	19
76605	2020-06-11 09:39:26	2020-06-11	8	[{"id_menu":5,"count":2}]	27756	delivery	5	13
76606	2020-06-11 09:42:10	2020-06-11	12	[{"id_menu":3,"count":1}]	447	pick-up	0	12
76607	2020-06-11 09:45:17	2020-06-11	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	22378	delivery	5	22
76608	2020-06-11 09:45:27	2020-06-11	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	30177	delivery	5	25
76609	2020-06-11 09:46:13	2020-06-11	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23648	delivery	5	47
76610	2020-06-11 09:50:49	2020-06-11	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	20031	delivery	5	38
76611	2020-06-11 09:58:26	2020-06-11	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	19711	pick-up	0	31
76612	2020-06-11 10:01:52	2020-06-11	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15713	delivery	5	45
76613	2020-06-11 10:04:23	2020-06-11	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16569	delivery	5	39
76614	2020-06-11 10:05:16	2020-06-11	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	30244	delivery	5	26
76615	2020-06-11 10:06:10	2020-06-11	12	[{"id_menu":3,"count":1}]	4072	pick-up	0	12
76616	2020-06-11 10:11:53	2020-06-11	9	[{"id_menu":7,"count":1}]	30134	delivery	5	14
76617	2020-06-11 10:12:17	2020-06-11	9	[{"id_menu":6,"count":1}]	25071	delivery	5	14
76618	2020-06-11 10:14:36	2020-06-11	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	5930	delivery	5	36
76619	2020-06-11 10:18:03	2020-06-11	12	[{"id_menu":1,"count":1}]	30200	delivery	5	17
76620	2020-06-11 10:19:13	2020-06-11	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	30269	delivery	5	28
76621	2020-06-11 10:22:27	2020-06-11	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30163	delivery	5	52
76622	2020-06-11 10:23:31	2020-06-11	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	19488	delivery	5	25
76623	2020-06-11 10:30:11	2020-06-11	14	[{"id_menu":2,"count":1}]	30233	pick-up	0	14
76624	2020-06-11 10:33:20	2020-06-11	9	[{"id_menu":7,"count":1}]	30183	delivery	5	14
76625	2020-06-11 10:34:06	2020-06-11	12	[{"id_menu":1,"count":1}]	22135	delivery	5	17
76626	2020-06-11 10:35:00	2020-06-11	9	[{"id_menu":6,"count":1}]	15032	delivery	5	14
76627	2020-06-11 10:36:28	2020-06-11	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	24041	pick-up	0	39
76628	2020-06-11 10:36:45	2020-06-11	12	[{"id_menu":1,"count":1}]	24604	delivery	5	17
76629	2020-06-11 10:41:15	2020-06-11	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	27493	delivery	5	22
76630	2020-06-11 10:41:38	2020-06-11	9	[{"id_menu":6,"count":1}]	30240	delivery	5	14
76631	2020-06-11 10:42:05	2020-06-11	8	[{"id_menu":5,"count":1}]	30215	delivery	5	13
76632	2020-06-11 10:45:18	2020-06-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	23156	pick-up	0	23
76633	2020-06-11 10:49:51	2020-06-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22964	delivery	5	23
76634	2020-06-11 10:54:33	2020-06-11	9	[{"id_menu":6,"count":2}]	17507	delivery	5	14
76635	2020-06-11 10:58:32	2020-06-11	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22261	delivery	5	53
76636	2020-06-11 10:59:01	2020-06-11	12	[{"id_menu":1,"count":1}]	24006	delivery	5	17
76637	2020-06-11 11:07:28	2020-06-11	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17005	delivery	5	36
76638	2020-06-11 11:11:37	2020-06-11	17	[{"id_menu":4,"count":1}]	24616	delivery	5	22
76639	2020-06-11 11:13:19	2020-06-11	8	[{"id_menu":5,"count":1}]	18883	delivery	5	13
76640	2020-06-11 11:14:53	2020-06-11	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	21675	delivery	5	26
76641	2020-06-11 11:15:56	2020-06-11	17	[{"id_menu":4,"count":1}]	30308	delivery	5	22
76642	2020-06-11 11:16:33	2020-06-11	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	30196	delivery	5	38
76643	2020-06-11 11:18:39	2020-06-11	14	[{"id_menu":2,"count":1}]	6817	pick-up	0	14
76644	2020-06-11 11:19:28	2020-06-11	9	[{"id_menu":6,"count":4}]	14488	delivery	5	14
76645	2020-06-11 11:20:13	2020-06-11	12	[{"id_menu":1,"count":1}]	27281	pick-up	0	12
76646	2020-06-11 11:22:54	2020-06-11	17	[{"id_menu":4,"count":1}]	26150	pick-up	0	17
76647	2020-06-11 11:25:45	2020-06-11	9	[{"id_menu":7,"count":1}]	30199	delivery	5	14
76648	2020-06-11 11:26:18	2020-06-11	9	[{"id_menu":6,"count":1}]	30129	delivery	5	14
76649	2020-06-11 11:26:46	2020-06-11	14	[{"id_menu":2,"count":1}]	30152	delivery	5	19
76650	2020-06-11 11:27:36	2020-06-11	9	[{"id_menu":6,"count":1}]	24587	delivery	5	14
76651	2020-06-11 11:30:01	2020-06-11	8	[{"id_menu":5,"count":1}]	27628	delivery	5	13
76652	2020-06-11 11:32:42	2020-06-11	17	[{"id_menu":4,"count":1}]	21076	pick-up	0	17
76653	2020-06-11 11:33:19	2020-06-11	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	30166	delivery	5	29
76654	2020-06-11 11:43:51	2020-06-11	9	[{"id_menu":7,"count":1}]	30247	delivery	5	14
76655	2020-06-11 11:46:12	2020-06-11	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	9566	delivery	5	31
76656	2020-06-11 11:50:31	2020-06-11	9	[{"id_menu":6,"count":3}]	11033	delivery	5	14
76657	2020-06-11 11:52:12	2020-06-11	8	[{"id_menu":5,"count":1}]	19026	delivery	5	13
76658	2020-06-11 11:56:12	2020-06-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23836	delivery	5	23
76659	2020-06-11 12:01:58	2020-06-11	14	[{"id_menu":2,"count":1}]	22950	delivery	5	19
76660	2020-06-11 12:06:03	2020-06-11	9	[{"id_menu":6,"count":1}]	20391	pick-up	0	9
76661	2020-06-11 12:07:30	2020-06-11	9	[{"id_menu":6,"count":1}]	27250	delivery	5	14
76662	2020-06-11 12:11:22	2020-06-11	9	[{"id_menu":6,"count":1}]	10176	delivery	5	14
76663	2020-06-11 12:12:36	2020-06-11	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	15386	delivery	5	25
76664	2020-06-11 12:13:09	2020-06-11	17	[{"id_menu":4,"count":2}]	30235	delivery	5	22
76665	2020-06-11 12:19:35	2020-06-11	8	[{"id_menu":5,"count":1}]	24721	delivery	5	13
76666	2020-06-11 12:21:18	2020-06-11	9	[{"id_menu":6,"count":1}]	2567	pick-up	0	9
76667	2020-06-11 12:23:00	2020-06-11	9	[{"id_menu":6,"count":1}]	30220	delivery	5	14
76668	2020-06-11 12:23:44	2020-06-11	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24914	delivery	5	40
76669	2020-06-11 12:23:50	2020-06-11	14	[{"id_menu":2,"count":1}]	13445	delivery	5	19
76670	2020-06-11 12:29:57	2020-06-11	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	18353	delivery	5	36
76671	2020-06-11 12:32:34	2020-06-11	14	[{"id_menu":2,"count":2}]	30277	delivery	5	19
76672	2020-06-11 12:34:04	2020-06-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1315	delivery	5	22
76673	2020-06-11 12:35:03	2020-06-11	12	[{"id_menu":1,"count":1}]	17711	delivery	5	17
76674	2020-06-11 12:36:59	2020-06-11	12	[{"id_menu":3,"count":1}]	23024	delivery	5	17
76675	2020-06-11 12:38:30	2020-06-11	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30146	delivery	5	40
76676	2020-06-11 12:41:09	2020-06-11	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	395	pick-up	0	29
76677	2020-06-11 12:45:55	2020-06-11	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	23111	pick-up	0	22
76678	2020-06-11 12:49:01	2020-06-11	9	[{"id_menu":7,"count":1}]	7858	delivery	5	14
76679	2020-06-11 12:51:10	2020-06-11	12	[{"id_menu":3,"count":1}]	14165	delivery	5	17
76680	2020-06-11 12:52:55	2020-06-11	9	[{"id_menu":6,"count":1}]	16818	delivery	5	14
76681	2020-06-11 12:55:17	2020-06-11	9	[{"id_menu":6,"count":1}]	14764	delivery	5	14
76682	2020-06-11 12:55:30	2020-06-11	14	[{"id_menu":2,"count":1}]	4248	delivery	5	19
76683	2020-06-11 12:59:21	2020-06-11	8	[{"id_menu":5,"count":1}]	21651	delivery	5	13
76684	2020-06-11 13:04:26	2020-06-11	14	[{"id_menu":2,"count":1}]	22214	pick-up	0	14
76685	2020-06-11 13:06:22	2020-06-11	9	[{"id_menu":7,"count":1}]	28151	pick-up	0	9
76686	2020-06-11 13:07:04	2020-06-11	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1989	pick-up	0	26
76687	2020-06-11 13:10:08	2020-06-11	17	[{"id_menu":4,"count":1}]	5097	delivery	5	22
76688	2020-06-11 13:14:25	2020-06-11	12	[{"id_menu":1,"count":1}]	30126	delivery	5	17
76689	2020-06-11 13:19:54	2020-06-11	9	[{"id_menu":6,"count":1}]	4976	pick-up	0	9
76690	2020-06-11 13:24:36	2020-06-11	12	[{"id_menu":1,"count":1}]	30168	delivery	5	17
76691	2020-06-11 13:24:40	2020-06-11	14	[{"id_menu":2,"count":1}]	16959	pick-up	0	14
76692	2020-06-11 13:27:02	2020-06-11	8	[{"id_menu":5,"count":1}]	30275	delivery	5	13
76693	2020-06-11 13:27:57	2020-06-11	14	[{"id_menu":2,"count":1}]	30294	delivery	5	19
76694	2020-06-11 13:29:16	2020-06-11	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	29974	pick-up	0	21
76695	2020-06-11 13:30:47	2020-06-11	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	620	delivery	5	27
76696	2020-06-11 13:33:06	2020-06-11	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	30150	delivery	5	31
76697	2020-06-11 13:33:07	2020-06-11	9	[{"id_menu":6,"count":3}]	30210	delivery	5	14
76698	2020-06-11 13:38:26	2020-06-11	9	[{"id_menu":7,"count":1}]	15809	delivery	5	14
76699	2020-06-11 13:38:45	2020-06-11	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	30197	delivery	5	27
76700	2020-06-11 13:39:28	2020-06-11	12	[{"id_menu":3,"count":1}]	6090	pick-up	0	12
76701	2020-06-11 13:44:27	2020-06-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	30149	delivery	5	22
76702	2020-06-11 13:45:20	2020-06-11	12	[{"id_menu":1,"count":1}]	15969	delivery	5	17
76703	2020-06-11 13:49:56	2020-06-11	8	[{"id_menu":5,"count":1}]	3198	delivery	5	13
76704	2020-06-11 13:51:53	2020-06-11	12	[{"id_menu":1,"count":1}]	30301	pick-up	0	12
76705	2020-06-11 13:52:33	2020-06-11	9	[{"id_menu":7,"count":3}]	25773	delivery	5	14
76706	2020-06-11 13:52:35	2020-06-11	9	[{"id_menu":6,"count":1}]	11265	delivery	5	14
76707	2020-06-11 13:53:30	2020-06-11	9	[{"id_menu":6,"count":1}]	30272	delivery	5	14
76708	2020-06-11 13:53:48	2020-06-11	8	[{"id_menu":5,"count":1}]	29125	delivery	5	13
76709	2020-06-11 13:58:42	2020-06-11	9	[{"id_menu":7,"count":1}]	30142	pick-up	0	9
76710	2020-06-11 13:59:32	2020-06-11	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	30305	delivery	5	39
76711	2020-06-11 14:03:01	2020-06-11	12	[{"id_menu":1,"count":1}]	329	delivery	5	17
76712	2020-06-11 14:04:53	2020-06-11	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	14826	delivery	5	31
76713	2020-06-11 14:09:47	2020-06-11	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2426	delivery	5	26
76714	2020-06-11 14:10:13	2020-06-11	12	[{"id_menu":3,"count":1}]	30147	delivery	5	17
76715	2020-06-11 14:23:08	2020-06-11	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	6246	pick-up	0	26
76716	2020-06-11 14:26:50	2020-06-11	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	30207	delivery	5	43
76717	2020-06-11 14:30:54	2020-06-11	9	[{"id_menu":7,"count":2}]	1025	delivery	5	14
76718	2020-06-11 14:37:21	2020-06-11	12	[{"id_menu":1,"count":1}]	14525	delivery	5	17
76719	2020-06-11 14:38:36	2020-06-11	12	[{"id_menu":1,"count":1}]	20531	delivery	5	17
76720	2020-06-11 14:39:33	2020-06-11	12	[{"id_menu":3,"count":1}]	29236	delivery	5	17
76721	2020-06-11 14:43:06	2020-06-11	12	[{"id_menu":3,"count":1}]	13373	delivery	5	17
76722	2020-06-11 14:47:25	2020-06-11	17	[{"id_menu":4,"count":1}]	27	delivery	5	22
76723	2020-06-11 14:50:15	2020-06-11	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30144	delivery	5	31
76724	2020-06-11 14:50:36	2020-06-11	8	[{"id_menu":5,"count":1}]	30250	delivery	5	13
76725	2020-06-11 15:08:14	2020-06-11	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	21868	delivery	5	26
76726	2020-06-11 15:09:20	2020-06-11	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	18351	delivery	5	31
76727	2020-06-11 15:13:40	2020-06-11	9	[{"id_menu":7,"count":1}]	30300	delivery	5	14
76728	2020-06-11 15:15:14	2020-06-11	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15546	delivery	5	37
76729	2020-06-11 15:16:02	2020-06-11	14	[{"id_menu":2,"count":1}]	30260	delivery	5	19
76730	2020-06-11 15:16:15	2020-06-11	9	[{"id_menu":6,"count":1}]	11716	delivery	5	14
76731	2020-06-11 15:20:46	2020-06-11	12	[{"id_menu":3,"count":1}]	30254	delivery	5	17
76732	2020-06-11 15:25:13	2020-06-11	9	[{"id_menu":6,"count":1}]	27207	delivery	5	14
76733	2020-06-11 15:27:03	2020-06-11	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	28971	delivery	5	31
76734	2020-06-11 15:31:42	2020-06-11	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	27545	delivery	5	36
76735	2020-06-11 15:33:23	2020-06-11	12	[{"id_menu":1,"count":1}]	15681	delivery	5	17
76736	2020-06-11 15:33:34	2020-06-11	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	30252	delivery	5	26
76737	2020-06-11 15:34:38	2020-06-11	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	30143	pick-up	0	26
76738	2020-06-11 15:34:59	2020-06-11	17	[{"id_menu":4,"count":1}]	30216	delivery	5	22
76739	2020-06-11 15:35:14	2020-06-11	9	[{"id_menu":6,"count":1}]	30178	delivery	5	14
76740	2020-06-11 15:37:57	2020-06-11	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	25827	pick-up	0	26
76741	2020-06-11 15:39:59	2020-06-11	8	[{"id_menu":5,"count":1}]	6201	delivery	5	13
76742	2020-06-11 15:40:02	2020-06-11	17	[{"id_menu":4,"count":1}]	30138	delivery	5	22
76743	2020-06-11 15:41:49	2020-06-11	12	[{"id_menu":1,"count":1}]	739	delivery	5	17
76744	2020-06-11 15:42:10	2020-06-11	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17717	delivery	5	31
76745	2020-06-11 15:43:25	2020-06-11	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13856	delivery	5	31
76746	2020-06-11 15:47:08	2020-06-11	9	[{"id_menu":7,"count":1}]	12060	pick-up	0	9
76747	2020-06-11 15:48:49	2020-06-11	12	[{"id_menu":1,"count":1}]	30203	delivery	5	17
76748	2020-06-11 15:48:50	2020-06-11	9	[{"id_menu":7,"count":1}]	27393	delivery	5	14
76749	2020-06-11 15:49:02	2020-06-11	14	[{"id_menu":2,"count":1}]	19125	pick-up	0	14
76750	2020-06-11 15:55:09	2020-06-11	9	[{"id_menu":7,"count":1}]	3229	delivery	5	14
76751	2020-06-11 15:55:53	2020-06-11	14	[{"id_menu":2,"count":1}]	1114	delivery	5	19
76752	2020-06-11 15:56:38	2020-06-11	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	12666	delivery	5	30
76753	2020-06-11 15:58:47	2020-06-11	9	[{"id_menu":6,"count":1}]	26185	delivery	5	14
76754	2020-06-11 16:00:34	2020-06-11	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1632	pick-up	0	25
76755	2020-06-11 16:02:54	2020-06-11	9	[{"id_menu":7,"count":1}]	30131	delivery	5	14
76756	2020-06-11 16:04:26	2020-06-11	8	[{"id_menu":5,"count":1}]	30280	delivery	5	13
76757	2020-06-11 16:05:08	2020-06-11	17	[{"id_menu":4,"count":1}]	2797	delivery	5	22
76758	2020-06-11 16:06:06	2020-06-11	17	[{"id_menu":4,"count":1}]	1548	pick-up	0	17
76759	2020-06-11 16:12:07	2020-06-11	9	[{"id_menu":7,"count":1}]	30222	delivery	5	14
76760	2020-06-11 16:13:14	2020-06-11	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	7279	delivery	5	34
76761	2020-06-11 16:16:49	2020-06-11	17	[{"id_menu":4,"count":1}]	8628	delivery	5	22
76762	2020-06-11 16:17:17	2020-06-11	9	[{"id_menu":7,"count":1}]	30162	delivery	5	14
76763	2020-06-11 16:20:17	2020-06-11	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	16430	pick-up	0	26
76764	2020-06-11 16:22:22	2020-06-11	12	[{"id_menu":1,"count":1}]	30293	delivery	5	17
76765	2020-06-11 16:22:48	2020-06-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	17966	delivery	5	23
76766	2020-06-11 16:23:45	2020-06-11	17	[{"id_menu":4,"count":1}]	30208	delivery	5	22
76767	2020-06-11 16:24:09	2020-06-11	14	[{"id_menu":2,"count":1}]	5125	delivery	5	19
76768	2020-06-11 16:24:49	2020-06-11	8	[{"id_menu":5,"count":2}]	19188	delivery	5	13
76769	2020-06-11 16:26:43	2020-06-11	9	[{"id_menu":7,"count":1}]	8713	delivery	5	14
76770	2020-06-11 16:29:15	2020-06-11	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	19965	delivery	5	31
76771	2020-06-11 16:30:58	2020-06-11	9	[{"id_menu":7,"count":1}]	27921	delivery	5	14
76772	2020-06-11 16:31:09	2020-06-11	9	[{"id_menu":6,"count":1}]	28551	pick-up	0	9
76773	2020-06-11 16:32:28	2020-06-11	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	23651	delivery	5	38
76774	2020-06-11 16:40:31	2020-06-11	9	[{"id_menu":6,"count":1}]	7840	delivery	5	14
76775	2020-06-11 16:41:34	2020-06-11	9	[{"id_menu":6,"count":1}]	18149	delivery	5	14
76776	2020-06-11 16:42:12	2020-06-11	12	[{"id_menu":1,"count":1}]	13477	pick-up	0	12
76777	2020-06-11 16:44:35	2020-06-11	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	7927	pick-up	0	21
76778	2020-06-11 16:46:11	2020-06-11	8	[{"id_menu":5,"count":1}]	12066	delivery	5	13
76779	2020-06-11 16:50:13	2020-06-11	9	[{"id_menu":7,"count":1}]	22536	delivery	5	14
76780	2020-06-11 16:53:15	2020-06-11	9	[{"id_menu":6,"count":1}]	30180	delivery	5	14
76781	2020-06-11 16:54:05	2020-06-11	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	304	delivery	5	43
76782	2020-06-11 16:57:55	2020-06-11	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	30182	delivery	5	31
76783	2020-06-11 16:58:14	2020-06-11	17	[{"id_menu":4,"count":2}]	30137	delivery	5	22
76784	2020-06-11 16:58:47	2020-06-11	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	30141	delivery	5	26
76785	2020-06-11 17:00:22	2020-06-11	8	[{"id_menu":5,"count":1}]	30248	delivery	5	13
76786	2020-06-11 17:01:09	2020-06-11	9	[{"id_menu":7,"count":1}]	22298	delivery	5	14
76787	2020-06-11 17:02:50	2020-06-11	9	[{"id_menu":7,"count":1}]	18654	delivery	5	14
76788	2020-06-11 17:10:13	2020-06-11	14	[{"id_menu":2,"count":1}]	29641	delivery	5	19
76789	2020-06-11 17:11:11	2020-06-11	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	30184	delivery	5	31
76790	2020-06-11 17:14:06	2020-06-11	14	[{"id_menu":2,"count":1}]	27557	pick-up	0	14
76791	2020-06-11 17:14:55	2020-06-11	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1706	pick-up	0	29
76792	2020-06-11 17:15:50	2020-06-11	9	[{"id_menu":7,"count":1}]	76	pick-up	0	9
76793	2020-06-11 17:20:40	2020-06-11	9	[{"id_menu":6,"count":1}]	6326	delivery	5	14
76794	2020-06-11 17:21:25	2020-06-11	8	[{"id_menu":5,"count":1}]	2995	delivery	5	13
76795	2020-06-11 17:22:37	2020-06-11	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	534	pick-up	0	29
76796	2020-06-11 17:24:50	2020-06-11	9	[{"id_menu":7,"count":1}]	5637	delivery	5	14
76797	2020-06-11 17:26:30	2020-06-11	9	[{"id_menu":6,"count":1}]	22704	delivery	5	14
76798	2020-06-11 17:34:05	2020-06-11	14	[{"id_menu":2,"count":1}]	3961	delivery	5	19
76799	2020-06-11 17:40:09	2020-06-11	8	[{"id_menu":5,"count":1}]	30165	delivery	5	13
76800	2020-06-11 17:41:33	2020-06-11	9	[{"id_menu":7,"count":1}]	20161	delivery	5	14
76801	2020-06-11 17:46:10	2020-06-11	8	[{"id_menu":5,"count":1}]	3458	pick-up	0	8
76802	2020-06-11 17:47:29	2020-06-11	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	28019	delivery	5	34
76803	2020-06-11 17:49:41	2020-06-11	14	[{"id_menu":2,"count":1}]	2776	delivery	5	19
76804	2020-06-11 17:49:42	2020-06-11	14	[{"id_menu":2,"count":1}]	30238	delivery	5	19
76805	2020-06-11 17:54:45	2020-06-11	17	[{"id_menu":4,"count":1}]	30173	delivery	5	22
76806	2020-06-11 17:57:04	2020-06-11	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11043	pick-up	0	38
76807	2020-06-11 17:59:08	2020-06-11	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	30139	delivery	5	30
76808	2020-06-11 17:59:26	2020-06-11	17	[{"id_menu":4,"count":1}]	20562	delivery	5	22
76809	2020-06-11 18:01:04	2020-06-11	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	9560	delivery	5	31
76810	2020-06-11 18:01:40	2020-06-11	8	[{"id_menu":5,"count":1}]	29399	delivery	5	13
76811	2020-06-11 18:04:10	2020-06-11	9	[{"id_menu":7,"count":1}]	15709	delivery	5	14
76812	2020-06-11 18:10:57	2020-06-11	9	[{"id_menu":6,"count":1}]	30284	delivery	5	14
76813	2020-06-11 18:11:43	2020-06-11	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10235	delivery	5	43
76814	2020-06-11 18:12:13	2020-06-11	12	[{"id_menu":1,"count":1}]	420	pick-up	0	12
76815	2020-06-11 18:14:38	2020-06-11	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2080	delivery	5	25
76816	2020-06-11 18:17:12	2020-06-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15552	pick-up	0	17
76817	2020-06-11 18:32:52	2020-06-11	8	[{"id_menu":5,"count":1}]	30202	delivery	5	13
76818	2020-06-11 18:35:22	2020-06-11	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	30219	delivery	5	39
76819	2020-06-11 18:35:38	2020-06-11	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	14929	delivery	5	26
76820	2020-06-11 18:37:46	2020-06-11	9	[{"id_menu":7,"count":1}]	2602	pick-up	0	9
76821	2020-06-11 18:44:09	2020-06-11	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	30278	delivery	5	28
76822	2020-06-11 18:46:21	2020-06-11	14	[{"id_menu":2,"count":1}]	30286	delivery	5	19
76823	2020-06-11 18:54:14	2020-06-11	14	[{"id_menu":2,"count":2}]	22316	delivery	5	19
76824	2020-06-11 18:56:25	2020-06-11	9	[{"id_menu":6,"count":1}]	30070	delivery	5	14
76825	2020-06-11 18:56:44	2020-06-11	14	[{"id_menu":2,"count":1}]	11089	delivery	5	19
76826	2020-06-11 18:58:18	2020-06-11	14	[{"id_menu":2,"count":1}]	22274	delivery	5	19
76827	2020-06-11 18:58:58	2020-06-11	9	[{"id_menu":7,"count":1}]	24742	delivery	5	14
76828	2020-06-11 19:02:16	2020-06-11	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	30224	delivery	5	57
76829	2020-06-11 19:04:39	2020-06-11	9	[{"id_menu":6,"count":1}]	30253	delivery	5	14
76830	2020-06-11 19:07:16	2020-06-11	12	[{"id_menu":3,"count":1}]	30292	delivery	5	17
76831	2020-06-11 19:07:18	2020-06-11	12	[{"id_menu":3,"count":1}]	260	delivery	5	17
76832	2020-06-11 19:09:34	2020-06-11	9	[{"id_menu":6,"count":1}]	20883	pick-up	0	9
76833	2020-06-11 19:10:19	2020-06-11	9	[{"id_menu":7,"count":1}]	21131	delivery	5	14
76834	2020-06-11 19:11:13	2020-06-11	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	3471	delivery	5	31
76835	2020-06-11 19:11:27	2020-06-11	8	[{"id_menu":5,"count":1}]	3368	delivery	5	13
76836	2020-06-11 19:16:17	2020-06-11	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27925	delivery	5	45
76837	2020-06-11 19:17:49	2020-06-11	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7118	pick-up	0	35
76838	2020-06-11 19:24:51	2020-06-11	14	[{"id_menu":2,"count":1}]	678	delivery	5	19
76839	2020-06-11 19:26:25	2020-06-11	9	[{"id_menu":6,"count":1}]	4969	delivery	5	14
76840	2020-06-11 19:33:20	2020-06-11	9	[{"id_menu":7,"count":1}]	583	delivery	5	14
76841	2020-06-11 19:34:24	2020-06-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	30261	delivery	5	22
76842	2020-06-11 19:34:26	2020-06-11	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	9175	delivery	5	43
76843	2020-06-11 19:37:03	2020-06-11	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	2198	pick-up	0	21
76844	2020-06-11 19:38:04	2020-06-11	8	[{"id_menu":5,"count":1}]	30179	delivery	5	13
76845	2020-06-11 19:40:23	2020-06-11	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13010	delivery	5	53
76846	2020-06-11 19:45:19	2020-06-11	14	[{"id_menu":2,"count":1}]	8600	delivery	5	19
76847	2020-06-11 19:48:12	2020-06-11	12	[{"id_menu":1,"count":1}]	3116	pick-up	0	12
76848	2020-06-11 19:49:16	2020-06-11	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	5668	pick-up	0	31
76849	2020-06-11 19:50:32	2020-06-11	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	25367	delivery	5	36
76850	2020-06-11 19:50:38	2020-06-11	17	[{"id_menu":4,"count":1}]	30298	delivery	5	22
76851	2020-06-11 19:51:11	2020-06-11	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	30205	delivery	5	26
76852	2020-06-11 19:54:07	2020-06-11	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19906	delivery	5	40
76853	2020-06-11 19:56:43	2020-06-11	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11806	delivery	5	22
76854	2020-06-11 19:57:46	2020-06-11	9	[{"id_menu":7,"count":1}]	8701	delivery	5	14
76855	2020-06-11 19:57:55	2020-06-11	17	[{"id_menu":4,"count":1}]	9398	delivery	5	22
76856	2020-06-11 19:58:36	2020-06-11	9	[{"id_menu":7,"count":1}]	30121	delivery	5	14
76857	2020-06-11 20:01:57	2020-06-11	9	[{"id_menu":7,"count":1}]	564	pick-up	0	9
76858	2020-06-11 20:02:44	2020-06-11	14	[{"id_menu":2,"count":1}]	30306	pick-up	0	14
76859	2020-06-11 20:03:04	2020-06-11	14	[{"id_menu":2,"count":1}]	3509	pick-up	0	14
76860	2020-06-11 20:04:52	2020-06-11	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	30273	delivery	5	22
76861	2020-06-11 20:06:46	2020-06-11	17	[{"id_menu":4,"count":1}]	30204	delivery	5	22
76862	2020-06-11 20:09:03	2020-06-11	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	30198	delivery	5	40
76863	2020-06-11 20:10:41	2020-06-11	8	[{"id_menu":5,"count":1}]	24631	delivery	5	13
76864	2020-06-11 20:18:59	2020-06-11	14	[{"id_menu":2,"count":1}]	7700	delivery	5	19
76865	2020-06-11 20:25:30	2020-06-11	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16989	delivery	5	34
76866	2020-06-11 20:25:37	2020-06-11	9	[{"id_menu":6,"count":1}]	9833	delivery	5	14
76867	2020-06-11 20:30:21	2020-06-11	9	[{"id_menu":6,"count":1}]	12200	delivery	5	14
76868	2020-06-11 20:30:41	2020-06-11	14	[{"id_menu":2,"count":1}]	122	pick-up	0	14
76869	2020-06-11 20:30:55	2020-06-11	9	[{"id_menu":6,"count":1}]	18070	delivery	5	14
76870	2020-06-11 20:31:33	2020-06-11	14	[{"id_menu":2,"count":1}]	19171	delivery	5	19
76871	2020-06-11 20:36:10	2020-06-11	14	[{"id_menu":2,"count":1}]	12546	delivery	5	19
76872	2020-06-11 20:39:30	2020-06-11	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	30281	pick-up	0	26
76873	2020-06-11 20:43:15	2020-06-11	17	[{"id_menu":4,"count":1}]	12527	delivery	5	22
76874	2020-06-11 20:48:22	2020-06-11	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2945	delivery	5	31
76875	2020-06-11 20:49:52	2020-06-11	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	23243	delivery	5	45
76876	2020-06-11 21:06:21	2020-06-11	9	[{"id_menu":7,"count":1}]	4284	delivery	5	14
76877	2020-06-11 21:07:09	2020-06-11	8	[{"id_menu":5,"count":1}]	21388	delivery	5	13
76878	2020-06-11 21:08:50	2020-06-11	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	17583	delivery	5	30
76879	2020-06-11 21:09:19	2020-06-11	17	[{"id_menu":4,"count":1}]	2731	pick-up	0	17
76880	2020-06-11 21:10:29	2020-06-11	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24794	delivery	5	22
76881	2020-06-11 21:13:46	2020-06-11	14	[{"id_menu":2,"count":1}]	10553	delivery	5	19
76882	2020-06-11 21:13:56	2020-06-11	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	30153	pick-up	0	26
76883	2020-06-11 21:14:04	2020-06-11	9	[{"id_menu":7,"count":2}]	30206	delivery	5	14
76884	2020-06-11 21:19:25	2020-06-11	9	[{"id_menu":6,"count":1}]	30161	delivery	5	14
76885	2020-06-11 21:19:36	2020-06-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21532	delivery	5	22
76886	2020-06-11 21:21:43	2020-06-11	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	10258	delivery	5	37
76887	2020-06-11 21:24:31	2020-06-11	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	4295	pick-up	0	38
76888	2020-06-11 21:26:28	2020-06-11	8	[{"id_menu":5,"count":1}]	30258	delivery	5	13
76889	2020-06-11 21:28:11	2020-06-11	14	[{"id_menu":2,"count":1}]	30234	delivery	5	19
76890	2020-06-11 21:31:21	2020-06-11	17	[{"id_menu":4,"count":2}]	12623	pick-up	0	17
76891	2020-06-11 21:34:23	2020-06-11	9	[{"id_menu":6,"count":2}]	16643	delivery	5	14
76892	2020-06-11 21:36:51	2020-06-11	14	[{"id_menu":2,"count":2}]	25858	delivery	5	19
76893	2020-06-11 21:41:14	2020-06-11	9	[{"id_menu":6,"count":1}]	1834	pick-up	0	9
76894	2020-06-11 21:41:55	2020-06-11	9	[{"id_menu":6,"count":1}]	30212	delivery	5	14
76895	2020-06-11 21:42:34	2020-06-11	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	28579	delivery	5	40
76896	2020-06-11 21:47:09	2020-06-11	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":2}]	22648	delivery	5	22
76897	2020-06-11 21:48:04	2020-06-11	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	30135	delivery	5	43
76898	2020-06-11 21:55:58	2020-06-11	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18840	delivery	5	40
76899	2020-06-11 21:57:14	2020-06-11	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":3}]	4223	pick-up	0	21
76900	2020-06-11 22:00:32	2020-06-11	9	[{"id_menu":7,"count":1}]	4681	delivery	5	14
76901	2020-06-11 22:00:43	2020-06-11	9	[{"id_menu":7,"count":1}]	11735	delivery	5	14
76902	2020-06-11 22:00:55	2020-06-11	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	6674	delivery	5	40
76903	2020-06-11 22:01:11	2020-06-11	9	[{"id_menu":7,"count":1}]	28745	delivery	5	14
76904	2020-06-11 22:03:00	2020-06-11	9	[{"id_menu":6,"count":1}]	30189	delivery	5	14
76905	2020-06-11 22:08:19	2020-06-11	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	9001	delivery	5	28
76906	2020-06-11 22:09:51	2020-06-11	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7550	pick-up	0	23
76907	2020-06-11 22:10:02	2020-06-11	9	[{"id_menu":7,"count":2}]	30123	pick-up	0	9
76908	2020-06-11 22:12:37	2020-06-11	8	[{"id_menu":5,"count":2}]	24779	delivery	5	13
76909	2020-06-11 22:15:50	2020-06-11	8	[{"id_menu":5,"count":1}]	3324	pick-up	0	8
76910	2020-06-11 22:17:05	2020-06-11	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	27012	delivery	5	28
76911	2020-06-11 22:18:13	2020-06-11	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	7280	delivery	5	28
76912	2020-06-11 22:20:16	2020-06-11	9	[{"id_menu":6,"count":1}]	5770	pick-up	0	9
76913	2020-06-11 22:23:58	2020-06-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19000	delivery	5	22
76914	2020-06-11 22:24:01	2020-06-11	9	[{"id_menu":7,"count":1}]	30151	delivery	5	14
76915	2020-06-11 22:24:57	2020-06-11	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4797	delivery	5	43
76916	2020-06-11 22:29:58	2020-06-11	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	30175	delivery	5	26
76917	2020-06-11 22:31:52	2020-06-11	9	[{"id_menu":6,"count":1}]	23913	delivery	5	14
76918	2020-06-11 22:33:36	2020-06-11	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	30236	delivery	5	57
76919	2020-06-11 22:42:02	2020-06-11	9	[{"id_menu":6,"count":1}]	356	delivery	5	14
76920	2020-06-11 22:42:16	2020-06-11	9	[{"id_menu":6,"count":1}]	30295	delivery	5	14
76921	2020-06-11 22:42:54	2020-06-11	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30169	delivery	5	31
76922	2020-06-11 22:44:38	2020-06-11	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2858	delivery	5	31
76923	2020-06-11 22:46:14	2020-06-11	9	[{"id_menu":6,"count":1}]	265	delivery	5	14
76924	2020-06-11 22:46:45	2020-06-11	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28348	delivery	5	39
76925	2020-06-11 22:48:35	2020-06-11	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	30307	delivery	5	52
76926	2020-06-11 22:49:49	2020-06-11	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	531	delivery	5	26
76927	2020-06-11 22:52:31	2020-06-11	8	[{"id_menu":5,"count":2}]	26860	pick-up	0	8
76928	2020-06-11 22:52:38	2020-06-11	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25842	delivery	5	35
76929	2020-06-11 23:01:08	2020-06-11	14	[{"id_menu":2,"count":1}]	15873	pick-up	0	14
76930	2020-06-11 23:10:46	2020-06-11	14	[{"id_menu":2,"count":1}]	8657	pick-up	0	14
76931	2020-06-11 23:11:38	2020-06-11	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11976	delivery	5	43
76932	2020-06-11 23:11:40	2020-06-11	8	[{"id_menu":5,"count":1}]	4277	delivery	5	13
76933	2020-06-11 23:12:24	2020-06-11	30	[{"id_menu":1,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5140	delivery	5	35
76934	2020-06-11 23:13:06	2020-06-11	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	30193	delivery	5	30
76935	2020-06-11 23:13:11	2020-06-11	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	6854	delivery	5	26
76936	2020-06-11 23:13:24	2020-06-11	9	[{"id_menu":7,"count":1}]	12565	delivery	5	14
76937	2020-06-11 23:26:46	2020-06-11	12	[{"id_menu":3,"count":1}]	26872	pick-up	0	12
76938	2020-06-11 23:26:53	2020-06-11	17	[{"id_menu":4,"count":1}]	30154	delivery	5	22
76939	2020-06-11 23:30:18	2020-06-11	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	21939	delivery	5	28
76940	2020-06-11 23:32:29	2020-06-11	9	[{"id_menu":6,"count":1}]	30209	pick-up	0	9
76941	2020-06-11 23:34:20	2020-06-11	12	[{"id_menu":1,"count":1}]	25852	pick-up	0	12
76942	2020-06-11 23:41:03	2020-06-11	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	9575	delivery	5	36
76943	2020-06-11 23:41:09	2020-06-11	14	[{"id_menu":2,"count":1}]	16132	delivery	5	19
76944	2020-06-11 23:44:55	2020-06-11	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	20738	pick-up	0	38
76945	2020-06-11 23:49:31	2020-06-11	17	[{"id_menu":4,"count":1}]	2050	pick-up	0	17
76946	2020-06-11 23:57:39	2020-06-11	8	[{"id_menu":5,"count":1}]	477	pick-up	0	8
76947	2020-06-11 23:59:40	2020-06-11	14	[{"id_menu":2,"count":2}]	3868	pick-up	0	14
76948	2020-06-12 00:04:07	2020-06-12	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	489	pick-up	0	23
76949	2020-06-12 00:04:52	2020-06-12	9	[{"id_menu":6,"count":1}]	30449	delivery	5	14
76950	2020-06-12 00:05:08	2020-06-12	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	802	pick-up	0	21
76951	2020-06-12 00:07:40	2020-06-12	14	[{"id_menu":2,"count":1}]	20724	delivery	5	19
76952	2020-06-12 00:11:25	2020-06-12	17	[{"id_menu":4,"count":1}]	30494	delivery	5	22
76953	2020-06-12 00:21:45	2020-06-12	14	[{"id_menu":2,"count":1}]	30320	delivery	5	19
76954	2020-06-12 00:22:47	2020-06-12	9	[{"id_menu":6,"count":1}]	21752	delivery	5	14
76955	2020-06-12 00:23:24	2020-06-12	17	[{"id_menu":4,"count":1}]	15829	delivery	5	22
76956	2020-06-12 00:26:50	2020-06-12	17	[{"id_menu":4,"count":1}]	25346	pick-up	0	17
76957	2020-06-12 00:27:45	2020-06-12	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	27665	delivery	5	40
76958	2020-06-12 00:31:31	2020-06-12	17	[{"id_menu":4,"count":1}]	3234	delivery	5	22
76959	2020-06-12 00:31:36	2020-06-12	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	16952	delivery	5	27
76960	2020-06-12 00:39:55	2020-06-12	12	[{"id_menu":3,"count":1}]	13694	delivery	5	17
76961	2020-06-12 00:44:01	2020-06-12	17	[{"id_menu":4,"count":1}]	21	delivery	5	22
76962	2020-06-12 00:45:28	2020-06-12	9	[{"id_menu":7,"count":1}]	12272	delivery	5	14
76963	2020-06-12 00:49:57	2020-06-12	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	30370	delivery	5	39
76964	2020-06-12 00:55:57	2020-06-12	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	30348	delivery	5	25
76965	2020-06-12 00:56:52	2020-06-12	9	[{"id_menu":6,"count":1}]	18491	delivery	5	14
76966	2020-06-12 00:57:29	2020-06-12	8	[{"id_menu":5,"count":1}]	10872	delivery	5	13
76967	2020-06-12 01:00:03	2020-06-12	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10180	delivery	5	36
76968	2020-06-12 01:01:29	2020-06-12	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21245	delivery	5	31
76969	2020-06-12 01:07:35	2020-06-12	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	30468	delivery	5	26
76970	2020-06-12 01:08:42	2020-06-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28045	delivery	5	22
76971	2020-06-12 01:15:40	2020-06-12	9	[{"id_menu":7,"count":1}]	5616	pick-up	0	9
76972	2020-06-12 01:21:36	2020-06-12	8	[{"id_menu":5,"count":1}]	18287	delivery	5	13
76973	2020-06-12 01:26:14	2020-06-12	14	[{"id_menu":2,"count":1}]	9810	delivery	5	19
76974	2020-06-12 01:35:36	2020-06-12	14	[{"id_menu":2,"count":1}]	9358	delivery	5	19
76975	2020-06-12 01:35:55	2020-06-12	9	[{"id_menu":7,"count":1}]	26712	delivery	5	14
76976	2020-06-12 01:51:15	2020-06-12	8	[{"id_menu":5,"count":1}]	11284	delivery	5	13
76977	2020-06-12 01:58:06	2020-06-12	9	[{"id_menu":6,"count":1}]	7998	delivery	5	14
76978	2020-06-12 01:58:18	2020-06-12	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	6988	delivery	5	40
76979	2020-06-12 02:01:50	2020-06-12	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	29484	delivery	5	26
76980	2020-06-12 02:04:05	2020-06-12	14	[{"id_menu":2,"count":1}]	30484	delivery	5	19
76981	2020-06-12 02:08:36	2020-06-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24719	delivery	5	22
76982	2020-06-12 02:10:06	2020-06-12	17	[{"id_menu":4,"count":1}]	30461	delivery	5	22
76983	2020-06-12 02:10:20	2020-06-12	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	30328	delivery	5	26
76984	2020-06-12 02:10:32	2020-06-12	9	[{"id_menu":7,"count":1}]	30453	delivery	5	14
76985	2020-06-12 02:13:40	2020-06-12	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	30380	pick-up	0	20
76986	2020-06-12 02:14:30	2020-06-12	12	[{"id_menu":1,"count":1}]	8815	delivery	5	17
76987	2020-06-12 02:15:10	2020-06-12	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	123	pick-up	0	37
76988	2020-06-12 02:19:15	2020-06-12	9	[{"id_menu":6,"count":1}]	12105	delivery	5	14
76989	2020-06-12 02:22:56	2020-06-12	8	[{"id_menu":5,"count":1}]	30372	delivery	5	13
76990	2020-06-12 02:24:49	2020-06-12	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	5760	pick-up	0	34
76991	2020-06-12 02:37:12	2020-06-12	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	30489	pick-up	0	26
76992	2020-06-12 02:43:31	2020-06-12	9	[{"id_menu":6,"count":1}]	30335	delivery	5	14
76993	2020-06-12 02:45:54	2020-06-12	14	[{"id_menu":2,"count":1}]	1893	delivery	5	19
76994	2020-06-12 02:49:47	2020-06-12	12	[{"id_menu":1,"count":1}]	2426	pick-up	0	12
76995	2020-06-12 02:49:59	2020-06-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	23954	pick-up	0	23
76996	2020-06-12 02:51:26	2020-06-12	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17587	delivery	5	22
76997	2020-06-12 02:53:22	2020-06-12	12	[{"id_menu":1,"count":1}]	30422	delivery	5	17
76998	2020-06-12 02:53:49	2020-06-12	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	11932	delivery	5	26
76999	2020-06-12 02:54:14	2020-06-12	12	[{"id_menu":3,"count":1}]	22512	delivery	5	17
77000	2020-06-12 02:54:18	2020-06-12	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	29647	delivery	5	28
77001	2020-06-12 02:55:56	2020-06-12	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	30343	delivery	5	43
77002	2020-06-12 02:58:53	2020-06-12	46	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	30445	delivery	5	51
77003	2020-06-12 03:04:13	2020-06-12	9	[{"id_menu":7,"count":1}]	30356	delivery	5	14
77004	2020-06-12 03:08:15	2020-06-12	14	[{"id_menu":2,"count":1}]	4050	delivery	5	19
77005	2020-06-12 03:11:56	2020-06-12	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26232	pick-up	0	26
77006	2020-06-12 03:12:23	2020-06-12	9	[{"id_menu":7,"count":1}]	30358	delivery	5	14
77007	2020-06-12 03:13:01	2020-06-12	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2600	delivery	5	26
77008	2020-06-12 03:20:19	2020-06-12	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	30502	delivery	5	39
77009	2020-06-12 03:26:13	2020-06-12	17	[{"id_menu":4,"count":1}]	12564	pick-up	0	17
77010	2020-06-12 03:29:33	2020-06-12	17	[{"id_menu":4,"count":1}]	30474	pick-up	0	17
77011	2020-06-12 03:30:21	2020-06-12	9	[{"id_menu":6,"count":1}]	30379	delivery	5	14
77012	2020-06-12 03:31:37	2020-06-12	8	[{"id_menu":5,"count":1}]	28624	delivery	5	13
77013	2020-06-12 03:31:47	2020-06-12	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	22641	delivery	5	36
77014	2020-06-12 03:33:01	2020-06-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9000	delivery	5	28
77015	2020-06-12 03:33:57	2020-06-12	12	[{"id_menu":3,"count":1}]	4735	delivery	5	17
77016	2020-06-12 03:34:46	2020-06-12	12	[{"id_menu":1,"count":1}]	14579	delivery	5	17
77017	2020-06-12 03:40:50	2020-06-12	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	30396	delivery	5	26
77018	2020-06-12 03:41:19	2020-06-12	14	[{"id_menu":2,"count":1}]	30329	delivery	5	19
77019	2020-06-12 03:42:05	2020-06-12	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	6134	pick-up	0	26
77020	2020-06-12 03:42:58	2020-06-12	8	[{"id_menu":5,"count":1}]	30486	delivery	5	13
77021	2020-06-12 03:43:49	2020-06-12	12	[{"id_menu":1,"count":1}]	5933	pick-up	0	12
77022	2020-06-12 03:44:14	2020-06-12	9	[{"id_menu":6,"count":1}]	18375	delivery	5	14
77023	2020-06-12 03:50:54	2020-06-12	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	30318	delivery	5	57
77024	2020-06-12 03:51:09	2020-06-12	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1568	pick-up	0	40
77025	2020-06-12 03:52:36	2020-06-12	17	[{"id_menu":4,"count":1}]	27746	delivery	5	22
77026	2020-06-12 03:53:47	2020-06-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5149	pick-up	0	23
77027	2020-06-12 03:56:39	2020-06-12	8	[{"id_menu":5,"count":1}]	25204	delivery	5	13
77028	2020-06-12 03:56:41	2020-06-12	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	30390	delivery	5	31
77029	2020-06-12 04:04:57	2020-06-12	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	20094	delivery	5	23
77030	2020-06-12 04:12:55	2020-06-12	17	[{"id_menu":4,"count":1}]	19991	pick-up	0	17
77031	2020-06-12 04:18:18	2020-06-12	9	[{"id_menu":7,"count":1}]	30376	delivery	5	14
77032	2020-06-12 04:19:41	2020-06-12	12	[{"id_menu":3,"count":1}]	16029	pick-up	0	12
77033	2020-06-12 04:22:02	2020-06-12	9	[{"id_menu":6,"count":1}]	6345	delivery	5	14
77034	2020-06-12 04:23:42	2020-06-12	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	9958	delivery	5	28
77035	2020-06-12 04:27:47	2020-06-12	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29017	delivery	5	43
77036	2020-06-12 04:28:47	2020-06-12	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27889	delivery	5	36
77037	2020-06-12 04:46:32	2020-06-12	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	30429	delivery	5	34
77038	2020-06-12 04:47:52	2020-06-12	12	[{"id_menu":1,"count":1}]	13758	delivery	5	17
77039	2020-06-12 04:49:24	2020-06-12	14	[{"id_menu":2,"count":1}]	1600	delivery	5	19
77040	2020-06-12 04:50:35	2020-06-12	14	[{"id_menu":2,"count":1}]	30435	delivery	5	19
77041	2020-06-12 04:52:48	2020-06-12	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	7914	delivery	5	22
77042	2020-06-12 04:54:18	2020-06-12	17	[{"id_menu":4,"count":1}]	30406	pick-up	0	17
77043	2020-06-12 04:57:08	2020-06-12	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	21442	pick-up	0	26
77044	2020-06-12 04:57:39	2020-06-12	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	3227	pick-up	0	21
77045	2020-06-12 05:01:55	2020-06-12	8	[{"id_menu":5,"count":1}]	30366	delivery	5	13
77046	2020-06-12 05:02:37	2020-06-12	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30384	delivery	5	52
77047	2020-06-12 05:04:31	2020-06-12	17	[{"id_menu":4,"count":1}]	21532	delivery	5	22
77048	2020-06-12 05:11:06	2020-06-12	14	[{"id_menu":2,"count":1}]	17790	pick-up	0	14
77049	2020-06-12 05:12:43	2020-06-12	9	[{"id_menu":7,"count":1}]	3873	delivery	5	14
77050	2020-06-12 05:15:32	2020-06-12	9	[{"id_menu":7,"count":1}]	2054	pick-up	0	9
77051	2020-06-12 05:20:04	2020-06-12	9	[{"id_menu":6,"count":1}]	4090	pick-up	0	9
77052	2020-06-12 05:20:33	2020-06-12	9	[{"id_menu":6,"count":1}]	12615	delivery	5	14
77053	2020-06-12 05:21:18	2020-06-12	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":2}]	6396	pick-up	0	29
77054	2020-06-12 05:22:24	2020-06-12	17	[{"id_menu":4,"count":2}]	6181	pick-up	0	17
77055	2020-06-12 05:23:09	2020-06-12	12	[{"id_menu":3,"count":1}]	12261	delivery	5	17
77056	2020-06-12 05:24:01	2020-06-12	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	7849	delivery	5	25
77057	2020-06-12 05:26:35	2020-06-12	14	[{"id_menu":2,"count":1}]	23890	pick-up	0	14
77058	2020-06-12 05:43:18	2020-06-12	9	[{"id_menu":6,"count":1}]	24417	pick-up	0	9
77059	2020-06-12 05:46:19	2020-06-12	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	30460	delivery	5	57
77060	2020-06-12 05:46:23	2020-06-12	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	22822	delivery	5	31
77061	2020-06-12 05:50:45	2020-06-12	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2413	pick-up	0	17
77062	2020-06-12 05:53:15	2020-06-12	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	30349	delivery	5	45
77063	2020-06-12 05:53:29	2020-06-12	17	[{"id_menu":4,"count":1}]	30438	delivery	5	22
77064	2020-06-12 06:01:31	2020-06-12	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	21223	delivery	5	26
77065	2020-06-12 06:03:12	2020-06-12	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	30456	delivery	5	27
77066	2020-06-12 06:03:36	2020-06-12	9	[{"id_menu":7,"count":1}]	2153	pick-up	0	9
77067	2020-06-12 06:10:54	2020-06-12	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	30423	delivery	5	45
77068	2020-06-12 06:20:57	2020-06-12	8	[{"id_menu":5,"count":1}]	17456	delivery	5	13
77069	2020-06-12 06:24:16	2020-06-12	8	[{"id_menu":5,"count":1}]	21117	delivery	5	13
77070	2020-06-12 06:25:31	2020-06-12	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	21003	delivery	5	57
77071	2020-06-12 06:26:55	2020-06-12	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	856	delivery	5	26
77072	2020-06-12 06:27:54	2020-06-12	9	[{"id_menu":7,"count":1}]	3494	pick-up	0	9
77073	2020-06-12 06:30:44	2020-06-12	12	[{"id_menu":1,"count":1}]	21714	delivery	5	17
77074	2020-06-12 06:33:50	2020-06-12	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14422	delivery	5	35
77075	2020-06-12 06:37:34	2020-06-12	8	[{"id_menu":5,"count":1}]	30317	delivery	5	13
77076	2020-06-12 06:38:11	2020-06-12	34	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	30434	delivery	5	39
77077	2020-06-12 06:38:23	2020-06-12	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21701	delivery	5	39
77078	2020-06-12 06:41:05	2020-06-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23097	delivery	5	23
77079	2020-06-12 06:43:55	2020-06-12	9	[{"id_menu":6,"count":1}]	24870	delivery	5	14
77080	2020-06-12 06:45:46	2020-06-12	8	[{"id_menu":5,"count":1}]	30504	delivery	5	13
77081	2020-06-12 06:48:14	2020-06-12	12	[{"id_menu":1,"count":1}]	30401	delivery	5	17
77082	2020-06-12 06:51:49	2020-06-12	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	30386	delivery	5	26
77083	2020-06-12 06:53:25	2020-06-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	30377	delivery	5	31
77084	2020-06-12 06:57:59	2020-06-12	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	30451	delivery	5	34
77085	2020-06-12 06:58:55	2020-06-12	8	[{"id_menu":5,"count":1}]	7172	delivery	5	13
77086	2020-06-12 07:01:52	2020-06-12	12	[{"id_menu":3,"count":1}]	26685	delivery	5	17
77087	2020-06-12 07:03:38	2020-06-12	12	[{"id_menu":3,"count":1}]	30465	delivery	5	17
77088	2020-06-12 07:06:19	2020-06-12	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3278	delivery	5	40
77089	2020-06-12 07:06:35	2020-06-12	9	[{"id_menu":7,"count":1}]	11653	delivery	5	14
77090	2020-06-12 07:07:40	2020-06-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6446	pick-up	0	23
77091	2020-06-12 07:14:14	2020-06-12	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	30354	delivery	5	39
77092	2020-06-12 07:16:39	2020-06-12	17	[{"id_menu":4,"count":1}]	23860	delivery	5	22
77093	2020-06-12 07:17:35	2020-06-12	9	[{"id_menu":7,"count":1}]	30416	delivery	5	14
77094	2020-06-12 07:18:21	2020-06-12	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19003	delivery	5	37
77095	2020-06-12 07:18:45	2020-06-12	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	30382	delivery	5	36
77096	2020-06-12 07:20:58	2020-06-12	14	[{"id_menu":2,"count":1}]	10249	delivery	5	19
77097	2020-06-12 07:26:32	2020-06-12	17	[{"id_menu":4,"count":1}]	5004	delivery	5	22
77098	2020-06-12 07:26:53	2020-06-12	17	[{"id_menu":4,"count":1}]	11862	delivery	5	22
77099	2020-06-12 07:29:31	2020-06-12	9	[{"id_menu":6,"count":1}]	7392	delivery	5	14
77100	2020-06-12 07:31:04	2020-06-12	9	[{"id_menu":7,"count":1}]	16588	delivery	5	14
77101	2020-06-12 07:31:14	2020-06-12	12	[{"id_menu":1,"count":1}]	30455	pick-up	0	12
77102	2020-06-12 07:31:58	2020-06-12	12	[{"id_menu":1,"count":2}]	2310	pick-up	0	12
77103	2020-06-12 07:33:54	2020-06-12	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	30498	delivery	5	46
77104	2020-06-12 07:34:15	2020-06-12	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	22572	delivery	5	45
77105	2020-06-12 07:35:14	2020-06-12	12	[{"id_menu":1,"count":1}]	30424	delivery	5	17
77106	2020-06-12 07:43:46	2020-06-12	14	[{"id_menu":2,"count":1}]	3756	pick-up	0	14
77107	2020-06-12 07:51:32	2020-06-12	14	[{"id_menu":2,"count":1}]	17353	pick-up	0	14
77108	2020-06-12 07:52:04	2020-06-12	17	[{"id_menu":4,"count":1}]	1735	delivery	5	22
77109	2020-06-12 07:53:25	2020-06-12	9	[{"id_menu":7,"count":1}]	30420	delivery	5	14
77110	2020-06-12 07:54:59	2020-06-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4818	delivery	5	31
77111	2020-06-12 07:55:58	2020-06-12	14	[{"id_menu":2,"count":1}]	2065	pick-up	0	14
77112	2020-06-12 08:08:08	2020-06-12	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":3}]	30413	delivery	5	27
77113	2020-06-12 08:09:57	2020-06-12	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	16346	delivery	5	48
77114	2020-06-12 08:10:13	2020-06-12	12	[{"id_menu":1,"count":1}]	30341	delivery	5	17
77115	2020-06-12 08:10:43	2020-06-12	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	30479	delivery	5	43
77116	2020-06-12 08:14:31	2020-06-12	9	[{"id_menu":7,"count":3}]	20757	delivery	5	14
77117	2020-06-12 08:17:37	2020-06-12	17	[{"id_menu":4,"count":1}]	30374	delivery	5	22
77118	2020-06-12 08:20:39	2020-06-12	12	[{"id_menu":3,"count":1}]	16456	delivery	5	17
77119	2020-06-12 08:24:23	2020-06-12	9	[{"id_menu":7,"count":1}]	30389	delivery	5	14
77120	2020-06-12 08:26:03	2020-06-12	9	[{"id_menu":7,"count":1}]	2821	pick-up	0	9
77121	2020-06-12 08:26:25	2020-06-12	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	7772	pick-up	0	21
77122	2020-06-12 08:28:45	2020-06-12	9	[{"id_menu":6,"count":1}]	21934	delivery	5	14
77123	2020-06-12 08:30:26	2020-06-12	14	[{"id_menu":2,"count":1}]	9428	delivery	5	19
77124	2020-06-12 08:31:24	2020-06-12	17	[{"id_menu":4,"count":1}]	813	pick-up	0	17
77125	2020-06-12 08:33:06	2020-06-12	9	[{"id_menu":6,"count":3}]	26174	delivery	5	14
77126	2020-06-12 08:33:22	2020-06-12	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	24798	delivery	5	31
77127	2020-06-12 08:36:24	2020-06-12	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	17503	delivery	5	30
77128	2020-06-12 08:36:40	2020-06-12	12	[{"id_menu":3,"count":1}]	1782	delivery	5	17
77129	2020-06-12 08:42:17	2020-06-12	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11435	pick-up	0	30
77130	2020-06-12 08:45:06	2020-06-12	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	30331	delivery	5	22
77131	2020-06-12 08:58:01	2020-06-12	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24580	delivery	5	39
77132	2020-06-12 09:05:35	2020-06-12	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1449	pick-up	0	24
77133	2020-06-12 09:07:18	2020-06-12	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	30325	delivery	5	34
77134	2020-06-12 09:14:53	2020-06-12	14	[{"id_menu":2,"count":1}]	25815	delivery	5	19
77135	2020-06-12 09:20:21	2020-06-12	8	[{"id_menu":5,"count":1}]	5134	pick-up	0	8
77136	2020-06-12 09:20:24	2020-06-12	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	28430	delivery	5	40
77137	2020-06-12 09:26:34	2020-06-12	9	[{"id_menu":6,"count":1}]	23729	pick-up	0	9
77138	2020-06-12 09:30:47	2020-06-12	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	30360	delivery	5	45
77139	2020-06-12 09:33:12	2020-06-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	30369	delivery	5	22
77140	2020-06-12 09:37:49	2020-06-12	14	[{"id_menu":2,"count":1}]	3491	pick-up	0	14
77141	2020-06-12 09:47:20	2020-06-12	9	[{"id_menu":6,"count":1}]	24096	delivery	5	14
77142	2020-06-12 09:49:06	2020-06-12	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30332	delivery	5	37
77143	2020-06-12 09:49:46	2020-06-12	8	[{"id_menu":5,"count":1}]	30441	delivery	5	13
77144	2020-06-12 09:52:19	2020-06-12	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	30408	delivery	5	46
77145	2020-06-12 09:56:09	2020-06-12	9	[{"id_menu":6,"count":1}]	14035	delivery	5	14
77146	2020-06-12 09:59:24	2020-06-12	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30342	delivery	5	40
77147	2020-06-12 10:00:56	2020-06-12	8	[{"id_menu":5,"count":1}]	27227	delivery	5	13
77148	2020-06-12 10:01:22	2020-06-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10669	delivery	5	23
77149	2020-06-12 10:09:56	2020-06-12	12	[{"id_menu":1,"count":1}]	7707	delivery	5	17
77150	2020-06-12 10:12:33	2020-06-12	9	[{"id_menu":7,"count":1}]	17246	delivery	5	14
77151	2020-06-12 10:14:48	2020-06-12	12	[{"id_menu":1,"count":1}]	2422	delivery	5	17
77152	2020-06-12 10:17:00	2020-06-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	30447	delivery	5	22
77153	2020-06-12 10:18:48	2020-06-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	30452	delivery	5	28
77154	2020-06-12 10:26:35	2020-06-12	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	30442	delivery	5	40
77155	2020-06-12 10:26:56	2020-06-12	8	[{"id_menu":5,"count":1}]	18920	pick-up	0	8
77156	2020-06-12 10:33:40	2020-06-12	9	[{"id_menu":7,"count":1}]	8617	pick-up	0	9
77157	2020-06-12 10:39:03	2020-06-12	14	[{"id_menu":2,"count":1}]	466	delivery	5	19
77158	2020-06-12 10:44:31	2020-06-12	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	18350	delivery	5	43
77159	2020-06-12 10:45:08	2020-06-12	14	[{"id_menu":2,"count":1}]	425	delivery	5	19
77160	2020-06-12 10:46:26	2020-06-12	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10183	pick-up	0	38
77161	2020-06-12 10:46:31	2020-06-12	12	[{"id_menu":3,"count":1}]	16900	delivery	5	17
77162	2020-06-12 10:51:34	2020-06-12	8	[{"id_menu":5,"count":1}]	5219	delivery	5	13
77163	2020-06-12 10:52:03	2020-06-12	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	30381	delivery	5	26
77164	2020-06-12 10:52:20	2020-06-12	9	[{"id_menu":7,"count":1}]	222	pick-up	0	9
77165	2020-06-12 10:52:28	2020-06-12	9	[{"id_menu":7,"count":1}]	12544	delivery	5	14
77166	2020-06-12 10:52:57	2020-06-12	14	[{"id_menu":2,"count":1}]	13011	delivery	5	19
77167	2020-06-12 10:57:43	2020-06-12	9	[{"id_menu":6,"count":1}]	3808	pick-up	0	9
77168	2020-06-12 10:59:34	2020-06-12	12	[{"id_menu":3,"count":1}]	16484	pick-up	0	12
77169	2020-06-12 11:01:06	2020-06-12	8	[{"id_menu":5,"count":1}]	19760	delivery	5	13
77170	2020-06-12 11:01:16	2020-06-12	9	[{"id_menu":7,"count":1}]	30365	delivery	5	14
77171	2020-06-12 11:01:47	2020-06-12	9	[{"id_menu":6,"count":1}]	632	pick-up	0	9
77172	2020-06-12 11:04:42	2020-06-12	17	[{"id_menu":4,"count":1}]	17398	delivery	5	22
77173	2020-06-12 11:07:20	2020-06-12	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	30427	delivery	5	53
77174	2020-06-12 11:08:22	2020-06-12	12	[{"id_menu":3,"count":1}]	29620	delivery	5	17
77175	2020-06-12 11:11:58	2020-06-12	8	[{"id_menu":5,"count":1}]	30344	delivery	5	13
77176	2020-06-12 11:12:01	2020-06-12	17	[{"id_menu":4,"count":1}]	25408	pick-up	0	17
77177	2020-06-12 11:13:05	2020-06-12	12	[{"id_menu":1,"count":1}]	4688	pick-up	0	12
77178	2020-06-12 11:13:58	2020-06-12	12	[{"id_menu":1,"count":1}]	12296	pick-up	0	12
77179	2020-06-12 11:17:38	2020-06-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30448	delivery	5	23
77180	2020-06-12 11:22:52	2020-06-12	9	[{"id_menu":6,"count":1}]	30404	delivery	5	14
77181	2020-06-12 11:23:13	2020-06-12	17	[{"id_menu":4,"count":1}]	349	delivery	5	22
77182	2020-06-12 11:25:12	2020-06-12	9	[{"id_menu":6,"count":1}]	30492	delivery	5	14
77183	2020-06-12 11:25:39	2020-06-12	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18343	delivery	5	34
77184	2020-06-12 11:30:31	2020-06-12	14	[{"id_menu":2,"count":1}]	30368	delivery	5	19
77185	2020-06-12 11:37:01	2020-06-12	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30430	delivery	5	45
77186	2020-06-12 11:37:41	2020-06-12	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	30439	delivery	5	26
77187	2020-06-12 11:40:55	2020-06-12	8	[{"id_menu":5,"count":1}]	30373	delivery	5	13
77188	2020-06-12 11:44:23	2020-06-12	12	[{"id_menu":1,"count":1}]	30458	delivery	5	17
77189	2020-06-12 11:50:59	2020-06-12	9	[{"id_menu":6,"count":2}]	25459	delivery	5	14
77190	2020-06-12 11:54:00	2020-06-12	9	[{"id_menu":7,"count":1}]	17520	pick-up	0	9
77191	2020-06-12 11:56:13	2020-06-12	17	[{"id_menu":4,"count":1}]	10944	delivery	5	22
77192	2020-06-12 11:57:05	2020-06-12	14	[{"id_menu":2,"count":1}]	30316	pick-up	0	14
77193	2020-06-12 12:02:33	2020-06-12	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	14054	delivery	5	28
77194	2020-06-12 12:07:12	2020-06-12	14	[{"id_menu":2,"count":1}]	30313	delivery	5	19
77195	2020-06-12 12:07:18	2020-06-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7358	delivery	5	31
77196	2020-06-12 12:17:20	2020-06-12	9	[{"id_menu":7,"count":1}]	23430	delivery	5	14
77197	2020-06-12 12:20:15	2020-06-12	17	[{"id_menu":4,"count":1}]	30471	delivery	5	22
77198	2020-06-12 12:28:36	2020-06-12	9	[{"id_menu":7,"count":1}]	30428	delivery	5	14
77199	2020-06-12 12:29:57	2020-06-12	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30399	delivery	5	37
77200	2020-06-12 12:31:28	2020-06-12	9	[{"id_menu":7,"count":1}]	8205	pick-up	0	9
77201	2020-06-12 12:31:39	2020-06-12	17	[{"id_menu":4,"count":1}]	10880	pick-up	0	17
77202	2020-06-12 12:38:34	2020-06-12	9	[{"id_menu":7,"count":1}]	7341	pick-up	0	9
77203	2020-06-12 12:40:53	2020-06-12	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19665	delivery	5	22
77204	2020-06-12 12:41:22	2020-06-12	9	[{"id_menu":6,"count":1}]	13598	delivery	5	14
77205	2020-06-12 12:47:25	2020-06-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7365	delivery	5	31
77206	2020-06-12 12:47:47	2020-06-12	12	[{"id_menu":1,"count":1}]	30350	delivery	5	17
77207	2020-06-12 12:49:11	2020-06-12	9	[{"id_menu":6,"count":1}]	15057	delivery	5	14
77208	2020-06-12 12:52:10	2020-06-12	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30462	delivery	5	37
77209	2020-06-12 12:52:12	2020-06-12	17	[{"id_menu":4,"count":1}]	26756	delivery	5	22
77210	2020-06-12 12:56:07	2020-06-12	9	[{"id_menu":6,"count":1}]	20598	pick-up	0	9
77211	2020-06-12 12:57:22	2020-06-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	15752	pick-up	0	26
77212	2020-06-12 13:09:42	2020-06-12	9	[{"id_menu":6,"count":1}]	28571	delivery	5	14
77213	2020-06-12 13:10:20	2020-06-12	12	[{"id_menu":1,"count":1}]	2367	pick-up	0	12
77214	2020-06-12 13:19:01	2020-06-12	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	30473	delivery	5	53
77215	2020-06-12 13:19:40	2020-06-12	9	[{"id_menu":6,"count":1}]	4451	pick-up	0	9
77216	2020-06-12 13:19:55	2020-06-12	9	[{"id_menu":6,"count":1}]	30419	delivery	5	14
77217	2020-06-12 13:21:11	2020-06-12	9	[{"id_menu":6,"count":1}]	30311	pick-up	0	9
77218	2020-06-12 13:24:38	2020-06-12	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	12466	pick-up	0	21
77219	2020-06-12 13:30:08	2020-06-12	8	[{"id_menu":5,"count":1}]	12534	delivery	5	13
77220	2020-06-12 13:33:39	2020-06-12	9	[{"id_menu":6,"count":1}]	30459	delivery	5	14
77221	2020-06-12 13:39:25	2020-06-12	8	[{"id_menu":5,"count":1}]	25003	delivery	5	13
77222	2020-06-12 13:44:16	2020-06-12	9	[{"id_menu":6,"count":1}]	30433	delivery	5	14
77223	2020-06-12 13:47:22	2020-06-12	12	[{"id_menu":1,"count":1}]	3135	pick-up	0	12
77224	2020-06-12 13:53:21	2020-06-12	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	22153	delivery	5	25
77225	2020-06-12 14:00:40	2020-06-12	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	30412	delivery	5	52
77226	2020-06-12 14:01:36	2020-06-12	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	30444	delivery	5	34
77227	2020-06-12 14:05:06	2020-06-12	12	[{"id_menu":3,"count":1}]	30346	delivery	5	17
77228	2020-06-12 14:05:44	2020-06-12	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	30415	delivery	5	31
77229	2020-06-12 14:14:46	2020-06-12	8	[{"id_menu":5,"count":1}]	30464	delivery	5	13
77230	2020-06-12 14:17:25	2020-06-12	17	[{"id_menu":4,"count":1}]	30394	delivery	5	22
77231	2020-06-12 14:24:21	2020-06-12	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	18833	delivery	5	40
77232	2020-06-12 14:24:58	2020-06-12	8	[{"id_menu":5,"count":1}]	18737	delivery	5	13
77233	2020-06-12 14:25:07	2020-06-12	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	24257	delivery	5	43
77234	2020-06-12 14:25:14	2020-06-12	8	[{"id_menu":5,"count":1}]	18653	delivery	5	13
77235	2020-06-12 14:25:16	2020-06-12	9	[{"id_menu":7,"count":1}]	30466	delivery	5	14
77236	2020-06-12 14:28:10	2020-06-12	12	[{"id_menu":1,"count":2}]	27703	delivery	5	17
77237	2020-06-12 14:34:53	2020-06-12	9	[{"id_menu":7,"count":1}]	22443	delivery	5	14
77238	2020-06-12 14:38:53	2020-06-12	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	30385	delivery	5	34
77239	2020-06-12 14:39:02	2020-06-12	12	[{"id_menu":3,"count":1}]	15194	pick-up	0	12
77240	2020-06-12 14:43:04	2020-06-12	9	[{"id_menu":7,"count":3}]	26436	delivery	5	14
77241	2020-06-12 14:44:18	2020-06-12	9	[{"id_menu":6,"count":1}]	23750	delivery	5	14
77242	2020-06-12 14:52:33	2020-06-12	9	[{"id_menu":6,"count":2}]	30495	delivery	5	14
77243	2020-06-12 14:55:09	2020-06-12	9	[{"id_menu":6,"count":1}]	30330	pick-up	0	9
77244	2020-06-12 15:00:41	2020-06-12	12	[{"id_menu":1,"count":1}]	30347	delivery	5	17
77245	2020-06-12 15:04:25	2020-06-12	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	3868	pick-up	0	21
77246	2020-06-12 15:05:57	2020-06-12	14	[{"id_menu":2,"count":1}]	5714	delivery	5	19
77247	2020-06-12 15:07:48	2020-06-12	14	[{"id_menu":2,"count":1}]	386	pick-up	0	14
77248	2020-06-12 15:08:10	2020-06-12	14	[{"id_menu":2,"count":2}]	8866	delivery	5	19
77249	2020-06-12 15:08:39	2020-06-12	9	[{"id_menu":6,"count":1}]	21625	delivery	5	14
77250	2020-06-12 15:13:49	2020-06-12	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	29702	pick-up	0	35
77251	2020-06-12 15:15:58	2020-06-12	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	28866	delivery	5	29
77252	2020-06-12 15:18:08	2020-06-12	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	30315	delivery	5	34
77253	2020-06-12 15:19:46	2020-06-12	12	[{"id_menu":3,"count":1}]	20563	delivery	5	17
77254	2020-06-12 15:22:24	2020-06-12	9	[{"id_menu":7,"count":1}]	30467	delivery	5	14
77255	2020-06-12 15:22:57	2020-06-12	9	[{"id_menu":7,"count":1}]	30446	delivery	5	14
77256	2020-06-12 15:31:15	2020-06-12	14	[{"id_menu":2,"count":1}]	30276	delivery	5	19
77257	2020-06-12 15:34:08	2020-06-12	9	[{"id_menu":6,"count":1}]	26262	delivery	5	14
77258	2020-06-12 15:34:24	2020-06-12	9	[{"id_menu":6,"count":1}]	16336	delivery	5	14
77259	2020-06-12 15:36:22	2020-06-12	12	[{"id_menu":1,"count":1}]	30414	delivery	5	17
77260	2020-06-12 15:40:48	2020-06-12	9	[{"id_menu":7,"count":1}]	30338	delivery	5	14
77261	2020-06-12 15:49:15	2020-06-12	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	24964	delivery	5	27
77262	2020-06-12 15:59:23	2020-06-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	833	pick-up	0	17
77263	2020-06-12 15:59:27	2020-06-12	12	[{"id_menu":1,"count":1}]	6952	pick-up	0	12
77264	2020-06-12 16:04:27	2020-06-12	9	[{"id_menu":6,"count":1}]	27318	pick-up	0	9
77265	2020-06-12 16:05:04	2020-06-12	12	[{"id_menu":3,"count":1}]	3433	pick-up	0	12
77266	2020-06-12 16:08:11	2020-06-12	12	[{"id_menu":1,"count":1}]	4830	delivery	5	17
77267	2020-06-12 16:14:10	2020-06-12	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":3}]	20852	delivery	5	26
77268	2020-06-12 16:19:44	2020-06-12	17	[{"id_menu":4,"count":1}]	30409	delivery	5	22
77269	2020-06-12 16:20:59	2020-06-12	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22094	delivery	5	31
77270	2020-06-12 16:22:17	2020-06-12	12	[{"id_menu":3,"count":1}]	4356	delivery	5	17
77271	2020-06-12 16:23:28	2020-06-12	9	[{"id_menu":7,"count":1}]	17122	delivery	5	14
77272	2020-06-12 16:24:45	2020-06-12	17	[{"id_menu":4,"count":1}]	7503	delivery	5	22
77273	2020-06-12 16:33:47	2020-06-12	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2561	delivery	5	45
77274	2020-06-12 16:35:47	2020-06-12	8	[{"id_menu":5,"count":2}]	30491	delivery	5	13
77275	2020-06-12 16:36:19	2020-06-12	9	[{"id_menu":6,"count":1}]	30411	pick-up	0	9
77276	2020-06-12 16:36:22	2020-06-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17794	delivery	5	22
77277	2020-06-12 16:43:32	2020-06-12	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13081	delivery	5	34
77278	2020-06-12 16:45:06	2020-06-12	9	[{"id_menu":7,"count":1}]	9382	delivery	5	14
77279	2020-06-12 16:56:59	2020-06-12	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	30457	delivery	5	27
77280	2020-06-12 16:59:04	2020-06-12	9	[{"id_menu":6,"count":1}]	21866	delivery	5	14
77281	2020-06-12 17:05:07	2020-06-12	14	[{"id_menu":2,"count":1}]	30359	delivery	5	19
77282	2020-06-12 17:05:52	2020-06-12	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	26033	delivery	5	22
77283	2020-06-12 17:06:44	2020-06-12	9	[{"id_menu":6,"count":1}]	23289	delivery	5	14
77284	2020-06-12 17:10:08	2020-06-12	14	[{"id_menu":2,"count":1}]	30403	delivery	5	19
77285	2020-06-12 17:18:12	2020-06-12	12	[{"id_menu":1,"count":1}]	30470	delivery	5	17
77286	2020-06-12 17:18:34	2020-06-12	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	4943	delivery	5	31
77287	2020-06-12 17:19:04	2020-06-12	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	3211	delivery	5	25
77288	2020-06-12 17:23:35	2020-06-12	9	[{"id_menu":6,"count":1}]	13026	delivery	5	14
77289	2020-06-12 17:27:02	2020-06-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	13940	delivery	5	23
77290	2020-06-12 17:32:00	2020-06-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	787	pick-up	0	18
77291	2020-06-12 17:32:04	2020-06-12	17	[{"id_menu":4,"count":1}]	11607	delivery	5	22
77292	2020-06-12 17:34:01	2020-06-12	9	[{"id_menu":7,"count":1}]	22698	delivery	5	14
77293	2020-06-12 17:39:42	2020-06-12	9	[{"id_menu":6,"count":1}]	30353	delivery	5	14
77294	2020-06-12 17:42:19	2020-06-12	9	[{"id_menu":7,"count":1}]	4313	delivery	5	14
77295	2020-06-12 17:43:47	2020-06-12	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	30375	pick-up	0	26
77296	2020-06-12 17:46:18	2020-06-12	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28579	delivery	5	22
77297	2020-06-12 17:47:43	2020-06-12	8	[{"id_menu":5,"count":1}]	15674	delivery	5	13
77298	2020-06-12 17:48:26	2020-06-12	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23434	delivery	5	34
77299	2020-06-12 17:52:32	2020-06-12	17	[{"id_menu":4,"count":1}]	30407	delivery	5	22
77300	2020-06-12 17:59:04	2020-06-12	9	[{"id_menu":6,"count":2}]	28987	delivery	5	14
77301	2020-06-12 18:01:28	2020-06-12	9	[{"id_menu":6,"count":1}]	30309	delivery	5	14
77302	2020-06-12 18:04:12	2020-06-12	9	[{"id_menu":7,"count":1}]	21312	pick-up	0	9
77303	2020-06-12 18:08:18	2020-06-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	30371	delivery	5	22
77304	2020-06-12 18:10:07	2020-06-12	9	[{"id_menu":6,"count":1}]	30393	pick-up	0	9
77305	2020-06-12 18:14:04	2020-06-12	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	8700	delivery	5	38
77306	2020-06-12 18:21:31	2020-06-12	17	[{"id_menu":4,"count":1}]	30436	delivery	5	22
77307	2020-06-12 18:23:32	2020-06-12	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30362	delivery	5	35
77308	2020-06-12 18:25:28	2020-06-12	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30334	delivery	5	37
77309	2020-06-12 18:26:11	2020-06-12	9	[{"id_menu":7,"count":1}]	26668	delivery	5	14
77310	2020-06-12 18:26:41	2020-06-12	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23268	delivery	5	49
77311	2020-06-12 18:27:16	2020-06-12	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2537	delivery	5	25
77312	2020-06-12 18:28:05	2020-06-12	9	[{"id_menu":6,"count":3}]	1951	delivery	5	14
77313	2020-06-12 18:28:23	2020-06-12	14	[{"id_menu":2,"count":1}]	3593	pick-up	0	14
77314	2020-06-12 18:34:33	2020-06-12	14	[{"id_menu":2,"count":1}]	27557	delivery	5	19
77315	2020-06-12 18:35:33	2020-06-12	9	[{"id_menu":6,"count":1}]	30454	pick-up	0	9
77316	2020-06-12 18:37:13	2020-06-12	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	21862	delivery	5	37
77317	2020-06-12 18:37:37	2020-06-12	9	[{"id_menu":6,"count":1}]	30421	delivery	5	14
77318	2020-06-12 18:40:24	2020-06-12	9	[{"id_menu":6,"count":3}]	25299	delivery	5	14
77319	2020-06-12 18:40:51	2020-06-12	14	[{"id_menu":2,"count":1}]	11859	delivery	5	19
77320	2020-06-12 18:42:12	2020-06-12	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18973	delivery	5	39
77321	2020-06-12 18:42:24	2020-06-12	12	[{"id_menu":1,"count":1}]	4836	delivery	5	17
77322	2020-06-12 18:42:47	2020-06-12	12	[{"id_menu":1,"count":1}]	4137	pick-up	0	12
77323	2020-06-12 18:44:16	2020-06-12	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3687	delivery	5	30
77324	2020-06-12 18:45:27	2020-06-12	8	[{"id_menu":5,"count":1}]	25337	pick-up	0	8
77325	2020-06-12 18:47:19	2020-06-12	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	13840	delivery	5	40
77326	2020-06-12 18:53:50	2020-06-12	8	[{"id_menu":5,"count":1}]	30327	delivery	5	13
77327	2020-06-12 18:56:25	2020-06-12	12	[{"id_menu":3,"count":1}]	30397	delivery	5	17
77328	2020-06-12 18:57:49	2020-06-12	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	30345	delivery	5	36
77329	2020-06-12 19:15:40	2020-06-12	8	[{"id_menu":5,"count":1}]	13777	delivery	5	13
77330	2020-06-12 19:21:37	2020-06-12	8	[{"id_menu":5,"count":1}]	30363	delivery	5	13
77331	2020-06-12 19:25:32	2020-06-12	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":3}]	30501	delivery	5	28
77332	2020-06-12 19:27:10	2020-06-12	12	[{"id_menu":3,"count":1}]	30323	delivery	5	17
77333	2020-06-12 19:30:44	2020-06-12	8	[{"id_menu":5,"count":1}]	16084	delivery	5	13
77334	2020-06-12 19:32:23	2020-06-12	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26936	delivery	5	35
77335	2020-06-12 19:32:39	2020-06-12	9	[{"id_menu":6,"count":1}]	30469	pick-up	0	9
77336	2020-06-12 19:35:05	2020-06-12	17	[{"id_menu":5,"count":3},{"id_menu":6,"count":1}]	30340	delivery	5	22
77337	2020-06-12 19:35:35	2020-06-12	12	[{"id_menu":1,"count":1}]	22312	delivery	5	17
77338	2020-06-12 19:37:06	2020-06-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	926	pick-up	0	17
77339	2020-06-12 19:37:29	2020-06-12	14	[{"id_menu":2,"count":1}]	14002	pick-up	0	14
77340	2020-06-12 19:43:34	2020-06-12	9	[{"id_menu":6,"count":1}]	7173	pick-up	0	9
77341	2020-06-12 19:46:43	2020-06-12	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	11436	delivery	5	26
77342	2020-06-12 19:47:22	2020-06-12	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9352	delivery	5	34
77343	2020-06-12 19:49:36	2020-06-12	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	15158	pick-up	0	20
77344	2020-06-12 19:55:25	2020-06-12	12	[{"id_menu":3,"count":1}]	30505	pick-up	0	12
77345	2020-06-12 20:02:47	2020-06-12	9	[{"id_menu":6,"count":1}]	788	delivery	5	14
77346	2020-06-12 20:08:28	2020-06-12	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	4578	delivery	5	26
77347	2020-06-12 20:17:47	2020-06-12	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	30378	delivery	5	37
77348	2020-06-12 20:18:26	2020-06-12	9	[{"id_menu":7,"count":1}]	8546	pick-up	0	9
77349	2020-06-12 20:27:34	2020-06-12	9	[{"id_menu":7,"count":1}]	2753	pick-up	0	9
77350	2020-06-12 20:28:26	2020-06-12	9	[{"id_menu":6,"count":1}]	4056	delivery	5	14
77351	2020-06-12 20:29:38	2020-06-12	9	[{"id_menu":6,"count":1}]	25710	delivery	5	14
77352	2020-06-12 20:32:41	2020-06-12	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	25827	delivery	5	40
77353	2020-06-12 20:33:56	2020-06-12	9	[{"id_menu":6,"count":1}]	30392	pick-up	0	9
77354	2020-06-12 20:34:05	2020-06-12	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	27783	delivery	5	23
77355	2020-06-12 20:38:21	2020-06-12	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	30364	delivery	5	34
77356	2020-06-12 20:44:21	2020-06-12	17	[{"id_menu":4,"count":1}]	2119	pick-up	0	17
77357	2020-06-12 20:44:56	2020-06-12	14	[{"id_menu":2,"count":1}]	24122	pick-up	0	14
77358	2020-06-12 20:46:48	2020-06-12	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	7246	delivery	5	26
77359	2020-06-12 20:48:55	2020-06-12	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	30391	delivery	5	22
77360	2020-06-12 20:49:29	2020-06-12	12	[{"id_menu":1,"count":1}]	14010	delivery	5	17
77361	2020-06-12 20:50:21	2020-06-12	9	[{"id_menu":6,"count":1}]	26711	delivery	5	14
77362	2020-06-12 20:58:32	2020-06-12	8	[{"id_menu":5,"count":1}]	30450	delivery	5	13
77363	2020-06-12 21:04:32	2020-06-12	8	[{"id_menu":5,"count":1}]	3946	pick-up	0	8
77364	2020-06-12 21:08:00	2020-06-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	29929	delivery	5	28
77365	2020-06-12 21:14:30	2020-06-12	9	[{"id_menu":6,"count":1}]	30337	delivery	5	14
77366	2020-06-12 21:17:26	2020-06-12	9	[{"id_menu":6,"count":1}]	29054	delivery	5	14
77367	2020-06-12 21:17:56	2020-06-12	9	[{"id_menu":6,"count":1}]	10433	delivery	5	14
77368	2020-06-12 21:24:01	2020-06-12	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	30387	delivery	5	26
77369	2020-06-12 21:25:30	2020-06-12	9	[{"id_menu":6,"count":1}]	11666	delivery	5	14
77370	2020-06-12 21:27:08	2020-06-12	9	[{"id_menu":7,"count":1}]	25860	delivery	5	14
77371	2020-06-12 21:32:55	2020-06-12	14	[{"id_menu":2,"count":1}]	15769	delivery	5	19
77372	2020-06-12 21:35:13	2020-06-12	14	[{"id_menu":2,"count":1}]	27149	delivery	5	19
77373	2020-06-12 21:36:05	2020-06-12	12	[{"id_menu":1,"count":1}]	17770	delivery	5	17
77374	2020-06-12 21:36:44	2020-06-12	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	22564	delivery	5	34
77375	2020-06-12 21:37:07	2020-06-12	14	[{"id_menu":2,"count":1}]	1979	pick-up	0	14
77376	2020-06-12 21:40:34	2020-06-12	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	15590	delivery	5	28
77377	2020-06-12 21:42:35	2020-06-12	9	[{"id_menu":6,"count":1}]	30463	delivery	5	14
77378	2020-06-12 21:44:54	2020-06-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20989	pick-up	0	18
77379	2020-06-12 21:49:03	2020-06-12	9	[{"id_menu":7,"count":1}]	23914	delivery	5	14
77380	2020-06-12 21:55:08	2020-06-12	9	[{"id_menu":7,"count":1}]	30418	delivery	5	14
77381	2020-06-12 22:02:17	2020-06-12	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2758	delivery	5	36
77382	2020-06-12 22:03:32	2020-06-12	9	[{"id_menu":6,"count":2}]	30426	delivery	5	14
77383	2020-06-12 22:06:58	2020-06-12	9	[{"id_menu":7,"count":3}]	30482	delivery	5	14
77384	2020-06-12 22:06:59	2020-06-12	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29723	delivery	5	43
77385	2020-06-12 22:09:01	2020-06-12	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	21159	delivery	5	25
77386	2020-06-12 22:11:05	2020-06-12	9	[{"id_menu":7,"count":1}]	23294	pick-up	0	9
77387	2020-06-12 22:11:43	2020-06-12	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	667	delivery	5	34
77388	2020-06-12 22:12:20	2020-06-12	12	[{"id_menu":1,"count":1}]	24984	delivery	5	17
77389	2020-06-12 22:16:08	2020-06-12	9	[{"id_menu":6,"count":1}]	21130	pick-up	0	9
77390	2020-06-12 22:16:42	2020-06-12	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	28768	delivery	5	34
77391	2020-06-12 22:20:40	2020-06-12	17	[{"id_menu":4,"count":1}]	8070	delivery	5	22
77392	2020-06-12 22:21:51	2020-06-12	14	[{"id_menu":2,"count":1}]	30431	delivery	5	19
77393	2020-06-12 22:21:57	2020-06-12	17	[{"id_menu":4,"count":1}]	8098	pick-up	0	17
77394	2020-06-12 22:26:23	2020-06-12	8	[{"id_menu":5,"count":1}]	30336	delivery	5	13
77395	2020-06-12 22:29:51	2020-06-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30503	delivery	5	23
77396	2020-06-12 22:31:46	2020-06-12	9	[{"id_menu":6,"count":1}]	30481	delivery	5	14
77397	2020-06-12 22:34:22	2020-06-12	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	30355	delivery	5	30
77398	2020-06-12 22:35:49	2020-06-12	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	12391	delivery	5	26
77399	2020-06-12 22:36:55	2020-06-12	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	30490	delivery	5	42
77400	2020-06-12 22:37:45	2020-06-12	9	[{"id_menu":6,"count":1}]	2101	delivery	5	14
77401	2020-06-12 22:41:07	2020-06-12	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	30496	pick-up	0	34
77402	2020-06-12 22:43:40	2020-06-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	11983	delivery	5	28
77403	2020-06-12 22:51:54	2020-06-12	17	[{"id_menu":4,"count":1}]	30437	delivery	5	22
77404	2020-06-12 22:53:30	2020-06-12	8	[{"id_menu":5,"count":1}]	150	pick-up	0	8
77405	2020-06-12 23:01:05	2020-06-12	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14406	pick-up	0	29
77406	2020-06-12 23:03:28	2020-06-12	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	20452	pick-up	0	26
77407	2020-06-12 23:04:11	2020-06-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4832	delivery	5	28
77408	2020-06-12 23:04:56	2020-06-12	17	[{"id_menu":4,"count":1}]	8461	delivery	5	22
77409	2020-06-12 23:13:07	2020-06-12	9	[{"id_menu":6,"count":1}]	14615	delivery	5	14
77410	2020-06-12 23:15:52	2020-06-12	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	6465	pick-up	0	17
77411	2020-06-12 23:16:15	2020-06-12	9	[{"id_menu":6,"count":1}]	21167	delivery	5	14
77412	2020-06-12 23:26:40	2020-06-12	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30432	delivery	5	37
77413	2020-06-12 23:31:04	2020-06-12	12	[{"id_menu":3,"count":1}]	536	pick-up	0	12
77414	2020-06-12 23:36:31	2020-06-12	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	30488	pick-up	0	26
77415	2020-06-12 23:44:28	2020-06-12	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	25410	delivery	5	26
77416	2020-06-12 23:49:44	2020-06-12	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":2}]	5183	delivery	5	31
77417	2020-06-12 23:57:21	2020-06-12	8	[{"id_menu":5,"count":1}]	19364	delivery	5	13
77418	2020-06-12 23:57:55	2020-06-12	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1293	delivery	5	34
77419	2020-06-13 00:00:12	2020-06-13	9	[{"id_menu":6,"count":1}]	21377	delivery	5	14
77420	2020-06-13 00:01:12	2020-06-13	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	30523	delivery	5	34
77421	2020-06-13 00:02:09	2020-06-13	9	[{"id_menu":6,"count":1}]	29121	delivery	5	14
77422	2020-06-13 00:04:58	2020-06-13	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	7151	pick-up	0	35
77423	2020-06-13 00:05:20	2020-06-13	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14073	delivery	5	34
77424	2020-06-13 00:12:15	2020-06-13	14	[{"id_menu":2,"count":1}]	4841	pick-up	0	14
77425	2020-06-13 00:19:40	2020-06-13	12	[{"id_menu":1,"count":1}]	7605	pick-up	0	12
77426	2020-06-13 00:25:08	2020-06-13	9	[{"id_menu":6,"count":1}]	5739	delivery	5	14
77427	2020-06-13 00:25:17	2020-06-13	14	[{"id_menu":2,"count":2}]	30585	delivery	5	19
77428	2020-06-13 00:26:12	2020-06-13	17	[{"id_menu":4,"count":1}]	9323	delivery	5	22
77429	2020-06-13 00:29:00	2020-06-13	12	[{"id_menu":3,"count":1}]	18407	delivery	5	17
77430	2020-06-13 00:30:14	2020-06-13	17	[{"id_menu":4,"count":1}]	13767	pick-up	0	17
77431	2020-06-13 00:30:45	2020-06-13	12	[{"id_menu":1,"count":1}]	8021	delivery	5	17
77432	2020-06-13 00:33:04	2020-06-13	9	[{"id_menu":7,"count":1}]	29213	delivery	5	14
77433	2020-06-13 00:37:15	2020-06-13	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	24709	delivery	5	45
77434	2020-06-13 00:37:20	2020-06-13	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	16175	delivery	5	27
77435	2020-06-13 00:37:20	2020-06-13	9	[{"id_menu":7,"count":1}]	30516	delivery	5	14
77436	2020-06-13 00:38:08	2020-06-13	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	30602	delivery	5	27
77437	2020-06-13 00:42:51	2020-06-13	9	[{"id_menu":6,"count":2}]	30618	pick-up	0	9
77438	2020-06-13 00:43:37	2020-06-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	20579	delivery	5	28
77439	2020-06-13 00:44:19	2020-06-13	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10571	delivery	5	40
77440	2020-06-13 00:44:28	2020-06-13	14	[{"id_menu":2,"count":1}]	13961	delivery	5	19
77441	2020-06-13 00:44:46	2020-06-13	39	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	30698	delivery	5	44
77442	2020-06-13 00:44:49	2020-06-13	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	30686	delivery	5	26
77443	2020-06-13 00:45:02	2020-06-13	17	[{"id_menu":4,"count":1}]	27161	pick-up	0	17
77444	2020-06-13 00:48:00	2020-06-13	9	[{"id_menu":7,"count":1}]	12389	delivery	5	14
77445	2020-06-13 00:55:02	2020-06-13	8	[{"id_menu":5,"count":1}]	28754	delivery	5	13
77446	2020-06-13 00:57:36	2020-06-13	12	[{"id_menu":3,"count":1}]	21703	delivery	5	17
77447	2020-06-13 00:59:08	2020-06-13	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5649	delivery	5	37
77448	2020-06-13 00:59:44	2020-06-13	14	[{"id_menu":2,"count":1}]	30525	delivery	5	19
77449	2020-06-13 01:01:52	2020-06-13	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	25276	pick-up	0	21
77450	2020-06-13 01:02:43	2020-06-13	17	[{"id_menu":4,"count":1}]	30537	pick-up	0	17
77451	2020-06-13 01:04:58	2020-06-13	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	9360	delivery	5	28
77452	2020-06-13 01:06:25	2020-06-13	12	[{"id_menu":1,"count":1}]	25692	delivery	5	17
77453	2020-06-13 01:08:07	2020-06-13	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7606	delivery	5	36
77454	2020-06-13 01:13:46	2020-06-13	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7280	delivery	5	22
77455	2020-06-13 01:23:06	2020-06-13	8	[{"id_menu":5,"count":1}]	20630	delivery	5	13
77456	2020-06-13 01:24:38	2020-06-13	8	[{"id_menu":5,"count":1}]	30510	delivery	5	13
77457	2020-06-13 01:24:57	2020-06-13	12	[{"id_menu":1,"count":1}]	30515	pick-up	0	12
77458	2020-06-13 01:25:21	2020-06-13	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	13664	delivery	5	34
77459	2020-06-13 01:26:08	2020-06-13	14	[{"id_menu":2,"count":1}]	30639	delivery	5	19
77460	2020-06-13 01:27:56	2020-06-13	8	[{"id_menu":5,"count":1}]	30555	delivery	5	13
77461	2020-06-13 01:35:04	2020-06-13	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2347	delivery	5	26
77462	2020-06-13 01:45:20	2020-06-13	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	11172	delivery	5	23
77463	2020-06-13 01:46:52	2020-06-13	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6055	delivery	5	30
77464	2020-06-13 01:50:25	2020-06-13	12	[{"id_menu":1,"count":1}]	16064	delivery	5	17
77465	2020-06-13 01:51:10	2020-06-13	8	[{"id_menu":5,"count":1}]	30636	delivery	5	13
77466	2020-06-13 01:51:51	2020-06-13	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1859	pick-up	0	26
77467	2020-06-13 01:55:06	2020-06-13	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	9998	delivery	5	28
77468	2020-06-13 01:57:33	2020-06-13	14	[{"id_menu":2,"count":1}]	30534	delivery	5	19
77469	2020-06-13 01:59:56	2020-06-13	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	30545	delivery	5	28
77470	2020-06-13 02:01:54	2020-06-13	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	30592	delivery	5	25
77471	2020-06-13 02:03:22	2020-06-13	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	748	delivery	5	26
77472	2020-06-13 02:04:25	2020-06-13	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	30509	delivery	5	26
77473	2020-06-13 02:04:57	2020-06-13	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26769	delivery	5	37
77474	2020-06-13 02:05:38	2020-06-13	9	[{"id_menu":6,"count":1}]	23424	pick-up	0	9
77475	2020-06-13 02:08:08	2020-06-13	9	[{"id_menu":7,"count":1}]	2951	delivery	5	14
77476	2020-06-13 02:10:24	2020-06-13	8	[{"id_menu":5,"count":1}]	30634	pick-up	0	8
77477	2020-06-13 02:12:43	2020-06-13	9	[{"id_menu":6,"count":1}]	4933	delivery	5	14
77478	2020-06-13 02:13:07	2020-06-13	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	4242	pick-up	0	24
77479	2020-06-13 02:18:08	2020-06-13	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	26981	delivery	5	27
77480	2020-06-13 02:19:00	2020-06-13	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	30514	delivery	5	22
77481	2020-06-13 02:26:02	2020-06-13	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30615	delivery	5	35
77482	2020-06-13 02:28:43	2020-06-13	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	30706	delivery	5	56
77483	2020-06-13 02:28:55	2020-06-13	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15816	pick-up	0	26
77484	2020-06-13 02:34:05	2020-06-13	8	[{"id_menu":5,"count":1}]	3428	delivery	5	13
77485	2020-06-13 02:40:04	2020-06-13	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	30649	delivery	5	31
77486	2020-06-13 02:40:55	2020-06-13	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	26405	delivery	5	40
77487	2020-06-13 02:41:42	2020-06-13	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	29888	delivery	5	44
77488	2020-06-13 02:42:16	2020-06-13	9	[{"id_menu":7,"count":1}]	10882	delivery	5	14
77489	2020-06-13 02:44:16	2020-06-13	8	[{"id_menu":5,"count":1}]	3160	delivery	5	13
77490	2020-06-13 02:47:10	2020-06-13	9	[{"id_menu":6,"count":1}]	14171	delivery	5	14
77491	2020-06-13 02:49:51	2020-06-13	12	[{"id_menu":3,"count":1}]	16624	delivery	5	17
77492	2020-06-13 02:51:06	2020-06-13	14	[{"id_menu":2,"count":1}]	25860	delivery	5	19
77493	2020-06-13 02:51:30	2020-06-13	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10103	delivery	5	34
77494	2020-06-13 02:55:35	2020-06-13	9	[{"id_menu":6,"count":1}]	12912	pick-up	0	9
77495	2020-06-13 03:04:23	2020-06-13	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13365	delivery	5	49
77496	2020-06-13 03:05:15	2020-06-13	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	21610	delivery	5	25
77497	2020-06-13 03:10:45	2020-06-13	9	[{"id_menu":6,"count":1}]	30512	delivery	5	14
77498	2020-06-13 03:13:28	2020-06-13	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16312	delivery	5	43
77499	2020-06-13 03:17:57	2020-06-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29188	delivery	5	23
77500	2020-06-13 03:18:09	2020-06-13	17	[{"id_menu":4,"count":1}]	13851	delivery	5	22
77501	2020-06-13 03:18:46	2020-06-13	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10433	delivery	5	34
77502	2020-06-13 03:23:09	2020-06-13	9	[{"id_menu":6,"count":1}]	30520	delivery	5	14
77503	2020-06-13 03:26:14	2020-06-13	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	30528	delivery	5	40
77504	2020-06-13 03:31:25	2020-06-13	9	[{"id_menu":7,"count":1}]	15788	delivery	5	14
77505	2020-06-13 03:35:14	2020-06-13	8	[{"id_menu":5,"count":1}]	5930	delivery	5	13
77506	2020-06-13 03:35:37	2020-06-13	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	30684	delivery	5	22
77507	2020-06-13 03:36:05	2020-06-13	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	19382	pick-up	0	21
77508	2020-06-13 03:38:06	2020-06-13	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28670	delivery	5	35
77509	2020-06-13 03:38:47	2020-06-13	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	21989	delivery	5	26
77510	2020-06-13 03:43:12	2020-06-13	8	[{"id_menu":5,"count":1}]	28929	pick-up	0	8
77511	2020-06-13 03:44:16	2020-06-13	9	[{"id_menu":6,"count":1}]	30551	delivery	5	14
77512	2020-06-13 03:45:42	2020-06-13	17	[{"id_menu":4,"count":1}]	30588	delivery	5	22
77513	2020-06-13 03:50:20	2020-06-13	9	[{"id_menu":6,"count":1}]	6379	delivery	5	14
77514	2020-06-13 04:02:59	2020-06-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30608	delivery	5	23
77515	2020-06-13 04:06:43	2020-06-13	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	11239	pick-up	0	20
77516	2020-06-13 04:07:14	2020-06-13	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	868	delivery	5	31
77517	2020-06-13 04:07:54	2020-06-13	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	7227	delivery	5	25
77518	2020-06-13 04:10:26	2020-06-13	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19181	delivery	5	22
77519	2020-06-13 04:11:03	2020-06-13	17	[{"id_menu":4,"count":1}]	15171	delivery	5	22
77520	2020-06-13 04:11:54	2020-06-13	9	[{"id_menu":6,"count":1}]	29796	delivery	5	14
77521	2020-06-13 04:21:39	2020-06-13	14	[{"id_menu":2,"count":1}]	30527	delivery	5	19
77522	2020-06-13 04:22:07	2020-06-13	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	30687	pick-up	0	29
77523	2020-06-13 04:28:44	2020-06-13	9	[{"id_menu":7,"count":1}]	7814	pick-up	0	9
77524	2020-06-13 04:30:23	2020-06-13	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	30694	delivery	5	28
77525	2020-06-13 04:35:30	2020-06-13	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30617	delivery	5	54
77526	2020-06-13 04:39:33	2020-06-13	14	[{"id_menu":2,"count":1}]	26675	delivery	5	19
77527	2020-06-13 04:40:24	2020-06-13	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2511	delivery	5	31
77528	2020-06-13 04:43:25	2020-06-13	17	[{"id_menu":4,"count":1}]	6238	pick-up	0	17
77529	2020-06-13 04:44:52	2020-06-13	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":2}]	30647	delivery	5	22
77530	2020-06-13 04:48:37	2020-06-13	9	[{"id_menu":6,"count":1}]	29404	delivery	5	14
77531	2020-06-13 04:51:11	2020-06-13	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	23082	delivery	5	26
77532	2020-06-13 04:54:31	2020-06-13	14	[{"id_menu":2,"count":1}]	7862	pick-up	0	14
77533	2020-06-13 04:55:37	2020-06-13	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	15603	delivery	5	28
77534	2020-06-13 04:56:31	2020-06-13	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10738	pick-up	0	25
77535	2020-06-13 04:56:40	2020-06-13	17	[{"id_menu":4,"count":1}]	14641	pick-up	0	17
77536	2020-06-13 04:57:23	2020-06-13	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	20473	delivery	5	28
77537	2020-06-13 04:59:50	2020-06-13	8	[{"id_menu":5,"count":1}]	19056	delivery	5	13
77538	2020-06-13 05:00:04	2020-06-13	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23729	delivery	5	22
77539	2020-06-13 05:01:07	2020-06-13	14	[{"id_menu":2,"count":1}]	4985	pick-up	0	14
77540	2020-06-13 05:03:50	2020-06-13	9	[{"id_menu":7,"count":1}]	12129	pick-up	0	9
77541	2020-06-13 05:06:30	2020-06-13	8	[{"id_menu":5,"count":1}]	9308	pick-up	0	8
77542	2020-06-13 05:06:37	2020-06-13	9	[{"id_menu":6,"count":1}]	28130	delivery	5	14
77543	2020-06-13 05:07:33	2020-06-13	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	30547	pick-up	0	38
77544	2020-06-13 05:07:59	2020-06-13	9	[{"id_menu":6,"count":1}]	13563	delivery	5	14
77545	2020-06-13 05:08:55	2020-06-13	12	[{"id_menu":3,"count":1}]	6326	delivery	5	17
77546	2020-06-13 05:10:27	2020-06-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	30573	delivery	5	23
77547	2020-06-13 05:10:49	2020-06-13	17	[{"id_menu":4,"count":1}]	4495	delivery	5	22
77548	2020-06-13 05:12:12	2020-06-13	9	[{"id_menu":6,"count":1}]	638	pick-up	0	9
77549	2020-06-13 05:12:55	2020-06-13	12	[{"id_menu":1,"count":1}]	30549	delivery	5	17
77550	2020-06-13 05:17:17	2020-06-13	17	[{"id_menu":4,"count":1}]	6535	delivery	5	22
77551	2020-06-13 05:18:51	2020-06-13	14	[{"id_menu":2,"count":1}]	3223	delivery	5	19
77552	2020-06-13 05:19:13	2020-06-13	12	[{"id_menu":1,"count":1}]	6911	delivery	5	17
77553	2020-06-13 05:19:39	2020-06-13	9	[{"id_menu":6,"count":1}]	24820	delivery	5	14
77554	2020-06-13 05:21:40	2020-06-13	12	[{"id_menu":1,"count":1}]	24538	delivery	5	17
77555	2020-06-13 05:22:26	2020-06-13	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	25259	delivery	5	37
77556	2020-06-13 05:23:21	2020-06-13	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	30705	delivery	5	34
77557	2020-06-13 05:29:00	2020-06-13	12	[{"id_menu":1,"count":1}]	29477	delivery	5	17
77558	2020-06-13 05:32:31	2020-06-13	17	[{"id_menu":4,"count":1}]	17876	delivery	5	22
77559	2020-06-13 05:32:51	2020-06-13	9	[{"id_menu":6,"count":2}]	28943	delivery	5	14
77560	2020-06-13 05:36:16	2020-06-13	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	27795	delivery	5	39
77561	2020-06-13 05:42:07	2020-06-13	9	[{"id_menu":7,"count":1}]	24950	pick-up	0	9
77562	2020-06-13 05:46:04	2020-06-13	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	30679	delivery	5	39
77563	2020-06-13 05:48:21	2020-06-13	9	[{"id_menu":7,"count":1}]	16490	delivery	5	14
77564	2020-06-13 05:50:52	2020-06-13	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	30693	delivery	5	38
77565	2020-06-13 05:50:59	2020-06-13	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	23561	pick-up	0	26
77566	2020-06-13 05:56:19	2020-06-13	9	[{"id_menu":6,"count":1}]	14749	delivery	5	14
77567	2020-06-13 05:58:04	2020-06-13	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	30623	pick-up	0	21
77568	2020-06-13 05:59:09	2020-06-13	12	[{"id_menu":3,"count":1}]	18409	pick-up	0	12
77569	2020-06-13 06:02:49	2020-06-13	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	9039	delivery	5	31
77570	2020-06-13 06:03:15	2020-06-13	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	14608	delivery	5	36
77571	2020-06-13 06:04:35	2020-06-13	9	[{"id_menu":6,"count":1}]	3662	delivery	5	14
77572	2020-06-13 06:08:25	2020-06-13	9	[{"id_menu":7,"count":2}]	30557	delivery	5	14
77573	2020-06-13 06:08:31	2020-06-13	9	[{"id_menu":6,"count":2}]	13111	delivery	5	14
77574	2020-06-13 06:10:42	2020-06-13	9	[{"id_menu":7,"count":1}]	11266	delivery	5	14
77575	2020-06-13 06:11:52	2020-06-13	17	[{"id_menu":4,"count":1}]	20852	delivery	5	22
77576	2020-06-13 06:17:34	2020-06-13	12	[{"id_menu":1,"count":1}]	30521	pick-up	0	12
77577	2020-06-13 06:18:08	2020-06-13	9	[{"id_menu":7,"count":1}]	28456	pick-up	0	9
77578	2020-06-13 06:19:28	2020-06-13	8	[{"id_menu":5,"count":1}]	9250	pick-up	0	8
77579	2020-06-13 06:20:39	2020-06-13	12	[{"id_menu":3,"count":1}]	30589	delivery	5	17
77580	2020-06-13 06:22:52	2020-06-13	14	[{"id_menu":2,"count":1}]	30583	delivery	5	19
77581	2020-06-13 06:25:07	2020-06-13	8	[{"id_menu":5,"count":1}]	13855	pick-up	0	8
77582	2020-06-13 06:27:44	2020-06-13	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	5891	delivery	5	25
77583	2020-06-13 06:29:24	2020-06-13	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	13759	delivery	5	26
77584	2020-06-13 06:32:47	2020-06-13	14	[{"id_menu":2,"count":1}]	2060	delivery	5	19
77585	2020-06-13 06:36:50	2020-06-13	9	[{"id_menu":7,"count":1}]	18526	delivery	5	14
77586	2020-06-13 06:39:12	2020-06-13	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	25757	delivery	5	22
77587	2020-06-13 06:42:27	2020-06-13	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30605	delivery	5	35
77588	2020-06-13 06:44:23	2020-06-13	12	[{"id_menu":1,"count":1}]	5133	pick-up	0	12
77589	2020-06-13 06:45:31	2020-06-13	8	[{"id_menu":5,"count":1}]	9339	pick-up	0	8
77590	2020-06-13 06:47:30	2020-06-13	12	[{"id_menu":3,"count":1}]	16869	delivery	5	17
77591	2020-06-13 06:52:40	2020-06-13	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	27861	delivery	5	25
77592	2020-06-13 06:54:26	2020-06-13	9	[{"id_menu":6,"count":1}]	30593	delivery	5	14
77593	2020-06-13 06:54:59	2020-06-13	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	24479	delivery	5	28
77594	2020-06-13 06:55:37	2020-06-13	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	30658	delivery	5	22
77595	2020-06-13 06:57:19	2020-06-13	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	26361	delivery	5	26
77596	2020-06-13 07:01:51	2020-06-13	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	15995	delivery	5	27
77597	2020-06-13 07:12:03	2020-06-13	17	[{"id_menu":4,"count":1}]	7924	delivery	5	22
77598	2020-06-13 07:12:17	2020-06-13	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	30631	delivery	5	25
77599	2020-06-13 07:12:40	2020-06-13	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	30710	delivery	5	36
77600	2020-06-13 07:12:59	2020-06-13	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	21439	delivery	5	25
77601	2020-06-13 07:13:56	2020-06-13	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	25751	delivery	5	26
77602	2020-06-13 07:16:19	2020-06-13	9	[{"id_menu":6,"count":1}]	30556	delivery	5	14
77603	2020-06-13 07:17:03	2020-06-13	9	[{"id_menu":7,"count":1}]	7125	delivery	5	14
77604	2020-06-13 07:20:07	2020-06-13	8	[{"id_menu":5,"count":1}]	2187	delivery	5	13
77605	2020-06-13 07:20:43	2020-06-13	17	[{"id_menu":4,"count":1}]	30690	delivery	5	22
77606	2020-06-13 07:26:29	2020-06-13	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	16855	delivery	5	25
77607	2020-06-13 07:31:42	2020-06-13	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	26788	delivery	5	34
77608	2020-06-13 07:35:27	2020-06-13	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	15380	delivery	5	35
77609	2020-06-13 07:37:09	2020-06-13	12	[{"id_menu":1,"count":2}]	23206	delivery	5	17
77610	2020-06-13 07:41:31	2020-06-13	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	19836	delivery	5	31
77611	2020-06-13 07:41:46	2020-06-13	17	[{"id_menu":4,"count":1}]	1593	pick-up	0	17
77612	2020-06-13 07:41:47	2020-06-13	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10837	pick-up	0	25
77613	2020-06-13 07:42:04	2020-06-13	17	[{"id_menu":4,"count":1}]	16844	pick-up	0	17
77614	2020-06-13 07:45:32	2020-06-13	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	18307	delivery	5	27
77615	2020-06-13 07:45:44	2020-06-13	9	[{"id_menu":7,"count":1}]	30683	delivery	5	14
77616	2020-06-13 07:49:25	2020-06-13	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18590	delivery	5	40
77617	2020-06-13 07:49:52	2020-06-13	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	11477	delivery	5	27
77618	2020-06-13 07:50:00	2020-06-13	14	[{"id_menu":2,"count":1}]	3056	delivery	5	19
77619	2020-06-13 07:53:36	2020-06-13	14	[{"id_menu":2,"count":1}]	5427	pick-up	0	14
77620	2020-06-13 07:59:06	2020-06-13	9	[{"id_menu":6,"count":1}]	30630	delivery	5	14
77621	2020-06-13 08:00:13	2020-06-13	14	[{"id_menu":2,"count":1}]	30506	delivery	5	19
77622	2020-06-13 08:02:57	2020-06-13	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17408	delivery	5	31
77623	2020-06-13 08:03:11	2020-06-13	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	30413	delivery	5	28
77624	2020-06-13 08:04:10	2020-06-13	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	4913	delivery	5	26
77625	2020-06-13 08:07:04	2020-06-13	9	[{"id_menu":7,"count":1}]	9728	pick-up	0	9
77626	2020-06-13 08:08:59	2020-06-13	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	13518	delivery	5	40
77627	2020-06-13 08:13:23	2020-06-13	12	[{"id_menu":1,"count":1}]	30543	delivery	5	17
77628	2020-06-13 08:14:16	2020-06-13	14	[{"id_menu":2,"count":1}]	30664	pick-up	0	14
77629	2020-06-13 08:15:28	2020-06-13	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6134	pick-up	0	26
77630	2020-06-13 08:15:32	2020-06-13	9	[{"id_menu":7,"count":1}]	30531	pick-up	0	9
77631	2020-06-13 08:15:49	2020-06-13	8	[{"id_menu":5,"count":1}]	27609	delivery	5	13
77632	2020-06-13 08:18:50	2020-06-13	9	[{"id_menu":7,"count":1}]	7200	pick-up	0	9
77633	2020-06-13 08:20:32	2020-06-13	8	[{"id_menu":5,"count":1}]	30704	delivery	5	13
77634	2020-06-13 08:20:42	2020-06-13	9	[{"id_menu":7,"count":2}]	26178	delivery	5	14
77635	2020-06-13 08:21:18	2020-06-13	12	[{"id_menu":3,"count":1}]	7330	pick-up	0	12
77636	2020-06-13 08:23:01	2020-06-13	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	11969	pick-up	0	21
77637	2020-06-13 08:23:15	2020-06-13	9	[{"id_menu":7,"count":1}]	30016	delivery	5	14
77638	2020-06-13 08:23:50	2020-06-13	9	[{"id_menu":6,"count":2}]	17672	delivery	5	14
77639	2020-06-13 08:25:31	2020-06-13	9	[{"id_menu":6,"count":1}]	6678	delivery	5	14
77640	2020-06-13 08:30:04	2020-06-13	17	[{"id_menu":4,"count":1}]	30642	delivery	5	22
77641	2020-06-13 08:33:18	2020-06-13	9	[{"id_menu":6,"count":1}]	12314	delivery	5	14
77642	2020-06-13 08:33:40	2020-06-13	14	[{"id_menu":2,"count":1}]	14175	delivery	5	19
77643	2020-06-13 08:34:58	2020-06-13	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	30625	delivery	5	45
77644	2020-06-13 08:37:02	2020-06-13	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	30613	delivery	5	22
77645	2020-06-13 08:37:56	2020-06-13	12	[{"id_menu":3,"count":1}]	30581	delivery	5	17
77646	2020-06-13 08:40:30	2020-06-13	14	[{"id_menu":2,"count":1}]	793	pick-up	0	14
77647	2020-06-13 08:42:29	2020-06-13	9	[{"id_menu":7,"count":1}]	21493	delivery	5	14
77648	2020-06-13 08:46:19	2020-06-13	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	838	delivery	5	40
77649	2020-06-13 08:46:20	2020-06-13	9	[{"id_menu":6,"count":2}]	28706	delivery	5	14
77650	2020-06-13 08:48:40	2020-06-13	9	[{"id_menu":7,"count":1}]	30701	delivery	5	14
77651	2020-06-13 08:50:12	2020-06-13	17	[{"id_menu":4,"count":1}]	30536	delivery	5	22
77652	2020-06-13 08:51:11	2020-06-13	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	30540	pick-up	0	26
77653	2020-06-13 08:57:38	2020-06-13	17	[{"id_menu":4,"count":1}]	14813	delivery	5	22
77654	2020-06-13 08:58:48	2020-06-13	12	[{"id_menu":3,"count":1}]	14879	delivery	5	17
77655	2020-06-13 09:04:49	2020-06-13	8	[{"id_menu":5,"count":1}]	30517	delivery	5	13
77656	2020-06-13 09:05:03	2020-06-13	14	[{"id_menu":2,"count":1}]	30626	delivery	5	19
77657	2020-06-13 09:05:52	2020-06-13	9	[{"id_menu":6,"count":1}]	10719	delivery	5	14
77658	2020-06-13 09:09:21	2020-06-13	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1991	pick-up	0	26
77659	2020-06-13 09:09:43	2020-06-13	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14358	pick-up	0	44
77660	2020-06-13 09:12:11	2020-06-13	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26621	delivery	5	40
77661	2020-06-13 09:14:33	2020-06-13	9	[{"id_menu":6,"count":1}]	274	pick-up	0	9
77662	2020-06-13 09:15:28	2020-06-13	12	[{"id_menu":1,"count":1}]	28392	delivery	5	17
77663	2020-06-13 09:15:29	2020-06-13	9	[{"id_menu":6,"count":1}]	30532	delivery	5	14
77664	2020-06-13 09:15:47	2020-06-13	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30530	delivery	5	31
77665	2020-06-13 09:16:44	2020-06-13	9	[{"id_menu":7,"count":1}]	8753	delivery	5	14
77666	2020-06-13 09:18:48	2020-06-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	30601	delivery	5	36
77667	2020-06-13 09:18:49	2020-06-13	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	30672	delivery	5	45
77668	2020-06-13 09:19:00	2020-06-13	17	[{"id_menu":4,"count":1}]	30632	pick-up	0	17
77669	2020-06-13 09:20:52	2020-06-13	14	[{"id_menu":2,"count":1}]	21801	delivery	5	19
77670	2020-06-13 09:21:10	2020-06-13	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5681	delivery	5	55
77671	2020-06-13 09:25:01	2020-06-13	14	[{"id_menu":2,"count":1}]	30638	delivery	5	19
77672	2020-06-13 09:25:52	2020-06-13	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	24585	delivery	5	29
77673	2020-06-13 09:29:00	2020-06-13	14	[{"id_menu":2,"count":1}]	21978	delivery	5	19
77674	2020-06-13 09:41:36	2020-06-13	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9324	delivery	5	34
77675	2020-06-13 09:45:52	2020-06-13	12	[{"id_menu":1,"count":1}]	8666	delivery	5	17
77676	2020-06-13 09:50:59	2020-06-13	9	[{"id_menu":7,"count":1}]	28500	delivery	5	14
77677	2020-06-13 09:51:14	2020-06-13	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	17649	delivery	5	28
77678	2020-06-13 09:55:34	2020-06-13	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	20820	pick-up	0	22
77679	2020-06-13 09:56:52	2020-06-13	9	[{"id_menu":7,"count":1}]	27559	delivery	5	14
77680	2020-06-13 09:59:50	2020-06-13	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	628	delivery	5	31
77681	2020-06-13 10:00:29	2020-06-13	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	30689	delivery	5	51
77682	2020-06-13 10:06:38	2020-06-13	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6019	delivery	5	51
77683	2020-06-13 10:10:28	2020-06-13	8	[{"id_menu":5,"count":1}]	29722	delivery	5	13
77684	2020-06-13 10:10:32	2020-06-13	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	30546	pick-up	0	48
77685	2020-06-13 10:14:55	2020-06-13	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14212	delivery	5	31
77686	2020-06-13 10:18:15	2020-06-13	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30671	delivery	5	31
77687	2020-06-13 10:18:36	2020-06-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	17944	delivery	5	28
77688	2020-06-13 10:20:21	2020-06-13	17	[{"id_menu":4,"count":1}]	24973	pick-up	0	17
77689	2020-06-13 10:23:01	2020-06-13	8	[{"id_menu":5,"count":1}]	30579	delivery	5	13
77690	2020-06-13 10:25:52	2020-06-13	8	[{"id_menu":5,"count":1}]	7498	delivery	5	13
77691	2020-06-13 10:26:09	2020-06-13	12	[{"id_menu":3,"count":1}]	11395	delivery	5	17
77692	2020-06-13 10:26:11	2020-06-13	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18757	delivery	5	40
77693	2020-06-13 10:26:38	2020-06-13	9	[{"id_menu":6,"count":1}]	20373	pick-up	0	9
77694	2020-06-13 10:27:46	2020-06-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	30682	delivery	5	28
77695	2020-06-13 10:30:40	2020-06-13	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	29394	delivery	5	29
77696	2020-06-13 10:30:42	2020-06-13	14	[{"id_menu":2,"count":1}]	30595	pick-up	0	14
77697	2020-06-13 10:33:35	2020-06-13	12	[{"id_menu":3,"count":1}]	15018	delivery	5	17
77698	2020-06-13 10:34:23	2020-06-13	9	[{"id_menu":7,"count":1}]	30569	delivery	5	14
77699	2020-06-13 10:37:19	2020-06-13	9	[{"id_menu":7,"count":1}]	25492	delivery	5	14
77700	2020-06-13 10:38:00	2020-06-13	17	[{"id_menu":4,"count":1}]	20486	delivery	5	22
77701	2020-06-13 10:43:32	2020-06-13	9	[{"id_menu":6,"count":1}]	25299	delivery	5	14
77702	2020-06-13 10:45:44	2020-06-13	8	[{"id_menu":5,"count":1}]	12614	delivery	5	13
77703	2020-06-13 10:58:23	2020-06-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	15728	delivery	5	36
77704	2020-06-13 10:59:32	2020-06-13	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	30518	delivery	5	30
77705	2020-06-13 11:00:05	2020-06-13	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	19883	delivery	5	28
77706	2020-06-13 11:06:20	2020-06-13	17	[{"id_menu":4,"count":1}]	2089	delivery	5	22
77707	2020-06-13 11:07:31	2020-06-13	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	30709	delivery	5	45
77708	2020-06-13 11:08:52	2020-06-13	9	[{"id_menu":7,"count":1}]	25357	pick-up	0	9
77709	2020-06-13 11:09:33	2020-06-13	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	19097	delivery	5	31
77710	2020-06-13 11:10:19	2020-06-13	12	[{"id_menu":3,"count":1}]	24899	delivery	5	17
77711	2020-06-13 11:11:12	2020-06-13	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	23623	delivery	5	27
77712	2020-06-13 11:13:22	2020-06-13	12	[{"id_menu":3,"count":1}]	9017	delivery	5	17
77713	2020-06-13 11:15:01	2020-06-13	9	[{"id_menu":6,"count":2}]	22946	delivery	5	14
77714	2020-06-13 11:16:35	2020-06-13	8	[{"id_menu":5,"count":1}]	30553	delivery	5	13
77715	2020-06-13 11:22:56	2020-06-13	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	14777	delivery	5	30
77716	2020-06-13 11:23:43	2020-06-13	9	[{"id_menu":7,"count":1}]	8180	delivery	5	14
77717	2020-06-13 11:26:31	2020-06-13	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	698	delivery	5	31
77718	2020-06-13 11:31:44	2020-06-13	9	[{"id_menu":7,"count":1}]	30678	delivery	5	14
77719	2020-06-13 11:35:58	2020-06-13	14	[{"id_menu":2,"count":1}]	14123	delivery	5	19
77720	2020-06-13 11:36:23	2020-06-13	17	[{"id_menu":4,"count":1}]	21698	delivery	5	22
77721	2020-06-13 11:39:06	2020-06-13	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	10520	delivery	5	27
77722	2020-06-13 11:40:59	2020-06-13	9	[{"id_menu":7,"count":1}]	19235	delivery	5	14
77723	2020-06-13 11:41:19	2020-06-13	9	[{"id_menu":7,"count":1}]	27000	delivery	5	14
77724	2020-06-13 11:44:47	2020-06-13	17	[{"id_menu":4,"count":1}]	30541	pick-up	0	17
77725	2020-06-13 11:46:20	2020-06-13	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2334	pick-up	0	26
77726	2020-06-13 11:48:02	2020-06-13	9	[{"id_menu":6,"count":1}]	22643	delivery	5	14
77727	2020-06-13 11:48:57	2020-06-13	9	[{"id_menu":7,"count":1}]	18360	delivery	5	14
77728	2020-06-13 11:54:27	2020-06-13	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	18145	delivery	5	23
77729	2020-06-13 11:55:08	2020-06-13	8	[{"id_menu":5,"count":1}]	30526	delivery	5	13
77730	2020-06-13 11:55:17	2020-06-13	14	[{"id_menu":2,"count":1}]	12746	delivery	5	19
77731	2020-06-13 11:55:53	2020-06-13	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4662	delivery	5	31
77732	2020-06-13 11:57:04	2020-06-13	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	18593	delivery	5	22
77733	2020-06-13 12:00:48	2020-06-13	12	[{"id_menu":3,"count":1}]	11285	delivery	5	17
77734	2020-06-13 12:04:58	2020-06-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30627	delivery	5	23
77735	2020-06-13 12:05:09	2020-06-13	9	[{"id_menu":7,"count":1}]	30650	delivery	5	14
77736	2020-06-13 12:10:29	2020-06-13	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	2543	delivery	5	48
77737	2020-06-13 12:13:16	2020-06-13	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	30567	delivery	5	26
77738	2020-06-13 12:15:28	2020-06-13	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14125	delivery	5	40
77739	2020-06-13 12:17:02	2020-06-13	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30604	delivery	5	54
77740	2020-06-13 12:18:39	2020-06-13	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3629	delivery	5	31
77741	2020-06-13 12:27:03	2020-06-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30696	delivery	5	23
77742	2020-06-13 12:31:41	2020-06-13	17	[{"id_menu":4,"count":1}]	26326	pick-up	0	17
77743	2020-06-13 12:32:07	2020-06-13	12	[{"id_menu":1,"count":1}]	18572	delivery	5	17
77744	2020-06-13 12:33:20	2020-06-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	27198	pick-up	0	23
77745	2020-06-13 12:40:10	2020-06-13	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	30571	delivery	5	48
77746	2020-06-13 12:41:30	2020-06-13	17	[{"id_menu":4,"count":1}]	30563	delivery	5	22
77747	2020-06-13 12:43:29	2020-06-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	13749	delivery	5	23
77748	2020-06-13 12:47:37	2020-06-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	14364	delivery	5	28
77749	2020-06-13 12:50:40	2020-06-13	14	[{"id_menu":2,"count":1}]	4292	delivery	5	19
77750	2020-06-13 12:53:11	2020-06-13	8	[{"id_menu":5,"count":1}]	23416	delivery	5	13
77751	2020-06-13 12:53:45	2020-06-13	12	[{"id_menu":3,"count":1}]	16592	delivery	5	17
77752	2020-06-13 12:55:18	2020-06-13	12	[{"id_menu":1,"count":1}]	6009	pick-up	0	12
77753	2020-06-13 13:00:59	2020-06-13	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	30695	delivery	5	26
77754	2020-06-13 13:02:02	2020-06-13	9	[{"id_menu":6,"count":1}]	20787	delivery	5	14
77755	2020-06-13 13:05:19	2020-06-13	17	[{"id_menu":4,"count":1}]	30508	delivery	5	22
77756	2020-06-13 13:06:09	2020-06-13	9	[{"id_menu":6,"count":1}]	30666	delivery	5	14
77757	2020-06-13 13:08:51	2020-06-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3260	delivery	5	23
77758	2020-06-13 13:11:40	2020-06-13	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	3648	delivery	5	37
77759	2020-06-13 13:13:17	2020-06-13	8	[{"id_menu":5,"count":1}]	15168	delivery	5	13
77760	2020-06-13 13:13:37	2020-06-13	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29851	delivery	5	22
77761	2020-06-13 13:13:46	2020-06-13	12	[{"id_menu":1,"count":1}]	30702	delivery	5	17
77762	2020-06-13 13:17:20	2020-06-13	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7143	delivery	5	31
77763	2020-06-13 13:18:13	2020-06-13	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	13444	delivery	5	30
77764	2020-06-13 13:22:23	2020-06-13	14	[{"id_menu":2,"count":1}]	30584	delivery	5	19
77765	2020-06-13 13:24:46	2020-06-13	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	30708	delivery	5	31
77766	2020-06-13 13:26:12	2020-06-13	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	30628	pick-up	0	38
77767	2020-06-13 13:30:41	2020-06-13	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	3507	pick-up	0	21
77768	2020-06-13 13:32:19	2020-06-13	14	[{"id_menu":2,"count":1}]	16550	pick-up	0	14
77769	2020-06-13 13:33:21	2020-06-13	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18667	delivery	5	22
77770	2020-06-13 13:38:30	2020-06-13	8	[{"id_menu":5,"count":1}]	30697	pick-up	0	8
77771	2020-06-13 13:39:38	2020-06-13	17	[{"id_menu":4,"count":1}]	48	delivery	5	22
77772	2020-06-13 13:40:20	2020-06-13	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	30511	delivery	5	22
77773	2020-06-13 13:43:31	2020-06-13	9	[{"id_menu":6,"count":1}]	30641	delivery	5	14
77774	2020-06-13 13:46:48	2020-06-13	12	[{"id_menu":3,"count":1}]	24707	delivery	5	17
77775	2020-06-13 13:50:37	2020-06-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	10793	delivery	5	28
77776	2020-06-13 13:51:18	2020-06-13	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	22415	delivery	5	52
77777	2020-06-13 13:51:31	2020-06-13	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	20807	delivery	5	31
77778	2020-06-13 13:56:50	2020-06-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7899	delivery	5	28
77779	2020-06-13 13:58:36	2020-06-13	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	701	pick-up	0	33
77780	2020-06-13 13:59:45	2020-06-13	8	[{"id_menu":5,"count":1}]	13621	delivery	5	13
77781	2020-06-13 14:01:50	2020-06-13	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4790	pick-up	0	30
77782	2020-06-13 14:02:55	2020-06-13	12	[{"id_menu":3,"count":1}]	30596	delivery	5	17
77783	2020-06-13 14:03:41	2020-06-13	14	[{"id_menu":2,"count":1}]	16434	pick-up	0	14
77784	2020-06-13 14:03:43	2020-06-13	17	[{"id_menu":4,"count":1}]	21552	delivery	5	22
77785	2020-06-13 14:05:56	2020-06-13	9	[{"id_menu":7,"count":1}]	9115	pick-up	0	9
77786	2020-06-13 14:12:37	2020-06-13	14	[{"id_menu":2,"count":2}]	30513	delivery	5	19
77787	2020-06-13 14:15:00	2020-06-13	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7727	delivery	5	40
77788	2020-06-13 14:15:30	2020-06-13	12	[{"id_menu":3,"count":1}]	9723	delivery	5	17
77789	2020-06-13 14:18:04	2020-06-13	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	13446	delivery	5	26
77790	2020-06-13 14:19:48	2020-06-13	9	[{"id_menu":7,"count":1}]	30586	delivery	5	14
77791	2020-06-13 14:20:40	2020-06-13	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	19656	delivery	5	28
77792	2020-06-13 14:21:38	2020-06-13	14	[{"id_menu":2,"count":1}]	11342	delivery	5	19
77793	2020-06-13 14:23:17	2020-06-13	14	[{"id_menu":2,"count":2}]	5917	pick-up	0	14
77794	2020-06-13 14:25:01	2020-06-13	12	[{"id_menu":1,"count":1}]	30665	delivery	5	17
77795	2020-06-13 14:28:35	2020-06-13	9	[{"id_menu":6,"count":1}]	30578	delivery	5	14
77796	2020-06-13 14:28:35	2020-06-13	14	[{"id_menu":2,"count":1}]	25432	delivery	5	19
77797	2020-06-13 14:28:42	2020-06-13	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	30674	delivery	5	45
77798	2020-06-13 14:31:26	2020-06-13	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	30566	delivery	5	26
77799	2020-06-13 14:34:19	2020-06-13	9	[{"id_menu":7,"count":1}]	30542	delivery	5	14
77800	2020-06-13 14:36:05	2020-06-13	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	30700	delivery	5	56
77867	2020-06-13 17:16:00	2020-06-13	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	30637	delivery	5	34
77801	2020-06-13 14:38:59	2020-06-13	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22053	pick-up	0	31
77802	2020-06-13 14:43:23	2020-06-13	12	[{"id_menu":3,"count":1}]	4633	delivery	5	17
77803	2020-06-13 14:45:25	2020-06-13	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10298	delivery	5	22
77804	2020-06-13 14:47:40	2020-06-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	15319	delivery	5	36
77805	2020-06-13 14:49:36	2020-06-13	12	[{"id_menu":1,"count":1}]	8726	delivery	5	17
77806	2020-06-13 14:50:01	2020-06-13	17	[{"id_menu":4,"count":1}]	12648	pick-up	0	17
77807	2020-06-13 14:55:01	2020-06-13	17	[{"id_menu":4,"count":1}]	3332	pick-up	0	17
77808	2020-06-13 14:55:29	2020-06-13	8	[{"id_menu":5,"count":1}]	30692	delivery	5	13
77809	2020-06-13 14:57:35	2020-06-13	12	[{"id_menu":3,"count":1}]	30657	delivery	5	17
77810	2020-06-13 14:58:15	2020-06-13	17	[{"id_menu":4,"count":1}]	5201	pick-up	0	17
77811	2020-06-13 15:00:29	2020-06-13	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27613	delivery	5	45
77812	2020-06-13 15:02:42	2020-06-13	8	[{"id_menu":5,"count":1}]	20849	delivery	5	13
77813	2020-06-13 15:05:09	2020-06-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8193	delivery	5	23
77814	2020-06-13 15:09:05	2020-06-13	17	[{"id_menu":4,"count":1}]	30713	delivery	5	22
77815	2020-06-13 15:12:21	2020-06-13	14	[{"id_menu":2,"count":1}]	30607	pick-up	0	14
77816	2020-06-13 15:13:39	2020-06-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20883	delivery	5	23
77817	2020-06-13 15:19:06	2020-06-13	8	[{"id_menu":5,"count":1}]	7206	pick-up	0	8
77818	2020-06-13 15:19:13	2020-06-13	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	30558	delivery	5	25
77819	2020-06-13 15:19:39	2020-06-13	9	[{"id_menu":7,"count":1}]	17805	delivery	5	14
77820	2020-06-13 15:19:50	2020-06-13	9	[{"id_menu":7,"count":2}]	23221	pick-up	0	9
77821	2020-06-13 15:23:47	2020-06-13	12	[{"id_menu":3,"count":1}]	6110	pick-up	0	12
77822	2020-06-13 15:25:30	2020-06-13	17	[{"id_menu":4,"count":1}]	30645	delivery	5	22
77823	2020-06-13 15:25:39	2020-06-13	17	[{"id_menu":4,"count":1}]	30562	pick-up	0	17
77824	2020-06-13 15:29:44	2020-06-13	9	[{"id_menu":7,"count":1}]	12040	delivery	5	14
77825	2020-06-13 15:31:34	2020-06-13	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	4850	pick-up	0	21
77826	2020-06-13 15:33:53	2020-06-13	12	[{"id_menu":1,"count":1}]	30614	delivery	5	17
77827	2020-06-13 15:33:55	2020-06-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29164	delivery	5	23
77828	2020-06-13 15:36:25	2020-06-13	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	21002	pick-up	0	26
77829	2020-06-13 15:37:14	2020-06-13	9	[{"id_menu":7,"count":1}]	4436	pick-up	0	9
77830	2020-06-13 15:39:53	2020-06-13	12	[{"id_menu":3,"count":1}]	8148	pick-up	0	12
77831	2020-06-13 15:40:12	2020-06-13	12	[{"id_menu":1,"count":1}]	2633	delivery	5	17
77832	2020-06-13 15:40:21	2020-06-13	9	[{"id_menu":6,"count":1}]	30643	delivery	5	14
77833	2020-06-13 15:47:30	2020-06-13	9	[{"id_menu":7,"count":1}]	15600	delivery	5	14
77834	2020-06-13 15:57:56	2020-06-13	8	[{"id_menu":5,"count":1}]	29469	delivery	5	13
77835	2020-06-13 16:03:30	2020-06-13	8	[{"id_menu":5,"count":1}]	14361	delivery	5	13
77836	2020-06-13 16:04:34	2020-06-13	9	[{"id_menu":7,"count":1}]	9567	delivery	5	14
77837	2020-06-13 16:04:38	2020-06-13	39	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	21590	delivery	5	44
77838	2020-06-13 16:08:03	2020-06-13	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11573	delivery	5	40
77839	2020-06-13 16:10:51	2020-06-13	9	[{"id_menu":6,"count":2}]	8286	pick-up	0	9
77840	2020-06-13 16:16:11	2020-06-13	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11181	delivery	5	47
77841	2020-06-13 16:18:33	2020-06-13	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	30572	delivery	5	45
77842	2020-06-13 16:20:32	2020-06-13	9	[{"id_menu":6,"count":1}]	10807	pick-up	0	9
77843	2020-06-13 16:20:51	2020-06-13	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	30554	delivery	5	25
77844	2020-06-13 16:20:51	2020-06-13	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1536	pick-up	0	38
77845	2020-06-13 16:21:33	2020-06-13	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27494	delivery	5	37
77846	2020-06-13 16:24:51	2020-06-13	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	30580	delivery	5	48
77847	2020-06-13 16:29:19	2020-06-13	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	30256	pick-up	0	35
77848	2020-06-13 16:31:45	2020-06-13	12	[{"id_menu":3,"count":1}]	17702	delivery	5	17
77849	2020-06-13 16:33:45	2020-06-13	9	[{"id_menu":7,"count":1}]	30621	delivery	5	14
77850	2020-06-13 16:37:35	2020-06-13	9	[{"id_menu":6,"count":1}]	25936	delivery	5	14
77851	2020-06-13 16:38:05	2020-06-13	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	30568	delivery	5	34
77852	2020-06-13 16:41:53	2020-06-13	8	[{"id_menu":5,"count":1}]	30561	delivery	5	13
77853	2020-06-13 16:42:33	2020-06-13	9	[{"id_menu":7,"count":1}]	25561	delivery	5	14
77854	2020-06-13 16:43:27	2020-06-13	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2891	pick-up	0	26
77855	2020-06-13 16:48:28	2020-06-13	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	787	pick-up	0	25
77856	2020-06-13 16:51:53	2020-06-13	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	30574	delivery	5	45
77857	2020-06-13 16:52:27	2020-06-13	14	[{"id_menu":2,"count":1}]	5013	delivery	5	19
77858	2020-06-13 16:55:23	2020-06-13	9	[{"id_menu":7,"count":1}]	9044	delivery	5	14
77859	2020-06-13 16:55:26	2020-06-13	14	[{"id_menu":2,"count":1}]	17415	delivery	5	19
77860	2020-06-13 16:56:46	2020-06-13	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	27860	delivery	5	26
77861	2020-06-13 17:01:45	2020-06-13	9	[{"id_menu":7,"count":1}]	16535	delivery	5	14
77862	2020-06-13 17:01:51	2020-06-13	9	[{"id_menu":6,"count":1}]	10680	delivery	5	14
77863	2020-06-13 17:06:51	2020-06-13	14	[{"id_menu":2,"count":1}]	18202	pick-up	0	14
77864	2020-06-13 17:13:16	2020-06-13	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3825	pick-up	0	17
77865	2020-06-13 17:14:01	2020-06-13	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	30113	delivery	5	40
77866	2020-06-13 17:15:33	2020-06-13	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	30640	delivery	5	26
77868	2020-06-13 17:18:23	2020-06-13	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	30611	delivery	5	51
77869	2020-06-13 17:19:30	2020-06-13	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":2}]	7049	delivery	5	28
77870	2020-06-13 17:19:51	2020-06-13	12	[{"id_menu":1,"count":1}]	30648	delivery	5	17
77871	2020-06-13 17:20:30	2020-06-13	9	[{"id_menu":6,"count":1}]	30539	delivery	5	14
77872	2020-06-13 17:20:52	2020-06-13	9	[{"id_menu":6,"count":2}]	19196	pick-up	0	9
77873	2020-06-13 17:21:21	2020-06-13	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	13891	delivery	5	42
77874	2020-06-13 17:25:16	2020-06-13	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3170	delivery	5	27
77875	2020-06-13 17:30:41	2020-06-13	12	[{"id_menu":1,"count":1}]	12602	pick-up	0	12
77876	2020-06-13 17:34:33	2020-06-13	8	[{"id_menu":5,"count":3}]	6627	delivery	5	13
77877	2020-06-13 17:38:14	2020-06-13	17	[{"id_menu":4,"count":1}]	30616	delivery	5	22
77878	2020-06-13 17:38:16	2020-06-13	8	[{"id_menu":5,"count":2}]	9733	delivery	5	13
77879	2020-06-13 17:39:03	2020-06-13	9	[{"id_menu":6,"count":2}]	12631	pick-up	0	9
77880	2020-06-13 17:42:26	2020-06-13	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	28600	delivery	5	31
77881	2020-06-13 17:51:18	2020-06-13	9	[{"id_menu":7,"count":1}]	27530	pick-up	0	9
77882	2020-06-13 17:51:26	2020-06-13	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	23164	delivery	5	22
77883	2020-06-13 17:52:01	2020-06-13	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	30533	delivery	5	31
77884	2020-06-13 17:52:40	2020-06-13	9	[{"id_menu":6,"count":1}]	18755	pick-up	0	9
77885	2020-06-13 17:55:11	2020-06-13	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20392	delivery	5	39
77886	2020-06-13 17:57:05	2020-06-13	12	[{"id_menu":3,"count":1}]	11201	pick-up	0	12
77887	2020-06-13 17:59:58	2020-06-13	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	30594	delivery	5	31
77888	2020-06-13 18:03:36	2020-06-13	17	[{"id_menu":4,"count":1}]	30622	delivery	5	22
77889	2020-06-13 18:06:05	2020-06-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	30656	delivery	5	36
77890	2020-06-13 18:07:07	2020-06-13	9	[{"id_menu":7,"count":1}]	26916	delivery	5	14
77891	2020-06-13 18:07:08	2020-06-13	12	[{"id_menu":1,"count":2}]	1531	pick-up	0	12
77892	2020-06-13 18:07:40	2020-06-13	8	[{"id_menu":5,"count":1}]	30712	delivery	5	13
77893	2020-06-13 18:10:25	2020-06-13	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	29312	delivery	5	22
77894	2020-06-13 18:10:44	2020-06-13	9	[{"id_menu":6,"count":1}]	2734	delivery	5	14
77895	2020-06-13 18:14:25	2020-06-13	14	[{"id_menu":2,"count":1}]	25292	delivery	5	19
77896	2020-06-13 18:15:25	2020-06-13	9	[{"id_menu":6,"count":1}]	30685	delivery	5	14
77897	2020-06-13 18:16:14	2020-06-13	9	[{"id_menu":6,"count":1}]	3851	pick-up	0	9
77898	2020-06-13 18:16:38	2020-06-13	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	30565	pick-up	0	17
77899	2020-06-13 18:18:22	2020-06-13	9	[{"id_menu":7,"count":1}]	30612	delivery	5	14
77900	2020-06-13 18:19:59	2020-06-13	9	[{"id_menu":6,"count":1}]	19132	delivery	5	14
77901	2020-06-13 18:21:12	2020-06-13	12	[{"id_menu":1,"count":1}]	30707	delivery	5	17
77902	2020-06-13 18:21:18	2020-06-13	14	[{"id_menu":2,"count":1}]	25571	pick-up	0	14
77903	2020-06-13 18:25:46	2020-06-13	12	[{"id_menu":1,"count":1}]	29547	delivery	5	17
77904	2020-06-13 18:28:02	2020-06-13	12	[{"id_menu":3,"count":1}]	6090	pick-up	0	12
77905	2020-06-13 18:30:42	2020-06-13	12	[{"id_menu":3,"count":1}]	30575	delivery	5	17
77906	2020-06-13 18:31:14	2020-06-13	8	[{"id_menu":5,"count":1}]	30676	delivery	5	13
77907	2020-06-13 18:32:29	2020-06-13	12	[{"id_menu":3,"count":1}]	28827	pick-up	0	12
77908	2020-06-13 18:33:07	2020-06-13	17	[{"id_menu":4,"count":1}]	11126	delivery	5	22
77909	2020-06-13 18:35:33	2020-06-13	9	[{"id_menu":7,"count":1}]	30519	pick-up	0	9
77910	2020-06-13 18:38:07	2020-06-13	9	[{"id_menu":6,"count":1}]	18557	pick-up	0	9
77911	2020-06-13 18:44:16	2020-06-13	12	[{"id_menu":3,"count":1}]	30606	delivery	5	17
77912	2020-06-13 18:44:41	2020-06-13	8	[{"id_menu":5,"count":1}]	27247	delivery	5	13
77913	2020-06-13 18:47:29	2020-06-13	9	[{"id_menu":7,"count":1}]	30587	delivery	5	14
77914	2020-06-13 18:49:41	2020-06-13	12	[{"id_menu":1,"count":1}]	10109	delivery	5	17
77915	2020-06-13 18:55:40	2020-06-13	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2176	pick-up	0	20
77916	2020-06-13 18:55:52	2020-06-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	30600	pick-up	0	31
77917	2020-06-13 18:56:17	2020-06-13	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28060	delivery	5	39
77918	2020-06-13 19:00:30	2020-06-13	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	30711	delivery	5	25
77919	2020-06-13 19:05:58	2020-06-13	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	30603	delivery	5	26
77920	2020-06-13 19:07:27	2020-06-13	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	26622	delivery	5	40
77921	2020-06-13 19:10:30	2020-06-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3573	pick-up	0	23
77922	2020-06-13 19:11:57	2020-06-13	14	[{"id_menu":2,"count":1}]	30576	delivery	5	19
77923	2020-06-13 19:13:03	2020-06-13	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1792	delivery	5	26
77924	2020-06-13 19:13:52	2020-06-13	17	[{"id_menu":4,"count":1}]	24587	delivery	5	22
77925	2020-06-13 19:16:54	2020-06-13	12	[{"id_menu":3,"count":1}]	17664	delivery	5	17
77926	2020-06-13 19:20:42	2020-06-13	8	[{"id_menu":5,"count":1}]	27070	pick-up	0	8
77927	2020-06-13 19:23:20	2020-06-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	28313	delivery	5	28
77928	2020-06-13 19:23:38	2020-06-13	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	4674	delivery	5	22
77929	2020-06-13 19:28:00	2020-06-13	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	18060	pick-up	0	38
77930	2020-06-13 19:30:33	2020-06-13	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	29900	delivery	5	42
77931	2020-06-13 19:34:56	2020-06-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	8491	delivery	5	28
77932	2020-06-13 19:37:21	2020-06-13	14	[{"id_menu":2,"count":1}]	30597	delivery	5	19
77933	2020-06-13 19:41:58	2020-06-13	8	[{"id_menu":5,"count":1}]	30524	delivery	5	13
77934	2020-06-13 19:45:18	2020-06-13	17	[{"id_menu":4,"count":1}]	25895	delivery	5	22
77935	2020-06-13 19:45:35	2020-06-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	17000	delivery	5	28
77936	2020-06-13 19:45:54	2020-06-13	9	[{"id_menu":6,"count":1}]	30660	pick-up	0	9
77937	2020-06-13 19:48:07	2020-06-13	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	21064	delivery	5	42
77938	2020-06-13 19:48:17	2020-06-13	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	13535	delivery	5	26
77939	2020-06-13 19:49:33	2020-06-13	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	6652	delivery	5	34
77940	2020-06-13 19:50:23	2020-06-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30635	delivery	5	23
77941	2020-06-13 19:51:34	2020-06-13	17	[{"id_menu":4,"count":1}]	14127	pick-up	0	17
77942	2020-06-13 19:52:47	2020-06-13	9	[{"id_menu":6,"count":1}]	30624	delivery	5	14
77943	2020-06-13 19:54:59	2020-06-13	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	15044	delivery	5	26
77944	2020-06-13 19:58:15	2020-06-13	9	[{"id_menu":7,"count":1}]	7101	delivery	5	14
77945	2020-06-13 20:02:22	2020-06-13	8	[{"id_menu":5,"count":1}]	9083	pick-up	0	8
77946	2020-06-13 20:02:41	2020-06-13	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	30655	delivery	5	30
77947	2020-06-13 20:04:05	2020-06-13	8	[{"id_menu":5,"count":1}]	3997	delivery	5	13
77948	2020-06-13 20:05:29	2020-06-13	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	30591	pick-up	0	35
77949	2020-06-13 20:06:46	2020-06-13	9	[{"id_menu":7,"count":1}]	6173	pick-up	0	9
77950	2020-06-13 20:07:27	2020-06-13	9	[{"id_menu":7,"count":1}]	1313	delivery	5	14
77951	2020-06-13 20:09:27	2020-06-13	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	17019	delivery	5	48
77952	2020-06-13 20:09:42	2020-06-13	14	[{"id_menu":2,"count":1}]	30610	delivery	5	19
77953	2020-06-13 20:11:43	2020-06-13	9	[{"id_menu":6,"count":1}]	30675	pick-up	0	9
77954	2020-06-13 20:12:47	2020-06-13	14	[{"id_menu":2,"count":1}]	28059	pick-up	0	14
77955	2020-06-13 20:22:27	2020-06-13	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6736	delivery	5	28
77956	2020-06-13 20:24:51	2020-06-13	14	[{"id_menu":2,"count":1}]	29964	delivery	5	19
77957	2020-06-13 20:25:17	2020-06-13	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16858	pick-up	0	34
77958	2020-06-13 20:26:41	2020-06-13	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	30535	delivery	5	42
77959	2020-06-13 20:27:01	2020-06-13	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	12793	delivery	5	31
77960	2020-06-13 20:29:57	2020-06-13	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	18240	delivery	5	40
77961	2020-06-13 20:32:25	2020-06-13	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	30633	delivery	5	28
77962	2020-06-13 20:32:51	2020-06-13	8	[{"id_menu":5,"count":1}]	27092	delivery	5	13
77963	2020-06-13 20:33:41	2020-06-13	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	6790	delivery	5	34
77964	2020-06-13 20:34:34	2020-06-13	12	[{"id_menu":1,"count":1}]	4957	pick-up	0	12
77965	2020-06-13 20:37:11	2020-06-13	17	[{"id_menu":4,"count":1}]	11248	delivery	5	22
77966	2020-06-13 20:38:11	2020-06-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	19143	delivery	5	28
77967	2020-06-13 20:39:49	2020-06-13	17	[{"id_menu":4,"count":1}]	3318	pick-up	0	17
77968	2020-06-13 20:45:23	2020-06-13	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30560	delivery	5	35
77969	2020-06-13 20:46:44	2020-06-13	8	[{"id_menu":5,"count":1}]	4347	delivery	5	13
77970	2020-06-13 20:48:44	2020-06-13	9	[{"id_menu":7,"count":1}]	2216	delivery	5	14
77971	2020-06-13 20:49:27	2020-06-13	12	[{"id_menu":1,"count":1}]	17366	delivery	5	17
77972	2020-06-13 20:49:32	2020-06-13	9	[{"id_menu":7,"count":1}]	30663	pick-up	0	9
77973	2020-06-13 20:53:40	2020-06-13	9	[{"id_menu":6,"count":1}]	10279	pick-up	0	9
77974	2020-06-13 20:59:16	2020-06-13	8	[{"id_menu":5,"count":1}]	4778	delivery	5	13
77975	2020-06-13 21:04:18	2020-06-13	12	[{"id_menu":1,"count":1}]	30699	delivery	5	17
77976	2020-06-13 21:09:00	2020-06-13	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	30653	delivery	5	30
77977	2020-06-13 21:09:13	2020-06-13	17	[{"id_menu":4,"count":1}]	15715	pick-up	0	17
77978	2020-06-13 21:15:44	2020-06-13	9	[{"id_menu":7,"count":1}]	24643	pick-up	0	9
77979	2020-06-13 21:15:51	2020-06-13	14	[{"id_menu":2,"count":1}]	30550	delivery	5	19
77980	2020-06-13 21:17:18	2020-06-13	8	[{"id_menu":5,"count":1}]	30564	delivery	5	13
77981	2020-06-13 21:18:38	2020-06-13	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	26386	delivery	5	26
77982	2020-06-13 21:20:43	2020-06-13	9	[{"id_menu":7,"count":1}]	8795	delivery	5	14
77983	2020-06-13 21:27:47	2020-06-13	9	[{"id_menu":6,"count":2}]	30668	delivery	5	14
77984	2020-06-13 21:28:26	2020-06-13	14	[{"id_menu":2,"count":1}]	30544	delivery	5	19
77985	2020-06-13 21:32:13	2020-06-13	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	14531	pick-up	0	20
77986	2020-06-13 21:33:49	2020-06-13	9	[{"id_menu":6,"count":1}]	24885	delivery	5	14
77987	2020-06-13 21:35:25	2020-06-13	12	[{"id_menu":1,"count":1}]	30669	pick-up	0	12
77988	2020-06-13 21:36:16	2020-06-13	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	30703	pick-up	0	21
77989	2020-06-13 21:39:10	2020-06-13	8	[{"id_menu":5,"count":1}]	28700	delivery	5	13
77990	2020-06-13 21:39:12	2020-06-13	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	30646	delivery	5	27
77991	2020-06-13 21:40:16	2020-06-13	17	[{"id_menu":4,"count":1}]	3103	delivery	5	22
77992	2020-06-13 21:40:22	2020-06-13	8	[{"id_menu":5,"count":1}]	30688	delivery	5	13
77993	2020-06-13 21:41:38	2020-06-13	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	10653	delivery	5	23
77994	2020-06-13 21:41:51	2020-06-13	46	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1042	delivery	5	51
77995	2020-06-13 21:43:55	2020-06-13	14	[{"id_menu":2,"count":1}]	30529	delivery	5	19
77996	2020-06-13 21:45:06	2020-06-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	12078	delivery	5	36
77997	2020-06-13 21:46:42	2020-06-13	9	[{"id_menu":7,"count":1}]	17005	delivery	5	14
77998	2020-06-13 21:48:09	2020-06-13	12	[{"id_menu":1,"count":1}]	30552	delivery	5	17
77999	2020-06-13 21:48:39	2020-06-13	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	17898	delivery	5	45
78000	2020-06-13 21:51:26	2020-06-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	25723	delivery	5	28
78001	2020-06-13 21:54:44	2020-06-13	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	30661	delivery	5	43
78002	2020-06-13 21:57:11	2020-06-13	9	[{"id_menu":6,"count":1}]	30681	delivery	5	14
78003	2020-06-13 21:59:48	2020-06-13	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6640	delivery	5	34
78004	2020-06-13 22:00:34	2020-06-13	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	30582	delivery	5	31
78005	2020-06-13 22:01:33	2020-06-13	17	[{"id_menu":4,"count":1}]	13870	delivery	5	22
78006	2020-06-13 22:03:25	2020-06-13	9	[{"id_menu":6,"count":1}]	4100	delivery	5	14
78007	2020-06-13 22:11:29	2020-06-13	17	[{"id_menu":4,"count":1}]	25064	delivery	5	22
78008	2020-06-13 22:12:00	2020-06-13	9	[{"id_menu":6,"count":1}]	30619	delivery	5	14
78009	2020-06-13 22:15:21	2020-06-13	14	[{"id_menu":2,"count":1}]	11442	delivery	5	19
78010	2020-06-13 22:25:41	2020-06-13	14	[{"id_menu":2,"count":1}]	30644	pick-up	0	14
78011	2020-06-13 22:26:15	2020-06-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30629	delivery	5	23
78012	2020-06-13 22:30:11	2020-06-13	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	30559	delivery	5	26
78013	2020-06-13 22:31:53	2020-06-13	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	17015	pick-up	0	20
78014	2020-06-13 22:33:54	2020-06-13	9	[{"id_menu":7,"count":2}]	30548	delivery	5	14
78015	2020-06-13 22:36:44	2020-06-13	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	30620	delivery	5	26
78016	2020-06-13 22:37:51	2020-06-13	9	[{"id_menu":6,"count":1}]	3102	pick-up	0	9
78017	2020-06-13 22:40:09	2020-06-13	14	[{"id_menu":2,"count":1}]	18341	delivery	5	19
78018	2020-06-13 22:42:00	2020-06-13	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	17675	delivery	5	30
78019	2020-06-13 22:42:18	2020-06-13	9	[{"id_menu":7,"count":1}]	6617	pick-up	0	9
78020	2020-06-13 22:42:49	2020-06-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	30522	delivery	5	23
78021	2020-06-13 22:53:42	2020-06-13	8	[{"id_menu":5,"count":1}]	29365	pick-up	0	8
78022	2020-06-13 22:54:34	2020-06-13	14	[{"id_menu":2,"count":1}]	27303	pick-up	0	14
78023	2020-06-13 22:59:21	2020-06-13	8	[{"id_menu":5,"count":1}]	30538	delivery	5	13
78024	2020-06-13 23:01:00	2020-06-13	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12906	delivery	5	31
78025	2020-06-13 23:05:26	2020-06-13	12	[{"id_menu":3,"count":2}]	4595	delivery	5	17
78026	2020-06-13 23:07:36	2020-06-13	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9844	delivery	5	43
78027	2020-06-13 23:08:49	2020-06-13	9	[{"id_menu":7,"count":1}]	5550	delivery	5	14
78028	2020-06-13 23:15:14	2020-06-13	8	[{"id_menu":5,"count":1}]	30609	delivery	5	13
78029	2020-06-13 23:17:02	2020-06-13	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	30677	delivery	5	23
78030	2020-06-13 23:17:32	2020-06-13	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30507	delivery	5	35
78031	2020-06-13 23:20:32	2020-06-13	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	20898	delivery	5	31
78032	2020-06-13 23:21:18	2020-06-13	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	27191	pick-up	0	29
78033	2020-06-13 23:22:24	2020-06-13	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	20780	pick-up	0	21
78034	2020-06-13 23:22:49	2020-06-13	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	13610	delivery	5	34
78035	2020-06-13 23:24:06	2020-06-13	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	11756	delivery	5	31
78036	2020-06-13 23:26:20	2020-06-13	8	[{"id_menu":5,"count":1}]	30691	delivery	5	13
78037	2020-06-13 23:35:45	2020-06-13	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	30667	delivery	5	45
78038	2020-06-13 23:38:03	2020-06-13	9	[{"id_menu":6,"count":1}]	13188	delivery	5	14
78039	2020-06-13 23:40:04	2020-06-13	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	30673	delivery	5	51
78040	2020-06-13 23:41:46	2020-06-13	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26607	delivery	5	31
78041	2020-06-13 23:43:11	2020-06-13	14	[{"id_menu":2,"count":2}]	12509	delivery	5	19
78042	2020-06-13 23:43:51	2020-06-13	37	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9791	delivery	5	42
78043	2020-06-13 23:48:59	2020-06-13	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	27118	delivery	5	31
78044	2020-06-13 23:52:44	2020-06-13	9	[{"id_menu":6,"count":1}]	11022	delivery	5	14
78045	2020-06-13 23:52:53	2020-06-13	12	[{"id_menu":3,"count":1}]	13671	delivery	5	17
78046	2020-06-13 23:55:42	2020-06-13	12	[{"id_menu":1,"count":1}]	21887	delivery	5	17
78047	2020-06-13 23:56:25	2020-06-13	14	[{"id_menu":2,"count":1}]	11617	delivery	5	19
78048	2020-06-13 23:58:33	2020-06-13	8	[{"id_menu":5,"count":1}]	5164	pick-up	0	8
78049	2020-06-13 23:58:41	2020-06-13	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":3}]	30662	delivery	5	34
78050	2020-06-13 23:59:14	2020-06-13	14	[{"id_menu":2,"count":1}]	30651	pick-up	0	14
78051	2020-06-14 00:02:05	2020-06-14	9	[{"id_menu":7,"count":1}]	23223	delivery	5	14
78052	2020-06-14 00:05:22	2020-06-14	9	[{"id_menu":6,"count":1}]	26233	delivery	5	14
78053	2020-06-14 00:08:26	2020-06-14	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28380	delivery	5	22
78054	2020-06-14 00:09:03	2020-06-14	8	[{"id_menu":5,"count":1}]	30891	delivery	5	13
78055	2020-06-14 00:10:25	2020-06-14	8	[{"id_menu":5,"count":1}]	23074	delivery	5	13
78056	2020-06-14 00:12:58	2020-06-14	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	12137	pick-up	0	26
78057	2020-06-14 00:15:12	2020-06-14	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8937	delivery	5	28
78058	2020-06-14 00:15:32	2020-06-14	17	[{"id_menu":4,"count":1}]	16254	delivery	5	22
78059	2020-06-14 00:16:43	2020-06-14	9	[{"id_menu":7,"count":1}]	30077	delivery	5	14
78060	2020-06-14 00:17:13	2020-06-14	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	28530	delivery	5	22
78061	2020-06-14 00:18:02	2020-06-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8707	delivery	5	31
78062	2020-06-14 00:19:30	2020-06-14	9	[{"id_menu":7,"count":1}]	30903	delivery	5	14
78063	2020-06-14 00:22:16	2020-06-14	9	[{"id_menu":6,"count":1}]	30808	delivery	5	14
78064	2020-06-14 00:22:54	2020-06-14	12	[{"id_menu":3,"count":1}]	2556	pick-up	0	12
78065	2020-06-14 00:23:11	2020-06-14	9	[{"id_menu":6,"count":1}]	30791	pick-up	0	9
78066	2020-06-14 00:23:49	2020-06-14	9	[{"id_menu":7,"count":1}]	12769	delivery	5	14
78067	2020-06-14 00:24:00	2020-06-14	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	30873	delivery	5	22
78068	2020-06-14 00:28:35	2020-06-14	14	[{"id_menu":2,"count":1}]	5042	delivery	5	19
78069	2020-06-14 00:29:23	2020-06-14	9	[{"id_menu":7,"count":1}]	13615	delivery	5	14
78070	2020-06-14 00:29:36	2020-06-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25108	delivery	5	22
78071	2020-06-14 00:30:05	2020-06-14	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	9525	delivery	5	35
78072	2020-06-14 00:31:04	2020-06-14	12	[{"id_menu":3,"count":1}]	21273	pick-up	0	12
78073	2020-06-14 00:31:39	2020-06-14	14	[{"id_menu":2,"count":1}]	5356	delivery	5	19
78074	2020-06-14 00:34:31	2020-06-14	39	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	16071	delivery	5	44
78075	2020-06-14 00:34:42	2020-06-14	14	[{"id_menu":2,"count":1}]	1104	pick-up	0	14
78076	2020-06-14 00:35:19	2020-06-14	9	[{"id_menu":7,"count":1}]	19319	delivery	5	14
78077	2020-06-14 00:37:57	2020-06-14	8	[{"id_menu":5,"count":1}]	30726	delivery	5	13
78078	2020-06-14 00:38:44	2020-06-14	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9733	delivery	5	43
78079	2020-06-14 00:40:27	2020-06-14	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12841	delivery	5	43
78080	2020-06-14 00:40:34	2020-06-14	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	30720	delivery	5	25
78081	2020-06-14 00:41:56	2020-06-14	14	[{"id_menu":2,"count":1}]	18468	delivery	5	19
78082	2020-06-14 00:44:37	2020-06-14	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27872	delivery	5	43
78083	2020-06-14 00:44:47	2020-06-14	9	[{"id_menu":7,"count":1}]	60	delivery	5	14
78084	2020-06-14 00:45:48	2020-06-14	14	[{"id_menu":2,"count":1}]	30804	delivery	5	19
78085	2020-06-14 00:46:53	2020-06-14	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9079	delivery	5	23
78086	2020-06-14 00:47:28	2020-06-14	8	[{"id_menu":5,"count":1}]	17133	pick-up	0	8
78087	2020-06-14 00:50:54	2020-06-14	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19112	delivery	5	35
78088	2020-06-14 00:50:59	2020-06-14	17	[{"id_menu":4,"count":1}]	2938	pick-up	0	17
78089	2020-06-14 00:51:57	2020-06-14	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	19363	delivery	5	57
78090	2020-06-14 00:52:58	2020-06-14	17	[{"id_menu":4,"count":1}]	20670	pick-up	0	17
78091	2020-06-14 00:55:49	2020-06-14	9	[{"id_menu":6,"count":1}]	15201	delivery	5	14
78092	2020-06-14 00:56:46	2020-06-14	14	[{"id_menu":2,"count":1}]	5109	delivery	5	19
78093	2020-06-14 01:00:09	2020-06-14	9	[{"id_menu":7,"count":1}]	30886	delivery	5	14
78094	2020-06-14 01:00:42	2020-06-14	9	[{"id_menu":7,"count":1}]	22480	delivery	5	14
78095	2020-06-14 01:09:25	2020-06-14	9	[{"id_menu":6,"count":1}]	18217	delivery	5	14
78096	2020-06-14 01:11:13	2020-06-14	12	[{"id_menu":3,"count":1}]	1513	delivery	5	17
78097	2020-06-14 01:15:21	2020-06-14	12	[{"id_menu":3,"count":1}]	30790	delivery	5	17
78098	2020-06-14 01:15:25	2020-06-14	14	[{"id_menu":2,"count":1}]	30909	pick-up	0	14
78099	2020-06-14 01:20:31	2020-06-14	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1387	pick-up	0	31
78100	2020-06-14 01:20:40	2020-06-14	9	[{"id_menu":6,"count":1}]	9928	delivery	5	14
78101	2020-06-14 01:21:07	2020-06-14	9	[{"id_menu":6,"count":1}]	30523	delivery	5	14
78102	2020-06-14 01:23:09	2020-06-14	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	30856	delivery	5	31
78103	2020-06-14 01:24:25	2020-06-14	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	664	delivery	5	38
78104	2020-06-14 01:26:53	2020-06-14	17	[{"id_menu":4,"count":1}]	18123	delivery	5	22
78105	2020-06-14 01:27:59	2020-06-14	14	[{"id_menu":2,"count":1}]	30743	pick-up	0	14
78106	2020-06-14 01:32:00	2020-06-14	9	[{"id_menu":6,"count":1}]	3146	delivery	5	14
78107	2020-06-14 01:32:29	2020-06-14	12	[{"id_menu":3,"count":1}]	2616	pick-up	0	12
78108	2020-06-14 01:32:39	2020-06-14	14	[{"id_menu":2,"count":1}]	10654	pick-up	0	14
78109	2020-06-14 01:33:08	2020-06-14	12	[{"id_menu":3,"count":2}]	1727	pick-up	0	12
78110	2020-06-14 01:38:25	2020-06-14	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	9024	delivery	5	37
78111	2020-06-14 01:40:03	2020-06-14	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18283	delivery	5	35
78112	2020-06-14 01:44:57	2020-06-14	8	[{"id_menu":5,"count":1}]	30746	delivery	5	13
78113	2020-06-14 01:46:01	2020-06-14	12	[{"id_menu":1,"count":1}]	30752	delivery	5	17
78114	2020-06-14 01:48:39	2020-06-14	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	14451	pick-up	0	29
78115	2020-06-14 01:50:20	2020-06-14	12	[{"id_menu":3,"count":1}]	11083	pick-up	0	12
78116	2020-06-14 01:51:02	2020-06-14	9	[{"id_menu":7,"count":1}]	30819	delivery	5	14
78117	2020-06-14 01:51:09	2020-06-14	9	[{"id_menu":6,"count":1}]	10894	delivery	5	14
78118	2020-06-14 01:53:13	2020-06-14	9	[{"id_menu":7,"count":1}]	11253	pick-up	0	9
78119	2020-06-14 01:53:15	2020-06-14	9	[{"id_menu":6,"count":1}]	3417	delivery	5	14
78120	2020-06-14 02:07:52	2020-06-14	8	[{"id_menu":5,"count":1}]	30930	delivery	5	13
78121	2020-06-14 02:08:42	2020-06-14	9	[{"id_menu":7,"count":1}]	1855	pick-up	0	9
78122	2020-06-14 02:09:32	2020-06-14	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":2}]	13827	delivery	5	28
78123	2020-06-14 02:11:32	2020-06-14	12	[{"id_menu":1,"count":1}]	7246	delivery	5	17
78124	2020-06-14 02:11:57	2020-06-14	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11029	delivery	5	45
78125	2020-06-14 02:15:25	2020-06-14	17	[{"id_menu":4,"count":1}]	5427	delivery	5	22
78126	2020-06-14 02:17:13	2020-06-14	9	[{"id_menu":6,"count":1}]	6824	delivery	5	14
78127	2020-06-14 02:19:29	2020-06-14	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	29379	delivery	5	26
78128	2020-06-14 02:22:03	2020-06-14	9	[{"id_menu":7,"count":1}]	18676	delivery	5	14
78129	2020-06-14 02:23:17	2020-06-14	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	30912	delivery	5	31
78130	2020-06-14 02:26:17	2020-06-14	9	[{"id_menu":7,"count":1}]	20957	delivery	5	14
78131	2020-06-14 02:27:40	2020-06-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	30828	pick-up	0	26
78132	2020-06-14 02:29:36	2020-06-14	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	6787	delivery	5	25
78133	2020-06-14 02:30:23	2020-06-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	14867	delivery	5	28
78134	2020-06-14 02:31:06	2020-06-14	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	30889	delivery	5	22
78135	2020-06-14 02:31:52	2020-06-14	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	7058	pick-up	0	43
78136	2020-06-14 02:31:56	2020-06-14	12	[{"id_menu":3,"count":1}]	2595	delivery	5	17
78137	2020-06-14 02:33:25	2020-06-14	9	[{"id_menu":6,"count":1}]	1659	delivery	5	14
78138	2020-06-14 02:34:15	2020-06-14	12	[{"id_menu":3,"count":1}]	30733	delivery	5	17
78139	2020-06-14 02:34:16	2020-06-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	30892	delivery	5	36
78140	2020-06-14 02:34:57	2020-06-14	17	[{"id_menu":4,"count":1}]	16613	delivery	5	22
78141	2020-06-14 02:37:59	2020-06-14	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30802	delivery	5	35
78142	2020-06-14 02:39:54	2020-06-14	12	[{"id_menu":3,"count":1}]	30857	delivery	5	17
78143	2020-06-14 02:40:05	2020-06-14	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	19244	delivery	5	36
78144	2020-06-14 02:41:02	2020-06-14	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	2130	delivery	5	26
78145	2020-06-14 02:44:46	2020-06-14	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30918	delivery	5	35
78146	2020-06-14 02:46:31	2020-06-14	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	29922	delivery	5	28
78147	2020-06-14 02:47:23	2020-06-14	8	[{"id_menu":5,"count":1}]	18911	delivery	5	13
78148	2020-06-14 02:49:15	2020-06-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	30786	delivery	5	31
78149	2020-06-14 02:53:28	2020-06-14	17	[{"id_menu":4,"count":1}]	30769	delivery	5	22
78150	2020-06-14 02:55:58	2020-06-14	9	[{"id_menu":6,"count":1}]	30890	delivery	5	14
78151	2020-06-14 02:56:39	2020-06-14	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	30781	delivery	5	27
78152	2020-06-14 02:57:40	2020-06-14	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3320	pick-up	0	26
78153	2020-06-14 03:00:51	2020-06-14	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	5662	delivery	5	27
78154	2020-06-14 03:09:32	2020-06-14	17	[{"id_menu":4,"count":1}]	7053	pick-up	0	17
78155	2020-06-14 03:14:36	2020-06-14	9	[{"id_menu":7,"count":1}]	26680	delivery	5	14
78156	2020-06-14 03:16:47	2020-06-14	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	30813	delivery	5	43
78157	2020-06-14 03:18:00	2020-06-14	8	[{"id_menu":5,"count":1}]	6659	delivery	5	13
78158	2020-06-14 03:20:11	2020-06-14	14	[{"id_menu":2,"count":1}]	30093	pick-up	0	14
78159	2020-06-14 03:20:38	2020-06-14	9	[{"id_menu":7,"count":1}]	13764	delivery	5	14
78160	2020-06-14 03:21:35	2020-06-14	9	[{"id_menu":7,"count":1}]	30843	delivery	5	14
78161	2020-06-14 03:23:44	2020-06-14	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	10101	delivery	5	34
78162	2020-06-14 03:26:50	2020-06-14	8	[{"id_menu":5,"count":1}]	30915	delivery	5	13
78163	2020-06-14 03:27:37	2020-06-14	14	[{"id_menu":2,"count":1}]	213	delivery	5	19
78164	2020-06-14 03:28:48	2020-06-14	17	[{"id_menu":4,"count":1}]	27808	delivery	5	22
78165	2020-06-14 03:30:49	2020-06-14	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	23130	delivery	5	35
78166	2020-06-14 03:34:30	2020-06-14	12	[{"id_menu":1,"count":1}]	17	pick-up	0	12
78167	2020-06-14 03:38:45	2020-06-14	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8898	delivery	5	42
78168	2020-06-14 03:40:34	2020-06-14	9	[{"id_menu":7,"count":1}]	30859	delivery	5	14
78169	2020-06-14 03:41:47	2020-06-14	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	30830	delivery	5	27
78170	2020-06-14 03:46:55	2020-06-14	9	[{"id_menu":7,"count":1}]	18138	delivery	5	14
78171	2020-06-14 03:50:48	2020-06-14	14	[{"id_menu":2,"count":1}]	24711	delivery	5	19
78172	2020-06-14 03:53:01	2020-06-14	9	[{"id_menu":6,"count":1}]	8842	delivery	5	14
78173	2020-06-14 03:53:45	2020-06-14	17	[{"id_menu":4,"count":1}]	30738	pick-up	0	17
78174	2020-06-14 03:54:03	2020-06-14	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	30869	delivery	5	26
78175	2020-06-14 03:54:18	2020-06-14	9	[{"id_menu":7,"count":1}]	22779	delivery	5	14
78176	2020-06-14 03:54:40	2020-06-14	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	13685	delivery	5	42
78177	2020-06-14 03:54:52	2020-06-14	9	[{"id_menu":7,"count":1}]	26015	delivery	5	14
78178	2020-06-14 03:55:57	2020-06-14	12	[{"id_menu":1,"count":1}]	30826	delivery	5	17
78179	2020-06-14 03:59:14	2020-06-14	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	26407	delivery	5	43
78180	2020-06-14 04:00:18	2020-06-14	9	[{"id_menu":7,"count":1}]	11495	delivery	5	14
78181	2020-06-14 04:00:48	2020-06-14	9	[{"id_menu":6,"count":1}]	13028	delivery	5	14
78182	2020-06-14 04:02:46	2020-06-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	30782	delivery	5	28
78183	2020-06-14 04:05:37	2020-06-14	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	30833	delivery	5	36
78184	2020-06-14 04:05:57	2020-06-14	9	[{"id_menu":6,"count":1}]	25053	delivery	5	14
78185	2020-06-14 04:06:07	2020-06-14	12	[{"id_menu":1,"count":1}]	27202	delivery	5	17
78186	2020-06-14 04:06:57	2020-06-14	9	[{"id_menu":6,"count":1}]	8867	delivery	5	14
78187	2020-06-14 04:11:33	2020-06-14	14	[{"id_menu":2,"count":1}]	9023	pick-up	0	14
78188	2020-06-14 04:14:50	2020-06-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19589	delivery	5	22
78189	2020-06-14 04:15:08	2020-06-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25297	delivery	5	22
78190	2020-06-14 04:16:36	2020-06-14	9	[{"id_menu":6,"count":1}]	23989	delivery	5	14
78191	2020-06-14 04:17:49	2020-06-14	12	[{"id_menu":1,"count":1}]	1988	delivery	5	17
78192	2020-06-14 04:20:01	2020-06-14	17	[{"id_menu":4,"count":1}]	20103	delivery	5	22
78193	2020-06-14 04:20:09	2020-06-14	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	665	pick-up	0	22
78194	2020-06-14 04:21:07	2020-06-14	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	7208	delivery	5	34
78195	2020-06-14 04:21:58	2020-06-14	9	[{"id_menu":7,"count":1}]	30606	delivery	5	14
78196	2020-06-14 04:22:21	2020-06-14	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	8338	delivery	5	26
78197	2020-06-14 04:23:49	2020-06-14	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	30884	delivery	5	34
78198	2020-06-14 04:26:55	2020-06-14	8	[{"id_menu":5,"count":1}]	30875	delivery	5	13
78199	2020-06-14 04:27:36	2020-06-14	12	[{"id_menu":1,"count":1}]	23749	delivery	5	17
78200	2020-06-14 04:30:11	2020-06-14	9	[{"id_menu":7,"count":2}]	10194	pick-up	0	9
78201	2020-06-14 04:33:39	2020-06-14	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	30809	delivery	5	31
78202	2020-06-14 04:36:12	2020-06-14	9	[{"id_menu":7,"count":1}]	12982	pick-up	0	9
78203	2020-06-14 04:36:16	2020-06-14	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30773	pick-up	0	32
78204	2020-06-14 04:37:16	2020-06-14	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7211	delivery	5	36
78205	2020-06-14 04:38:00	2020-06-14	12	[{"id_menu":1,"count":1}]	286	delivery	5	17
78206	2020-06-14 04:40:32	2020-06-14	8	[{"id_menu":5,"count":1}]	30759	delivery	5	13
78207	2020-06-14 04:42:03	2020-06-14	12	[{"id_menu":1,"count":1}]	14913	pick-up	0	12
78208	2020-06-14 04:43:23	2020-06-14	9	[{"id_menu":7,"count":1}]	30816	delivery	5	14
78209	2020-06-14 04:44:55	2020-06-14	9	[{"id_menu":6,"count":1}]	30882	delivery	5	14
78210	2020-06-14 04:46:14	2020-06-14	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	30865	delivery	5	26
78211	2020-06-14 04:46:23	2020-06-14	9	[{"id_menu":7,"count":1}]	8458	pick-up	0	9
78212	2020-06-14 04:48:20	2020-06-14	9	[{"id_menu":6,"count":1}]	20832	delivery	5	14
78213	2020-06-14 04:50:54	2020-06-14	8	[{"id_menu":5,"count":1}]	21201	delivery	5	13
78214	2020-06-14 04:51:17	2020-06-14	12	[{"id_menu":1,"count":1}]	12011	delivery	5	17
78215	2020-06-14 04:51:25	2020-06-14	12	[{"id_menu":3,"count":1}]	19883	delivery	5	17
78216	2020-06-14 04:53:45	2020-06-14	17	[{"id_menu":4,"count":1}]	30732	delivery	5	22
78217	2020-06-14 04:53:55	2020-06-14	9	[{"id_menu":6,"count":1}]	25110	delivery	5	14
78218	2020-06-14 04:54:03	2020-06-14	17	[{"id_menu":4,"count":1}]	16834	delivery	5	22
78219	2020-06-14 04:55:59	2020-06-14	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	12990	pick-up	0	26
78220	2020-06-14 04:59:06	2020-06-14	12	[{"id_menu":3,"count":1}]	13947	delivery	5	17
78221	2020-06-14 05:00:31	2020-06-14	14	[{"id_menu":2,"count":1}]	30727	delivery	5	19
78222	2020-06-14 05:02:54	2020-06-14	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	10323	delivery	5	27
78223	2020-06-14 05:03:25	2020-06-14	8	[{"id_menu":5,"count":1}]	12274	delivery	5	13
78224	2020-06-14 05:04:01	2020-06-14	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	30745	delivery	5	26
78225	2020-06-14 05:06:22	2020-06-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	2865	delivery	5	31
78226	2020-06-14 05:09:17	2020-06-14	8	[{"id_menu":5,"count":1}]	5559	pick-up	0	8
78227	2020-06-14 05:09:44	2020-06-14	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	24422	delivery	5	28
78228	2020-06-14 05:10:53	2020-06-14	9	[{"id_menu":6,"count":1}]	30768	delivery	5	14
78229	2020-06-14 05:11:20	2020-06-14	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	5075	delivery	5	31
78230	2020-06-14 05:11:21	2020-06-14	12	[{"id_menu":1,"count":1}]	25300	delivery	5	17
78231	2020-06-14 05:12:34	2020-06-14	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	30862	delivery	5	23
78232	2020-06-14 05:14:00	2020-06-14	9	[{"id_menu":6,"count":1}]	30730	delivery	5	14
78233	2020-06-14 05:16:48	2020-06-14	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	119	delivery	5	43
78234	2020-06-14 05:18:48	2020-06-14	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4166	pick-up	0	39
78235	2020-06-14 05:25:54	2020-06-14	9	[{"id_menu":7,"count":1}]	15028	pick-up	0	9
78236	2020-06-14 05:27:52	2020-06-14	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	30779	delivery	5	26
78237	2020-06-14 05:29:13	2020-06-14	9	[{"id_menu":6,"count":1}]	10669	delivery	5	14
78238	2020-06-14 05:31:53	2020-06-14	8	[{"id_menu":5,"count":1}]	23781	delivery	5	13
78239	2020-06-14 05:32:32	2020-06-14	14	[{"id_menu":2,"count":1}]	3193	pick-up	0	14
78240	2020-06-14 05:33:48	2020-06-14	17	[{"id_menu":4,"count":1}]	21599	pick-up	0	17
78241	2020-06-14 05:35:48	2020-06-14	12	[{"id_menu":1,"count":1}]	28806	delivery	5	17
78242	2020-06-14 05:37:07	2020-06-14	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	16187	delivery	5	38
78243	2020-06-14 05:37:35	2020-06-14	9	[{"id_menu":6,"count":1}]	23288	delivery	5	14
78244	2020-06-14 05:38:25	2020-06-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	2854	delivery	5	31
78245	2020-06-14 05:45:25	2020-06-14	9	[{"id_menu":6,"count":1}]	16618	delivery	5	14
78246	2020-06-14 05:49:18	2020-06-14	9	[{"id_menu":7,"count":1}]	11756	delivery	5	14
78247	2020-06-14 05:51:05	2020-06-14	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	19419	delivery	5	23
78248	2020-06-14 05:51:31	2020-06-14	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	28446	pick-up	0	25
78249	2020-06-14 05:51:47	2020-06-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	30797	delivery	5	31
78250	2020-06-14 05:52:15	2020-06-14	12	[{"id_menu":3,"count":1}]	28611	delivery	5	17
78251	2020-06-14 05:54:11	2020-06-14	12	[{"id_menu":3,"count":1}]	30870	delivery	5	17
78252	2020-06-14 05:54:33	2020-06-14	9	[{"id_menu":6,"count":1}]	3574	delivery	5	14
78253	2020-06-14 05:55:34	2020-06-14	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30925	delivery	5	37
78254	2020-06-14 05:55:50	2020-06-14	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	27693	delivery	5	34
78255	2020-06-14 05:58:31	2020-06-14	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	30845	delivery	5	45
78256	2020-06-14 05:59:25	2020-06-14	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	30774	delivery	5	30
78257	2020-06-14 06:01:06	2020-06-14	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	4703	delivery	5	34
78258	2020-06-14 06:02:11	2020-06-14	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22383	pick-up	0	47
78259	2020-06-14 06:03:36	2020-06-14	12	[{"id_menu":3,"count":1}]	22690	delivery	5	17
78260	2020-06-14 06:03:41	2020-06-14	9	[{"id_menu":7,"count":1}]	13537	delivery	5	14
78261	2020-06-14 06:04:59	2020-06-14	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":2}]	8381	delivery	5	28
78262	2020-06-14 06:05:55	2020-06-14	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	28748	delivery	5	34
78263	2020-06-14 06:07:21	2020-06-14	12	[{"id_menu":3,"count":1}]	27114	delivery	5	17
78264	2020-06-14 06:07:54	2020-06-14	9	[{"id_menu":7,"count":3}]	30850	delivery	5	14
78265	2020-06-14 06:10:09	2020-06-14	14	[{"id_menu":2,"count":1}]	30767	delivery	5	19
78266	2020-06-14 06:12:43	2020-06-14	8	[{"id_menu":5,"count":1}]	23935	delivery	5	13
78267	2020-06-14 06:14:08	2020-06-14	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	30844	delivery	5	31
78268	2020-06-14 06:15:33	2020-06-14	17	[{"id_menu":4,"count":1}]	8377	delivery	5	22
78269	2020-06-14 06:17:01	2020-06-14	9	[{"id_menu":6,"count":1}]	13495	pick-up	0	9
78270	2020-06-14 06:17:57	2020-06-14	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3314	delivery	5	35
78271	2020-06-14 06:18:49	2020-06-14	12	[{"id_menu":1,"count":1}]	30778	delivery	5	17
78272	2020-06-14 06:19:50	2020-06-14	8	[{"id_menu":5,"count":1}]	24023	pick-up	0	8
78273	2020-06-14 06:20:03	2020-06-14	9	[{"id_menu":7,"count":1}]	5747	delivery	5	14
78274	2020-06-14 06:22:27	2020-06-14	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10317	delivery	5	49
78275	2020-06-14 06:23:17	2020-06-14	33	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	810	delivery	5	38
78276	2020-06-14 06:23:50	2020-06-14	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	16469	pick-up	0	17
78277	2020-06-14 06:25:18	2020-06-14	8	[{"id_menu":5,"count":1}]	30917	delivery	5	13
78278	2020-06-14 06:28:44	2020-06-14	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20545	delivery	5	39
78279	2020-06-14 06:29:40	2020-06-14	9	[{"id_menu":7,"count":1}]	19213	delivery	5	14
78280	2020-06-14 06:30:22	2020-06-14	9	[{"id_menu":6,"count":1}]	25621	delivery	5	14
78281	2020-06-14 06:30:55	2020-06-14	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21444	delivery	5	34
78282	2020-06-14 06:35:49	2020-06-14	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	13808	delivery	5	27
78283	2020-06-14 06:37:19	2020-06-14	17	[{"id_menu":4,"count":1}]	2436	pick-up	0	17
78284	2020-06-14 06:37:42	2020-06-14	9	[{"id_menu":6,"count":1}]	30860	delivery	5	14
78285	2020-06-14 06:45:56	2020-06-14	9	[{"id_menu":6,"count":1}]	8969	delivery	5	14
78286	2020-06-14 06:47:27	2020-06-14	14	[{"id_menu":2,"count":1}]	30836	delivery	5	19
78287	2020-06-14 06:52:01	2020-06-14	14	[{"id_menu":2,"count":1}]	30901	delivery	5	19
78288	2020-06-14 06:53:58	2020-06-14	12	[{"id_menu":1,"count":1}]	27116	delivery	5	17
78289	2020-06-14 07:02:06	2020-06-14	9	[{"id_menu":7,"count":1}]	1581	pick-up	0	9
78290	2020-06-14 07:03:24	2020-06-14	9	[{"id_menu":7,"count":3}]	28478	delivery	5	14
78291	2020-06-14 07:03:55	2020-06-14	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	30799	delivery	5	22
78292	2020-06-14 07:04:18	2020-06-14	9	[{"id_menu":6,"count":1}]	21789	delivery	5	14
78293	2020-06-14 07:10:00	2020-06-14	9	[{"id_menu":7,"count":1}]	11430	delivery	5	14
78294	2020-06-14 07:10:58	2020-06-14	14	[{"id_menu":2,"count":1}]	3600	pick-up	0	14
78295	2020-06-14 07:13:45	2020-06-14	8	[{"id_menu":5,"count":1}]	3010	delivery	5	13
78296	2020-06-14 07:14:25	2020-06-14	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	8223	delivery	5	25
78297	2020-06-14 07:18:29	2020-06-14	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	30749	delivery	5	26
78298	2020-06-14 07:20:15	2020-06-14	14	[{"id_menu":2,"count":1}]	30900	delivery	5	19
78299	2020-06-14 07:20:44	2020-06-14	17	[{"id_menu":4,"count":1}]	30851	delivery	5	22
78300	2020-06-14 07:22:16	2020-06-14	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30811	delivery	5	23
78301	2020-06-14 07:22:18	2020-06-14	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	30766	pick-up	0	21
78302	2020-06-14 07:27:01	2020-06-14	8	[{"id_menu":5,"count":1}]	30787	delivery	5	13
78303	2020-06-14 07:27:46	2020-06-14	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	30780	delivery	5	39
78304	2020-06-14 07:28:18	2020-06-14	17	[{"id_menu":4,"count":1}]	5457	pick-up	0	17
78305	2020-06-14 07:30:04	2020-06-14	8	[{"id_menu":5,"count":1}]	13656	pick-up	0	8
78306	2020-06-14 07:33:19	2020-06-14	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":2}]	21811	delivery	5	28
78307	2020-06-14 07:38:12	2020-06-14	14	[{"id_menu":2,"count":1}]	10801	pick-up	0	14
78308	2020-06-14 07:38:27	2020-06-14	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	25510	delivery	5	22
78309	2020-06-14 07:40:24	2020-06-14	14	[{"id_menu":2,"count":1}]	30877	delivery	5	19
78310	2020-06-14 07:40:37	2020-06-14	8	[{"id_menu":5,"count":2}]	30868	delivery	5	13
78311	2020-06-14 07:41:40	2020-06-14	9	[{"id_menu":6,"count":1}]	4490	delivery	5	14
78312	2020-06-14 07:48:19	2020-06-14	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	11739	delivery	5	39
78313	2020-06-14 07:48:19	2020-06-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	13166	pick-up	0	31
78314	2020-06-14 07:49:18	2020-06-14	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30800	delivery	5	35
78315	2020-06-14 07:52:05	2020-06-14	9	[{"id_menu":7,"count":2}]	27178	delivery	5	14
78316	2020-06-14 07:52:05	2020-06-14	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	23464	delivery	5	40
78317	2020-06-14 07:54:54	2020-06-14	8	[{"id_menu":5,"count":2}]	27383	delivery	5	13
78318	2020-06-14 07:55:17	2020-06-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4414	delivery	5	28
78319	2020-06-14 07:56:09	2020-06-14	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1896	pick-up	0	21
78320	2020-06-14 07:57:58	2020-06-14	12	[{"id_menu":3,"count":1}]	4673	delivery	5	17
78321	2020-06-14 08:00:15	2020-06-14	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23527	delivery	5	48
78322	2020-06-14 08:01:04	2020-06-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	30929	pick-up	0	17
78323	2020-06-14 08:02:02	2020-06-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6148	delivery	5	36
78324	2020-06-14 08:02:07	2020-06-14	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	26416	delivery	5	25
78325	2020-06-14 08:02:12	2020-06-14	9	[{"id_menu":6,"count":1}]	30719	delivery	5	14
78326	2020-06-14 08:03:30	2020-06-14	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	8311	delivery	5	34
78327	2020-06-14 08:05:39	2020-06-14	9	[{"id_menu":7,"count":1}]	29074	delivery	5	14
78328	2020-06-14 08:06:25	2020-06-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	889	delivery	5	36
78329	2020-06-14 08:07:23	2020-06-14	9	[{"id_menu":6,"count":1}]	18140	delivery	5	14
78330	2020-06-14 08:08:03	2020-06-14	9	[{"id_menu":7,"count":1}]	30863	pick-up	0	9
78331	2020-06-14 08:08:12	2020-06-14	9	[{"id_menu":6,"count":1}]	19782	delivery	5	14
78332	2020-06-14 08:11:41	2020-06-14	14	[{"id_menu":2,"count":1}]	6609	pick-up	0	14
78333	2020-06-14 08:13:25	2020-06-14	8	[{"id_menu":5,"count":1}]	16406	pick-up	0	8
78334	2020-06-14 08:14:17	2020-06-14	9	[{"id_menu":6,"count":1}]	24198	pick-up	0	9
78335	2020-06-14 08:17:08	2020-06-14	9	[{"id_menu":6,"count":1}]	30794	delivery	5	14
78336	2020-06-14 08:17:30	2020-06-14	14	[{"id_menu":2,"count":1}]	2706	delivery	5	19
78337	2020-06-14 08:17:35	2020-06-14	9	[{"id_menu":7,"count":2}]	25394	delivery	5	14
78338	2020-06-14 08:17:39	2020-06-14	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	30823	delivery	5	51
78339	2020-06-14 08:22:12	2020-06-14	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	12393	delivery	5	31
78340	2020-06-14 08:24:42	2020-06-14	17	[{"id_menu":4,"count":1}]	1036	pick-up	0	17
78341	2020-06-14 08:27:40	2020-06-14	14	[{"id_menu":2,"count":1}]	832	pick-up	0	14
78342	2020-06-14 08:30:52	2020-06-14	9	[{"id_menu":7,"count":1}]	26741	delivery	5	14
78343	2020-06-14 08:31:25	2020-06-14	12	[{"id_menu":1,"count":1}]	8910	delivery	5	17
78344	2020-06-14 08:32:32	2020-06-14	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	30854	delivery	5	26
78345	2020-06-14 08:33:37	2020-06-14	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	30754	delivery	5	28
78346	2020-06-14 08:36:48	2020-06-14	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	15717	delivery	5	23
78347	2020-06-14 08:38:47	2020-06-14	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	6342	pick-up	0	21
78348	2020-06-14 08:40:19	2020-06-14	17	[{"id_menu":4,"count":1}]	9875	delivery	5	22
78349	2020-06-14 08:43:02	2020-06-14	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	30755	delivery	5	28
78350	2020-06-14 08:44:23	2020-06-14	12	[{"id_menu":3,"count":1}]	30807	delivery	5	17
78351	2020-06-14 08:49:22	2020-06-14	9	[{"id_menu":6,"count":1}]	22863	delivery	5	14
78352	2020-06-14 08:49:37	2020-06-14	12	[{"id_menu":3,"count":1}]	30818	delivery	5	17
78353	2020-06-14 08:50:51	2020-06-14	9	[{"id_menu":6,"count":1}]	30753	delivery	5	14
78354	2020-06-14 08:50:59	2020-06-14	8	[{"id_menu":5,"count":1}]	30805	delivery	5	13
78355	2020-06-14 08:51:10	2020-06-14	8	[{"id_menu":5,"count":1}]	231	delivery	5	13
78356	2020-06-14 08:54:37	2020-06-14	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	6076	delivery	5	31
78357	2020-06-14 08:56:10	2020-06-14	12	[{"id_menu":1,"count":1}]	30747	delivery	5	17
78358	2020-06-14 08:57:44	2020-06-14	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7871	delivery	5	52
78359	2020-06-14 09:00:24	2020-06-14	9	[{"id_menu":7,"count":1}]	30741	delivery	5	14
78360	2020-06-14 09:01:11	2020-06-14	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	23241	pick-up	0	26
78361	2020-06-14 09:04:13	2020-06-14	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	18927	delivery	5	43
78362	2020-06-14 09:04:34	2020-06-14	9	[{"id_menu":7,"count":1}]	11659	delivery	5	14
78363	2020-06-14 09:05:41	2020-06-14	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	30907	delivery	5	31
78364	2020-06-14 09:06:14	2020-06-14	12	[{"id_menu":3,"count":1}]	11314	pick-up	0	12
78365	2020-06-14 09:07:30	2020-06-14	17	[{"id_menu":4,"count":1}]	14775	delivery	5	22
78366	2020-06-14 09:08:21	2020-06-14	14	[{"id_menu":2,"count":1}]	19042	pick-up	0	14
78367	2020-06-14 09:17:19	2020-06-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	30914	delivery	5	31
78368	2020-06-14 09:21:00	2020-06-14	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	12336	delivery	5	42
78369	2020-06-14 09:25:14	2020-06-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	20581	delivery	5	31
78370	2020-06-14 09:26:00	2020-06-14	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1920	delivery	5	31
78371	2020-06-14 09:28:15	2020-06-14	9	[{"id_menu":7,"count":1}]	7070	delivery	5	14
78372	2020-06-14 09:29:41	2020-06-14	12	[{"id_menu":1,"count":1}]	30931	delivery	5	17
78373	2020-06-14 09:33:36	2020-06-14	14	[{"id_menu":2,"count":1}]	10870	pick-up	0	14
78374	2020-06-14 09:35:44	2020-06-14	17	[{"id_menu":4,"count":1}]	30839	pick-up	0	17
78375	2020-06-14 09:36:07	2020-06-14	12	[{"id_menu":3,"count":1}]	7931	delivery	5	17
78376	2020-06-14 09:36:32	2020-06-14	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2538	pick-up	0	38
78377	2020-06-14 09:38:43	2020-06-14	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	30415	delivery	5	31
78378	2020-06-14 09:40:20	2020-06-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17245	pick-up	0	26
78379	2020-06-14 09:40:26	2020-06-14	9	[{"id_menu":6,"count":1}]	30770	pick-up	0	9
78380	2020-06-14 09:40:39	2020-06-14	9	[{"id_menu":6,"count":1}]	17572	delivery	5	14
78381	2020-06-14 09:44:29	2020-06-14	9	[{"id_menu":6,"count":1}]	30724	delivery	5	14
78382	2020-06-14 09:44:56	2020-06-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	30718	delivery	5	31
78383	2020-06-14 09:46:32	2020-06-14	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	26035	pick-up	0	26
78384	2020-06-14 09:47:57	2020-06-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6022	delivery	5	22
78385	2020-06-14 09:50:40	2020-06-14	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	19783	delivery	5	34
78386	2020-06-14 09:51:27	2020-06-14	14	[{"id_menu":2,"count":1}]	30785	pick-up	0	14
78387	2020-06-14 09:51:57	2020-06-14	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	28320	delivery	5	28
78388	2020-06-14 09:56:49	2020-06-14	9	[{"id_menu":6,"count":1}]	5311	pick-up	0	9
78389	2020-06-14 09:57:10	2020-06-14	9	[{"id_menu":7,"count":1}]	12149	delivery	5	14
78390	2020-06-14 09:57:39	2020-06-14	9	[{"id_menu":6,"count":1}]	5786	delivery	5	14
78391	2020-06-14 10:05:15	2020-06-14	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	11380	pick-up	0	26
78392	2020-06-14 10:06:12	2020-06-14	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	30721	delivery	5	40
78393	2020-06-14 10:07:06	2020-06-14	9	[{"id_menu":7,"count":1}]	2032	pick-up	0	9
78394	2020-06-14 10:08:24	2020-06-14	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	24911	delivery	5	36
78395	2020-06-14 10:09:50	2020-06-14	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2442	pick-up	0	31
78396	2020-06-14 10:10:42	2020-06-14	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	906	delivery	5	31
78397	2020-06-14 10:11:47	2020-06-14	9	[{"id_menu":6,"count":1}]	30725	delivery	5	14
78398	2020-06-14 10:13:28	2020-06-14	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	7704	delivery	5	27
78399	2020-06-14 10:18:14	2020-06-14	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	22997	pick-up	0	24
78400	2020-06-14 10:20:16	2020-06-14	9	[{"id_menu":6,"count":1}]	3989	delivery	5	14
78401	2020-06-14 10:21:52	2020-06-14	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	113	pick-up	0	18
78402	2020-06-14 10:22:23	2020-06-14	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	27106	delivery	5	26
78403	2020-06-14 10:22:33	2020-06-14	8	[{"id_menu":5,"count":1}]	17968	delivery	5	13
78404	2020-06-14 10:24:23	2020-06-14	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19348	delivery	5	45
78405	2020-06-14 10:24:25	2020-06-14	9	[{"id_menu":7,"count":1}]	1563	pick-up	0	9
78406	2020-06-14 10:28:11	2020-06-14	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15334	delivery	5	40
78407	2020-06-14 10:31:36	2020-06-14	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12474	delivery	5	43
78408	2020-06-14 10:31:40	2020-06-14	8	[{"id_menu":5,"count":1}]	7182	pick-up	0	8
78409	2020-06-14 10:32:09	2020-06-14	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	30926	delivery	5	36
78410	2020-06-14 10:34:09	2020-06-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":3}]	3480	delivery	5	36
78411	2020-06-14 10:34:49	2020-06-14	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	12666	delivery	5	31
78412	2020-06-14 10:35:08	2020-06-14	9	[{"id_menu":6,"count":1}]	30919	delivery	5	14
78413	2020-06-14 10:39:36	2020-06-14	9	[{"id_menu":7,"count":1}]	15614	delivery	5	14
78414	2020-06-14 10:41:38	2020-06-14	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	30821	delivery	5	31
78415	2020-06-14 10:44:32	2020-06-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	10875	pick-up	0	23
78416	2020-06-14 10:44:58	2020-06-14	8	[{"id_menu":5,"count":1}]	527	pick-up	0	8
78417	2020-06-14 10:46:00	2020-06-14	12	[{"id_menu":3,"count":1}]	13829	delivery	5	17
78418	2020-06-14 10:46:49	2020-06-14	12	[{"id_menu":3,"count":1}]	2908	delivery	5	17
78419	2020-06-14 10:53:35	2020-06-14	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	21562	delivery	5	26
78420	2020-06-14 10:55:25	2020-06-14	12	[{"id_menu":3,"count":1}]	23206	delivery	5	17
78421	2020-06-14 10:57:41	2020-06-14	17	[{"id_menu":4,"count":1}]	10340	delivery	5	22
78422	2020-06-14 11:00:28	2020-06-14	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	23246	delivery	5	22
78423	2020-06-14 11:02:13	2020-06-14	14	[{"id_menu":2,"count":1}]	15026	delivery	5	19
78424	2020-06-14 11:02:43	2020-06-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24165	delivery	5	22
78425	2020-06-14 11:02:47	2020-06-14	8	[{"id_menu":5,"count":1}]	30820	delivery	5	13
78426	2020-06-14 11:02:55	2020-06-14	12	[{"id_menu":1,"count":1}]	23292	delivery	5	17
78427	2020-06-14 11:04:59	2020-06-14	8	[{"id_menu":5,"count":1}]	6853	delivery	5	13
78428	2020-06-14 11:05:40	2020-06-14	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	14905	delivery	5	26
78429	2020-06-14 11:06:32	2020-06-14	8	[{"id_menu":5,"count":1}]	25279	pick-up	0	8
78430	2020-06-14 11:06:33	2020-06-14	12	[{"id_menu":3,"count":1}]	30916	delivery	5	17
78431	2020-06-14 11:08:28	2020-06-14	17	[{"id_menu":4,"count":1}]	5699	delivery	5	22
78432	2020-06-14 11:08:49	2020-06-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7140	pick-up	0	31
78433	2020-06-14 11:10:23	2020-06-14	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	30866	delivery	5	36
78434	2020-06-14 11:12:10	2020-06-14	9	[{"id_menu":7,"count":1}]	18759	delivery	5	14
78435	2020-06-14 11:12:30	2020-06-14	8	[{"id_menu":5,"count":1}]	7791	delivery	5	13
78436	2020-06-14 11:13:35	2020-06-14	9	[{"id_menu":7,"count":1}]	29541	pick-up	0	9
78437	2020-06-14 11:14:43	2020-06-14	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6092	pick-up	0	52
78438	2020-06-14 11:17:26	2020-06-14	8	[{"id_menu":5,"count":1}]	11095	delivery	5	13
78439	2020-06-14 11:23:08	2020-06-14	14	[{"id_menu":2,"count":1}]	20215	pick-up	0	14
78440	2020-06-14 11:23:12	2020-06-14	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	4020	delivery	5	31
78441	2020-06-14 11:23:19	2020-06-14	8	[{"id_menu":5,"count":2}]	4356	pick-up	0	8
78442	2020-06-14 11:23:43	2020-06-14	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1079	delivery	5	43
78443	2020-06-14 11:24:14	2020-06-14	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	30842	delivery	5	34
78444	2020-06-14 11:24:28	2020-06-14	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	2933	pick-up	0	20
78445	2020-06-14 11:24:32	2020-06-14	12	[{"id_menu":3,"count":1}]	11905	delivery	5	17
78446	2020-06-14 11:24:55	2020-06-14	14	[{"id_menu":2,"count":1}]	30717	delivery	5	19
78447	2020-06-14 11:25:13	2020-06-14	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9008	pick-up	0	29
78448	2020-06-14 11:30:39	2020-06-14	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	30751	pick-up	0	35
78449	2020-06-14 11:31:48	2020-06-14	8	[{"id_menu":5,"count":1}]	30933	delivery	5	13
78450	2020-06-14 11:31:49	2020-06-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	30908	delivery	5	31
78451	2020-06-14 11:32:22	2020-06-14	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	23665	delivery	5	26
78452	2020-06-14 11:32:29	2020-06-14	41	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	5430	pick-up	0	41
78453	2020-06-14 11:32:41	2020-06-14	9	[{"id_menu":6,"count":1}]	14294	delivery	5	14
78454	2020-06-14 11:35:46	2020-06-14	12	[{"id_menu":3,"count":1}]	3449	delivery	5	17
78455	2020-06-14 11:40:43	2020-06-14	12	[{"id_menu":1,"count":1}]	2728	delivery	5	17
78456	2020-06-14 11:43:12	2020-06-14	9	[{"id_menu":6,"count":1}]	12001	pick-up	0	9
78457	2020-06-14 11:43:42	2020-06-14	8	[{"id_menu":5,"count":1}]	30822	delivery	5	13
78458	2020-06-14 11:45:40	2020-06-14	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2443	delivery	5	31
78459	2020-06-14 11:50:13	2020-06-14	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	30744	delivery	5	22
78460	2020-06-14 11:50:22	2020-06-14	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	11841	delivery	5	39
78461	2020-06-14 11:54:20	2020-06-14	14	[{"id_menu":2,"count":1}]	26922	delivery	5	19
78462	2020-06-14 12:01:18	2020-06-14	12	[{"id_menu":1,"count":1}]	30734	delivery	5	17
78463	2020-06-14 12:02:42	2020-06-14	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	615	pick-up	0	26
78464	2020-06-14 12:04:12	2020-06-14	8	[{"id_menu":5,"count":1}]	30887	delivery	5	13
78465	2020-06-14 12:09:16	2020-06-14	17	[{"id_menu":4,"count":1}]	22189	delivery	5	22
78466	2020-06-14 12:10:24	2020-06-14	9	[{"id_menu":7,"count":1}]	6794	delivery	5	14
78467	2020-06-14 12:10:41	2020-06-14	12	[{"id_menu":1,"count":1}]	23133	pick-up	0	12
78468	2020-06-14 12:10:45	2020-06-14	9	[{"id_menu":7,"count":1}]	12733	delivery	5	14
78469	2020-06-14 12:12:00	2020-06-14	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	30792	delivery	5	27
78470	2020-06-14 12:12:59	2020-06-14	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7500	delivery	5	28
78471	2020-06-14 12:14:31	2020-06-14	17	[{"id_menu":4,"count":1}]	5740	delivery	5	22
78472	2020-06-14 12:21:36	2020-06-14	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20211	delivery	5	23
78473	2020-06-14 12:23:26	2020-06-14	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8548	delivery	5	31
78474	2020-06-14 12:23:38	2020-06-14	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	19891	delivery	5	28
78475	2020-06-14 12:24:52	2020-06-14	14	[{"id_menu":2,"count":3}]	12541	delivery	5	19
78476	2020-06-14 12:25:15	2020-06-14	14	[{"id_menu":2,"count":1}]	8127	pick-up	0	14
78477	2020-06-14 12:29:51	2020-06-14	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	30731	delivery	5	31
78478	2020-06-14 12:34:32	2020-06-14	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	13662	pick-up	0	22
78479	2020-06-14 12:34:35	2020-06-14	12	[{"id_menu":1,"count":2}]	30864	pick-up	0	12
78480	2020-06-14 12:36:07	2020-06-14	17	[{"id_menu":4,"count":1}]	6968	pick-up	0	17
78481	2020-06-14 12:37:23	2020-06-14	12	[{"id_menu":3,"count":1}]	30896	delivery	5	17
78482	2020-06-14 12:38:44	2020-06-14	12	[{"id_menu":3,"count":1}]	10906	delivery	5	17
78483	2020-06-14 12:41:26	2020-06-14	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	25141	pick-up	0	25
78484	2020-06-14 12:43:32	2020-06-14	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	19760	delivery	5	31
78485	2020-06-14 12:48:05	2020-06-14	9	[{"id_menu":7,"count":1}]	29842	pick-up	0	9
78486	2020-06-14 12:51:46	2020-06-14	9	[{"id_menu":6,"count":1}]	6516	pick-up	0	9
78487	2020-06-14 13:02:03	2020-06-14	9	[{"id_menu":7,"count":1}]	6009	pick-up	0	9
78488	2020-06-14 13:04:17	2020-06-14	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5773	delivery	5	31
78489	2020-06-14 13:05:51	2020-06-14	8	[{"id_menu":5,"count":1}]	20289	delivery	5	13
78490	2020-06-14 13:07:23	2020-06-14	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17687	delivery	5	43
78491	2020-06-14 13:14:03	2020-06-14	14	[{"id_menu":2,"count":1}]	408	pick-up	0	14
78492	2020-06-14 13:14:29	2020-06-14	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	30835	delivery	5	26
78493	2020-06-14 13:17:52	2020-06-14	14	[{"id_menu":2,"count":1}]	30723	delivery	5	19
78494	2020-06-14 13:26:24	2020-06-14	17	[{"id_menu":4,"count":1}]	19480	delivery	5	22
78495	2020-06-14 13:28:49	2020-06-14	8	[{"id_menu":5,"count":1}]	30825	delivery	5	13
78496	2020-06-14 13:28:58	2020-06-14	9	[{"id_menu":6,"count":1}]	21064	delivery	5	14
78497	2020-06-14 13:37:01	2020-06-14	14	[{"id_menu":2,"count":1}]	30847	delivery	5	19
78498	2020-06-14 13:37:24	2020-06-14	9	[{"id_menu":6,"count":1}]	1618	pick-up	0	9
78499	2020-06-14 13:39:21	2020-06-14	12	[{"id_menu":3,"count":1}]	11395	pick-up	0	12
78500	2020-06-14 13:39:49	2020-06-14	9	[{"id_menu":7,"count":1}]	20629	delivery	5	14
78501	2020-06-14 13:40:57	2020-06-14	8	[{"id_menu":5,"count":1}]	30742	delivery	5	13
78502	2020-06-14 13:42:22	2020-06-14	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5878	delivery	5	54
78503	2020-06-14 13:43:33	2020-06-14	17	[{"id_menu":4,"count":1}]	30763	delivery	5	22
78504	2020-06-14 13:45:23	2020-06-14	8	[{"id_menu":5,"count":1}]	2361	delivery	5	13
78505	2020-06-14 13:47:03	2020-06-14	14	[{"id_menu":2,"count":1}]	7358	delivery	5	19
78506	2020-06-14 13:48:08	2020-06-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	9967	delivery	5	36
78507	2020-06-14 13:49:45	2020-06-14	8	[{"id_menu":5,"count":1}]	12365	delivery	5	13
78508	2020-06-14 13:49:57	2020-06-14	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":2}]	29962	delivery	5	36
78509	2020-06-14 13:51:04	2020-06-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	29845	delivery	5	22
78510	2020-06-14 13:51:38	2020-06-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	30834	delivery	5	28
78511	2020-06-14 13:51:48	2020-06-14	12	[{"id_menu":3,"count":1}]	10649	pick-up	0	12
78512	2020-06-14 13:53:35	2020-06-14	14	[{"id_menu":2,"count":1}]	30883	delivery	5	19
78513	2020-06-14 13:55:07	2020-06-14	9	[{"id_menu":6,"count":1}]	30393	delivery	5	14
78514	2020-06-14 14:02:54	2020-06-14	12	[{"id_menu":3,"count":2}]	7275	delivery	5	17
78515	2020-06-14 14:05:40	2020-06-14	9	[{"id_menu":7,"count":1}]	15590	pick-up	0	9
78516	2020-06-14 14:09:25	2020-06-14	8	[{"id_menu":5,"count":1}]	14144	delivery	5	13
78517	2020-06-14 14:09:39	2020-06-14	9	[{"id_menu":6,"count":1}]	9324	delivery	5	14
78518	2020-06-14 14:10:11	2020-06-14	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	5520	pick-up	0	29
78519	2020-06-14 14:12:10	2020-06-14	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	25735	pick-up	0	26
78520	2020-06-14 14:14:14	2020-06-14	12	[{"id_menu":3,"count":1}]	17995	pick-up	0	12
78521	2020-06-14 14:14:57	2020-06-14	9	[{"id_menu":6,"count":1}]	18530	delivery	5	14
78522	2020-06-14 14:19:52	2020-06-14	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	17087	delivery	5	26
78523	2020-06-14 14:20:50	2020-06-14	12	[{"id_menu":3,"count":1}]	784	pick-up	0	12
78524	2020-06-14 14:21:07	2020-06-14	9	[{"id_menu":7,"count":1}]	3739	delivery	5	14
78525	2020-06-14 14:21:18	2020-06-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	30876	pick-up	0	26
78526	2020-06-14 14:22:35	2020-06-14	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	30784	delivery	5	26
78527	2020-06-14 14:25:56	2020-06-14	9	[{"id_menu":6,"count":1}]	30848	delivery	5	14
78528	2020-06-14 14:29:18	2020-06-14	9	[{"id_menu":7,"count":1}]	11689	delivery	5	14
78529	2020-06-14 14:29:26	2020-06-14	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10589	pick-up	0	38
78530	2020-06-14 14:29:28	2020-06-14	9	[{"id_menu":6,"count":1}]	30881	delivery	5	14
78531	2020-06-14 14:31:09	2020-06-14	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	17980	delivery	5	44
78532	2020-06-14 14:32:06	2020-06-14	12	[{"id_menu":1,"count":1}]	30810	delivery	5	17
78533	2020-06-14 14:32:39	2020-06-14	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":2}]	30729	delivery	5	27
78534	2020-06-14 14:32:54	2020-06-14	9	[{"id_menu":6,"count":1}]	5735	delivery	5	14
78535	2020-06-14 14:33:31	2020-06-14	12	[{"id_menu":3,"count":1}]	4293	delivery	5	17
78536	2020-06-14 14:33:48	2020-06-14	14	[{"id_menu":2,"count":1}]	25254	pick-up	0	14
78537	2020-06-14 14:33:53	2020-06-14	8	[{"id_menu":5,"count":1}]	27495	delivery	5	13
78538	2020-06-14 14:34:24	2020-06-14	12	[{"id_menu":1,"count":1}]	7645	delivery	5	17
78539	2020-06-14 14:34:34	2020-06-14	14	[{"id_menu":2,"count":1}]	30806	delivery	5	19
78540	2020-06-14 14:36:17	2020-06-14	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	30871	delivery	5	45
78541	2020-06-14 14:36:49	2020-06-14	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	30878	delivery	5	36
78542	2020-06-14 14:36:58	2020-06-14	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	30837	delivery	5	39
78543	2020-06-14 14:41:14	2020-06-14	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16151	delivery	5	34
78544	2020-06-14 14:46:18	2020-06-14	12	[{"id_menu":1,"count":1}]	30874	delivery	5	17
78545	2020-06-14 14:48:28	2020-06-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	17732	delivery	5	28
78546	2020-06-14 14:52:30	2020-06-14	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	30750	pick-up	0	17
78547	2020-06-14 14:52:54	2020-06-14	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16540	delivery	5	43
78548	2020-06-14 14:54:09	2020-06-14	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2101	delivery	5	26
78549	2020-06-14 14:55:54	2020-06-14	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2460	pick-up	0	40
78550	2020-06-14 15:00:22	2020-06-14	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	30841	delivery	5	43
78551	2020-06-14 15:00:30	2020-06-14	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30740	delivery	5	37
78552	2020-06-14 15:01:10	2020-06-14	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	6416	delivery	5	40
78553	2020-06-14 15:03:33	2020-06-14	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30739	delivery	5	31
78554	2020-06-14 15:04:44	2020-06-14	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	21731	delivery	5	26
78555	2020-06-14 15:06:03	2020-06-14	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	30899	delivery	5	42
78556	2020-06-14 15:07:10	2020-06-14	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	30757	delivery	5	48
78557	2020-06-14 15:07:54	2020-06-14	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2735	pick-up	0	41
78558	2020-06-14 15:08:16	2020-06-14	14	[{"id_menu":2,"count":1}]	6257	delivery	5	19
78559	2020-06-14 15:11:09	2020-06-14	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30840	delivery	5	40
78560	2020-06-14 15:13:50	2020-06-14	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	30827	delivery	5	43
78561	2020-06-14 15:14:28	2020-06-14	14	[{"id_menu":2,"count":1}]	7834	pick-up	0	14
78562	2020-06-14 15:16:01	2020-06-14	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	4094	pick-up	0	21
78563	2020-06-14 15:16:30	2020-06-14	14	[{"id_menu":2,"count":1}]	16737	delivery	5	19
78564	2020-06-14 15:16:42	2020-06-14	14	[{"id_menu":2,"count":1}]	30905	delivery	5	19
78565	2020-06-14 15:20:10	2020-06-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	30832	delivery	5	28
78566	2020-06-14 15:22:40	2020-06-14	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	8612	delivery	5	23
78567	2020-06-14 15:22:54	2020-06-14	9	[{"id_menu":6,"count":1}]	19229	delivery	5	14
78568	2020-06-14 15:23:07	2020-06-14	8	[{"id_menu":5,"count":1}]	29302	delivery	5	13
78569	2020-06-14 15:26:32	2020-06-14	9	[{"id_menu":6,"count":1}]	29510	delivery	5	14
78570	2020-06-14 15:27:25	2020-06-14	12	[{"id_menu":3,"count":1}]	8050	delivery	5	17
78571	2020-06-14 15:30:27	2020-06-14	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	4054	pick-up	0	24
78572	2020-06-14 15:31:21	2020-06-14	9	[{"id_menu":7,"count":1}]	29075	delivery	5	14
78573	2020-06-14 15:34:15	2020-06-14	17	[{"id_menu":4,"count":1}]	7297	delivery	5	22
78574	2020-06-14 15:34:25	2020-06-14	8	[{"id_menu":5,"count":1}]	28508	delivery	5	13
78575	2020-06-14 15:35:45	2020-06-14	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	701	delivery	5	25
78576	2020-06-14 15:39:50	2020-06-14	9	[{"id_menu":7,"count":1}]	2176	delivery	5	14
78577	2020-06-14 15:46:12	2020-06-14	17	[{"id_menu":4,"count":1}]	30829	delivery	5	22
78578	2020-06-14 15:46:26	2020-06-14	8	[{"id_menu":5,"count":1}]	2220	delivery	5	13
78579	2020-06-14 15:48:41	2020-06-14	17	[{"id_menu":4,"count":1}]	13202	delivery	5	22
78580	2020-06-14 15:49:54	2020-06-14	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9695	delivery	5	45
78581	2020-06-14 15:50:42	2020-06-14	14	[{"id_menu":2,"count":1}]	1025	pick-up	0	14
78582	2020-06-14 15:50:46	2020-06-14	17	[{"id_menu":4,"count":1}]	24556	delivery	5	22
78583	2020-06-14 15:52:10	2020-06-14	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27913	delivery	5	36
78584	2020-06-14 15:52:58	2020-06-14	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10717	delivery	5	45
78585	2020-06-14 15:54:30	2020-06-14	14	[{"id_menu":2,"count":1}]	2426	pick-up	0	14
78586	2020-06-14 15:55:11	2020-06-14	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	21597	delivery	5	26
78587	2020-06-14 15:55:29	2020-06-14	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30902	delivery	5	48
78588	2020-06-14 15:56:49	2020-06-14	14	[{"id_menu":2,"count":1}]	5047	pick-up	0	14
78589	2020-06-14 15:57:50	2020-06-14	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18271	delivery	5	37
78590	2020-06-14 15:58:20	2020-06-14	8	[{"id_menu":5,"count":1}]	26603	delivery	5	13
78591	2020-06-14 15:59:36	2020-06-14	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	30846	delivery	5	25
78592	2020-06-14 16:04:57	2020-06-14	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	26256	delivery	5	31
78593	2020-06-14 16:05:16	2020-06-14	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	30748	delivery	5	31
78594	2020-06-14 16:07:44	2020-06-14	30	[{"id_menu":1,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24284	pick-up	0	30
78595	2020-06-14 16:08:00	2020-06-14	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30880	delivery	5	40
78596	2020-06-14 16:08:42	2020-06-14	12	[{"id_menu":1,"count":1}]	4112	pick-up	0	12
78597	2020-06-14 16:11:00	2020-06-14	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	12420	pick-up	0	22
78598	2020-06-14 16:12:25	2020-06-14	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	17768	delivery	5	28
78599	2020-06-14 16:13:07	2020-06-14	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	23085	delivery	5	28
78600	2020-06-14 16:15:53	2020-06-14	12	[{"id_menu":1,"count":1}]	1590	pick-up	0	12
78601	2020-06-14 16:16:53	2020-06-14	12	[{"id_menu":3,"count":1}]	25836	delivery	5	17
78602	2020-06-14 16:17:56	2020-06-14	12	[{"id_menu":1,"count":1}]	3160	pick-up	0	12
78603	2020-06-14 16:18:35	2020-06-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5451	delivery	5	28
78604	2020-06-14 16:18:45	2020-06-14	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	18335	delivery	5	31
78605	2020-06-14 16:18:56	2020-06-14	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	30898	delivery	5	40
78606	2020-06-14 16:20:19	2020-06-14	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	7607	delivery	5	31
78607	2020-06-14 16:20:59	2020-06-14	12	[{"id_menu":1,"count":1}]	2139	pick-up	0	12
78608	2020-06-14 16:21:50	2020-06-14	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	7217	delivery	5	40
78609	2020-06-14 16:30:39	2020-06-14	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2549	delivery	5	31
78610	2020-06-14 16:33:03	2020-06-14	17	[{"id_menu":4,"count":1}]	2217	pick-up	0	17
78611	2020-06-14 16:33:28	2020-06-14	12	[{"id_menu":1,"count":1}]	1681	pick-up	0	12
78612	2020-06-14 16:35:31	2020-06-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	19886	delivery	5	28
78613	2020-06-14 16:36:05	2020-06-14	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	30849	delivery	5	34
78614	2020-06-14 16:36:48	2020-06-14	12	[{"id_menu":1,"count":1}]	28151	pick-up	0	12
78615	2020-06-14 16:38:04	2020-06-14	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	30756	delivery	5	28
78616	2020-06-14 16:39:22	2020-06-14	12	[{"id_menu":3,"count":1}]	9865	delivery	5	17
78617	2020-06-14 16:42:14	2020-06-14	9	[{"id_menu":6,"count":1}]	11915	pick-up	0	9
78618	2020-06-14 16:42:28	2020-06-14	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18543	delivery	5	36
78619	2020-06-14 16:43:58	2020-06-14	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	7702	delivery	5	28
78620	2020-06-14 16:47:56	2020-06-14	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	19367	delivery	5	43
78621	2020-06-14 16:50:05	2020-06-14	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4451	delivery	5	43
78622	2020-06-14 16:50:07	2020-06-14	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	4368	delivery	5	26
78623	2020-06-14 16:51:45	2020-06-14	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	25887	pick-up	0	21
78624	2020-06-14 16:52:02	2020-06-14	12	[{"id_menu":3,"count":1}]	13477	delivery	5	17
78625	2020-06-14 16:58:11	2020-06-14	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	881	pick-up	0	29
78626	2020-06-14 17:07:35	2020-06-14	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30934	delivery	5	23
78627	2020-06-14 17:07:53	2020-06-14	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	17725	delivery	5	42
78628	2020-06-14 17:09:06	2020-06-14	9	[{"id_menu":7,"count":1}]	30783	delivery	5	14
78629	2020-06-14 17:11:02	2020-06-14	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	30872	delivery	5	42
78630	2020-06-14 17:12:22	2020-06-14	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21387	delivery	5	23
78631	2020-06-14 17:12:40	2020-06-14	17	[{"id_menu":4,"count":1}]	21309	delivery	5	22
78632	2020-06-14 17:14:56	2020-06-14	9	[{"id_menu":6,"count":1}]	30861	delivery	5	14
78633	2020-06-14 17:17:04	2020-06-14	9	[{"id_menu":6,"count":2}]	25214	pick-up	0	9
78634	2020-06-14 17:17:06	2020-06-14	8	[{"id_menu":5,"count":2}]	21607	delivery	5	13
78635	2020-06-14 17:19:48	2020-06-14	8	[{"id_menu":5,"count":1}]	9711	delivery	5	13
78636	2020-06-14 17:20:11	2020-06-14	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10576	delivery	5	36
78637	2020-06-14 17:21:41	2020-06-14	9	[{"id_menu":7,"count":2}]	9427	delivery	5	14
78638	2020-06-14 17:21:57	2020-06-14	14	[{"id_menu":2,"count":1}]	30894	delivery	5	19
78639	2020-06-14 17:24:08	2020-06-14	9	[{"id_menu":7,"count":1}]	30924	delivery	5	14
78640	2020-06-14 17:27:26	2020-06-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	25077	delivery	5	28
78641	2020-06-14 17:33:54	2020-06-14	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	30922	delivery	5	36
78642	2020-06-14 17:37:04	2020-06-14	8	[{"id_menu":5,"count":1}]	5019	pick-up	0	8
78643	2020-06-14 17:38:43	2020-06-14	9	[{"id_menu":6,"count":3}]	22462	delivery	5	14
78644	2020-06-14 17:38:55	2020-06-14	12	[{"id_menu":1,"count":1}]	717	pick-up	0	12
78645	2020-06-14 17:39:10	2020-06-14	8	[{"id_menu":5,"count":1}]	8269	delivery	5	13
78646	2020-06-14 17:39:32	2020-06-14	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	3255	pick-up	0	20
78647	2020-06-14 17:40:33	2020-06-14	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10350	delivery	5	53
78648	2020-06-14 17:42:56	2020-06-14	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1529	pick-up	0	22
78649	2020-06-14 17:43:21	2020-06-14	17	[{"id_menu":4,"count":1}]	16760	pick-up	0	17
78650	2020-06-14 17:45:40	2020-06-14	14	[{"id_menu":2,"count":1}]	1269	delivery	5	19
78651	2020-06-14 17:47:18	2020-06-14	9	[{"id_menu":6,"count":1}]	30817	delivery	5	14
78652	2020-06-14 17:47:57	2020-06-14	17	[{"id_menu":4,"count":1}]	30519	pick-up	0	17
78653	2020-06-14 17:48:36	2020-06-14	9	[{"id_menu":6,"count":1}]	30801	delivery	5	14
78654	2020-06-14 17:50:53	2020-06-14	12	[{"id_menu":1,"count":1}]	30736	delivery	5	17
78655	2020-06-14 17:53:06	2020-06-14	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2280	pick-up	0	18
78656	2020-06-14 17:53:07	2020-06-14	17	[{"id_menu":4,"count":1}]	28865	pick-up	0	17
78657	2020-06-14 17:53:20	2020-06-14	9	[{"id_menu":6,"count":1}]	25064	delivery	5	14
78658	2020-06-14 17:53:23	2020-06-14	17	[{"id_menu":4,"count":1}]	26860	pick-up	0	17
78659	2020-06-14 17:55:10	2020-06-14	12	[{"id_menu":1,"count":1}]	10244	delivery	5	17
78660	2020-06-14 17:58:51	2020-06-14	8	[{"id_menu":5,"count":1}]	2444	pick-up	0	8
78661	2020-06-14 18:03:04	2020-06-14	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	5278	delivery	5	25
78662	2020-06-14 18:04:16	2020-06-14	8	[{"id_menu":5,"count":1}]	2532	pick-up	0	8
78663	2020-06-14 18:05:35	2020-06-14	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2233	pick-up	0	21
78664	2020-06-14 18:05:38	2020-06-14	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	17788	delivery	5	28
78665	2020-06-14 18:07:15	2020-06-14	9	[{"id_menu":6,"count":1}]	9930	delivery	5	14
78666	2020-06-14 18:07:50	2020-06-14	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12694	delivery	5	22
78667	2020-06-14 18:08:50	2020-06-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	30911	delivery	5	22
78668	2020-06-14 18:08:54	2020-06-14	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2741	delivery	5	49
78669	2020-06-14 18:09:45	2020-06-14	9	[{"id_menu":6,"count":1}]	7101	delivery	5	14
78670	2020-06-14 18:11:03	2020-06-14	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	30906	delivery	5	43
78671	2020-06-14 18:11:49	2020-06-14	14	[{"id_menu":2,"count":1}]	4233	delivery	5	19
78672	2020-06-14 18:11:51	2020-06-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	14699	delivery	5	22
78673	2020-06-14 18:14:42	2020-06-14	9	[{"id_menu":7,"count":1}]	1244	pick-up	0	9
78674	2020-06-14 18:16:59	2020-06-14	17	[{"id_menu":4,"count":1}]	10007	pick-up	0	17
78675	2020-06-14 18:19:33	2020-06-14	9	[{"id_menu":7,"count":1}]	13215	pick-up	0	9
78676	2020-06-14 18:22:58	2020-06-14	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	20266	delivery	5	38
78677	2020-06-14 18:24:55	2020-06-14	9	[{"id_menu":7,"count":1}]	25799	delivery	5	14
78678	2020-06-14 18:25:38	2020-06-14	14	[{"id_menu":2,"count":1}]	22784	pick-up	0	14
78679	2020-06-14 18:29:22	2020-06-14	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":3}]	30760	delivery	5	26
78680	2020-06-14 18:30:54	2020-06-14	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	11420	delivery	5	46
78681	2020-06-14 18:37:11	2020-06-14	12	[{"id_menu":3,"count":1}]	21485	pick-up	0	12
78682	2020-06-14 18:40:17	2020-06-14	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	30904	delivery	5	25
78683	2020-06-14 18:41:25	2020-06-14	8	[{"id_menu":5,"count":1}]	11491	pick-up	0	8
78684	2020-06-14 18:45:16	2020-06-14	14	[{"id_menu":2,"count":1}]	9402	delivery	5	19
78685	2020-06-14 18:47:58	2020-06-14	12	[{"id_menu":3,"count":1}]	6910	delivery	5	17
78686	2020-06-14 18:48:55	2020-06-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	21029	delivery	5	28
78687	2020-06-14 18:52:00	2020-06-14	9	[{"id_menu":7,"count":1}]	22267	delivery	5	14
78688	2020-06-14 18:53:48	2020-06-14	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14600	delivery	5	39
78689	2020-06-14 18:54:56	2020-06-14	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	5215	pick-up	0	47
78690	2020-06-14 18:56:50	2020-06-14	12	[{"id_menu":3,"count":1}]	24105	delivery	5	17
78691	2020-06-14 18:59:20	2020-06-14	12	[{"id_menu":1,"count":1}]	14306	delivery	5	17
78692	2020-06-14 19:02:43	2020-06-14	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	30928	delivery	5	25
78693	2020-06-14 19:06:00	2020-06-14	9	[{"id_menu":6,"count":1}]	3144	pick-up	0	9
78694	2020-06-14 19:07:51	2020-06-14	9	[{"id_menu":6,"count":1}]	25842	delivery	5	14
78695	2020-06-14 19:07:54	2020-06-14	12	[{"id_menu":3,"count":1}]	30852	delivery	5	17
78696	2020-06-14 19:08:35	2020-06-14	8	[{"id_menu":5,"count":1}]	23102	delivery	5	13
78697	2020-06-14 19:11:46	2020-06-14	8	[{"id_menu":5,"count":1}]	22913	delivery	5	13
78698	2020-06-14 19:12:42	2020-06-14	12	[{"id_menu":3,"count":1}]	3512	pick-up	0	12
78699	2020-06-14 19:13:34	2020-06-14	17	[{"id_menu":4,"count":1}]	30814	pick-up	0	17
78700	2020-06-14 19:13:55	2020-06-14	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3515	delivery	5	45
78701	2020-06-14 19:14:34	2020-06-14	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19686	delivery	5	40
78702	2020-06-14 19:17:34	2020-06-14	8	[{"id_menu":5,"count":1}]	209	pick-up	0	8
78703	2020-06-14 19:17:57	2020-06-14	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	30879	delivery	5	36
78704	2020-06-14 19:18:38	2020-06-14	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	16662	delivery	5	28
78705	2020-06-14 19:22:34	2020-06-14	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	17669	delivery	5	31
78706	2020-06-14 19:23:17	2020-06-14	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15735	delivery	5	22
78707	2020-06-14 19:24:33	2020-06-14	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29737	delivery	5	40
78708	2020-06-14 19:27:43	2020-06-14	12	[{"id_menu":3,"count":1}]	22221	delivery	5	17
78709	2020-06-14 19:28:55	2020-06-14	9	[{"id_menu":7,"count":1}]	30838	delivery	5	14
78710	2020-06-14 19:29:44	2020-06-14	9	[{"id_menu":6,"count":1}]	30867	delivery	5	14
78711	2020-06-14 19:30:20	2020-06-14	9	[{"id_menu":6,"count":1}]	26239	pick-up	0	9
78712	2020-06-14 19:32:05	2020-06-14	9	[{"id_menu":6,"count":1}]	11010	pick-up	0	9
78713	2020-06-14 19:32:38	2020-06-14	12	[{"id_menu":1,"count":1}]	23673	delivery	5	17
78714	2020-06-14 19:32:39	2020-06-14	9	[{"id_menu":7,"count":1}]	30775	delivery	5	14
78715	2020-06-14 19:34:21	2020-06-14	9	[{"id_menu":6,"count":2}]	23541	delivery	5	14
78716	2020-06-14 19:34:32	2020-06-14	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	227	pick-up	0	26
78717	2020-06-14 19:40:27	2020-06-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	30722	delivery	5	22
78718	2020-06-14 19:42:28	2020-06-14	12	[{"id_menu":1,"count":1}]	30815	delivery	5	17
78719	2020-06-14 19:44:06	2020-06-14	9	[{"id_menu":6,"count":1}]	5580	delivery	5	14
78720	2020-06-14 19:44:45	2020-06-14	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	30858	delivery	5	23
78721	2020-06-14 19:44:55	2020-06-14	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	30798	delivery	5	34
78722	2020-06-14 19:48:31	2020-06-14	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6598	delivery	5	43
78723	2020-06-14 19:50:37	2020-06-14	9	[{"id_menu":6,"count":1}]	30762	pick-up	0	9
78724	2020-06-14 19:51:13	2020-06-14	9	[{"id_menu":7,"count":2}]	12525	delivery	5	14
78725	2020-06-14 19:56:30	2020-06-14	8	[{"id_menu":5,"count":1}]	30920	delivery	5	13
78726	2020-06-14 19:59:05	2020-06-14	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	764	delivery	5	22
78727	2020-06-14 20:05:45	2020-06-14	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	18269	delivery	5	34
78728	2020-06-14 20:07:23	2020-06-14	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30888	delivery	5	23
78729	2020-06-14 20:08:16	2020-06-14	14	[{"id_menu":2,"count":1}]	10991	delivery	5	19
78730	2020-06-14 20:12:22	2020-06-14	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	9005	delivery	5	26
78731	2020-06-14 20:15:23	2020-06-14	14	[{"id_menu":2,"count":1}]	27613	delivery	5	19
78732	2020-06-14 20:16:30	2020-06-14	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14462	pick-up	0	17
78733	2020-06-14 20:19:04	2020-06-14	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18937	delivery	5	34
78734	2020-06-14 20:19:09	2020-06-14	17	[{"id_menu":4,"count":1}]	4728	delivery	5	22
78735	2020-06-14 20:19:53	2020-06-14	8	[{"id_menu":5,"count":1}]	30885	delivery	5	13
78736	2020-06-14 20:20:33	2020-06-14	9	[{"id_menu":6,"count":1}]	26574	delivery	5	14
78737	2020-06-14 20:20:35	2020-06-14	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	30777	pick-up	0	47
78738	2020-06-14 20:20:36	2020-06-14	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	30923	delivery	5	22
78739	2020-06-14 20:20:42	2020-06-14	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	18958	pick-up	0	21
78740	2020-06-14 20:23:54	2020-06-14	9	[{"id_menu":7,"count":1}]	23025	delivery	5	14
78741	2020-06-14 20:27:41	2020-06-14	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21693	delivery	5	22
78742	2020-06-14 20:28:10	2020-06-14	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	26998	delivery	5	43
78743	2020-06-14 20:29:14	2020-06-14	12	[{"id_menu":3,"count":1}]	20742	delivery	5	17
78744	2020-06-14 20:29:20	2020-06-14	14	[{"id_menu":2,"count":1}]	30772	pick-up	0	14
78745	2020-06-14 20:34:12	2020-06-14	17	[{"id_menu":4,"count":1}]	22261	delivery	5	22
78746	2020-06-14 20:35:34	2020-06-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3169	delivery	5	28
78747	2020-06-14 20:38:56	2020-06-14	8	[{"id_menu":5,"count":1}]	17769	delivery	5	13
78748	2020-06-14 20:43:34	2020-06-14	14	[{"id_menu":2,"count":1}]	6134	pick-up	0	14
78749	2020-06-14 20:43:42	2020-06-14	8	[{"id_menu":5,"count":1}]	2807	pick-up	0	8
78750	2020-06-14 20:44:56	2020-06-14	14	[{"id_menu":2,"count":1}]	8448	delivery	5	19
78751	2020-06-14 20:46:49	2020-06-14	14	[{"id_menu":2,"count":1}]	27148	pick-up	0	14
78752	2020-06-14 20:47:33	2020-06-14	12	[{"id_menu":1,"count":1}]	6439	pick-up	0	12
78753	2020-06-14 20:48:10	2020-06-14	12	[{"id_menu":1,"count":1}]	30935	delivery	5	17
78754	2020-06-14 20:50:36	2020-06-14	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	17780	delivery	5	44
78755	2020-06-14 20:52:33	2020-06-14	12	[{"id_menu":1,"count":1}]	6687	pick-up	0	12
78756	2020-06-14 20:53:34	2020-06-14	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	30921	delivery	5	22
78757	2020-06-14 20:54:38	2020-06-14	9	[{"id_menu":7,"count":1}]	2780	pick-up	0	9
78758	2020-06-14 20:55:43	2020-06-14	12	[{"id_menu":3,"count":1}]	20782	pick-up	0	12
78759	2020-06-14 20:55:51	2020-06-14	17	[{"id_menu":4,"count":1}]	22175	delivery	5	22
78760	2020-06-14 20:55:54	2020-06-14	12	[{"id_menu":1,"count":1}]	30771	pick-up	0	12
78761	2020-06-14 20:59:50	2020-06-14	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	18491	delivery	5	28
78762	2020-06-14 21:00:17	2020-06-14	12	[{"id_menu":1,"count":2}]	23302	delivery	5	17
78763	2020-06-14 21:02:19	2020-06-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2551	pick-up	0	31
78764	2020-06-14 21:03:04	2020-06-14	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	12457	delivery	5	26
78765	2020-06-14 21:05:23	2020-06-14	9	[{"id_menu":6,"count":1}]	30795	delivery	5	14
78766	2020-06-14 21:05:27	2020-06-14	8	[{"id_menu":5,"count":1}]	6744	pick-up	0	8
78767	2020-06-14 21:09:00	2020-06-14	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	27455	delivery	5	31
78768	2020-06-14 21:09:59	2020-06-14	9	[{"id_menu":7,"count":1}]	16472	pick-up	0	9
78769	2020-06-14 21:10:09	2020-06-14	9	[{"id_menu":7,"count":1}]	27863	delivery	5	14
78770	2020-06-14 21:10:22	2020-06-14	9	[{"id_menu":6,"count":1}]	7189	pick-up	0	9
78771	2020-06-14 21:13:21	2020-06-14	8	[{"id_menu":5,"count":1}]	5748	pick-up	0	8
78772	2020-06-14 21:14:08	2020-06-14	17	[{"id_menu":4,"count":1}]	244	delivery	5	22
78773	2020-06-14 21:14:46	2020-06-14	9	[{"id_menu":6,"count":1}]	13888	pick-up	0	9
78774	2020-06-14 21:15:41	2020-06-14	9	[{"id_menu":6,"count":1}]	30893	delivery	5	14
78775	2020-06-14 21:20:11	2020-06-14	12	[{"id_menu":1,"count":1}]	28305	pick-up	0	12
78776	2020-06-14 21:22:47	2020-06-14	17	[{"id_menu":4,"count":1}]	16916	delivery	5	22
78777	2020-06-14 21:22:57	2020-06-14	8	[{"id_menu":5,"count":1}]	30824	delivery	5	13
78778	2020-06-14 21:24:52	2020-06-14	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	30796	delivery	5	31
78779	2020-06-14 21:25:35	2020-06-14	9	[{"id_menu":7,"count":1}]	29036	pick-up	0	9
78780	2020-06-14 21:25:36	2020-06-14	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15995	delivery	5	31
78781	2020-06-14 21:26:56	2020-06-14	9	[{"id_menu":7,"count":1}]	17790	pick-up	0	9
78782	2020-06-14 21:28:34	2020-06-14	17	[{"id_menu":4,"count":1}]	1266	pick-up	0	17
78783	2020-06-14 21:29:09	2020-06-14	9	[{"id_menu":7,"count":1}]	12340	delivery	5	14
78784	2020-06-14 21:30:29	2020-06-14	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	30735	delivery	5	36
78785	2020-06-14 21:33:33	2020-06-14	17	[{"id_menu":4,"count":1}]	10159	delivery	5	22
78786	2020-06-14 21:33:40	2020-06-14	8	[{"id_menu":5,"count":1}]	16165	pick-up	0	8
78787	2020-06-14 21:38:22	2020-06-14	17	[{"id_menu":4,"count":1}]	21411	delivery	5	22
78788	2020-06-14 21:41:44	2020-06-14	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	30803	delivery	5	28
78789	2020-06-14 21:44:43	2020-06-14	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	30855	pick-up	0	17
78790	2020-06-14 21:46:36	2020-06-14	14	[{"id_menu":2,"count":1}]	24876	delivery	5	19
78791	2020-06-14 21:48:05	2020-06-14	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22199	delivery	5	49
78792	2020-06-14 21:48:53	2020-06-14	9	[{"id_menu":6,"count":1}]	8019	pick-up	0	9
78793	2020-06-14 21:49:37	2020-06-14	9	[{"id_menu":7,"count":1}]	30895	delivery	5	14
78794	2020-06-14 21:49:55	2020-06-14	9	[{"id_menu":6,"count":1}]	8891	delivery	5	14
78795	2020-06-14 21:50:16	2020-06-14	9	[{"id_menu":7,"count":1}]	30764	delivery	5	14
78796	2020-06-14 21:50:52	2020-06-14	9	[{"id_menu":6,"count":2}]	9831	delivery	5	14
78797	2020-06-14 21:52:13	2020-06-14	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	12132	delivery	5	27
78798	2020-06-14 21:53:19	2020-06-14	17	[{"id_menu":4,"count":1}]	14640	delivery	5	22
78799	2020-06-14 21:54:25	2020-06-14	12	[{"id_menu":3,"count":1}]	23875	delivery	5	17
78800	2020-06-14 21:54:36	2020-06-14	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30789	delivery	5	40
78801	2020-06-14 21:57:39	2020-06-14	12	[{"id_menu":3,"count":1}]	20477	pick-up	0	12
78802	2020-06-14 21:58:54	2020-06-14	14	[{"id_menu":2,"count":1}]	28593	delivery	5	19
78803	2020-06-14 21:59:58	2020-06-14	17	[{"id_menu":4,"count":1}]	8099	delivery	5	22
78804	2020-06-14 22:03:37	2020-06-14	9	[{"id_menu":6,"count":1}]	6756	delivery	5	14
78805	2020-06-14 22:03:46	2020-06-14	9	[{"id_menu":7,"count":1}]	24608	delivery	5	14
78806	2020-06-14 22:04:05	2020-06-14	12	[{"id_menu":1,"count":1}]	30788	delivery	5	17
78807	2020-06-14 22:04:13	2020-06-14	9	[{"id_menu":6,"count":1}]	1262	pick-up	0	9
78808	2020-06-14 22:04:16	2020-06-14	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21484	delivery	5	48
78809	2020-06-14 22:11:29	2020-06-14	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	30913	delivery	5	23
78810	2020-06-14 22:12:36	2020-06-14	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26236	delivery	5	23
78811	2020-06-14 22:13:42	2020-06-14	8	[{"id_menu":5,"count":1}]	30776	delivery	5	13
78812	2020-06-14 22:15:10	2020-06-14	14	[{"id_menu":2,"count":1}]	4964	delivery	5	19
78813	2020-06-14 22:15:55	2020-06-14	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	30793	delivery	5	40
78814	2020-06-14 22:16:27	2020-06-14	9	[{"id_menu":7,"count":1}]	23147	pick-up	0	9
78815	2020-06-14 22:16:49	2020-06-14	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	16170	delivery	5	36
78816	2020-06-14 22:17:45	2020-06-14	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10387	delivery	5	23
78817	2020-06-14 22:18:07	2020-06-14	14	[{"id_menu":2,"count":1}]	30812	pick-up	0	14
78818	2020-06-14 22:19:15	2020-06-14	12	[{"id_menu":3,"count":1}]	1649	pick-up	0	12
78819	2020-06-14 22:23:48	2020-06-14	17	[{"id_menu":4,"count":1}]	24975	delivery	5	22
78820	2020-06-14 22:25:22	2020-06-14	12	[{"id_menu":3,"count":1}]	11170	delivery	5	17
78821	2020-06-14 22:26:57	2020-06-14	9	[{"id_menu":6,"count":1}]	4968	delivery	5	14
78822	2020-06-14 22:28:08	2020-06-14	9	[{"id_menu":7,"count":1}]	5509	delivery	5	14
78823	2020-06-14 22:28:10	2020-06-14	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1106	pick-up	0	21
78824	2020-06-14 22:29:01	2020-06-14	9	[{"id_menu":6,"count":1}]	25677	delivery	5	14
78825	2020-06-14 22:29:11	2020-06-14	14	[{"id_menu":2,"count":1}]	29215	delivery	5	19
78826	2020-06-14 22:32:53	2020-06-14	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1125	pick-up	0	21
78827	2020-06-14 22:33:02	2020-06-14	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	24702	delivery	5	34
78828	2020-06-14 22:33:35	2020-06-14	14	[{"id_menu":2,"count":1}]	1832	pick-up	0	14
78829	2020-06-14 22:35:02	2020-06-14	17	[{"id_menu":4,"count":2}]	30831	delivery	5	22
78830	2020-06-14 22:36:20	2020-06-14	8	[{"id_menu":5,"count":1}]	30761	delivery	5	13
78831	2020-06-14 22:42:39	2020-06-14	12	[{"id_menu":1,"count":1}]	4350	pick-up	0	12
78832	2020-06-14 22:44:41	2020-06-14	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	30765	delivery	5	51
78833	2020-06-14 22:44:56	2020-06-14	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	30624	delivery	5	48
78834	2020-06-14 22:48:59	2020-06-14	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	30897	pick-up	0	26
78835	2020-06-14 22:53:23	2020-06-14	14	[{"id_menu":2,"count":1}]	2894	pick-up	0	14
78836	2020-06-14 22:57:14	2020-06-14	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	30910	delivery	5	22
78837	2020-06-14 23:01:17	2020-06-14	17	[{"id_menu":4,"count":1}]	26967	pick-up	0	17
78838	2020-06-14 23:04:22	2020-06-14	12	[{"id_menu":1,"count":1}]	1756	pick-up	0	12
78839	2020-06-14 23:04:26	2020-06-14	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	30737	delivery	5	26
78840	2020-06-14 23:12:23	2020-06-14	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":2}]	30853	delivery	5	22
78841	2020-06-14 23:14:33	2020-06-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	30716	delivery	5	31
78842	2020-06-14 23:14:57	2020-06-14	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1961	pick-up	0	26
78843	2020-06-14 23:22:55	2020-06-14	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24872	pick-up	0	34
78844	2020-06-14 23:24:11	2020-06-14	9	[{"id_menu":6,"count":1}]	30932	delivery	5	14
78845	2020-06-14 23:24:15	2020-06-14	9	[{"id_menu":7,"count":2}]	21716	delivery	5	14
78846	2020-06-14 23:24:22	2020-06-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3802	pick-up	0	26
78847	2020-06-14 23:27:19	2020-06-14	14	[{"id_menu":2,"count":1}]	21335	delivery	5	19
78848	2020-06-14 23:27:22	2020-06-14	49	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	19561	delivery	5	54
78849	2020-06-14 23:29:14	2020-06-14	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15188	delivery	5	23
78850	2020-06-14 23:31:38	2020-06-14	12	[{"id_menu":1,"count":2}]	18704	pick-up	0	12
78851	2020-06-14 23:32:22	2020-06-14	17	[{"id_menu":4,"count":1}]	30927	delivery	5	22
78852	2020-06-14 23:34:21	2020-06-14	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	16839	delivery	5	31
78853	2020-06-14 23:35:15	2020-06-14	9	[{"id_menu":7,"count":1}]	23029	delivery	5	14
78854	2020-06-14 23:39:55	2020-06-14	12	[{"id_menu":1,"count":1}]	26821	pick-up	0	12
78855	2020-06-14 23:40:24	2020-06-14	17	[{"id_menu":4,"count":1}]	2418	delivery	5	22
78856	2020-06-14 23:44:40	2020-06-14	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30715	delivery	5	23
78857	2020-06-14 23:44:50	2020-06-14	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	30758	delivery	5	22
78858	2020-06-14 23:47:40	2020-06-14	9	[{"id_menu":6,"count":1}]	30728	pick-up	0	9
78859	2020-06-14 23:52:45	2020-06-14	12	[{"id_menu":3,"count":1}]	3066	pick-up	0	12
78860	2020-06-14 23:56:02	2020-06-14	8	[{"id_menu":5,"count":1}]	16230	delivery	5	13
78861	2020-06-14 23:56:37	2020-06-14	8	[{"id_menu":5,"count":2}]	13136	pick-up	0	8
78862	2020-06-14 23:58:34	2020-06-14	17	[{"id_menu":4,"count":1}]	23954	delivery	5	22
78863	2020-06-15 00:00:01	2020-06-15	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	30954	delivery	5	26
78864	2020-06-15 00:00:59	2020-06-15	9	[{"id_menu":6,"count":1}]	31009	delivery	5	14
78865	2020-06-15 00:02:17	2020-06-15	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	22556	delivery	5	25
78866	2020-06-15 00:12:41	2020-06-15	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1344	pick-up	0	21
78867	2020-06-15 00:16:02	2020-06-15	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	6295	delivery	5	36
78868	2020-06-15 00:20:36	2020-06-15	9	[{"id_menu":7,"count":1}]	31067	delivery	5	14
78869	2020-06-15 00:27:38	2020-06-15	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	21671	delivery	5	44
78870	2020-06-15 00:32:25	2020-06-15	8	[{"id_menu":5,"count":1}]	30984	delivery	5	13
78871	2020-06-15 00:33:06	2020-06-15	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15916	delivery	5	31
78872	2020-06-15 00:33:32	2020-06-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	18406	delivery	5	28
78873	2020-06-15 00:38:36	2020-06-15	9	[{"id_menu":6,"count":1}]	17491	pick-up	0	9
78874	2020-06-15 00:41:38	2020-06-15	9	[{"id_menu":6,"count":1}]	15079	delivery	5	14
78875	2020-06-15 00:50:18	2020-06-15	14	[{"id_menu":2,"count":1}]	16685	delivery	5	19
78876	2020-06-15 00:51:29	2020-06-15	9	[{"id_menu":7,"count":1}]	2706	delivery	5	14
78877	2020-06-15 00:55:34	2020-06-15	17	[{"id_menu":4,"count":2}]	22359	pick-up	0	17
78878	2020-06-15 01:05:24	2020-06-15	8	[{"id_menu":5,"count":1}]	8873	pick-up	0	8
78879	2020-06-15 01:08:40	2020-06-15	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31042	delivery	5	22
78880	2020-06-15 01:14:28	2020-06-15	12	[{"id_menu":1,"count":1}]	30983	delivery	5	17
78881	2020-06-15 01:15:37	2020-06-15	14	[{"id_menu":2,"count":1}]	3864	pick-up	0	14
78882	2020-06-15 01:16:51	2020-06-15	23	[{"id_menu":2,"count":3},{"id_menu":7,"count":1}]	30995	delivery	5	28
78883	2020-06-15 01:22:16	2020-06-15	17	[{"id_menu":4,"count":2}]	20183	delivery	5	22
78884	2020-06-15 01:23:06	2020-06-15	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1070	pick-up	0	22
78885	2020-06-15 01:29:23	2020-06-15	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	20464	delivery	5	43
78886	2020-06-15 01:33:15	2020-06-15	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	31003	delivery	5	45
78887	2020-06-15 01:39:22	2020-06-15	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	30952	delivery	5	36
78888	2020-06-15 01:39:53	2020-06-15	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	30998	delivery	5	31
78889	2020-06-15 01:42:51	2020-06-15	9	[{"id_menu":7,"count":2}]	27716	delivery	5	14
78890	2020-06-15 01:50:11	2020-06-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30349	delivery	5	23
78891	2020-06-15 01:52:26	2020-06-15	8	[{"id_menu":5,"count":1}]	8409	delivery	5	13
78892	2020-06-15 01:59:36	2020-06-15	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	22318	delivery	5	31
78893	2020-06-15 02:05:13	2020-06-15	17	[{"id_menu":4,"count":1}]	5613	delivery	5	22
78894	2020-06-15 02:15:44	2020-06-15	9	[{"id_menu":7,"count":1}]	16592	delivery	5	14
78895	2020-06-15 02:20:30	2020-06-15	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5989	delivery	5	22
78896	2020-06-15 02:24:51	2020-06-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12875	delivery	5	23
78897	2020-06-15 02:25:26	2020-06-15	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	31051	delivery	5	35
78898	2020-06-15 02:37:03	2020-06-15	12	[{"id_menu":3,"count":1}]	8595	pick-up	0	12
78899	2020-06-15 02:42:08	2020-06-15	9	[{"id_menu":6,"count":1}]	30957	pick-up	0	9
78900	2020-06-15 02:42:14	2020-06-15	12	[{"id_menu":1,"count":1}]	30972	delivery	5	17
78901	2020-06-15 02:50:59	2020-06-15	17	[{"id_menu":4,"count":1}]	27127	pick-up	0	17
78902	2020-06-15 03:02:32	2020-06-15	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	22414	delivery	5	40
78903	2020-06-15 03:02:51	2020-06-15	17	[{"id_menu":4,"count":1}]	18227	delivery	5	22
78904	2020-06-15 03:03:32	2020-06-15	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2421	pick-up	0	26
78905	2020-06-15 03:12:00	2020-06-15	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20579	delivery	5	54
78906	2020-06-15 03:12:59	2020-06-15	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13601	delivery	5	55
78907	2020-06-15 03:16:53	2020-06-15	9	[{"id_menu":6,"count":1}]	442	delivery	5	14
78908	2020-06-15 03:26:22	2020-06-15	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	25882	delivery	5	45
78909	2020-06-15 03:30:18	2020-06-15	9	[{"id_menu":7,"count":1}]	29799	delivery	5	14
78910	2020-06-15 03:30:19	2020-06-15	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	3335	delivery	5	31
78911	2020-06-15 03:33:44	2020-06-15	9	[{"id_menu":6,"count":1}]	31027	delivery	5	14
78912	2020-06-15 03:34:18	2020-06-15	9	[{"id_menu":6,"count":1}]	4372	delivery	5	14
78913	2020-06-15 03:35:00	2020-06-15	9	[{"id_menu":7,"count":1}]	15063	pick-up	0	9
78914	2020-06-15 03:45:43	2020-06-15	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	20557	delivery	5	45
78915	2020-06-15 03:48:21	2020-06-15	14	[{"id_menu":2,"count":1}]	7796	delivery	5	19
78916	2020-06-15 03:56:02	2020-06-15	12	[{"id_menu":3,"count":1}]	31045	delivery	5	17
78917	2020-06-15 04:27:01	2020-06-15	9	[{"id_menu":6,"count":1}]	31028	delivery	5	14
78918	2020-06-15 04:31:47	2020-06-15	14	[{"id_menu":2,"count":1}]	25596	pick-up	0	14
78919	2020-06-15 04:38:28	2020-06-15	17	[{"id_menu":4,"count":1}]	31008	delivery	5	22
78920	2020-06-15 04:40:48	2020-06-15	12	[{"id_menu":3,"count":1}]	20754	pick-up	0	12
78921	2020-06-15 04:43:13	2020-06-15	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	31039	delivery	5	43
78922	2020-06-15 04:45:32	2020-06-15	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	18591	delivery	5	31
78923	2020-06-15 04:56:13	2020-06-15	12	[{"id_menu":1,"count":1}]	26359	delivery	5	17
78924	2020-06-15 04:58:49	2020-06-15	14	[{"id_menu":2,"count":1}]	23698	delivery	5	19
78925	2020-06-15 05:02:15	2020-06-15	12	[{"id_menu":3,"count":1}]	30987	pick-up	0	12
78926	2020-06-15 05:12:56	2020-06-15	9	[{"id_menu":6,"count":1}]	27799	delivery	5	14
78927	2020-06-15 05:15:37	2020-06-15	8	[{"id_menu":5,"count":1}]	3260	pick-up	0	8
78928	2020-06-15 05:17:19	2020-06-15	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	7582	delivery	5	31
78929	2020-06-15 05:18:49	2020-06-15	14	[{"id_menu":2,"count":1}]	30970	delivery	5	19
78930	2020-06-15 05:21:24	2020-06-15	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9352	delivery	5	36
78931	2020-06-15 05:21:59	2020-06-15	9	[{"id_menu":6,"count":1}]	8219	pick-up	0	9
78932	2020-06-15 05:25:03	2020-06-15	14	[{"id_menu":2,"count":1}]	574	pick-up	0	14
78933	2020-06-15 05:30:48	2020-06-15	12	[{"id_menu":1,"count":1}]	22381	pick-up	0	12
78934	2020-06-15 05:40:40	2020-06-15	12	[{"id_menu":1,"count":1}]	4329	delivery	5	17
78935	2020-06-15 05:41:13	2020-06-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3819	delivery	5	23
78936	2020-06-15 05:47:41	2020-06-15	14	[{"id_menu":2,"count":1}]	5642	pick-up	0	14
78937	2020-06-15 05:49:02	2020-06-15	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	9017	delivery	5	36
78938	2020-06-15 05:51:39	2020-06-15	9	[{"id_menu":6,"count":1}]	24221	delivery	5	14
78939	2020-06-15 05:54:31	2020-06-15	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1661	pick-up	0	35
78940	2020-06-15 05:57:17	2020-06-15	12	[{"id_menu":1,"count":1}]	3198	pick-up	0	12
78941	2020-06-15 05:59:23	2020-06-15	9	[{"id_menu":6,"count":1}]	17534	delivery	5	14
78942	2020-06-15 06:01:24	2020-06-15	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3701	delivery	5	27
78943	2020-06-15 06:14:24	2020-06-15	14	[{"id_menu":2,"count":1}]	3117	delivery	5	19
78944	2020-06-15 06:15:05	2020-06-15	9	[{"id_menu":7,"count":1}]	30985	delivery	5	14
78945	2020-06-15 06:15:43	2020-06-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	31098	delivery	5	28
78946	2020-06-15 06:23:15	2020-06-15	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	25532	delivery	5	31
78947	2020-06-15 06:30:28	2020-06-15	8	[{"id_menu":5,"count":1}]	352	pick-up	0	8
78948	2020-06-15 06:36:06	2020-06-15	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17799	delivery	5	31
78949	2020-06-15 06:36:50	2020-06-15	14	[{"id_menu":2,"count":1}]	4804	pick-up	0	14
78950	2020-06-15 06:39:20	2020-06-15	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	31063	pick-up	0	25
78951	2020-06-15 06:44:42	2020-06-15	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	30963	delivery	5	34
78952	2020-06-15 06:48:21	2020-06-15	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	31106	delivery	5	27
78953	2020-06-15 07:07:26	2020-06-15	9	[{"id_menu":7,"count":1}]	29193	delivery	5	14
78954	2020-06-15 07:12:57	2020-06-15	17	[{"id_menu":4,"count":1}]	28343	delivery	5	22
78955	2020-06-15 07:14:08	2020-06-15	9	[{"id_menu":6,"count":2}]	6664	delivery	5	14
78956	2020-06-15 07:20:22	2020-06-15	17	[{"id_menu":4,"count":1}]	29048	delivery	5	22
78957	2020-06-15 07:31:44	2020-06-15	12	[{"id_menu":1,"count":1}]	27912	delivery	5	17
78958	2020-06-15 07:31:47	2020-06-15	12	[{"id_menu":1,"count":1}]	9476	delivery	5	17
78959	2020-06-15 07:32:21	2020-06-15	9	[{"id_menu":7,"count":1}]	31093	delivery	5	14
78960	2020-06-15 07:36:42	2020-06-15	8	[{"id_menu":5,"count":1}]	31004	delivery	5	13
78961	2020-06-15 07:38:52	2020-06-15	12	[{"id_menu":3,"count":1}]	28929	pick-up	0	12
78962	2020-06-15 07:41:13	2020-06-15	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1623	pick-up	0	22
78963	2020-06-15 07:46:45	2020-06-15	12	[{"id_menu":1,"count":3}]	30602	delivery	5	17
78964	2020-06-15 07:47:03	2020-06-15	17	[{"id_menu":4,"count":1}]	31109	delivery	5	22
78965	2020-06-15 07:51:27	2020-06-15	8	[{"id_menu":5,"count":1}]	31085	delivery	5	13
78966	2020-06-15 07:51:54	2020-06-15	9	[{"id_menu":6,"count":1}]	27694	delivery	5	14
78967	2020-06-15 07:57:14	2020-06-15	8	[{"id_menu":5,"count":1}]	8700	delivery	5	13
78968	2020-06-15 07:57:19	2020-06-15	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21273	pick-up	0	26
78969	2020-06-15 08:00:40	2020-06-15	14	[{"id_menu":2,"count":2}]	14885	delivery	5	19
78970	2020-06-15 08:04:19	2020-06-15	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31110	delivery	5	35
78971	2020-06-15 08:13:44	2020-06-15	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30982	delivery	5	43
78972	2020-06-15 08:16:56	2020-06-15	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	26993	delivery	5	22
78973	2020-06-15 08:17:45	2020-06-15	8	[{"id_menu":5,"count":1}]	30951	delivery	5	13
78974	2020-06-15 08:21:59	2020-06-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	29127	pick-up	0	18
78975	2020-06-15 08:27:33	2020-06-15	12	[{"id_menu":1,"count":1}]	30996	delivery	5	17
78976	2020-06-15 08:29:06	2020-06-15	8	[{"id_menu":5,"count":1}]	31111	delivery	5	13
78977	2020-06-15 08:31:34	2020-06-15	17	[{"id_menu":4,"count":1}]	30977	delivery	5	22
78978	2020-06-15 08:45:47	2020-06-15	14	[{"id_menu":2,"count":1}]	31070	delivery	5	19
78979	2020-06-15 08:47:04	2020-06-15	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	11878	pick-up	0	43
78980	2020-06-15 08:48:52	2020-06-15	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31034	delivery	5	39
78981	2020-06-15 08:50:18	2020-06-15	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	10894	delivery	5	27
78982	2020-06-15 08:55:23	2020-06-15	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	22606	delivery	5	30
78983	2020-06-15 08:58:58	2020-06-15	8	[{"id_menu":5,"count":1}]	10325	pick-up	0	8
78984	2020-06-15 09:04:20	2020-06-15	8	[{"id_menu":5,"count":1}]	14473	delivery	5	13
78985	2020-06-15 09:08:26	2020-06-15	9	[{"id_menu":6,"count":1}]	29776	delivery	5	14
78986	2020-06-15 09:09:13	2020-06-15	14	[{"id_menu":2,"count":1}]	30665	delivery	5	19
78987	2020-06-15 09:16:07	2020-06-15	14	[{"id_menu":2,"count":1}]	23005	delivery	5	19
78988	2020-06-15 09:19:00	2020-06-15	8	[{"id_menu":5,"count":1}]	3153	pick-up	0	8
78989	2020-06-15 09:19:12	2020-06-15	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	31007	delivery	5	34
78990	2020-06-15 09:19:12	2020-06-15	9	[{"id_menu":6,"count":1}]	2965	delivery	5	14
78991	2020-06-15 09:34:45	2020-06-15	9	[{"id_menu":7,"count":1}]	31012	delivery	5	14
78992	2020-06-15 09:38:46	2020-06-15	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31019	delivery	5	22
78993	2020-06-15 09:40:04	2020-06-15	17	[{"id_menu":4,"count":1}]	29469	delivery	5	22
78994	2020-06-15 09:46:29	2020-06-15	17	[{"id_menu":4,"count":1}]	1414	pick-up	0	17
78995	2020-06-15 09:53:08	2020-06-15	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	12579	delivery	5	31
78996	2020-06-15 09:54:15	2020-06-15	17	[{"id_menu":4,"count":1}]	12078	delivery	5	22
78997	2020-06-15 09:55:32	2020-06-15	8	[{"id_menu":5,"count":1}]	3851	pick-up	0	8
78998	2020-06-15 09:55:33	2020-06-15	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	10829	delivery	5	36
78999	2020-06-15 10:01:02	2020-06-15	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6200	delivery	5	22
79000	2020-06-15 10:05:07	2020-06-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11716	delivery	5	23
79001	2020-06-15 10:05:40	2020-06-15	9	[{"id_menu":7,"count":1}]	21956	delivery	5	14
79002	2020-06-15 10:12:00	2020-06-15	17	[{"id_menu":4,"count":1}]	2005	delivery	5	22
79003	2020-06-15 10:12:55	2020-06-15	14	[{"id_menu":2,"count":1}]	7947	delivery	5	19
79004	2020-06-15 10:20:38	2020-06-15	14	[{"id_menu":2,"count":3}]	30941	delivery	5	19
79005	2020-06-15 10:27:30	2020-06-15	8	[{"id_menu":5,"count":1}]	581	delivery	5	13
79006	2020-06-15 10:27:54	2020-06-15	8	[{"id_menu":5,"count":1}]	19794	delivery	5	13
79007	2020-06-15 10:32:12	2020-06-15	12	[{"id_menu":1,"count":1}]	7574	pick-up	0	12
79008	2020-06-15 10:33:45	2020-06-15	12	[{"id_menu":3,"count":1}]	543	delivery	5	17
79009	2020-06-15 10:33:50	2020-06-15	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	20338	pick-up	0	21
79010	2020-06-15 10:37:16	2020-06-15	12	[{"id_menu":3,"count":1}]	31074	delivery	5	17
79011	2020-06-15 10:45:08	2020-06-15	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	2185	pick-up	0	26
79012	2020-06-15 10:46:31	2020-06-15	12	[{"id_menu":1,"count":1}]	4751	pick-up	0	12
79013	2020-06-15 10:48:25	2020-06-15	8	[{"id_menu":5,"count":1}]	21437	delivery	5	13
79014	2020-06-15 10:57:09	2020-06-15	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	31021	delivery	5	36
79015	2020-06-15 11:02:25	2020-06-15	12	[{"id_menu":1,"count":1}]	30993	delivery	5	17
79016	2020-06-15 11:13:28	2020-06-15	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	20970	delivery	5	25
79017	2020-06-15 11:13:55	2020-06-15	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	30968	pick-up	0	20
79018	2020-06-15 11:14:52	2020-06-15	8	[{"id_menu":5,"count":1}]	24622	delivery	5	13
79019	2020-06-15 11:14:58	2020-06-15	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5970	pick-up	0	50
79020	2020-06-15 11:16:46	2020-06-15	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	9716	delivery	5	34
79021	2020-06-15 11:17:24	2020-06-15	17	[{"id_menu":4,"count":1}]	6044	delivery	5	22
79022	2020-06-15 11:24:57	2020-06-15	8	[{"id_menu":5,"count":1}]	23431	delivery	5	13
79023	2020-06-15 11:28:23	2020-06-15	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	31001	delivery	5	40
79024	2020-06-15 11:31:34	2020-06-15	9	[{"id_menu":7,"count":3}]	18167	delivery	5	14
79025	2020-06-15 11:33:27	2020-06-15	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	443	delivery	5	42
79026	2020-06-15 11:34:06	2020-06-15	14	[{"id_menu":2,"count":1}]	30991	delivery	5	19
79027	2020-06-15 11:40:10	2020-06-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	31099	delivery	5	31
79028	2020-06-15 11:43:18	2020-06-15	12	[{"id_menu":1,"count":1}]	7603	pick-up	0	12
79029	2020-06-15 11:44:01	2020-06-15	12	[{"id_menu":3,"count":1}]	31073	delivery	5	17
79030	2020-06-15 11:44:22	2020-06-15	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	18420	delivery	5	30
79031	2020-06-15 12:02:33	2020-06-15	12	[{"id_menu":3,"count":1}]	31086	delivery	5	17
79032	2020-06-15 12:04:39	2020-06-15	14	[{"id_menu":2,"count":1}]	25346	pick-up	0	14
79033	2020-06-15 12:10:23	2020-06-15	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	31084	delivery	5	48
79034	2020-06-15 12:13:34	2020-06-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12205	delivery	5	31
79035	2020-06-15 12:15:18	2020-06-15	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	304	pick-up	0	18
79036	2020-06-15 12:17:18	2020-06-15	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	19822	delivery	5	31
79037	2020-06-15 12:17:57	2020-06-15	43	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	26736	delivery	5	48
79038	2020-06-15 12:23:49	2020-06-15	9	[{"id_menu":7,"count":1}]	6104	delivery	5	14
79039	2020-06-15 12:26:07	2020-06-15	8	[{"id_menu":5,"count":1}]	31080	delivery	5	13
79040	2020-06-15 12:28:04	2020-06-15	8	[{"id_menu":5,"count":1}]	24569	delivery	5	13
79041	2020-06-15 12:28:08	2020-06-15	9	[{"id_menu":6,"count":1}]	31015	delivery	5	14
79042	2020-06-15 12:31:30	2020-06-15	8	[{"id_menu":5,"count":1}]	24763	delivery	5	13
79043	2020-06-15 12:43:22	2020-06-15	12	[{"id_menu":1,"count":1}]	17673	delivery	5	17
79044	2020-06-15 12:44:58	2020-06-15	9	[{"id_menu":6,"count":1}]	31107	delivery	5	14
79045	2020-06-15 12:48:56	2020-06-15	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3990	delivery	5	43
79046	2020-06-15 12:51:22	2020-06-15	12	[{"id_menu":3,"count":1}]	30979	delivery	5	17
79047	2020-06-15 12:52:24	2020-06-15	17	[{"id_menu":4,"count":1}]	13193	delivery	5	22
79048	2020-06-15 12:53:46	2020-06-15	14	[{"id_menu":2,"count":1}]	15585	delivery	5	19
79049	2020-06-15 13:03:01	2020-06-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5643	pick-up	0	23
79050	2020-06-15 13:08:43	2020-06-15	12	[{"id_menu":3,"count":1}]	9241	pick-up	0	12
79051	2020-06-15 13:11:47	2020-06-15	8	[{"id_menu":5,"count":1}]	26911	pick-up	0	8
79052	2020-06-15 13:13:21	2020-06-15	12	[{"id_menu":3,"count":1}]	31087	delivery	5	17
79053	2020-06-15 13:26:52	2020-06-15	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	31035	delivery	5	31
79054	2020-06-15 13:33:45	2020-06-15	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	26049	delivery	5	40
79055	2020-06-15 13:34:28	2020-06-15	9	[{"id_menu":6,"count":1}]	21319	delivery	5	14
79056	2020-06-15 13:40:07	2020-06-15	14	[{"id_menu":2,"count":1}]	4193	pick-up	0	14
79057	2020-06-15 13:42:50	2020-06-15	9	[{"id_menu":6,"count":1}]	1687	pick-up	0	9
79058	2020-06-15 13:47:03	2020-06-15	17	[{"id_menu":4,"count":1}]	30973	delivery	5	22
79059	2020-06-15 13:49:17	2020-06-15	9	[{"id_menu":7,"count":1}]	29628	pick-up	0	9
79060	2020-06-15 13:50:56	2020-06-15	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	12265	delivery	5	31
79061	2020-06-15 13:54:35	2020-06-15	8	[{"id_menu":5,"count":1}]	25285	delivery	5	13
79062	2020-06-15 14:09:00	2020-06-15	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27449	delivery	5	34
79063	2020-06-15 14:09:26	2020-06-15	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14138	delivery	5	22
79064	2020-06-15 14:11:58	2020-06-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	31058	delivery	5	28
79065	2020-06-15 14:12:34	2020-06-15	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	30831	delivery	5	29
79066	2020-06-15 14:12:38	2020-06-15	14	[{"id_menu":2,"count":1}]	31103	delivery	5	19
79067	2020-06-15 14:16:02	2020-06-15	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":3}]	16170	delivery	5	26
79068	2020-06-15 14:17:40	2020-06-15	9	[{"id_menu":7,"count":1}]	31057	pick-up	0	9
79069	2020-06-15 14:20:05	2020-06-15	8	[{"id_menu":5,"count":1}]	19934	delivery	5	13
79070	2020-06-15 14:23:14	2020-06-15	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	6809	delivery	5	34
79071	2020-06-15 14:27:08	2020-06-15	8	[{"id_menu":5,"count":1}]	22995	delivery	5	13
79072	2020-06-15 14:29:42	2020-06-15	9	[{"id_menu":6,"count":1}]	19234	delivery	5	14
79073	2020-06-15 14:34:48	2020-06-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	23992	delivery	5	31
79074	2020-06-15 14:35:41	2020-06-15	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	30937	delivery	5	45
79075	2020-06-15 14:35:57	2020-06-15	9	[{"id_menu":7,"count":1}]	14575	delivery	5	14
79076	2020-06-15 14:36:13	2020-06-15	9	[{"id_menu":7,"count":1}]	30700	delivery	5	14
79077	2020-06-15 14:45:49	2020-06-15	12	[{"id_menu":1,"count":1}]	8609	pick-up	0	12
79078	2020-06-15 14:47:44	2020-06-15	9	[{"id_menu":7,"count":1}]	17861	pick-up	0	9
79079	2020-06-15 14:48:18	2020-06-15	14	[{"id_menu":2,"count":1}]	18048	delivery	5	19
79080	2020-06-15 14:50:33	2020-06-15	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	18840	delivery	5	31
79081	2020-06-15 14:50:50	2020-06-15	12	[{"id_menu":1,"count":1}]	17340	delivery	5	17
79082	2020-06-15 14:51:17	2020-06-15	9	[{"id_menu":6,"count":1}]	31079	delivery	5	14
79083	2020-06-15 14:54:29	2020-06-15	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19661	delivery	5	22
79084	2020-06-15 14:55:52	2020-06-15	12	[{"id_menu":3,"count":1}]	27176	delivery	5	17
79085	2020-06-15 14:57:54	2020-06-15	9	[{"id_menu":7,"count":1}]	8382	delivery	5	14
79086	2020-06-15 15:04:27	2020-06-15	9	[{"id_menu":7,"count":2}]	30948	delivery	5	14
79087	2020-06-15 15:05:06	2020-06-15	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27130	delivery	5	22
79088	2020-06-15 15:07:34	2020-06-15	9	[{"id_menu":7,"count":1}]	1834	pick-up	0	9
79089	2020-06-15 15:10:44	2020-06-15	12	[{"id_menu":1,"count":1}]	24752	pick-up	0	12
79090	2020-06-15 15:18:46	2020-06-15	8	[{"id_menu":5,"count":1}]	31048	delivery	5	13
79091	2020-06-15 15:19:20	2020-06-15	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	15416	delivery	5	36
79092	2020-06-15 15:26:01	2020-06-15	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	28795	delivery	5	31
79093	2020-06-15 15:47:04	2020-06-15	8	[{"id_menu":5,"count":1}]	12889	pick-up	0	8
79094	2020-06-15 15:51:15	2020-06-15	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	28315	delivery	5	40
79095	2020-06-15 15:54:19	2020-06-15	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	20385	delivery	5	26
79096	2020-06-15 15:54:41	2020-06-15	12	[{"id_menu":1,"count":1}]	28808	delivery	5	17
79097	2020-06-15 15:57:04	2020-06-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	31047	delivery	5	28
79098	2020-06-15 15:58:47	2020-06-15	12	[{"id_menu":1,"count":1}]	31076	pick-up	0	12
79099	2020-06-15 16:00:31	2020-06-15	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12170	delivery	5	36
79100	2020-06-15 16:03:00	2020-06-15	8	[{"id_menu":5,"count":1}]	31061	delivery	5	13
79101	2020-06-15 16:05:54	2020-06-15	12	[{"id_menu":3,"count":1}]	5240	pick-up	0	12
79102	2020-06-15 16:13:52	2020-06-15	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	17634	delivery	5	27
79103	2020-06-15 16:16:26	2020-06-15	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	31065	delivery	5	27
79104	2020-06-15 16:28:12	2020-06-15	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	16826	delivery	5	43
79105	2020-06-15 16:28:53	2020-06-15	17	[{"id_menu":4,"count":1}]	31089	delivery	5	22
79106	2020-06-15 16:31:20	2020-06-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	21196	delivery	5	28
79107	2020-06-15 16:34:27	2020-06-15	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	31000	delivery	5	57
79108	2020-06-15 16:38:20	2020-06-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	30938	delivery	5	31
79109	2020-06-15 16:39:25	2020-06-15	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	31010	delivery	5	40
79110	2020-06-15 16:40:30	2020-06-15	9	[{"id_menu":6,"count":1}]	2951	delivery	5	14
79111	2020-06-15 16:47:28	2020-06-15	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	31005	delivery	5	40
79112	2020-06-15 16:50:30	2020-06-15	17	[{"id_menu":4,"count":1}]	30988	delivery	5	22
79113	2020-06-15 16:56:17	2020-06-15	17	[{"id_menu":4,"count":1}]	21077	delivery	5	22
79114	2020-06-15 17:07:29	2020-06-15	9	[{"id_menu":7,"count":1}]	31006	pick-up	0	9
79115	2020-06-15 17:14:26	2020-06-15	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	10071	delivery	5	34
79116	2020-06-15 17:18:27	2020-06-15	9	[{"id_menu":6,"count":1}]	30981	delivery	5	14
79117	2020-06-15 17:27:57	2020-06-15	8	[{"id_menu":5,"count":1}]	30976	pick-up	0	8
79118	2020-06-15 17:31:07	2020-06-15	12	[{"id_menu":3,"count":1}]	1630	pick-up	0	12
79119	2020-06-15 17:34:28	2020-06-15	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	4673	delivery	5	31
79120	2020-06-15 17:36:42	2020-06-15	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	30960	delivery	5	26
79121	2020-06-15 17:38:24	2020-06-15	9	[{"id_menu":7,"count":1}]	31100	delivery	5	14
79122	2020-06-15 17:43:51	2020-06-15	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	31018	delivery	5	51
79123	2020-06-15 17:44:17	2020-06-15	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	30997	delivery	5	22
79124	2020-06-15 17:44:30	2020-06-15	9	[{"id_menu":6,"count":1}]	27183	delivery	5	14
79125	2020-06-15 17:44:37	2020-06-15	9	[{"id_menu":6,"count":1}]	10915	delivery	5	14
79126	2020-06-15 17:47:15	2020-06-15	9	[{"id_menu":6,"count":1}]	26296	delivery	5	14
79127	2020-06-15 17:52:26	2020-06-15	14	[{"id_menu":2,"count":2}]	31026	delivery	5	19
79128	2020-06-15 17:56:13	2020-06-15	12	[{"id_menu":3,"count":1}]	30969	delivery	5	17
79129	2020-06-15 17:58:19	2020-06-15	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24510	delivery	5	31
79130	2020-06-15 17:58:39	2020-06-15	8	[{"id_menu":5,"count":1}]	1331	delivery	5	13
79131	2020-06-15 18:04:51	2020-06-15	12	[{"id_menu":3,"count":1}]	106	pick-up	0	12
79132	2020-06-15 18:06:22	2020-06-15	9	[{"id_menu":7,"count":1}]	15504	delivery	5	14
79133	2020-06-15 18:08:19	2020-06-15	12	[{"id_menu":3,"count":1}]	11862	delivery	5	17
79134	2020-06-15 18:09:47	2020-06-15	12	[{"id_menu":1,"count":1}]	17377	pick-up	0	12
79135	2020-06-15 18:16:34	2020-06-15	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	22288	delivery	5	31
79136	2020-06-15 18:17:58	2020-06-15	9	[{"id_menu":6,"count":1}]	3380	pick-up	0	9
79137	2020-06-15 18:18:52	2020-06-15	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	23696	pick-up	0	26
79138	2020-06-15 18:23:02	2020-06-15	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5543	pick-up	0	26
79139	2020-06-15 18:23:57	2020-06-15	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":2}]	11932	delivery	5	26
79140	2020-06-15 18:29:56	2020-06-15	12	[{"id_menu":3,"count":1}]	2244	pick-up	0	12
79141	2020-06-15 18:32:35	2020-06-15	9	[{"id_menu":6,"count":1}]	31016	delivery	5	14
79142	2020-06-15 18:36:54	2020-06-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	26222	delivery	5	31
79143	2020-06-15 18:50:19	2020-06-15	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	30936	delivery	5	26
79144	2020-06-15 19:03:10	2020-06-15	8	[{"id_menu":5,"count":1}]	23285	delivery	5	13
79145	2020-06-15 19:03:25	2020-06-15	8	[{"id_menu":5,"count":2}]	16794	pick-up	0	8
79146	2020-06-15 19:06:25	2020-06-15	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	31014	delivery	5	36
79147	2020-06-15 19:09:59	2020-06-15	9	[{"id_menu":7,"count":1}]	6787	delivery	5	14
79148	2020-06-15 19:11:19	2020-06-15	17	[{"id_menu":4,"count":1}]	23398	delivery	5	22
79149	2020-06-15 19:11:43	2020-06-15	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	31053	delivery	5	31
79150	2020-06-15 19:15:14	2020-06-15	12	[{"id_menu":3,"count":1}]	19222	delivery	5	17
79151	2020-06-15 19:17:15	2020-06-15	9	[{"id_menu":6,"count":1}]	31066	pick-up	0	9
79152	2020-06-15 19:20:12	2020-06-15	8	[{"id_menu":5,"count":1}]	31096	delivery	5	13
79153	2020-06-15 19:22:24	2020-06-15	14	[{"id_menu":2,"count":1}]	22836	delivery	5	19
79154	2020-06-15 19:23:58	2020-06-15	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5014	pick-up	0	38
79155	2020-06-15 19:43:16	2020-06-15	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	30350	delivery	5	26
79156	2020-06-15 19:50:55	2020-06-15	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	5041	pick-up	0	25
79157	2020-06-15 19:53:47	2020-06-15	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	24332	delivery	5	27
79158	2020-06-15 20:10:23	2020-06-15	14	[{"id_menu":2,"count":1}]	31040	delivery	5	19
79159	2020-06-15 20:13:32	2020-06-15	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	31062	delivery	5	26
79160	2020-06-15 20:19:57	2020-06-15	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	4020	pick-up	0	17
79161	2020-06-15 20:24:06	2020-06-15	9	[{"id_menu":7,"count":1}]	11887	delivery	5	14
79162	2020-06-15 20:26:46	2020-06-15	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2662	pick-up	0	26
79163	2020-06-15 20:27:51	2020-06-15	9	[{"id_menu":6,"count":1}]	26971	delivery	5	14
79164	2020-06-15 20:36:31	2020-06-15	9	[{"id_menu":7,"count":1}]	30986	delivery	5	14
79165	2020-06-15 20:41:38	2020-06-15	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	24423	delivery	5	27
79166	2020-06-15 20:42:58	2020-06-15	17	[{"id_menu":4,"count":1}]	30942	delivery	5	22
79167	2020-06-15 20:53:02	2020-06-15	9	[{"id_menu":7,"count":1}]	31075	delivery	5	14
79168	2020-06-15 20:56:32	2020-06-15	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8597	delivery	5	40
79169	2020-06-15 20:58:24	2020-06-15	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	30975	delivery	5	39
79170	2020-06-15 21:06:41	2020-06-15	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5161	delivery	5	39
79171	2020-06-15 21:11:49	2020-06-15	17	[{"id_menu":4,"count":1}]	23030	delivery	5	22
79172	2020-06-15 21:18:41	2020-06-15	12	[{"id_menu":3,"count":1}]	3288	pick-up	0	12
79173	2020-06-15 21:21:54	2020-06-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	18044	delivery	5	23
79174	2020-06-15 21:23:02	2020-06-15	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	31059	delivery	5	23
79175	2020-06-15 21:26:06	2020-06-15	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	19673	delivery	5	35
79176	2020-06-15 21:29:00	2020-06-15	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	21447	delivery	5	27
79177	2020-06-15 21:30:12	2020-06-15	12	[{"id_menu":1,"count":1}]	4190	delivery	5	17
79178	2020-06-15 21:32:40	2020-06-15	14	[{"id_menu":2,"count":1}]	10448	delivery	5	19
79179	2020-06-15 21:43:02	2020-06-15	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	31011	pick-up	0	25
79180	2020-06-15 22:05:29	2020-06-15	14	[{"id_menu":2,"count":1}]	17590	delivery	5	19
79181	2020-06-15 22:07:42	2020-06-15	17	[{"id_menu":4,"count":1}]	28827	delivery	5	22
79182	2020-06-15 22:10:21	2020-06-15	17	[{"id_menu":4,"count":1}]	30956	delivery	5	22
79183	2020-06-15 22:12:27	2020-06-15	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	755	pick-up	0	31
79184	2020-06-15 22:17:28	2020-06-15	9	[{"id_menu":7,"count":1}]	29749	delivery	5	14
79185	2020-06-15 22:20:18	2020-06-15	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	23988	delivery	5	31
79186	2020-06-15 22:21:50	2020-06-15	9	[{"id_menu":6,"count":1}]	5811	delivery	5	14
79187	2020-06-15 22:24:40	2020-06-15	17	[{"id_menu":4,"count":1}]	31052	delivery	5	22
79188	2020-06-15 22:26:45	2020-06-15	14	[{"id_menu":2,"count":1}]	15309	pick-up	0	14
79189	2020-06-15 22:26:52	2020-06-15	9	[{"id_menu":6,"count":1}]	14643	delivery	5	14
79190	2020-06-15 22:30:05	2020-06-15	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	17008	delivery	5	26
79191	2020-06-15 22:45:34	2020-06-15	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1557	pick-up	0	22
79192	2020-06-15 22:45:59	2020-06-15	9	[{"id_menu":7,"count":1}]	22311	delivery	5	14
79193	2020-06-15 22:50:57	2020-06-15	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4348	delivery	5	22
79194	2020-06-15 23:09:50	2020-06-15	17	[{"id_menu":4,"count":1}]	4453	pick-up	0	17
79195	2020-06-15 23:11:06	2020-06-15	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	30179	delivery	5	31
79196	2020-06-15 23:11:57	2020-06-15	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28087	delivery	5	22
79197	2020-06-15 23:19:59	2020-06-15	17	[{"id_menu":4,"count":1}]	30750	pick-up	0	17
79198	2020-06-15 23:25:03	2020-06-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	30940	delivery	5	23
79199	2020-06-15 23:25:37	2020-06-15	12	[{"id_menu":1,"count":1}]	8176	delivery	5	17
79200	2020-06-15 23:28:22	2020-06-15	12	[{"id_menu":3,"count":1}]	31017	pick-up	0	12
79201	2020-06-15 23:35:53	2020-06-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8282	pick-up	0	18
79202	2020-06-15 23:38:53	2020-06-15	9	[{"id_menu":7,"count":1}]	31105	delivery	5	14
79203	2020-06-15 23:44:51	2020-06-15	12	[{"id_menu":1,"count":1}]	3600	pick-up	0	12
79204	2020-06-15 23:52:05	2020-06-15	8	[{"id_menu":5,"count":1}]	31077	pick-up	0	8
79205	2020-06-15 23:54:20	2020-06-15	14	[{"id_menu":2,"count":1}]	12103	delivery	5	19
79206	2020-06-15 23:54:28	2020-06-15	14	[{"id_menu":2,"count":1}]	22784	delivery	5	19
79207	2020-06-15 23:57:07	2020-06-15	12	[{"id_menu":1,"count":1}]	23049	delivery	5	17
79208	2020-06-16 00:00:52	2020-06-16	17	[{"id_menu":4,"count":1}]	17602	delivery	5	22
79209	2020-06-16 00:04:19	2020-06-16	12	[{"id_menu":3,"count":1}]	31179	delivery	5	17
79210	2020-06-16 00:07:36	2020-06-16	9	[{"id_menu":7,"count":3}]	23457	delivery	5	14
79211	2020-06-16 00:11:22	2020-06-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7931	pick-up	0	18
79212	2020-06-16 00:19:42	2020-06-16	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21008	delivery	5	39
79213	2020-06-16 00:22:35	2020-06-16	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	31212	delivery	5	43
79214	2020-06-16 00:25:56	2020-06-16	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	5138	delivery	5	29
79215	2020-06-16 00:28:39	2020-06-16	14	[{"id_menu":2,"count":1}]	11779	pick-up	0	14
79216	2020-06-16 00:34:49	2020-06-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	31202	pick-up	0	21
79217	2020-06-16 00:35:17	2020-06-16	8	[{"id_menu":5,"count":1}]	2735	pick-up	0	8
79218	2020-06-16 00:37:05	2020-06-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13617	delivery	5	22
79219	2020-06-16 00:38:43	2020-06-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8380	delivery	5	28
79220	2020-06-16 00:42:33	2020-06-16	9	[{"id_menu":6,"count":1}]	25236	pick-up	0	9
79221	2020-06-16 00:43:35	2020-06-16	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8303	pick-up	0	25
79222	2020-06-16 00:44:08	2020-06-16	9	[{"id_menu":7,"count":1}]	8061	delivery	5	14
79223	2020-06-16 00:44:17	2020-06-16	17	[{"id_menu":4,"count":1}]	24725	pick-up	0	17
79224	2020-06-16 00:44:49	2020-06-16	17	[{"id_menu":4,"count":1}]	31251	delivery	5	22
79225	2020-06-16 00:53:48	2020-06-16	9	[{"id_menu":6,"count":1}]	26586	delivery	5	14
79226	2020-06-16 01:04:51	2020-06-16	9	[{"id_menu":6,"count":1}]	31124	pick-up	0	9
79227	2020-06-16 01:05:09	2020-06-16	9	[{"id_menu":6,"count":1}]	28929	pick-up	0	9
79228	2020-06-16 01:07:54	2020-06-16	8	[{"id_menu":5,"count":1}]	31171	delivery	5	13
79229	2020-06-16 01:08:58	2020-06-16	14	[{"id_menu":2,"count":2}]	18830	delivery	5	19
79230	2020-06-16 01:10:01	2020-06-16	12	[{"id_menu":1,"count":1}]	30241	delivery	5	17
79231	2020-06-16 01:11:07	2020-06-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	10234	delivery	5	28
79232	2020-06-16 01:16:23	2020-06-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	13092	pick-up	0	23
79233	2020-06-16 01:22:27	2020-06-16	8	[{"id_menu":5,"count":1}]	28659	delivery	5	13
79234	2020-06-16 01:24:41	2020-06-16	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	21779	delivery	5	27
79235	2020-06-16 01:27:50	2020-06-16	17	[{"id_menu":4,"count":1}]	31225	pick-up	0	17
79236	2020-06-16 01:35:42	2020-06-16	9	[{"id_menu":6,"count":1}]	22307	delivery	5	14
79237	2020-06-16 01:40:32	2020-06-16	14	[{"id_menu":2,"count":1}]	12150	pick-up	0	14
79238	2020-06-16 01:43:40	2020-06-16	12	[{"id_menu":3,"count":2}]	28959	delivery	5	17
79239	2020-06-16 01:46:14	2020-06-16	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8068	pick-up	0	34
79240	2020-06-16 01:46:48	2020-06-16	9	[{"id_menu":6,"count":1}]	2504	pick-up	0	9
79241	2020-06-16 01:49:01	2020-06-16	14	[{"id_menu":2,"count":1}]	24409	delivery	5	19
79242	2020-06-16 01:50:04	2020-06-16	9	[{"id_menu":6,"count":1}]	12147	delivery	5	14
79243	2020-06-16 01:50:30	2020-06-16	9	[{"id_menu":6,"count":2}]	16342	pick-up	0	9
79244	2020-06-16 02:00:25	2020-06-16	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	10928	pick-up	0	21
79245	2020-06-16 02:02:57	2020-06-16	8	[{"id_menu":5,"count":1}]	3380	pick-up	0	8
79246	2020-06-16 02:03:34	2020-06-16	9	[{"id_menu":6,"count":1}]	15901	delivery	5	14
79247	2020-06-16 02:04:33	2020-06-16	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	31149	delivery	5	40
79248	2020-06-16 02:04:34	2020-06-16	14	[{"id_menu":2,"count":1}]	107	pick-up	0	14
79249	2020-06-16 02:10:39	2020-06-16	8	[{"id_menu":5,"count":1}]	9152	delivery	5	13
79250	2020-06-16 02:11:22	2020-06-16	12	[{"id_menu":3,"count":1}]	7361	pick-up	0	12
79251	2020-06-16 02:13:39	2020-06-16	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9729	delivery	5	45
79252	2020-06-16 02:16:23	2020-06-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	31244	delivery	5	26
79253	2020-06-16 02:22:21	2020-06-16	12	[{"id_menu":1,"count":1}]	17478	pick-up	0	12
79254	2020-06-16 02:23:58	2020-06-16	8	[{"id_menu":5,"count":2}]	31203	delivery	5	13
79255	2020-06-16 02:24:14	2020-06-16	12	[{"id_menu":1,"count":1}]	21912	delivery	5	17
79256	2020-06-16 02:25:14	2020-06-16	8	[{"id_menu":5,"count":1}]	21562	delivery	5	13
79257	2020-06-16 02:25:36	2020-06-16	9	[{"id_menu":6,"count":1}]	1115	delivery	5	14
79258	2020-06-16 02:43:16	2020-06-16	9	[{"id_menu":6,"count":1}]	3426	delivery	5	14
79259	2020-06-16 02:53:06	2020-06-16	17	[{"id_menu":4,"count":1}]	2007	pick-up	0	17
79260	2020-06-16 02:53:36	2020-06-16	14	[{"id_menu":2,"count":1}]	26037	delivery	5	19
79261	2020-06-16 02:56:15	2020-06-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	27274	delivery	5	28
79262	2020-06-16 03:02:03	2020-06-16	17	[{"id_menu":4,"count":1}]	1439	pick-up	0	17
79263	2020-06-16 03:02:37	2020-06-16	17	[{"id_menu":4,"count":1}]	31146	delivery	5	22
79264	2020-06-16 03:07:17	2020-06-16	9	[{"id_menu":6,"count":1}]	2820	pick-up	0	9
79265	2020-06-16 03:08:54	2020-06-16	17	[{"id_menu":4,"count":2}]	17799	delivery	5	22
79266	2020-06-16 03:24:00	2020-06-16	14	[{"id_menu":2,"count":1}]	18154	delivery	5	19
79267	2020-06-16 03:28:23	2020-06-16	9	[{"id_menu":7,"count":1}]	20558	delivery	5	14
79268	2020-06-16 03:35:14	2020-06-16	9	[{"id_menu":6,"count":1}]	12397	delivery	5	14
79269	2020-06-16 03:35:35	2020-06-16	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	24959	delivery	5	26
79270	2020-06-16 03:35:58	2020-06-16	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	6965	pick-up	0	32
79271	2020-06-16 03:36:57	2020-06-16	12	[{"id_menu":3,"count":1}]	31183	delivery	5	17
79272	2020-06-16 03:37:36	2020-06-16	12	[{"id_menu":3,"count":1}]	13873	delivery	5	17
79273	2020-06-16 03:39:42	2020-06-16	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31239	delivery	5	35
79274	2020-06-16 03:45:32	2020-06-16	12	[{"id_menu":3,"count":1}]	1528	delivery	5	17
79275	2020-06-16 03:46:45	2020-06-16	9	[{"id_menu":6,"count":1}]	7706	delivery	5	14
79276	2020-06-16 03:49:29	2020-06-16	17	[{"id_menu":4,"count":1}]	20592	delivery	5	22
79277	2020-06-16 03:49:59	2020-06-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	24837	delivery	5	31
79278	2020-06-16 04:00:16	2020-06-16	9	[{"id_menu":7,"count":1}]	31151	delivery	5	14
79279	2020-06-16 04:03:25	2020-06-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31252	delivery	5	23
79280	2020-06-16 04:12:35	2020-06-16	17	[{"id_menu":4,"count":1}]	9862	pick-up	0	17
79281	2020-06-16 04:16:08	2020-06-16	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	31285	delivery	5	39
79282	2020-06-16 04:19:22	2020-06-16	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6037	pick-up	0	34
79283	2020-06-16 04:24:24	2020-06-16	8	[{"id_menu":5,"count":1}]	31182	delivery	5	13
79284	2020-06-16 04:32:13	2020-06-16	9	[{"id_menu":7,"count":1}]	31255	pick-up	0	9
79285	2020-06-16 04:33:06	2020-06-16	14	[{"id_menu":2,"count":1}]	12086	delivery	5	19
79286	2020-06-16 04:33:35	2020-06-16	12	[{"id_menu":1,"count":1}]	12934	delivery	5	17
79287	2020-06-16 04:34:46	2020-06-16	9	[{"id_menu":7,"count":2}]	1227	delivery	5	14
79288	2020-06-16 04:35:23	2020-06-16	12	[{"id_menu":1,"count":1}]	19554	pick-up	0	12
79289	2020-06-16 04:37:25	2020-06-16	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	12608	delivery	5	37
79290	2020-06-16 04:37:44	2020-06-16	9	[{"id_menu":6,"count":1}]	924	pick-up	0	9
79291	2020-06-16 04:43:28	2020-06-16	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	31241	delivery	5	27
79292	2020-06-16 04:46:50	2020-06-16	17	[{"id_menu":4,"count":1}]	31242	delivery	5	22
79293	2020-06-16 04:53:00	2020-06-16	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	31112	delivery	5	39
79294	2020-06-16 04:54:33	2020-06-16	12	[{"id_menu":3,"count":3}]	15935	delivery	5	17
79295	2020-06-16 04:57:38	2020-06-16	12	[{"id_menu":1,"count":1}]	23381	delivery	5	17
79296	2020-06-16 04:58:43	2020-06-16	17	[{"id_menu":4,"count":1}]	23760	pick-up	0	17
79297	2020-06-16 05:00:29	2020-06-16	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	13081	delivery	5	27
79298	2020-06-16 05:06:26	2020-06-16	8	[{"id_menu":5,"count":1}]	5565	delivery	5	13
79299	2020-06-16 05:06:42	2020-06-16	17	[{"id_menu":4,"count":1}]	24295	delivery	5	22
79300	2020-06-16 05:08:35	2020-06-16	9	[{"id_menu":7,"count":1}]	29042	pick-up	0	9
79301	2020-06-16 05:08:40	2020-06-16	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	31128	delivery	5	43
79302	2020-06-16 05:09:39	2020-06-16	9	[{"id_menu":6,"count":1}]	31181	delivery	5	14
79303	2020-06-16 05:30:31	2020-06-16	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	31267	pick-up	0	20
79304	2020-06-16 05:41:40	2020-06-16	9	[{"id_menu":7,"count":1}]	31238	pick-up	0	9
79305	2020-06-16 05:44:26	2020-06-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17005	delivery	5	31
79306	2020-06-16 05:51:55	2020-06-16	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	27247	delivery	5	22
79307	2020-06-16 05:52:58	2020-06-16	9	[{"id_menu":7,"count":1}]	6039	pick-up	0	9
79308	2020-06-16 05:53:19	2020-06-16	9	[{"id_menu":7,"count":1}]	8949	delivery	5	14
79309	2020-06-16 05:55:53	2020-06-16	17	[{"id_menu":4,"count":1}]	31130	pick-up	0	17
79310	2020-06-16 06:00:07	2020-06-16	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	7595	delivery	5	26
79311	2020-06-16 06:00:07	2020-06-16	17	[{"id_menu":4,"count":2}]	31257	delivery	5	22
79312	2020-06-16 06:07:39	2020-06-16	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31154	delivery	5	43
79313	2020-06-16 06:08:36	2020-06-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15026	pick-up	0	26
79314	2020-06-16 06:12:22	2020-06-16	8	[{"id_menu":5,"count":1}]	10033	delivery	5	13
79315	2020-06-16 06:15:33	2020-06-16	17	[{"id_menu":4,"count":1}]	18519	delivery	5	22
79316	2020-06-16 06:22:17	2020-06-16	9	[{"id_menu":6,"count":1}]	11554	pick-up	0	9
79317	2020-06-16 06:29:54	2020-06-16	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	11560	delivery	5	26
79318	2020-06-16 06:33:37	2020-06-16	12	[{"id_menu":3,"count":1}]	2140	pick-up	0	12
79319	2020-06-16 06:36:41	2020-06-16	9	[{"id_menu":6,"count":1}]	10335	delivery	5	14
79320	2020-06-16 06:40:52	2020-06-16	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	31246	delivery	5	23
79321	2020-06-16 06:45:29	2020-06-16	8	[{"id_menu":5,"count":1}]	31156	delivery	5	13
79322	2020-06-16 06:46:23	2020-06-16	9	[{"id_menu":6,"count":1}]	31280	delivery	5	14
79323	2020-06-16 06:49:03	2020-06-16	14	[{"id_menu":2,"count":1}]	30623	pick-up	0	14
79324	2020-06-16 06:52:30	2020-06-16	12	[{"id_menu":3,"count":1}]	20069	delivery	5	17
79325	2020-06-16 06:53:22	2020-06-16	8	[{"id_menu":5,"count":1}]	197	delivery	5	13
79326	2020-06-16 07:01:52	2020-06-16	14	[{"id_menu":2,"count":1}]	6091	pick-up	0	14
79327	2020-06-16 07:02:20	2020-06-16	12	[{"id_menu":3,"count":1}]	22427	pick-up	0	12
79328	2020-06-16 07:07:12	2020-06-16	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	24767	delivery	5	45
79329	2020-06-16 07:09:32	2020-06-16	17	[{"id_menu":4,"count":1}]	29124	delivery	5	22
79330	2020-06-16 07:14:20	2020-06-16	8	[{"id_menu":5,"count":1}]	24122	pick-up	0	8
79331	2020-06-16 07:17:24	2020-06-16	12	[{"id_menu":3,"count":1}]	24615	delivery	5	17
79332	2020-06-16 07:21:57	2020-06-16	9	[{"id_menu":6,"count":2}]	11046	delivery	5	14
79333	2020-06-16 07:23:59	2020-06-16	9	[{"id_menu":7,"count":1}]	18580	delivery	5	14
79334	2020-06-16 07:27:31	2020-06-16	12	[{"id_menu":1,"count":1}]	2641	pick-up	0	12
79335	2020-06-16 07:30:00	2020-06-16	14	[{"id_menu":2,"count":1}]	26773	delivery	5	19
79336	2020-06-16 07:30:49	2020-06-16	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	19741	delivery	5	27
79337	2020-06-16 07:31:31	2020-06-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	18429	delivery	5	22
79338	2020-06-16 07:37:50	2020-06-16	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11246	pick-up	0	44
79339	2020-06-16 07:45:15	2020-06-16	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	14867	delivery	5	26
79340	2020-06-16 07:46:07	2020-06-16	17	[{"id_menu":4,"count":1}]	31150	delivery	5	22
79341	2020-06-16 07:48:17	2020-06-16	9	[{"id_menu":6,"count":1}]	25710	delivery	5	14
79342	2020-06-16 07:50:50	2020-06-16	8	[{"id_menu":5,"count":1}]	26085	delivery	5	13
79343	2020-06-16 07:51:43	2020-06-16	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	11159	delivery	5	22
79344	2020-06-16 07:54:43	2020-06-16	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9296	delivery	5	39
79345	2020-06-16 08:06:30	2020-06-16	14	[{"id_menu":2,"count":1}]	17245	pick-up	0	14
79346	2020-06-16 08:07:12	2020-06-16	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	31263	pick-up	0	40
79347	2020-06-16 08:09:08	2020-06-16	8	[{"id_menu":5,"count":1}]	31281	delivery	5	13
79348	2020-06-16 08:15:19	2020-06-16	8	[{"id_menu":5,"count":1}]	27662	delivery	5	13
79349	2020-06-16 08:23:31	2020-06-16	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1992	delivery	5	22
79350	2020-06-16 08:23:55	2020-06-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	31141	delivery	5	28
79351	2020-06-16 08:29:20	2020-06-16	17	[{"id_menu":4,"count":1}]	1672	pick-up	0	17
79352	2020-06-16 08:33:11	2020-06-16	9	[{"id_menu":7,"count":1}]	31222	delivery	5	14
79353	2020-06-16 08:36:14	2020-06-16	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	31173	pick-up	0	35
79354	2020-06-16 08:36:44	2020-06-16	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13116	delivery	5	39
79355	2020-06-16 08:39:07	2020-06-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11466	delivery	5	31
79356	2020-06-16 08:50:40	2020-06-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27978	delivery	5	23
79357	2020-06-16 08:51:43	2020-06-16	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	23069	delivery	5	46
79358	2020-06-16 08:52:04	2020-06-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	18020	delivery	5	31
79359	2020-06-16 08:55:08	2020-06-16	14	[{"id_menu":2,"count":1}]	1142	delivery	5	19
79360	2020-06-16 08:58:39	2020-06-16	17	[{"id_menu":4,"count":1}]	29848	delivery	5	22
79361	2020-06-16 08:59:27	2020-06-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	31184	delivery	5	31
79362	2020-06-16 08:59:35	2020-06-16	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31270	delivery	5	40
79363	2020-06-16 09:00:02	2020-06-16	9	[{"id_menu":7,"count":1}]	24612	delivery	5	14
79364	2020-06-16 09:00:34	2020-06-16	12	[{"id_menu":1,"count":1}]	31174	delivery	5	17
79365	2020-06-16 09:01:55	2020-06-16	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	22722	delivery	5	34
79366	2020-06-16 09:03:07	2020-06-16	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	8858	delivery	5	34
79367	2020-06-16 09:05:14	2020-06-16	8	[{"id_menu":5,"count":1}]	26562	delivery	5	13
79368	2020-06-16 09:10:41	2020-06-16	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	12819	delivery	5	34
79369	2020-06-16 09:16:35	2020-06-16	12	[{"id_menu":1,"count":1}]	6469	delivery	5	17
79370	2020-06-16 09:25:49	2020-06-16	17	[{"id_menu":4,"count":1}]	3024	pick-up	0	17
79371	2020-06-16 09:29:00	2020-06-16	12	[{"id_menu":1,"count":1}]	26896	delivery	5	17
79372	2020-06-16 09:34:29	2020-06-16	17	[{"id_menu":4,"count":1}]	31129	pick-up	0	17
79373	2020-06-16 09:36:03	2020-06-16	9	[{"id_menu":6,"count":1}]	1143	pick-up	0	9
79374	2020-06-16 09:36:58	2020-06-16	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	12484	delivery	5	31
79375	2020-06-16 09:40:05	2020-06-16	14	[{"id_menu":2,"count":1}]	31237	delivery	5	19
79376	2020-06-16 09:40:29	2020-06-16	9	[{"id_menu":7,"count":1}]	4546	pick-up	0	9
79377	2020-06-16 09:50:31	2020-06-16	12	[{"id_menu":3,"count":1}]	6543	pick-up	0	12
79378	2020-06-16 09:51:48	2020-06-16	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	31172	delivery	5	39
79379	2020-06-16 09:55:21	2020-06-16	8	[{"id_menu":5,"count":1}]	31256	delivery	5	13
79380	2020-06-16 09:56:41	2020-06-16	14	[{"id_menu":2,"count":1}]	14513	delivery	5	19
79381	2020-06-16 10:01:24	2020-06-16	9	[{"id_menu":7,"count":1}]	13110	delivery	5	14
79382	2020-06-16 10:04:49	2020-06-16	17	[{"id_menu":4,"count":1}]	22875	pick-up	0	17
79383	2020-06-16 10:06:50	2020-06-16	9	[{"id_menu":6,"count":1}]	28230	delivery	5	14
79384	2020-06-16 10:09:23	2020-06-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31115	delivery	5	23
79385	2020-06-16 10:09:33	2020-06-16	12	[{"id_menu":3,"count":2}]	8657	pick-up	0	12
79386	2020-06-16 10:17:39	2020-06-16	14	[{"id_menu":2,"count":1}]	31140	delivery	5	19
79387	2020-06-16 10:21:27	2020-06-16	14	[{"id_menu":2,"count":1}]	10912	pick-up	0	14
79388	2020-06-16 10:25:54	2020-06-16	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	31188	delivery	5	34
79389	2020-06-16 10:25:54	2020-06-16	12	[{"id_menu":3,"count":2}]	1922	pick-up	0	12
79390	2020-06-16 10:27:04	2020-06-16	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8814	delivery	5	39
79391	2020-06-16 10:28:56	2020-06-16	17	[{"id_menu":4,"count":1}]	2551	pick-up	0	17
79392	2020-06-16 10:35:15	2020-06-16	8	[{"id_menu":5,"count":1}]	31254	delivery	5	13
79393	2020-06-16 10:39:35	2020-06-16	9	[{"id_menu":7,"count":1}]	7333	delivery	5	14
79394	2020-06-16 10:43:26	2020-06-16	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	31198	delivery	5	31
79395	2020-06-16 10:45:57	2020-06-16	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31258	delivery	5	22
79396	2020-06-16 10:49:51	2020-06-16	14	[{"id_menu":2,"count":1}]	31126	delivery	5	19
79397	2020-06-16 10:51:11	2020-06-16	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	7247	pick-up	0	29
79398	2020-06-16 10:55:11	2020-06-16	8	[{"id_menu":5,"count":1}]	17041	pick-up	0	8
79399	2020-06-16 10:56:48	2020-06-16	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1674	delivery	5	44
79400	2020-06-16 10:56:54	2020-06-16	14	[{"id_menu":2,"count":1}]	2938	delivery	5	19
79401	2020-06-16 10:58:48	2020-06-16	12	[{"id_menu":1,"count":1}]	16486	delivery	5	17
79402	2020-06-16 11:02:10	2020-06-16	9	[{"id_menu":6,"count":1}]	31136	delivery	5	14
79403	2020-06-16 11:06:24	2020-06-16	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16362	pick-up	0	50
79404	2020-06-16 11:10:59	2020-06-16	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	31125	delivery	5	43
79405	2020-06-16 11:11:06	2020-06-16	9	[{"id_menu":7,"count":1}]	13637	delivery	5	14
79406	2020-06-16 11:11:25	2020-06-16	12	[{"id_menu":1,"count":1}]	5924	delivery	5	17
79407	2020-06-16 11:13:11	2020-06-16	17	[{"id_menu":4,"count":1}]	17547	delivery	5	22
79408	2020-06-16 11:14:06	2020-06-16	9	[{"id_menu":7,"count":1}]	5180	pick-up	0	9
79409	2020-06-16 11:26:55	2020-06-16	12	[{"id_menu":1,"count":1}]	7516	delivery	5	17
79410	2020-06-16 11:27:06	2020-06-16	14	[{"id_menu":2,"count":1}]	22623	pick-up	0	14
79411	2020-06-16 11:28:34	2020-06-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	31206	delivery	5	26
79412	2020-06-16 11:36:30	2020-06-16	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	31201	delivery	5	26
79413	2020-06-16 11:40:00	2020-06-16	29	[{"id_menu":3,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6828	delivery	5	34
79414	2020-06-16 11:42:37	2020-06-16	8	[{"id_menu":5,"count":1}]	15693	delivery	5	13
79415	2020-06-16 11:44:46	2020-06-16	9	[{"id_menu":6,"count":2}]	31226	pick-up	0	9
79416	2020-06-16 11:50:16	2020-06-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	31276	delivery	5	28
79417	2020-06-16 11:51:06	2020-06-16	14	[{"id_menu":2,"count":1}]	31180	delivery	5	19
79418	2020-06-16 11:51:25	2020-06-16	8	[{"id_menu":5,"count":1}]	31215	delivery	5	13
79419	2020-06-16 11:52:57	2020-06-16	8	[{"id_menu":5,"count":1}]	634	pick-up	0	8
79420	2020-06-16 11:55:17	2020-06-16	9	[{"id_menu":6,"count":1}]	29417	delivery	5	14
79421	2020-06-16 11:57:23	2020-06-16	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	13441	delivery	5	23
79422	2020-06-16 12:04:38	2020-06-16	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	26918	delivery	5	48
79423	2020-06-16 12:08:14	2020-06-16	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	4887	delivery	5	29
79424	2020-06-16 12:08:39	2020-06-16	17	[{"id_menu":4,"count":1}]	31157	delivery	5	22
79425	2020-06-16 12:13:41	2020-06-16	12	[{"id_menu":3,"count":1}]	21617	pick-up	0	12
79426	2020-06-16 12:25:39	2020-06-16	17	[{"id_menu":4,"count":2}]	29252	pick-up	0	17
79427	2020-06-16 12:26:18	2020-06-16	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31170	delivery	5	37
79428	2020-06-16 12:27:58	2020-06-16	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	31160	pick-up	0	35
79429	2020-06-16 12:29:51	2020-06-16	12	[{"id_menu":3,"count":1}]	21259	delivery	5	17
79430	2020-06-16 12:31:32	2020-06-16	14	[{"id_menu":2,"count":1}]	8706	pick-up	0	14
79431	2020-06-16 12:34:16	2020-06-16	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	31284	delivery	5	26
79432	2020-06-16 12:35:01	2020-06-16	8	[{"id_menu":5,"count":1}]	10408	delivery	5	13
79433	2020-06-16 12:39:43	2020-06-16	9	[{"id_menu":6,"count":1}]	24639	delivery	5	14
79434	2020-06-16 12:42:03	2020-06-16	12	[{"id_menu":3,"count":1}]	2123	pick-up	0	12
79435	2020-06-16 12:44:33	2020-06-16	17	[{"id_menu":4,"count":1}]	10109	delivery	5	22
79436	2020-06-16 13:00:36	2020-06-16	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	31261	delivery	5	31
79437	2020-06-16 13:07:22	2020-06-16	9	[{"id_menu":7,"count":1}]	10556	delivery	5	14
79438	2020-06-16 13:11:14	2020-06-16	17	[{"id_menu":4,"count":1}]	7675	delivery	5	22
79439	2020-06-16 13:13:14	2020-06-16	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	13722	delivery	5	26
79440	2020-06-16 13:18:04	2020-06-16	12	[{"id_menu":1,"count":1}]	17342	delivery	5	17
79441	2020-06-16 13:19:58	2020-06-16	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	22873	delivery	5	39
79442	2020-06-16 13:20:37	2020-06-16	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	9852	pick-up	0	26
79443	2020-06-16 13:20:40	2020-06-16	9	[{"id_menu":7,"count":1}]	2197	pick-up	0	9
79444	2020-06-16 13:23:10	2020-06-16	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1155	pick-up	0	20
79445	2020-06-16 13:30:24	2020-06-16	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31177	delivery	5	22
79446	2020-06-16 13:32:09	2020-06-16	12	[{"id_menu":3,"count":1}]	21334	delivery	5	17
79447	2020-06-16 13:36:41	2020-06-16	9	[{"id_menu":6,"count":1}]	8528	delivery	5	14
79448	2020-06-16 13:37:08	2020-06-16	12	[{"id_menu":1,"count":1}]	12676	delivery	5	17
79449	2020-06-16 13:38:49	2020-06-16	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	31260	delivery	5	56
79450	2020-06-16 13:42:28	2020-06-16	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	31162	delivery	5	43
79451	2020-06-16 13:45:24	2020-06-16	46	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	15958	delivery	5	51
79452	2020-06-16 13:50:37	2020-06-16	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	31158	delivery	5	45
79453	2020-06-16 13:52:51	2020-06-16	14	[{"id_menu":2,"count":2}]	6645	pick-up	0	14
79454	2020-06-16 13:54:00	2020-06-16	8	[{"id_menu":5,"count":1}]	31210	delivery	5	13
79455	2020-06-16 13:54:01	2020-06-16	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	30783	delivery	5	39
79456	2020-06-16 13:59:13	2020-06-16	12	[{"id_menu":1,"count":1}]	5558	delivery	5	17
79457	2020-06-16 14:01:31	2020-06-16	8	[{"id_menu":5,"count":1}]	2005	delivery	5	13
79458	2020-06-16 14:04:55	2020-06-16	9	[{"id_menu":6,"count":1}]	31248	delivery	5	14
79459	2020-06-16 14:18:24	2020-06-16	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	7971	delivery	5	46
79460	2020-06-16 14:23:09	2020-06-16	8	[{"id_menu":5,"count":1}]	13834	delivery	5	13
79461	2020-06-16 14:26:40	2020-06-16	9	[{"id_menu":6,"count":1}]	26909	delivery	5	14
79462	2020-06-16 14:28:55	2020-06-16	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2804	pick-up	0	31
79463	2020-06-16 14:29:40	2020-06-16	14	[{"id_menu":2,"count":1}]	7565	delivery	5	19
79464	2020-06-16 14:29:54	2020-06-16	17	[{"id_menu":4,"count":1}]	10793	pick-up	0	17
79465	2020-06-16 14:36:30	2020-06-16	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2596	delivery	5	22
79466	2020-06-16 14:37:14	2020-06-16	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6783	delivery	5	43
79467	2020-06-16 14:38:53	2020-06-16	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2008	pick-up	0	29
79468	2020-06-16 14:39:34	2020-06-16	9	[{"id_menu":6,"count":1}]	12271	pick-up	0	9
79469	2020-06-16 14:42:14	2020-06-16	9	[{"id_menu":7,"count":1}]	31278	delivery	5	14
79470	2020-06-16 14:43:05	2020-06-16	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	31165	delivery	5	36
79471	2020-06-16 14:44:38	2020-06-16	8	[{"id_menu":5,"count":1}]	9733	delivery	5	13
79472	2020-06-16 14:48:21	2020-06-16	8	[{"id_menu":5,"count":1}]	3332	pick-up	0	8
79473	2020-06-16 14:52:32	2020-06-16	8	[{"id_menu":5,"count":1}]	31190	pick-up	0	8
79474	2020-06-16 14:53:37	2020-06-16	14	[{"id_menu":2,"count":1}]	26967	delivery	5	19
79475	2020-06-16 14:58:04	2020-06-16	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	964	delivery	5	48
79476	2020-06-16 14:58:41	2020-06-16	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	16328	pick-up	0	29
79477	2020-06-16 15:08:14	2020-06-16	12	[{"id_menu":1,"count":1}]	18271	delivery	5	17
79478	2020-06-16 15:16:48	2020-06-16	9	[{"id_menu":6,"count":1}]	29702	pick-up	0	9
79479	2020-06-16 15:19:09	2020-06-16	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	4228	delivery	5	25
79480	2020-06-16 15:20:44	2020-06-16	9	[{"id_menu":6,"count":1}]	7567	delivery	5	14
79481	2020-06-16 15:23:36	2020-06-16	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	381	delivery	5	25
79482	2020-06-16 15:29:37	2020-06-16	12	[{"id_menu":1,"count":2}]	4161	pick-up	0	12
79483	2020-06-16 15:29:56	2020-06-16	8	[{"id_menu":5,"count":1}]	24766	pick-up	0	8
79484	2020-06-16 15:30:33	2020-06-16	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	21540	delivery	5	39
79485	2020-06-16 15:45:35	2020-06-16	12	[{"id_menu":1,"count":1}]	4997	delivery	5	17
79486	2020-06-16 15:55:13	2020-06-16	14	[{"id_menu":2,"count":1}]	5146	delivery	5	19
79487	2020-06-16 15:57:00	2020-06-16	17	[{"id_menu":4,"count":1}]	13498	delivery	5	22
79488	2020-06-16 15:59:30	2020-06-16	9	[{"id_menu":6,"count":1}]	31230	delivery	5	14
79489	2020-06-16 16:03:37	2020-06-16	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31209	delivery	5	22
79490	2020-06-16 16:04:16	2020-06-16	9	[{"id_menu":7,"count":1}]	31221	delivery	5	14
79491	2020-06-16 16:09:16	2020-06-16	9	[{"id_menu":7,"count":1}]	2660	pick-up	0	9
79492	2020-06-16 16:12:56	2020-06-16	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	31234	delivery	5	34
79493	2020-06-16 16:18:00	2020-06-16	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3579	delivery	5	22
79494	2020-06-16 16:18:48	2020-06-16	17	[{"id_menu":4,"count":1}]	7043	pick-up	0	17
79495	2020-06-16 16:21:47	2020-06-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	6252	delivery	5	31
79496	2020-06-16 16:26:54	2020-06-16	8	[{"id_menu":5,"count":1}]	5004	delivery	5	13
79497	2020-06-16 16:28:46	2020-06-16	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	29226	pick-up	0	26
79498	2020-06-16 16:29:30	2020-06-16	12	[{"id_menu":3,"count":1}]	31122	delivery	5	17
79499	2020-06-16 16:31:51	2020-06-16	9	[{"id_menu":7,"count":1}]	25836	pick-up	0	9
79500	2020-06-16 16:34:18	2020-06-16	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19473	delivery	5	22
79501	2020-06-16 16:34:39	2020-06-16	8	[{"id_menu":5,"count":1}]	20067	delivery	5	13
79502	2020-06-16 16:36:20	2020-06-16	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	31279	delivery	5	31
79503	2020-06-16 16:41:15	2020-06-16	9	[{"id_menu":6,"count":1}]	31204	delivery	5	14
79504	2020-06-16 16:42:53	2020-06-16	9	[{"id_menu":6,"count":1}]	31142	delivery	5	14
79505	2020-06-16 16:51:37	2020-06-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	26241	delivery	5	31
79506	2020-06-16 16:55:53	2020-06-16	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1306	pick-up	0	20
79507	2020-06-16 17:01:24	2020-06-16	9	[{"id_menu":7,"count":1}]	5970	pick-up	0	9
79508	2020-06-16 17:02:58	2020-06-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2064	delivery	5	31
79509	2020-06-16 17:08:30	2020-06-16	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	7086	pick-up	0	38
79510	2020-06-16 17:18:04	2020-06-16	9	[{"id_menu":6,"count":1}]	7306	pick-up	0	9
79511	2020-06-16 17:19:25	2020-06-16	9	[{"id_menu":7,"count":1}]	31147	delivery	5	14
79512	2020-06-16 17:21:21	2020-06-16	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31155	delivery	5	48
79513	2020-06-16 17:24:05	2020-06-16	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	11616	delivery	5	26
79514	2020-06-16 17:26:21	2020-06-16	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	31123	delivery	5	25
79515	2020-06-16 17:30:15	2020-06-16	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	31163	delivery	5	46
79516	2020-06-16 17:30:57	2020-06-16	17	[{"id_menu":4,"count":1}]	2627	pick-up	0	17
79517	2020-06-16 17:34:06	2020-06-16	9	[{"id_menu":6,"count":1}]	31195	delivery	5	14
79518	2020-06-16 17:37:34	2020-06-16	14	[{"id_menu":2,"count":1}]	31153	pick-up	0	14
79519	2020-06-16 17:45:17	2020-06-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	31133	delivery	5	28
79520	2020-06-16 17:48:48	2020-06-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	9562	delivery	5	28
79521	2020-06-16 17:59:23	2020-06-16	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	13855	pick-up	0	26
79522	2020-06-16 18:05:22	2020-06-16	14	[{"id_menu":2,"count":2}]	25894	delivery	5	19
79523	2020-06-16 18:05:46	2020-06-16	9	[{"id_menu":6,"count":2}]	31277	delivery	5	14
79524	2020-06-16 18:08:53	2020-06-16	9	[{"id_menu":6,"count":1}]	5063	pick-up	0	9
79525	2020-06-16 18:14:03	2020-06-16	9	[{"id_menu":7,"count":1}]	31265	delivery	5	14
79526	2020-06-16 18:14:47	2020-06-16	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3980	pick-up	0	31
79527	2020-06-16 18:19:04	2020-06-16	9	[{"id_menu":7,"count":1}]	31220	pick-up	0	9
79528	2020-06-16 18:23:56	2020-06-16	9	[{"id_menu":7,"count":2}]	31197	delivery	5	14
79529	2020-06-16 18:26:21	2020-06-16	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	31159	delivery	5	44
79530	2020-06-16 18:26:55	2020-06-16	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	14854	delivery	5	25
79531	2020-06-16 18:30:00	2020-06-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	31134	pick-up	0	23
79532	2020-06-16 18:32:34	2020-06-16	17	[{"id_menu":4,"count":1}]	27488	delivery	5	22
79533	2020-06-16 18:32:41	2020-06-16	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2630	pick-up	0	21
79534	2020-06-16 18:33:53	2020-06-16	9	[{"id_menu":6,"count":1}]	31166	delivery	5	14
79535	2020-06-16 18:34:39	2020-06-16	17	[{"id_menu":4,"count":1}]	9806	delivery	5	22
79536	2020-06-16 18:41:28	2020-06-16	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	31164	delivery	5	22
79537	2020-06-16 18:42:50	2020-06-16	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19957	pick-up	0	35
79538	2020-06-16 18:43:13	2020-06-16	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15763	delivery	5	49
79539	2020-06-16 18:47:59	2020-06-16	12	[{"id_menu":3,"count":1}]	23813	delivery	5	17
79540	2020-06-16 18:48:12	2020-06-16	12	[{"id_menu":1,"count":1}]	6116	delivery	5	17
79541	2020-06-16 18:59:28	2020-06-16	9	[{"id_menu":6,"count":1}]	11961	delivery	5	14
79542	2020-06-16 19:06:44	2020-06-16	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23590	delivery	5	34
79543	2020-06-16 19:08:24	2020-06-16	14	[{"id_menu":2,"count":1}]	31196	delivery	5	19
79544	2020-06-16 19:09:48	2020-06-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	14259	delivery	5	31
79545	2020-06-16 19:17:01	2020-06-16	9	[{"id_menu":6,"count":1}]	74	pick-up	0	9
79546	2020-06-16 19:24:04	2020-06-16	9	[{"id_menu":6,"count":1}]	5503	pick-up	0	9
79547	2020-06-16 19:25:17	2020-06-16	17	[{"id_menu":4,"count":1}]	3308	delivery	5	22
79548	2020-06-16 19:27:21	2020-06-16	17	[{"id_menu":4,"count":1}]	12108	pick-up	0	17
79549	2020-06-16 19:29:35	2020-06-16	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	31176	delivery	5	40
79550	2020-06-16 19:29:36	2020-06-16	8	[{"id_menu":5,"count":1}]	25088	delivery	5	13
79551	2020-06-16 19:30:54	2020-06-16	9	[{"id_menu":7,"count":1}]	26477	delivery	5	14
79552	2020-06-16 19:31:17	2020-06-16	9	[{"id_menu":6,"count":1}]	26004	delivery	5	14
79553	2020-06-16 19:32:01	2020-06-16	14	[{"id_menu":2,"count":1}]	1361	delivery	5	19
79554	2020-06-16 19:38:16	2020-06-16	9	[{"id_menu":6,"count":1}]	28555	delivery	5	14
79555	2020-06-16 19:39:39	2020-06-16	12	[{"id_menu":3,"count":1}]	31214	pick-up	0	12
79556	2020-06-16 19:41:52	2020-06-16	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31145	delivery	5	36
79557	2020-06-16 19:47:20	2020-06-16	14	[{"id_menu":2,"count":1}]	3864	pick-up	0	14
79558	2020-06-16 19:49:52	2020-06-16	17	[{"id_menu":4,"count":1}]	9240	delivery	5	22
79559	2020-06-16 19:50:13	2020-06-16	8	[{"id_menu":5,"count":1}]	31169	delivery	5	13
79560	2020-06-16 19:55:05	2020-06-16	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11367	delivery	5	22
79561	2020-06-16 20:16:28	2020-06-16	8	[{"id_menu":5,"count":1}]	31119	delivery	5	13
79562	2020-06-16 20:22:19	2020-06-16	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16570	delivery	5	43
79563	2020-06-16 20:24:00	2020-06-16	9	[{"id_menu":7,"count":1}]	26127	pick-up	0	9
79564	2020-06-16 20:24:59	2020-06-16	14	[{"id_menu":2,"count":1}]	10394	delivery	5	19
79565	2020-06-16 20:25:38	2020-06-16	12	[{"id_menu":3,"count":1}]	26071	delivery	5	17
79566	2020-06-16 20:26:30	2020-06-16	9	[{"id_menu":6,"count":1}]	9766	pick-up	0	9
79567	2020-06-16 20:28:56	2020-06-16	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	20556	delivery	5	26
79568	2020-06-16 20:37:58	2020-06-16	17	[{"id_menu":4,"count":1}]	7429	delivery	5	22
79569	2020-06-16 20:38:12	2020-06-16	17	[{"id_menu":4,"count":1}]	31192	pick-up	0	17
79570	2020-06-16 20:42:57	2020-06-16	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	18556	delivery	5	27
79571	2020-06-16 20:43:55	2020-06-16	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	26485	delivery	5	25
79572	2020-06-16 20:46:22	2020-06-16	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	31273	delivery	5	31
79573	2020-06-16 20:51:59	2020-06-16	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16534	delivery	5	48
79574	2020-06-16 20:55:34	2020-06-16	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	20579	delivery	5	26
79575	2020-06-16 20:56:31	2020-06-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4583	pick-up	0	26
79576	2020-06-16 20:57:17	2020-06-16	17	[{"id_menu":4,"count":1}]	28283	pick-up	0	17
79577	2020-06-16 20:57:23	2020-06-16	17	[{"id_menu":4,"count":1}]	22337	pick-up	0	17
79578	2020-06-16 21:03:20	2020-06-16	14	[{"id_menu":2,"count":1}]	3382	delivery	5	19
79579	2020-06-16 21:05:09	2020-06-16	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25459	delivery	5	35
79580	2020-06-16 21:07:27	2020-06-16	9	[{"id_menu":7,"count":1}]	31137	delivery	5	14
79581	2020-06-16 21:13:22	2020-06-16	14	[{"id_menu":2,"count":1}]	18687	pick-up	0	14
79582	2020-06-16 21:17:46	2020-06-16	8	[{"id_menu":5,"count":1}]	22663	delivery	5	13
79583	2020-06-16 21:21:58	2020-06-16	9	[{"id_menu":7,"count":1}]	24357	delivery	5	14
79584	2020-06-16 21:23:32	2020-06-16	8	[{"id_menu":5,"count":1}]	31185	delivery	5	13
79585	2020-06-16 21:23:34	2020-06-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6625	delivery	5	28
79586	2020-06-16 21:29:13	2020-06-16	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	3979	delivery	5	43
79587	2020-06-16 21:29:33	2020-06-16	9	[{"id_menu":7,"count":1}]	991	delivery	5	14
79588	2020-06-16 21:31:00	2020-06-16	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	31271	delivery	5	29
79589	2020-06-16 21:33:26	2020-06-16	9	[{"id_menu":6,"count":1}]	7036	delivery	5	14
79590	2020-06-16 21:35:11	2020-06-16	9	[{"id_menu":7,"count":2}]	13550	delivery	5	14
79591	2020-06-16 21:38:26	2020-06-16	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	28960	pick-up	0	22
79592	2020-06-16 21:38:54	2020-06-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	969	delivery	5	28
79593	2020-06-16 21:41:27	2020-06-16	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	31223	delivery	5	34
79594	2020-06-16 21:42:18	2020-06-16	14	[{"id_menu":2,"count":1}]	10273	pick-up	0	14
79595	2020-06-16 21:42:36	2020-06-16	9	[{"id_menu":6,"count":2}]	18345	delivery	5	14
79596	2020-06-16 21:46:07	2020-06-16	8	[{"id_menu":5,"count":1}]	29258	delivery	5	13
79597	2020-06-16 21:52:10	2020-06-16	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	31194	delivery	5	57
79598	2020-06-16 21:52:20	2020-06-16	17	[{"id_menu":4,"count":1}]	8394	delivery	5	22
79599	2020-06-16 21:56:35	2020-06-16	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7192	delivery	5	37
79600	2020-06-16 21:58:48	2020-06-16	9	[{"id_menu":6,"count":1}]	26047	pick-up	0	9
79601	2020-06-16 22:08:00	2020-06-16	14	[{"id_menu":2,"count":1}]	29509	delivery	5	19
79602	2020-06-16 22:08:39	2020-06-16	17	[{"id_menu":4,"count":1}]	8640	pick-up	0	17
79603	2020-06-16 22:09:43	2020-06-16	8	[{"id_menu":5,"count":1}]	11903	delivery	5	13
79604	2020-06-16 22:16:54	2020-06-16	9	[{"id_menu":6,"count":1}]	31286	delivery	5	14
79605	2020-06-16 22:19:35	2020-06-16	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	31207	delivery	5	26
79606	2020-06-16 22:25:20	2020-06-16	9	[{"id_menu":6,"count":1}]	26086	delivery	5	14
79607	2020-06-16 22:26:07	2020-06-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	31116	delivery	5	26
79608	2020-06-16 22:30:58	2020-06-16	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	31118	delivery	5	26
79609	2020-06-16 22:32:53	2020-06-16	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4800	pick-up	0	29
79610	2020-06-16 22:36:03	2020-06-16	9	[{"id_menu":6,"count":1}]	24900	delivery	5	14
79611	2020-06-16 22:36:05	2020-06-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	9447	delivery	5	23
79612	2020-06-16 22:40:59	2020-06-16	12	[{"id_menu":3,"count":1}]	2288	delivery	5	17
79613	2020-06-16 22:43:52	2020-06-16	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	1970	pick-up	0	26
79614	2020-06-16 22:44:51	2020-06-16	9	[{"id_menu":7,"count":1}]	16518	delivery	5	14
79615	2020-06-16 22:48:39	2020-06-16	14	[{"id_menu":2,"count":1}]	31283	delivery	5	19
79616	2020-06-16 22:50:18	2020-06-16	9	[{"id_menu":7,"count":1}]	26874	delivery	5	14
79617	2020-06-16 22:50:26	2020-06-16	12	[{"id_menu":1,"count":1}]	31217	delivery	5	17
79618	2020-06-16 22:52:11	2020-06-16	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	19464	delivery	5	48
79619	2020-06-16 22:54:23	2020-06-16	9	[{"id_menu":6,"count":1}]	5402	pick-up	0	9
79620	2020-06-16 22:55:59	2020-06-16	14	[{"id_menu":2,"count":1}]	31078	delivery	5	19
79621	2020-06-16 22:58:43	2020-06-16	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	3851	delivery	5	29
79622	2020-06-16 22:58:51	2020-06-16	9	[{"id_menu":6,"count":1}]	31264	delivery	5	14
79623	2020-06-16 22:59:33	2020-06-16	9	[{"id_menu":6,"count":1}]	14127	delivery	5	14
79624	2020-06-16 23:01:26	2020-06-16	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	31233	delivery	5	40
79625	2020-06-16 23:06:04	2020-06-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	23222	delivery	5	28
79626	2020-06-16 23:07:25	2020-06-16	9	[{"id_menu":6,"count":1}]	31167	delivery	5	14
79627	2020-06-16 23:09:48	2020-06-16	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	30102	delivery	5	43
79628	2020-06-16 23:11:10	2020-06-16	9	[{"id_menu":7,"count":1}]	26739	delivery	5	14
79629	2020-06-16 23:17:11	2020-06-16	9	[{"id_menu":6,"count":1}]	16512	delivery	5	14
79630	2020-06-16 23:17:58	2020-06-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	28859	delivery	5	31
79631	2020-06-16 23:21:06	2020-06-16	17	[{"id_menu":4,"count":1}]	14772	delivery	5	22
79632	2020-06-16 23:27:01	2020-06-16	9	[{"id_menu":7,"count":1}]	1865	pick-up	0	9
79633	2020-06-16 23:28:54	2020-06-16	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	410	delivery	5	34
79634	2020-06-16 23:30:48	2020-06-16	17	[{"id_menu":4,"count":1}]	1507	pick-up	0	17
79635	2020-06-16 23:35:59	2020-06-16	12	[{"id_menu":1,"count":1}]	31262	delivery	5	17
79636	2020-06-16 23:36:05	2020-06-16	38	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	31168	delivery	5	43
79637	2020-06-16 23:38:02	2020-06-16	8	[{"id_menu":5,"count":1}]	20594	delivery	5	13
79638	2020-06-16 23:41:58	2020-06-16	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	15246	delivery	5	29
79639	2020-06-16 23:45:18	2020-06-16	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12169	delivery	5	45
79640	2020-06-16 23:45:55	2020-06-16	12	[{"id_menu":1,"count":1}]	31249	delivery	5	17
79641	2020-06-16 23:53:49	2020-06-16	9	[{"id_menu":7,"count":1}]	2959	pick-up	0	9
79642	2020-06-16 23:57:27	2020-06-16	17	[{"id_menu":4,"count":1}]	24891	delivery	5	22
79643	2020-06-16 23:57:57	2020-06-16	9	[{"id_menu":7,"count":1}]	27329	delivery	5	14
79644	2020-06-16 23:59:58	2020-06-16	8	[{"id_menu":5,"count":1}]	31231	delivery	5	13
79645	2020-06-17 00:02:10	2020-06-17	9	[{"id_menu":6,"count":1}]	1263	pick-up	0	9
79646	2020-06-17 00:02:56	2020-06-17	12	[{"id_menu":1,"count":1}]	31413	delivery	5	17
79647	2020-06-17 00:04:44	2020-06-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	14483	delivery	5	28
79648	2020-06-17 00:07:38	2020-06-17	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9847	delivery	5	45
79649	2020-06-17 00:09:00	2020-06-17	9	[{"id_menu":7,"count":1}]	8272	delivery	5	14
79650	2020-06-17 00:09:12	2020-06-17	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	27779	delivery	5	25
79651	2020-06-17 00:09:54	2020-06-17	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	10954	delivery	5	40
79652	2020-06-17 00:11:49	2020-06-17	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	8561	pick-up	0	26
79653	2020-06-17 00:16:08	2020-06-17	12	[{"id_menu":3,"count":1}]	16292	delivery	5	17
79654	2020-06-17 00:18:58	2020-06-17	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3476	pick-up	0	29
79655	2020-06-17 00:28:00	2020-06-17	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1309	delivery	5	40
79656	2020-06-17 00:28:53	2020-06-17	9	[{"id_menu":6,"count":1}]	31290	delivery	5	14
79657	2020-06-17 00:34:01	2020-06-17	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2065	delivery	5	31
79658	2020-06-17 00:36:28	2020-06-17	17	[{"id_menu":4,"count":1}]	21514	delivery	5	22
79659	2020-06-17 00:38:26	2020-06-17	8	[{"id_menu":5,"count":2}]	31419	delivery	5	13
79660	2020-06-17 00:38:45	2020-06-17	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":2}]	31348	delivery	5	28
79661	2020-06-17 00:39:28	2020-06-17	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	31460	delivery	5	27
79662	2020-06-17 00:42:39	2020-06-17	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3420	pick-up	0	30
79663	2020-06-17 00:44:36	2020-06-17	9	[{"id_menu":6,"count":1}]	31322	delivery	5	14
79664	2020-06-17 00:47:19	2020-06-17	12	[{"id_menu":3,"count":1}]	6180	delivery	5	17
79665	2020-06-17 00:48:09	2020-06-17	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	13236	delivery	5	29
79666	2020-06-17 00:48:35	2020-06-17	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	14867	delivery	5	36
79667	2020-06-17 00:49:17	2020-06-17	9	[{"id_menu":7,"count":1}]	31469	delivery	5	14
79668	2020-06-17 00:50:51	2020-06-17	17	[{"id_menu":4,"count":1}]	31405	delivery	5	22
79669	2020-06-17 00:53:42	2020-06-17	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	7947	delivery	5	26
79670	2020-06-17 00:59:18	2020-06-17	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	6753	delivery	5	43
79671	2020-06-17 01:01:19	2020-06-17	8	[{"id_menu":5,"count":1}]	27468	delivery	5	13
79672	2020-06-17 01:01:55	2020-06-17	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	18981	pick-up	0	29
79673	2020-06-17 01:02:38	2020-06-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15735	delivery	5	23
79674	2020-06-17 01:05:38	2020-06-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8071	pick-up	0	23
79675	2020-06-17 01:06:29	2020-06-17	9	[{"id_menu":7,"count":1}]	9809	pick-up	0	9
79676	2020-06-17 01:08:22	2020-06-17	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	31335	delivery	5	26
79677	2020-06-17 01:09:04	2020-06-17	12	[{"id_menu":1,"count":1}]	13339	delivery	5	17
79678	2020-06-17 01:14:07	2020-06-17	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	31417	delivery	5	25
79679	2020-06-17 01:18:23	2020-06-17	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1235	pick-up	0	26
79680	2020-06-17 01:23:14	2020-06-17	9	[{"id_menu":6,"count":1}]	31429	delivery	5	14
79681	2020-06-17 01:25:56	2020-06-17	9	[{"id_menu":7,"count":1}]	31452	pick-up	0	9
79682	2020-06-17 01:25:58	2020-06-17	9	[{"id_menu":6,"count":1}]	19964	delivery	5	14
79683	2020-06-17 01:26:13	2020-06-17	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	13078	delivery	5	30
79684	2020-06-17 01:26:35	2020-06-17	9	[{"id_menu":7,"count":1}]	31396	delivery	5	14
79685	2020-06-17 01:30:02	2020-06-17	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5950	delivery	5	22
79686	2020-06-17 01:35:09	2020-06-17	8	[{"id_menu":5,"count":1}]	9402	pick-up	0	8
79687	2020-06-17 01:35:17	2020-06-17	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8214	delivery	5	39
79688	2020-06-17 01:36:30	2020-06-17	12	[{"id_menu":3,"count":1}]	31428	delivery	5	17
79689	2020-06-17 01:37:05	2020-06-17	9	[{"id_menu":6,"count":2}]	22277	delivery	5	14
79690	2020-06-17 01:38:30	2020-06-17	12	[{"id_menu":3,"count":1}]	31350	delivery	5	17
79691	2020-06-17 01:41:07	2020-06-17	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	19677	delivery	5	23
79692	2020-06-17 01:43:14	2020-06-17	17	[{"id_menu":4,"count":1}]	20066	delivery	5	22
79693	2020-06-17 01:50:47	2020-06-17	8	[{"id_menu":5,"count":1}]	13695	delivery	5	13
79694	2020-06-17 01:52:18	2020-06-17	12	[{"id_menu":3,"count":1}]	9766	pick-up	0	12
79695	2020-06-17 01:53:25	2020-06-17	9	[{"id_menu":7,"count":1}]	310	pick-up	0	9
79696	2020-06-17 01:56:19	2020-06-17	8	[{"id_menu":5,"count":1}]	12217	delivery	5	13
79697	2020-06-17 01:57:45	2020-06-17	17	[{"id_menu":4,"count":1}]	11394	delivery	5	22
79698	2020-06-17 01:58:14	2020-06-17	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	20832	delivery	5	45
79699	2020-06-17 02:03:11	2020-06-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	20288	delivery	5	31
79700	2020-06-17 02:03:43	2020-06-17	12	[{"id_menu":3,"count":2}]	26986	pick-up	0	12
79701	2020-06-17 02:05:19	2020-06-17	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3579	delivery	5	31
79702	2020-06-17 02:10:12	2020-06-17	9	[{"id_menu":7,"count":1}]	905	delivery	5	14
79703	2020-06-17 02:16:11	2020-06-17	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	20299	delivery	5	37
79704	2020-06-17 02:18:44	2020-06-17	9	[{"id_menu":6,"count":3}]	1700	delivery	5	14
79705	2020-06-17 02:24:07	2020-06-17	9	[{"id_menu":6,"count":1}]	31360	delivery	5	14
79706	2020-06-17 02:24:40	2020-06-17	17	[{"id_menu":4,"count":1}]	23237	pick-up	0	17
79707	2020-06-17 02:28:53	2020-06-17	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":2}]	21042	delivery	5	22
79708	2020-06-17 02:28:57	2020-06-17	12	[{"id_menu":1,"count":1}]	31412	delivery	5	17
79709	2020-06-17 02:31:55	2020-06-17	12	[{"id_menu":3,"count":1}]	10795	pick-up	0	12
79710	2020-06-17 02:32:47	2020-06-17	17	[{"id_menu":4,"count":1}]	22622	delivery	5	22
79711	2020-06-17 02:38:49	2020-06-17	12	[{"id_menu":1,"count":1}]	31329	delivery	5	17
79712	2020-06-17 02:39:32	2020-06-17	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	19565	delivery	5	36
79713	2020-06-17 02:42:13	2020-06-17	9	[{"id_menu":6,"count":1}]	24059	delivery	5	14
79714	2020-06-17 02:42:48	2020-06-17	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20592	delivery	5	22
79715	2020-06-17 02:43:39	2020-06-17	9	[{"id_menu":7,"count":1}]	7919	pick-up	0	9
79716	2020-06-17 02:54:54	2020-06-17	9	[{"id_menu":6,"count":1}]	15865	delivery	5	14
79717	2020-06-17 03:03:59	2020-06-17	12	[{"id_menu":1,"count":1}]	1944	delivery	5	17
79718	2020-06-17 03:05:00	2020-06-17	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31319	delivery	5	52
79719	2020-06-17 03:09:57	2020-06-17	9	[{"id_menu":7,"count":2}]	28819	delivery	5	14
79720	2020-06-17 03:15:48	2020-06-17	12	[{"id_menu":1,"count":1}]	12855	pick-up	0	12
79721	2020-06-17 03:17:03	2020-06-17	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	27499	delivery	5	25
79722	2020-06-17 03:17:27	2020-06-17	12	[{"id_menu":1,"count":1}]	31431	pick-up	0	12
79723	2020-06-17 03:17:46	2020-06-17	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7180	delivery	5	51
79724	2020-06-17 03:24:52	2020-06-17	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	376	pick-up	0	29
79725	2020-06-17 03:28:14	2020-06-17	8	[{"id_menu":5,"count":1}]	31354	delivery	5	13
79726	2020-06-17 03:28:19	2020-06-17	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	8876	delivery	5	25
79727	2020-06-17 03:32:08	2020-06-17	14	[{"id_menu":2,"count":2}]	13267	pick-up	0	14
79728	2020-06-17 03:34:27	2020-06-17	12	[{"id_menu":1,"count":1}]	19434	delivery	5	17
79729	2020-06-17 03:36:17	2020-06-17	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13634	delivery	5	31
79730	2020-06-17 03:37:51	2020-06-17	9	[{"id_menu":7,"count":1}]	31339	delivery	5	14
79731	2020-06-17 03:40:00	2020-06-17	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1751	delivery	5	43
79732	2020-06-17 03:41:23	2020-06-17	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2594	delivery	5	34
79733	2020-06-17 03:41:38	2020-06-17	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31352	delivery	5	48
79734	2020-06-17 03:45:35	2020-06-17	8	[{"id_menu":5,"count":1}]	31324	delivery	5	13
79735	2020-06-17 03:47:12	2020-06-17	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":2}]	12949	delivery	5	26
79736	2020-06-17 03:47:45	2020-06-17	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	31308	delivery	5	51
79737	2020-06-17 03:48:22	2020-06-17	9	[{"id_menu":7,"count":1}]	31330	delivery	5	14
79738	2020-06-17 03:50:27	2020-06-17	17	[{"id_menu":4,"count":1}]	4248	pick-up	0	17
79739	2020-06-17 03:57:14	2020-06-17	14	[{"id_menu":2,"count":1}]	6067	delivery	5	19
79740	2020-06-17 04:00:48	2020-06-17	8	[{"id_menu":5,"count":1}]	3586	delivery	5	13
79741	2020-06-17 04:01:28	2020-06-17	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	10166	delivery	5	25
79742	2020-06-17 04:11:29	2020-06-17	14	[{"id_menu":2,"count":1}]	13967	delivery	5	19
79743	2020-06-17 04:11:52	2020-06-17	12	[{"id_menu":1,"count":1}]	9171	pick-up	0	12
79744	2020-06-17 04:13:54	2020-06-17	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	31441	delivery	5	34
79745	2020-06-17 04:15:50	2020-06-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31321	delivery	5	23
79746	2020-06-17 04:25:34	2020-06-17	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	31347	delivery	5	26
79747	2020-06-17 04:28:49	2020-06-17	12	[{"id_menu":1,"count":1}]	1645	pick-up	0	12
79748	2020-06-17 04:29:53	2020-06-17	12	[{"id_menu":1,"count":1}]	777	delivery	5	17
79749	2020-06-17 04:44:43	2020-06-17	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	29560	delivery	5	31
79750	2020-06-17 04:46:19	2020-06-17	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	31415	delivery	5	40
79751	2020-06-17 04:48:14	2020-06-17	17	[{"id_menu":4,"count":1}]	31408	delivery	5	22
79752	2020-06-17 04:51:11	2020-06-17	9	[{"id_menu":6,"count":1}]	27251	delivery	5	14
79753	2020-06-17 05:00:31	2020-06-17	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	9795	delivery	5	25
79754	2020-06-17 05:01:55	2020-06-17	8	[{"id_menu":5,"count":1}]	29541	pick-up	0	8
79755	2020-06-17 05:05:54	2020-06-17	12	[{"id_menu":3,"count":1}]	31312	delivery	5	17
79756	2020-06-17 05:07:29	2020-06-17	17	[{"id_menu":4,"count":1}]	11858	delivery	5	22
79757	2020-06-17 05:09:58	2020-06-17	8	[{"id_menu":5,"count":1}]	24853	pick-up	0	8
79758	2020-06-17 05:15:01	2020-06-17	8	[{"id_menu":5,"count":1}]	4003	delivery	5	13
79759	2020-06-17 05:16:10	2020-06-17	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1479	delivery	5	37
79760	2020-06-17 05:17:26	2020-06-17	12	[{"id_menu":3,"count":1}]	24422	delivery	5	17
79761	2020-06-17 05:17:33	2020-06-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	31313	delivery	5	28
79762	2020-06-17 05:18:59	2020-06-17	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	21887	delivery	5	45
79763	2020-06-17 05:23:04	2020-06-17	14	[{"id_menu":2,"count":1}]	22938	delivery	5	19
79764	2020-06-17 05:25:18	2020-06-17	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	31328	delivery	5	31
79765	2020-06-17 05:30:04	2020-06-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	8330	delivery	5	28
79766	2020-06-17 05:36:43	2020-06-17	8	[{"id_menu":5,"count":1}]	26698	delivery	5	13
79767	2020-06-17 05:37:37	2020-06-17	12	[{"id_menu":1,"count":1}]	10850	delivery	5	17
79768	2020-06-17 05:38:24	2020-06-17	17	[{"id_menu":4,"count":1}]	26622	delivery	5	22
79769	2020-06-17 05:44:01	2020-06-17	14	[{"id_menu":2,"count":1}]	2804	pick-up	0	14
79770	2020-06-17 05:44:47	2020-06-17	12	[{"id_menu":3,"count":1}]	4459	delivery	5	17
79771	2020-06-17 05:45:15	2020-06-17	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	13054	delivery	5	36
79772	2020-06-17 05:49:13	2020-06-17	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	6881	delivery	5	28
79773	2020-06-17 05:53:18	2020-06-17	9	[{"id_menu":6,"count":1}]	9106	pick-up	0	9
79774	2020-06-17 05:55:10	2020-06-17	9	[{"id_menu":6,"count":1}]	31465	delivery	5	14
79775	2020-06-17 05:55:54	2020-06-17	9	[{"id_menu":7,"count":1}]	31298	delivery	5	14
79776	2020-06-17 05:56:43	2020-06-17	9	[{"id_menu":6,"count":1}]	31384	delivery	5	14
79777	2020-06-17 06:01:16	2020-06-17	9	[{"id_menu":7,"count":1}]	18958	pick-up	0	9
79778	2020-06-17 06:05:00	2020-06-17	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31401	delivery	5	49
79779	2020-06-17 06:05:44	2020-06-17	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	30841	delivery	5	36
79780	2020-06-17 06:07:52	2020-06-17	14	[{"id_menu":2,"count":1}]	6137	delivery	5	19
79781	2020-06-17 06:16:34	2020-06-17	14	[{"id_menu":2,"count":1}]	29123	delivery	5	19
79782	2020-06-17 06:16:34	2020-06-17	17	[{"id_menu":4,"count":1}]	31363	delivery	5	22
79783	2020-06-17 06:20:12	2020-06-17	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	12287	delivery	5	36
79784	2020-06-17 06:31:41	2020-06-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3123	delivery	5	28
79785	2020-06-17 06:32:31	2020-06-17	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	30520	delivery	5	29
79786	2020-06-17 06:35:35	2020-06-17	9	[{"id_menu":7,"count":1}]	21765	delivery	5	14
79787	2020-06-17 06:36:37	2020-06-17	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	31406	delivery	5	39
79788	2020-06-17 06:36:43	2020-06-17	17	[{"id_menu":4,"count":1}]	2415	pick-up	0	17
79789	2020-06-17 06:42:13	2020-06-17	12	[{"id_menu":1,"count":1}]	5346	delivery	5	17
79790	2020-06-17 06:43:25	2020-06-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1635	delivery	5	28
79791	2020-06-17 06:43:30	2020-06-17	9	[{"id_menu":6,"count":1}]	14747	delivery	5	14
79792	2020-06-17 06:44:11	2020-06-17	14	[{"id_menu":2,"count":1}]	31303	delivery	5	19
79793	2020-06-17 06:45:06	2020-06-17	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31376	delivery	5	31
79794	2020-06-17 06:47:03	2020-06-17	8	[{"id_menu":5,"count":1}]	31463	delivery	5	13
79795	2020-06-17 06:53:02	2020-06-17	8	[{"id_menu":5,"count":1}]	3343	delivery	5	13
79796	2020-06-17 06:55:54	2020-06-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31470	delivery	5	23
79797	2020-06-17 06:56:45	2020-06-17	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	31471	delivery	5	27
79798	2020-06-17 06:59:34	2020-06-17	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	16231	delivery	5	31
79799	2020-06-17 07:02:25	2020-06-17	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	27992	pick-up	0	21
79800	2020-06-17 07:02:47	2020-06-17	12	[{"id_menu":1,"count":1}]	31353	delivery	5	17
79801	2020-06-17 07:03:24	2020-06-17	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	19817	delivery	5	28
79802	2020-06-17 07:04:17	2020-06-17	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31333	delivery	5	31
79803	2020-06-17 07:04:50	2020-06-17	17	[{"id_menu":4,"count":1}]	3104	pick-up	0	17
79804	2020-06-17 07:06:42	2020-06-17	17	[{"id_menu":4,"count":1}]	9859	delivery	5	22
79805	2020-06-17 07:07:29	2020-06-17	9	[{"id_menu":6,"count":1}]	31459	delivery	5	14
79806	2020-06-17 07:14:38	2020-06-17	9	[{"id_menu":7,"count":1}]	31369	pick-up	0	9
79807	2020-06-17 07:23:30	2020-06-17	14	[{"id_menu":2,"count":1}]	22493	pick-up	0	14
79808	2020-06-17 07:27:47	2020-06-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2206	pick-up	0	23
79809	2020-06-17 07:29:49	2020-06-17	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2310	pick-up	0	17
79810	2020-06-17 07:33:03	2020-06-17	9	[{"id_menu":6,"count":1}]	12231	delivery	5	14
79811	2020-06-17 07:34:48	2020-06-17	8	[{"id_menu":5,"count":1}]	26231	pick-up	0	8
79812	2020-06-17 07:35:01	2020-06-17	14	[{"id_menu":2,"count":1}]	24113	delivery	5	19
79813	2020-06-17 07:36:10	2020-06-17	9	[{"id_menu":7,"count":2}]	31451	delivery	5	14
79814	2020-06-17 07:41:15	2020-06-17	8	[{"id_menu":5,"count":2}]	31397	delivery	5	13
79815	2020-06-17 07:47:15	2020-06-17	17	[{"id_menu":4,"count":1}]	16692	delivery	5	22
79816	2020-06-17 07:53:47	2020-06-17	9	[{"id_menu":6,"count":1}]	30649	delivery	5	14
79817	2020-06-17 07:54:02	2020-06-17	9	[{"id_menu":7,"count":1}]	5264	delivery	5	14
79818	2020-06-17 07:55:51	2020-06-17	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31327	delivery	5	40
79819	2020-06-17 07:58:11	2020-06-17	8	[{"id_menu":5,"count":1}]	31299	delivery	5	13
79820	2020-06-17 07:59:18	2020-06-17	9	[{"id_menu":7,"count":1}]	18633	delivery	5	14
79821	2020-06-17 08:08:47	2020-06-17	9	[{"id_menu":7,"count":1}]	13363	delivery	5	14
79822	2020-06-17 08:10:49	2020-06-17	14	[{"id_menu":2,"count":1}]	4509	delivery	5	19
79823	2020-06-17 08:10:55	2020-06-17	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	24275	delivery	5	26
79824	2020-06-17 08:11:17	2020-06-17	12	[{"id_menu":3,"count":1}]	24259	delivery	5	17
79825	2020-06-17 08:16:27	2020-06-17	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	20057	delivery	5	34
79826	2020-06-17 08:17:27	2020-06-17	14	[{"id_menu":2,"count":1}]	6163	pick-up	0	14
79827	2020-06-17 08:18:39	2020-06-17	12	[{"id_menu":1,"count":1}]	31389	pick-up	0	12
79828	2020-06-17 08:27:28	2020-06-17	17	[{"id_menu":4,"count":1}]	31438	delivery	5	22
79829	2020-06-17 08:30:42	2020-06-17	12	[{"id_menu":3,"count":1}]	31305	delivery	5	17
79830	2020-06-17 08:31:49	2020-06-17	9	[{"id_menu":7,"count":1}]	31450	delivery	5	14
79831	2020-06-17 08:33:21	2020-06-17	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	29462	delivery	5	26
79832	2020-06-17 08:34:55	2020-06-17	14	[{"id_menu":2,"count":1}]	16774	delivery	5	19
79833	2020-06-17 08:35:14	2020-06-17	14	[{"id_menu":2,"count":1}]	31295	pick-up	0	14
79834	2020-06-17 08:41:39	2020-06-17	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2203	pick-up	0	26
79835	2020-06-17 08:51:03	2020-06-17	14	[{"id_menu":2,"count":1}]	31379	delivery	5	19
79836	2020-06-17 08:51:57	2020-06-17	9	[{"id_menu":6,"count":1}]	19233	pick-up	0	9
79837	2020-06-17 08:52:55	2020-06-17	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	20780	pick-up	0	26
79838	2020-06-17 08:56:08	2020-06-17	14	[{"id_menu":2,"count":1}]	31357	pick-up	0	14
79839	2020-06-17 09:00:15	2020-06-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7574	pick-up	0	26
79840	2020-06-17 09:01:49	2020-06-17	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	18496	delivery	5	45
79841	2020-06-17 09:06:57	2020-06-17	12	[{"id_menu":1,"count":1}]	6706	delivery	5	17
79842	2020-06-17 09:07:25	2020-06-17	8	[{"id_menu":5,"count":1}]	28761	delivery	5	13
79843	2020-06-17 09:07:30	2020-06-17	9	[{"id_menu":6,"count":1}]	31291	delivery	5	14
79844	2020-06-17 09:12:00	2020-06-17	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	31410	delivery	5	42
79845	2020-06-17 09:15:02	2020-06-17	43	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3390	pick-up	0	43
79846	2020-06-17 09:16:16	2020-06-17	9	[{"id_menu":7,"count":1}]	29519	delivery	5	14
79847	2020-06-17 09:19:45	2020-06-17	9	[{"id_menu":7,"count":2}]	31394	delivery	5	14
79848	2020-06-17 09:32:57	2020-06-17	12	[{"id_menu":1,"count":1}]	7041	delivery	5	17
79849	2020-06-17 09:35:59	2020-06-17	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	10726	delivery	5	34
79850	2020-06-17 09:36:37	2020-06-17	12	[{"id_menu":1,"count":1}]	3320	pick-up	0	12
79851	2020-06-17 09:42:53	2020-06-17	9	[{"id_menu":6,"count":1}]	31309	delivery	5	14
79852	2020-06-17 09:46:35	2020-06-17	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	8688	pick-up	0	26
79853	2020-06-17 09:50:49	2020-06-17	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	31427	delivery	5	25
79854	2020-06-17 09:52:48	2020-06-17	9	[{"id_menu":7,"count":1}]	16367	delivery	5	14
79855	2020-06-17 09:56:55	2020-06-17	9	[{"id_menu":6,"count":1}]	15267	pick-up	0	9
79856	2020-06-17 09:57:06	2020-06-17	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	78	pick-up	0	21
79857	2020-06-17 10:04:07	2020-06-17	17	[{"id_menu":4,"count":1}]	3335	pick-up	0	17
79858	2020-06-17 10:05:43	2020-06-17	8	[{"id_menu":5,"count":1}]	21895	delivery	5	13
79859	2020-06-17 10:06:18	2020-06-17	9	[{"id_menu":6,"count":1}]	20563	delivery	5	14
79860	2020-06-17 10:06:47	2020-06-17	9	[{"id_menu":6,"count":1}]	30269	delivery	5	14
79861	2020-06-17 10:10:33	2020-06-17	9	[{"id_menu":7,"count":1}]	1308	pick-up	0	9
79862	2020-06-17 10:16:56	2020-06-17	12	[{"id_menu":3,"count":1}]	20629	delivery	5	17
79863	2020-06-17 10:21:40	2020-06-17	9	[{"id_menu":7,"count":1}]	31454	delivery	5	14
79864	2020-06-17 10:23:40	2020-06-17	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	30818	delivery	5	22
79865	2020-06-17 10:26:25	2020-06-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20269	delivery	5	23
79866	2020-06-17 10:27:44	2020-06-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	29480	pick-up	0	23
79867	2020-06-17 10:28:35	2020-06-17	14	[{"id_menu":2,"count":1}]	31455	delivery	5	19
79868	2020-06-17 10:29:04	2020-06-17	17	[{"id_menu":4,"count":1}]	5516	pick-up	0	17
79869	2020-06-17 10:33:53	2020-06-17	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	31320	delivery	5	39
79870	2020-06-17 10:33:59	2020-06-17	12	[{"id_menu":3,"count":1}]	27651	delivery	5	17
79871	2020-06-17 10:38:58	2020-06-17	9	[{"id_menu":7,"count":1}]	6189	delivery	5	14
79872	2020-06-17 10:50:46	2020-06-17	14	[{"id_menu":2,"count":1}]	3480	delivery	5	19
79873	2020-06-17 10:51:44	2020-06-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1259	pick-up	0	23
79874	2020-06-17 10:55:31	2020-06-17	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	23794	delivery	5	40
79875	2020-06-17 10:59:05	2020-06-17	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17231	delivery	5	31
79876	2020-06-17 11:00:02	2020-06-17	12	[{"id_menu":3,"count":1}]	20785	delivery	5	17
79877	2020-06-17 11:05:10	2020-06-17	17	[{"id_menu":4,"count":1}]	1541	delivery	5	22
79878	2020-06-17 11:08:29	2020-06-17	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	31337	delivery	5	44
79879	2020-06-17 11:11:59	2020-06-17	14	[{"id_menu":2,"count":1}]	2132	delivery	5	19
79880	2020-06-17 11:13:04	2020-06-17	8	[{"id_menu":5,"count":1}]	6489	pick-up	0	8
79881	2020-06-17 11:13:09	2020-06-17	12	[{"id_menu":1,"count":1}]	31409	delivery	5	17
79882	2020-06-17 11:13:32	2020-06-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	21266	delivery	5	28
79883	2020-06-17 11:13:46	2020-06-17	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	25791	delivery	5	34
79884	2020-06-17 11:16:19	2020-06-17	14	[{"id_menu":2,"count":1}]	5473	pick-up	0	14
79885	2020-06-17 11:17:16	2020-06-17	14	[{"id_menu":2,"count":1}]	3592	delivery	5	19
79886	2020-06-17 11:19:32	2020-06-17	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	31364	pick-up	0	31
79887	2020-06-17 11:26:39	2020-06-17	9	[{"id_menu":7,"count":1}]	31311	delivery	5	14
79888	2020-06-17 11:30:39	2020-06-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	17038	delivery	5	23
79889	2020-06-17 11:36:45	2020-06-17	14	[{"id_menu":2,"count":1}]	1963	delivery	5	19
79890	2020-06-17 11:37:27	2020-06-17	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2559	pick-up	0	20
79891	2020-06-17 11:43:00	2020-06-17	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	482	delivery	5	26
79892	2020-06-17 11:47:27	2020-06-17	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	232	pick-up	0	20
79893	2020-06-17 11:52:48	2020-06-17	12	[{"id_menu":1,"count":1}]	24044	delivery	5	17
79894	2020-06-17 11:56:27	2020-06-17	9	[{"id_menu":6,"count":1}]	13888	delivery	5	14
79895	2020-06-17 11:58:12	2020-06-17	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	31411	delivery	5	45
79896	2020-06-17 11:59:00	2020-06-17	12	[{"id_menu":3,"count":1}]	31332	pick-up	0	12
79897	2020-06-17 12:00:11	2020-06-17	9	[{"id_menu":6,"count":3}]	10057	delivery	5	14
79898	2020-06-17 12:01:48	2020-06-17	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	28009	pick-up	0	25
79899	2020-06-17 12:01:56	2020-06-17	9	[{"id_menu":6,"count":1}]	23616	delivery	5	14
79900	2020-06-17 12:03:06	2020-06-17	9	[{"id_menu":6,"count":1}]	31358	delivery	5	14
79901	2020-06-17 12:03:52	2020-06-17	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	587	pick-up	0	21
79902	2020-06-17 12:10:02	2020-06-17	8	[{"id_menu":5,"count":1}]	27471	delivery	5	13
79903	2020-06-17 12:14:07	2020-06-17	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2897	pick-up	0	38
79904	2020-06-17 12:20:28	2020-06-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31425	delivery	5	23
79905	2020-06-17 12:20:34	2020-06-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	23147	delivery	5	31
79906	2020-06-17 12:21:02	2020-06-17	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	9257	delivery	5	22
79907	2020-06-17 12:23:48	2020-06-17	17	[{"id_menu":4,"count":1}]	31331	delivery	5	22
79908	2020-06-17 12:24:41	2020-06-17	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31194	delivery	5	40
79909	2020-06-17 12:27:17	2020-06-17	12	[{"id_menu":3,"count":1}]	15653	delivery	5	17
79910	2020-06-17 12:27:18	2020-06-17	9	[{"id_menu":7,"count":1}]	5418	delivery	5	14
79911	2020-06-17 12:28:12	2020-06-17	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6131	delivery	5	40
79912	2020-06-17 12:28:59	2020-06-17	17	[{"id_menu":4,"count":1}]	26757	pick-up	0	17
79913	2020-06-17 12:31:46	2020-06-17	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	17039	delivery	5	42
79914	2020-06-17 12:32:48	2020-06-17	14	[{"id_menu":2,"count":2}]	8165	delivery	5	19
79915	2020-06-17 12:34:02	2020-06-17	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	8036	delivery	5	26
79916	2020-06-17 12:35:10	2020-06-17	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":2}]	31367	delivery	5	26
79917	2020-06-17 12:38:50	2020-06-17	8	[{"id_menu":5,"count":1}]	31293	delivery	5	13
79918	2020-06-17 12:40:17	2020-06-17	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	31435	pick-up	0	26
79919	2020-06-17 12:42:44	2020-06-17	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	16382	delivery	5	36
79920	2020-06-17 12:43:22	2020-06-17	8	[{"id_menu":5,"count":1}]	30070	delivery	5	13
79921	2020-06-17 12:44:55	2020-06-17	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	5015	pick-up	0	21
79922	2020-06-17 12:50:53	2020-06-17	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21234	delivery	5	31
79923	2020-06-17 12:52:13	2020-06-17	9	[{"id_menu":7,"count":1}]	17569	delivery	5	14
79924	2020-06-17 12:57:26	2020-06-17	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	790	pick-up	0	49
79925	2020-06-17 12:57:48	2020-06-17	9	[{"id_menu":7,"count":1}]	16703	delivery	5	14
79926	2020-06-17 13:06:29	2020-06-17	14	[{"id_menu":2,"count":1}]	13639	delivery	5	19
79927	2020-06-17 13:08:07	2020-06-17	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	31464	delivery	5	39
79928	2020-06-17 13:11:11	2020-06-17	9	[{"id_menu":6,"count":1}]	24023	delivery	5	14
79929	2020-06-17 13:11:48	2020-06-17	17	[{"id_menu":4,"count":1}]	5507	pick-up	0	17
79930	2020-06-17 13:12:15	2020-06-17	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":2}]	31457	delivery	5	30
79931	2020-06-17 13:18:27	2020-06-17	9	[{"id_menu":7,"count":1}]	2615	pick-up	0	9
79932	2020-06-17 13:18:52	2020-06-17	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	31341	delivery	5	40
79933	2020-06-17 13:19:52	2020-06-17	49	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	30607	delivery	5	54
79934	2020-06-17 13:24:07	2020-06-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6588	delivery	5	31
79935	2020-06-17 13:34:08	2020-06-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	22071	pick-up	0	23
79936	2020-06-17 13:36:50	2020-06-17	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22925	delivery	5	35
79937	2020-06-17 13:37:59	2020-06-17	9	[{"id_menu":6,"count":1}]	225	pick-up	0	9
79938	2020-06-17 13:38:46	2020-06-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":3}]	5192	delivery	5	28
79939	2020-06-17 13:39:05	2020-06-17	12	[{"id_menu":3,"count":2}]	21684	delivery	5	17
79940	2020-06-17 13:40:14	2020-06-17	12	[{"id_menu":1,"count":1}]	31393	delivery	5	17
79941	2020-06-17 13:42:05	2020-06-17	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	31439	delivery	5	29
79942	2020-06-17 13:45:10	2020-06-17	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	16127	delivery	5	34
79943	2020-06-17 13:45:37	2020-06-17	9	[{"id_menu":6,"count":1}]	715	pick-up	0	9
79944	2020-06-17 13:52:20	2020-06-17	33	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	970	pick-up	0	33
79945	2020-06-17 13:54:34	2020-06-17	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31359	delivery	5	22
79946	2020-06-17 13:55:03	2020-06-17	9	[{"id_menu":7,"count":2}]	22228	delivery	5	14
79947	2020-06-17 13:55:49	2020-06-17	8	[{"id_menu":5,"count":1}]	16126	delivery	5	13
79948	2020-06-17 13:56:23	2020-06-17	9	[{"id_menu":6,"count":1}]	5441	delivery	5	14
79949	2020-06-17 13:57:09	2020-06-17	8	[{"id_menu":5,"count":1}]	11262	pick-up	0	8
79950	2020-06-17 13:57:53	2020-06-17	12	[{"id_menu":3,"count":1}]	1894	pick-up	0	12
79951	2020-06-17 13:58:58	2020-06-17	12	[{"id_menu":3,"count":1}]	2935	delivery	5	17
79952	2020-06-17 13:59:14	2020-06-17	12	[{"id_menu":1,"count":1}]	586	pick-up	0	12
79953	2020-06-17 14:00:59	2020-06-17	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22992	delivery	5	31
79954	2020-06-17 14:01:17	2020-06-17	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	23807	delivery	5	36
79955	2020-06-17 14:03:37	2020-06-17	9	[{"id_menu":6,"count":1}]	16271	delivery	5	14
79956	2020-06-17 14:04:50	2020-06-17	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	7372	delivery	5	30
79957	2020-06-17 14:07:05	2020-06-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	31422	pick-up	0	23
79958	2020-06-17 14:07:41	2020-06-17	9	[{"id_menu":7,"count":1}]	7159	delivery	5	14
79959	2020-06-17 14:08:42	2020-06-17	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4836	delivery	5	57
79960	2020-06-17 14:10:48	2020-06-17	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31462	delivery	5	48
79961	2020-06-17 14:13:17	2020-06-17	12	[{"id_menu":3,"count":1}]	15817	pick-up	0	12
79962	2020-06-17 14:13:32	2020-06-17	12	[{"id_menu":1,"count":2}]	20233	delivery	5	17
79963	2020-06-17 14:15:45	2020-06-17	17	[{"id_menu":4,"count":1}]	27725	delivery	5	22
79964	2020-06-17 14:22:11	2020-06-17	17	[{"id_menu":4,"count":1}]	11969	pick-up	0	17
79965	2020-06-17 14:22:44	2020-06-17	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	11046	delivery	5	34
79966	2020-06-17 14:25:52	2020-06-17	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31310	delivery	5	31
79967	2020-06-17 14:26:34	2020-06-17	17	[{"id_menu":4,"count":1}]	2631	pick-up	0	17
79968	2020-06-17 14:28:23	2020-06-17	9	[{"id_menu":6,"count":1}]	12062	delivery	5	14
79969	2020-06-17 14:28:39	2020-06-17	12	[{"id_menu":3,"count":1}]	8024	delivery	5	17
79970	2020-06-17 14:28:58	2020-06-17	17	[{"id_menu":4,"count":1}]	3614	delivery	5	22
79971	2020-06-17 14:28:59	2020-06-17	9	[{"id_menu":7,"count":1}]	31297	delivery	5	14
79972	2020-06-17 14:29:27	2020-06-17	8	[{"id_menu":5,"count":1}]	10122	delivery	5	13
79973	2020-06-17 14:32:54	2020-06-17	12	[{"id_menu":3,"count":1}]	14615	delivery	5	17
79974	2020-06-17 14:33:20	2020-06-17	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	1444	delivery	5	22
79975	2020-06-17 14:41:23	2020-06-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	340	delivery	5	28
79976	2020-06-17 14:45:23	2020-06-17	17	[{"id_menu":4,"count":1}]	8905	delivery	5	22
79977	2020-06-17 14:49:24	2020-06-17	9	[{"id_menu":7,"count":1}]	31323	delivery	5	14
79978	2020-06-17 14:49:27	2020-06-17	9	[{"id_menu":6,"count":1}]	2153	delivery	5	14
79979	2020-06-17 14:51:55	2020-06-17	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	31404	delivery	5	40
79980	2020-06-17 14:52:10	2020-06-17	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	25941	delivery	5	31
79981	2020-06-17 14:53:02	2020-06-17	12	[{"id_menu":3,"count":1}]	31418	delivery	5	17
79982	2020-06-17 14:53:56	2020-06-17	9	[{"id_menu":7,"count":1}]	20505	delivery	5	14
79983	2020-06-17 14:57:25	2020-06-17	12	[{"id_menu":3,"count":1}]	20358	delivery	5	17
79984	2020-06-17 14:59:23	2020-06-17	14	[{"id_menu":2,"count":1}]	3940	delivery	5	19
79985	2020-06-17 15:00:38	2020-06-17	9	[{"id_menu":6,"count":1}]	8478	delivery	5	14
79986	2020-06-17 15:00:46	2020-06-17	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	31387	delivery	5	43
79987	2020-06-17 15:01:55	2020-06-17	8	[{"id_menu":5,"count":1}]	1859	pick-up	0	8
79988	2020-06-17 15:01:56	2020-06-17	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10435	delivery	5	22
79989	2020-06-17 15:02:57	2020-06-17	12	[{"id_menu":3,"count":1}]	27752	delivery	5	17
79990	2020-06-17 15:05:27	2020-06-17	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31370	delivery	5	34
79991	2020-06-17 15:08:50	2020-06-17	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	7719	delivery	5	34
79992	2020-06-17 15:09:05	2020-06-17	17	[{"id_menu":4,"count":1}]	31301	delivery	5	22
79993	2020-06-17 15:09:59	2020-06-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29436	delivery	5	23
79994	2020-06-17 15:25:40	2020-06-17	17	[{"id_menu":4,"count":1}]	31385	delivery	5	22
79995	2020-06-17 15:29:53	2020-06-17	14	[{"id_menu":2,"count":1}]	2283	pick-up	0	14
79996	2020-06-17 15:36:23	2020-06-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	17094	delivery	5	28
79997	2020-06-17 15:38:55	2020-06-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	31461	delivery	5	31
79998	2020-06-17 15:39:16	2020-06-17	9	[{"id_menu":6,"count":1}]	25954	pick-up	0	9
79999	2020-06-17 15:40:22	2020-06-17	12	[{"id_menu":1,"count":1}]	14133	pick-up	0	12
80000	2020-06-17 15:41:48	2020-06-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":3}]	31400	delivery	5	23
80001	2020-06-17 15:47:37	2020-06-17	17	[{"id_menu":4,"count":1}]	20407	delivery	5	22
80002	2020-06-17 15:51:56	2020-06-17	12	[{"id_menu":3,"count":1}]	31346	delivery	5	17
80003	2020-06-17 15:55:21	2020-06-17	12	[{"id_menu":3,"count":1}]	31390	delivery	5	17
80004	2020-06-17 15:57:46	2020-06-17	9	[{"id_menu":6,"count":1}]	29348	delivery	5	14
80005	2020-06-17 15:59:21	2020-06-17	14	[{"id_menu":2,"count":1}]	7098	delivery	5	19
80006	2020-06-17 15:59:37	2020-06-17	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27051	delivery	5	37
80007	2020-06-17 16:04:45	2020-06-17	9	[{"id_menu":7,"count":1}]	31443	delivery	5	14
80008	2020-06-17 16:10:01	2020-06-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	18166	delivery	5	28
80009	2020-06-17 16:11:03	2020-06-17	14	[{"id_menu":2,"count":1}]	17668	pick-up	0	14
80010	2020-06-17 16:19:02	2020-06-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2517	pick-up	0	23
80011	2020-06-17 16:19:50	2020-06-17	17	[{"id_menu":4,"count":1}]	30909	pick-up	0	17
80012	2020-06-17 16:31:21	2020-06-17	9	[{"id_menu":6,"count":1}]	660	pick-up	0	9
80013	2020-06-17 16:35:53	2020-06-17	14	[{"id_menu":2,"count":1}]	31456	delivery	5	19
80014	2020-06-17 16:44:16	2020-06-17	9	[{"id_menu":7,"count":1}]	15991	pick-up	0	9
80015	2020-06-17 16:48:28	2020-06-17	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	26919	delivery	5	46
80016	2020-06-17 16:49:43	2020-06-17	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	6976	delivery	5	27
80017	2020-06-17 16:53:09	2020-06-17	17	[{"id_menu":4,"count":1}]	31325	pick-up	0	17
80018	2020-06-17 16:53:34	2020-06-17	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	14025	pick-up	0	25
80019	2020-06-17 16:54:57	2020-06-17	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	27010	delivery	5	34
80020	2020-06-17 16:57:00	2020-06-17	17	[{"id_menu":4,"count":1}]	3205	pick-up	0	17
80021	2020-06-17 17:03:28	2020-06-17	8	[{"id_menu":5,"count":1}]	1326	pick-up	0	8
80022	2020-06-17 17:07:50	2020-06-17	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	31372	delivery	5	48
80023	2020-06-17 17:09:39	2020-06-17	12	[{"id_menu":1,"count":1}]	21480	delivery	5	17
80024	2020-06-17 17:16:17	2020-06-17	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31314	delivery	5	22
80025	2020-06-17 17:19:08	2020-06-17	9	[{"id_menu":7,"count":1}]	31424	delivery	5	14
80026	2020-06-17 17:21:18	2020-06-17	9	[{"id_menu":6,"count":1}]	24427	delivery	5	14
80027	2020-06-17 17:21:28	2020-06-17	8	[{"id_menu":5,"count":1}]	10244	delivery	5	13
80028	2020-06-17 17:25:41	2020-06-17	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2119	delivery	5	26
80029	2020-06-17 17:26:11	2020-06-17	8	[{"id_menu":5,"count":1}]	8149	delivery	5	13
80030	2020-06-17 17:31:00	2020-06-17	9	[{"id_menu":7,"count":2}]	31326	delivery	5	14
80031	2020-06-17 17:32:30	2020-06-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	12712	delivery	5	28
80032	2020-06-17 17:34:59	2020-06-17	9	[{"id_menu":6,"count":1}]	24105	pick-up	0	9
80033	2020-06-17 17:35:10	2020-06-17	12	[{"id_menu":3,"count":2}]	20748	delivery	5	17
80034	2020-06-17 17:35:55	2020-06-17	9	[{"id_menu":6,"count":1}]	1870	pick-up	0	9
80035	2020-06-17 17:36:12	2020-06-17	14	[{"id_menu":2,"count":1}]	8326	pick-up	0	14
80036	2020-06-17 17:40:20	2020-06-17	9	[{"id_menu":6,"count":1}]	22114	delivery	5	14
80037	2020-06-17 17:40:39	2020-06-17	9	[{"id_menu":6,"count":1}]	31386	delivery	5	14
80038	2020-06-17 17:42:51	2020-06-17	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	23457	delivery	5	43
80039	2020-06-17 17:43:16	2020-06-17	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	29988	pick-up	0	22
80040	2020-06-17 17:46:28	2020-06-17	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1905	pick-up	0	20
80041	2020-06-17 17:54:14	2020-06-17	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	11565	delivery	5	34
80042	2020-06-17 17:54:33	2020-06-17	39	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	31440	delivery	5	44
80043	2020-06-17 17:55:53	2020-06-17	8	[{"id_menu":5,"count":1}]	27907	delivery	5	13
80044	2020-06-17 17:56:25	2020-06-17	14	[{"id_menu":2,"count":1}]	2885	delivery	5	19
80045	2020-06-17 18:00:29	2020-06-17	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	3373	pick-up	0	26
80046	2020-06-17 18:00:50	2020-06-17	17	[{"id_menu":4,"count":1}]	12442	delivery	5	22
80047	2020-06-17 18:01:14	2020-06-17	17	[{"id_menu":4,"count":1}]	3825	pick-up	0	17
80048	2020-06-17 18:03:33	2020-06-17	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9001	delivery	5	49
80049	2020-06-17 18:06:15	2020-06-17	17	[{"id_menu":4,"count":1}]	6444	delivery	5	22
80050	2020-06-17 18:09:22	2020-06-17	14	[{"id_menu":2,"count":1}]	31380	delivery	5	19
80051	2020-06-17 18:09:25	2020-06-17	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	31416	delivery	5	31
80052	2020-06-17 18:11:55	2020-06-17	9	[{"id_menu":7,"count":1}]	29847	delivery	5	14
80053	2020-06-17 18:13:01	2020-06-17	9	[{"id_menu":6,"count":1}]	29746	delivery	5	14
80054	2020-06-17 18:14:16	2020-06-17	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	31437	delivery	5	34
80055	2020-06-17 18:14:58	2020-06-17	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2661	delivery	5	22
80056	2020-06-17 18:17:10	2020-06-17	8	[{"id_menu":5,"count":1}]	31449	delivery	5	13
80057	2020-06-17 18:17:57	2020-06-17	14	[{"id_menu":2,"count":1}]	15502	delivery	5	19
80058	2020-06-17 18:21:13	2020-06-17	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	31383	delivery	5	31
80059	2020-06-17 18:25:00	2020-06-17	9	[{"id_menu":6,"count":1}]	31374	delivery	5	14
80060	2020-06-17 18:27:09	2020-06-17	9	[{"id_menu":7,"count":1}]	29697	delivery	5	14
80061	2020-06-17 18:30:41	2020-06-17	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	24188	delivery	5	27
80062	2020-06-17 18:31:07	2020-06-17	12	[{"id_menu":3,"count":1}]	23152	delivery	5	17
80063	2020-06-17 18:40:30	2020-06-17	14	[{"id_menu":2,"count":1}]	7880	pick-up	0	14
80064	2020-06-17 18:45:18	2020-06-17	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6017	delivery	5	30
80065	2020-06-17 18:50:13	2020-06-17	9	[{"id_menu":7,"count":1}]	31307	delivery	5	14
80066	2020-06-17 18:50:26	2020-06-17	12	[{"id_menu":1,"count":1}]	31436	delivery	5	17
80067	2020-06-17 18:53:59	2020-06-17	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	31371	delivery	5	26
80068	2020-06-17 18:55:30	2020-06-17	9	[{"id_menu":6,"count":2}]	31468	delivery	5	14
80069	2020-06-17 18:57:52	2020-06-17	8	[{"id_menu":5,"count":1}]	31402	delivery	5	13
80070	2020-06-17 19:00:36	2020-06-17	14	[{"id_menu":2,"count":1}]	31472	delivery	5	19
80071	2020-06-17 19:00:38	2020-06-17	12	[{"id_menu":1,"count":1}]	2663	delivery	5	17
80072	2020-06-17 19:07:35	2020-06-17	12	[{"id_menu":1,"count":1}]	12841	delivery	5	17
80073	2020-06-17 19:15:05	2020-06-17	9	[{"id_menu":7,"count":1}]	23617	delivery	5	14
80074	2020-06-17 19:15:22	2020-06-17	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	31306	delivery	5	26
80075	2020-06-17 19:20:21	2020-06-17	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	31317	delivery	5	36
80076	2020-06-17 19:20:34	2020-06-17	12	[{"id_menu":3,"count":1}]	21634	pick-up	0	12
80077	2020-06-17 19:25:12	2020-06-17	9	[{"id_menu":6,"count":1}]	16170	delivery	5	14
80078	2020-06-17 19:25:22	2020-06-17	8	[{"id_menu":5,"count":1}]	31302	delivery	5	13
80079	2020-06-17 19:25:49	2020-06-17	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31349	delivery	5	43
80080	2020-06-17 19:25:59	2020-06-17	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	23218	delivery	5	34
80081	2020-06-17 19:30:31	2020-06-17	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1656	pick-up	0	17
80082	2020-06-17 19:30:35	2020-06-17	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	31294	delivery	5	26
80083	2020-06-17 19:33:41	2020-06-17	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	31338	delivery	5	26
80084	2020-06-17 19:37:15	2020-06-17	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	13001	delivery	5	31
80085	2020-06-17 19:39:59	2020-06-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31467	delivery	5	23
80086	2020-06-17 19:42:29	2020-06-17	9	[{"id_menu":6,"count":1}]	28082	delivery	5	14
80087	2020-06-17 19:45:41	2020-06-17	9	[{"id_menu":7,"count":1}]	21645	delivery	5	14
80088	2020-06-17 19:46:59	2020-06-17	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	31355	delivery	5	40
80089	2020-06-17 19:49:39	2020-06-17	9	[{"id_menu":6,"count":1}]	16831	delivery	5	14
80090	2020-06-17 19:52:11	2020-06-17	9	[{"id_menu":7,"count":1}]	15674	delivery	5	14
80091	2020-06-17 19:55:19	2020-06-17	17	[{"id_menu":4,"count":1}]	12070	pick-up	0	17
80092	2020-06-17 19:55:51	2020-06-17	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	2089	delivery	5	40
80093	2020-06-17 20:00:03	2020-06-17	9	[{"id_menu":6,"count":1}]	12583	delivery	5	14
80094	2020-06-17 20:00:43	2020-06-17	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5306	pick-up	0	17
80095	2020-06-17 20:01:23	2020-06-17	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	25804	delivery	5	40
80096	2020-06-17 20:03:02	2020-06-17	9	[{"id_menu":7,"count":1}]	17156	delivery	5	14
80097	2020-06-17 20:14:40	2020-06-17	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7439	delivery	5	52
80098	2020-06-17 20:14:42	2020-06-17	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	29414	delivery	5	22
80099	2020-06-17 20:16:35	2020-06-17	9	[{"id_menu":7,"count":1}]	2342	delivery	5	14
80100	2020-06-17 20:18:47	2020-06-17	8	[{"id_menu":5,"count":1}]	8694	delivery	5	13
80101	2020-06-17 20:18:53	2020-06-17	9	[{"id_menu":6,"count":1}]	22921	delivery	5	14
80102	2020-06-17 20:19:37	2020-06-17	9	[{"id_menu":7,"count":1}]	11682	pick-up	0	9
80103	2020-06-17 20:24:09	2020-06-17	8	[{"id_menu":5,"count":1}]	7212	delivery	5	13
80104	2020-06-17 20:28:23	2020-06-17	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	29766	pick-up	0	20
80105	2020-06-17 20:29:41	2020-06-17	17	[{"id_menu":4,"count":1}]	1677	delivery	5	22
80106	2020-06-17 20:29:49	2020-06-17	8	[{"id_menu":5,"count":1}]	13731	delivery	5	13
80107	2020-06-17 20:30:25	2020-06-17	17	[{"id_menu":4,"count":1}]	5189	pick-up	0	17
80108	2020-06-17 20:36:10	2020-06-17	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	22961	delivery	5	34
80109	2020-06-17 20:38:04	2020-06-17	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	18450	delivery	5	31
80110	2020-06-17 20:48:17	2020-06-17	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	26630	delivery	5	43
80111	2020-06-17 20:49:12	2020-06-17	17	[{"id_menu":4,"count":1}]	13303	delivery	5	22
80112	2020-06-17 20:52:51	2020-06-17	12	[{"id_menu":3,"count":1}]	5963	delivery	5	17
80113	2020-06-17 20:52:55	2020-06-17	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26965	delivery	5	31
80114	2020-06-17 20:57:56	2020-06-17	9	[{"id_menu":7,"count":1}]	31362	delivery	5	14
80115	2020-06-17 20:58:32	2020-06-17	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31300	delivery	5	37
80116	2020-06-17 21:01:01	2020-06-17	8	[{"id_menu":5,"count":1}]	27773	delivery	5	13
80117	2020-06-17 21:01:03	2020-06-17	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	31448	delivery	5	43
80118	2020-06-17 21:02:37	2020-06-17	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	27703	delivery	5	40
80119	2020-06-17 21:06:22	2020-06-17	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31365	delivery	5	52
80120	2020-06-17 21:09:26	2020-06-17	8	[{"id_menu":5,"count":1}]	27618	delivery	5	13
80121	2020-06-17 21:14:09	2020-06-17	14	[{"id_menu":2,"count":1}]	18687	delivery	5	19
80122	2020-06-17 21:18:47	2020-06-17	17	[{"id_menu":4,"count":1}]	7330	pick-up	0	17
80123	2020-06-17 21:23:52	2020-06-17	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31432	delivery	5	51
80124	2020-06-17 21:27:10	2020-06-17	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11215	delivery	5	31
80125	2020-06-17 21:30:04	2020-06-17	14	[{"id_menu":2,"count":1}]	1307	pick-up	0	14
80126	2020-06-17 21:30:44	2020-06-17	8	[{"id_menu":5,"count":1}]	31403	delivery	5	13
80127	2020-06-17 21:31:22	2020-06-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5286	pick-up	0	26
80128	2020-06-17 21:43:09	2020-06-17	12	[{"id_menu":1,"count":1}]	31292	delivery	5	17
80129	2020-06-17 21:44:54	2020-06-17	12	[{"id_menu":3,"count":1}]	29742	pick-up	0	12
80130	2020-06-17 21:49:03	2020-06-17	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	8866	delivery	5	31
80131	2020-06-17 21:51:31	2020-06-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	31361	delivery	5	28
80132	2020-06-17 21:51:57	2020-06-17	17	[{"id_menu":4,"count":1}]	7832	delivery	5	22
80133	2020-06-17 21:53:22	2020-06-17	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13767	delivery	5	36
80134	2020-06-17 22:00:03	2020-06-17	8	[{"id_menu":5,"count":1}]	22477	pick-up	0	8
80135	2020-06-17 22:00:47	2020-06-17	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	6862	pick-up	0	21
80136	2020-06-17 22:05:08	2020-06-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	11486	delivery	5	28
80137	2020-06-17 22:08:24	2020-06-17	12	[{"id_menu":1,"count":1}]	15666	delivery	5	17
80138	2020-06-17 22:13:09	2020-06-17	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	31296	delivery	5	26
80139	2020-06-17 22:14:09	2020-06-17	43	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2651	delivery	5	48
80140	2020-06-17 22:23:16	2020-06-17	17	[{"id_menu":4,"count":1}]	23241	pick-up	0	17
80141	2020-06-17 22:23:20	2020-06-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	22539	pick-up	0	23
80142	2020-06-17 22:23:28	2020-06-17	17	[{"id_menu":4,"count":1}]	11189	delivery	5	22
80143	2020-06-17 22:28:59	2020-06-17	17	[{"id_menu":4,"count":1}]	18156	delivery	5	22
80144	2020-06-17 22:31:22	2020-06-17	14	[{"id_menu":2,"count":1}]	31442	delivery	5	19
80145	2020-06-17 22:34:55	2020-06-17	9	[{"id_menu":7,"count":1}]	11156	pick-up	0	9
80146	2020-06-17 22:36:34	2020-06-17	8	[{"id_menu":5,"count":1}]	28007	delivery	5	13
80147	2020-06-17 22:37:06	2020-06-17	9	[{"id_menu":6,"count":1}]	5638	delivery	5	14
80148	2020-06-17 22:40:25	2020-06-17	12	[{"id_menu":3,"count":1}]	31377	delivery	5	17
80149	2020-06-17 22:42:22	2020-06-17	17	[{"id_menu":4,"count":1}]	23665	delivery	5	22
80150	2020-06-17 22:43:28	2020-06-17	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	18927	delivery	5	34
80151	2020-06-17 22:46:11	2020-06-17	17	[{"id_menu":4,"count":1}]	515	pick-up	0	17
80152	2020-06-17 22:47:00	2020-06-17	12	[{"id_menu":1,"count":1}]	25015	pick-up	0	12
80153	2020-06-17 22:47:21	2020-06-17	14	[{"id_menu":2,"count":1}]	10755	pick-up	0	14
80154	2020-06-17 22:48:24	2020-06-17	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	11594	delivery	5	34
80155	2020-06-17 22:48:39	2020-06-17	9	[{"id_menu":6,"count":1}]	31378	delivery	5	14
80156	2020-06-17 22:51:33	2020-06-17	14	[{"id_menu":2,"count":2}]	15273	delivery	5	19
80157	2020-06-17 22:52:00	2020-06-17	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31368	delivery	5	22
80158	2020-06-17 22:55:10	2020-06-17	8	[{"id_menu":5,"count":1}]	21365	delivery	5	13
80159	2020-06-17 22:57:47	2020-06-17	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31381	delivery	5	31
80160	2020-06-17 22:59:55	2020-06-17	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	163	pick-up	0	38
80161	2020-06-17 23:05:35	2020-06-17	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31343	delivery	5	22
80162	2020-06-17 23:05:56	2020-06-17	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	31340	delivery	5	43
80163	2020-06-17 23:06:32	2020-06-17	14	[{"id_menu":2,"count":1}]	385	delivery	5	19
80164	2020-06-17 23:10:24	2020-06-17	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25505	delivery	5	37
80165	2020-06-17 23:10:29	2020-06-17	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2507	delivery	5	38
80166	2020-06-17 23:10:35	2020-06-17	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	31392	delivery	5	22
80167	2020-06-17 23:12:09	2020-06-17	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	30879	delivery	5	22
80168	2020-06-17 23:12:36	2020-06-17	14	[{"id_menu":2,"count":1}]	29713	delivery	5	19
80169	2020-06-17 23:15:39	2020-06-17	17	[{"id_menu":4,"count":1}]	12506	pick-up	0	17
80170	2020-06-17 23:16:43	2020-06-17	9	[{"id_menu":6,"count":1}]	14722	pick-up	0	9
80171	2020-06-17 23:19:25	2020-06-17	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28930	delivery	5	22
80172	2020-06-17 23:20:12	2020-06-17	9	[{"id_menu":7,"count":1}]	31351	pick-up	0	9
80173	2020-06-17 23:20:43	2020-06-17	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	20038	delivery	5	30
80174	2020-06-17 23:21:00	2020-06-17	12	[{"id_menu":1,"count":1}]	31444	delivery	5	17
80175	2020-06-17 23:24:35	2020-06-17	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31446	delivery	5	35
80176	2020-06-17 23:25:11	2020-06-17	12	[{"id_menu":3,"count":1}]	24829	delivery	5	17
80177	2020-06-17 23:29:02	2020-06-17	9	[{"id_menu":6,"count":1}]	14982	pick-up	0	9
80178	2020-06-17 23:33:03	2020-06-17	17	[{"id_menu":4,"count":1}]	15780	pick-up	0	17
80179	2020-06-17 23:37:17	2020-06-17	9	[{"id_menu":7,"count":1}]	818	pick-up	0	9
80180	2020-06-17 23:38:14	2020-06-17	12	[{"id_menu":1,"count":1}]	31391	delivery	5	17
80181	2020-06-17 23:38:18	2020-06-17	8	[{"id_menu":5,"count":1}]	27567	delivery	5	13
80182	2020-06-17 23:39:13	2020-06-17	9	[{"id_menu":6,"count":1}]	4172	delivery	5	14
80183	2020-06-17 23:39:40	2020-06-17	12	[{"id_menu":3,"count":3}]	15907	pick-up	0	12
80184	2020-06-17 23:40:32	2020-06-17	9	[{"id_menu":7,"count":1}]	11222	delivery	5	14
80185	2020-06-17 23:43:52	2020-06-17	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":2}]	12433	delivery	5	31
80186	2020-06-17 23:50:08	2020-06-17	17	[{"id_menu":4,"count":1}]	10918	pick-up	0	17
80187	2020-06-17 23:51:49	2020-06-17	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	209	pick-up	0	25
80188	2020-06-17 23:53:16	2020-06-17	12	[{"id_menu":1,"count":1}]	1025	pick-up	0	12
80189	2020-06-17 23:53:49	2020-06-17	8	[{"id_menu":5,"count":1}]	7830	delivery	5	13
80190	2020-06-17 23:53:52	2020-06-17	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	29800	delivery	5	26
80191	2020-06-17 23:55:04	2020-06-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28345	delivery	5	23
80192	2020-06-17 23:56:10	2020-06-17	9	[{"id_menu":6,"count":1}]	7297	pick-up	0	9
80193	2020-06-18 00:00:19	2020-06-18	12	[{"id_menu":1,"count":1}]	23614	delivery	5	17
80194	2020-06-18 00:06:51	2020-06-18	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31525	delivery	5	53
80195	2020-06-18 00:11:19	2020-06-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4577	pick-up	0	23
80196	2020-06-18 00:13:49	2020-06-18	8	[{"id_menu":5,"count":1}]	4913	delivery	5	13
80197	2020-06-18 00:16:10	2020-06-18	9	[{"id_menu":6,"count":1}]	31664	pick-up	0	9
80198	2020-06-18 00:24:38	2020-06-18	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25071	delivery	5	35
80199	2020-06-18 00:28:42	2020-06-18	14	[{"id_menu":2,"count":1}]	31499	delivery	5	19
80200	2020-06-18 00:29:34	2020-06-18	12	[{"id_menu":3,"count":1}]	31512	delivery	5	17
80201	2020-06-18 00:29:59	2020-06-18	9	[{"id_menu":6,"count":1}]	31632	delivery	5	14
80202	2020-06-18 00:30:09	2020-06-18	12	[{"id_menu":3,"count":1}]	31583	delivery	5	17
80203	2020-06-18 00:32:28	2020-06-18	14	[{"id_menu":2,"count":1}]	1900	pick-up	0	14
80204	2020-06-18 00:32:44	2020-06-18	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	30464	delivery	5	31
80205	2020-06-18 00:33:21	2020-06-18	14	[{"id_menu":2,"count":1}]	19813	delivery	5	19
80206	2020-06-18 00:33:57	2020-06-18	8	[{"id_menu":5,"count":1}]	30128	delivery	5	13
80207	2020-06-18 00:42:47	2020-06-18	12	[{"id_menu":3,"count":1}]	10434	delivery	5	17
80208	2020-06-18 00:46:57	2020-06-18	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	31543	delivery	5	31
80209	2020-06-18 00:47:18	2020-06-18	14	[{"id_menu":2,"count":1}]	3782	pick-up	0	14
80210	2020-06-18 00:51:10	2020-06-18	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	31685	delivery	5	28
80211	2020-06-18 00:51:54	2020-06-18	8	[{"id_menu":5,"count":1}]	10584	delivery	5	13
80212	2020-06-18 00:57:06	2020-06-18	8	[{"id_menu":5,"count":1}]	31655	delivery	5	13
80213	2020-06-18 00:58:06	2020-06-18	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	31645	delivery	5	30
80214	2020-06-18 00:58:41	2020-06-18	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	8536	delivery	5	26
80215	2020-06-18 01:04:39	2020-06-18	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14590	delivery	5	35
80216	2020-06-18 01:05:22	2020-06-18	9	[{"id_menu":6,"count":1}]	31520	delivery	5	14
80217	2020-06-18 01:07:32	2020-06-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	26002	delivery	5	22
80218	2020-06-18 01:10:31	2020-06-18	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	10442	delivery	5	37
80219	2020-06-18 01:11:21	2020-06-18	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15897	delivery	5	35
80220	2020-06-18 01:14:36	2020-06-18	9	[{"id_menu":7,"count":1}]	1568	delivery	5	14
80221	2020-06-18 01:14:57	2020-06-18	12	[{"id_menu":3,"count":1}]	14392	pick-up	0	12
80222	2020-06-18 01:16:00	2020-06-18	8	[{"id_menu":5,"count":1}]	29127	pick-up	0	8
80223	2020-06-18 01:16:07	2020-06-18	14	[{"id_menu":2,"count":1}]	31580	delivery	5	19
80224	2020-06-18 01:19:30	2020-06-18	14	[{"id_menu":2,"count":1}]	31619	delivery	5	19
80225	2020-06-18 01:20:42	2020-06-18	9	[{"id_menu":6,"count":2}]	3940	pick-up	0	9
80226	2020-06-18 01:22:07	2020-06-18	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	31056	delivery	5	44
80227	2020-06-18 01:23:11	2020-06-18	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31498	delivery	5	52
80228	2020-06-18 01:25:04	2020-06-18	14	[{"id_menu":2,"count":1}]	31546	pick-up	0	14
80229	2020-06-18 01:25:12	2020-06-18	12	[{"id_menu":1,"count":1}]	8065	pick-up	0	12
80230	2020-06-18 01:25:23	2020-06-18	9	[{"id_menu":7,"count":1}]	4391	delivery	5	14
80231	2020-06-18 01:25:39	2020-06-18	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	31563	delivery	5	40
80232	2020-06-18 01:27:49	2020-06-18	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18033	delivery	5	34
80233	2020-06-18 01:29:50	2020-06-18	12	[{"id_menu":3,"count":1}]	30366	delivery	5	17
80234	2020-06-18 01:31:03	2020-06-18	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	7802	delivery	5	26
80235	2020-06-18 01:31:21	2020-06-18	12	[{"id_menu":3,"count":1}]	31515	delivery	5	17
80236	2020-06-18 01:33:17	2020-06-18	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3676	delivery	5	40
80237	2020-06-18 01:33:35	2020-06-18	17	[{"id_menu":4,"count":1}]	30622	delivery	5	22
80238	2020-06-18 01:37:50	2020-06-18	17	[{"id_menu":4,"count":1}]	3463	delivery	5	22
80239	2020-06-18 01:38:51	2020-06-18	9	[{"id_menu":6,"count":1}]	14753	delivery	5	14
80240	2020-06-18 01:40:52	2020-06-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	30866	delivery	5	28
80241	2020-06-18 01:46:29	2020-06-18	9	[{"id_menu":7,"count":1}]	31653	delivery	5	14
80242	2020-06-18 01:47:15	2020-06-18	14	[{"id_menu":2,"count":1}]	31640	delivery	5	19
80243	2020-06-18 01:47:40	2020-06-18	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1183	pick-up	0	26
80244	2020-06-18 01:49:31	2020-06-18	9	[{"id_menu":7,"count":1}]	22735	delivery	5	14
80245	2020-06-18 01:50:37	2020-06-18	9	[{"id_menu":6,"count":1}]	2429	pick-up	0	9
80246	2020-06-18 01:51:36	2020-06-18	9	[{"id_menu":6,"count":1}]	29175	pick-up	0	9
80247	2020-06-18 01:52:37	2020-06-18	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	31586	delivery	5	43
80248	2020-06-18 01:59:00	2020-06-18	14	[{"id_menu":2,"count":1}]	26045	delivery	5	19
80249	2020-06-18 02:00:04	2020-06-18	12	[{"id_menu":3,"count":2}]	3320	pick-up	0	12
80250	2020-06-18 02:03:02	2020-06-18	9	[{"id_menu":7,"count":1}]	31489	delivery	5	14
80251	2020-06-18 02:03:02	2020-06-18	9	[{"id_menu":6,"count":1}]	31591	delivery	5	14
80252	2020-06-18 02:04:02	2020-06-18	14	[{"id_menu":2,"count":1}]	31612	delivery	5	19
80253	2020-06-18 02:06:51	2020-06-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	31559	delivery	5	28
80254	2020-06-18 02:12:46	2020-06-18	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	10023	delivery	5	40
80255	2020-06-18 02:12:48	2020-06-18	8	[{"id_menu":5,"count":1}]	7924	delivery	5	13
80256	2020-06-18 02:18:22	2020-06-18	8	[{"id_menu":5,"count":1}]	2846	delivery	5	13
80257	2020-06-18 02:19:41	2020-06-18	8	[{"id_menu":5,"count":1}]	31551	delivery	5	13
80258	2020-06-18 02:23:54	2020-06-18	9	[{"id_menu":7,"count":2}]	20503	pick-up	0	9
80259	2020-06-18 02:38:42	2020-06-18	12	[{"id_menu":1,"count":1}]	10315	pick-up	0	12
80260	2020-06-18 02:40:28	2020-06-18	12	[{"id_menu":1,"count":1}]	28105	delivery	5	17
80261	2020-06-18 02:40:45	2020-06-18	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31585	delivery	5	37
80262	2020-06-18 02:41:44	2020-06-18	12	[{"id_menu":1,"count":1}]	31570	pick-up	0	12
80263	2020-06-18 02:42:07	2020-06-18	14	[{"id_menu":2,"count":1}]	16952	delivery	5	19
80264	2020-06-18 02:45:09	2020-06-18	8	[{"id_menu":5,"count":1}]	25337	pick-up	0	8
80265	2020-06-18 02:47:45	2020-06-18	14	[{"id_menu":2,"count":1}]	14490	delivery	5	19
80266	2020-06-18 02:48:25	2020-06-18	14	[{"id_menu":2,"count":1}]	31532	delivery	5	19
80267	2020-06-18 02:51:27	2020-06-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	31576	delivery	5	28
80268	2020-06-18 02:53:08	2020-06-18	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	17054	delivery	5	26
80269	2020-06-18 02:53:34	2020-06-18	9	[{"id_menu":7,"count":1}]	28615	delivery	5	14
80270	2020-06-18 02:55:49	2020-06-18	14	[{"id_menu":2,"count":1}]	15907	delivery	5	19
80271	2020-06-18 02:56:09	2020-06-18	9	[{"id_menu":6,"count":1}]	31351	delivery	5	14
80272	2020-06-18 02:58:55	2020-06-18	9	[{"id_menu":6,"count":1}]	5930	delivery	5	14
80273	2020-06-18 03:01:35	2020-06-18	9	[{"id_menu":7,"count":1}]	21461	delivery	5	14
80274	2020-06-18 03:06:00	2020-06-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	31600	delivery	5	23
80275	2020-06-18 03:09:30	2020-06-18	9	[{"id_menu":6,"count":1}]	31571	pick-up	0	9
80276	2020-06-18 03:09:48	2020-06-18	17	[{"id_menu":4,"count":1}]	1360	delivery	5	22
80277	2020-06-18 03:10:33	2020-06-18	8	[{"id_menu":5,"count":1}]	31533	delivery	5	13
80278	2020-06-18 03:12:17	2020-06-18	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	14747	delivery	5	34
80279	2020-06-18 03:13:28	2020-06-18	12	[{"id_menu":3,"count":1}]	20898	delivery	5	17
80280	2020-06-18 03:13:36	2020-06-18	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31521	delivery	5	31
80281	2020-06-18 03:21:04	2020-06-18	23	[{"id_menu":2,"count":3},{"id_menu":6,"count":1}]	31650	delivery	5	28
80282	2020-06-18 03:23:01	2020-06-18	17	[{"id_menu":4,"count":1}]	17610	delivery	5	22
80283	2020-06-18 03:26:50	2020-06-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	24691	delivery	5	23
80284	2020-06-18 03:28:46	2020-06-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3221	delivery	5	28
80285	2020-06-18 03:30:04	2020-06-18	14	[{"id_menu":2,"count":1}]	19480	delivery	5	19
80286	2020-06-18 03:32:46	2020-06-18	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	12174	delivery	5	29
80287	2020-06-18 03:50:48	2020-06-18	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	31568	delivery	5	26
80288	2020-06-18 03:54:10	2020-06-18	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	4624	delivery	5	26
80289	2020-06-18 03:54:46	2020-06-18	8	[{"id_menu":5,"count":1}]	31596	pick-up	0	8
80290	2020-06-18 03:55:16	2020-06-18	9	[{"id_menu":7,"count":1}]	26610	delivery	5	14
80291	2020-06-18 03:56:51	2020-06-18	17	[{"id_menu":4,"count":1}]	8546	pick-up	0	17
80292	2020-06-18 03:57:13	2020-06-18	17	[{"id_menu":4,"count":1}]	31618	delivery	5	22
80293	2020-06-18 03:59:20	2020-06-18	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	31604	delivery	5	31
80294	2020-06-18 04:00:37	2020-06-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31599	delivery	5	22
80295	2020-06-18 04:03:24	2020-06-18	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1056	delivery	5	40
80296	2020-06-18 04:07:00	2020-06-18	14	[{"id_menu":2,"count":1}]	20763	delivery	5	19
80297	2020-06-18 04:07:46	2020-06-18	12	[{"id_menu":1,"count":1}]	31686	delivery	5	17
80298	2020-06-18 04:09:21	2020-06-18	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	29917	delivery	5	26
80299	2020-06-18 04:11:04	2020-06-18	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	19583	delivery	5	26
80300	2020-06-18 04:11:08	2020-06-18	9	[{"id_menu":7,"count":1}]	31615	pick-up	0	9
80301	2020-06-18 04:13:47	2020-06-18	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	31561	delivery	5	31
80302	2020-06-18 04:18:32	2020-06-18	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30837	delivery	5	52
80303	2020-06-18 04:19:32	2020-06-18	9	[{"id_menu":7,"count":1}]	23471	delivery	5	14
80304	2020-06-18 04:21:25	2020-06-18	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	25872	delivery	5	23
80305	2020-06-18 04:22:17	2020-06-18	9	[{"id_menu":7,"count":1}]	25987	delivery	5	14
80306	2020-06-18 04:23:17	2020-06-18	17	[{"id_menu":4,"count":1}]	31567	delivery	5	22
80307	2020-06-18 04:25:16	2020-06-18	9	[{"id_menu":6,"count":1}]	4689	delivery	5	14
80308	2020-06-18 04:30:59	2020-06-18	9	[{"id_menu":7,"count":1}]	5418	delivery	5	14
80309	2020-06-18 04:39:08	2020-06-18	9	[{"id_menu":7,"count":1}]	19978	delivery	5	14
80310	2020-06-18 04:47:07	2020-06-18	9	[{"id_menu":6,"count":1}]	31621	delivery	5	14
80311	2020-06-18 04:47:08	2020-06-18	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	31479	delivery	5	27
80312	2020-06-18 04:51:06	2020-06-18	8	[{"id_menu":5,"count":1}]	2168	delivery	5	13
80313	2020-06-18 04:51:14	2020-06-18	17	[{"id_menu":4,"count":1}]	21680	delivery	5	22
80314	2020-06-18 04:53:28	2020-06-18	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1352	pick-up	0	38
80315	2020-06-18 04:58:12	2020-06-18	14	[{"id_menu":2,"count":1}]	27875	delivery	5	19
80316	2020-06-18 04:59:34	2020-06-18	14	[{"id_menu":2,"count":2}]	11380	delivery	5	19
80317	2020-06-18 05:08:39	2020-06-18	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	19643	delivery	5	31
80318	2020-06-18 05:10:19	2020-06-18	12	[{"id_menu":1,"count":1}]	31637	delivery	5	17
80319	2020-06-18 05:14:37	2020-06-18	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	6496	delivery	5	37
80320	2020-06-18 05:15:17	2020-06-18	17	[{"id_menu":4,"count":1}]	6046	delivery	5	22
80321	2020-06-18 05:17:20	2020-06-18	9	[{"id_menu":7,"count":1}]	7094	delivery	5	14
80322	2020-06-18 05:17:47	2020-06-18	12	[{"id_menu":3,"count":1}]	8521	pick-up	0	12
80323	2020-06-18 05:18:37	2020-06-18	12	[{"id_menu":1,"count":1}]	5186	delivery	5	17
80324	2020-06-18 05:23:14	2020-06-18	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	23984	delivery	5	40
80325	2020-06-18 05:24:16	2020-06-18	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	10880	pick-up	0	21
80326	2020-06-18 05:30:59	2020-06-18	12	[{"id_menu":3,"count":2}]	1754	delivery	5	17
80327	2020-06-18 05:33:03	2020-06-18	9	[{"id_menu":6,"count":1}]	12324	delivery	5	14
80328	2020-06-18 05:33:05	2020-06-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	26909	delivery	5	22
80329	2020-06-18 05:36:34	2020-06-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	31663	delivery	5	28
80330	2020-06-18 05:43:28	2020-06-18	17	[{"id_menu":4,"count":1}]	19331	delivery	5	22
80331	2020-06-18 05:47:52	2020-06-18	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14705	delivery	5	36
80332	2020-06-18 05:49:48	2020-06-18	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	27082	pick-up	0	22
80333	2020-06-18 05:51:50	2020-06-18	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6842	delivery	5	45
80334	2020-06-18 05:52:06	2020-06-18	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	30064	delivery	5	45
80335	2020-06-18 05:54:50	2020-06-18	14	[{"id_menu":2,"count":1}]	31486	pick-up	0	14
80336	2020-06-18 05:55:48	2020-06-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	31488	delivery	5	28
80337	2020-06-18 05:56:51	2020-06-18	12	[{"id_menu":1,"count":2}]	31651	delivery	5	17
80338	2020-06-18 05:57:50	2020-06-18	12	[{"id_menu":3,"count":1}]	5970	pick-up	0	12
80339	2020-06-18 06:01:45	2020-06-18	9	[{"id_menu":7,"count":1}]	7168	delivery	5	14
80340	2020-06-18 06:02:25	2020-06-18	9	[{"id_menu":7,"count":1}]	31526	delivery	5	14
80341	2020-06-18 06:04:16	2020-06-18	9	[{"id_menu":6,"count":2}]	6394	delivery	5	14
80342	2020-06-18 06:06:47	2020-06-18	9	[{"id_menu":6,"count":1}]	11401	pick-up	0	9
80343	2020-06-18 06:07:39	2020-06-18	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	28357	pick-up	0	40
80344	2020-06-18 06:08:11	2020-06-18	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	31670	delivery	5	37
80345	2020-06-18 06:10:02	2020-06-18	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	18917	delivery	5	22
80346	2020-06-18 06:13:03	2020-06-18	12	[{"id_menu":1,"count":1}]	31513	delivery	5	17
80347	2020-06-18 06:14:20	2020-06-18	12	[{"id_menu":1,"count":1}]	2663	delivery	5	17
80348	2020-06-18 06:16:10	2020-06-18	12	[{"id_menu":3,"count":1}]	31644	delivery	5	17
80349	2020-06-18 06:17:49	2020-06-18	17	[{"id_menu":4,"count":1}]	10993	delivery	5	22
80350	2020-06-18 06:20:43	2020-06-18	12	[{"id_menu":1,"count":1}]	9483	pick-up	0	12
80351	2020-06-18 06:22:36	2020-06-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7912	delivery	5	22
80352	2020-06-18 06:23:47	2020-06-18	9	[{"id_menu":7,"count":1}]	31511	delivery	5	14
80353	2020-06-18 06:23:58	2020-06-18	12	[{"id_menu":1,"count":2}]	3512	delivery	5	17
80354	2020-06-18 06:26:27	2020-06-18	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	19726	delivery	5	34
80355	2020-06-18 06:27:55	2020-06-18	12	[{"id_menu":3,"count":1}]	12296	delivery	5	17
80356	2020-06-18 06:28:18	2020-06-18	17	[{"id_menu":4,"count":2}]	23771	delivery	5	22
80357	2020-06-18 06:33:01	2020-06-18	12	[{"id_menu":3,"count":1}]	17503	delivery	5	17
80358	2020-06-18 06:33:25	2020-06-18	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	31648	delivery	5	26
80359	2020-06-18 06:33:27	2020-06-18	9	[{"id_menu":6,"count":1}]	31482	delivery	5	14
80360	2020-06-18 06:33:50	2020-06-18	17	[{"id_menu":4,"count":1}]	271	pick-up	0	17
80361	2020-06-18 06:34:33	2020-06-18	14	[{"id_menu":2,"count":1}]	31584	delivery	5	19
80362	2020-06-18 06:34:42	2020-06-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	31642	delivery	5	28
80363	2020-06-18 06:44:47	2020-06-18	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17780	delivery	5	39
80364	2020-06-18 06:45:37	2020-06-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	31666	delivery	5	28
80365	2020-06-18 06:53:19	2020-06-18	14	[{"id_menu":2,"count":1}]	19281	delivery	5	19
80366	2020-06-18 06:59:37	2020-06-18	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10656	delivery	5	40
80367	2020-06-18 07:01:28	2020-06-18	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	26840	delivery	5	26
80368	2020-06-18 07:07:53	2020-06-18	9	[{"id_menu":6,"count":1}]	11715	pick-up	0	9
80369	2020-06-18 07:10:32	2020-06-18	17	[{"id_menu":4,"count":1}]	12811	delivery	5	22
80370	2020-06-18 07:11:13	2020-06-18	9	[{"id_menu":6,"count":1}]	22478	pick-up	0	9
80371	2020-06-18 07:18:50	2020-06-18	8	[{"id_menu":5,"count":1}]	31668	delivery	5	13
80372	2020-06-18 07:20:50	2020-06-18	9	[{"id_menu":6,"count":1}]	28095	delivery	5	14
80373	2020-06-18 07:20:55	2020-06-18	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10352	delivery	5	34
80374	2020-06-18 07:31:42	2020-06-18	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23238	delivery	5	22
80375	2020-06-18 07:33:10	2020-06-18	12	[{"id_menu":1,"count":1}]	15563	delivery	5	17
80376	2020-06-18 07:34:36	2020-06-18	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	30419	delivery	5	39
80377	2020-06-18 07:34:53	2020-06-18	8	[{"id_menu":5,"count":1}]	23685	delivery	5	13
80378	2020-06-18 07:35:14	2020-06-18	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29566	delivery	5	53
80379	2020-06-18 07:41:57	2020-06-18	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	30188	delivery	5	22
80380	2020-06-18 07:44:19	2020-06-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	31550	delivery	5	28
80381	2020-06-18 07:44:22	2020-06-18	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	7829	delivery	5	22
80382	2020-06-18 07:45:50	2020-06-18	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3647	pick-up	0	26
80383	2020-06-18 07:47:52	2020-06-18	12	[{"id_menu":1,"count":2}]	6054	delivery	5	17
80384	2020-06-18 07:49:21	2020-06-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	28141	delivery	5	23
80385	2020-06-18 07:52:56	2020-06-18	14	[{"id_menu":2,"count":1}]	2321	pick-up	0	14
80386	2020-06-18 07:56:40	2020-06-18	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	25692	delivery	5	45
80387	2020-06-18 07:59:06	2020-06-18	9	[{"id_menu":7,"count":1}]	2752	delivery	5	14
80388	2020-06-18 07:59:45	2020-06-18	9	[{"id_menu":6,"count":1}]	23333	pick-up	0	9
80389	2020-06-18 08:00:05	2020-06-18	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	31665	delivery	5	25
80390	2020-06-18 08:01:51	2020-06-18	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	13592	delivery	5	39
80391	2020-06-18 08:05:51	2020-06-18	14	[{"id_menu":2,"count":1}]	8161	delivery	5	19
80392	2020-06-18 08:08:50	2020-06-18	12	[{"id_menu":3,"count":1}]	31682	delivery	5	17
80393	2020-06-18 08:10:37	2020-06-18	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	17545	delivery	5	35
80394	2020-06-18 08:13:20	2020-06-18	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	10214	delivery	5	30
80395	2020-06-18 08:15:14	2020-06-18	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	31509	pick-up	0	31
80396	2020-06-18 08:16:36	2020-06-18	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15791	delivery	5	31
80397	2020-06-18 08:16:54	2020-06-18	9	[{"id_menu":7,"count":1}]	31522	delivery	5	14
80398	2020-06-18 08:17:09	2020-06-18	12	[{"id_menu":1,"count":1}]	31566	delivery	5	17
80399	2020-06-18 08:18:52	2020-06-18	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	7547	delivery	5	30
80400	2020-06-18 08:20:13	2020-06-18	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	28539	delivery	5	40
80401	2020-06-18 08:25:18	2020-06-18	12	[{"id_menu":3,"count":1}]	31598	delivery	5	17
80402	2020-06-18 08:25:40	2020-06-18	9	[{"id_menu":7,"count":1}]	31514	delivery	5	14
80403	2020-06-18 08:25:56	2020-06-18	9	[{"id_menu":7,"count":1}]	4605	delivery	5	14
80404	2020-06-18 08:27:12	2020-06-18	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	24902	delivery	5	40
80405	2020-06-18 08:27:55	2020-06-18	12	[{"id_menu":3,"count":1}]	1415	pick-up	0	12
80406	2020-06-18 08:31:08	2020-06-18	9	[{"id_menu":7,"count":1}]	31680	delivery	5	14
80407	2020-06-18 08:31:39	2020-06-18	12	[{"id_menu":1,"count":1}]	3051	pick-up	0	12
80408	2020-06-18 08:31:40	2020-06-18	9	[{"id_menu":6,"count":1}]	3527	pick-up	0	9
80409	2020-06-18 08:35:09	2020-06-18	8	[{"id_menu":5,"count":1}]	4044	delivery	5	13
80410	2020-06-18 08:39:11	2020-06-18	12	[{"id_menu":1,"count":1}]	31641	pick-up	0	12
80411	2020-06-18 08:40:21	2020-06-18	12	[{"id_menu":1,"count":1}]	7133	delivery	5	17
80412	2020-06-18 08:41:51	2020-06-18	14	[{"id_menu":2,"count":1}]	31523	delivery	5	19
80413	2020-06-18 08:41:56	2020-06-18	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	10345	pick-up	0	21
80414	2020-06-18 08:42:34	2020-06-18	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":3}]	31524	delivery	5	26
80415	2020-06-18 08:46:56	2020-06-18	12	[{"id_menu":1,"count":1}]	6369	delivery	5	17
80416	2020-06-18 08:49:56	2020-06-18	12	[{"id_menu":3,"count":1}]	31500	pick-up	0	12
80417	2020-06-18 08:56:56	2020-06-18	14	[{"id_menu":2,"count":1}]	8127	delivery	5	19
80418	2020-06-18 08:57:23	2020-06-18	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	26693	delivery	5	43
80419	2020-06-18 08:57:46	2020-06-18	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17429	delivery	5	22
80420	2020-06-18 08:59:15	2020-06-18	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	14027	pick-up	0	29
80421	2020-06-18 08:59:56	2020-06-18	9	[{"id_menu":6,"count":1}]	31505	delivery	5	14
80422	2020-06-18 09:06:24	2020-06-18	12	[{"id_menu":1,"count":1}]	31625	delivery	5	17
80423	2020-06-18 09:08:58	2020-06-18	12	[{"id_menu":1,"count":1}]	17320	delivery	5	17
80424	2020-06-18 09:09:40	2020-06-18	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	31240	delivery	5	34
80425	2020-06-18 09:11:52	2020-06-18	8	[{"id_menu":5,"count":1}]	9770	delivery	5	13
80426	2020-06-18 09:14:49	2020-06-18	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	10842	delivery	5	26
80427	2020-06-18 09:15:42	2020-06-18	9	[{"id_menu":6,"count":1}]	31547	delivery	5	14
80428	2020-06-18 09:17:05	2020-06-18	14	[{"id_menu":2,"count":1}]	31291	delivery	5	19
80429	2020-06-18 09:22:32	2020-06-18	12	[{"id_menu":3,"count":1}]	233	delivery	5	17
80430	2020-06-18 09:22:39	2020-06-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	626	pick-up	0	23
80431	2020-06-18 09:29:54	2020-06-18	9	[{"id_menu":6,"count":1}]	14354	delivery	5	14
80432	2020-06-18 09:30:03	2020-06-18	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1001	pick-up	0	20
80433	2020-06-18 09:30:42	2020-06-18	8	[{"id_menu":5,"count":1}]	31611	delivery	5	13
80434	2020-06-18 09:31:01	2020-06-18	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	31603	delivery	5	25
80435	2020-06-18 09:32:07	2020-06-18	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	31581	pick-up	0	26
80436	2020-06-18 09:32:58	2020-06-18	14	[{"id_menu":2,"count":2}]	16114	delivery	5	19
80437	2020-06-18 09:33:14	2020-06-18	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	5636	delivery	5	36
80438	2020-06-18 09:34:14	2020-06-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	29419	pick-up	0	17
80439	2020-06-18 09:34:21	2020-06-18	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	8640	pick-up	0	21
80440	2020-06-18 09:37:43	2020-06-18	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	16157	delivery	5	34
80441	2020-06-18 09:40:10	2020-06-18	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	31483	delivery	5	34
80442	2020-06-18 09:41:31	2020-06-18	8	[{"id_menu":5,"count":1}]	30488	delivery	5	13
80443	2020-06-18 09:45:39	2020-06-18	9	[{"id_menu":6,"count":1}]	22844	pick-up	0	9
80444	2020-06-18 09:46:14	2020-06-18	8	[{"id_menu":5,"count":1}]	8991	delivery	5	13
80445	2020-06-18 09:46:53	2020-06-18	12	[{"id_menu":1,"count":1}]	31496	delivery	5	17
80446	2020-06-18 09:48:40	2020-06-18	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	31667	delivery	5	27
80447	2020-06-18 09:48:43	2020-06-18	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	20302	delivery	5	31
80448	2020-06-18 09:49:35	2020-06-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	31623	delivery	5	22
80449	2020-06-18 09:50:55	2020-06-18	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	31578	delivery	5	26
80450	2020-06-18 09:52:46	2020-06-18	12	[{"id_menu":3,"count":1}]	23424	pick-up	0	12
80451	2020-06-18 09:59:39	2020-06-18	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	23603	delivery	5	26
80452	2020-06-18 10:00:59	2020-06-18	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	3205	pick-up	0	32
80453	2020-06-18 10:05:21	2020-06-18	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	18057	pick-up	0	24
80454	2020-06-18 10:08:32	2020-06-18	9	[{"id_menu":6,"count":1}]	31472	delivery	5	14
80455	2020-06-18 10:10:21	2020-06-18	8	[{"id_menu":5,"count":1}]	23307	delivery	5	13
80456	2020-06-18 10:12:38	2020-06-18	8	[{"id_menu":5,"count":1}]	3604	pick-up	0	8
80457	2020-06-18 10:14:30	2020-06-18	8	[{"id_menu":5,"count":1}]	31594	delivery	5	13
80458	2020-06-18 10:25:06	2020-06-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	31595	delivery	5	28
80459	2020-06-18 10:25:25	2020-06-18	9	[{"id_menu":7,"count":1}]	458	pick-up	0	9
80460	2020-06-18 10:25:39	2020-06-18	8	[{"id_menu":5,"count":1}]	19027	delivery	5	13
80461	2020-06-18 10:29:58	2020-06-18	8	[{"id_menu":5,"count":2}]	20244	delivery	5	13
80462	2020-06-18 10:30:15	2020-06-18	12	[{"id_menu":3,"count":1}]	31556	delivery	5	17
80463	2020-06-18 10:32:54	2020-06-18	12	[{"id_menu":3,"count":2}]	21025	delivery	5	17
80464	2020-06-18 10:39:27	2020-06-18	17	[{"id_menu":4,"count":1}]	31620	delivery	5	22
80465	2020-06-18 10:39:31	2020-06-18	17	[{"id_menu":4,"count":1}]	27023	delivery	5	22
80466	2020-06-18 10:44:29	2020-06-18	12	[{"id_menu":1,"count":1}]	12851	pick-up	0	12
80467	2020-06-18 10:44:30	2020-06-18	17	[{"id_menu":4,"count":1}]	2433	pick-up	0	17
80468	2020-06-18 10:47:05	2020-06-18	9	[{"id_menu":6,"count":1}]	28986	delivery	5	14
80469	2020-06-18 10:47:53	2020-06-18	14	[{"id_menu":2,"count":1}]	31629	delivery	5	19
80470	2020-06-18 10:49:15	2020-06-18	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	22609	delivery	5	44
80471	2020-06-18 10:51:54	2020-06-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9719	delivery	5	22
80472	2020-06-18 10:52:07	2020-06-18	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	31492	delivery	5	22
80473	2020-06-18 11:02:24	2020-06-18	12	[{"id_menu":1,"count":1}]	26742	delivery	5	17
80474	2020-06-18 11:02:58	2020-06-18	12	[{"id_menu":3,"count":1}]	1736	pick-up	0	12
80475	2020-06-18 11:10:25	2020-06-18	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18316	pick-up	0	32
80476	2020-06-18 11:11:00	2020-06-18	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	31542	delivery	5	26
80477	2020-06-18 11:15:50	2020-06-18	12	[{"id_menu":3,"count":1}]	25831	pick-up	0	12
80478	2020-06-18 11:22:07	2020-06-18	9	[{"id_menu":6,"count":1}]	12029	delivery	5	14
80479	2020-06-18 11:24:02	2020-06-18	9	[{"id_menu":7,"count":1}]	1148	pick-up	0	9
80480	2020-06-18 11:24:04	2020-06-18	12	[{"id_menu":3,"count":1}]	9577	delivery	5	17
80481	2020-06-18 11:24:43	2020-06-18	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	30855	delivery	5	48
80482	2020-06-18 11:26:58	2020-06-18	9	[{"id_menu":7,"count":1}]	31493	delivery	5	14
80483	2020-06-18 11:30:22	2020-06-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	26291	delivery	5	28
80484	2020-06-18 11:32:45	2020-06-18	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	23241	pick-up	0	29
80485	2020-06-18 11:35:14	2020-06-18	12	[{"id_menu":3,"count":1}]	7725	delivery	5	17
80486	2020-06-18 11:35:15	2020-06-18	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	25598	delivery	5	39
80487	2020-06-18 11:41:41	2020-06-18	8	[{"id_menu":5,"count":1}]	31485	delivery	5	13
80488	2020-06-18 11:43:27	2020-06-18	14	[{"id_menu":2,"count":1}]	1507	delivery	5	19
80489	2020-06-18 11:44:07	2020-06-18	9	[{"id_menu":6,"count":1}]	31536	delivery	5	14
80490	2020-06-18 11:50:37	2020-06-18	14	[{"id_menu":2,"count":1}]	30864	pick-up	0	14
80491	2020-06-18 11:50:43	2020-06-18	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	31606	delivery	5	22
80492	2020-06-18 11:53:18	2020-06-18	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	12558	pick-up	0	20
80493	2020-06-18 11:54:57	2020-06-18	9	[{"id_menu":7,"count":1}]	29027	delivery	5	14
80494	2020-06-18 11:56:07	2020-06-18	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	31673	delivery	5	31
80495	2020-06-18 12:01:07	2020-06-18	12	[{"id_menu":1,"count":1}]	31518	delivery	5	17
80496	2020-06-18 12:05:39	2020-06-18	9	[{"id_menu":7,"count":1}]	31508	delivery	5	14
80497	2020-06-18 12:08:56	2020-06-18	9	[{"id_menu":7,"count":1}]	31541	delivery	5	14
80498	2020-06-18 12:09:42	2020-06-18	8	[{"id_menu":5,"count":1}]	31609	delivery	5	13
80499	2020-06-18 12:10:39	2020-06-18	12	[{"id_menu":3,"count":1}]	18000	delivery	5	17
80500	2020-06-18 12:12:42	2020-06-18	9	[{"id_menu":6,"count":1}]	9198	delivery	5	14
80501	2020-06-18 12:14:14	2020-06-18	17	[{"id_menu":4,"count":1}]	12075	pick-up	0	17
80502	2020-06-18 12:19:09	2020-06-18	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	31592	delivery	5	30
80503	2020-06-18 12:19:45	2020-06-18	9	[{"id_menu":7,"count":1}]	4906	pick-up	0	9
80504	2020-06-18 12:20:03	2020-06-18	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	31575	delivery	5	22
80505	2020-06-18 12:20:36	2020-06-18	9	[{"id_menu":6,"count":1}]	9200	pick-up	0	9
80506	2020-06-18 12:22:15	2020-06-18	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	31674	delivery	5	31
80507	2020-06-18 12:22:36	2020-06-18	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	31544	delivery	5	39
80508	2020-06-18 12:25:29	2020-06-18	9	[{"id_menu":6,"count":1}]	12822	delivery	5	14
80509	2020-06-18 12:32:33	2020-06-18	9	[{"id_menu":6,"count":1}]	4582	delivery	5	14
80510	2020-06-18 12:32:54	2020-06-18	8	[{"id_menu":5,"count":1}]	8246	delivery	5	13
80511	2020-06-18 12:36:30	2020-06-18	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	20080	delivery	5	26
80512	2020-06-18 12:40:10	2020-06-18	14	[{"id_menu":2,"count":1}]	24307	delivery	5	19
80513	2020-06-18 12:44:37	2020-06-18	17	[{"id_menu":4,"count":1}]	4640	pick-up	0	17
80514	2020-06-18 12:47:54	2020-06-18	12	[{"id_menu":1,"count":1}]	4054	pick-up	0	12
80515	2020-06-18 12:48:16	2020-06-18	14	[{"id_menu":2,"count":1}]	26874	delivery	5	19
80516	2020-06-18 12:55:13	2020-06-18	14	[{"id_menu":2,"count":1}]	14928	delivery	5	19
80517	2020-06-18 12:55:27	2020-06-18	17	[{"id_menu":4,"count":1}]	31527	pick-up	0	17
80518	2020-06-18 12:56:41	2020-06-18	12	[{"id_menu":1,"count":1}]	6622	pick-up	0	12
80519	2020-06-18 12:58:17	2020-06-18	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25152	delivery	5	35
80520	2020-06-18 13:00:30	2020-06-18	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	31579	delivery	5	48
80521	2020-06-18 13:01:42	2020-06-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31676	delivery	5	23
80522	2020-06-18 13:03:25	2020-06-18	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	29099	delivery	5	39
80523	2020-06-18 13:08:46	2020-06-18	9	[{"id_menu":6,"count":1}]	31661	delivery	5	14
80524	2020-06-18 13:09:31	2020-06-18	9	[{"id_menu":7,"count":1}]	2520	pick-up	0	9
80525	2020-06-18 13:18:29	2020-06-18	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	31516	delivery	5	26
80526	2020-06-18 13:25:01	2020-06-18	8	[{"id_menu":5,"count":1}]	9377	delivery	5	13
80527	2020-06-18 13:27:22	2020-06-18	8	[{"id_menu":5,"count":3}]	10570	delivery	5	13
80528	2020-06-18 13:29:08	2020-06-18	14	[{"id_menu":2,"count":1}]	16736	pick-up	0	14
80529	2020-06-18 13:30:37	2020-06-18	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	31540	delivery	5	39
80530	2020-06-18 13:30:55	2020-06-18	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	15073	delivery	5	31
80531	2020-06-18 13:31:04	2020-06-18	9	[{"id_menu":7,"count":1}]	19380	delivery	5	14
80532	2020-06-18 13:36:25	2020-06-18	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	31582	delivery	5	31
80533	2020-06-18 13:41:41	2020-06-18	12	[{"id_menu":1,"count":1}]	8024	delivery	5	17
80534	2020-06-18 13:48:42	2020-06-18	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	17139	pick-up	0	24
80535	2020-06-18 13:52:38	2020-06-18	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	11772	delivery	5	25
80536	2020-06-18 13:52:40	2020-06-18	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2050	pick-up	0	20
80537	2020-06-18 13:58:04	2020-06-18	12	[{"id_menu":1,"count":1}]	31538	delivery	5	17
80538	2020-06-18 13:59:04	2020-06-18	12	[{"id_menu":3,"count":1}]	31494	delivery	5	17
80539	2020-06-18 14:00:30	2020-06-18	12	[{"id_menu":3,"count":1}]	27384	delivery	5	17
80540	2020-06-18 14:01:54	2020-06-18	17	[{"id_menu":4,"count":1}]	24948	delivery	5	22
80541	2020-06-18 14:02:07	2020-06-18	9	[{"id_menu":7,"count":1}]	30462	delivery	5	14
80542	2020-06-18 14:07:47	2020-06-18	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	8363	pick-up	0	22
80543	2020-06-18 14:08:33	2020-06-18	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	31555	pick-up	0	47
80544	2020-06-18 14:09:12	2020-06-18	9	[{"id_menu":6,"count":1}]	31643	delivery	5	14
80545	2020-06-18 14:09:16	2020-06-18	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	26187	delivery	5	31
80546	2020-06-18 14:10:56	2020-06-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4673	pick-up	0	23
80547	2020-06-18 14:12:07	2020-06-18	12	[{"id_menu":3,"count":1}]	5241	pick-up	0	12
80548	2020-06-18 14:19:32	2020-06-18	9	[{"id_menu":6,"count":1}]	10287	delivery	5	14
80549	2020-06-18 14:24:28	2020-06-18	14	[{"id_menu":2,"count":1}]	8014	pick-up	0	14
80550	2020-06-18 14:26:17	2020-06-18	9	[{"id_menu":7,"count":1}]	11973	delivery	5	14
80551	2020-06-18 14:27:05	2020-06-18	8	[{"id_menu":5,"count":1}]	15421	delivery	5	13
80552	2020-06-18 14:31:24	2020-06-18	14	[{"id_menu":2,"count":1}]	31672	pick-up	0	14
80553	2020-06-18 14:32:52	2020-06-18	8	[{"id_menu":5,"count":1}]	31549	delivery	5	13
80554	2020-06-18 14:34:28	2020-06-18	8	[{"id_menu":5,"count":1}]	13246	delivery	5	13
80555	2020-06-18 14:35:58	2020-06-18	9	[{"id_menu":7,"count":1}]	31671	delivery	5	14
80556	2020-06-18 14:36:55	2020-06-18	9	[{"id_menu":7,"count":1}]	31589	delivery	5	14
80557	2020-06-18 14:38:15	2020-06-18	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	31605	delivery	5	25
80558	2020-06-18 14:39:57	2020-06-18	8	[{"id_menu":5,"count":2}]	494	delivery	5	13
80559	2020-06-18 14:45:16	2020-06-18	17	[{"id_menu":4,"count":1}]	30806	delivery	5	22
80560	2020-06-18 14:50:16	2020-06-18	8	[{"id_menu":5,"count":1}]	5616	delivery	5	13
80561	2020-06-18 14:53:35	2020-06-18	9	[{"id_menu":6,"count":1}]	17067	delivery	5	14
80562	2020-06-18 14:54:20	2020-06-18	12	[{"id_menu":1,"count":1}]	29017	delivery	5	17
80563	2020-06-18 14:54:35	2020-06-18	14	[{"id_menu":2,"count":1}]	5640	delivery	5	19
80564	2020-06-18 14:58:03	2020-06-18	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	17778	pick-up	0	21
80565	2020-06-18 14:58:36	2020-06-18	8	[{"id_menu":5,"count":1}]	31646	delivery	5	13
80566	2020-06-18 14:59:15	2020-06-18	9	[{"id_menu":6,"count":1}]	11709	delivery	5	14
80567	2020-06-18 14:59:22	2020-06-18	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11896	delivery	5	43
80568	2020-06-18 15:04:38	2020-06-18	9	[{"id_menu":6,"count":1}]	31631	delivery	5	14
80569	2020-06-18 15:05:02	2020-06-18	9	[{"id_menu":6,"count":1}]	12117	delivery	5	14
80570	2020-06-18 15:08:27	2020-06-18	14	[{"id_menu":2,"count":1}]	14093	delivery	5	19
80571	2020-06-18 15:10:55	2020-06-18	9	[{"id_menu":6,"count":1}]	10576	delivery	5	14
80572	2020-06-18 15:11:28	2020-06-18	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	16188	delivery	5	36
80573	2020-06-18 15:11:48	2020-06-18	9	[{"id_menu":6,"count":1}]	16982	delivery	5	14
80574	2020-06-18 15:13:21	2020-06-18	14	[{"id_menu":2,"count":1}]	7429	pick-up	0	14
80575	2020-06-18 15:14:51	2020-06-18	9	[{"id_menu":6,"count":1}]	12720	delivery	5	14
80576	2020-06-18 15:17:10	2020-06-18	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	20761	pick-up	0	20
80577	2020-06-18 15:20:35	2020-06-18	9	[{"id_menu":6,"count":1}]	27161	delivery	5	14
80578	2020-06-18 15:22:10	2020-06-18	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	31587	delivery	5	45
80579	2020-06-18 15:22:51	2020-06-18	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	22643	pick-up	0	21
80580	2020-06-18 15:22:58	2020-06-18	9	[{"id_menu":6,"count":2}]	4166	delivery	5	14
80581	2020-06-18 15:33:21	2020-06-18	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31649	delivery	5	31
80582	2020-06-18 15:38:06	2020-06-18	12	[{"id_menu":1,"count":1}]	29283	pick-up	0	12
80583	2020-06-18 15:38:52	2020-06-18	17	[{"id_menu":4,"count":1}]	25333	pick-up	0	17
80584	2020-06-18 15:39:28	2020-06-18	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	31491	delivery	5	25
80585	2020-06-18 15:43:05	2020-06-18	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7685	delivery	5	34
80586	2020-06-18 15:43:06	2020-06-18	9	[{"id_menu":7,"count":1}]	20724	delivery	5	14
80587	2020-06-18 15:43:57	2020-06-18	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	27560	delivery	5	34
80588	2020-06-18 15:47:12	2020-06-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	27372	delivery	5	28
80589	2020-06-18 15:47:38	2020-06-18	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	31679	delivery	5	26
80590	2020-06-18 15:49:49	2020-06-18	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	31593	pick-up	0	21
80591	2020-06-18 15:50:02	2020-06-18	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	24950	pick-up	0	20
80592	2020-06-18 15:54:01	2020-06-18	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	31590	delivery	5	26
80593	2020-06-18 15:55:25	2020-06-18	14	[{"id_menu":2,"count":1}]	7567	delivery	5	19
80726	2020-06-18 21:12:22	2020-06-18	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	31529	delivery	5	31
80594	2020-06-18 15:57:38	2020-06-18	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	31503	delivery	5	45
80595	2020-06-18 15:58:02	2020-06-18	14	[{"id_menu":2,"count":1}]	28308	delivery	5	19
80596	2020-06-18 16:02:38	2020-06-18	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	7486	delivery	5	36
80597	2020-06-18 16:06:09	2020-06-18	9	[{"id_menu":7,"count":1}]	19195	delivery	5	14
80598	2020-06-18 16:08:44	2020-06-18	12	[{"id_menu":1,"count":1}]	7151	delivery	5	17
80599	2020-06-18 16:14:35	2020-06-18	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9076	delivery	5	40
80600	2020-06-18 16:14:40	2020-06-18	8	[{"id_menu":5,"count":1}]	21496	delivery	5	13
80601	2020-06-18 16:14:52	2020-06-18	12	[{"id_menu":3,"count":1}]	31622	delivery	5	17
80602	2020-06-18 16:16:38	2020-06-18	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31484	delivery	5	35
80603	2020-06-18 16:17:21	2020-06-18	9	[{"id_menu":6,"count":1}]	30935	delivery	5	14
80604	2020-06-18 16:19:25	2020-06-18	8	[{"id_menu":5,"count":1}]	31669	delivery	5	13
80605	2020-06-18 16:20:14	2020-06-18	12	[{"id_menu":1,"count":1}]	6150	delivery	5	17
80606	2020-06-18 16:22:04	2020-06-18	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	23348	delivery	5	46
80607	2020-06-18 16:23:05	2020-06-18	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	9191	pick-up	0	38
80608	2020-06-18 16:24:32	2020-06-18	9	[{"id_menu":7,"count":1}]	31574	delivery	5	14
80609	2020-06-18 16:27:24	2020-06-18	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	24664	delivery	5	45
80610	2020-06-18 16:31:47	2020-06-18	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	30903	delivery	5	34
80611	2020-06-18 16:33:00	2020-06-18	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	23595	delivery	5	31
80612	2020-06-18 16:34:38	2020-06-18	9	[{"id_menu":6,"count":1}]	28901	delivery	5	14
80613	2020-06-18 16:36:57	2020-06-18	34	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	31552	delivery	5	39
80614	2020-06-18 16:40:00	2020-06-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31531	delivery	5	23
80615	2020-06-18 16:42:24	2020-06-18	9	[{"id_menu":6,"count":1}]	31647	delivery	5	14
80616	2020-06-18 16:45:28	2020-06-18	12	[{"id_menu":3,"count":1}]	31624	delivery	5	17
80617	2020-06-18 16:45:53	2020-06-18	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13320	pick-up	0	34
80618	2020-06-18 16:48:04	2020-06-18	12	[{"id_menu":3,"count":1}]	11394	pick-up	0	12
80619	2020-06-18 16:50:01	2020-06-18	17	[{"id_menu":4,"count":1}]	29990	pick-up	0	17
80620	2020-06-18 16:51:59	2020-06-18	9	[{"id_menu":6,"count":1}]	24607	delivery	5	14
80621	2020-06-18 16:54:21	2020-06-18	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3998	delivery	5	31
80622	2020-06-18 16:56:39	2020-06-18	8	[{"id_menu":5,"count":1}]	23709	pick-up	0	8
80623	2020-06-18 16:58:49	2020-06-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	31506	delivery	5	22
80624	2020-06-18 17:08:23	2020-06-18	12	[{"id_menu":1,"count":1}]	31490	delivery	5	17
80625	2020-06-18 17:08:25	2020-06-18	9	[{"id_menu":6,"count":1}]	20920	delivery	5	14
80626	2020-06-18 17:08:40	2020-06-18	9	[{"id_menu":6,"count":2}]	28633	delivery	5	14
80627	2020-06-18 17:08:59	2020-06-18	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	31684	delivery	5	30
80628	2020-06-18 17:09:53	2020-06-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	31617	delivery	5	22
80629	2020-06-18 17:10:50	2020-06-18	14	[{"id_menu":2,"count":1}]	16810	delivery	5	19
80630	2020-06-18 17:11:34	2020-06-18	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	31280	delivery	5	26
80631	2020-06-18 17:15:47	2020-06-18	12	[{"id_menu":1,"count":1}]	9149	delivery	5	17
80632	2020-06-18 17:16:35	2020-06-18	17	[{"id_menu":4,"count":1}]	18658	delivery	5	22
80633	2020-06-18 17:18:58	2020-06-18	9	[{"id_menu":7,"count":1}]	31477	delivery	5	14
80634	2020-06-18 17:23:22	2020-06-18	12	[{"id_menu":3,"count":1}]	6572	pick-up	0	12
80635	2020-06-18 17:27:44	2020-06-18	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	903	delivery	5	37
80636	2020-06-18 17:27:49	2020-06-18	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":2}]	31610	pick-up	0	26
80637	2020-06-18 17:28:22	2020-06-18	9	[{"id_menu":7,"count":1}]	30469	delivery	5	14
80638	2020-06-18 17:30:17	2020-06-18	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7588	delivery	5	40
80639	2020-06-18 17:32:05	2020-06-18	14	[{"id_menu":2,"count":1}]	9183	delivery	5	19
80640	2020-06-18 17:35:09	2020-06-18	17	[{"id_menu":4,"count":1}]	1777	pick-up	0	17
80641	2020-06-18 17:38:47	2020-06-18	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	31630	delivery	5	45
80642	2020-06-18 17:40:29	2020-06-18	14	[{"id_menu":2,"count":1}]	1170	delivery	5	19
80643	2020-06-18 17:41:48	2020-06-18	12	[{"id_menu":3,"count":1}]	31601	delivery	5	17
80644	2020-06-18 17:44:06	2020-06-18	8	[{"id_menu":5,"count":2}]	25312	delivery	5	13
80645	2020-06-18 17:44:43	2020-06-18	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31652	delivery	5	31
80646	2020-06-18 17:44:45	2020-06-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	31487	delivery	5	28
80647	2020-06-18 17:44:51	2020-06-18	14	[{"id_menu":2,"count":1}]	31683	delivery	5	19
80648	2020-06-18 17:48:27	2020-06-18	14	[{"id_menu":2,"count":1}]	10679	pick-up	0	14
80649	2020-06-18 17:48:33	2020-06-18	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	115	pick-up	0	21
80650	2020-06-18 17:52:43	2020-06-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31480	delivery	5	23
80651	2020-06-18 17:55:54	2020-06-18	9	[{"id_menu":7,"count":1}]	8448	delivery	5	14
80652	2020-06-18 17:59:03	2020-06-18	12	[{"id_menu":1,"count":1}]	12696	delivery	5	17
80653	2020-06-18 17:59:47	2020-06-18	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31660	delivery	5	40
80654	2020-06-18 18:03:16	2020-06-18	8	[{"id_menu":5,"count":1}]	12062	delivery	5	13
80655	2020-06-18 18:08:15	2020-06-18	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	7387	delivery	5	40
80656	2020-06-18 18:12:02	2020-06-18	9	[{"id_menu":6,"count":1}]	31537	delivery	5	14
80657	2020-06-18 18:14:40	2020-06-18	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20396	delivery	5	34
80793	2020-06-19 00:29:35	2020-06-19	17	[{"id_menu":4,"count":1}]	19264	delivery	5	22
80658	2020-06-18 18:19:08	2020-06-18	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	31654	delivery	5	40
80659	2020-06-18 18:27:14	2020-06-18	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	18540	delivery	5	57
80660	2020-06-18 18:30:20	2020-06-18	8	[{"id_menu":5,"count":1}]	31656	delivery	5	13
80661	2020-06-18 18:30:31	2020-06-18	9	[{"id_menu":7,"count":1}]	31577	delivery	5	14
80662	2020-06-18 18:31:13	2020-06-18	12	[{"id_menu":3,"count":1}]	510	pick-up	0	12
80663	2020-06-18 18:31:50	2020-06-18	12	[{"id_menu":3,"count":1}]	1405	delivery	5	17
80664	2020-06-18 18:32:41	2020-06-18	9	[{"id_menu":7,"count":1}]	31635	pick-up	0	9
80665	2020-06-18 18:32:57	2020-06-18	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	31481	delivery	5	26
80666	2020-06-18 18:36:03	2020-06-18	9	[{"id_menu":7,"count":1}]	21722	pick-up	0	9
80667	2020-06-18 18:38:41	2020-06-18	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	31557	delivery	5	45
80668	2020-06-18 18:43:05	2020-06-18	17	[{"id_menu":4,"count":1}]	31677	delivery	5	22
80669	2020-06-18 18:45:32	2020-06-18	14	[{"id_menu":2,"count":1}]	31678	delivery	5	19
80670	2020-06-18 18:46:31	2020-06-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	16754	delivery	5	28
80671	2020-06-18 18:47:13	2020-06-18	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	31502	delivery	5	27
80672	2020-06-18 18:47:42	2020-06-18	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	13987	delivery	5	25
80673	2020-06-18 18:51:11	2020-06-18	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4082	pick-up	0	29
80674	2020-06-18 18:51:46	2020-06-18	9	[{"id_menu":6,"count":1}]	5106	delivery	5	14
80675	2020-06-18 18:53:33	2020-06-18	8	[{"id_menu":5,"count":1}]	31474	delivery	5	13
80676	2020-06-18 18:54:42	2020-06-18	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	31569	delivery	5	43
80677	2020-06-18 18:56:34	2020-06-18	14	[{"id_menu":2,"count":1}]	30629	delivery	5	19
80678	2020-06-18 18:57:30	2020-06-18	17	[{"id_menu":4,"count":1}]	31473	delivery	5	22
80679	2020-06-18 19:02:49	2020-06-18	8	[{"id_menu":5,"count":1}]	6267	delivery	5	13
80680	2020-06-18 19:04:37	2020-06-18	8	[{"id_menu":5,"count":1}]	11129	delivery	5	13
80681	2020-06-18 19:09:39	2020-06-18	12	[{"id_menu":1,"count":1}]	8	pick-up	0	12
80682	2020-06-18 19:12:13	2020-06-18	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	31597	delivery	5	26
80683	2020-06-18 19:12:27	2020-06-18	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	22243	delivery	5	40
80684	2020-06-18 19:12:47	2020-06-18	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	11976	delivery	5	31
80685	2020-06-18 19:13:59	2020-06-18	8	[{"id_menu":5,"count":1}]	26402	delivery	5	13
80686	2020-06-18 19:14:27	2020-06-18	9	[{"id_menu":7,"count":1}]	31548	delivery	5	14
80687	2020-06-18 19:17:12	2020-06-18	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	15728	delivery	5	29
80688	2020-06-18 19:21:17	2020-06-18	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	31658	delivery	5	30
80689	2020-06-18 19:29:41	2020-06-18	12	[{"id_menu":1,"count":2}]	31628	pick-up	0	12
80690	2020-06-18 19:30:42	2020-06-18	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5125	delivery	5	31
80691	2020-06-18 19:38:53	2020-06-18	9	[{"id_menu":6,"count":3}]	31602	delivery	5	14
80692	2020-06-18 19:42:28	2020-06-18	9	[{"id_menu":6,"count":1}]	21510	pick-up	0	9
80693	2020-06-18 19:45:50	2020-06-18	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	13827	delivery	5	30
80694	2020-06-18 19:46:02	2020-06-18	12	[{"id_menu":3,"count":1}]	1813	pick-up	0	12
80695	2020-06-18 19:47:52	2020-06-18	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	31364	pick-up	0	22
80696	2020-06-18 19:49:12	2020-06-18	12	[{"id_menu":1,"count":1}]	31218	pick-up	0	12
80697	2020-06-18 19:51:16	2020-06-18	9	[{"id_menu":6,"count":1}]	4748	delivery	5	14
80698	2020-06-18 19:54:23	2020-06-18	9	[{"id_menu":6,"count":1}]	14529	delivery	5	14
80699	2020-06-18 20:06:24	2020-06-18	12	[{"id_menu":3,"count":1}]	3386	delivery	5	17
80700	2020-06-18 20:09:20	2020-06-18	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	31564	delivery	5	29
80701	2020-06-18 20:11:44	2020-06-18	12	[{"id_menu":1,"count":2}]	26210	pick-up	0	12
80702	2020-06-18 20:12:27	2020-06-18	8	[{"id_menu":5,"count":1}]	23714	delivery	5	13
80703	2020-06-18 20:17:29	2020-06-18	9	[{"id_menu":6,"count":1}]	16228	pick-up	0	9
80704	2020-06-18 20:18:48	2020-06-18	17	[{"id_menu":4,"count":1}]	16226	delivery	5	22
80705	2020-06-18 20:18:48	2020-06-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	10798	pick-up	0	23
80706	2020-06-18 20:20:11	2020-06-18	8	[{"id_menu":5,"count":1}]	31495	delivery	5	13
80707	2020-06-18 20:20:24	2020-06-18	9	[{"id_menu":7,"count":1}]	31688	pick-up	0	9
80708	2020-06-18 20:23:31	2020-06-18	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	10224	delivery	5	36
80709	2020-06-18 20:23:55	2020-06-18	9	[{"id_menu":6,"count":1}]	1095	pick-up	0	9
80710	2020-06-18 20:25:39	2020-06-18	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	29247	delivery	5	31
80711	2020-06-18 20:29:29	2020-06-18	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	26974	pick-up	0	26
80712	2020-06-18 20:40:12	2020-06-18	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	5310	delivery	5	34
80713	2020-06-18 20:42:45	2020-06-18	14	[{"id_menu":2,"count":2}]	2867	delivery	5	19
80714	2020-06-18 20:43:45	2020-06-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4398	delivery	5	28
80715	2020-06-18 20:47:09	2020-06-18	17	[{"id_menu":4,"count":1}]	15350	delivery	5	22
80716	2020-06-18 20:47:37	2020-06-18	9	[{"id_menu":7,"count":1}]	14405	delivery	5	14
80717	2020-06-18 20:49:06	2020-06-18	9	[{"id_menu":6,"count":1}]	3087	delivery	5	14
80718	2020-06-18 20:49:19	2020-06-18	9	[{"id_menu":6,"count":1}]	31588	delivery	5	14
80719	2020-06-18 20:50:29	2020-06-18	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	31572	delivery	5	26
80720	2020-06-18 20:52:28	2020-06-18	8	[{"id_menu":5,"count":1}]	31657	delivery	5	13
80721	2020-06-18 20:55:36	2020-06-18	12	[{"id_menu":1,"count":1}]	31562	delivery	5	17
80722	2020-06-18 21:02:09	2020-06-18	14	[{"id_menu":2,"count":1}]	4973	pick-up	0	14
80723	2020-06-18 21:02:31	2020-06-18	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	31535	delivery	5	30
80724	2020-06-18 21:06:57	2020-06-18	17	[{"id_menu":4,"count":1}]	3507	delivery	5	22
80725	2020-06-18 21:08:00	2020-06-18	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31616	delivery	5	34
80727	2020-06-18 21:14:19	2020-06-18	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17078	delivery	5	34
80728	2020-06-18 21:17:30	2020-06-18	9	[{"id_menu":7,"count":1}]	28239	delivery	5	14
80729	2020-06-18 21:17:50	2020-06-18	12	[{"id_menu":3,"count":1}]	14319	pick-up	0	12
80730	2020-06-18 21:25:56	2020-06-18	12	[{"id_menu":1,"count":1}]	12889	pick-up	0	12
80731	2020-06-18 21:27:07	2020-06-18	14	[{"id_menu":2,"count":1}]	13851	pick-up	0	14
80732	2020-06-18 21:41:34	2020-06-18	17	[{"id_menu":4,"count":1}]	20412	delivery	5	22
80733	2020-06-18 21:42:23	2020-06-18	9	[{"id_menu":6,"count":1}]	4459	delivery	5	14
80734	2020-06-18 21:43:32	2020-06-18	14	[{"id_menu":2,"count":1}]	2582	pick-up	0	14
80735	2020-06-18 21:45:24	2020-06-18	17	[{"id_menu":4,"count":1}]	1996	pick-up	0	17
80736	2020-06-18 21:48:30	2020-06-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3037	delivery	5	22
80737	2020-06-18 21:49:06	2020-06-18	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18492	delivery	5	37
80738	2020-06-18 21:51:24	2020-06-18	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8985	delivery	5	31
80739	2020-06-18 21:57:13	2020-06-18	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3253	delivery	5	31
80740	2020-06-18 21:59:05	2020-06-18	9	[{"id_menu":7,"count":1}]	21949	delivery	5	14
80741	2020-06-18 22:09:03	2020-06-18	12	[{"id_menu":3,"count":1}]	950	pick-up	0	12
80742	2020-06-18 22:15:22	2020-06-18	17	[{"id_menu":4,"count":1}]	22489	delivery	5	22
80743	2020-06-18 22:16:05	2020-06-18	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	22786	delivery	5	31
80744	2020-06-18 22:22:44	2020-06-18	14	[{"id_menu":2,"count":1}]	10830	delivery	5	19
80745	2020-06-18 22:23:13	2020-06-18	9	[{"id_menu":7,"count":2}]	31478	delivery	5	14
80746	2020-06-18 22:23:21	2020-06-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5473	delivery	5	28
80747	2020-06-18 22:28:32	2020-06-18	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17049	delivery	5	34
80748	2020-06-18 22:36:11	2020-06-18	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	23946	pick-up	0	31
80749	2020-06-18 22:36:18	2020-06-18	9	[{"id_menu":7,"count":1}]	4373	delivery	5	14
80750	2020-06-18 22:37:12	2020-06-18	14	[{"id_menu":2,"count":1}]	18326	delivery	5	19
80751	2020-06-18 22:37:48	2020-06-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	31519	delivery	5	28
80752	2020-06-18 22:40:21	2020-06-18	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	9339	pick-up	0	26
80753	2020-06-18 22:41:18	2020-06-18	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	31626	delivery	5	26
80754	2020-06-18 22:42:50	2020-06-18	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	3146	pick-up	0	20
80755	2020-06-18 22:43:03	2020-06-18	8	[{"id_menu":5,"count":1}]	9726	delivery	5	13
80756	2020-06-18 22:49:40	2020-06-18	14	[{"id_menu":2,"count":1}]	14976	delivery	5	19
80757	2020-06-18 22:54:37	2020-06-18	9	[{"id_menu":6,"count":1}]	31554	pick-up	0	9
80758	2020-06-18 22:56:44	2020-06-18	9	[{"id_menu":6,"count":1}]	31638	delivery	5	14
80759	2020-06-18 22:59:35	2020-06-18	12	[{"id_menu":1,"count":2}]	3825	pick-up	0	12
80760	2020-06-18 23:01:04	2020-06-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2071	pick-up	0	23
80761	2020-06-18 23:02:28	2020-06-18	9	[{"id_menu":6,"count":1}]	28582	pick-up	0	9
80762	2020-06-18 23:04:04	2020-06-18	9	[{"id_menu":6,"count":1}]	27559	delivery	5	14
80763	2020-06-18 23:11:24	2020-06-18	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17137	delivery	5	48
80764	2020-06-18 23:12:20	2020-06-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31681	delivery	5	22
80765	2020-06-18 23:13:34	2020-06-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	11389	delivery	5	28
80766	2020-06-18 23:15:34	2020-06-18	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1541	delivery	5	45
80767	2020-06-18 23:15:40	2020-06-18	17	[{"id_menu":4,"count":1}]	3361	pick-up	0	17
80768	2020-06-18 23:20:45	2020-06-18	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	31530	delivery	5	38
80769	2020-06-18 23:22:57	2020-06-18	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	31639	delivery	5	42
80770	2020-06-18 23:24:33	2020-06-18	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29022	delivery	5	36
80771	2020-06-18 23:26:16	2020-06-18	14	[{"id_menu":2,"count":1}]	581	delivery	5	19
80772	2020-06-18 23:28:41	2020-06-18	12	[{"id_menu":1,"count":1}]	31633	delivery	5	17
80773	2020-06-18 23:30:51	2020-06-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	31539	delivery	5	28
80774	2020-06-18 23:32:31	2020-06-18	12	[{"id_menu":3,"count":1}]	10968	pick-up	0	12
80775	2020-06-18 23:39:42	2020-06-18	12	[{"id_menu":1,"count":1}]	8920	delivery	5	17
80776	2020-06-18 23:43:22	2020-06-18	17	[{"id_menu":4,"count":1}]	2435	delivery	5	22
80777	2020-06-18 23:49:25	2020-06-18	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	13797	delivery	5	26
80778	2020-06-18 23:51:27	2020-06-18	12	[{"id_menu":1,"count":1}]	2101	pick-up	0	12
80779	2020-06-18 23:53:45	2020-06-18	12	[{"id_menu":3,"count":1}]	4533	pick-up	0	12
80780	2020-06-18 23:56:35	2020-06-18	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8224	pick-up	0	52
80781	2020-06-19 00:03:42	2020-06-19	14	[{"id_menu":2,"count":1}]	22547	delivery	5	19
80782	2020-06-19 00:09:32	2020-06-19	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	31768	delivery	5	43
80783	2020-06-19 00:10:41	2020-06-19	12	[{"id_menu":1,"count":1}]	31753	delivery	5	17
80784	2020-06-19 00:13:49	2020-06-19	8	[{"id_menu":5,"count":1}]	31485	delivery	5	13
80785	2020-06-19 00:14:30	2020-06-19	8	[{"id_menu":5,"count":1}]	23064	delivery	5	13
80786	2020-06-19 00:17:29	2020-06-19	8	[{"id_menu":5,"count":1}]	31900	delivery	5	13
80787	2020-06-19 00:21:44	2020-06-19	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	14463	pick-up	0	40
80788	2020-06-19 00:22:12	2020-06-19	9	[{"id_menu":7,"count":1}]	31808	delivery	5	14
80789	2020-06-19 00:22:59	2020-06-19	12	[{"id_menu":3,"count":1}]	6769	pick-up	0	12
80790	2020-06-19 00:24:53	2020-06-19	9	[{"id_menu":6,"count":1}]	6182	pick-up	0	9
80791	2020-06-19 00:27:07	2020-06-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	31910	delivery	5	28
80792	2020-06-19 00:29:10	2020-06-19	12	[{"id_menu":1,"count":1}]	18893	delivery	5	17
80794	2020-06-19 00:39:34	2020-06-19	14	[{"id_menu":2,"count":1}]	13888	pick-up	0	14
80795	2020-06-19 00:41:30	2020-06-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	18741	delivery	5	31
80796	2020-06-19 00:42:36	2020-06-19	9	[{"id_menu":7,"count":1}]	31913	delivery	5	14
80797	2020-06-19 00:43:20	2020-06-19	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	31738	delivery	5	31
80798	2020-06-19 00:43:53	2020-06-19	12	[{"id_menu":1,"count":1}]	31780	delivery	5	17
80799	2020-06-19 00:43:59	2020-06-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17606	delivery	5	23
80800	2020-06-19 00:46:14	2020-06-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":3}]	7421	delivery	5	28
80801	2020-06-19 00:47:54	2020-06-19	17	[{"id_menu":4,"count":1}]	15590	pick-up	0	17
80802	2020-06-19 00:49:31	2020-06-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16853	pick-up	0	26
80803	2020-06-19 00:52:14	2020-06-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	10100	delivery	5	28
80804	2020-06-19 00:52:51	2020-06-19	9	[{"id_menu":6,"count":1}]	20216	delivery	5	14
80805	2020-06-19 00:55:42	2020-06-19	12	[{"id_menu":1,"count":1}]	17061	delivery	5	17
80806	2020-06-19 00:55:52	2020-06-19	9	[{"id_menu":6,"count":1}]	22507	delivery	5	14
80807	2020-06-19 00:58:44	2020-06-19	9	[{"id_menu":6,"count":1}]	12937	delivery	5	14
80808	2020-06-19 01:00:13	2020-06-19	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	28925	delivery	5	38
80809	2020-06-19 01:04:07	2020-06-19	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	13339	delivery	5	31
80810	2020-06-19 01:05:39	2020-06-19	9	[{"id_menu":7,"count":1}]	31697	delivery	5	14
80811	2020-06-19 01:14:52	2020-06-19	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4479	delivery	5	30
80812	2020-06-19 01:16:41	2020-06-19	14	[{"id_menu":2,"count":1}]	12567	delivery	5	19
80813	2020-06-19 01:17:23	2020-06-19	14	[{"id_menu":2,"count":1}]	10659	pick-up	0	14
80814	2020-06-19 01:17:26	2020-06-19	14	[{"id_menu":2,"count":1}]	11464	delivery	5	19
80815	2020-06-19 01:26:22	2020-06-19	12	[{"id_menu":3,"count":1}]	19357	pick-up	0	12
80816	2020-06-19 01:28:21	2020-06-19	17	[{"id_menu":4,"count":1}]	1945	pick-up	0	17
80817	2020-06-19 01:29:11	2020-06-19	9	[{"id_menu":6,"count":1}]	4102	pick-up	0	9
80818	2020-06-19 01:29:23	2020-06-19	9	[{"id_menu":7,"count":1}]	15085	delivery	5	14
80819	2020-06-19 01:29:49	2020-06-19	14	[{"id_menu":2,"count":1}]	2374	pick-up	0	14
80820	2020-06-19 01:30:15	2020-06-19	9	[{"id_menu":6,"count":1}]	13547	pick-up	0	9
80821	2020-06-19 01:31:57	2020-06-19	12	[{"id_menu":1,"count":1}]	6775	delivery	5	17
80822	2020-06-19 01:35:31	2020-06-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":3}]	25737	delivery	5	22
80823	2020-06-19 01:43:24	2020-06-19	9	[{"id_menu":6,"count":1}]	7281	delivery	5	14
80824	2020-06-19 01:45:56	2020-06-19	9	[{"id_menu":7,"count":1}]	16247	delivery	5	14
80825	2020-06-19 01:49:25	2020-06-19	8	[{"id_menu":5,"count":1}]	31746	delivery	5	13
80826	2020-06-19 01:50:39	2020-06-19	29	[{"id_menu":3,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	31827	delivery	5	34
80827	2020-06-19 01:53:57	2020-06-19	17	[{"id_menu":4,"count":1}]	3444	pick-up	0	17
80828	2020-06-19 01:54:20	2020-06-19	17	[{"id_menu":4,"count":1}]	28306	delivery	5	22
80829	2020-06-19 01:57:43	2020-06-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	22552	delivery	5	28
80830	2020-06-19 01:57:58	2020-06-19	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	31819	delivery	5	35
80831	2020-06-19 02:01:32	2020-06-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	19237	delivery	5	36
80832	2020-06-19 02:02:40	2020-06-19	8	[{"id_menu":5,"count":1}]	14014	pick-up	0	8
80833	2020-06-19 02:06:25	2020-06-19	8	[{"id_menu":5,"count":1}]	31767	delivery	5	13
80834	2020-06-19 02:09:48	2020-06-19	14	[{"id_menu":2,"count":1}]	11577	delivery	5	19
80835	2020-06-19 02:14:43	2020-06-19	12	[{"id_menu":1,"count":1}]	16539	pick-up	0	12
80836	2020-06-19 02:18:12	2020-06-19	9	[{"id_menu":7,"count":1}]	29191	delivery	5	14
80837	2020-06-19 02:19:33	2020-06-19	9	[{"id_menu":6,"count":1}]	31794	pick-up	0	9
80838	2020-06-19 02:21:17	2020-06-19	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	7121	delivery	5	31
80839	2020-06-19 02:24:13	2020-06-19	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	31682	pick-up	0	26
80840	2020-06-19 02:24:28	2020-06-19	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	19443	delivery	5	25
80841	2020-06-19 02:30:40	2020-06-19	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	31749	delivery	5	36
80842	2020-06-19 02:33:06	2020-06-19	14	[{"id_menu":2,"count":1}]	31739	delivery	5	19
80843	2020-06-19 02:37:07	2020-06-19	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	31741	delivery	5	30
80844	2020-06-19 02:38:44	2020-06-19	9	[{"id_menu":6,"count":1}]	21458	delivery	5	14
80845	2020-06-19 02:38:52	2020-06-19	14	[{"id_menu":2,"count":1}]	31893	delivery	5	19
80846	2020-06-19 02:43:00	2020-06-19	8	[{"id_menu":5,"count":1}]	31173	pick-up	0	8
80847	2020-06-19 02:46:18	2020-06-19	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	31834	delivery	5	22
80848	2020-06-19 02:50:49	2020-06-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	26749	delivery	5	28
80849	2020-06-19 02:57:36	2020-06-19	9	[{"id_menu":6,"count":1}]	4577	pick-up	0	9
80850	2020-06-19 03:00:35	2020-06-19	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	31689	delivery	5	42
80851	2020-06-19 03:03:40	2020-06-19	17	[{"id_menu":4,"count":1}]	31882	delivery	5	22
80852	2020-06-19 03:05:57	2020-06-19	14	[{"id_menu":2,"count":1}]	23701	delivery	5	19
80853	2020-06-19 03:08:38	2020-06-19	8	[{"id_menu":5,"count":1}]	30013	delivery	5	13
80854	2020-06-19 03:17:22	2020-06-19	9	[{"id_menu":7,"count":1}]	29508	delivery	5	14
80855	2020-06-19 03:18:45	2020-06-19	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	31268	delivery	5	43
80856	2020-06-19 03:20:58	2020-06-19	9	[{"id_menu":7,"count":1}]	23623	delivery	5	14
80857	2020-06-19 03:27:23	2020-06-19	9	[{"id_menu":6,"count":1}]	12465	delivery	5	14
80858	2020-06-19 03:30:16	2020-06-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31340	delivery	5	23
80859	2020-06-19 03:33:46	2020-06-19	12	[{"id_menu":1,"count":1}]	211	delivery	5	17
80860	2020-06-19 03:38:42	2020-06-19	17	[{"id_menu":4,"count":1}]	31773	pick-up	0	17
80861	2020-06-19 03:49:17	2020-06-19	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	31760	delivery	5	26
80862	2020-06-19 03:51:09	2020-06-19	8	[{"id_menu":5,"count":1}]	2959	pick-up	0	8
80863	2020-06-19 03:51:55	2020-06-19	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	27965	delivery	5	25
80864	2020-06-19 03:52:06	2020-06-19	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	461	delivery	5	42
80865	2020-06-19 03:52:12	2020-06-19	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	30119	delivery	5	36
80866	2020-06-19 03:53:50	2020-06-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	27166	pick-up	0	26
80867	2020-06-19 04:04:25	2020-06-19	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16545	delivery	5	31
80868	2020-06-19 04:20:58	2020-06-19	12	[{"id_menu":1,"count":1}]	31065	delivery	5	17
80869	2020-06-19 04:25:51	2020-06-19	9	[{"id_menu":6,"count":2}]	19361	pick-up	0	9
80870	2020-06-19 04:27:56	2020-06-19	9	[{"id_menu":6,"count":1}]	249	pick-up	0	9
80871	2020-06-19 04:29:06	2020-06-19	17	[{"id_menu":4,"count":1}]	31822	delivery	5	22
80872	2020-06-19 04:30:37	2020-06-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4607	pick-up	0	23
80873	2020-06-19 04:30:52	2020-06-19	9	[{"id_menu":7,"count":1}]	1529	pick-up	0	9
80874	2020-06-19 04:33:51	2020-06-19	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	31786	delivery	5	40
80875	2020-06-19 04:36:59	2020-06-19	9	[{"id_menu":7,"count":2}]	31861	delivery	5	14
80876	2020-06-19 04:38:03	2020-06-19	9	[{"id_menu":7,"count":1}]	26303	delivery	5	14
80877	2020-06-19 04:39:20	2020-06-19	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	5963	pick-up	0	20
80878	2020-06-19 04:42:24	2020-06-19	9	[{"id_menu":6,"count":1}]	31881	delivery	5	14
80879	2020-06-19 04:45:57	2020-06-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4749	delivery	5	23
80880	2020-06-19 04:47:24	2020-06-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	26126	delivery	5	28
80881	2020-06-19 04:48:57	2020-06-19	9	[{"id_menu":6,"count":1}]	13394	delivery	5	14
80882	2020-06-19 04:54:37	2020-06-19	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	26168	delivery	5	34
80883	2020-06-19 04:54:40	2020-06-19	12	[{"id_menu":1,"count":1}]	10850	delivery	5	17
80884	2020-06-19 04:59:36	2020-06-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31765	delivery	5	22
80885	2020-06-19 05:05:13	2020-06-19	14	[{"id_menu":2,"count":1}]	13841	pick-up	0	14
80886	2020-06-19 05:07:31	2020-06-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	31804	delivery	5	22
80887	2020-06-19 05:13:10	2020-06-19	14	[{"id_menu":2,"count":1}]	31758	delivery	5	19
80888	2020-06-19 05:15:34	2020-06-19	14	[{"id_menu":2,"count":1}]	28806	delivery	5	19
80889	2020-06-19 05:21:23	2020-06-19	37	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	31755	delivery	5	42
80890	2020-06-19 05:21:29	2020-06-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	31712	delivery	5	31
80891	2020-06-19 05:24:01	2020-06-19	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	31866	pick-up	0	21
80892	2020-06-19 05:24:40	2020-06-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1931	pick-up	0	23
80893	2020-06-19 05:26:23	2020-06-19	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	8100	delivery	5	26
80894	2020-06-19 05:26:53	2020-06-19	9	[{"id_menu":6,"count":1}]	31700	delivery	5	14
80895	2020-06-19 05:30:10	2020-06-19	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	31782	delivery	5	46
80896	2020-06-19 05:32:17	2020-06-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":3}]	31812	delivery	5	22
80897	2020-06-19 05:32:40	2020-06-19	9	[{"id_menu":6,"count":1}]	18220	delivery	5	14
80898	2020-06-19 05:40:36	2020-06-19	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	31854	delivery	5	42
80899	2020-06-19 05:41:54	2020-06-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24318	delivery	5	23
80900	2020-06-19 05:43:35	2020-06-19	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	7623	delivery	5	25
80901	2020-06-19 05:43:57	2020-06-19	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1513	delivery	5	31
80902	2020-06-19 05:45:08	2020-06-19	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31813	delivery	5	54
80903	2020-06-19 05:46:32	2020-06-19	12	[{"id_menu":1,"count":1}]	7771	pick-up	0	12
80904	2020-06-19 05:50:10	2020-06-19	8	[{"id_menu":5,"count":1}]	22965	pick-up	0	8
80905	2020-06-19 05:51:01	2020-06-19	14	[{"id_menu":2,"count":1}]	31787	delivery	5	19
80906	2020-06-19 05:52:28	2020-06-19	8	[{"id_menu":5,"count":1}]	31851	delivery	5	13
80907	2020-06-19 05:53:33	2020-06-19	12	[{"id_menu":3,"count":1}]	28211	delivery	5	17
80908	2020-06-19 06:00:34	2020-06-19	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	31892	delivery	5	36
80909	2020-06-19 06:03:19	2020-06-19	9	[{"id_menu":7,"count":1}]	9398	delivery	5	14
80910	2020-06-19 06:08:32	2020-06-19	12	[{"id_menu":1,"count":1}]	9467	pick-up	0	12
80911	2020-06-19 06:12:29	2020-06-19	14	[{"id_menu":2,"count":1}]	6250	pick-up	0	14
80912	2020-06-19 06:16:45	2020-06-19	17	[{"id_menu":4,"count":1}]	31840	delivery	5	22
80913	2020-06-19 06:17:39	2020-06-19	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	31883	pick-up	0	24
80914	2020-06-19 06:23:06	2020-06-19	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31832	delivery	5	43
80915	2020-06-19 06:23:07	2020-06-19	9	[{"id_menu":6,"count":1}]	886	delivery	5	14
80916	2020-06-19 06:25:40	2020-06-19	14	[{"id_menu":2,"count":1}]	6784	pick-up	0	14
80917	2020-06-19 06:27:57	2020-06-19	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1740	delivery	5	40
80918	2020-06-19 06:29:03	2020-06-19	14	[{"id_menu":2,"count":1}]	16079	pick-up	0	14
80919	2020-06-19 06:29:21	2020-06-19	9	[{"id_menu":6,"count":1}]	12372	delivery	5	14
80920	2020-06-19 06:31:00	2020-06-19	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	868	pick-up	0	33
80921	2020-06-19 06:34:19	2020-06-19	12	[{"id_menu":3,"count":1}]	30564	delivery	5	17
80922	2020-06-19 06:36:07	2020-06-19	12	[{"id_menu":1,"count":1}]	7456	delivery	5	17
80923	2020-06-19 06:39:50	2020-06-19	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	11801	pick-up	0	24
80924	2020-06-19 06:45:11	2020-06-19	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	19108	delivery	5	48
80925	2020-06-19 06:50:08	2020-06-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31707	delivery	5	23
80926	2020-06-19 06:50:30	2020-06-19	17	[{"id_menu":4,"count":1}]	5744	delivery	5	22
80927	2020-06-19 06:50:38	2020-06-19	9	[{"id_menu":7,"count":1}]	1724	delivery	5	14
80928	2020-06-19 06:52:04	2020-06-19	14	[{"id_menu":2,"count":1}]	3123	pick-up	0	14
80929	2020-06-19 06:52:38	2020-06-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5463	delivery	5	28
80930	2020-06-19 06:55:13	2020-06-19	8	[{"id_menu":5,"count":1}]	26020	delivery	5	13
80931	2020-06-19 07:00:29	2020-06-19	14	[{"id_menu":2,"count":1}]	28953	delivery	5	19
80932	2020-06-19 07:00:39	2020-06-19	9	[{"id_menu":7,"count":1}]	197	delivery	5	14
80933	2020-06-19 07:02:21	2020-06-19	9	[{"id_menu":7,"count":2}]	31908	delivery	5	14
80934	2020-06-19 07:04:40	2020-06-19	9	[{"id_menu":6,"count":1}]	14734	pick-up	0	9
80935	2020-06-19 07:05:40	2020-06-19	9	[{"id_menu":6,"count":1}]	31751	delivery	5	14
80936	2020-06-19 07:07:32	2020-06-19	9	[{"id_menu":7,"count":1}]	9967	delivery	5	14
80937	2020-06-19 07:11:45	2020-06-19	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14730	delivery	5	53
80938	2020-06-19 07:21:58	2020-06-19	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2806	delivery	5	31
80939	2020-06-19 07:22:17	2020-06-19	12	[{"id_menu":1,"count":1}]	25023	delivery	5	17
80940	2020-06-19 07:24:47	2020-06-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31809	delivery	5	23
80941	2020-06-19 07:26:47	2020-06-19	14	[{"id_menu":2,"count":1}]	7084	pick-up	0	14
80942	2020-06-19 07:31:37	2020-06-19	9	[{"id_menu":6,"count":1}]	21584	delivery	5	14
80943	2020-06-19 07:32:25	2020-06-19	12	[{"id_menu":1,"count":1}]	18222	pick-up	0	12
80944	2020-06-19 07:34:21	2020-06-19	12	[{"id_menu":3,"count":2}]	31871	delivery	5	17
80945	2020-06-19 07:36:07	2020-06-19	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	31745	delivery	5	30
80946	2020-06-19 07:38:18	2020-06-19	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	19445	delivery	5	26
80947	2020-06-19 07:40:21	2020-06-19	9	[{"id_menu":7,"count":1}]	4060	delivery	5	14
80948	2020-06-19 07:45:33	2020-06-19	9	[{"id_menu":7,"count":1}]	16850	delivery	5	14
80949	2020-06-19 07:45:45	2020-06-19	12	[{"id_menu":1,"count":1}]	24074	pick-up	0	12
80950	2020-06-19 07:45:51	2020-06-19	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	6476	delivery	5	34
80951	2020-06-19 07:48:48	2020-06-19	9	[{"id_menu":6,"count":2}]	13458	delivery	5	14
80952	2020-06-19 07:53:49	2020-06-19	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	9163	delivery	5	38
80953	2020-06-19 07:54:31	2020-06-19	14	[{"id_menu":2,"count":2}]	17425	delivery	5	19
80954	2020-06-19 07:56:53	2020-06-19	8	[{"id_menu":5,"count":1}]	27423	delivery	5	13
80955	2020-06-19 08:00:20	2020-06-19	14	[{"id_menu":2,"count":1}]	31886	delivery	5	19
80956	2020-06-19 08:05:49	2020-06-19	9	[{"id_menu":7,"count":1}]	31846	delivery	5	14
80957	2020-06-19 08:09:54	2020-06-19	9	[{"id_menu":7,"count":1}]	5808	delivery	5	14
80958	2020-06-19 08:16:34	2020-06-19	9	[{"id_menu":7,"count":1}]	23143	delivery	5	14
80959	2020-06-19 08:19:19	2020-06-19	12	[{"id_menu":3,"count":1}]	21779	delivery	5	17
80960	2020-06-19 08:21:54	2020-06-19	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	26272	delivery	5	31
80961	2020-06-19 08:22:14	2020-06-19	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	13881	delivery	5	40
80962	2020-06-19 08:25:22	2020-06-19	9	[{"id_menu":6,"count":1}]	31793	delivery	5	14
80963	2020-06-19 08:30:56	2020-06-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":3}]	8737	delivery	5	28
80964	2020-06-19 08:31:26	2020-06-19	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13187	delivery	5	34
80965	2020-06-19 08:39:47	2020-06-19	17	[{"id_menu":4,"count":1}]	31790	pick-up	0	17
80966	2020-06-19 08:40:35	2020-06-19	9	[{"id_menu":7,"count":1}]	31837	delivery	5	14
80967	2020-06-19 08:44:01	2020-06-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	15629	delivery	5	28
80968	2020-06-19 08:44:45	2020-06-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31718	delivery	5	23
80969	2020-06-19 08:45:14	2020-06-19	9	[{"id_menu":6,"count":1}]	9043	pick-up	0	9
80970	2020-06-19 08:51:28	2020-06-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18551	pick-up	0	17
80971	2020-06-19 08:57:05	2020-06-19	9	[{"id_menu":7,"count":1}]	8600	delivery	5	14
80972	2020-06-19 08:58:00	2020-06-19	14	[{"id_menu":2,"count":1}]	28827	pick-up	0	14
80973	2020-06-19 09:01:51	2020-06-19	9	[{"id_menu":6,"count":1}]	31848	delivery	5	14
80974	2020-06-19 09:03:46	2020-06-19	9	[{"id_menu":6,"count":1}]	29167	delivery	5	14
80975	2020-06-19 09:06:52	2020-06-19	8	[{"id_menu":5,"count":1}]	12324	delivery	5	13
80976	2020-06-19 09:07:01	2020-06-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31761	delivery	5	22
80977	2020-06-19 09:10:17	2020-06-19	17	[{"id_menu":4,"count":1}]	31829	delivery	5	22
80978	2020-06-19 09:12:22	2020-06-19	14	[{"id_menu":2,"count":1}]	30976	pick-up	0	14
80979	2020-06-19 09:14:37	2020-06-19	9	[{"id_menu":6,"count":1}]	24044	delivery	5	14
80980	2020-06-19 09:18:01	2020-06-19	9	[{"id_menu":7,"count":1}]	27610	delivery	5	14
80981	2020-06-19 09:20:18	2020-06-19	14	[{"id_menu":2,"count":1}]	4870	pick-up	0	14
80982	2020-06-19 09:23:22	2020-06-19	9	[{"id_menu":6,"count":1}]	4548	delivery	5	14
80983	2020-06-19 09:26:11	2020-06-19	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	31869	delivery	5	37
80984	2020-06-19 09:27:19	2020-06-19	12	[{"id_menu":3,"count":1}]	5473	pick-up	0	12
80985	2020-06-19 09:30:01	2020-06-19	9	[{"id_menu":7,"count":1}]	4710	delivery	5	14
80986	2020-06-19 09:30:06	2020-06-19	9	[{"id_menu":6,"count":1}]	9190	pick-up	0	9
80987	2020-06-19 09:33:01	2020-06-19	17	[{"id_menu":4,"count":1}]	20499	delivery	5	22
80988	2020-06-19 09:33:52	2020-06-19	9	[{"id_menu":7,"count":1}]	31902	delivery	5	14
80989	2020-06-19 09:35:29	2020-06-19	9	[{"id_menu":6,"count":1}]	13159	delivery	5	14
80990	2020-06-19 09:35:48	2020-06-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31720	delivery	5	22
80991	2020-06-19 09:36:07	2020-06-19	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":2}]	25582	delivery	5	26
80992	2020-06-19 09:37:56	2020-06-19	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	25191	delivery	5	38
80993	2020-06-19 09:40:44	2020-06-19	9	[{"id_menu":7,"count":1}]	31710	pick-up	0	9
80994	2020-06-19 09:41:26	2020-06-19	14	[{"id_menu":2,"count":1}]	12388	pick-up	0	14
80995	2020-06-19 09:54:18	2020-06-19	14	[{"id_menu":2,"count":1}]	28074	pick-up	0	14
80996	2020-06-19 09:55:12	2020-06-19	9	[{"id_menu":7,"count":2}]	20579	delivery	5	14
80997	2020-06-19 09:55:34	2020-06-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	12760	delivery	5	28
80998	2020-06-19 09:59:39	2020-06-19	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	19161	delivery	5	23
80999	2020-06-19 10:04:12	2020-06-19	9	[{"id_menu":7,"count":1}]	31732	delivery	5	14
81000	2020-06-19 10:06:53	2020-06-19	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	31872	delivery	5	40
81001	2020-06-19 10:08:18	2020-06-19	12	[{"id_menu":3,"count":1}]	31914	delivery	5	17
81002	2020-06-19 10:10:42	2020-06-19	8	[{"id_menu":5,"count":1}]	13114	delivery	5	13
81003	2020-06-19 10:12:40	2020-06-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	22464	delivery	5	31
81004	2020-06-19 10:17:16	2020-06-19	17	[{"id_menu":4,"count":1}]	31802	delivery	5	22
81005	2020-06-19 10:17:52	2020-06-19	9	[{"id_menu":6,"count":1}]	19926	delivery	5	14
81006	2020-06-19 10:19:26	2020-06-19	9	[{"id_menu":6,"count":1}]	2200	pick-up	0	9
81007	2020-06-19 10:20:28	2020-06-19	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	4047	delivery	5	34
81008	2020-06-19 10:20:44	2020-06-19	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	9458	pick-up	0	24
81009	2020-06-19 10:21:12	2020-06-19	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9440	delivery	5	43
81010	2020-06-19 10:21:48	2020-06-19	8	[{"id_menu":5,"count":1}]	3467	delivery	5	13
81011	2020-06-19 10:30:34	2020-06-19	17	[{"id_menu":4,"count":1}]	10798	pick-up	0	17
81012	2020-06-19 10:30:44	2020-06-19	9	[{"id_menu":7,"count":1}]	2818	delivery	5	14
81013	2020-06-19 10:31:50	2020-06-19	12	[{"id_menu":1,"count":1}]	11407	delivery	5	17
81014	2020-06-19 10:36:51	2020-06-19	9	[{"id_menu":6,"count":1}]	31826	delivery	5	14
81015	2020-06-19 10:37:55	2020-06-19	9	[{"id_menu":6,"count":1}]	31733	delivery	5	14
81016	2020-06-19 10:38:28	2020-06-19	8	[{"id_menu":5,"count":1}]	31705	delivery	5	13
81017	2020-06-19 10:48:07	2020-06-19	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	586	pick-up	0	29
81018	2020-06-19 10:48:39	2020-06-19	12	[{"id_menu":3,"count":1}]	1068	pick-up	0	12
81019	2020-06-19 10:57:48	2020-06-19	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3480	pick-up	0	25
81020	2020-06-19 10:58:59	2020-06-19	14	[{"id_menu":2,"count":1}]	16378	delivery	5	19
81021	2020-06-19 11:10:25	2020-06-19	12	[{"id_menu":1,"count":1}]	7111	delivery	5	17
81022	2020-06-19 11:14:00	2020-06-19	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19464	delivery	5	39
81023	2020-06-19 11:14:07	2020-06-19	8	[{"id_menu":5,"count":2}]	2821	pick-up	0	8
81024	2020-06-19 11:16:32	2020-06-19	9	[{"id_menu":6,"count":1}]	6116	delivery	5	14
81025	2020-06-19 11:19:03	2020-06-19	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31776	delivery	5	36
81026	2020-06-19 11:24:40	2020-06-19	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	81	pick-up	0	29
81027	2020-06-19 11:26:57	2020-06-19	12	[{"id_menu":1,"count":1}]	5432	delivery	5	17
81028	2020-06-19 11:30:20	2020-06-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24625	delivery	5	22
81029	2020-06-19 11:35:04	2020-06-19	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	31906	delivery	5	34
81030	2020-06-19 11:40:28	2020-06-19	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	22211	delivery	5	25
81031	2020-06-19 11:42:18	2020-06-19	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	31740	delivery	5	40
81032	2020-06-19 11:49:19	2020-06-19	12	[{"id_menu":1,"count":1}]	10153	pick-up	0	12
81033	2020-06-19 11:50:42	2020-06-19	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31696	delivery	5	40
81034	2020-06-19 11:53:46	2020-06-19	8	[{"id_menu":5,"count":1}]	31796	delivery	5	13
81035	2020-06-19 11:54:03	2020-06-19	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	19207	delivery	5	31
81036	2020-06-19 11:57:12	2020-06-19	9	[{"id_menu":6,"count":1}]	20845	delivery	5	14
81037	2020-06-19 11:58:17	2020-06-19	14	[{"id_menu":2,"count":1}]	31803	delivery	5	19
81038	2020-06-19 12:00:26	2020-06-19	12	[{"id_menu":3,"count":1}]	3385	pick-up	0	12
81039	2020-06-19 12:01:49	2020-06-19	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	30818	delivery	5	43
81040	2020-06-19 12:06:14	2020-06-19	12	[{"id_menu":1,"count":1}]	31762	pick-up	0	12
81041	2020-06-19 12:09:20	2020-06-19	9	[{"id_menu":7,"count":1}]	10623	delivery	5	14
81042	2020-06-19 12:11:22	2020-06-19	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	6591	delivery	5	26
81043	2020-06-19 12:12:48	2020-06-19	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	31792	delivery	5	23
81044	2020-06-19 12:16:56	2020-06-19	9	[{"id_menu":7,"count":2}]	12541	pick-up	0	9
81045	2020-06-19 12:19:05	2020-06-19	14	[{"id_menu":2,"count":1}]	11191	pick-up	0	14
81046	2020-06-19 12:20:03	2020-06-19	9	[{"id_menu":7,"count":1}]	3898	pick-up	0	9
81047	2020-06-19 12:20:50	2020-06-19	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	31737	delivery	5	27
81048	2020-06-19 12:20:51	2020-06-19	12	[{"id_menu":1,"count":1}]	3835	delivery	5	17
81049	2020-06-19 12:22:05	2020-06-19	8	[{"id_menu":5,"count":1}]	29581	delivery	5	13
81050	2020-06-19 12:23:25	2020-06-19	12	[{"id_menu":1,"count":1}]	30162	delivery	5	17
81051	2020-06-19 12:24:04	2020-06-19	9	[{"id_menu":6,"count":1}]	26263	delivery	5	14
81052	2020-06-19 12:28:02	2020-06-19	12	[{"id_menu":1,"count":1}]	30455	pick-up	0	12
81053	2020-06-19 12:31:24	2020-06-19	12	[{"id_menu":3,"count":1}]	17134	delivery	5	17
81054	2020-06-19 12:31:44	2020-06-19	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	6235	pick-up	0	29
81055	2020-06-19 12:34:10	2020-06-19	8	[{"id_menu":5,"count":1}]	31867	delivery	5	13
81056	2020-06-19 12:38:07	2020-06-19	14	[{"id_menu":2,"count":1}]	10574	delivery	5	19
81057	2020-06-19 12:41:04	2020-06-19	9	[{"id_menu":6,"count":1}]	21013	delivery	5	14
81058	2020-06-19 12:41:56	2020-06-19	8	[{"id_menu":5,"count":1}]	13179	delivery	5	13
81059	2020-06-19 12:42:39	2020-06-19	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31774	delivery	5	54
81060	2020-06-19 12:43:37	2020-06-19	12	[{"id_menu":1,"count":1}]	26013	pick-up	0	12
81061	2020-06-19 12:43:40	2020-06-19	8	[{"id_menu":5,"count":1}]	31857	delivery	5	13
81062	2020-06-19 12:47:10	2020-06-19	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	31704	delivery	5	38
81063	2020-06-19 12:56:59	2020-06-19	9	[{"id_menu":6,"count":1}]	20855	delivery	5	14
81064	2020-06-19 12:57:09	2020-06-19	12	[{"id_menu":1,"count":1}]	31117	delivery	5	17
81065	2020-06-19 12:57:42	2020-06-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	16498	delivery	5	22
81066	2020-06-19 13:00:25	2020-06-19	12	[{"id_menu":1,"count":1}]	20480	delivery	5	17
81067	2020-06-19 13:02:04	2020-06-19	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	31828	delivery	5	23
81068	2020-06-19 13:05:20	2020-06-19	14	[{"id_menu":2,"count":1}]	5116	delivery	5	19
81069	2020-06-19 13:06:02	2020-06-19	9	[{"id_menu":6,"count":1}]	31814	delivery	5	14
81070	2020-06-19 13:11:18	2020-06-19	12	[{"id_menu":1,"count":2}]	3630	delivery	5	17
81071	2020-06-19 13:13:57	2020-06-19	8	[{"id_menu":5,"count":1}]	4310	delivery	5	13
81072	2020-06-19 13:17:28	2020-06-19	9	[{"id_menu":6,"count":1}]	31896	pick-up	0	9
81073	2020-06-19 13:17:39	2020-06-19	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	18658	delivery	5	34
81074	2020-06-19 13:19:10	2020-06-19	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1115	pick-up	0	21
81075	2020-06-19 13:23:35	2020-06-19	17	[{"id_menu":4,"count":1}]	31735	pick-up	0	17
81076	2020-06-19 13:26:00	2020-06-19	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1215	pick-up	0	29
81077	2020-06-19 13:27:56	2020-06-19	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	23356	delivery	5	26
81078	2020-06-19 13:36:52	2020-06-19	8	[{"id_menu":5,"count":1}]	9128	pick-up	0	8
81079	2020-06-19 13:37:37	2020-06-19	12	[{"id_menu":1,"count":1}]	3734	pick-up	0	12
81080	2020-06-19 13:38:15	2020-06-19	9	[{"id_menu":6,"count":1}]	27544	pick-up	0	9
81081	2020-06-19 13:40:38	2020-06-19	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31698	delivery	5	35
81082	2020-06-19 13:42:32	2020-06-19	12	[{"id_menu":1,"count":1}]	12894	delivery	5	17
81083	2020-06-19 13:42:54	2020-06-19	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	31777	delivery	5	31
81084	2020-06-19 13:44:16	2020-06-19	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	167	delivery	5	25
81085	2020-06-19 13:45:19	2020-06-19	9	[{"id_menu":7,"count":1}]	5781	delivery	5	14
81086	2020-06-19 13:45:45	2020-06-19	8	[{"id_menu":5,"count":1}]	7806	pick-up	0	8
81087	2020-06-19 13:47:36	2020-06-19	8	[{"id_menu":5,"count":1}]	17941	delivery	5	13
81088	2020-06-19 13:50:14	2020-06-19	9	[{"id_menu":6,"count":1}]	31703	pick-up	0	9
81089	2020-06-19 13:54:31	2020-06-19	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	16368	delivery	5	40
81090	2020-06-19 13:54:36	2020-06-19	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9981	delivery	5	53
81091	2020-06-19 13:55:51	2020-06-19	9	[{"id_menu":6,"count":1}]	31911	delivery	5	14
81092	2020-06-19 13:56:17	2020-06-19	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	18206	delivery	5	26
81093	2020-06-19 14:00:22	2020-06-19	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31764	delivery	5	48
81094	2020-06-19 14:01:32	2020-06-19	8	[{"id_menu":5,"count":1}]	1203	pick-up	0	8
81095	2020-06-19 14:02:21	2020-06-19	9	[{"id_menu":6,"count":2}]	15786	delivery	5	14
81096	2020-06-19 14:02:46	2020-06-19	9	[{"id_menu":6,"count":1}]	31690	pick-up	0	9
81097	2020-06-19 14:03:57	2020-06-19	14	[{"id_menu":2,"count":1}]	3003	pick-up	0	14
81098	2020-06-19 14:06:40	2020-06-19	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31856	delivery	5	31
81099	2020-06-19 14:06:49	2020-06-19	12	[{"id_menu":1,"count":1}]	21328	delivery	5	17
81100	2020-06-19 14:11:59	2020-06-19	12	[{"id_menu":1,"count":1}]	10717	pick-up	0	12
81101	2020-06-19 14:14:06	2020-06-19	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28832	delivery	5	34
81102	2020-06-19 14:28:28	2020-06-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":3}]	31771	delivery	5	22
81103	2020-06-19 14:30:06	2020-06-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	31904	delivery	5	28
81104	2020-06-19 14:31:59	2020-06-19	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	29608	delivery	5	40
81105	2020-06-19 14:33:10	2020-06-19	9	[{"id_menu":6,"count":2}]	31859	delivery	5	14
81106	2020-06-19 14:35:10	2020-06-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12031	pick-up	0	17
81107	2020-06-19 14:43:31	2020-06-19	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	265	pick-up	0	38
81108	2020-06-19 14:43:33	2020-06-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16287	delivery	5	23
81109	2020-06-19 14:44:30	2020-06-19	9	[{"id_menu":7,"count":1}]	21786	pick-up	0	9
81110	2020-06-19 14:44:58	2020-06-19	9	[{"id_menu":6,"count":1}]	22986	pick-up	0	9
81111	2020-06-19 14:50:31	2020-06-19	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31890	delivery	5	34
81112	2020-06-19 14:50:32	2020-06-19	12	[{"id_menu":1,"count":1}]	28914	delivery	5	17
81113	2020-06-19 14:52:29	2020-06-19	8	[{"id_menu":5,"count":1}]	31717	delivery	5	13
81114	2020-06-19 14:55:31	2020-06-19	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	28818	delivery	5	31
81115	2020-06-19 14:58:59	2020-06-19	12	[{"id_menu":3,"count":1}]	7963	pick-up	0	12
81116	2020-06-19 14:59:23	2020-06-19	9	[{"id_menu":6,"count":1}]	31731	delivery	5	14
81117	2020-06-19 15:01:19	2020-06-19	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	24706	delivery	5	37
81118	2020-06-19 15:05:29	2020-06-19	9	[{"id_menu":6,"count":1}]	21485	pick-up	0	9
81119	2020-06-19 15:08:16	2020-06-19	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	3048	pick-up	0	22
81120	2020-06-19 15:10:57	2020-06-19	9	[{"id_menu":6,"count":1}]	31818	delivery	5	14
81121	2020-06-19 15:14:06	2020-06-19	14	[{"id_menu":2,"count":1}]	23312	delivery	5	19
81122	2020-06-19 15:17:17	2020-06-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19399	delivery	5	22
81123	2020-06-19 15:20:41	2020-06-19	8	[{"id_menu":5,"count":1}]	30381	delivery	5	13
81124	2020-06-19 15:24:35	2020-06-19	9	[{"id_menu":6,"count":1}]	13082	delivery	5	14
81125	2020-06-19 15:25:39	2020-06-19	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1227	pick-up	0	21
81126	2020-06-19 15:25:41	2020-06-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	31711	delivery	5	36
81127	2020-06-19 15:28:02	2020-06-19	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31781	delivery	5	39
81128	2020-06-19 15:32:22	2020-06-19	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	14382	delivery	5	31
81129	2020-06-19 15:33:32	2020-06-19	14	[{"id_menu":2,"count":1}]	2600	pick-up	0	14
81130	2020-06-19 15:35:06	2020-06-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	31729	delivery	5	28
81131	2020-06-19 15:37:13	2020-06-19	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	20545	delivery	5	45
81132	2020-06-19 15:40:26	2020-06-19	17	[{"id_menu":4,"count":1}]	3744	delivery	5	22
81133	2020-06-19 15:44:04	2020-06-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	31724	delivery	5	22
81134	2020-06-19 15:44:50	2020-06-19	12	[{"id_menu":1,"count":1}]	31779	delivery	5	17
81135	2020-06-19 15:46:22	2020-06-19	17	[{"id_menu":4,"count":1}]	22938	pick-up	0	17
81136	2020-06-19 15:46:25	2020-06-19	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21195	delivery	5	37
81137	2020-06-19 15:48:20	2020-06-19	8	[{"id_menu":5,"count":1}]	13645	delivery	5	13
81138	2020-06-19 15:53:56	2020-06-19	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	21901	delivery	5	27
81139	2020-06-19 15:57:22	2020-06-19	12	[{"id_menu":1,"count":1}]	31860	delivery	5	17
81140	2020-06-19 15:58:07	2020-06-19	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":2}]	20965	delivery	5	34
81141	2020-06-19 15:58:46	2020-06-19	9	[{"id_menu":6,"count":1}]	31728	delivery	5	14
81142	2020-06-19 15:59:50	2020-06-19	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31858	delivery	5	37
81143	2020-06-19 16:00:33	2020-06-19	9	[{"id_menu":7,"count":1}]	19378	delivery	5	14
81144	2020-06-19 16:02:41	2020-06-19	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	31901	delivery	5	26
81145	2020-06-19 16:02:47	2020-06-19	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	29493	pick-up	0	26
81146	2020-06-19 16:03:50	2020-06-19	12	[{"id_menu":3,"count":1}]	29176	delivery	5	17
81147	2020-06-19 16:03:57	2020-06-19	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8584	delivery	5	46
81148	2020-06-19 16:10:04	2020-06-19	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	31897	delivery	5	39
81149	2020-06-19 16:10:54	2020-06-19	9	[{"id_menu":7,"count":1}]	31815	delivery	5	14
81150	2020-06-19 16:23:18	2020-06-19	9	[{"id_menu":6,"count":1}]	31845	delivery	5	14
81151	2020-06-19 16:23:53	2020-06-19	8	[{"id_menu":5,"count":1}]	31747	delivery	5	13
81152	2020-06-19 16:24:28	2020-06-19	9	[{"id_menu":7,"count":1}]	6013	delivery	5	14
81153	2020-06-19 16:24:29	2020-06-19	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4793	delivery	5	38
81154	2020-06-19 16:25:51	2020-06-19	9	[{"id_menu":6,"count":1}]	31850	delivery	5	14
81155	2020-06-19 16:26:50	2020-06-19	9	[{"id_menu":6,"count":1}]	3259	pick-up	0	9
81156	2020-06-19 16:28:28	2020-06-19	12	[{"id_menu":3,"count":1}]	29978	delivery	5	17
81157	2020-06-19 16:32:37	2020-06-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7544	delivery	5	23
81158	2020-06-19 16:35:35	2020-06-19	12	[{"id_menu":1,"count":1}]	511	pick-up	0	12
81159	2020-06-19 16:37:13	2020-06-19	9	[{"id_menu":6,"count":1}]	18304	delivery	5	14
81160	2020-06-19 16:45:54	2020-06-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":3}]	19494	delivery	5	28
81161	2020-06-19 16:50:58	2020-06-19	14	[{"id_menu":2,"count":1}]	25508	delivery	5	19
81162	2020-06-19 16:57:09	2020-06-19	9	[{"id_menu":6,"count":1}]	4172	delivery	5	14
81163	2020-06-19 17:00:16	2020-06-19	9	[{"id_menu":6,"count":1}]	31824	delivery	5	14
81164	2020-06-19 17:05:44	2020-06-19	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	31852	delivery	5	27
81165	2020-06-19 17:07:09	2020-06-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	31821	delivery	5	23
81166	2020-06-19 17:09:13	2020-06-19	9	[{"id_menu":6,"count":1}]	18424	pick-up	0	9
81167	2020-06-19 17:12:31	2020-06-19	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2248	pick-up	0	26
81168	2020-06-19 17:17:42	2020-06-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	31766	delivery	5	31
81169	2020-06-19 17:23:03	2020-06-19	17	[{"id_menu":4,"count":1}]	16084	delivery	5	22
81170	2020-06-19 17:28:37	2020-06-19	9	[{"id_menu":6,"count":1}]	11961	delivery	5	14
81171	2020-06-19 17:32:44	2020-06-19	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	31785	delivery	5	22
81172	2020-06-19 17:36:03	2020-06-19	9	[{"id_menu":6,"count":1}]	26255	pick-up	0	9
81173	2020-06-19 17:36:04	2020-06-19	9	[{"id_menu":7,"count":1}]	28288	delivery	5	14
81174	2020-06-19 17:36:07	2020-06-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24643	pick-up	0	18
81175	2020-06-19 17:36:50	2020-06-19	12	[{"id_menu":1,"count":1}]	22765	pick-up	0	12
81176	2020-06-19 17:37:25	2020-06-19	9	[{"id_menu":6,"count":1}]	20248	delivery	5	14
81177	2020-06-19 17:40:48	2020-06-19	9	[{"id_menu":6,"count":1}]	31743	delivery	5	14
81178	2020-06-19 17:43:57	2020-06-19	9	[{"id_menu":6,"count":1}]	3912	delivery	5	14
81179	2020-06-19 17:45:46	2020-06-19	14	[{"id_menu":2,"count":1}]	1681	delivery	5	19
81180	2020-06-19 17:52:36	2020-06-19	17	[{"id_menu":4,"count":1}]	17780	delivery	5	22
81181	2020-06-19 17:54:59	2020-06-19	9	[{"id_menu":6,"count":1}]	18492	delivery	5	14
81182	2020-06-19 17:55:16	2020-06-19	9	[{"id_menu":7,"count":2}]	31438	delivery	5	14
81183	2020-06-19 17:56:20	2020-06-19	9	[{"id_menu":6,"count":1}]	6965	delivery	5	14
81184	2020-06-19 17:57:38	2020-06-19	9	[{"id_menu":6,"count":1}]	31757	delivery	5	14
81185	2020-06-19 18:01:29	2020-06-19	12	[{"id_menu":3,"count":1}]	18003	delivery	5	17
81186	2020-06-19 18:06:37	2020-06-19	12	[{"id_menu":1,"count":1}]	31725	delivery	5	17
81187	2020-06-19 18:08:13	2020-06-19	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	31788	delivery	5	34
81188	2020-06-19 18:08:25	2020-06-19	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31836	delivery	5	35
81189	2020-06-19 18:08:25	2020-06-19	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	31885	delivery	5	26
81190	2020-06-19 18:18:36	2020-06-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	31722	delivery	5	28
81191	2020-06-19 18:18:38	2020-06-19	12	[{"id_menu":3,"count":1}]	24051	delivery	5	17
81192	2020-06-19 18:19:52	2020-06-19	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	16887	pick-up	0	25
81193	2020-06-19 18:19:55	2020-06-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10518	delivery	5	22
81194	2020-06-19 18:21:57	2020-06-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31723	delivery	5	23
81195	2020-06-19 18:22:52	2020-06-19	9	[{"id_menu":6,"count":1}]	1702	pick-up	0	9
81196	2020-06-19 18:23:27	2020-06-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	22315	delivery	5	28
81197	2020-06-19 18:24:09	2020-06-19	17	[{"id_menu":4,"count":1}]	21998	delivery	5	22
81198	2020-06-19 18:29:37	2020-06-19	12	[{"id_menu":1,"count":1}]	29231	pick-up	0	12
81199	2020-06-19 18:31:23	2020-06-19	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	31807	delivery	5	27
81200	2020-06-19 18:37:16	2020-06-19	12	[{"id_menu":1,"count":1}]	21617	pick-up	0	12
81201	2020-06-19 18:40:53	2020-06-19	14	[{"id_menu":2,"count":1}]	15601	delivery	5	19
81202	2020-06-19 18:43:00	2020-06-19	9	[{"id_menu":7,"count":1}]	31898	delivery	5	14
81203	2020-06-19 18:44:18	2020-06-19	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19792	delivery	5	34
81204	2020-06-19 18:49:19	2020-06-19	9	[{"id_menu":6,"count":1}]	17610	delivery	5	14
81205	2020-06-19 18:53:17	2020-06-19	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	31876	pick-up	0	21
81206	2020-06-19 18:53:57	2020-06-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6869	pick-up	0	17
81207	2020-06-19 18:54:25	2020-06-19	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	31889	delivery	5	38
81208	2020-06-19 19:02:07	2020-06-19	14	[{"id_menu":2,"count":1}]	3160	pick-up	0	14
81209	2020-06-19 19:02:14	2020-06-19	9	[{"id_menu":7,"count":1}]	6183	pick-up	0	9
81210	2020-06-19 19:06:43	2020-06-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	31775	delivery	5	28
81211	2020-06-19 19:10:23	2020-06-19	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	31811	delivery	5	46
81212	2020-06-19 19:11:12	2020-06-19	9	[{"id_menu":6,"count":1}]	26753	delivery	5	14
81213	2020-06-19 19:11:47	2020-06-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	9808	delivery	5	36
81214	2020-06-19 19:12:28	2020-06-19	12	[{"id_menu":1,"count":1}]	9210	delivery	5	17
81215	2020-06-19 19:12:42	2020-06-19	9	[{"id_menu":6,"count":1}]	1326	pick-up	0	9
81216	2020-06-19 19:13:57	2020-06-19	9	[{"id_menu":6,"count":1}]	6627	delivery	5	14
81217	2020-06-19 19:16:15	2020-06-19	14	[{"id_menu":2,"count":1}]	14172	pick-up	0	14
81218	2020-06-19 19:20:10	2020-06-19	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31754	delivery	5	34
81219	2020-06-19 19:20:17	2020-06-19	14	[{"id_menu":2,"count":1}]	7086	pick-up	0	14
81220	2020-06-19 19:23:05	2020-06-19	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	11754	delivery	5	31
81221	2020-06-19 19:23:11	2020-06-19	12	[{"id_menu":3,"count":1}]	10954	pick-up	0	12
81222	2020-06-19 19:28:39	2020-06-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31903	pick-up	0	17
81223	2020-06-19 19:30:00	2020-06-19	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":3}]	31721	delivery	5	26
81224	2020-06-19 19:30:08	2020-06-19	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	20136	delivery	5	48
81225	2020-06-19 19:41:09	2020-06-19	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	27003	delivery	5	31
81226	2020-06-19 19:42:34	2020-06-19	12	[{"id_menu":1,"count":1}]	31880	delivery	5	17
81227	2020-06-19 19:48:47	2020-06-19	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18580	delivery	5	39
81228	2020-06-19 19:52:44	2020-06-19	8	[{"id_menu":5,"count":1}]	31894	delivery	5	13
81229	2020-06-19 19:58:42	2020-06-19	17	[{"id_menu":4,"count":1}]	28213	delivery	5	22
81230	2020-06-19 19:58:45	2020-06-19	9	[{"id_menu":6,"count":1}]	18017	delivery	5	14
81231	2020-06-19 20:03:47	2020-06-19	8	[{"id_menu":5,"count":1}]	31817	delivery	5	13
81232	2020-06-19 20:06:07	2020-06-19	12	[{"id_menu":1,"count":1}]	15395	pick-up	0	12
81233	2020-06-19 20:06:19	2020-06-19	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	3851	pick-up	0	26
81234	2020-06-19 20:08:30	2020-06-19	9	[{"id_menu":6,"count":1}]	24228	delivery	5	14
81235	2020-06-19 20:10:45	2020-06-19	8	[{"id_menu":5,"count":1}]	24098	delivery	5	13
81236	2020-06-19 20:12:48	2020-06-19	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	31701	pick-up	0	21
81237	2020-06-19 20:17:05	2020-06-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	15948	delivery	5	28
81238	2020-06-19 20:18:43	2020-06-19	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	10550	delivery	5	48
81239	2020-06-19 20:19:25	2020-06-19	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2599	pick-up	0	29
81240	2020-06-19 20:21:27	2020-06-19	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	4578	pick-up	0	21
81241	2020-06-19 20:23:29	2020-06-19	17	[{"id_menu":4,"count":1}]	18161	delivery	5	22
81242	2020-06-19 20:23:46	2020-06-19	17	[{"id_menu":4,"count":1}]	31820	delivery	5	22
81243	2020-06-19 20:24:14	2020-06-19	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	31830	delivery	5	43
81244	2020-06-19 20:25:29	2020-06-19	9	[{"id_menu":7,"count":1}]	21910	pick-up	0	9
81245	2020-06-19 20:27:11	2020-06-19	9	[{"id_menu":7,"count":1}]	12043	delivery	5	14
81246	2020-06-19 20:28:09	2020-06-19	9	[{"id_menu":7,"count":1}]	23696	pick-up	0	9
81247	2020-06-19 20:30:47	2020-06-19	9	[{"id_menu":6,"count":1}]	24646	delivery	5	14
81248	2020-06-19 20:32:27	2020-06-19	12	[{"id_menu":3,"count":1}]	11843	delivery	5	17
81249	2020-06-19 20:35:01	2020-06-19	9	[{"id_menu":7,"count":1}]	31708	delivery	5	14
81250	2020-06-19 20:38:26	2020-06-19	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	11046	delivery	5	31
81251	2020-06-19 20:43:21	2020-06-19	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	31895	delivery	5	26
81252	2020-06-19 20:45:32	2020-06-19	14	[{"id_menu":2,"count":1}]	29699	delivery	5	19
81253	2020-06-19 20:49:16	2020-06-19	12	[{"id_menu":1,"count":1}]	31806	delivery	5	17
81254	2020-06-19 20:51:06	2020-06-19	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9235	delivery	5	36
81255	2020-06-19 20:51:51	2020-06-19	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31692	delivery	5	34
81256	2020-06-19 20:53:35	2020-06-19	17	[{"id_menu":4,"count":1}]	23405	delivery	5	22
81257	2020-06-19 20:56:03	2020-06-19	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	26037	delivery	5	26
81258	2020-06-19 20:56:07	2020-06-19	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	4829	delivery	5	34
81259	2020-06-19 20:56:13	2020-06-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	27861	delivery	5	36
81260	2020-06-19 20:58:02	2020-06-19	12	[{"id_menu":1,"count":1}]	22214	pick-up	0	12
81261	2020-06-19 20:58:05	2020-06-19	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	12578	pick-up	0	21
81262	2020-06-19 21:01:00	2020-06-19	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	22408	delivery	5	26
81263	2020-06-19 21:04:56	2020-06-19	17	[{"id_menu":4,"count":1}]	1176	delivery	5	22
81264	2020-06-19 21:08:44	2020-06-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	31744	delivery	5	36
81265	2020-06-19 21:09:49	2020-06-19	14	[{"id_menu":2,"count":1}]	31847	delivery	5	19
81266	2020-06-19 21:17:12	2020-06-19	12	[{"id_menu":1,"count":1}]	781	pick-up	0	12
81267	2020-06-19 21:17:51	2020-06-19	12	[{"id_menu":3,"count":1}]	25815	delivery	5	17
81268	2020-06-19 21:18:26	2020-06-19	9	[{"id_menu":7,"count":2}]	16179	delivery	5	14
81269	2020-06-19 21:22:17	2020-06-19	9	[{"id_menu":7,"count":1}]	31874	delivery	5	14
81270	2020-06-19 21:23:29	2020-06-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	10598	pick-up	0	31
81271	2020-06-19 21:24:29	2020-06-19	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3579	delivery	5	39
81272	2020-06-19 21:24:48	2020-06-19	17	[{"id_menu":4,"count":1}]	7040	pick-up	0	17
81273	2020-06-19 21:30:10	2020-06-19	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	11737	pick-up	0	29
81274	2020-06-19 21:48:13	2020-06-19	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	4190	delivery	5	31
81275	2020-06-19 21:49:16	2020-06-19	12	[{"id_menu":3,"count":1}]	18561	delivery	5	17
81276	2020-06-19 21:50:01	2020-06-19	12	[{"id_menu":1,"count":1}]	31853	delivery	5	17
81277	2020-06-19 21:59:32	2020-06-19	12	[{"id_menu":3,"count":1}]	31833	pick-up	0	12
81278	2020-06-19 21:59:58	2020-06-19	29	[{"id_menu":3,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31772	delivery	5	34
81279	2020-06-19 22:00:25	2020-06-19	9	[{"id_menu":7,"count":1}]	31727	delivery	5	14
81280	2020-06-19 22:02:38	2020-06-19	9	[{"id_menu":6,"count":1}]	7688	pick-up	0	9
81281	2020-06-19 22:09:36	2020-06-19	8	[{"id_menu":5,"count":1}]	31810	delivery	5	13
81282	2020-06-19 22:10:44	2020-06-19	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	11677	delivery	5	25
81283	2020-06-19 22:10:47	2020-06-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	5643	delivery	5	36
81284	2020-06-19 22:10:47	2020-06-19	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	18476	delivery	5	26
81285	2020-06-19 22:11:03	2020-06-19	12	[{"id_menu":3,"count":1}]	26187	delivery	5	17
81286	2020-06-19 22:12:15	2020-06-19	12	[{"id_menu":3,"count":1}]	31875	delivery	5	17
81287	2020-06-19 22:12:44	2020-06-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	31800	delivery	5	22
81288	2020-06-19 22:13:46	2020-06-19	12	[{"id_menu":1,"count":1}]	31842	delivery	5	17
81289	2020-06-19 22:16:46	2020-06-19	8	[{"id_menu":5,"count":1}]	31709	pick-up	0	8
81290	2020-06-19 22:19:54	2020-06-19	17	[{"id_menu":4,"count":1}]	31769	delivery	5	22
81291	2020-06-19 22:31:27	2020-06-19	17	[{"id_menu":4,"count":1}]	6163	delivery	5	22
81292	2020-06-19 22:36:55	2020-06-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	115	pick-up	0	31
81293	2020-06-19 22:44:30	2020-06-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	11929	delivery	5	28
81294	2020-06-19 22:45:48	2020-06-19	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31714	delivery	5	52
81295	2020-06-19 22:46:13	2020-06-19	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	13630	delivery	5	43
81296	2020-06-19 22:47:52	2020-06-19	17	[{"id_menu":4,"count":1}]	31805	delivery	5	22
81297	2020-06-19 22:55:17	2020-06-19	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	31862	delivery	5	51
81298	2020-06-19 23:04:07	2020-06-19	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2855	pick-up	0	30
81299	2020-06-19 23:10:13	2020-06-19	8	[{"id_menu":5,"count":1}]	19160	delivery	5	13
81300	2020-06-19 23:12:07	2020-06-19	12	[{"id_menu":1,"count":1}]	31789	delivery	5	17
81301	2020-06-19 23:13:47	2020-06-19	8	[{"id_menu":5,"count":1}]	26526	pick-up	0	8
81302	2020-06-19 23:14:12	2020-06-19	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14054	pick-up	0	40
81303	2020-06-19 23:17:06	2020-06-19	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13173	pick-up	0	31
81304	2020-06-19 23:17:35	2020-06-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	30679	delivery	5	22
81305	2020-06-19 23:17:54	2020-06-19	12	[{"id_menu":1,"count":1}]	4546	delivery	5	17
81306	2020-06-19 23:18:47	2020-06-19	17	[{"id_menu":4,"count":2}]	19363	delivery	5	22
81307	2020-06-19 23:18:49	2020-06-19	9	[{"id_menu":6,"count":1}]	31843	pick-up	0	9
81308	2020-06-19 23:24:38	2020-06-19	12	[{"id_menu":3,"count":1}]	31783	delivery	5	17
81309	2020-06-19 23:24:44	2020-06-19	17	[{"id_menu":4,"count":1}]	2526	pick-up	0	17
81310	2020-06-19 23:31:55	2020-06-19	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	31912	delivery	5	31
81311	2020-06-19 23:38:22	2020-06-19	9	[{"id_menu":6,"count":1}]	31877	pick-up	0	9
81312	2020-06-19 23:38:50	2020-06-19	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31838	delivery	5	37
81313	2020-06-19 23:41:32	2020-06-19	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9457	delivery	5	35
81314	2020-06-19 23:42:34	2020-06-19	17	[{"id_menu":4,"count":1}]	14	delivery	5	22
81315	2020-06-19 23:46:02	2020-06-19	12	[{"id_menu":1,"count":1}]	26742	delivery	5	17
81316	2020-06-19 23:51:32	2020-06-19	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	31706	delivery	5	35
81317	2020-06-19 23:51:48	2020-06-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	31699	delivery	5	22
81318	2020-06-19 23:52:51	2020-06-19	14	[{"id_menu":2,"count":1}]	2372	delivery	5	19
81319	2020-06-19 23:57:41	2020-06-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	31916	pick-up	0	23
81320	2020-06-20 00:00:17	2020-06-20	9	[{"id_menu":7,"count":1}]	14228	delivery	5	14
81321	2020-06-20 00:00:50	2020-06-20	14	[{"id_menu":2,"count":1}]	32033	delivery	5	19
81322	2020-06-20 00:02:59	2020-06-20	12	[{"id_menu":1,"count":1}]	424	pick-up	0	12
81323	2020-06-20 00:04:14	2020-06-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	32071	delivery	5	28
81324	2020-06-20 00:05:10	2020-06-20	12	[{"id_menu":1,"count":1}]	4395	delivery	5	17
81325	2020-06-20 00:08:21	2020-06-20	12	[{"id_menu":3,"count":1}]	17402	pick-up	0	12
81326	2020-06-20 00:08:53	2020-06-20	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	18566	delivery	5	22
81327	2020-06-20 00:09:35	2020-06-20	12	[{"id_menu":3,"count":1}]	21070	delivery	5	17
81328	2020-06-20 00:09:53	2020-06-20	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	19867	delivery	5	45
81329	2020-06-20 00:10:26	2020-06-20	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	14635	delivery	5	26
81330	2020-06-20 00:10:28	2020-06-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	25974	delivery	5	28
81331	2020-06-20 00:17:53	2020-06-20	9	[{"id_menu":6,"count":1}]	32120	delivery	5	14
81332	2020-06-20 00:17:55	2020-06-20	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	32013	delivery	5	31
81333	2020-06-20 00:22:00	2020-06-20	17	[{"id_menu":4,"count":1}]	138	pick-up	0	17
81334	2020-06-20 00:22:50	2020-06-20	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29614	delivery	5	40
81335	2020-06-20 00:23:42	2020-06-20	9	[{"id_menu":7,"count":1}]	16592	pick-up	0	9
81336	2020-06-20 00:24:11	2020-06-20	14	[{"id_menu":2,"count":1}]	29252	delivery	5	19
81337	2020-06-20 00:24:34	2020-06-20	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	4165	delivery	5	39
81338	2020-06-20 00:25:19	2020-06-20	17	[{"id_menu":4,"count":1}]	32079	pick-up	0	17
81339	2020-06-20 00:28:43	2020-06-20	17	[{"id_menu":4,"count":1}]	28346	delivery	5	22
81340	2020-06-20 00:31:58	2020-06-20	8	[{"id_menu":5,"count":1}]	10942	pick-up	0	8
81341	2020-06-20 00:36:22	2020-06-20	8	[{"id_menu":5,"count":1}]	32066	delivery	5	13
81342	2020-06-20 00:36:40	2020-06-20	9	[{"id_menu":6,"count":2}]	32052	delivery	5	14
81343	2020-06-20 00:37:56	2020-06-20	9	[{"id_menu":6,"count":1}]	32017	delivery	5	14
81344	2020-06-20 00:38:50	2020-06-20	8	[{"id_menu":5,"count":2}]	13570	delivery	5	13
81345	2020-06-20 00:39:46	2020-06-20	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15773	delivery	5	53
81346	2020-06-20 00:40:53	2020-06-20	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	31962	delivery	5	42
81347	2020-06-20 00:41:30	2020-06-20	12	[{"id_menu":1,"count":2}]	22758	pick-up	0	12
81348	2020-06-20 00:50:50	2020-06-20	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32074	delivery	5	47
81349	2020-06-20 00:51:06	2020-06-20	8	[{"id_menu":5,"count":1}]	25044	delivery	5	13
81350	2020-06-20 00:54:26	2020-06-20	9	[{"id_menu":7,"count":1}]	16239	delivery	5	14
81351	2020-06-20 00:55:17	2020-06-20	8	[{"id_menu":5,"count":1}]	18149	delivery	5	13
81352	2020-06-20 00:57:48	2020-06-20	9	[{"id_menu":6,"count":2}]	22564	delivery	5	14
81353	2020-06-20 00:58:05	2020-06-20	17	[{"id_menu":4,"count":1}]	7	delivery	5	22
81354	2020-06-20 00:58:18	2020-06-20	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	23989	delivery	5	25
81355	2020-06-20 01:00:15	2020-06-20	8	[{"id_menu":5,"count":1}]	2190	pick-up	0	8
81356	2020-06-20 01:02:26	2020-06-20	12	[{"id_menu":3,"count":1}]	3361	pick-up	0	12
81357	2020-06-20 01:02:34	2020-06-20	8	[{"id_menu":5,"count":1}]	32132	delivery	5	13
81358	2020-06-20 01:03:39	2020-06-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23571	pick-up	0	17
81359	2020-06-20 01:07:16	2020-06-20	9	[{"id_menu":6,"count":1}]	18157	pick-up	0	9
81360	2020-06-20 01:09:05	2020-06-20	9	[{"id_menu":7,"count":1}]	11849	delivery	5	14
81361	2020-06-20 01:09:22	2020-06-20	12	[{"id_menu":3,"count":1}]	31918	delivery	5	17
81362	2020-06-20 01:10:32	2020-06-20	12	[{"id_menu":1,"count":1}]	31941	delivery	5	17
81363	2020-06-20 01:11:14	2020-06-20	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8038	delivery	5	36
81364	2020-06-20 01:11:39	2020-06-20	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	24534	pick-up	0	21
81365	2020-06-20 01:12:30	2020-06-20	12	[{"id_menu":3,"count":1}]	30872	delivery	5	17
81366	2020-06-20 01:14:38	2020-06-20	9	[{"id_menu":6,"count":1}]	32098	delivery	5	14
81367	2020-06-20 01:17:36	2020-06-20	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14349	delivery	5	48
81368	2020-06-20 01:17:57	2020-06-20	9	[{"id_menu":6,"count":1}]	2875	pick-up	0	9
81369	2020-06-20 01:18:46	2020-06-20	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	32131	delivery	5	26
81370	2020-06-20 01:19:45	2020-06-20	9	[{"id_menu":6,"count":1}]	1101	delivery	5	14
81371	2020-06-20 01:19:45	2020-06-20	9	[{"id_menu":6,"count":1}]	3168	pick-up	0	9
81372	2020-06-20 01:20:58	2020-06-20	17	[{"id_menu":4,"count":1}]	24466	delivery	5	22
81373	2020-06-20 01:21:22	2020-06-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	31951	delivery	5	28
81374	2020-06-20 01:24:14	2020-06-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	32070	delivery	5	28
81375	2020-06-20 01:26:35	2020-06-20	17	[{"id_menu":4,"count":1}]	3883	delivery	5	22
81376	2020-06-20 01:30:45	2020-06-20	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	32035	delivery	5	31
81377	2020-06-20 01:34:30	2020-06-20	14	[{"id_menu":2,"count":1}]	31999	delivery	5	19
81378	2020-06-20 01:35:17	2020-06-20	9	[{"id_menu":6,"count":1}]	32067	delivery	5	14
81379	2020-06-20 01:42:58	2020-06-20	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11735	delivery	5	49
81380	2020-06-20 01:43:58	2020-06-20	8	[{"id_menu":5,"count":1}]	29773	delivery	5	13
81381	2020-06-20 01:44:54	2020-06-20	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	32001	delivery	5	29
81382	2020-06-20 01:46:06	2020-06-20	9	[{"id_menu":6,"count":1}]	18640	delivery	5	14
81383	2020-06-20 01:52:04	2020-06-20	12	[{"id_menu":1,"count":1}]	32061	delivery	5	17
81384	2020-06-20 01:55:29	2020-06-20	8	[{"id_menu":5,"count":1}]	32084	delivery	5	13
81385	2020-06-20 01:59:49	2020-06-20	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32077	delivery	5	39
81386	2020-06-20 02:00:36	2020-06-20	17	[{"id_menu":4,"count":1}]	477	pick-up	0	17
81387	2020-06-20 02:01:03	2020-06-20	14	[{"id_menu":2,"count":1}]	1727	pick-up	0	14
81388	2020-06-20 02:01:37	2020-06-20	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	31959	delivery	5	43
81389	2020-06-20 02:02:27	2020-06-20	9	[{"id_menu":6,"count":1}]	5704	delivery	5	14
81390	2020-06-20 02:08:37	2020-06-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9128	delivery	5	22
81391	2020-06-20 02:10:10	2020-06-20	9	[{"id_menu":7,"count":1}]	10482	pick-up	0	9
81392	2020-06-20 02:10:38	2020-06-20	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1803	pick-up	0	25
81393	2020-06-20 02:11:03	2020-06-20	8	[{"id_menu":5,"count":1}]	17138	pick-up	0	8
81394	2020-06-20 02:14:02	2020-06-20	17	[{"id_menu":4,"count":1}]	16288	delivery	5	22
81395	2020-06-20 02:17:14	2020-06-20	9	[{"id_menu":7,"count":2}]	32130	delivery	5	14
81396	2020-06-20 02:25:25	2020-06-20	12	[{"id_menu":3,"count":1}]	21840	delivery	5	17
81397	2020-06-20 02:28:22	2020-06-20	9	[{"id_menu":7,"count":1}]	2795	pick-up	0	9
81398	2020-06-20 02:30:21	2020-06-20	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	25296	pick-up	0	26
81399	2020-06-20 02:30:48	2020-06-20	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	29358	delivery	5	36
81400	2020-06-20 02:32:05	2020-06-20	9	[{"id_menu":6,"count":1}]	32011	delivery	5	14
81401	2020-06-20 02:34:12	2020-06-20	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	28230	delivery	5	31
81402	2020-06-20 02:34:46	2020-06-20	9	[{"id_menu":7,"count":2}]	31942	delivery	5	14
81403	2020-06-20 02:35:45	2020-06-20	9	[{"id_menu":6,"count":1}]	5966	delivery	5	14
81404	2020-06-20 02:41:00	2020-06-20	14	[{"id_menu":2,"count":1}]	641	delivery	5	19
81405	2020-06-20 02:46:03	2020-06-20	12	[{"id_menu":1,"count":1}]	26361	delivery	5	17
81406	2020-06-20 02:47:52	2020-06-20	14	[{"id_menu":2,"count":1}]	31923	delivery	5	19
81407	2020-06-20 02:49:26	2020-06-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11640	delivery	5	23
81408	2020-06-20 02:50:12	2020-06-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32037	delivery	5	23
81409	2020-06-20 02:51:34	2020-06-20	9	[{"id_menu":6,"count":1}]	29738	delivery	5	14
81410	2020-06-20 02:53:53	2020-06-20	14	[{"id_menu":2,"count":1}]	9638	delivery	5	19
81411	2020-06-20 02:54:05	2020-06-20	9	[{"id_menu":6,"count":1}]	5244	delivery	5	14
81412	2020-06-20 02:55:13	2020-06-20	12	[{"id_menu":1,"count":1}]	26150	pick-up	0	12
81413	2020-06-20 02:59:32	2020-06-20	8	[{"id_menu":5,"count":1}]	9215	delivery	5	13
81414	2020-06-20 03:02:27	2020-06-20	14	[{"id_menu":2,"count":1}]	12156	delivery	5	19
81415	2020-06-20 03:02:38	2020-06-20	9	[{"id_menu":7,"count":1}]	26815	delivery	5	14
81416	2020-06-20 03:02:52	2020-06-20	8	[{"id_menu":5,"count":1}]	31981	delivery	5	13
81417	2020-06-20 03:03:51	2020-06-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	32108	delivery	5	28
81418	2020-06-20 03:05:28	2020-06-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	32003	delivery	5	22
81419	2020-06-20 03:05:32	2020-06-20	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	18865	delivery	5	26
81420	2020-06-20 03:05:40	2020-06-20	9	[{"id_menu":6,"count":1}]	542	delivery	5	14
81421	2020-06-20 03:07:39	2020-06-20	17	[{"id_menu":4,"count":1}]	7084	delivery	5	22
81422	2020-06-20 03:07:50	2020-06-20	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	32030	delivery	5	39
81423	2020-06-20 03:15:00	2020-06-20	9	[{"id_menu":7,"count":1}]	3876	delivery	5	14
81424	2020-06-20 03:17:00	2020-06-20	9	[{"id_menu":7,"count":1}]	346	pick-up	0	9
81425	2020-06-20 03:24:46	2020-06-20	9	[{"id_menu":6,"count":1}]	32055	delivery	5	14
81426	2020-06-20 03:26:42	2020-06-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	31979	delivery	5	28
81427	2020-06-20 03:26:42	2020-06-20	9	[{"id_menu":6,"count":1}]	8610	pick-up	0	9
81428	2020-06-20 03:27:33	2020-06-20	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31917	delivery	5	37
81429	2020-06-20 03:29:47	2020-06-20	9	[{"id_menu":6,"count":2}]	32135	delivery	5	14
81430	2020-06-20 03:31:01	2020-06-20	9	[{"id_menu":7,"count":1}]	32043	delivery	5	14
81431	2020-06-20 03:36:10	2020-06-20	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5907	pick-up	0	26
81432	2020-06-20 03:36:12	2020-06-20	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15377	delivery	5	39
81433	2020-06-20 03:37:39	2020-06-20	9	[{"id_menu":7,"count":1}]	32029	delivery	5	14
81434	2020-06-20 03:37:48	2020-06-20	14	[{"id_menu":2,"count":1}]	3115	pick-up	0	14
81435	2020-06-20 03:39:48	2020-06-20	14	[{"id_menu":2,"count":1}]	18353	pick-up	0	14
81436	2020-06-20 03:40:00	2020-06-20	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	32142	delivery	5	26
81437	2020-06-20 03:44:46	2020-06-20	9	[{"id_menu":6,"count":1}]	1424	delivery	5	14
81438	2020-06-20 03:47:16	2020-06-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	21121	pick-up	0	23
81439	2020-06-20 03:49:24	2020-06-20	17	[{"id_menu":4,"count":1}]	7829	delivery	5	22
81440	2020-06-20 03:50:18	2020-06-20	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14844	delivery	5	48
81441	2020-06-20 03:52:49	2020-06-20	12	[{"id_menu":3,"count":1}]	31993	delivery	5	17
81442	2020-06-20 03:53:20	2020-06-20	9	[{"id_menu":7,"count":1}]	2524	pick-up	0	9
81443	2020-06-20 03:54:13	2020-06-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	23538	delivery	5	28
81444	2020-06-20 03:58:50	2020-06-20	12	[{"id_menu":1,"count":1}]	988	delivery	5	17
81445	2020-06-20 04:01:26	2020-06-20	17	[{"id_menu":4,"count":1}]	906	pick-up	0	17
81446	2020-06-20 04:02:06	2020-06-20	14	[{"id_menu":2,"count":2}]	12350	pick-up	0	14
81447	2020-06-20 04:04:38	2020-06-20	9	[{"id_menu":7,"count":1}]	20558	delivery	5	14
81448	2020-06-20 04:05:31	2020-06-20	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	17799	delivery	5	22
81449	2020-06-20 04:06:51	2020-06-20	9	[{"id_menu":6,"count":1}]	31975	delivery	5	14
81450	2020-06-20 04:07:43	2020-06-20	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	31939	delivery	5	31
81451	2020-06-20 04:09:41	2020-06-20	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	31978	delivery	5	48
81452	2020-06-20 04:10:46	2020-06-20	8	[{"id_menu":5,"count":1}]	5668	pick-up	0	8
81453	2020-06-20 04:12:43	2020-06-20	17	[{"id_menu":4,"count":1}]	19019	delivery	5	22
81454	2020-06-20 04:14:30	2020-06-20	9	[{"id_menu":7,"count":1}]	11315	delivery	5	14
81455	2020-06-20 04:15:14	2020-06-20	9	[{"id_menu":6,"count":1}]	4132	delivery	5	14
81456	2020-06-20 04:15:43	2020-06-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	30576	delivery	5	22
81457	2020-06-20 04:16:21	2020-06-20	9	[{"id_menu":6,"count":1}]	32140	delivery	5	14
81458	2020-06-20 04:17:54	2020-06-20	9	[{"id_menu":6,"count":2}]	28441	delivery	5	14
81459	2020-06-20 04:20:07	2020-06-20	14	[{"id_menu":2,"count":1}]	9116	delivery	5	19
81460	2020-06-20 04:20:53	2020-06-20	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	32148	delivery	5	26
81461	2020-06-20 04:22:19	2020-06-20	9	[{"id_menu":6,"count":1}]	32089	delivery	5	14
81462	2020-06-20 04:24:06	2020-06-20	8	[{"id_menu":5,"count":1}]	31936	delivery	5	13
81463	2020-06-20 04:24:11	2020-06-20	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	19123	delivery	5	40
81464	2020-06-20 04:27:02	2020-06-20	9	[{"id_menu":7,"count":1}]	31120	delivery	5	14
81465	2020-06-20 04:28:50	2020-06-20	38	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	31073	pick-up	0	38
81466	2020-06-20 04:29:51	2020-06-20	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	28776	delivery	5	25
81467	2020-06-20 04:31:16	2020-06-20	8	[{"id_menu":5,"count":1}]	9986	delivery	5	13
81468	2020-06-20 04:31:17	2020-06-20	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	5958	delivery	5	31
81469	2020-06-20 04:31:50	2020-06-20	9	[{"id_menu":6,"count":1}]	31935	delivery	5	14
81470	2020-06-20 04:33:48	2020-06-20	8	[{"id_menu":5,"count":1}]	22367	delivery	5	13
81471	2020-06-20 04:39:21	2020-06-20	9	[{"id_menu":6,"count":1}]	32022	pick-up	0	9
81472	2020-06-20 04:40:22	2020-06-20	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":2}]	3052	pick-up	0	26
81473	2020-06-20 04:40:52	2020-06-20	8	[{"id_menu":5,"count":1}]	1528	pick-up	0	8
81474	2020-06-20 04:41:20	2020-06-20	14	[{"id_menu":2,"count":1}]	17064	delivery	5	19
81475	2020-06-20 04:42:34	2020-06-20	12	[{"id_menu":1,"count":1}]	32038	delivery	5	17
81476	2020-06-20 04:44:40	2020-06-20	14	[{"id_menu":2,"count":1}]	9763	delivery	5	19
81477	2020-06-20 04:46:29	2020-06-20	12	[{"id_menu":1,"count":1}]	996	delivery	5	17
81478	2020-06-20 04:47:23	2020-06-20	8	[{"id_menu":5,"count":1}]	32007	delivery	5	13
81479	2020-06-20 04:48:21	2020-06-20	8	[{"id_menu":5,"count":1}]	31431	delivery	5	13
81480	2020-06-20 04:50:05	2020-06-20	17	[{"id_menu":4,"count":1}]	32041	delivery	5	22
81481	2020-06-20 04:54:30	2020-06-20	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	32068	delivery	5	38
81482	2020-06-20 04:55:30	2020-06-20	14	[{"id_menu":2,"count":1}]	13667	delivery	5	19
81483	2020-06-20 05:04:26	2020-06-20	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23986	delivery	5	22
81484	2020-06-20 05:10:52	2020-06-20	9	[{"id_menu":7,"count":1}]	8622	delivery	5	14
81485	2020-06-20 05:18:20	2020-06-20	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3518	delivery	5	46
81486	2020-06-20 05:18:39	2020-06-20	17	[{"id_menu":4,"count":1}]	31881	delivery	5	22
81487	2020-06-20 05:19:13	2020-06-20	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	22952	pick-up	0	39
81488	2020-06-20 05:20:09	2020-06-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	18374	delivery	5	28
81489	2020-06-20 05:21:07	2020-06-20	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9451	delivery	5	31
81490	2020-06-20 05:22:20	2020-06-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32128	delivery	5	23
81491	2020-06-20 05:26:28	2020-06-20	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	29343	delivery	5	31
81492	2020-06-20 05:32:03	2020-06-20	14	[{"id_menu":2,"count":1}]	31966	delivery	5	19
81493	2020-06-20 05:32:41	2020-06-20	12	[{"id_menu":1,"count":1}]	32109	delivery	5	17
81494	2020-06-20 05:33:44	2020-06-20	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8835	delivery	5	43
81495	2020-06-20 05:38:16	2020-06-20	9	[{"id_menu":6,"count":1}]	13371	delivery	5	14
81496	2020-06-20 05:43:30	2020-06-20	9	[{"id_menu":6,"count":1}]	1467	delivery	5	14
81497	2020-06-20 05:44:03	2020-06-20	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	32104	delivery	5	25
81498	2020-06-20 05:44:09	2020-06-20	9	[{"id_menu":7,"count":1}]	13861	delivery	5	14
81499	2020-06-20 05:49:36	2020-06-20	14	[{"id_menu":2,"count":1}]	17182	delivery	5	19
81500	2020-06-20 05:50:23	2020-06-20	12	[{"id_menu":1,"count":1}]	32087	delivery	5	17
81501	2020-06-20 05:51:15	2020-06-20	9	[{"id_menu":7,"count":1}]	20168	delivery	5	14
81502	2020-06-20 05:52:55	2020-06-20	14	[{"id_menu":2,"count":1}]	22313	pick-up	0	14
81503	2020-06-20 05:58:39	2020-06-20	17	[{"id_menu":4,"count":1}]	14568	delivery	5	22
81504	2020-06-20 06:01:23	2020-06-20	9	[{"id_menu":6,"count":1}]	32125	delivery	5	14
81505	2020-06-20 06:06:17	2020-06-20	12	[{"id_menu":3,"count":1}]	31963	delivery	5	17
81506	2020-06-20 06:09:48	2020-06-20	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18699	delivery	5	51
81507	2020-06-20 06:12:23	2020-06-20	12	[{"id_menu":1,"count":1}]	8877	delivery	5	17
81508	2020-06-20 06:14:28	2020-06-20	9	[{"id_menu":6,"count":1}]	32073	delivery	5	14
81509	2020-06-20 06:14:35	2020-06-20	8	[{"id_menu":5,"count":2}]	11109	delivery	5	13
81510	2020-06-20 06:15:04	2020-06-20	9	[{"id_menu":7,"count":1}]	20042	delivery	5	14
81511	2020-06-20 06:15:20	2020-06-20	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	17570	delivery	5	26
81512	2020-06-20 06:19:07	2020-06-20	17	[{"id_menu":4,"count":1}]	27428	delivery	5	22
81513	2020-06-20 06:20:40	2020-06-20	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	24948	delivery	5	57
81514	2020-06-20 06:21:06	2020-06-20	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2392	pick-up	0	22
81515	2020-06-20 06:26:45	2020-06-20	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9804	delivery	5	30
81516	2020-06-20 06:29:55	2020-06-20	9	[{"id_menu":7,"count":1}]	216	pick-up	0	9
81517	2020-06-20 06:31:08	2020-06-20	17	[{"id_menu":4,"count":1}]	32008	pick-up	0	17
81518	2020-06-20 06:31:25	2020-06-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	24000	pick-up	0	23
81519	2020-06-20 06:34:15	2020-06-20	9	[{"id_menu":7,"count":1}]	31969	delivery	5	14
81520	2020-06-20 06:36:05	2020-06-20	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	10474	delivery	5	45
81521	2020-06-20 06:41:31	2020-06-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13188	delivery	5	23
81522	2020-06-20 06:43:58	2020-06-20	9	[{"id_menu":6,"count":2}]	32136	delivery	5	14
81523	2020-06-20 06:47:09	2020-06-20	9	[{"id_menu":6,"count":1}]	10917	delivery	5	14
81524	2020-06-20 06:49:22	2020-06-20	17	[{"id_menu":4,"count":1}]	5320	delivery	5	22
81525	2020-06-20 06:50:10	2020-06-20	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	11213	delivery	5	35
81526	2020-06-20 06:54:27	2020-06-20	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	13370	pick-up	0	26
81527	2020-06-20 06:55:13	2020-06-20	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	32126	delivery	5	22
81528	2020-06-20 06:56:03	2020-06-20	9	[{"id_menu":7,"count":1}]	10177	delivery	5	14
81529	2020-06-20 06:58:31	2020-06-20	12	[{"id_menu":1,"count":1}]	826	pick-up	0	12
81530	2020-06-20 07:05:58	2020-06-20	12	[{"id_menu":3,"count":1}]	5972	pick-up	0	12
81531	2020-06-20 07:08:29	2020-06-20	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	28139	delivery	5	26
81532	2020-06-20 07:11:37	2020-06-20	12	[{"id_menu":3,"count":1}]	32062	delivery	5	17
81533	2020-06-20 07:11:43	2020-06-20	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	31214	pick-up	0	26
81534	2020-06-20 07:11:52	2020-06-20	9	[{"id_menu":7,"count":3}]	31998	delivery	5	14
81535	2020-06-20 07:11:53	2020-06-20	14	[{"id_menu":2,"count":1}]	12343	delivery	5	19
81536	2020-06-20 07:13:15	2020-06-20	12	[{"id_menu":1,"count":2}]	29075	delivery	5	17
81537	2020-06-20 07:14:44	2020-06-20	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	18332	delivery	5	22
81538	2020-06-20 07:16:18	2020-06-20	9	[{"id_menu":7,"count":1}]	5141	pick-up	0	9
81539	2020-06-20 07:19:20	2020-06-20	8	[{"id_menu":5,"count":1}]	14676	delivery	5	13
81540	2020-06-20 07:20:00	2020-06-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	23680	delivery	5	28
81541	2020-06-20 07:20:40	2020-06-20	12	[{"id_menu":3,"count":1}]	28364	delivery	5	17
81542	2020-06-20 07:22:27	2020-06-20	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	32032	delivery	5	34
81543	2020-06-20 07:23:07	2020-06-20	8	[{"id_menu":5,"count":1}]	32082	delivery	5	13
81544	2020-06-20 07:23:49	2020-06-20	17	[{"id_menu":4,"count":1}]	12717	pick-up	0	17
81545	2020-06-20 07:25:07	2020-06-20	17	[{"id_menu":4,"count":1}]	16246	pick-up	0	17
81546	2020-06-20 07:26:48	2020-06-20	14	[{"id_menu":2,"count":1}]	3545	delivery	5	19
81547	2020-06-20 07:27:33	2020-06-20	9	[{"id_menu":7,"count":1}]	12645	delivery	5	14
81548	2020-06-20 07:28:20	2020-06-20	12	[{"id_menu":3,"count":1}]	2227	pick-up	0	12
81549	2020-06-20 07:28:43	2020-06-20	17	[{"id_menu":4,"count":1}]	10721	delivery	5	22
81550	2020-06-20 07:36:58	2020-06-20	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	6330	delivery	5	31
81551	2020-06-20 07:38:49	2020-06-20	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	31995	delivery	5	38
81552	2020-06-20 07:39:37	2020-06-20	9	[{"id_menu":7,"count":1}]	7094	pick-up	0	9
81553	2020-06-20 07:46:22	2020-06-20	12	[{"id_menu":1,"count":1}]	14673	pick-up	0	12
81554	2020-06-20 07:48:49	2020-06-20	8	[{"id_menu":5,"count":1}]	523	delivery	5	13
81555	2020-06-20 07:52:03	2020-06-20	9	[{"id_menu":6,"count":1}]	23425	delivery	5	14
81556	2020-06-20 07:54:25	2020-06-20	14	[{"id_menu":2,"count":1}]	14358	pick-up	0	14
81557	2020-06-20 07:55:28	2020-06-20	12	[{"id_menu":3,"count":1}]	1755	pick-up	0	12
81558	2020-06-20 08:00:16	2020-06-20	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	32083	delivery	5	38
81559	2020-06-20 08:04:14	2020-06-20	14	[{"id_menu":2,"count":1}]	1448	delivery	5	19
81560	2020-06-20 08:10:06	2020-06-20	17	[{"id_menu":4,"count":1}]	15440	pick-up	0	17
81561	2020-06-20 08:10:29	2020-06-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	29576	delivery	5	28
81562	2020-06-20 08:12:48	2020-06-20	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	26218	delivery	5	40
81563	2020-06-20 08:13:11	2020-06-20	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11535	delivery	5	54
81564	2020-06-20 08:14:14	2020-06-20	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9014	delivery	5	22
81565	2020-06-20 08:16:26	2020-06-20	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	28768	delivery	5	39
81566	2020-06-20 08:17:47	2020-06-20	12	[{"id_menu":1,"count":1}]	32047	delivery	5	17
81567	2020-06-20 08:18:19	2020-06-20	17	[{"id_menu":4,"count":1}]	31957	pick-up	0	17
81568	2020-06-20 08:20:10	2020-06-20	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	10327	delivery	5	26
81569	2020-06-20 08:20:14	2020-06-20	9	[{"id_menu":6,"count":1}]	4607	delivery	5	14
81570	2020-06-20 08:22:38	2020-06-20	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	26355	delivery	5	40
81571	2020-06-20 08:22:44	2020-06-20	12	[{"id_menu":1,"count":1}]	1736	pick-up	0	12
81572	2020-06-20 08:22:59	2020-06-20	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	31958	delivery	5	30
81573	2020-06-20 08:24:44	2020-06-20	17	[{"id_menu":4,"count":1}]	32141	delivery	5	22
81574	2020-06-20 08:30:06	2020-06-20	9	[{"id_menu":7,"count":1}]	31940	delivery	5	14
81575	2020-06-20 08:30:46	2020-06-20	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	32046	delivery	5	34
81576	2020-06-20 08:32:33	2020-06-20	9	[{"id_menu":6,"count":2}]	19097	delivery	5	14
81577	2020-06-20 08:34:39	2020-06-20	12	[{"id_menu":1,"count":1}]	31919	delivery	5	17
81578	2020-06-20 08:37:50	2020-06-20	9	[{"id_menu":7,"count":1}]	22066	delivery	5	14
81579	2020-06-20 08:39:18	2020-06-20	12	[{"id_menu":3,"count":1}]	27426	delivery	5	17
81580	2020-06-20 08:40:24	2020-06-20	14	[{"id_menu":2,"count":1}]	9244	delivery	5	19
81581	2020-06-20 08:42:40	2020-06-20	9	[{"id_menu":7,"count":1}]	4652	pick-up	0	9
81582	2020-06-20 08:44:04	2020-06-20	8	[{"id_menu":5,"count":1}]	18976	pick-up	0	8
81583	2020-06-20 08:45:18	2020-06-20	8	[{"id_menu":5,"count":1}]	20366	delivery	5	13
81584	2020-06-20 08:45:52	2020-06-20	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	32102	delivery	5	34
81585	2020-06-20 08:47:43	2020-06-20	14	[{"id_menu":2,"count":1}]	16501	pick-up	0	14
81586	2020-06-20 08:49:33	2020-06-20	9	[{"id_menu":7,"count":1}]	32153	delivery	5	14
81587	2020-06-20 08:50:29	2020-06-20	17	[{"id_menu":4,"count":1}]	26110	delivery	5	22
81588	2020-06-20 08:50:33	2020-06-20	9	[{"id_menu":6,"count":1}]	27200	delivery	5	14
81589	2020-06-20 08:54:46	2020-06-20	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	10342	pick-up	0	34
81590	2020-06-20 08:55:29	2020-06-20	9	[{"id_menu":7,"count":1}]	27662	delivery	5	14
81591	2020-06-20 08:58:00	2020-06-20	17	[{"id_menu":4,"count":1}]	27861	pick-up	0	17
81592	2020-06-20 09:04:21	2020-06-20	14	[{"id_menu":2,"count":1}]	23914	delivery	5	19
81593	2020-06-20 09:04:39	2020-06-20	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	32040	delivery	5	42
81594	2020-06-20 09:04:41	2020-06-20	8	[{"id_menu":5,"count":1}]	32121	pick-up	0	8
81595	2020-06-20 09:05:11	2020-06-20	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3683	delivery	5	49
81596	2020-06-20 09:07:30	2020-06-20	17	[{"id_menu":4,"count":1}]	27049	delivery	5	22
81597	2020-06-20 09:10:25	2020-06-20	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	6232	delivery	5	27
81598	2020-06-20 09:14:10	2020-06-20	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	24128	delivery	5	26
81599	2020-06-20 09:16:00	2020-06-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	32058	delivery	5	28
81600	2020-06-20 09:22:14	2020-06-20	9	[{"id_menu":6,"count":1}]	1490	pick-up	0	9
81601	2020-06-20 09:25:05	2020-06-20	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5138	pick-up	0	25
81602	2020-06-20 09:31:59	2020-06-20	12	[{"id_menu":1,"count":1}]	31949	delivery	5	17
81603	2020-06-20 09:36:10	2020-06-20	9	[{"id_menu":6,"count":1}]	27295	delivery	5	14
81604	2020-06-20 09:37:08	2020-06-20	9	[{"id_menu":6,"count":1}]	28315	delivery	5	14
81605	2020-06-20 09:42:01	2020-06-20	9	[{"id_menu":7,"count":1}]	31947	delivery	5	14
81606	2020-06-20 09:44:14	2020-06-20	8	[{"id_menu":5,"count":1}]	2536	pick-up	0	8
81607	2020-06-20 09:45:48	2020-06-20	14	[{"id_menu":2,"count":1}]	24943	pick-up	0	14
81608	2020-06-20 09:48:14	2020-06-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	32137	pick-up	0	17
81609	2020-06-20 09:48:33	2020-06-20	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	18828	pick-up	0	21
81610	2020-06-20 09:50:22	2020-06-20	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	21039	delivery	5	30
81611	2020-06-20 09:54:40	2020-06-20	14	[{"id_menu":2,"count":1}]	1649	pick-up	0	14
81612	2020-06-20 09:55:38	2020-06-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	32123	delivery	5	22
81613	2020-06-20 09:56:00	2020-06-20	9	[{"id_menu":7,"count":1}]	32086	delivery	5	14
81614	2020-06-20 09:56:50	2020-06-20	8	[{"id_menu":5,"count":1}]	31811	delivery	5	13
81615	2020-06-20 09:57:28	2020-06-20	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	32145	delivery	5	45
81616	2020-06-20 09:59:12	2020-06-20	8	[{"id_menu":5,"count":2}]	32044	delivery	5	13
81617	2020-06-20 09:59:24	2020-06-20	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32129	delivery	5	36
81618	2020-06-20 10:00:24	2020-06-20	9	[{"id_menu":7,"count":1}]	11349	delivery	5	14
81619	2020-06-20 10:04:10	2020-06-20	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32114	delivery	5	51
81620	2020-06-20 10:04:56	2020-06-20	9	[{"id_menu":7,"count":1}]	9552	delivery	5	14
81621	2020-06-20 10:06:58	2020-06-20	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6049	pick-up	0	26
81622	2020-06-20 10:07:29	2020-06-20	12	[{"id_menu":3,"count":1}]	5994	delivery	5	17
81623	2020-06-20 10:11:32	2020-06-20	9	[{"id_menu":7,"count":1}]	31937	delivery	5	14
81624	2020-06-20 10:13:54	2020-06-20	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	30162	delivery	5	36
81625	2020-06-20 10:14:32	2020-06-20	14	[{"id_menu":2,"count":1}]	31933	pick-up	0	14
81626	2020-06-20 10:14:33	2020-06-20	12	[{"id_menu":3,"count":1}]	31950	pick-up	0	12
81627	2020-06-20 10:19:12	2020-06-20	12	[{"id_menu":1,"count":1}]	23890	pick-up	0	12
81628	2020-06-20 10:21:20	2020-06-20	9	[{"id_menu":6,"count":1}]	31938	delivery	5	14
81629	2020-06-20 10:22:15	2020-06-20	8	[{"id_menu":5,"count":1}]	32009	delivery	5	13
81630	2020-06-20 10:26:07	2020-06-20	12	[{"id_menu":3,"count":1}]	18163	delivery	5	17
81631	2020-06-20 10:27:42	2020-06-20	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	8201	delivery	5	40
81632	2020-06-20 10:30:21	2020-06-20	17	[{"id_menu":4,"count":1}]	708	delivery	5	22
81633	2020-06-20 10:32:19	2020-06-20	9	[{"id_menu":7,"count":1}]	22443	delivery	5	14
81634	2020-06-20 10:33:52	2020-06-20	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	31987	delivery	5	31
81635	2020-06-20 10:38:18	2020-06-20	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31931	delivery	5	34
81636	2020-06-20 10:45:41	2020-06-20	17	[{"id_menu":4,"count":1}]	2259	pick-up	0	17
81637	2020-06-20 10:51:04	2020-06-20	9	[{"id_menu":6,"count":1}]	32118	delivery	5	14
81638	2020-06-20 10:54:27	2020-06-20	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27510	delivery	5	39
81639	2020-06-20 10:56:03	2020-06-20	17	[{"id_menu":4,"count":1}]	12716	delivery	5	22
81640	2020-06-20 11:01:19	2020-06-20	17	[{"id_menu":4,"count":1}]	32019	delivery	5	22
81641	2020-06-20 11:04:22	2020-06-20	9	[{"id_menu":7,"count":1}]	31985	pick-up	0	9
81642	2020-06-20 11:11:54	2020-06-20	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	31932	delivery	5	43
81643	2020-06-20 11:13:44	2020-06-20	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	26108	pick-up	0	29
81644	2020-06-20 11:18:08	2020-06-20	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4052	delivery	5	39
81645	2020-06-20 11:19:33	2020-06-20	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	32004	delivery	5	23
81646	2020-06-20 11:23:04	2020-06-20	9	[{"id_menu":6,"count":1}]	32065	delivery	5	14
81647	2020-06-20 11:23:25	2020-06-20	9	[{"id_menu":7,"count":1}]	32139	delivery	5	14
81648	2020-06-20 11:23:45	2020-06-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	32103	delivery	5	28
81649	2020-06-20 11:24:36	2020-06-20	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1283	delivery	5	31
81650	2020-06-20 11:27:25	2020-06-20	12	[{"id_menu":3,"count":1}]	15608	delivery	5	17
81651	2020-06-20 11:29:51	2020-06-20	9	[{"id_menu":6,"count":2}]	21603	delivery	5	14
81652	2020-06-20 11:29:58	2020-06-20	9	[{"id_menu":7,"count":1}]	28241	delivery	5	14
81653	2020-06-20 11:31:39	2020-06-20	14	[{"id_menu":2,"count":2}]	1404	delivery	5	19
81654	2020-06-20 11:39:17	2020-06-20	12	[{"id_menu":3,"count":1}]	11618	delivery	5	17
81655	2020-06-20 11:42:05	2020-06-20	14	[{"id_menu":2,"count":1}]	9920	pick-up	0	14
81656	2020-06-20 11:46:12	2020-06-20	9	[{"id_menu":6,"count":1}]	8388	pick-up	0	9
81657	2020-06-20 11:47:39	2020-06-20	12	[{"id_menu":1,"count":1}]	31982	delivery	5	17
81658	2020-06-20 11:48:17	2020-06-20	14	[{"id_menu":2,"count":1}]	8699	delivery	5	19
81659	2020-06-20 11:49:03	2020-06-20	8	[{"id_menu":5,"count":1}]	7933	delivery	5	13
81725	2020-06-20 14:14:39	2020-06-20	17	[{"id_menu":4,"count":1}]	32110	delivery	5	22
81660	2020-06-20 11:53:22	2020-06-20	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32099	delivery	5	43
81661	2020-06-20 11:54:23	2020-06-20	8	[{"id_menu":5,"count":1}]	23320	delivery	5	13
81662	2020-06-20 11:54:30	2020-06-20	8	[{"id_menu":5,"count":1}]	2540	pick-up	0	8
81663	2020-06-20 11:55:24	2020-06-20	9	[{"id_menu":6,"count":1}]	32097	delivery	5	14
81664	2020-06-20 11:55:33	2020-06-20	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	25799	delivery	5	27
81665	2020-06-20 11:57:16	2020-06-20	12	[{"id_menu":3,"count":1}]	15780	pick-up	0	12
81666	2020-06-20 12:07:15	2020-06-20	17	[{"id_menu":4,"count":1}]	21325	delivery	5	22
81667	2020-06-20 12:08:57	2020-06-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19033	delivery	5	23
81668	2020-06-20 12:10:06	2020-06-20	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	32000	delivery	5	43
81669	2020-06-20 12:12:38	2020-06-20	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	28047	delivery	5	31
81670	2020-06-20 12:15:19	2020-06-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	28737	delivery	5	28
81671	2020-06-20 12:16:52	2020-06-20	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	14113	delivery	5	39
81672	2020-06-20 12:18:53	2020-06-20	12	[{"id_menu":3,"count":1}]	32002	pick-up	0	12
81673	2020-06-20 12:19:20	2020-06-20	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5970	delivery	5	30
81674	2020-06-20 12:24:33	2020-06-20	8	[{"id_menu":5,"count":1}]	16181	delivery	5	13
81675	2020-06-20 12:25:01	2020-06-20	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32085	delivery	5	34
81676	2020-06-20 12:25:33	2020-06-20	8	[{"id_menu":5,"count":1}]	32107	delivery	5	13
81677	2020-06-20 12:28:49	2020-06-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	24949	delivery	5	28
81678	2020-06-20 12:33:00	2020-06-20	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32122	delivery	5	22
81679	2020-06-20 12:35:05	2020-06-20	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7211	delivery	5	43
81680	2020-06-20 12:42:01	2020-06-20	22	[{"id_menu":2,"count":3},{"id_menu":5,"count":1}]	1568	pick-up	0	22
81681	2020-06-20 12:43:16	2020-06-20	9	[{"id_menu":6,"count":1}]	4199	delivery	5	14
81682	2020-06-20 12:44:33	2020-06-20	9	[{"id_menu":6,"count":1}]	31921	delivery	5	14
81683	2020-06-20 12:51:42	2020-06-20	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25417	delivery	5	35
81684	2020-06-20 12:53:06	2020-06-20	17	[{"id_menu":4,"count":1}]	707	delivery	5	22
81685	2020-06-20 12:53:45	2020-06-20	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32059	delivery	5	45
81686	2020-06-20 13:07:35	2020-06-20	9	[{"id_menu":6,"count":1}]	15737	delivery	5	14
81687	2020-06-20 13:09:16	2020-06-20	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	32042	delivery	5	39
81688	2020-06-20 13:10:14	2020-06-20	17	[{"id_menu":4,"count":1}]	21975	pick-up	0	17
81689	2020-06-20 13:13:43	2020-06-20	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15902	delivery	5	31
81690	2020-06-20 13:16:16	2020-06-20	14	[{"id_menu":2,"count":1}]	3754	delivery	5	19
81691	2020-06-20 13:17:35	2020-06-20	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	27913	delivery	5	53
81692	2020-06-20 13:17:50	2020-06-20	14	[{"id_menu":2,"count":1}]	31967	delivery	5	19
81693	2020-06-20 13:18:22	2020-06-20	9	[{"id_menu":6,"count":1}]	32021	delivery	5	14
81694	2020-06-20 13:22:30	2020-06-20	17	[{"id_menu":4,"count":1}]	16017	delivery	5	22
81695	2020-06-20 13:22:58	2020-06-20	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	10957	delivery	5	36
81696	2020-06-20 13:31:03	2020-06-20	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	21770	delivery	5	31
81697	2020-06-20 13:32:30	2020-06-20	8	[{"id_menu":5,"count":1}]	32060	delivery	5	13
81698	2020-06-20 13:33:12	2020-06-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	27831	delivery	5	28
81699	2020-06-20 13:33:21	2020-06-20	9	[{"id_menu":7,"count":3}]	31485	delivery	5	14
81700	2020-06-20 13:35:02	2020-06-20	17	[{"id_menu":4,"count":1}]	25873	delivery	5	22
81701	2020-06-20 13:35:19	2020-06-20	14	[{"id_menu":2,"count":1}]	30039	delivery	5	19
81702	2020-06-20 13:37:21	2020-06-20	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	26095	pick-up	0	26
81703	2020-06-20 13:38:28	2020-06-20	14	[{"id_menu":2,"count":1}]	11183	pick-up	0	14
81704	2020-06-20 13:38:52	2020-06-20	14	[{"id_menu":2,"count":1}]	12614	delivery	5	19
81705	2020-06-20 13:39:23	2020-06-20	12	[{"id_menu":1,"count":1}]	29771	delivery	5	17
81706	2020-06-20 13:44:35	2020-06-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	32127	delivery	5	22
81707	2020-06-20 13:48:17	2020-06-20	17	[{"id_menu":4,"count":1}]	31974	delivery	5	22
81708	2020-06-20 13:49:48	2020-06-20	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28131	delivery	5	31
81709	2020-06-20 13:56:24	2020-06-20	14	[{"id_menu":2,"count":1}]	8377	delivery	5	19
81710	2020-06-20 13:56:32	2020-06-20	14	[{"id_menu":2,"count":1}]	32091	pick-up	0	14
81711	2020-06-20 13:58:38	2020-06-20	8	[{"id_menu":5,"count":1}]	32050	delivery	5	13
81712	2020-06-20 13:59:07	2020-06-20	17	[{"id_menu":4,"count":1}]	1473	pick-up	0	17
81713	2020-06-20 14:01:40	2020-06-20	12	[{"id_menu":1,"count":1}]	31946	delivery	5	17
81714	2020-06-20 14:04:29	2020-06-20	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	8714	delivery	5	22
81715	2020-06-20 14:06:36	2020-06-20	17	[{"id_menu":4,"count":1}]	11667	delivery	5	22
81716	2020-06-20 14:09:17	2020-06-20	9	[{"id_menu":7,"count":1}]	32045	delivery	5	14
81717	2020-06-20 14:09:42	2020-06-20	12	[{"id_menu":3,"count":1}]	20379	pick-up	0	12
81718	2020-06-20 14:09:44	2020-06-20	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	25853	delivery	5	31
81719	2020-06-20 14:10:12	2020-06-20	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	11795	pick-up	0	35
81720	2020-06-20 14:10:47	2020-06-20	9	[{"id_menu":6,"count":1}]	229	delivery	5	14
81721	2020-06-20 14:12:07	2020-06-20	12	[{"id_menu":1,"count":1}]	32133	pick-up	0	12
81722	2020-06-20 14:13:08	2020-06-20	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7031	delivery	5	45
81723	2020-06-20 14:13:30	2020-06-20	12	[{"id_menu":3,"count":1}]	14086	pick-up	0	12
81724	2020-06-20 14:13:54	2020-06-20	8	[{"id_menu":5,"count":1}]	27558	delivery	5	13
81726	2020-06-20 14:15:20	2020-06-20	12	[{"id_menu":3,"count":1}]	32054	delivery	5	17
81727	2020-06-20 14:15:33	2020-06-20	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	32152	delivery	5	26
81728	2020-06-20 14:19:21	2020-06-20	14	[{"id_menu":2,"count":1}]	24848	pick-up	0	14
81729	2020-06-20 14:19:26	2020-06-20	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	28252	pick-up	0	40
81730	2020-06-20 14:23:35	2020-06-20	17	[{"id_menu":4,"count":1}]	32056	delivery	5	22
81731	2020-06-20 14:24:59	2020-06-20	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	32057	delivery	5	36
81732	2020-06-20 14:25:24	2020-06-20	8	[{"id_menu":5,"count":1}]	8597	delivery	5	13
81733	2020-06-20 14:25:54	2020-06-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	27601	delivery	5	28
81734	2020-06-20 14:31:14	2020-06-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	19706	delivery	5	28
81735	2020-06-20 14:33:59	2020-06-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	8317	delivery	5	28
81736	2020-06-20 14:34:47	2020-06-20	9	[{"id_menu":6,"count":1}]	32147	delivery	5	14
81737	2020-06-20 14:36:35	2020-06-20	12	[{"id_menu":1,"count":1}]	32026	delivery	5	17
81738	2020-06-20 14:38:26	2020-06-20	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8187	delivery	5	48
81739	2020-06-20 14:39:47	2020-06-20	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	9267	delivery	5	36
81740	2020-06-20 14:40:01	2020-06-20	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	11228	delivery	5	39
81741	2020-06-20 14:40:29	2020-06-20	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2187	delivery	5	31
81742	2020-06-20 14:45:34	2020-06-20	12	[{"id_menu":1,"count":1}]	192	pick-up	0	12
81743	2020-06-20 14:47:33	2020-06-20	14	[{"id_menu":2,"count":1}]	3682	delivery	5	19
81744	2020-06-20 14:48:50	2020-06-20	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	32094	delivery	5	28
81745	2020-06-20 14:49:15	2020-06-20	17	[{"id_menu":4,"count":1}]	12124	pick-up	0	17
81746	2020-06-20 14:56:36	2020-06-20	14	[{"id_menu":2,"count":1}]	31952	delivery	5	19
81747	2020-06-20 15:02:32	2020-06-20	9	[{"id_menu":7,"count":1}]	4007	pick-up	0	9
81748	2020-06-20 15:05:51	2020-06-20	9	[{"id_menu":6,"count":1}]	9088	delivery	5	14
81749	2020-06-20 15:06:16	2020-06-20	9	[{"id_menu":6,"count":1}]	3419	pick-up	0	9
81750	2020-06-20 15:09:43	2020-06-20	9	[{"id_menu":7,"count":1}]	31977	delivery	5	14
81751	2020-06-20 15:10:22	2020-06-20	8	[{"id_menu":5,"count":1}]	4436	pick-up	0	8
81752	2020-06-20 15:14:07	2020-06-20	9	[{"id_menu":6,"count":1}]	11038	delivery	5	14
81753	2020-06-20 15:16:09	2020-06-20	9	[{"id_menu":6,"count":1}]	30588	delivery	5	14
81754	2020-06-20 15:17:49	2020-06-20	8	[{"id_menu":5,"count":1}]	31922	delivery	5	13
81755	2020-06-20 15:20:06	2020-06-20	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	31994	delivery	5	26
81756	2020-06-20 15:20:51	2020-06-20	14	[{"id_menu":2,"count":2}]	32023	delivery	5	19
81757	2020-06-20 15:21:02	2020-06-20	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	18672	delivery	5	39
81758	2020-06-20 15:22:25	2020-06-20	17	[{"id_menu":4,"count":1}]	18797	delivery	5	22
81759	2020-06-20 15:22:51	2020-06-20	9	[{"id_menu":6,"count":1}]	21536	delivery	5	14
81760	2020-06-20 15:26:30	2020-06-20	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	32111	pick-up	0	26
81761	2020-06-20 15:28:01	2020-06-20	8	[{"id_menu":5,"count":1}]	29108	delivery	5	13
81762	2020-06-20 15:29:01	2020-06-20	17	[{"id_menu":4,"count":1}]	26659	delivery	5	22
81763	2020-06-20 15:30:24	2020-06-20	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	293	pick-up	0	21
81764	2020-06-20 15:31:23	2020-06-20	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	19054	delivery	5	43
81765	2020-06-20 15:35:24	2020-06-20	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27889	delivery	5	45
81766	2020-06-20 15:38:22	2020-06-20	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	11522	delivery	5	34
81767	2020-06-20 15:39:09	2020-06-20	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	18228	pick-up	0	20
81768	2020-06-20 15:39:45	2020-06-20	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12327	delivery	5	37
81769	2020-06-20 15:41:06	2020-06-20	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	8484	delivery	5	26
81770	2020-06-20 15:42:03	2020-06-20	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	3352	pick-up	0	26
81771	2020-06-20 15:43:16	2020-06-20	9	[{"id_menu":6,"count":1}]	1462	pick-up	0	9
81772	2020-06-20 15:47:42	2020-06-20	9	[{"id_menu":6,"count":2}]	623	pick-up	0	9
81773	2020-06-20 15:47:52	2020-06-20	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	31970	delivery	5	31
81774	2020-06-20 15:48:33	2020-06-20	9	[{"id_menu":6,"count":1}]	32112	delivery	5	14
81775	2020-06-20 15:49:18	2020-06-20	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	32143	delivery	5	31
81776	2020-06-20 15:52:15	2020-06-20	9	[{"id_menu":7,"count":1}]	32014	delivery	5	14
81777	2020-06-20 15:52:39	2020-06-20	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14476	delivery	5	31
81778	2020-06-20 15:53:53	2020-06-20	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7819	delivery	5	42
81779	2020-06-20 15:55:31	2020-06-20	8	[{"id_menu":5,"count":1}]	32100	delivery	5	13
81780	2020-06-20 15:56:10	2020-06-20	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	10622	pick-up	0	40
81781	2020-06-20 15:56:27	2020-06-20	9	[{"id_menu":6,"count":1}]	13902	delivery	5	14
81782	2020-06-20 16:00:35	2020-06-20	9	[{"id_menu":6,"count":1}]	32150	delivery	5	14
81783	2020-06-20 16:01:41	2020-06-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	27621	delivery	5	22
81784	2020-06-20 16:06:00	2020-06-20	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	20579	delivery	5	26
81785	2020-06-20 16:11:40	2020-06-20	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	32146	delivery	5	35
81786	2020-06-20 16:12:37	2020-06-20	8	[{"id_menu":5,"count":1}]	10215	delivery	5	13
81787	2020-06-20 16:15:23	2020-06-20	14	[{"id_menu":2,"count":1}]	2613	pick-up	0	14
81788	2020-06-20 16:21:23	2020-06-20	14	[{"id_menu":2,"count":1}]	4735	delivery	5	19
81789	2020-06-20 16:21:32	2020-06-20	9	[{"id_menu":6,"count":1}]	31928	delivery	5	14
81790	2020-06-20 16:28:17	2020-06-20	12	[{"id_menu":3,"count":2}]	32092	pick-up	0	12
81791	2020-06-20 16:29:45	2020-06-20	14	[{"id_menu":2,"count":1}]	18317	delivery	5	19
81792	2020-06-20 16:30:11	2020-06-20	8	[{"id_menu":5,"count":1}]	2264	delivery	5	13
81793	2020-06-20 16:32:39	2020-06-20	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	27863	pick-up	0	29
81794	2020-06-20 16:32:51	2020-06-20	8	[{"id_menu":5,"count":2}]	31986	delivery	5	13
81795	2020-06-20 16:35:06	2020-06-20	8	[{"id_menu":5,"count":1}]	18425	pick-up	0	8
81796	2020-06-20 16:36:13	2020-06-20	8	[{"id_menu":5,"count":1}]	29947	delivery	5	13
81797	2020-06-20 16:36:29	2020-06-20	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	12770	delivery	5	26
81798	2020-06-20 16:41:23	2020-06-20	9	[{"id_menu":7,"count":1}]	32151	delivery	5	14
81799	2020-06-20 16:43:56	2020-06-20	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	13854	delivery	5	45
81800	2020-06-20 16:44:33	2020-06-20	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	4089	pick-up	0	26
81801	2020-06-20 16:47:36	2020-06-20	12	[{"id_menu":3,"count":1}]	12906	delivery	5	17
81802	2020-06-20 16:48:52	2020-06-20	9	[{"id_menu":7,"count":2}]	31990	delivery	5	14
81803	2020-06-20 16:49:22	2020-06-20	8	[{"id_menu":5,"count":1}]	32005	delivery	5	13
81804	2020-06-20 16:50:44	2020-06-20	9	[{"id_menu":7,"count":1}]	18826	delivery	5	14
81805	2020-06-20 16:50:52	2020-06-20	9	[{"id_menu":7,"count":1}]	32093	delivery	5	14
81806	2020-06-20 16:53:35	2020-06-20	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	15752	pick-up	0	29
81807	2020-06-20 16:53:48	2020-06-20	8	[{"id_menu":5,"count":1}]	10254	delivery	5	13
81808	2020-06-20 16:54:54	2020-06-20	9	[{"id_menu":6,"count":1}]	9357	delivery	5	14
81809	2020-06-20 16:55:35	2020-06-20	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	32149	delivery	5	30
81810	2020-06-20 16:55:58	2020-06-20	9	[{"id_menu":6,"count":1}]	32024	delivery	5	14
81811	2020-06-20 16:59:23	2020-06-20	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	9390	delivery	5	40
81812	2020-06-20 17:02:37	2020-06-20	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25257	delivery	5	35
81813	2020-06-20 17:03:26	2020-06-20	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	4871	delivery	5	31
81814	2020-06-20 17:07:32	2020-06-20	9	[{"id_menu":7,"count":1}]	20408	delivery	5	14
81815	2020-06-20 17:10:24	2020-06-20	9	[{"id_menu":7,"count":1}]	506	pick-up	0	9
81816	2020-06-20 17:11:35	2020-06-20	12	[{"id_menu":1,"count":1}]	2935	pick-up	0	12
81817	2020-06-20 17:13:03	2020-06-20	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10480	pick-up	0	17
81818	2020-06-20 17:13:13	2020-06-20	9	[{"id_menu":7,"count":1}]	23232	delivery	5	14
81819	2020-06-20 17:13:23	2020-06-20	21	[{"id_menu":1,"count":3},{"id_menu":7,"count":1}]	29763	delivery	5	26
81820	2020-06-20 17:15:58	2020-06-20	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	31924	delivery	5	38
81821	2020-06-20 17:21:58	2020-06-20	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32138	delivery	5	51
81822	2020-06-20 17:23:21	2020-06-20	17	[{"id_menu":4,"count":1}]	16230	delivery	5	22
81823	2020-06-20 17:26:31	2020-06-20	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	13507	delivery	5	45
81824	2020-06-20 17:26:59	2020-06-20	9	[{"id_menu":7,"count":1}]	371	pick-up	0	9
81825	2020-06-20 17:28:22	2020-06-20	9	[{"id_menu":6,"count":1}]	32048	delivery	5	14
81826	2020-06-20 17:34:47	2020-06-20	9	[{"id_menu":7,"count":1}]	10588	delivery	5	14
81827	2020-06-20 17:46:08	2020-06-20	14	[{"id_menu":2,"count":1}]	19486	pick-up	0	14
81828	2020-06-20 17:50:59	2020-06-20	17	[{"id_menu":4,"count":1}]	32144	pick-up	0	17
81829	2020-06-20 17:56:04	2020-06-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	32031	delivery	5	22
81830	2020-06-20 17:56:28	2020-06-20	9	[{"id_menu":7,"count":1}]	32020	delivery	5	14
81831	2020-06-20 17:56:42	2020-06-20	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31988	delivery	5	40
81832	2020-06-20 17:59:26	2020-06-20	14	[{"id_menu":2,"count":1}]	32015	delivery	5	19
81833	2020-06-20 18:01:27	2020-06-20	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2535	delivery	5	30
81834	2020-06-20 18:03:34	2020-06-20	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30107	delivery	5	35
81835	2020-06-20 18:04:06	2020-06-20	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	32101	delivery	5	45
81836	2020-06-20 18:04:21	2020-06-20	12	[{"id_menu":1,"count":1}]	16469	pick-up	0	12
81837	2020-06-20 18:04:52	2020-06-20	17	[{"id_menu":4,"count":1}]	15449	pick-up	0	17
81838	2020-06-20 18:05:10	2020-06-20	9	[{"id_menu":6,"count":1}]	16415	delivery	5	14
81839	2020-06-20 18:07:05	2020-06-20	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	23109	delivery	5	45
81840	2020-06-20 18:15:22	2020-06-20	12	[{"id_menu":3,"count":1}]	13537	pick-up	0	12
81841	2020-06-20 18:16:07	2020-06-20	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	23432	pick-up	0	21
81842	2020-06-20 18:16:45	2020-06-20	8	[{"id_menu":5,"count":1}]	25389	delivery	5	13
81843	2020-06-20 18:16:49	2020-06-20	8	[{"id_menu":5,"count":1}]	32096	delivery	5	13
81844	2020-06-20 18:20:54	2020-06-20	17	[{"id_menu":4,"count":1}]	16091	delivery	5	22
81845	2020-06-20 18:21:13	2020-06-20	9	[{"id_menu":7,"count":1}]	9784	delivery	5	14
81846	2020-06-20 18:24:40	2020-06-20	12	[{"id_menu":3,"count":1}]	12169	delivery	5	17
81847	2020-06-20 18:27:44	2020-06-20	9	[{"id_menu":6,"count":1}]	3205	pick-up	0	9
81848	2020-06-20 18:29:07	2020-06-20	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	5190	delivery	5	26
81849	2020-06-20 18:29:33	2020-06-20	8	[{"id_menu":5,"count":1}]	9174	delivery	5	13
81850	2020-06-20 18:29:52	2020-06-20	14	[{"id_menu":2,"count":1}]	31976	delivery	5	19
81851	2020-06-20 18:33:50	2020-06-20	9	[{"id_menu":7,"count":1}]	31965	delivery	5	14
81852	2020-06-20 18:34:49	2020-06-20	8	[{"id_menu":5,"count":1}]	19143	delivery	5	13
81853	2020-06-20 18:35:00	2020-06-20	9	[{"id_menu":6,"count":1}]	14668	delivery	5	14
81854	2020-06-20 18:36:18	2020-06-20	9	[{"id_menu":6,"count":1}]	14259	delivery	5	14
81855	2020-06-20 18:38:21	2020-06-20	9	[{"id_menu":7,"count":1}]	32076	pick-up	0	9
81856	2020-06-20 18:39:10	2020-06-20	12	[{"id_menu":3,"count":1}]	26502	delivery	5	17
81857	2020-06-20 18:39:13	2020-06-20	14	[{"id_menu":2,"count":1}]	17087	delivery	5	19
81858	2020-06-20 18:48:01	2020-06-20	12	[{"id_menu":3,"count":1}]	30607	delivery	5	17
81859	2020-06-20 18:48:53	2020-06-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	10858	delivery	5	28
81860	2020-06-20 18:49:27	2020-06-20	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	32006	delivery	5	37
81861	2020-06-20 18:51:39	2020-06-20	12	[{"id_menu":1,"count":1}]	32025	pick-up	0	12
81862	2020-06-20 18:55:08	2020-06-20	12	[{"id_menu":1,"count":1}]	19669	delivery	5	17
81863	2020-06-20 19:02:21	2020-06-20	9	[{"id_menu":6,"count":2}]	10643	delivery	5	14
81864	2020-06-20 19:02:22	2020-06-20	9	[{"id_menu":6,"count":1}]	21492	delivery	5	14
81865	2020-06-20 19:04:51	2020-06-20	9	[{"id_menu":6,"count":1}]	31926	delivery	5	14
81866	2020-06-20 19:06:31	2020-06-20	9	[{"id_menu":7,"count":1}]	23990	delivery	5	14
81867	2020-06-20 19:07:21	2020-06-20	9	[{"id_menu":6,"count":1}]	31925	pick-up	0	9
81868	2020-06-20 19:10:30	2020-06-20	14	[{"id_menu":2,"count":1}]	28078	delivery	5	19
81869	2020-06-20 19:15:15	2020-06-20	14	[{"id_menu":2,"count":1}]	21516	delivery	5	19
81870	2020-06-20 19:15:24	2020-06-20	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	13025	pick-up	0	29
81871	2020-06-20 19:15:33	2020-06-20	8	[{"id_menu":5,"count":1}]	10331	delivery	5	13
81872	2020-06-20 19:20:02	2020-06-20	12	[{"id_menu":3,"count":1}]	21562	delivery	5	17
81873	2020-06-20 19:20:40	2020-06-20	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	15139	delivery	5	42
81874	2020-06-20 19:21:37	2020-06-20	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3420	pick-up	0	26
81875	2020-06-20 19:21:45	2020-06-20	9	[{"id_menu":7,"count":1}]	29678	pick-up	0	9
81876	2020-06-20 19:22:10	2020-06-20	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	31930	delivery	5	26
81877	2020-06-20 19:22:29	2020-06-20	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	21617	delivery	5	29
81878	2020-06-20 19:24:50	2020-06-20	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	32016	delivery	5	36
81879	2020-06-20 19:27:28	2020-06-20	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	32078	delivery	5	26
81880	2020-06-20 19:28:12	2020-06-20	14	[{"id_menu":2,"count":1}]	21142	delivery	5	19
81881	2020-06-20 19:28:34	2020-06-20	9	[{"id_menu":6,"count":1}]	32106	delivery	5	14
81882	2020-06-20 19:29:03	2020-06-20	8	[{"id_menu":5,"count":1}]	31954	delivery	5	13
81883	2020-06-20 19:30:25	2020-06-20	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	31961	delivery	5	26
81884	2020-06-20 19:32:02	2020-06-20	12	[{"id_menu":3,"count":1}]	32095	delivery	5	17
81885	2020-06-20 19:32:43	2020-06-20	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	31953	delivery	5	40
81886	2020-06-20 19:39:56	2020-06-20	12	[{"id_menu":1,"count":1}]	8962	delivery	5	17
81887	2020-06-20 19:40:08	2020-06-20	14	[{"id_menu":2,"count":1}]	32154	delivery	5	19
81888	2020-06-20 19:41:28	2020-06-20	9	[{"id_menu":6,"count":1}]	26813	delivery	5	14
81889	2020-06-20 19:41:42	2020-06-20	12	[{"id_menu":1,"count":1}]	2567	pick-up	0	12
81890	2020-06-20 19:45:19	2020-06-20	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2507	delivery	5	27
81891	2020-06-20 19:46:41	2020-06-20	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":3}]	27557	pick-up	0	26
81892	2020-06-20 19:47:37	2020-06-20	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	24918	delivery	5	26
81893	2020-06-20 19:49:40	2020-06-20	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	19321	pick-up	0	29
81894	2020-06-20 19:50:18	2020-06-20	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	5215	pick-up	0	21
81895	2020-06-20 19:51:04	2020-06-20	14	[{"id_menu":2,"count":1}]	20442	delivery	5	19
81896	2020-06-20 19:51:07	2020-06-20	9	[{"id_menu":7,"count":1}]	2287	delivery	5	14
81897	2020-06-20 19:54:23	2020-06-20	17	[{"id_menu":4,"count":1}]	11624	delivery	5	22
81898	2020-06-20 19:56:04	2020-06-20	12	[{"id_menu":1,"count":1}]	21156	delivery	5	17
81899	2020-06-20 19:56:59	2020-06-20	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	32116	delivery	5	23
81900	2020-06-20 20:00:41	2020-06-20	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	7938	delivery	5	26
81901	2020-06-20 20:01:58	2020-06-20	8	[{"id_menu":5,"count":1}]	9973	delivery	5	13
81902	2020-06-20 20:04:06	2020-06-20	17	[{"id_menu":4,"count":1}]	32036	delivery	5	22
81903	2020-06-20 20:06:31	2020-06-20	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	31996	delivery	5	31
81904	2020-06-20 20:06:57	2020-06-20	12	[{"id_menu":3,"count":1}]	20935	delivery	5	17
81905	2020-06-20 20:09:06	2020-06-20	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	7370	delivery	5	52
81906	2020-06-20 20:09:53	2020-06-20	12	[{"id_menu":1,"count":1}]	20175	pick-up	0	12
81907	2020-06-20 20:10:02	2020-06-20	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	32069	delivery	5	23
81908	2020-06-20 20:11:36	2020-06-20	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	32072	delivery	5	23
81909	2020-06-20 20:12:12	2020-06-20	9	[{"id_menu":7,"count":1}]	11779	pick-up	0	9
81910	2020-06-20 20:16:26	2020-06-20	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	8716	delivery	5	31
81911	2020-06-20 20:16:41	2020-06-20	9	[{"id_menu":6,"count":2}]	13429	pick-up	0	9
81912	2020-06-20 20:18:33	2020-06-20	12	[{"id_menu":3,"count":1}]	16660	delivery	5	17
81913	2020-06-20 20:18:49	2020-06-20	14	[{"id_menu":2,"count":1}]	1295	delivery	5	19
81914	2020-06-20 20:19:06	2020-06-20	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	31421	delivery	5	25
81915	2020-06-20 20:20:11	2020-06-20	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	32053	delivery	5	27
81916	2020-06-20 20:22:31	2020-06-20	8	[{"id_menu":5,"count":1}]	15798	delivery	5	13
81917	2020-06-20 20:23:08	2020-06-20	9	[{"id_menu":7,"count":1}]	32090	delivery	5	14
81918	2020-06-20 20:23:10	2020-06-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14621	delivery	5	22
81919	2020-06-20 20:24:29	2020-06-20	9	[{"id_menu":6,"count":1}]	32119	delivery	5	14
81920	2020-06-20 20:26:30	2020-06-20	14	[{"id_menu":2,"count":1}]	6391	pick-up	0	14
81921	2020-06-20 20:26:31	2020-06-20	9	[{"id_menu":7,"count":1}]	16111	pick-up	0	9
81922	2020-06-20 20:27:06	2020-06-20	17	[{"id_menu":4,"count":1}]	4072	pick-up	0	17
81923	2020-06-20 20:30:23	2020-06-20	26	[{"id_menu":4,"count":3},{"id_menu":6,"count":1}]	31964	delivery	5	31
81924	2020-06-20 20:31:24	2020-06-20	9	[{"id_menu":7,"count":1}]	21064	delivery	5	14
81925	2020-06-20 20:31:56	2020-06-20	9	[{"id_menu":6,"count":1}]	24407	delivery	5	14
81926	2020-06-20 20:40:19	2020-06-20	12	[{"id_menu":3,"count":1}]	24071	delivery	5	17
81927	2020-06-20 20:41:44	2020-06-20	8	[{"id_menu":5,"count":1}]	32012	pick-up	0	8
81928	2020-06-20 20:41:55	2020-06-20	12	[{"id_menu":1,"count":1}]	171	delivery	5	17
81929	2020-06-20 20:43:22	2020-06-20	17	[{"id_menu":4,"count":1}]	748	delivery	5	22
81930	2020-06-20 20:45:19	2020-06-20	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3862	delivery	5	39
81931	2020-06-20 20:48:03	2020-06-20	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	25750	pick-up	0	31
81932	2020-06-20 20:51:54	2020-06-20	17	[{"id_menu":4,"count":1}]	31983	delivery	5	22
81933	2020-06-20 20:54:23	2020-06-20	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	32117	delivery	5	27
81934	2020-06-20 20:56:00	2020-06-20	12	[{"id_menu":1,"count":1}]	30510	delivery	5	17
81935	2020-06-20 20:57:31	2020-06-20	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	310	pick-up	0	35
81936	2020-06-20 20:58:28	2020-06-20	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	27010	delivery	5	31
81937	2020-06-20 20:58:37	2020-06-20	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	32028	delivery	5	34
81938	2020-06-20 20:59:20	2020-06-20	17	[{"id_menu":4,"count":1}]	32063	pick-up	0	17
81939	2020-06-20 20:59:38	2020-06-20	9	[{"id_menu":6,"count":1}]	1148	pick-up	0	9
81940	2020-06-20 21:03:27	2020-06-20	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32039	delivery	5	40
81941	2020-06-20 21:03:35	2020-06-20	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1266	pick-up	0	31
81942	2020-06-20 21:10:38	2020-06-20	21	[{"id_menu":1,"count":3},{"id_menu":6,"count":1}]	32115	delivery	5	26
81943	2020-06-20 21:11:17	2020-06-20	17	[{"id_menu":4,"count":1}]	27951	delivery	5	22
81944	2020-06-20 21:11:23	2020-06-20	8	[{"id_menu":5,"count":1}]	1444	delivery	5	13
81945	2020-06-20 21:14:14	2020-06-20	14	[{"id_menu":2,"count":1}]	1269	pick-up	0	14
81946	2020-06-20 21:14:23	2020-06-20	9	[{"id_menu":7,"count":1}]	27566	delivery	5	14
81947	2020-06-20 21:17:53	2020-06-20	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14301	delivery	5	31
81948	2020-06-20 21:18:51	2020-06-20	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4294	delivery	5	52
81949	2020-06-20 21:24:13	2020-06-20	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	5291	delivery	5	22
81950	2020-06-20 21:26:04	2020-06-20	12	[{"id_menu":1,"count":1}]	32124	delivery	5	17
81951	2020-06-20 21:27:35	2020-06-20	12	[{"id_menu":1,"count":1}]	31945	delivery	5	17
81952	2020-06-20 21:28:36	2020-06-20	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	31948	delivery	5	27
81953	2020-06-20 21:29:01	2020-06-20	9	[{"id_menu":6,"count":1}]	23200	delivery	5	14
81954	2020-06-20 21:30:23	2020-06-20	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	31934	delivery	5	31
81955	2020-06-20 21:30:31	2020-06-20	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	24998	delivery	5	34
81956	2020-06-20 21:31:43	2020-06-20	14	[{"id_menu":2,"count":1}]	548	delivery	5	19
81957	2020-06-20 21:34:02	2020-06-20	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1167	delivery	5	45
81958	2020-06-20 21:34:07	2020-06-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16651	delivery	5	22
81959	2020-06-20 21:35:54	2020-06-20	12	[{"id_menu":1,"count":1}]	32105	delivery	5	17
81960	2020-06-20 21:41:41	2020-06-20	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6467	delivery	5	43
81961	2020-06-20 21:42:45	2020-06-20	8	[{"id_menu":5,"count":1}]	32134	delivery	5	13
81962	2020-06-20 21:43:46	2020-06-20	9	[{"id_menu":7,"count":1}]	20754	pick-up	0	9
81963	2020-06-20 21:44:26	2020-06-20	12	[{"id_menu":3,"count":1}]	13424	delivery	5	17
81964	2020-06-20 21:44:39	2020-06-20	9	[{"id_menu":7,"count":1}]	18726	delivery	5	14
81965	2020-06-20 21:48:08	2020-06-20	12	[{"id_menu":3,"count":1}]	19911	pick-up	0	12
81966	2020-06-20 21:48:38	2020-06-20	14	[{"id_menu":2,"count":1}]	2702	pick-up	0	14
81967	2020-06-20 21:51:47	2020-06-20	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31049	delivery	5	34
81968	2020-06-20 21:54:27	2020-06-20	12	[{"id_menu":1,"count":1}]	31989	delivery	5	17
81969	2020-06-20 21:55:26	2020-06-20	17	[{"id_menu":4,"count":1}]	31971	delivery	5	22
81970	2020-06-20 21:57:13	2020-06-20	12	[{"id_menu":3,"count":1}]	29004	delivery	5	17
81971	2020-06-20 22:03:08	2020-06-20	9	[{"id_menu":6,"count":1}]	14375	delivery	5	14
81972	2020-06-20 22:04:14	2020-06-20	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	21676	delivery	5	26
81973	2020-06-20 22:04:42	2020-06-20	9	[{"id_menu":6,"count":1}]	8702	delivery	5	14
81974	2020-06-20 22:05:16	2020-06-20	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	25658	delivery	5	26
81975	2020-06-20 22:05:59	2020-06-20	9	[{"id_menu":7,"count":1}]	23875	delivery	5	14
81976	2020-06-20 22:07:00	2020-06-20	12	[{"id_menu":1,"count":1}]	24771	delivery	5	17
81977	2020-06-20 22:07:43	2020-06-20	9	[{"id_menu":7,"count":1}]	13285	delivery	5	14
81978	2020-06-20 22:14:08	2020-06-20	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32088	delivery	5	35
81979	2020-06-20 22:17:03	2020-06-20	12	[{"id_menu":1,"count":1}]	989	delivery	5	17
81980	2020-06-20 22:17:25	2020-06-20	12	[{"id_menu":1,"count":1}]	27314	delivery	5	17
81981	2020-06-20 22:21:22	2020-06-20	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	18900	delivery	5	34
81982	2020-06-20 22:22:16	2020-06-20	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	31980	delivery	5	31
81983	2020-06-20 22:22:24	2020-06-20	14	[{"id_menu":2,"count":1}]	31984	pick-up	0	14
81984	2020-06-20 22:23:18	2020-06-20	9	[{"id_menu":7,"count":1}]	1605	pick-up	0	9
81985	2020-06-20 22:23:35	2020-06-20	9	[{"id_menu":7,"count":1}]	21221	delivery	5	14
81986	2020-06-20 22:24:52	2020-06-20	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	32081	delivery	5	26
81987	2020-06-20 22:25:54	2020-06-20	17	[{"id_menu":4,"count":1}]	31920	pick-up	0	17
81988	2020-06-20 22:26:57	2020-06-20	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	28728	delivery	5	31
81989	2020-06-20 22:28:52	2020-06-20	9	[{"id_menu":6,"count":1}]	31929	pick-up	0	9
81990	2020-06-20 22:30:57	2020-06-20	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	31997	pick-up	0	26
81991	2020-06-20 22:31:27	2020-06-20	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	5311	pick-up	0	24
81992	2020-06-20 22:35:44	2020-06-20	9	[{"id_menu":7,"count":1}]	31927	delivery	5	14
81993	2020-06-20 22:43:16	2020-06-20	9	[{"id_menu":6,"count":1}]	32064	delivery	5	14
81994	2020-06-20 22:44:43	2020-06-20	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	32051	pick-up	0	26
81995	2020-06-20 22:47:23	2020-06-20	9	[{"id_menu":6,"count":1}]	20938	delivery	5	14
81996	2020-06-20 22:47:45	2020-06-20	8	[{"id_menu":5,"count":1}]	31991	delivery	5	13
81997	2020-06-20 22:49:20	2020-06-20	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31973	delivery	5	34
81998	2020-06-20 22:52:25	2020-06-20	9	[{"id_menu":7,"count":1}]	6130	delivery	5	14
81999	2020-06-20 22:53:53	2020-06-20	9	[{"id_menu":6,"count":1}]	3260	pick-up	0	9
82000	2020-06-20 22:57:46	2020-06-20	9	[{"id_menu":6,"count":1}]	21109	pick-up	0	9
82001	2020-06-20 22:58:57	2020-06-20	8	[{"id_menu":5,"count":1}]	21369	delivery	5	13
82002	2020-06-20 23:00:55	2020-06-20	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7051	pick-up	0	31
82003	2020-06-20 23:03:44	2020-06-20	9	[{"id_menu":6,"count":1}]	29546	delivery	5	14
82004	2020-06-20 23:03:44	2020-06-20	12	[{"id_menu":1,"count":1}]	32075	delivery	5	17
82005	2020-06-20 23:06:03	2020-06-20	14	[{"id_menu":2,"count":1}]	31972	delivery	5	19
82006	2020-06-20 23:06:23	2020-06-20	12	[{"id_menu":1,"count":1}]	27774	delivery	5	17
82007	2020-06-20 23:06:45	2020-06-20	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31943	delivery	5	48
82008	2020-06-20 23:08:02	2020-06-20	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	25850	delivery	5	31
82009	2020-06-20 23:09:59	2020-06-20	9	[{"id_menu":7,"count":1}]	31780	delivery	5	14
82010	2020-06-20 23:18:21	2020-06-20	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	31679	delivery	5	26
82011	2020-06-20 23:19:35	2020-06-20	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25134	delivery	5	37
82012	2020-06-20 23:21:16	2020-06-20	14	[{"id_menu":2,"count":1}]	24198	pick-up	0	14
82013	2020-06-20 23:23:55	2020-06-20	9	[{"id_menu":6,"count":1}]	17446	delivery	5	14
82014	2020-06-20 23:28:38	2020-06-20	9	[{"id_menu":6,"count":1}]	31960	delivery	5	14
82015	2020-06-20 23:32:15	2020-06-20	12	[{"id_menu":3,"count":1}]	22618	delivery	5	17
82016	2020-06-20 23:38:03	2020-06-20	9	[{"id_menu":7,"count":1}]	29632	delivery	5	14
82017	2020-06-20 23:38:29	2020-06-20	14	[{"id_menu":2,"count":1}]	4459	delivery	5	19
82018	2020-06-20 23:40:48	2020-06-20	14	[{"id_menu":2,"count":1}]	10276	delivery	5	19
82019	2020-06-20 23:41:54	2020-06-20	14	[{"id_menu":2,"count":1}]	227	delivery	5	19
82020	2020-06-20 23:42:01	2020-06-20	8	[{"id_menu":5,"count":1}]	6156	delivery	5	13
82021	2020-06-20 23:43:20	2020-06-20	14	[{"id_menu":2,"count":1}]	6212	delivery	5	19
82022	2020-06-20 23:46:38	2020-06-20	8	[{"id_menu":5,"count":1}]	16720	delivery	5	13
82023	2020-06-20 23:47:02	2020-06-20	12	[{"id_menu":3,"count":1}]	5051	pick-up	0	12
82024	2020-06-20 23:47:20	2020-06-20	14	[{"id_menu":2,"count":1}]	2770	delivery	5	19
82025	2020-06-20 23:48:42	2020-06-20	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	26901	delivery	5	30
82026	2020-06-20 23:54:42	2020-06-20	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	29601	delivery	5	39
82027	2020-06-20 23:56:09	2020-06-20	9	[{"id_menu":6,"count":1}]	21760	delivery	5	14
82028	2020-06-20 23:57:52	2020-06-20	8	[{"id_menu":5,"count":1}]	20871	delivery	5	13
82029	2020-06-20 23:58:47	2020-06-20	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	757	pick-up	0	26
82030	2020-06-21 00:01:18	2020-06-21	17	[{"id_menu":4,"count":1}]	32411	delivery	5	22
82031	2020-06-21 00:03:06	2020-06-21	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4788	delivery	5	54
82032	2020-06-21 00:03:18	2020-06-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12832	pick-up	0	17
82033	2020-06-21 00:04:02	2020-06-21	8	[{"id_menu":5,"count":2}]	32161	delivery	5	13
82034	2020-06-21 00:07:20	2020-06-21	12	[{"id_menu":1,"count":1}]	1166	pick-up	0	12
82035	2020-06-21 00:09:32	2020-06-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	32405	delivery	5	22
82036	2020-06-21 00:12:03	2020-06-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	32222	delivery	5	31
82037	2020-06-21 00:12:27	2020-06-21	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	13468	delivery	5	43
82038	2020-06-21 00:12:30	2020-06-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20130	delivery	5	22
82039	2020-06-21 00:12:35	2020-06-21	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	5048	pick-up	0	20
82040	2020-06-21 00:13:47	2020-06-21	12	[{"id_menu":3,"count":1}]	3447	pick-up	0	12
82041	2020-06-21 00:14:16	2020-06-21	9	[{"id_menu":7,"count":1}]	32397	delivery	5	14
82042	2020-06-21 00:16:05	2020-06-21	9	[{"id_menu":7,"count":1}]	30108	pick-up	0	9
82043	2020-06-21 00:18:06	2020-06-21	12	[{"id_menu":1,"count":1}]	15791	delivery	5	17
82044	2020-06-21 00:20:19	2020-06-21	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	32248	delivery	5	34
82045	2020-06-21 00:22:02	2020-06-21	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	32300	delivery	5	26
82046	2020-06-21 00:24:26	2020-06-21	14	[{"id_menu":2,"count":1}]	32163	delivery	5	19
82047	2020-06-21 00:26:14	2020-06-21	12	[{"id_menu":3,"count":2}]	11334	pick-up	0	12
82048	2020-06-21 00:27:27	2020-06-21	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	5790	pick-up	0	31
82049	2020-06-21 00:29:16	2020-06-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10819	pick-up	0	26
82050	2020-06-21 00:31:47	2020-06-21	8	[{"id_menu":5,"count":1}]	24130	delivery	5	13
82051	2020-06-21 00:32:26	2020-06-21	9	[{"id_menu":7,"count":1}]	4024	delivery	5	14
82052	2020-06-21 00:32:47	2020-06-21	9	[{"id_menu":7,"count":1}]	32252	delivery	5	14
82053	2020-06-21 00:36:56	2020-06-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	7530	delivery	5	22
82054	2020-06-21 00:36:59	2020-06-21	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	19464	delivery	5	45
82055	2020-06-21 00:39:13	2020-06-21	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	20727	delivery	5	29
82056	2020-06-21 00:40:53	2020-06-21	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	8363	pick-up	0	22
82057	2020-06-21 00:41:30	2020-06-21	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	18406	delivery	5	34
82058	2020-06-21 00:42:07	2020-06-21	14	[{"id_menu":2,"count":1}]	2052	pick-up	0	14
82059	2020-06-21 00:42:37	2020-06-21	9	[{"id_menu":6,"count":1}]	32333	delivery	5	14
82060	2020-06-21 00:44:41	2020-06-21	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	4332	delivery	5	25
82061	2020-06-21 00:45:16	2020-06-21	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13318	delivery	5	31
82062	2020-06-21 00:47:57	2020-06-21	12	[{"id_menu":3,"count":1}]	1896	pick-up	0	12
82063	2020-06-21 00:55:42	2020-06-21	17	[{"id_menu":4,"count":1}]	8019	pick-up	0	17
82064	2020-06-21 00:55:55	2020-06-21	17	[{"id_menu":4,"count":1}]	32215	delivery	5	22
82065	2020-06-21 00:58:46	2020-06-21	14	[{"id_menu":2,"count":2}]	27925	delivery	5	19
82066	2020-06-21 01:01:26	2020-06-21	9	[{"id_menu":7,"count":2}]	7899	delivery	5	14
82067	2020-06-21 01:01:35	2020-06-21	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10452	pick-up	0	40
82068	2020-06-21 01:03:42	2020-06-21	12	[{"id_menu":1,"count":1}]	32218	delivery	5	17
82069	2020-06-21 01:03:43	2020-06-21	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	110	pick-up	0	21
82070	2020-06-21 01:04:00	2020-06-21	12	[{"id_menu":3,"count":1}]	8679	pick-up	0	12
82071	2020-06-21 01:06:54	2020-06-21	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	30662	delivery	5	43
82072	2020-06-21 01:10:42	2020-06-21	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	16613	pick-up	0	39
82073	2020-06-21 01:13:33	2020-06-21	9	[{"id_menu":7,"count":1}]	32217	delivery	5	14
82074	2020-06-21 01:13:56	2020-06-21	9	[{"id_menu":6,"count":1}]	22938	delivery	5	14
82075	2020-06-21 01:15:47	2020-06-21	9	[{"id_menu":7,"count":3}]	32283	delivery	5	14
82076	2020-06-21 01:17:06	2020-06-21	17	[{"id_menu":4,"count":1}]	29800	delivery	5	22
82077	2020-06-21 01:17:48	2020-06-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32174	delivery	5	23
82078	2020-06-21 01:18:09	2020-06-21	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	32200	delivery	5	40
82079	2020-06-21 01:22:53	2020-06-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2743	delivery	5	23
82080	2020-06-21 01:23:04	2020-06-21	12	[{"id_menu":1,"count":1}]	10461	delivery	5	17
82081	2020-06-21 01:24:57	2020-06-21	9	[{"id_menu":7,"count":1}]	9921	pick-up	0	9
82082	2020-06-21 01:25:01	2020-06-21	9	[{"id_menu":7,"count":1}]	1183	delivery	5	14
82083	2020-06-21 01:25:45	2020-06-21	12	[{"id_menu":3,"count":1}]	2720	pick-up	0	12
82084	2020-06-21 01:26:06	2020-06-21	8	[{"id_menu":5,"count":1}]	14444	delivery	5	13
82085	2020-06-21 01:27:05	2020-06-21	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	32328	delivery	5	31
82086	2020-06-21 01:28:05	2020-06-21	17	[{"id_menu":4,"count":1}]	32243	delivery	5	22
82087	2020-06-21 01:28:35	2020-06-21	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	14	delivery	5	26
82088	2020-06-21 01:29:54	2020-06-21	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	16367	delivery	5	48
82089	2020-06-21 01:30:38	2020-06-21	12	[{"id_menu":3,"count":1}]	32399	pick-up	0	12
82090	2020-06-21 01:32:03	2020-06-21	14	[{"id_menu":2,"count":1}]	9171	pick-up	0	14
82091	2020-06-21 01:32:49	2020-06-21	9	[{"id_menu":7,"count":1}]	22184	delivery	5	14
82092	2020-06-21 01:36:03	2020-06-21	12	[{"id_menu":3,"count":1}]	8457	pick-up	0	12
82093	2020-06-21 01:37:04	2020-06-21	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	19127	delivery	5	40
82094	2020-06-21 01:40:03	2020-06-21	26	[{"id_menu":2,"count":3},{"id_menu":3,"count":1}]	32263	delivery	5	31
82095	2020-06-21 01:41:15	2020-06-21	17	[{"id_menu":4,"count":1}]	20149	delivery	5	22
82096	2020-06-21 01:41:33	2020-06-21	14	[{"id_menu":2,"count":1}]	7354	pick-up	0	14
82097	2020-06-21 01:41:43	2020-06-21	8	[{"id_menu":5,"count":1}]	20967	delivery	5	13
82098	2020-06-21 01:41:44	2020-06-21	9	[{"id_menu":7,"count":1}]	6088	delivery	5	14
82099	2020-06-21 01:43:26	2020-06-21	9	[{"id_menu":7,"count":1}]	4193	delivery	5	14
82100	2020-06-21 01:44:50	2020-06-21	17	[{"id_menu":4,"count":2}]	32414	delivery	5	22
82101	2020-06-21 01:46:05	2020-06-21	12	[{"id_menu":3,"count":1}]	29180	delivery	5	17
82102	2020-06-21 01:48:47	2020-06-21	14	[{"id_menu":2,"count":1}]	30512	delivery	5	19
82103	2020-06-21 01:50:07	2020-06-21	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6527	delivery	5	54
82104	2020-06-21 01:51:10	2020-06-21	12	[{"id_menu":1,"count":1}]	32262	delivery	5	17
82105	2020-06-21 01:54:05	2020-06-21	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	9603	delivery	5	44
82106	2020-06-21 01:55:36	2020-06-21	9	[{"id_menu":7,"count":1}]	13124	delivery	5	14
82107	2020-06-21 01:55:40	2020-06-21	12	[{"id_menu":3,"count":1}]	3511	pick-up	0	12
82108	2020-06-21 01:57:21	2020-06-21	8	[{"id_menu":5,"count":1}]	25054	delivery	5	13
82109	2020-06-21 01:58:45	2020-06-21	9	[{"id_menu":7,"count":2}]	5338	delivery	5	14
82110	2020-06-21 01:58:50	2020-06-21	17	[{"id_menu":4,"count":1}]	32214	pick-up	0	17
82111	2020-06-21 02:02:51	2020-06-21	8	[{"id_menu":5,"count":1}]	19724	delivery	5	13
82112	2020-06-21 02:09:03	2020-06-21	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	26198	delivery	5	26
82113	2020-06-21 02:09:07	2020-06-21	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	27113	delivery	5	48
82114	2020-06-21 02:11:37	2020-06-21	17	[{"id_menu":4,"count":1}]	13049	delivery	5	22
82115	2020-06-21 02:13:37	2020-06-21	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	32190	delivery	5	38
82116	2020-06-21 02:14:42	2020-06-21	8	[{"id_menu":5,"count":1}]	10525	pick-up	0	8
82117	2020-06-21 02:16:36	2020-06-21	9	[{"id_menu":7,"count":1}]	10235	delivery	5	14
82118	2020-06-21 02:16:45	2020-06-21	17	[{"id_menu":4,"count":1}]	32171	pick-up	0	17
82119	2020-06-21 02:18:57	2020-06-21	8	[{"id_menu":5,"count":1}]	29821	delivery	5	13
82120	2020-06-21 02:19:25	2020-06-21	9	[{"id_menu":6,"count":1}]	32268	delivery	5	14
82121	2020-06-21 02:19:50	2020-06-21	14	[{"id_menu":2,"count":1}]	14661	delivery	5	19
82122	2020-06-21 02:20:51	2020-06-21	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	30734	delivery	5	40
82123	2020-06-21 02:21:11	2020-06-21	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	32175	delivery	5	36
82124	2020-06-21 02:23:02	2020-06-21	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32309	delivery	5	37
82125	2020-06-21 02:24:13	2020-06-21	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	8656	pick-up	0	26
82126	2020-06-21 02:24:33	2020-06-21	9	[{"id_menu":7,"count":1}]	10860	delivery	5	14
82127	2020-06-21 02:25:52	2020-06-21	14	[{"id_menu":2,"count":1}]	17352	pick-up	0	14
82128	2020-06-21 02:28:15	2020-06-21	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	32261	delivery	5	25
82129	2020-06-21 02:28:49	2020-06-21	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32351	delivery	5	31
82130	2020-06-21 02:29:21	2020-06-21	26	[{"id_menu":4,"count":3},{"id_menu":7,"count":1}]	20565	delivery	5	31
82131	2020-06-21 02:31:38	2020-06-21	17	[{"id_menu":4,"count":1}]	31208	delivery	5	22
82132	2020-06-21 02:35:40	2020-06-21	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	15188	delivery	5	40
82133	2020-06-21 02:36:03	2020-06-21	12	[{"id_menu":3,"count":1}]	14850	delivery	5	17
82134	2020-06-21 02:38:01	2020-06-21	17	[{"id_menu":4,"count":1}]	18511	pick-up	0	17
82135	2020-06-21 02:38:35	2020-06-21	17	[{"id_menu":4,"count":1}]	32297	pick-up	0	17
82136	2020-06-21 02:38:52	2020-06-21	9	[{"id_menu":7,"count":1}]	10010	pick-up	0	9
82137	2020-06-21 02:39:07	2020-06-21	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17867	delivery	5	43
82138	2020-06-21 02:42:53	2020-06-21	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15026	pick-up	0	29
82139	2020-06-21 02:43:47	2020-06-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32194	delivery	5	22
82140	2020-06-21 02:45:51	2020-06-21	9	[{"id_menu":6,"count":2}]	31533	delivery	5	14
82141	2020-06-21 02:46:38	2020-06-21	8	[{"id_menu":5,"count":1}]	32390	delivery	5	13
82142	2020-06-21 02:47:22	2020-06-21	14	[{"id_menu":2,"count":1}]	3607	pick-up	0	14
82143	2020-06-21 02:48:19	2020-06-21	17	[{"id_menu":4,"count":1}]	32260	delivery	5	22
82144	2020-06-21 02:50:50	2020-06-21	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	27429	pick-up	0	21
82145	2020-06-21 02:51:04	2020-06-21	14	[{"id_menu":2,"count":1}]	30408	delivery	5	19
82146	2020-06-21 02:54:46	2020-06-21	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	12011	delivery	5	40
82147	2020-06-21 02:55:19	2020-06-21	12	[{"id_menu":3,"count":2}]	7974	pick-up	0	12
82148	2020-06-21 02:57:39	2020-06-21	8	[{"id_menu":5,"count":1}]	6354	delivery	5	13
82149	2020-06-21 03:03:18	2020-06-21	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12546	delivery	5	39
82150	2020-06-21 03:05:56	2020-06-21	9	[{"id_menu":6,"count":1}]	3619	pick-up	0	9
82151	2020-06-21 03:08:14	2020-06-21	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	9053	pick-up	0	21
82152	2020-06-21 03:10:51	2020-06-21	9	[{"id_menu":6,"count":1}]	660	delivery	5	14
82153	2020-06-21 03:11:43	2020-06-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	96	pick-up	0	18
82154	2020-06-21 03:12:53	2020-06-21	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	31969	delivery	5	25
82155	2020-06-21 03:13:59	2020-06-21	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	32316	delivery	5	36
82156	2020-06-21 03:17:34	2020-06-21	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	32409	delivery	5	43
82157	2020-06-21 03:18:58	2020-06-21	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	32271	delivery	5	40
82158	2020-06-21 03:21:00	2020-06-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12375	delivery	5	31
82159	2020-06-21 03:23:34	2020-06-21	9	[{"id_menu":7,"count":1}]	17501	delivery	5	14
82160	2020-06-21 03:24:34	2020-06-21	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27809	delivery	5	35
82161	2020-06-21 03:25:49	2020-06-21	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	30329	pick-up	0	25
82162	2020-06-21 03:26:51	2020-06-21	17	[{"id_menu":4,"count":1}]	1440	pick-up	0	17
82163	2020-06-21 03:27:41	2020-06-21	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	32199	delivery	5	26
82164	2020-06-21 03:29:01	2020-06-21	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	32408	delivery	5	42
82165	2020-06-21 03:53:55	2020-06-21	14	[{"id_menu":2,"count":1}]	19207	delivery	5	19
82166	2020-06-21 03:55:18	2020-06-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29017	delivery	5	22
82167	2020-06-21 03:56:38	2020-06-21	9	[{"id_menu":7,"count":1}]	32369	delivery	5	14
82168	2020-06-21 03:59:24	2020-06-21	12	[{"id_menu":1,"count":1}]	9633	delivery	5	17
82169	2020-06-21 04:00:38	2020-06-21	12	[{"id_menu":3,"count":1}]	1273	delivery	5	17
82170	2020-06-21 04:00:51	2020-06-21	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	28413	delivery	5	31
82171	2020-06-21 04:02:09	2020-06-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3059	delivery	5	28
82172	2020-06-21 04:03:54	2020-06-21	14	[{"id_menu":2,"count":1}]	26900	delivery	5	19
82173	2020-06-21 04:04:54	2020-06-21	9	[{"id_menu":7,"count":1}]	32323	delivery	5	14
82174	2020-06-21 04:05:47	2020-06-21	9	[{"id_menu":7,"count":1}]	4584	delivery	5	14
82175	2020-06-21 04:06:31	2020-06-21	14	[{"id_menu":2,"count":1}]	29394	pick-up	0	14
82176	2020-06-21 04:10:19	2020-06-21	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	32216	delivery	5	34
82177	2020-06-21 04:11:19	2020-06-21	17	[{"id_menu":4,"count":1}]	32393	delivery	5	22
82178	2020-06-21 04:14:39	2020-06-21	17	[{"id_menu":4,"count":1}]	23596	delivery	5	22
82179	2020-06-21 04:16:33	2020-06-21	12	[{"id_menu":1,"count":1}]	32313	delivery	5	17
82180	2020-06-21 04:17:47	2020-06-21	8	[{"id_menu":5,"count":1}]	32290	delivery	5	13
82181	2020-06-21 04:24:41	2020-06-21	8	[{"id_menu":5,"count":1}]	32188	delivery	5	13
82182	2020-06-21 04:24:59	2020-06-21	9	[{"id_menu":6,"count":1}]	32168	pick-up	0	9
82183	2020-06-21 04:28:12	2020-06-21	9	[{"id_menu":6,"count":1}]	15929	delivery	5	14
82184	2020-06-21 04:29:50	2020-06-21	9	[{"id_menu":6,"count":1}]	32258	delivery	5	14
82185	2020-06-21 04:30:39	2020-06-21	9	[{"id_menu":6,"count":1}]	32419	delivery	5	14
82186	2020-06-21 04:33:16	2020-06-21	9	[{"id_menu":7,"count":1}]	32374	delivery	5	14
82187	2020-06-21 04:33:52	2020-06-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	25805	delivery	5	31
82188	2020-06-21 04:34:02	2020-06-21	8	[{"id_menu":5,"count":1}]	3530	delivery	5	13
82189	2020-06-21 04:36:45	2020-06-21	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":2}]	32179	delivery	5	31
82190	2020-06-21 04:38:42	2020-06-21	12	[{"id_menu":1,"count":1}]	32241	delivery	5	17
82191	2020-06-21 04:41:14	2020-06-21	17	[{"id_menu":4,"count":1}]	3160	pick-up	0	17
82192	2020-06-21 04:42:09	2020-06-21	8	[{"id_menu":5,"count":1}]	8585	delivery	5	13
82193	2020-06-21 04:43:24	2020-06-21	8	[{"id_menu":5,"count":1}]	20338	pick-up	0	8
82260	2020-06-21 06:42:05	2020-06-21	9	[{"id_menu":7,"count":1}]	12209	delivery	5	14
82194	2020-06-21 04:43:33	2020-06-21	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	22050	delivery	5	34
82195	2020-06-21 04:46:08	2020-06-21	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	13530	delivery	5	31
82196	2020-06-21 04:48:10	2020-06-21	17	[{"id_menu":4,"count":1}]	32242	delivery	5	22
82197	2020-06-21 04:48:36	2020-06-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	29685	pick-up	0	26
82198	2020-06-21 04:48:50	2020-06-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32274	delivery	5	23
82199	2020-06-21 04:49:11	2020-06-21	17	[{"id_menu":4,"count":1}]	32288	delivery	5	22
82200	2020-06-21 04:50:24	2020-06-21	9	[{"id_menu":6,"count":2}]	16025	delivery	5	14
82201	2020-06-21 04:52:05	2020-06-21	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32327	delivery	5	37
82202	2020-06-21 04:52:58	2020-06-21	9	[{"id_menu":7,"count":1}]	11273	delivery	5	14
82203	2020-06-21 04:53:21	2020-06-21	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	19677	delivery	5	22
82204	2020-06-21 04:53:23	2020-06-21	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	32278	delivery	5	23
82205	2020-06-21 04:53:27	2020-06-21	9	[{"id_menu":6,"count":1}]	32319	delivery	5	14
82206	2020-06-21 04:54:51	2020-06-21	8	[{"id_menu":5,"count":1}]	32186	delivery	5	13
82207	2020-06-21 04:54:56	2020-06-21	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	31621	delivery	5	25
82208	2020-06-21 04:54:59	2020-06-21	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	32363	delivery	5	26
82209	2020-06-21 04:57:48	2020-06-21	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32329	delivery	5	36
82210	2020-06-21 04:57:53	2020-06-21	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	905	pick-up	0	20
82211	2020-06-21 04:58:04	2020-06-21	8	[{"id_menu":5,"count":1}]	8257	delivery	5	13
82212	2020-06-21 05:00:47	2020-06-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	18839	delivery	5	31
82213	2020-06-21 05:02:30	2020-06-21	12	[{"id_menu":3,"count":1}]	8104	pick-up	0	12
82214	2020-06-21 05:03:36	2020-06-21	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	417	pick-up	0	29
82215	2020-06-21 05:03:58	2020-06-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36	delivery	5	23
82216	2020-06-21 05:12:50	2020-06-21	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	27828	delivery	5	25
82217	2020-06-21 05:15:25	2020-06-21	9	[{"id_menu":6,"count":1}]	32270	delivery	5	14
82218	2020-06-21 05:17:46	2020-06-21	9	[{"id_menu":7,"count":1}]	3347	delivery	5	14
82219	2020-06-21 05:18:27	2020-06-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20270	pick-up	0	18
82220	2020-06-21 05:19:04	2020-06-21	22	[{"id_menu":2,"count":3},{"id_menu":5,"count":1}]	32167	pick-up	0	22
82221	2020-06-21 05:20:52	2020-06-21	9	[{"id_menu":7,"count":3}]	9532	delivery	5	14
82222	2020-06-21 05:23:58	2020-06-21	9	[{"id_menu":7,"count":1}]	30491	delivery	5	14
82223	2020-06-21 05:25:28	2020-06-21	14	[{"id_menu":2,"count":1}]	32156	delivery	5	19
82224	2020-06-21 05:27:15	2020-06-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3871	pick-up	0	17
82225	2020-06-21 05:27:18	2020-06-21	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28432	delivery	5	31
82226	2020-06-21 05:28:16	2020-06-21	9	[{"id_menu":7,"count":1}]	14235	delivery	5	14
82227	2020-06-21 05:31:44	2020-06-21	14	[{"id_menu":2,"count":1}]	1813	delivery	5	19
82228	2020-06-21 05:32:17	2020-06-21	9	[{"id_menu":7,"count":1}]	28111	delivery	5	14
82229	2020-06-21 05:32:23	2020-06-21	17	[{"id_menu":4,"count":1}]	32348	delivery	5	22
82230	2020-06-21 05:32:43	2020-06-21	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	15390	delivery	5	40
82231	2020-06-21 05:35:45	2020-06-21	9	[{"id_menu":7,"count":1}]	16244	pick-up	0	9
82232	2020-06-21 05:44:59	2020-06-21	12	[{"id_menu":3,"count":1}]	32420	delivery	5	17
82233	2020-06-21 05:50:46	2020-06-21	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	11109	delivery	5	31
82234	2020-06-21 05:51:14	2020-06-21	9	[{"id_menu":7,"count":1}]	32169	delivery	5	14
82235	2020-06-21 05:53:45	2020-06-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2107	pick-up	0	17
82236	2020-06-21 05:53:52	2020-06-21	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	32249	delivery	5	48
82237	2020-06-21 05:54:11	2020-06-21	14	[{"id_menu":2,"count":1}]	26208	delivery	5	19
82238	2020-06-21 05:55:48	2020-06-21	9	[{"id_menu":6,"count":1}]	18065	delivery	5	14
82239	2020-06-21 05:57:55	2020-06-21	17	[{"id_menu":5,"count":3},{"id_menu":6,"count":1}]	32255	delivery	5	22
82240	2020-06-21 05:58:52	2020-06-21	9	[{"id_menu":7,"count":2}]	32293	delivery	5	14
82241	2020-06-21 06:02:58	2020-06-21	8	[{"id_menu":5,"count":1}]	13054	pick-up	0	8
82242	2020-06-21 06:04:48	2020-06-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	13256	pick-up	0	23
82243	2020-06-21 06:07:50	2020-06-21	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	8908	delivery	5	31
82244	2020-06-21 06:09:31	2020-06-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	19680	delivery	5	22
82245	2020-06-21 06:13:25	2020-06-21	12	[{"id_menu":1,"count":1}]	26734	delivery	5	17
82246	2020-06-21 06:14:01	2020-06-21	17	[{"id_menu":4,"count":1}]	5979	delivery	5	22
82247	2020-06-21 06:18:15	2020-06-21	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	28183	delivery	5	36
82248	2020-06-21 06:19:28	2020-06-21	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9791	delivery	5	40
82249	2020-06-21 06:19:39	2020-06-21	14	[{"id_menu":2,"count":1}]	3	pick-up	0	14
82250	2020-06-21 06:25:05	2020-06-21	9	[{"id_menu":7,"count":1}]	27783	delivery	5	14
82251	2020-06-21 06:27:20	2020-06-21	9	[{"id_menu":7,"count":1}]	25243	delivery	5	14
82252	2020-06-21 06:29:37	2020-06-21	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	758	delivery	5	40
82253	2020-06-21 06:29:57	2020-06-21	9	[{"id_menu":6,"count":1}]	32282	delivery	5	14
82254	2020-06-21 06:30:13	2020-06-21	14	[{"id_menu":2,"count":1}]	482	delivery	5	19
82255	2020-06-21 06:33:00	2020-06-21	9	[{"id_menu":6,"count":1}]	32170	delivery	5	14
82256	2020-06-21 06:38:34	2020-06-21	8	[{"id_menu":5,"count":1}]	32299	delivery	5	13
82257	2020-06-21 06:38:36	2020-06-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19143	delivery	5	22
82258	2020-06-21 06:40:55	2020-06-21	17	[{"id_menu":4,"count":1}]	29706	delivery	5	22
82259	2020-06-21 06:41:43	2020-06-21	12	[{"id_menu":3,"count":1}]	1230	pick-up	0	12
82261	2020-06-21 06:42:31	2020-06-21	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14759	delivery	5	45
82262	2020-06-21 06:42:53	2020-06-21	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	32304	pick-up	0	37
82263	2020-06-21 06:43:18	2020-06-21	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	32383	delivery	5	23
82264	2020-06-21 06:44:45	2020-06-21	8	[{"id_menu":5,"count":1}]	10556	delivery	5	13
82265	2020-06-21 06:44:55	2020-06-21	14	[{"id_menu":2,"count":1}]	24455	delivery	5	19
82266	2020-06-21 06:45:47	2020-06-21	12	[{"id_menu":1,"count":1}]	11444	pick-up	0	12
82267	2020-06-21 06:46:17	2020-06-21	9	[{"id_menu":6,"count":1}]	32416	delivery	5	14
82268	2020-06-21 06:47:02	2020-06-21	9	[{"id_menu":7,"count":1}]	32233	delivery	5	14
82269	2020-06-21 06:47:29	2020-06-21	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	6749	delivery	5	34
82270	2020-06-21 06:47:41	2020-06-21	9	[{"id_menu":7,"count":2}]	32314	delivery	5	14
82271	2020-06-21 06:50:28	2020-06-21	9	[{"id_menu":7,"count":1}]	32301	delivery	5	14
82272	2020-06-21 06:55:02	2020-06-21	9	[{"id_menu":7,"count":1}]	19434	delivery	5	14
82273	2020-06-21 06:56:32	2020-06-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13487	pick-up	0	17
82274	2020-06-21 06:57:06	2020-06-21	8	[{"id_menu":5,"count":1}]	32182	delivery	5	13
82275	2020-06-21 06:57:37	2020-06-21	8	[{"id_menu":5,"count":1}]	32204	delivery	5	13
82276	2020-06-21 07:00:22	2020-06-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1582	pick-up	0	17
82277	2020-06-21 07:00:27	2020-06-21	9	[{"id_menu":6,"count":1}]	12827	delivery	5	14
82278	2020-06-21 07:01:08	2020-06-21	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	6961	delivery	5	36
82279	2020-06-21 07:02:23	2020-06-21	14	[{"id_menu":2,"count":1}]	13865	delivery	5	19
82280	2020-06-21 07:03:52	2020-06-21	17	[{"id_menu":4,"count":1}]	32310	pick-up	0	17
82281	2020-06-21 07:06:24	2020-06-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	32257	delivery	5	31
82282	2020-06-21 07:07:25	2020-06-21	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	100	delivery	5	26
82283	2020-06-21 07:09:02	2020-06-21	8	[{"id_menu":5,"count":1}]	31989	delivery	5	13
82284	2020-06-21 07:09:16	2020-06-21	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	32298	delivery	5	31
82285	2020-06-21 07:09:27	2020-06-21	12	[{"id_menu":3,"count":1}]	30086	delivery	5	17
82286	2020-06-21 07:10:34	2020-06-21	9	[{"id_menu":6,"count":1}]	11360	delivery	5	14
82287	2020-06-21 07:10:46	2020-06-21	17	[{"id_menu":4,"count":1}]	21753	delivery	5	22
82288	2020-06-21 07:10:47	2020-06-21	14	[{"id_menu":2,"count":1}]	30209	pick-up	0	14
82289	2020-06-21 07:12:37	2020-06-21	14	[{"id_menu":2,"count":1}]	10499	delivery	5	19
82290	2020-06-21 07:15:04	2020-06-21	9	[{"id_menu":7,"count":1}]	2822	pick-up	0	9
82291	2020-06-21 07:18:35	2020-06-21	9	[{"id_menu":6,"count":1}]	32226	delivery	5	14
82292	2020-06-21 07:25:52	2020-06-21	9	[{"id_menu":6,"count":3}]	32345	delivery	5	14
82293	2020-06-21 07:26:13	2020-06-21	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	25382	delivery	5	56
82294	2020-06-21 07:27:05	2020-06-21	9	[{"id_menu":7,"count":1}]	32247	delivery	5	14
82295	2020-06-21 07:29:02	2020-06-21	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	7729	delivery	5	36
82296	2020-06-21 07:29:36	2020-06-21	17	[{"id_menu":4,"count":1}]	32402	delivery	5	22
82297	2020-06-21 07:30:09	2020-06-21	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	29357	delivery	5	26
82298	2020-06-21 07:32:00	2020-06-21	9	[{"id_menu":6,"count":1}]	32277	delivery	5	14
82299	2020-06-21 07:32:09	2020-06-21	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32286	delivery	5	51
82300	2020-06-21 07:33:47	2020-06-21	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	21887	delivery	5	28
82301	2020-06-21 07:34:10	2020-06-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	20413	pick-up	0	26
82302	2020-06-21 07:34:37	2020-06-21	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	20749	delivery	5	43
82303	2020-06-21 07:34:58	2020-06-21	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	32266	delivery	5	40
82304	2020-06-21 07:35:11	2020-06-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23457	delivery	5	22
82305	2020-06-21 07:36:51	2020-06-21	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6174	delivery	5	34
82306	2020-06-21 07:39:47	2020-06-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32367	delivery	5	22
82307	2020-06-21 07:40:24	2020-06-21	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	24918	delivery	5	25
82308	2020-06-21 07:40:43	2020-06-21	9	[{"id_menu":7,"count":1}]	8755	delivery	5	14
82309	2020-06-21 07:44:20	2020-06-21	17	[{"id_menu":4,"count":1}]	13677	pick-up	0	17
82310	2020-06-21 07:45:31	2020-06-21	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18642	delivery	5	45
82311	2020-06-21 07:46:46	2020-06-21	12	[{"id_menu":1,"count":1}]	13537	delivery	5	17
82312	2020-06-21 07:49:32	2020-06-21	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14786	delivery	5	31
82313	2020-06-21 07:53:24	2020-06-21	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9196	delivery	5	54
82314	2020-06-21 07:54:05	2020-06-21	9	[{"id_menu":7,"count":1}]	12089	delivery	5	14
82315	2020-06-21 07:56:32	2020-06-21	14	[{"id_menu":2,"count":1}]	12537	delivery	5	19
82316	2020-06-21 07:57:51	2020-06-21	9	[{"id_menu":6,"count":1}]	32302	delivery	5	14
82317	2020-06-21 07:58:15	2020-06-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	32291	delivery	5	28
82318	2020-06-21 08:00:05	2020-06-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32322	delivery	5	23
82319	2020-06-21 08:02:09	2020-06-21	12	[{"id_menu":3,"count":1}]	31402	delivery	5	17
82320	2020-06-21 08:02:29	2020-06-21	9	[{"id_menu":6,"count":1}]	13307	pick-up	0	9
82321	2020-06-21 08:03:26	2020-06-21	9	[{"id_menu":6,"count":1}]	28666	delivery	5	14
82322	2020-06-21 08:04:31	2020-06-21	9	[{"id_menu":6,"count":1}]	30625	delivery	5	14
82323	2020-06-21 08:06:37	2020-06-21	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	32389	delivery	5	40
82324	2020-06-21 08:06:46	2020-06-21	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	30351	delivery	5	39
82325	2020-06-21 08:06:55	2020-06-21	14	[{"id_menu":2,"count":1}]	3634	delivery	5	19
82326	2020-06-21 08:08:34	2020-06-21	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	4251	delivery	5	43
82327	2020-06-21 08:09:09	2020-06-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32391	delivery	5	22
82328	2020-06-21 08:09:12	2020-06-21	9	[{"id_menu":7,"count":1}]	1607	delivery	5	14
82329	2020-06-21 08:09:38	2020-06-21	17	[{"id_menu":4,"count":1}]	9175	delivery	5	22
82330	2020-06-21 08:11:29	2020-06-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32338	delivery	5	23
82331	2020-06-21 08:18:15	2020-06-21	14	[{"id_menu":2,"count":1}]	7572	delivery	5	19
82332	2020-06-21 08:18:22	2020-06-21	12	[{"id_menu":1,"count":1}]	27217	delivery	5	17
82333	2020-06-21 08:18:31	2020-06-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	14849	delivery	5	31
82334	2020-06-21 08:20:52	2020-06-21	14	[{"id_menu":2,"count":2}]	6838	delivery	5	19
82335	2020-06-21 08:21:12	2020-06-21	9	[{"id_menu":6,"count":1}]	3113	pick-up	0	9
82336	2020-06-21 08:21:16	2020-06-21	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	22246	delivery	5	40
82337	2020-06-21 08:22:09	2020-06-21	8	[{"id_menu":5,"count":1}]	30307	delivery	5	13
82338	2020-06-21 08:22:47	2020-06-21	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	14862	delivery	5	26
82339	2020-06-21 08:24:34	2020-06-21	8	[{"id_menu":5,"count":1}]	20965	delivery	5	13
82340	2020-06-21 08:25:15	2020-06-21	9	[{"id_menu":6,"count":1}]	9215	delivery	5	14
82341	2020-06-21 08:25:56	2020-06-21	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	32365	delivery	5	23
82342	2020-06-21 08:28:03	2020-06-21	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	14846	delivery	5	26
82343	2020-06-21 08:28:05	2020-06-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	28446	delivery	5	31
82344	2020-06-21 08:30:00	2020-06-21	12	[{"id_menu":3,"count":1}]	32232	pick-up	0	12
82345	2020-06-21 08:30:14	2020-06-21	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	28477	delivery	5	25
82346	2020-06-21 08:31:48	2020-06-21	12	[{"id_menu":3,"count":1}]	2193	pick-up	0	12
82347	2020-06-21 08:36:12	2020-06-21	9	[{"id_menu":7,"count":1}]	32201	delivery	5	14
82348	2020-06-21 08:37:14	2020-06-21	9	[{"id_menu":7,"count":1}]	32281	delivery	5	14
82349	2020-06-21 08:40:04	2020-06-21	9	[{"id_menu":6,"count":1}]	32246	delivery	5	14
82350	2020-06-21 08:45:08	2020-06-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20382	delivery	5	22
82351	2020-06-21 08:45:18	2020-06-21	14	[{"id_menu":2,"count":1}]	25408	pick-up	0	14
82352	2020-06-21 08:46:27	2020-06-21	8	[{"id_menu":5,"count":1}]	32212	delivery	5	13
82353	2020-06-21 08:51:51	2020-06-21	12	[{"id_menu":3,"count":1}]	27147	delivery	5	17
82354	2020-06-21 08:52:50	2020-06-21	9	[{"id_menu":6,"count":1}]	32235	delivery	5	14
82355	2020-06-21 08:57:34	2020-06-21	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	12274	delivery	5	46
82356	2020-06-21 09:01:23	2020-06-21	14	[{"id_menu":2,"count":1}]	15130	delivery	5	19
82357	2020-06-21 09:04:50	2020-06-21	12	[{"id_menu":3,"count":1}]	8583	delivery	5	17
82358	2020-06-21 09:06:40	2020-06-21	12	[{"id_menu":1,"count":1}]	13613	delivery	5	17
82359	2020-06-21 09:09:47	2020-06-21	9	[{"id_menu":6,"count":1}]	25208	delivery	5	14
82360	2020-06-21 09:10:46	2020-06-21	12	[{"id_menu":1,"count":1}]	32360	delivery	5	17
82361	2020-06-21 09:10:54	2020-06-21	9	[{"id_menu":6,"count":1}]	13151	pick-up	0	9
82362	2020-06-21 09:12:09	2020-06-21	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	32202	delivery	5	30
82363	2020-06-21 09:12:14	2020-06-21	12	[{"id_menu":1,"count":1}]	25851	delivery	5	17
82364	2020-06-21 09:12:35	2020-06-21	8	[{"id_menu":5,"count":1}]	32354	delivery	5	13
82365	2020-06-21 09:13:51	2020-06-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32229	delivery	5	23
82366	2020-06-21 09:15:28	2020-06-21	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32368	delivery	5	34
82367	2020-06-21 09:17:16	2020-06-21	17	[{"id_menu":4,"count":1}]	17769	delivery	5	22
82368	2020-06-21 09:19:35	2020-06-21	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	32176	delivery	5	52
82369	2020-06-21 09:24:17	2020-06-21	9	[{"id_menu":7,"count":1}]	20048	delivery	5	14
82370	2020-06-21 09:25:30	2020-06-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24990	delivery	5	23
82371	2020-06-21 09:26:30	2020-06-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1640	delivery	5	31
82372	2020-06-21 09:28:26	2020-06-21	9	[{"id_menu":6,"count":1}]	26391	pick-up	0	9
82373	2020-06-21 09:29:37	2020-06-21	9	[{"id_menu":7,"count":1}]	13166	pick-up	0	9
82374	2020-06-21 09:31:30	2020-06-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":3}]	21610	delivery	5	28
82375	2020-06-21 09:31:52	2020-06-21	8	[{"id_menu":5,"count":1}]	32307	pick-up	0	8
82376	2020-06-21 09:33:08	2020-06-21	9	[{"id_menu":7,"count":1}]	32187	delivery	5	14
82377	2020-06-21 09:33:10	2020-06-21	12	[{"id_menu":3,"count":1}]	6113	delivery	5	17
82378	2020-06-21 09:33:32	2020-06-21	14	[{"id_menu":2,"count":1}]	10381	pick-up	0	14
82379	2020-06-21 09:33:41	2020-06-21	9	[{"id_menu":7,"count":4}]	32335	delivery	5	14
82380	2020-06-21 09:37:22	2020-06-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	32240	delivery	5	31
82381	2020-06-21 09:37:49	2020-06-21	14	[{"id_menu":2,"count":1}]	5903	delivery	5	19
82382	2020-06-21 09:37:51	2020-06-21	8	[{"id_menu":5,"count":1}]	4728	delivery	5	13
82383	2020-06-21 09:38:10	2020-06-21	9	[{"id_menu":7,"count":1}]	11788	delivery	5	14
82384	2020-06-21 09:40:53	2020-06-21	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	11237	delivery	5	31
82385	2020-06-21 09:46:00	2020-06-21	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32353	delivery	5	39
82386	2020-06-21 09:46:11	2020-06-21	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	2857	pick-up	0	26
82387	2020-06-21 09:47:57	2020-06-21	14	[{"id_menu":2,"count":1}]	26024	delivery	5	19
82388	2020-06-21 09:48:20	2020-06-21	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":3}]	6509	delivery	5	26
82389	2020-06-21 09:49:53	2020-06-21	12	[{"id_menu":1,"count":3}]	27830	delivery	5	17
82390	2020-06-21 09:50:17	2020-06-21	8	[{"id_menu":5,"count":1}]	11172	delivery	5	13
82391	2020-06-21 09:51:33	2020-06-21	8	[{"id_menu":5,"count":1}]	32359	delivery	5	13
82392	2020-06-21 09:51:39	2020-06-21	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14183	delivery	5	37
82393	2020-06-21 09:51:47	2020-06-21	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	19685	delivery	5	26
82394	2020-06-21 09:53:56	2020-06-21	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	32332	delivery	5	40
82395	2020-06-21 09:56:32	2020-06-21	8	[{"id_menu":5,"count":1}]	13661	delivery	5	13
82396	2020-06-21 09:56:50	2020-06-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	30276	delivery	5	23
82397	2020-06-21 09:57:43	2020-06-21	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	32165	delivery	5	25
82398	2020-06-21 09:57:46	2020-06-21	9	[{"id_menu":6,"count":1}]	32346	delivery	5	14
82399	2020-06-21 09:59:03	2020-06-21	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5948	delivery	5	31
82400	2020-06-21 10:01:30	2020-06-21	9	[{"id_menu":7,"count":1}]	32198	delivery	5	14
82401	2020-06-21 10:06:27	2020-06-21	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	32160	delivery	5	26
82402	2020-06-21 10:07:30	2020-06-21	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	32315	delivery	5	43
82403	2020-06-21 10:08:09	2020-06-21	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	13855	pick-up	0	21
82404	2020-06-21 10:11:23	2020-06-21	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	2064	pick-up	0	43
82405	2020-06-21 10:11:43	2020-06-21	12	[{"id_menu":1,"count":1}]	24771	delivery	5	17
82406	2020-06-21 10:14:04	2020-06-21	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	27908	delivery	5	55
82407	2020-06-21 10:15:53	2020-06-21	12	[{"id_menu":1,"count":1}]	25770	pick-up	0	12
82408	2020-06-21 10:16:11	2020-06-21	17	[{"id_menu":4,"count":1}]	9578	delivery	5	22
82409	2020-06-21 10:16:42	2020-06-21	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	2567	pick-up	0	35
82410	2020-06-21 10:17:12	2020-06-21	9	[{"id_menu":7,"count":1}]	21371	delivery	5	14
82411	2020-06-21 10:18:33	2020-06-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5520	pick-up	0	23
82412	2020-06-21 10:21:00	2020-06-21	12	[{"id_menu":3,"count":1}]	32355	delivery	5	17
82413	2020-06-21 10:26:13	2020-06-21	8	[{"id_menu":5,"count":1}]	11493	delivery	5	13
82414	2020-06-21 10:26:38	2020-06-21	12	[{"id_menu":3,"count":1}]	32221	delivery	5	17
82415	2020-06-21 10:30:25	2020-06-21	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	11650	delivery	5	36
82416	2020-06-21 10:31:21	2020-06-21	9	[{"id_menu":7,"count":1}]	18900	delivery	5	14
82417	2020-06-21 10:31:44	2020-06-21	9	[{"id_menu":6,"count":1}]	21352	pick-up	0	9
82418	2020-06-21 10:32:12	2020-06-21	8	[{"id_menu":5,"count":2}]	12284	pick-up	0	8
82419	2020-06-21 10:36:25	2020-06-21	12	[{"id_menu":3,"count":1}]	12913	delivery	5	17
82420	2020-06-21 10:37:30	2020-06-21	9	[{"id_menu":7,"count":1}]	10442	delivery	5	14
82421	2020-06-21 10:38:33	2020-06-21	9	[{"id_menu":7,"count":1}]	2130	pick-up	0	9
82422	2020-06-21 10:38:56	2020-06-21	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	12340	delivery	5	31
82423	2020-06-21 10:42:35	2020-06-21	12	[{"id_menu":1,"count":1}]	32178	delivery	5	17
82424	2020-06-21 10:43:15	2020-06-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6474	delivery	5	31
82425	2020-06-21 10:46:56	2020-06-21	12	[{"id_menu":1,"count":1}]	21993	pick-up	0	12
82426	2020-06-21 10:52:10	2020-06-21	12	[{"id_menu":3,"count":1}]	24392	delivery	5	17
82427	2020-06-21 10:52:43	2020-06-21	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28164	delivery	5	39
82428	2020-06-21 10:52:47	2020-06-21	8	[{"id_menu":5,"count":1}]	32251	delivery	5	13
82429	2020-06-21 10:53:23	2020-06-21	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6015	delivery	5	40
82430	2020-06-21 10:54:53	2020-06-21	12	[{"id_menu":1,"count":1}]	1168	pick-up	0	12
82431	2020-06-21 10:55:02	2020-06-21	12	[{"id_menu":1,"count":1}]	13062	pick-up	0	12
82432	2020-06-21 10:55:16	2020-06-21	9	[{"id_menu":6,"count":1}]	9624	delivery	5	14
82433	2020-06-21 10:56:27	2020-06-21	17	[{"id_menu":4,"count":1}]	32421	delivery	5	22
82434	2020-06-21 11:00:33	2020-06-21	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24975	delivery	5	40
82435	2020-06-21 11:02:54	2020-06-21	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	28633	delivery	5	31
82436	2020-06-21 11:03:11	2020-06-21	14	[{"id_menu":2,"count":1}]	32325	pick-up	0	14
82437	2020-06-21 11:03:11	2020-06-21	8	[{"id_menu":5,"count":1}]	18840	delivery	5	13
82438	2020-06-21 11:04:11	2020-06-21	14	[{"id_menu":2,"count":1}]	2071	pick-up	0	14
82439	2020-06-21 11:04:23	2020-06-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11804	delivery	5	23
82440	2020-06-21 11:07:00	2020-06-21	12	[{"id_menu":3,"count":1}]	32357	delivery	5	17
82441	2020-06-21 11:07:15	2020-06-21	12	[{"id_menu":3,"count":1}]	8161	pick-up	0	12
82442	2020-06-21 11:10:09	2020-06-21	9	[{"id_menu":7,"count":1}]	32379	delivery	5	14
82443	2020-06-21 11:10:51	2020-06-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32206	delivery	5	22
82444	2020-06-21 11:12:36	2020-06-21	12	[{"id_menu":1,"count":1}]	28458	delivery	5	17
82445	2020-06-21 11:15:59	2020-06-21	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	3636	pick-up	0	21
82446	2020-06-21 11:16:27	2020-06-21	12	[{"id_menu":1,"count":1}]	1223	pick-up	0	12
82447	2020-06-21 11:16:54	2020-06-21	30	[{"id_menu":3,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32213	delivery	5	35
82448	2020-06-21 11:19:00	2020-06-21	17	[{"id_menu":4,"count":1}]	15798	pick-up	0	17
82449	2020-06-21 11:20:54	2020-06-21	12	[{"id_menu":1,"count":1}]	22525	delivery	5	17
82450	2020-06-21 11:23:46	2020-06-21	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3350	delivery	5	49
82451	2020-06-21 11:23:57	2020-06-21	17	[{"id_menu":4,"count":1}]	32207	delivery	5	22
82452	2020-06-21 11:25:29	2020-06-21	12	[{"id_menu":3,"count":1}]	31767	delivery	5	17
82453	2020-06-21 11:27:43	2020-06-21	9	[{"id_menu":6,"count":1}]	19857	delivery	5	14
82454	2020-06-21 11:28:15	2020-06-21	9	[{"id_menu":6,"count":1}]	32234	delivery	5	14
82455	2020-06-21 11:30:00	2020-06-21	12	[{"id_menu":1,"count":1}]	19911	pick-up	0	12
82456	2020-06-21 11:30:39	2020-06-21	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	20215	pick-up	0	35
82457	2020-06-21 11:30:52	2020-06-21	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	32341	delivery	5	34
82458	2020-06-21 11:31:15	2020-06-21	9	[{"id_menu":7,"count":1}]	32196	delivery	5	14
82459	2020-06-21 11:33:26	2020-06-21	9	[{"id_menu":6,"count":1}]	27308	delivery	5	14
82460	2020-06-21 11:38:21	2020-06-21	8	[{"id_menu":5,"count":1}]	19798	delivery	5	13
82461	2020-06-21 11:39:32	2020-06-21	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	31006	pick-up	0	41
82462	2020-06-21 11:42:17	2020-06-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32403	delivery	5	22
82463	2020-06-21 11:42:22	2020-06-21	14	[{"id_menu":2,"count":1}]	12849	delivery	5	19
82464	2020-06-21 11:46:11	2020-06-21	12	[{"id_menu":1,"count":1}]	17567	delivery	5	17
82465	2020-06-21 11:47:44	2020-06-21	8	[{"id_menu":5,"count":1}]	32162	delivery	5	13
82466	2020-06-21 11:48:56	2020-06-21	17	[{"id_menu":4,"count":1}]	3946	pick-up	0	17
82467	2020-06-21 11:48:59	2020-06-21	9	[{"id_menu":7,"count":1}]	24902	delivery	5	14
82468	2020-06-21 11:49:43	2020-06-21	9	[{"id_menu":6,"count":1}]	22737	delivery	5	14
82469	2020-06-21 11:50:14	2020-06-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	32253	delivery	5	22
82470	2020-06-21 11:51:05	2020-06-21	12	[{"id_menu":3,"count":1}]	14905	delivery	5	17
82471	2020-06-21 11:52:17	2020-06-21	14	[{"id_menu":2,"count":1}]	20813	delivery	5	19
82472	2020-06-21 11:55:53	2020-06-21	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	8098	pick-up	0	21
82473	2020-06-21 11:57:57	2020-06-21	9	[{"id_menu":6,"count":1}]	32415	delivery	5	14
82474	2020-06-21 11:59:26	2020-06-21	14	[{"id_menu":2,"count":1}]	3069	pick-up	0	14
82475	2020-06-21 12:00:01	2020-06-21	12	[{"id_menu":3,"count":1}]	27991	delivery	5	17
82476	2020-06-21 12:00:32	2020-06-21	14	[{"id_menu":2,"count":1}]	9017	pick-up	0	14
82477	2020-06-21 12:03:14	2020-06-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	25415	delivery	5	22
82478	2020-06-21 12:03:14	2020-06-21	17	[{"id_menu":4,"count":1}]	2286	pick-up	0	17
82479	2020-06-21 12:05:57	2020-06-21	12	[{"id_menu":3,"count":1}]	11652	delivery	5	17
82480	2020-06-21 12:06:13	2020-06-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32238	pick-up	0	18
82481	2020-06-21 12:07:50	2020-06-21	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	32410	pick-up	0	29
82482	2020-06-21 12:08:39	2020-06-21	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	25134	delivery	5	25
82483	2020-06-21 12:09:46	2020-06-21	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	11414	delivery	5	26
82484	2020-06-21 12:12:49	2020-06-21	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	32177	delivery	5	26
82485	2020-06-21 12:15:13	2020-06-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6448	delivery	5	22
82486	2020-06-21 12:15:34	2020-06-21	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	22485	delivery	5	39
82487	2020-06-21 12:21:39	2020-06-21	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	4075	delivery	5	34
82488	2020-06-21 12:23:37	2020-06-21	9	[{"id_menu":6,"count":1}]	32404	delivery	5	14
82489	2020-06-21 12:25:01	2020-06-21	8	[{"id_menu":5,"count":1}]	15614	delivery	5	13
82490	2020-06-21 12:28:13	2020-06-21	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	19300	pick-up	0	26
82491	2020-06-21 12:30:45	2020-06-21	9	[{"id_menu":7,"count":1}]	32183	delivery	5	14
82492	2020-06-21 12:31:55	2020-06-21	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	7206	delivery	5	29
82493	2020-06-21 12:33:37	2020-06-21	17	[{"id_menu":4,"count":1}]	32272	pick-up	0	17
82494	2020-06-21 12:37:05	2020-06-21	9	[{"id_menu":6,"count":1}]	32287	delivery	5	14
82495	2020-06-21 12:38:22	2020-06-21	12	[{"id_menu":1,"count":1}]	6221	pick-up	0	12
82496	2020-06-21 12:39:38	2020-06-21	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	9021	delivery	5	31
82497	2020-06-21 12:41:00	2020-06-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29462	delivery	5	22
82498	2020-06-21 12:41:01	2020-06-21	14	[{"id_menu":2,"count":1}]	32192	delivery	5	19
82499	2020-06-21 12:43:20	2020-06-21	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20986	delivery	5	52
82500	2020-06-21 12:45:13	2020-06-21	9	[{"id_menu":6,"count":1}]	31716	delivery	5	14
82501	2020-06-21 12:47:17	2020-06-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32381	delivery	5	22
82502	2020-06-21 12:49:32	2020-06-21	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	15645	pick-up	0	20
82503	2020-06-21 12:51:01	2020-06-21	12	[{"id_menu":3,"count":1}]	31682	pick-up	0	12
82504	2020-06-21 12:51:42	2020-06-21	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32228	delivery	5	31
82505	2020-06-21 12:53:19	2020-06-21	17	[{"id_menu":4,"count":1}]	16749	delivery	5	22
82506	2020-06-21 12:53:57	2020-06-21	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	32330	delivery	5	45
82507	2020-06-21 12:55:00	2020-06-21	9	[{"id_menu":7,"count":1}]	1270	delivery	5	14
82508	2020-06-21 12:56:27	2020-06-21	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	32417	pick-up	0	20
82509	2020-06-21 12:56:29	2020-06-21	17	[{"id_menu":4,"count":1}]	26787	delivery	5	22
82510	2020-06-21 12:56:41	2020-06-21	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	19130	delivery	5	40
82511	2020-06-21 12:59:34	2020-06-21	17	[{"id_menu":4,"count":1}]	32197	delivery	5	22
82512	2020-06-21 13:04:55	2020-06-21	12	[{"id_menu":3,"count":1}]	3444	pick-up	0	12
82513	2020-06-21 13:05:13	2020-06-21	8	[{"id_menu":5,"count":1}]	32203	delivery	5	13
82514	2020-06-21 13:06:45	2020-06-21	9	[{"id_menu":7,"count":1}]	15930	delivery	5	14
82515	2020-06-21 13:10:25	2020-06-21	9	[{"id_menu":7,"count":1}]	32376	delivery	5	14
82516	2020-06-21 13:12:01	2020-06-21	12	[{"id_menu":1,"count":1}]	32152	delivery	5	17
82517	2020-06-21 13:12:19	2020-06-21	14	[{"id_menu":2,"count":1}]	29001	delivery	5	19
82518	2020-06-21 13:15:00	2020-06-21	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	12409	delivery	5	30
82519	2020-06-21 13:15:16	2020-06-21	14	[{"id_menu":2,"count":1}]	32312	delivery	5	19
82520	2020-06-21 13:15:18	2020-06-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8629	pick-up	0	26
82521	2020-06-21 13:17:41	2020-06-21	17	[{"id_menu":4,"count":1}]	15186	pick-up	0	17
82522	2020-06-21 13:19:14	2020-06-21	9	[{"id_menu":7,"count":2}]	32264	delivery	5	14
82523	2020-06-21 13:20:11	2020-06-21	9	[{"id_menu":7,"count":1}]	32349	delivery	5	14
82524	2020-06-21 13:21:25	2020-06-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	32366	delivery	5	22
82525	2020-06-21 13:24:12	2020-06-21	14	[{"id_menu":2,"count":1}]	3345	delivery	5	19
82526	2020-06-21 13:24:31	2020-06-21	9	[{"id_menu":6,"count":1}]	8941	delivery	5	14
82527	2020-06-21 13:25:15	2020-06-21	14	[{"id_menu":2,"count":1}]	11073	pick-up	0	14
82528	2020-06-21 13:25:59	2020-06-21	17	[{"id_menu":4,"count":1}]	32347	delivery	5	22
82529	2020-06-21 13:26:00	2020-06-21	9	[{"id_menu":7,"count":1}]	19091	pick-up	0	9
82530	2020-06-21 13:26:03	2020-06-21	9	[{"id_menu":6,"count":1}]	9105	delivery	5	14
82531	2020-06-21 13:28:51	2020-06-21	9	[{"id_menu":6,"count":1}]	28726	delivery	5	14
82532	2020-06-21 13:28:53	2020-06-21	12	[{"id_menu":3,"count":1}]	1241	delivery	5	17
82533	2020-06-21 13:30:30	2020-06-21	17	[{"id_menu":4,"count":2}]	547	pick-up	0	17
82534	2020-06-21 13:34:45	2020-06-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6490	pick-up	0	17
82535	2020-06-21 13:34:56	2020-06-21	9	[{"id_menu":6,"count":1}]	3996	delivery	5	14
82536	2020-06-21 13:38:01	2020-06-21	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32223	delivery	5	39
82537	2020-06-21 13:39:30	2020-06-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	28709	delivery	5	28
82538	2020-06-21 13:39:39	2020-06-21	17	[{"id_menu":4,"count":1}]	3080	pick-up	0	17
82539	2020-06-21 13:40:50	2020-06-21	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	32380	delivery	5	43
82540	2020-06-21 13:43:00	2020-06-21	8	[{"id_menu":5,"count":1}]	11603	delivery	5	13
82541	2020-06-21 13:44:43	2020-06-21	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	32256	delivery	5	48
82542	2020-06-21 13:45:23	2020-06-21	9	[{"id_menu":7,"count":2}]	32239	delivery	5	14
82543	2020-06-21 13:46:08	2020-06-21	12	[{"id_menu":3,"count":1}]	2418	delivery	5	17
82544	2020-06-21 13:47:41	2020-06-21	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	32220	delivery	5	27
82545	2020-06-21 13:48:25	2020-06-21	9	[{"id_menu":6,"count":1}]	8125	delivery	5	14
82546	2020-06-21 13:49:06	2020-06-21	17	[{"id_menu":4,"count":1}]	32305	delivery	5	22
82547	2020-06-21 13:49:54	2020-06-21	8	[{"id_menu":5,"count":1}]	32189	delivery	5	13
82548	2020-06-21 13:49:58	2020-06-21	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32382	delivery	5	31
82549	2020-06-21 13:52:16	2020-06-21	12	[{"id_menu":1,"count":1}]	32259	delivery	5	17
82550	2020-06-21 13:58:28	2020-06-21	9	[{"id_menu":6,"count":1}]	24540	delivery	5	14
82551	2020-06-21 13:59:35	2020-06-21	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	15535	delivery	5	34
82552	2020-06-21 14:01:01	2020-06-21	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	28253	delivery	5	26
82553	2020-06-21 14:03:55	2020-06-21	12	[{"id_menu":1,"count":1}]	32384	pick-up	0	12
82554	2020-06-21 14:06:13	2020-06-21	12	[{"id_menu":3,"count":1}]	18807	delivery	5	17
82555	2020-06-21 14:06:43	2020-06-21	17	[{"id_menu":4,"count":1}]	17569	pick-up	0	17
82556	2020-06-21 14:08:51	2020-06-21	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	32254	delivery	5	40
82557	2020-06-21 14:11:54	2020-06-21	9	[{"id_menu":6,"count":1}]	8234	delivery	5	14
82558	2020-06-21 14:12:05	2020-06-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	9167	delivery	5	28
82559	2020-06-21 14:15:01	2020-06-21	8	[{"id_menu":5,"count":1}]	5994	delivery	5	13
82560	2020-06-21 14:20:47	2020-06-21	9	[{"id_menu":6,"count":1}]	29958	delivery	5	14
82561	2020-06-21 14:26:27	2020-06-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	32350	delivery	5	31
82562	2020-06-21 14:26:45	2020-06-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32236	delivery	5	23
82563	2020-06-21 14:27:26	2020-06-21	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	20618	delivery	5	23
82564	2020-06-21 14:28:14	2020-06-21	14	[{"id_menu":2,"count":1}]	4258	delivery	5	19
82565	2020-06-21 14:29:05	2020-06-21	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	12975	delivery	5	30
82566	2020-06-21 14:30:23	2020-06-21	14	[{"id_menu":2,"count":1}]	23087	pick-up	0	14
82567	2020-06-21 14:32:49	2020-06-21	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	32292	delivery	5	28
82568	2020-06-21 14:34:16	2020-06-21	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	24634	delivery	5	34
82569	2020-06-21 14:34:57	2020-06-21	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4796	delivery	5	39
82570	2020-06-21 14:39:33	2020-06-21	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":2}]	32401	delivery	5	22
82571	2020-06-21 14:40:57	2020-06-21	9	[{"id_menu":6,"count":1}]	32265	delivery	5	14
82572	2020-06-21 14:44:28	2020-06-21	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	32191	delivery	5	26
82573	2020-06-21 14:46:48	2020-06-21	9	[{"id_menu":6,"count":1}]	32375	delivery	5	14
82574	2020-06-21 14:47:05	2020-06-21	12	[{"id_menu":1,"count":1}]	32344	delivery	5	17
82575	2020-06-21 14:49:02	2020-06-21	9	[{"id_menu":7,"count":1}]	755	pick-up	0	9
82576	2020-06-21 14:54:26	2020-06-21	9	[{"id_menu":6,"count":1}]	32386	delivery	5	14
82577	2020-06-21 14:54:35	2020-06-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29660	delivery	5	22
82578	2020-06-21 14:56:45	2020-06-21	14	[{"id_menu":2,"count":1}]	15768	delivery	5	19
82579	2020-06-21 15:00:13	2020-06-21	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	13753	delivery	5	26
82580	2020-06-21 15:00:55	2020-06-21	17	[{"id_menu":4,"count":1}]	12965	delivery	5	22
82581	2020-06-21 15:02:16	2020-06-21	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	32159	delivery	5	34
82582	2020-06-21 15:04:15	2020-06-21	12	[{"id_menu":3,"count":1}]	4644	pick-up	0	12
82583	2020-06-21 15:08:15	2020-06-21	9	[{"id_menu":7,"count":2}]	27426	delivery	5	14
82584	2020-06-21 15:10:02	2020-06-21	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	6009	pick-up	0	21
82585	2020-06-21 15:12:19	2020-06-21	12	[{"id_menu":1,"count":1}]	826	pick-up	0	12
82586	2020-06-21 15:13:09	2020-06-21	9	[{"id_menu":6,"count":1}]	32208	delivery	5	14
82587	2020-06-21 15:14:21	2020-06-21	9	[{"id_menu":6,"count":1}]	8598	pick-up	0	9
82588	2020-06-21 15:16:16	2020-06-21	9	[{"id_menu":7,"count":1}]	10179	delivery	5	14
82589	2020-06-21 15:17:10	2020-06-21	17	[{"id_menu":4,"count":1}]	356	pick-up	0	17
82590	2020-06-21 15:17:57	2020-06-21	14	[{"id_menu":2,"count":1}]	24531	delivery	5	19
82591	2020-06-21 15:20:10	2020-06-21	12	[{"id_menu":3,"count":1}]	25930	delivery	5	17
82592	2020-06-21 15:20:41	2020-06-21	9	[{"id_menu":6,"count":1}]	7638	delivery	5	14
82593	2020-06-21 15:22:34	2020-06-21	17	[{"id_menu":4,"count":1}]	1313	delivery	5	22
82594	2020-06-21 15:22:56	2020-06-21	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	31190	delivery	5	29
82595	2020-06-21 15:24:39	2020-06-21	9	[{"id_menu":7,"count":1}]	32180	delivery	5	14
82596	2020-06-21 15:27:10	2020-06-21	12	[{"id_menu":3,"count":1}]	12070	pick-up	0	12
82597	2020-06-21 15:28:21	2020-06-21	9	[{"id_menu":6,"count":1}]	11791	pick-up	0	9
82598	2020-06-21 15:28:24	2020-06-21	9	[{"id_menu":7,"count":1}]	16484	pick-up	0	9
82599	2020-06-21 15:29:02	2020-06-21	9	[{"id_menu":7,"count":1}]	7279	delivery	5	14
82600	2020-06-21 15:31:28	2020-06-21	14	[{"id_menu":2,"count":1}]	8146	pick-up	0	14
82601	2020-06-21 15:32:41	2020-06-21	12	[{"id_menu":1,"count":1}]	32172	pick-up	0	12
82602	2020-06-21 15:33:39	2020-06-21	12	[{"id_menu":1,"count":1}]	32231	delivery	5	17
82603	2020-06-21 15:34:18	2020-06-21	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32326	delivery	5	40
82604	2020-06-21 15:34:27	2020-06-21	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	8782	delivery	5	22
82605	2020-06-21 15:35:41	2020-06-21	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	15910	pick-up	0	24
82606	2020-06-21 15:36:00	2020-06-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	32387	delivery	5	28
82607	2020-06-21 15:37:56	2020-06-21	8	[{"id_menu":5,"count":1}]	9198	pick-up	0	8
82608	2020-06-21 15:38:35	2020-06-21	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1518	delivery	5	39
82609	2020-06-21 15:41:14	2020-06-21	17	[{"id_menu":4,"count":2}]	32352	delivery	5	22
82610	2020-06-21 15:41:41	2020-06-21	8	[{"id_menu":5,"count":1}]	32273	delivery	5	13
82611	2020-06-21 15:47:12	2020-06-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	9036	delivery	5	31
82612	2020-06-21 15:50:05	2020-06-21	9	[{"id_menu":6,"count":1}]	32275	delivery	5	14
82613	2020-06-21 15:52:38	2020-06-21	9	[{"id_menu":6,"count":1}]	5192	delivery	5	14
82614	2020-06-21 15:52:56	2020-06-21	14	[{"id_menu":2,"count":1}]	10356	delivery	5	19
82615	2020-06-21 15:54:07	2020-06-21	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	25118	delivery	5	43
82616	2020-06-21 15:55:37	2020-06-21	14	[{"id_menu":2,"count":1}]	32289	delivery	5	19
82617	2020-06-21 15:59:53	2020-06-21	9	[{"id_menu":6,"count":1}]	13191	delivery	5	14
82618	2020-06-21 16:00:35	2020-06-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29642	delivery	5	23
82619	2020-06-21 16:01:01	2020-06-21	17	[{"id_menu":4,"count":1}]	30201	delivery	5	22
82620	2020-06-21 16:01:40	2020-06-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	31167	delivery	5	22
82621	2020-06-21 16:02:35	2020-06-21	8	[{"id_menu":5,"count":1}]	20482	delivery	5	13
82622	2020-06-21 16:03:18	2020-06-21	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	14218	delivery	5	36
82623	2020-06-21 16:05:05	2020-06-21	9	[{"id_menu":7,"count":1}]	32377	delivery	5	14
82624	2020-06-21 16:08:00	2020-06-21	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32361	delivery	5	45
82625	2020-06-21 16:10:50	2020-06-21	12	[{"id_menu":3,"count":1}]	9082	pick-up	0	12
82626	2020-06-21 16:11:05	2020-06-21	14	[{"id_menu":2,"count":1}]	17540	delivery	5	19
82627	2020-06-21 16:11:46	2020-06-21	17	[{"id_menu":4,"count":1}]	805	pick-up	0	17
82628	2020-06-21 16:12:04	2020-06-21	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	21184	delivery	5	34
82629	2020-06-21 16:13:40	2020-06-21	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	10785	pick-up	0	26
82630	2020-06-21 16:13:59	2020-06-21	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29655	delivery	5	34
82631	2020-06-21 16:15:37	2020-06-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	14974	delivery	5	31
82632	2020-06-21 16:15:55	2020-06-21	8	[{"id_menu":5,"count":1}]	2647	delivery	5	13
82633	2020-06-21 16:17:45	2020-06-21	12	[{"id_menu":3,"count":1}]	15187	pick-up	0	12
82634	2020-06-21 16:18:28	2020-06-21	17	[{"id_menu":4,"count":1}]	5963	pick-up	0	17
82635	2020-06-21 16:18:45	2020-06-21	9	[{"id_menu":6,"count":2}]	32407	delivery	5	14
82636	2020-06-21 16:22:48	2020-06-21	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	18318	delivery	5	34
82637	2020-06-21 16:22:56	2020-06-21	17	[{"id_menu":4,"count":1}]	295	delivery	5	22
82638	2020-06-21 16:23:06	2020-06-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	25779	delivery	5	31
82639	2020-06-21 16:24:23	2020-06-21	14	[{"id_menu":2,"count":1}]	28583	delivery	5	19
82640	2020-06-21 16:25:59	2020-06-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	13585	delivery	5	23
82641	2020-06-21 16:26:55	2020-06-21	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25799	delivery	5	35
82642	2020-06-21 16:37:14	2020-06-21	9	[{"id_menu":6,"count":1}]	28221	delivery	5	14
82643	2020-06-21 16:37:20	2020-06-21	9	[{"id_menu":6,"count":1}]	31843	delivery	5	14
82644	2020-06-21 16:38:05	2020-06-21	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32308	delivery	5	40
82645	2020-06-21 16:39:32	2020-06-21	8	[{"id_menu":5,"count":1}]	8293	delivery	5	13
82646	2020-06-21 16:40:49	2020-06-21	12	[{"id_menu":3,"count":1}]	13502	pick-up	0	12
82647	2020-06-21 16:42:03	2020-06-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	271	delivery	5	31
82648	2020-06-21 16:44:24	2020-06-21	9	[{"id_menu":6,"count":1}]	32276	delivery	5	14
82649	2020-06-21 16:45:30	2020-06-21	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	7205	delivery	5	25
82650	2020-06-21 16:48:36	2020-06-21	12	[{"id_menu":3,"count":1}]	32173	delivery	5	17
82651	2020-06-21 16:56:40	2020-06-21	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	32373	delivery	5	30
82652	2020-06-21 16:58:24	2020-06-21	9	[{"id_menu":6,"count":1}]	30956	delivery	5	14
82653	2020-06-21 16:59:45	2020-06-21	9	[{"id_menu":6,"count":2}]	32395	delivery	5	14
82654	2020-06-21 16:59:50	2020-06-21	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2704	delivery	5	43
82655	2020-06-21 17:00:58	2020-06-21	9	[{"id_menu":7,"count":1}]	32245	delivery	5	14
82656	2020-06-21 17:01:26	2020-06-21	9	[{"id_menu":6,"count":1}]	5030	delivery	5	14
82657	2020-06-21 17:01:41	2020-06-21	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20673	delivery	5	54
82658	2020-06-21 17:06:33	2020-06-21	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":2}]	6976	delivery	5	34
82659	2020-06-21 17:09:12	2020-06-21	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	1234	delivery	5	31
82660	2020-06-21 17:10:57	2020-06-21	9	[{"id_menu":7,"count":1}]	1176	delivery	5	14
82661	2020-06-21 17:11:06	2020-06-21	9	[{"id_menu":6,"count":1}]	23891	delivery	5	14
82662	2020-06-21 17:11:43	2020-06-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	27557	delivery	5	28
82663	2020-06-21 17:18:19	2020-06-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32224	delivery	5	22
82664	2020-06-21 17:18:59	2020-06-21	9	[{"id_menu":7,"count":1}]	32250	delivery	5	14
82665	2020-06-21 17:23:13	2020-06-21	12	[{"id_menu":3,"count":1}]	3403	pick-up	0	12
82666	2020-06-21 17:26:35	2020-06-21	9	[{"id_menu":6,"count":1}]	25836	pick-up	0	9
82667	2020-06-21 17:28:20	2020-06-21	14	[{"id_menu":2,"count":1}]	7020	delivery	5	19
82668	2020-06-21 17:29:41	2020-06-21	14	[{"id_menu":2,"count":1}]	9855	delivery	5	19
82669	2020-06-21 17:30:16	2020-06-21	12	[{"id_menu":3,"count":1}]	13050	pick-up	0	12
82670	2020-06-21 17:32:55	2020-06-21	12	[{"id_menu":1,"count":1}]	28245	delivery	5	17
82671	2020-06-21 17:39:42	2020-06-21	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28210	delivery	5	39
82672	2020-06-21 17:40:09	2020-06-21	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3129	delivery	5	31
82673	2020-06-21 17:40:22	2020-06-21	9	[{"id_menu":6,"count":1}]	24998	delivery	5	14
82674	2020-06-21 17:42:20	2020-06-21	9	[{"id_menu":7,"count":1}]	1406	delivery	5	14
82675	2020-06-21 17:43:03	2020-06-21	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20136	delivery	5	37
82676	2020-06-21 17:44:24	2020-06-21	17	[{"id_menu":4,"count":1}]	2966	pick-up	0	17
82677	2020-06-21 17:45:41	2020-06-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5982	delivery	5	22
82678	2020-06-21 17:45:58	2020-06-21	12	[{"id_menu":1,"count":1}]	9366	delivery	5	17
82679	2020-06-21 17:48:03	2020-06-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15441	delivery	5	23
82680	2020-06-21 17:48:12	2020-06-21	14	[{"id_menu":2,"count":1}]	8032	delivery	5	19
82681	2020-06-21 17:49:53	2020-06-21	14	[{"id_menu":2,"count":1}]	18344	pick-up	0	14
82682	2020-06-21 17:50:07	2020-06-21	9	[{"id_menu":6,"count":1}]	24363	delivery	5	14
82683	2020-06-21 17:58:30	2020-06-21	14	[{"id_menu":2,"count":1}]	21337	delivery	5	19
82684	2020-06-21 17:59:47	2020-06-21	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	32340	delivery	5	34
82685	2020-06-21 18:05:12	2020-06-21	12	[{"id_menu":3,"count":1}]	32280	delivery	5	17
82686	2020-06-21 18:05:48	2020-06-21	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	32343	delivery	5	27
82687	2020-06-21 18:08:44	2020-06-21	12	[{"id_menu":1,"count":1}]	19380	delivery	5	17
82688	2020-06-21 18:10:49	2020-06-21	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4967	pick-up	0	31
82689	2020-06-21 18:11:29	2020-06-21	12	[{"id_menu":1,"count":1}]	10845	delivery	5	17
82690	2020-06-21 18:13:42	2020-06-21	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	32193	delivery	5	39
82691	2020-06-21 18:18:42	2020-06-21	9	[{"id_menu":7,"count":1}]	32331	delivery	5	14
82692	2020-06-21 18:18:45	2020-06-21	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16181	delivery	5	31
82693	2020-06-21 18:19:38	2020-06-21	12	[{"id_menu":1,"count":1}]	32303	delivery	5	17
82694	2020-06-21 18:21:58	2020-06-21	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	2199	delivery	5	26
82695	2020-06-21 18:22:55	2020-06-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	12711	delivery	5	22
82696	2020-06-21 18:24:09	2020-06-21	9	[{"id_menu":6,"count":1}]	2096	pick-up	0	9
82697	2020-06-21 18:28:18	2020-06-21	12	[{"id_menu":3,"count":1}]	32311	pick-up	0	12
82698	2020-06-21 18:31:14	2020-06-21	9	[{"id_menu":6,"count":1}]	32195	delivery	5	14
82699	2020-06-21 18:33:21	2020-06-21	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	32237	delivery	5	26
82700	2020-06-21 18:33:39	2020-06-21	8	[{"id_menu":5,"count":1}]	32267	delivery	5	13
82701	2020-06-21 18:34:56	2020-06-21	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	32396	delivery	5	27
82702	2020-06-21 18:35:28	2020-06-21	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17114	delivery	5	34
82703	2020-06-21 18:37:07	2020-06-21	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	16365	delivery	5	43
82704	2020-06-21 18:37:08	2020-06-21	14	[{"id_menu":2,"count":1}]	24692	delivery	5	19
82705	2020-06-21 18:38:44	2020-06-21	9	[{"id_menu":7,"count":1}]	743	pick-up	0	9
82706	2020-06-21 18:39:55	2020-06-21	9	[{"id_menu":7,"count":1}]	32230	delivery	5	14
82707	2020-06-21 18:40:52	2020-06-21	9	[{"id_menu":6,"count":1}]	32284	delivery	5	14
82708	2020-06-21 18:42:37	2020-06-21	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	11554	pick-up	0	21
82709	2020-06-21 18:43:17	2020-06-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	32318	delivery	5	31
82710	2020-06-21 18:47:33	2020-06-21	17	[{"id_menu":4,"count":1}]	25993	delivery	5	22
82711	2020-06-21 18:48:32	2020-06-21	12	[{"id_menu":1,"count":1}]	4122	delivery	5	17
82712	2020-06-21 18:50:57	2020-06-21	9	[{"id_menu":6,"count":1}]	32211	delivery	5	14
82713	2020-06-21 18:53:24	2020-06-21	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32385	delivery	5	51
82714	2020-06-21 18:59:01	2020-06-21	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28743	delivery	5	34
82715	2020-06-21 18:59:04	2020-06-21	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4190	delivery	5	30
82716	2020-06-21 19:00:14	2020-06-21	12	[{"id_menu":1,"count":1}]	11532	pick-up	0	12
82717	2020-06-21 19:01:04	2020-06-21	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	27249	delivery	5	43
82718	2020-06-21 19:07:23	2020-06-21	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":2}]	31428	delivery	5	28
82719	2020-06-21 19:07:40	2020-06-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	32210	delivery	5	31
82720	2020-06-21 19:08:13	2020-06-21	14	[{"id_menu":2,"count":1}]	3371	delivery	5	19
82721	2020-06-21 19:09:24	2020-06-21	8	[{"id_menu":5,"count":1}]	32378	delivery	5	13
82722	2020-06-21 19:10:19	2020-06-21	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	31707	delivery	5	36
82723	2020-06-21 19:10:34	2020-06-21	12	[{"id_menu":3,"count":1}]	10354	delivery	5	17
82724	2020-06-21 19:14:01	2020-06-21	14	[{"id_menu":2,"count":1}]	22217	delivery	5	19
82725	2020-06-21 19:14:16	2020-06-21	14	[{"id_menu":2,"count":1}]	32394	delivery	5	19
82726	2020-06-21 19:15:24	2020-06-21	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":3}]	12954	delivery	5	25
82727	2020-06-21 19:15:36	2020-06-21	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5346	delivery	5	34
82728	2020-06-21 19:15:55	2020-06-21	17	[{"id_menu":4,"count":1}]	20309	delivery	5	22
82729	2020-06-21 19:16:06	2020-06-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3089	pick-up	0	23
82730	2020-06-21 19:20:18	2020-06-21	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	32155	delivery	5	36
82731	2020-06-21 19:23:15	2020-06-21	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	32418	pick-up	0	31
82732	2020-06-21 19:25:18	2020-06-21	14	[{"id_menu":2,"count":1}]	8725	delivery	5	19
82733	2020-06-21 19:27:47	2020-06-21	12	[{"id_menu":1,"count":1}]	32388	pick-up	0	12
82734	2020-06-21 19:29:49	2020-06-21	14	[{"id_menu":2,"count":1}]	11446	pick-up	0	14
82735	2020-06-21 19:34:51	2020-06-21	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	32306	delivery	5	43
82736	2020-06-21 19:36:31	2020-06-21	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	22722	delivery	5	31
82737	2020-06-21 19:36:51	2020-06-21	12	[{"id_menu":3,"count":1}]	8546	delivery	5	17
82738	2020-06-21 19:43:27	2020-06-21	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	30000	pick-up	0	31
82739	2020-06-21 19:43:48	2020-06-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3180	pick-up	0	26
82740	2020-06-21 19:44:53	2020-06-21	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	675	delivery	5	31
82741	2020-06-21 19:45:16	2020-06-21	9	[{"id_menu":6,"count":1}]	5509	delivery	5	14
82742	2020-06-21 19:45:25	2020-06-21	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	30864	delivery	5	30
82743	2020-06-21 19:45:35	2020-06-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15292	delivery	5	22
82744	2020-06-21 19:50:12	2020-06-21	9	[{"id_menu":7,"count":1}]	6894	delivery	5	14
82745	2020-06-21 19:53:37	2020-06-21	8	[{"id_menu":5,"count":1}]	5935	delivery	5	13
82746	2020-06-21 19:57:38	2020-06-21	12	[{"id_menu":3,"count":1}]	13164	delivery	5	17
82747	2020-06-21 19:59:17	2020-06-21	8	[{"id_menu":5,"count":1}]	32371	delivery	5	13
82748	2020-06-21 20:01:09	2020-06-21	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	32342	delivery	5	31
82749	2020-06-21 20:02:08	2020-06-21	17	[{"id_menu":4,"count":1}]	1414	delivery	5	22
82750	2020-06-21 20:02:12	2020-06-21	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32279	delivery	5	34
82751	2020-06-21 20:05:11	2020-06-21	12	[{"id_menu":3,"count":1}]	20493	pick-up	0	12
82752	2020-06-21 20:06:40	2020-06-21	17	[{"id_menu":4,"count":1}]	3904	pick-up	0	17
82753	2020-06-21 20:06:43	2020-06-21	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	32285	delivery	5	26
82754	2020-06-21 20:08:17	2020-06-21	8	[{"id_menu":5,"count":1}]	11961	delivery	5	13
82755	2020-06-21 20:08:29	2020-06-21	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	28606	pick-up	0	26
82756	2020-06-21 20:16:41	2020-06-21	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	20077	delivery	5	39
82757	2020-06-21 20:17:14	2020-06-21	8	[{"id_menu":5,"count":1}]	24982	delivery	5	13
82758	2020-06-21 20:19:04	2020-06-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	16802	delivery	5	28
82759	2020-06-21 20:21:35	2020-06-21	17	[{"id_menu":4,"count":1}]	22623	pick-up	0	17
82760	2020-06-21 20:21:41	2020-06-21	17	[{"id_menu":4,"count":1}]	13651	pick-up	0	17
82761	2020-06-21 20:22:22	2020-06-21	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	17251	delivery	5	31
82762	2020-06-21 20:23:06	2020-06-21	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	32158	delivery	5	34
82763	2020-06-21 20:23:24	2020-06-21	9	[{"id_menu":7,"count":1}]	21600	delivery	5	14
82764	2020-06-21 20:24:24	2020-06-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	11118	delivery	5	31
82765	2020-06-21 20:26:38	2020-06-21	9	[{"id_menu":6,"count":1}]	32400	delivery	5	14
82766	2020-06-21 20:27:01	2020-06-21	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	10003	delivery	5	25
82767	2020-06-21 20:27:54	2020-06-21	9	[{"id_menu":6,"count":1}]	27855	delivery	5	14
82768	2020-06-21 20:33:28	2020-06-21	14	[{"id_menu":2,"count":1}]	11277	delivery	5	19
82769	2020-06-21 20:35:24	2020-06-21	9	[{"id_menu":7,"count":1}]	32227	delivery	5	14
82770	2020-06-21 20:44:10	2020-06-21	17	[{"id_menu":4,"count":1}]	32398	delivery	5	22
82771	2020-06-21 20:44:16	2020-06-21	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	5458	delivery	5	31
82772	2020-06-21 20:49:03	2020-06-21	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	20833	delivery	5	39
82773	2020-06-21 20:53:12	2020-06-21	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	9539	delivery	5	27
82774	2020-06-21 20:55:28	2020-06-21	9	[{"id_menu":7,"count":1}]	788	pick-up	0	9
82775	2020-06-21 20:57:01	2020-06-21	23	[{"id_menu":2,"count":3},{"id_menu":6,"count":1}]	24452	pick-up	0	23
82776	2020-06-21 21:00:49	2020-06-21	12	[{"id_menu":1,"count":1}]	21553	delivery	5	17
82777	2020-06-21 21:02:41	2020-06-21	9	[{"id_menu":7,"count":1}]	26890	delivery	5	14
82778	2020-06-21 21:03:32	2020-06-21	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	24609	pick-up	0	43
82779	2020-06-21 21:08:11	2020-06-21	9	[{"id_menu":7,"count":1}]	24899	delivery	5	14
82780	2020-06-21 21:09:52	2020-06-21	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	8649	delivery	5	28
82781	2020-06-21 21:14:07	2020-06-21	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	5082	pick-up	0	29
82782	2020-06-21 21:14:42	2020-06-21	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	29662	pick-up	0	18
82783	2020-06-21 21:16:47	2020-06-21	14	[{"id_menu":2,"count":1}]	32320	delivery	5	19
82784	2020-06-21 21:19:42	2020-06-21	14	[{"id_menu":2,"count":1}]	6036	delivery	5	19
82785	2020-06-21 21:20:38	2020-06-21	9	[{"id_menu":6,"count":1}]	5789	delivery	5	14
82786	2020-06-21 21:25:36	2020-06-21	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19082	delivery	5	35
82787	2020-06-21 21:25:48	2020-06-21	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":3}]	14825	delivery	5	27
82788	2020-06-21 21:26:18	2020-06-21	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	32364	delivery	5	39
82789	2020-06-21 21:28:00	2020-06-21	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	32337	delivery	5	43
82790	2020-06-21 21:28:19	2020-06-21	8	[{"id_menu":5,"count":1}]	21749	delivery	5	13
82791	2020-06-21 21:30:10	2020-06-21	9	[{"id_menu":6,"count":1}]	7835	delivery	5	14
82792	2020-06-21 21:31:20	2020-06-21	8	[{"id_menu":5,"count":1}]	20492	delivery	5	13
82793	2020-06-21 21:32:12	2020-06-21	12	[{"id_menu":3,"count":1}]	30050	delivery	5	17
82794	2020-06-21 21:33:17	2020-06-21	12	[{"id_menu":1,"count":1}]	25785	delivery	5	17
82795	2020-06-21 21:34:41	2020-06-21	8	[{"id_menu":5,"count":1}]	25827	pick-up	0	8
82796	2020-06-21 21:35:17	2020-06-21	8	[{"id_menu":5,"count":1}]	7951	delivery	5	13
82797	2020-06-21 21:37:14	2020-06-21	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	32269	delivery	5	31
82798	2020-06-21 21:39:05	2020-06-21	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	14229	delivery	5	34
82799	2020-06-21 21:39:52	2020-06-21	9	[{"id_menu":7,"count":1}]	32164	delivery	5	14
82800	2020-06-21 21:42:52	2020-06-21	9	[{"id_menu":7,"count":1}]	18643	delivery	5	14
82801	2020-06-21 21:44:50	2020-06-21	14	[{"id_menu":2,"count":1}]	19005	pick-up	0	14
82802	2020-06-21 21:45:54	2020-06-21	9	[{"id_menu":6,"count":1}]	32185	delivery	5	14
82803	2020-06-21 21:46:55	2020-06-21	8	[{"id_menu":5,"count":1}]	847	pick-up	0	8
82804	2020-06-21 21:47:34	2020-06-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32181	delivery	5	22
82805	2020-06-21 21:48:47	2020-06-21	17	[{"id_menu":4,"count":1}]	3524	pick-up	0	17
82806	2020-06-21 21:48:49	2020-06-21	9	[{"id_menu":7,"count":1}]	30094	delivery	5	14
82807	2020-06-21 21:51:33	2020-06-21	12	[{"id_menu":3,"count":2}]	32184	pick-up	0	12
82808	2020-06-21 21:51:37	2020-06-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	31298	delivery	5	28
82809	2020-06-21 21:56:49	2020-06-21	12	[{"id_menu":3,"count":1}]	6243	pick-up	0	12
82810	2020-06-21 21:57:07	2020-06-21	9	[{"id_menu":6,"count":1}]	10783	pick-up	0	9
82811	2020-06-21 21:58:26	2020-06-21	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	32358	delivery	5	22
82812	2020-06-21 21:58:35	2020-06-21	8	[{"id_menu":5,"count":1}]	3159	delivery	5	13
82813	2020-06-21 21:59:13	2020-06-21	9	[{"id_menu":6,"count":1}]	19908	delivery	5	14
82814	2020-06-21 21:59:14	2020-06-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20811	delivery	5	22
82815	2020-06-21 21:59:37	2020-06-21	14	[{"id_menu":2,"count":1}]	28279	pick-up	0	14
82816	2020-06-21 22:01:27	2020-06-21	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23409	delivery	5	36
82817	2020-06-21 22:05:59	2020-06-21	12	[{"id_menu":3,"count":1}]	23585	pick-up	0	12
82818	2020-06-21 22:09:27	2020-06-21	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	12068	delivery	5	31
82819	2020-06-21 22:10:25	2020-06-21	14	[{"id_menu":2,"count":1}]	32392	delivery	5	19
82820	2020-06-21 22:10:43	2020-06-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32295	delivery	5	22
82821	2020-06-21 22:11:13	2020-06-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	31129	pick-up	0	26
82822	2020-06-21 22:13:00	2020-06-21	9	[{"id_menu":6,"count":1}]	25079	delivery	5	14
82823	2020-06-21 22:13:29	2020-06-21	9	[{"id_menu":6,"count":3}]	32296	delivery	5	14
82824	2020-06-21 22:14:06	2020-06-21	12	[{"id_menu":1,"count":1}]	16176	delivery	5	17
82825	2020-06-21 22:14:25	2020-06-21	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32166	delivery	5	39
82826	2020-06-21 22:16:07	2020-06-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31254	delivery	5	22
82827	2020-06-21 22:16:25	2020-06-21	9	[{"id_menu":6,"count":1}]	371	delivery	5	14
82828	2020-06-21 22:16:41	2020-06-21	9	[{"id_menu":6,"count":1}]	15965	delivery	5	14
82829	2020-06-21 22:19:48	2020-06-21	8	[{"id_menu":5,"count":1}]	32157	delivery	5	13
82830	2020-06-21 22:23:26	2020-06-21	8	[{"id_menu":5,"count":1}]	32209	delivery	5	13
82831	2020-06-21 22:25:26	2020-06-21	14	[{"id_menu":2,"count":1}]	32334	delivery	5	19
82832	2020-06-21 22:25:45	2020-06-21	8	[{"id_menu":5,"count":1}]	4624	pick-up	0	8
82833	2020-06-21 22:26:14	2020-06-21	9	[{"id_menu":7,"count":1}]	32339	delivery	5	14
82834	2020-06-21 22:28:24	2020-06-21	9	[{"id_menu":6,"count":1}]	6392	delivery	5	14
82835	2020-06-21 22:28:37	2020-06-21	14	[{"id_menu":2,"count":1}]	32336	pick-up	0	14
82836	2020-06-21 22:33:10	2020-06-21	9	[{"id_menu":6,"count":1}]	32412	delivery	5	14
82837	2020-06-21 22:38:35	2020-06-21	14	[{"id_menu":2,"count":1}]	2311	pick-up	0	14
82838	2020-06-21 22:38:37	2020-06-21	12	[{"id_menu":1,"count":1}]	2807	delivery	5	17
82839	2020-06-21 22:39:08	2020-06-21	9	[{"id_menu":6,"count":1}]	7992	pick-up	0	9
82840	2020-06-21 22:39:46	2020-06-21	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32356	delivery	5	35
82841	2020-06-21 22:45:05	2020-06-21	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	30455	pick-up	0	31
82842	2020-06-21 22:45:34	2020-06-21	12	[{"id_menu":1,"count":1}]	13744	delivery	5	17
82843	2020-06-21 22:46:40	2020-06-21	17	[{"id_menu":4,"count":1}]	15281	delivery	5	22
82844	2020-06-21 22:47:55	2020-06-21	9	[{"id_menu":6,"count":1}]	32413	delivery	5	14
82845	2020-06-21 22:49:06	2020-06-21	17	[{"id_menu":4,"count":1}]	5416	delivery	5	22
82846	2020-06-21 22:49:13	2020-06-21	9	[{"id_menu":7,"count":3}]	32324	delivery	5	14
82847	2020-06-21 22:49:18	2020-06-21	12	[{"id_menu":1,"count":2}]	14252	pick-up	0	12
82848	2020-06-21 22:52:05	2020-06-21	9	[{"id_menu":6,"count":1}]	32317	delivery	5	14
82849	2020-06-21 22:56:38	2020-06-21	14	[{"id_menu":2,"count":1}]	552	pick-up	0	14
82850	2020-06-21 22:57:43	2020-06-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	29367	pick-up	0	23
82851	2020-06-21 22:59:22	2020-06-21	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	32321	delivery	5	26
82852	2020-06-21 23:00:43	2020-06-21	9	[{"id_menu":6,"count":1}]	2105	delivery	5	14
82853	2020-06-21 23:01:02	2020-06-21	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	12142	delivery	5	25
82854	2020-06-21 23:02:35	2020-06-21	9	[{"id_menu":6,"count":1}]	5802	pick-up	0	9
82855	2020-06-21 23:05:43	2020-06-21	9	[{"id_menu":6,"count":1}]	11740	delivery	5	14
82856	2020-06-21 23:05:54	2020-06-21	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	32244	delivery	5	34
82857	2020-06-21 23:07:15	2020-06-21	14	[{"id_menu":2,"count":1}]	22226	pick-up	0	14
82858	2020-06-21 23:07:41	2020-06-21	12	[{"id_menu":3,"count":1}]	23696	pick-up	0	12
82859	2020-06-21 23:09:25	2020-06-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16350	delivery	5	31
82860	2020-06-21 23:10:14	2020-06-21	9	[{"id_menu":7,"count":1}]	32080	delivery	5	14
82861	2020-06-21 23:10:31	2020-06-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	28158	pick-up	0	17
82862	2020-06-21 23:14:04	2020-06-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4202	pick-up	0	26
82863	2020-06-21 23:18:33	2020-06-21	8	[{"id_menu":5,"count":1}]	12182	delivery	5	13
82864	2020-06-21 23:21:14	2020-06-21	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32205	delivery	5	31
82865	2020-06-21 23:21:32	2020-06-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32372	delivery	5	23
82866	2020-06-21 23:21:47	2020-06-21	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	4470	pick-up	0	22
82867	2020-06-21 23:23:36	2020-06-21	12	[{"id_menu":1,"count":1}]	30685	delivery	5	17
82868	2020-06-21 23:24:13	2020-06-21	12	[{"id_menu":3,"count":1}]	20328	pick-up	0	12
82869	2020-06-21 23:24:48	2020-06-21	12	[{"id_menu":1,"count":1}]	2366	pick-up	0	12
82870	2020-06-21 23:26:13	2020-06-21	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":2}]	32362	delivery	5	22
82871	2020-06-21 23:27:38	2020-06-21	17	[{"id_menu":4,"count":1}]	19212	delivery	5	22
82872	2020-06-21 23:29:25	2020-06-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32225	delivery	5	22
82873	2020-06-21 23:31:55	2020-06-21	14	[{"id_menu":2,"count":1}]	32294	pick-up	0	14
82874	2020-06-21 23:32:09	2020-06-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29716	pick-up	0	17
82875	2020-06-21 23:33:05	2020-06-21	9	[{"id_menu":7,"count":1}]	24307	delivery	5	14
82876	2020-06-21 23:34:22	2020-06-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6192	delivery	5	28
82877	2020-06-21 23:37:13	2020-06-21	12	[{"id_menu":3,"count":1}]	13348	delivery	5	17
82878	2020-06-21 23:37:45	2020-06-21	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	30975	delivery	5	36
82879	2020-06-21 23:38:05	2020-06-21	17	[{"id_menu":4,"count":1}]	14681	delivery	5	22
82880	2020-06-21 23:50:54	2020-06-21	9	[{"id_menu":7,"count":1}]	19260	delivery	5	14
82881	2020-06-21 23:54:34	2020-06-21	9	[{"id_menu":6,"count":1}]	27802	delivery	5	14
82882	2020-06-21 23:57:34	2020-06-21	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	32370	delivery	5	27
82883	2020-06-21 23:59:33	2020-06-21	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	30818	delivery	5	25
82884	2020-06-21 23:59:46	2020-06-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	32406	delivery	5	22
82885	2020-06-21 23:59:51	2020-06-21	9	[{"id_menu":6,"count":1}]	29729	delivery	5	14
82886	2020-06-22 00:04:35	2020-06-22	9	[{"id_menu":7,"count":1}]	32460	delivery	5	14
82887	2020-06-22 00:07:06	2020-06-22	14	[{"id_menu":2,"count":1}]	17472	pick-up	0	14
82888	2020-06-22 00:08:28	2020-06-22	8	[{"id_menu":5,"count":1}]	228	delivery	5	13
82889	2020-06-22 00:11:52	2020-06-22	12	[{"id_menu":1,"count":1}]	32	pick-up	0	12
82890	2020-06-22 00:19:47	2020-06-22	9	[{"id_menu":6,"count":1}]	30885	delivery	5	14
82891	2020-06-22 00:23:35	2020-06-22	9	[{"id_menu":6,"count":1}]	14527	delivery	5	14
82892	2020-06-22 00:31:02	2020-06-22	12	[{"id_menu":1,"count":1}]	17582	pick-up	0	12
82893	2020-06-22 00:37:53	2020-06-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31161	delivery	5	23
82894	2020-06-22 00:40:35	2020-06-22	14	[{"id_menu":2,"count":1}]	14585	pick-up	0	14
82895	2020-06-22 00:41:21	2020-06-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32493	delivery	5	22
82896	2020-06-22 00:41:29	2020-06-22	14	[{"id_menu":2,"count":1}]	17003	delivery	5	19
82897	2020-06-22 00:53:42	2020-06-22	17	[{"id_menu":4,"count":1}]	30032	delivery	5	22
82898	2020-06-22 00:55:53	2020-06-22	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	30762	pick-up	0	29
82899	2020-06-22 01:10:34	2020-06-22	14	[{"id_menu":2,"count":1}]	19711	pick-up	0	14
82900	2020-06-22 01:11:13	2020-06-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	27538	pick-up	0	23
82901	2020-06-22 01:17:14	2020-06-22	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	16870	delivery	5	34
82902	2020-06-22 01:18:26	2020-06-22	14	[{"id_menu":2,"count":1}]	1306	pick-up	0	14
82903	2020-06-22 01:27:25	2020-06-22	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	32491	delivery	5	43
82904	2020-06-22 01:31:35	2020-06-22	12	[{"id_menu":3,"count":1}]	8057	delivery	5	17
82905	2020-06-22 01:37:47	2020-06-22	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4674	delivery	5	45
82906	2020-06-22 02:00:26	2020-06-22	8	[{"id_menu":5,"count":1}]	17503	delivery	5	13
82907	2020-06-22 02:00:42	2020-06-22	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3478	delivery	5	40
82908	2020-06-22 02:01:11	2020-06-22	12	[{"id_menu":3,"count":1}]	3320	pick-up	0	12
82909	2020-06-22 02:04:30	2020-06-22	12	[{"id_menu":3,"count":1}]	12264	delivery	5	17
82910	2020-06-22 02:17:17	2020-06-22	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	32464	delivery	5	44
82911	2020-06-22 02:18:17	2020-06-22	9	[{"id_menu":6,"count":1}]	11986	delivery	5	14
82912	2020-06-22 02:20:14	2020-06-22	9	[{"id_menu":6,"count":1}]	4761	delivery	5	14
82913	2020-06-22 02:20:20	2020-06-22	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4351	pick-up	0	29
82914	2020-06-22 02:23:52	2020-06-22	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	24215	delivery	5	43
82915	2020-06-22 02:25:36	2020-06-22	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27266	delivery	5	47
82916	2020-06-22 02:32:10	2020-06-22	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	32607	delivery	5	27
82917	2020-06-22 02:33:43	2020-06-22	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	8600	delivery	5	26
82918	2020-06-22 02:34:59	2020-06-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	32630	delivery	5	23
82919	2020-06-22 02:36:55	2020-06-22	17	[{"id_menu":4,"count":1}]	32450	pick-up	0	17
82920	2020-06-22 02:44:08	2020-06-22	12	[{"id_menu":3,"count":2}]	32486	delivery	5	17
82921	2020-06-22 02:45:42	2020-06-22	12	[{"id_menu":1,"count":1}]	2929	delivery	5	17
82922	2020-06-22 02:51:48	2020-06-22	9	[{"id_menu":6,"count":1}]	32595	delivery	5	14
82923	2020-06-22 02:55:33	2020-06-22	14	[{"id_menu":2,"count":1}]	19492	delivery	5	19
82924	2020-06-22 02:58:40	2020-06-22	17	[{"id_menu":4,"count":1}]	13627	delivery	5	22
82925	2020-06-22 03:02:09	2020-06-22	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	28803	delivery	5	45
82926	2020-06-22 03:06:59	2020-06-22	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	25654	delivery	5	26
82927	2020-06-22 03:10:48	2020-06-22	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	32552	delivery	5	23
82928	2020-06-22 03:16:26	2020-06-22	8	[{"id_menu":5,"count":1}]	32471	delivery	5	13
82929	2020-06-22 03:19:43	2020-06-22	9	[{"id_menu":7,"count":1}]	32628	delivery	5	14
82930	2020-06-22 03:23:04	2020-06-22	12	[{"id_menu":3,"count":1}]	25844	delivery	5	17
82931	2020-06-22 03:34:20	2020-06-22	14	[{"id_menu":2,"count":1}]	29746	delivery	5	19
82932	2020-06-22 03:34:53	2020-06-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	26588	delivery	5	22
82933	2020-06-22 03:36:20	2020-06-22	8	[{"id_menu":5,"count":1}]	6147	pick-up	0	8
82934	2020-06-22 03:44:46	2020-06-22	14	[{"id_menu":2,"count":1}]	32488	pick-up	0	14
82935	2020-06-22 03:55:58	2020-06-22	9	[{"id_menu":6,"count":1}]	32517	delivery	5	14
82936	2020-06-22 03:56:45	2020-06-22	9	[{"id_menu":6,"count":1}]	15184	delivery	5	14
82937	2020-06-22 04:03:13	2020-06-22	8	[{"id_menu":5,"count":1}]	32479	pick-up	0	8
82938	2020-06-22 04:06:16	2020-06-22	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	32531	delivery	5	34
82939	2020-06-22 04:06:25	2020-06-22	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	18490	pick-up	0	29
82940	2020-06-22 04:10:16	2020-06-22	8	[{"id_menu":5,"count":1}]	8822	delivery	5	13
82941	2020-06-22 04:14:09	2020-06-22	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	440	delivery	5	25
82942	2020-06-22 04:21:09	2020-06-22	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32501	delivery	5	37
82943	2020-06-22 04:28:42	2020-06-22	9	[{"id_menu":6,"count":1}]	8024	delivery	5	14
82944	2020-06-22 04:29:08	2020-06-22	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	31076	pick-up	0	40
82945	2020-06-22 04:38:42	2020-06-22	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32425	delivery	5	46
82946	2020-06-22 04:40:51	2020-06-22	12	[{"id_menu":1,"count":1}]	29231	pick-up	0	12
82947	2020-06-22 04:41:44	2020-06-22	9	[{"id_menu":6,"count":1}]	25686	delivery	5	14
82948	2020-06-22 04:44:02	2020-06-22	17	[{"id_menu":4,"count":1}]	23947	pick-up	0	17
82949	2020-06-22 04:46:52	2020-06-22	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	15686	pick-up	0	29
82950	2020-06-22 04:47:33	2020-06-22	17	[{"id_menu":4,"count":1}]	26657	delivery	5	22
82951	2020-06-22 04:48:41	2020-06-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32451	delivery	5	22
82952	2020-06-22 04:51:01	2020-06-22	9	[{"id_menu":7,"count":1}]	25513	delivery	5	14
82953	2020-06-22 04:54:56	2020-06-22	9	[{"id_menu":7,"count":1}]	28923	delivery	5	14
82954	2020-06-22 04:56:24	2020-06-22	9	[{"id_menu":6,"count":1}]	25658	delivery	5	14
82955	2020-06-22 05:02:18	2020-06-22	12	[{"id_menu":1,"count":1}]	32581	pick-up	0	12
82956	2020-06-22 05:09:37	2020-06-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	32537	pick-up	0	23
82957	2020-06-22 05:18:23	2020-06-22	9	[{"id_menu":7,"count":1}]	6838	delivery	5	14
82958	2020-06-22 05:19:28	2020-06-22	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6919	delivery	5	45
82959	2020-06-22 05:25:33	2020-06-22	17	[{"id_menu":4,"count":1}]	5292	pick-up	0	17
82960	2020-06-22 05:32:54	2020-06-22	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	4479	delivery	5	25
82961	2020-06-22 05:41:27	2020-06-22	17	[{"id_menu":4,"count":1}]	15450	delivery	5	22
82962	2020-06-22 05:41:35	2020-06-22	12	[{"id_menu":1,"count":1}]	8431	pick-up	0	12
82963	2020-06-22 05:46:21	2020-06-22	17	[{"id_menu":4,"count":1}]	21099	pick-up	0	17
82964	2020-06-22 05:49:19	2020-06-22	12	[{"id_menu":3,"count":1}]	302	pick-up	0	12
82965	2020-06-22 05:53:20	2020-06-22	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	19078	pick-up	0	22
82966	2020-06-22 05:54:42	2020-06-22	14	[{"id_menu":2,"count":1}]	32536	delivery	5	19
82967	2020-06-22 05:57:32	2020-06-22	17	[{"id_menu":4,"count":1}]	21999	pick-up	0	17
82968	2020-06-22 05:57:48	2020-06-22	12	[{"id_menu":3,"count":1}]	32541	delivery	5	17
82969	2020-06-22 05:58:02	2020-06-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	32449	delivery	5	28
82970	2020-06-22 05:59:07	2020-06-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	25856	delivery	5	36
82971	2020-06-22 06:04:48	2020-06-22	9	[{"id_menu":6,"count":1}]	31017	pick-up	0	9
82972	2020-06-22 06:06:36	2020-06-22	8	[{"id_menu":5,"count":1}]	32596	delivery	5	13
82973	2020-06-22 06:18:43	2020-06-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	13662	pick-up	0	31
82974	2020-06-22 06:19:26	2020-06-22	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	6524	delivery	5	26
82975	2020-06-22 06:20:05	2020-06-22	12	[{"id_menu":1,"count":1}]	21785	pick-up	0	12
82976	2020-06-22 06:21:08	2020-06-22	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	19733	delivery	5	22
82977	2020-06-22 06:23:20	2020-06-22	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	24386	delivery	5	36
82978	2020-06-22 06:25:07	2020-06-22	17	[{"id_menu":4,"count":2}]	32545	delivery	5	22
82979	2020-06-22 06:25:42	2020-06-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8718	delivery	5	22
82980	2020-06-22 06:28:35	2020-06-22	8	[{"id_menu":5,"count":1}]	32492	delivery	5	13
82981	2020-06-22 06:32:57	2020-06-22	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32481	delivery	5	52
82982	2020-06-22 06:36:13	2020-06-22	12	[{"id_menu":3,"count":1}]	27673	delivery	5	17
82983	2020-06-22 06:41:43	2020-06-22	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	20628	pick-up	0	29
82984	2020-06-22 06:46:05	2020-06-22	17	[{"id_menu":4,"count":3}]	16450	delivery	5	22
82985	2020-06-22 06:49:50	2020-06-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5584	delivery	5	23
82986	2020-06-22 06:51:38	2020-06-22	9	[{"id_menu":7,"count":1}]	29224	delivery	5	14
82987	2020-06-22 06:51:44	2020-06-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32508	delivery	5	23
82988	2020-06-22 06:52:53	2020-06-22	14	[{"id_menu":2,"count":2}]	28529	delivery	5	19
82989	2020-06-22 06:53:06	2020-06-22	9	[{"id_menu":6,"count":1}]	31107	delivery	5	14
82990	2020-06-22 06:53:44	2020-06-22	12	[{"id_menu":1,"count":1}]	18820	delivery	5	17
82991	2020-06-22 06:59:54	2020-06-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32554	delivery	5	23
82992	2020-06-22 07:00:34	2020-06-22	17	[{"id_menu":4,"count":1}]	32455	delivery	5	22
82993	2020-06-22 07:01:37	2020-06-22	12	[{"id_menu":1,"count":1}]	20216	pick-up	0	12
82994	2020-06-22 07:05:43	2020-06-22	14	[{"id_menu":2,"count":1}]	32507	delivery	5	19
82995	2020-06-22 07:09:29	2020-06-22	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	32594	delivery	5	26
82996	2020-06-22 07:30:45	2020-06-22	9	[{"id_menu":7,"count":1}]	798	pick-up	0	9
82997	2020-06-22 07:36:16	2020-06-22	9	[{"id_menu":6,"count":1}]	32603	delivery	5	14
82998	2020-06-22 07:37:02	2020-06-22	9	[{"id_menu":6,"count":1}]	15798	delivery	5	14
82999	2020-06-22 07:37:50	2020-06-22	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":2}]	23793	delivery	5	22
83000	2020-06-22 07:40:45	2020-06-22	8	[{"id_menu":5,"count":1}]	26428	delivery	5	13
83001	2020-06-22 07:41:33	2020-06-22	12	[{"id_menu":1,"count":1}]	30735	delivery	5	17
83002	2020-06-22 07:42:45	2020-06-22	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32477	delivery	5	37
83003	2020-06-22 07:50:21	2020-06-22	9	[{"id_menu":7,"count":1}]	2752	delivery	5	14
83004	2020-06-22 07:52:23	2020-06-22	12	[{"id_menu":1,"count":1}]	21288	delivery	5	17
83005	2020-06-22 08:00:21	2020-06-22	12	[{"id_menu":1,"count":1}]	15386	delivery	5	17
83006	2020-06-22 08:08:56	2020-06-22	8	[{"id_menu":5,"count":1}]	26648	delivery	5	13
83007	2020-06-22 08:13:38	2020-06-22	12	[{"id_menu":3,"count":1}]	26136	delivery	5	17
83008	2020-06-22 08:16:10	2020-06-22	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	3888	delivery	5	28
83009	2020-06-22 08:19:28	2020-06-22	14	[{"id_menu":2,"count":1}]	32437	delivery	5	19
83010	2020-06-22 08:20:47	2020-06-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	32445	delivery	5	28
83011	2020-06-22 08:23:17	2020-06-22	9	[{"id_menu":7,"count":1}]	31071	delivery	5	14
83012	2020-06-22 08:23:35	2020-06-22	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	32503	pick-up	0	17
83013	2020-06-22 08:28:12	2020-06-22	14	[{"id_menu":2,"count":2}]	2699	pick-up	0	14
83014	2020-06-22 08:29:12	2020-06-22	9	[{"id_menu":6,"count":1}]	18348	delivery	5	14
83015	2020-06-22 08:29:36	2020-06-22	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9833	delivery	5	36
83016	2020-06-22 08:29:58	2020-06-22	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1796	pick-up	0	17
83017	2020-06-22 08:31:02	2020-06-22	12	[{"id_menu":1,"count":1}]	4172	pick-up	0	12
83018	2020-06-22 08:43:59	2020-06-22	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	15028	delivery	5	40
83019	2020-06-22 08:45:19	2020-06-22	12	[{"id_menu":1,"count":1}]	16217	pick-up	0	12
83020	2020-06-22 08:46:19	2020-06-22	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	32577	delivery	5	45
83021	2020-06-22 08:53:36	2020-06-22	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	32436	delivery	5	39
83022	2020-06-22 08:54:10	2020-06-22	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	32533	delivery	5	31
83023	2020-06-22 08:54:44	2020-06-22	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19273	delivery	5	53
83024	2020-06-22 08:56:23	2020-06-22	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11789	delivery	5	31
83025	2020-06-22 08:58:08	2020-06-22	9	[{"id_menu":7,"count":1}]	32527	delivery	5	14
83026	2020-06-22 08:58:18	2020-06-22	9	[{"id_menu":6,"count":1}]	26430	pick-up	0	9
83027	2020-06-22 08:58:42	2020-06-22	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15812	delivery	5	34
83028	2020-06-22 08:59:35	2020-06-22	12	[{"id_menu":3,"count":1}]	32500	pick-up	0	12
83029	2020-06-22 09:05:41	2020-06-22	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	27452	delivery	5	25
83030	2020-06-22 09:07:06	2020-06-22	9	[{"id_menu":7,"count":1}]	32456	delivery	5	14
83031	2020-06-22 09:09:48	2020-06-22	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	20960	delivery	5	40
83032	2020-06-22 09:18:10	2020-06-22	9	[{"id_menu":7,"count":1}]	332	pick-up	0	9
83033	2020-06-22 09:20:55	2020-06-22	9	[{"id_menu":6,"count":1}]	32529	delivery	5	14
83034	2020-06-22 09:26:10	2020-06-22	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	27970	delivery	5	27
83035	2020-06-22 09:28:04	2020-06-22	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":3}]	32513	delivery	5	22
83036	2020-06-22 10:01:31	2020-06-22	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	32515	delivery	5	26
83037	2020-06-22 10:03:45	2020-06-22	12	[{"id_menu":3,"count":1}]	6421	delivery	5	17
83038	2020-06-22 10:05:48	2020-06-22	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	32505	delivery	5	31
83039	2020-06-22 10:16:45	2020-06-22	17	[{"id_menu":4,"count":1}]	11896	pick-up	0	17
83040	2020-06-22 10:24:51	2020-06-22	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	934	pick-up	0	38
83041	2020-06-22 10:24:59	2020-06-22	8	[{"id_menu":5,"count":1}]	20024	pick-up	0	8
83042	2020-06-22 10:26:38	2020-06-22	12	[{"id_menu":1,"count":1}]	29451	delivery	5	17
83043	2020-06-22 10:39:32	2020-06-22	17	[{"id_menu":4,"count":2}]	32429	delivery	5	22
83044	2020-06-22 10:49:14	2020-06-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	32542	pick-up	0	31
83045	2020-06-22 10:52:23	2020-06-22	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	32602	delivery	5	37
83046	2020-06-22 10:53:37	2020-06-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	12123	delivery	5	36
83047	2020-06-22 11:03:14	2020-06-22	9	[{"id_menu":6,"count":1}]	32431	delivery	5	14
83048	2020-06-22 11:08:32	2020-06-22	9	[{"id_menu":7,"count":1}]	32510	delivery	5	14
83049	2020-06-22 11:09:14	2020-06-22	9	[{"id_menu":7,"count":1}]	32592	delivery	5	14
83050	2020-06-22 11:09:18	2020-06-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	32534	delivery	5	28
83051	2020-06-22 11:11:48	2020-06-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1656	pick-up	0	23
83052	2020-06-22 11:22:35	2020-06-22	12	[{"id_menu":3,"count":1}]	32530	delivery	5	17
83053	2020-06-22 11:22:39	2020-06-22	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	32591	delivery	5	44
83054	2020-06-22 11:22:41	2020-06-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7098	pick-up	0	31
83055	2020-06-22 11:23:14	2020-06-22	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	24791	delivery	5	43
83056	2020-06-22 11:26:41	2020-06-22	14	[{"id_menu":2,"count":1}]	12578	pick-up	0	14
83057	2020-06-22 11:28:59	2020-06-22	8	[{"id_menu":5,"count":1}]	15915	delivery	5	13
83058	2020-06-22 11:39:18	2020-06-22	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	13600	delivery	5	26
83059	2020-06-22 11:45:49	2020-06-22	8	[{"id_menu":5,"count":1}]	1097	delivery	5	13
83060	2020-06-22 11:47:38	2020-06-22	12	[{"id_menu":3,"count":1}]	32612	delivery	5	17
83061	2020-06-22 12:08:18	2020-06-22	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	25834	delivery	5	31
83062	2020-06-22 12:12:04	2020-06-22	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	25291	delivery	5	22
83063	2020-06-22 12:15:06	2020-06-22	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1266	pick-up	0	43
83064	2020-06-22 12:25:06	2020-06-22	9	[{"id_menu":6,"count":1}]	13862	delivery	5	14
83065	2020-06-22 12:27:06	2020-06-22	9	[{"id_menu":6,"count":1}]	32485	delivery	5	14
83066	2020-06-22 12:33:27	2020-06-22	17	[{"id_menu":4,"count":1}]	32618	delivery	5	22
83067	2020-06-22 12:37:52	2020-06-22	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	32583	delivery	5	29
83068	2020-06-22 12:38:35	2020-06-22	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	30099	delivery	5	40
83069	2020-06-22 12:47:17	2020-06-22	9	[{"id_menu":7,"count":1}]	32433	delivery	5	14
83070	2020-06-22 12:48:21	2020-06-22	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	32470	delivery	5	45
83071	2020-06-22 12:54:22	2020-06-22	9	[{"id_menu":7,"count":1}]	32468	pick-up	0	9
83072	2020-06-22 12:55:20	2020-06-22	9	[{"id_menu":7,"count":1}]	23249	delivery	5	14
83073	2020-06-22 13:00:49	2020-06-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	13859	pick-up	0	31
83074	2020-06-22 13:00:50	2020-06-22	12	[{"id_menu":1,"count":1}]	5422	delivery	5	17
83075	2020-06-22 13:01:52	2020-06-22	14	[{"id_menu":2,"count":1}]	3961	pick-up	0	14
83076	2020-06-22 13:03:54	2020-06-22	14	[{"id_menu":2,"count":1}]	13767	pick-up	0	14
83077	2020-06-22 13:07:22	2020-06-22	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	27660	delivery	5	53
83078	2020-06-22 13:08:13	2020-06-22	14	[{"id_menu":2,"count":1}]	18076	delivery	5	19
83079	2020-06-22 13:14:35	2020-06-22	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	21671	delivery	5	36
83080	2020-06-22 13:17:04	2020-06-22	17	[{"id_menu":4,"count":1}]	6500	pick-up	0	17
83081	2020-06-22 13:19:44	2020-06-22	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2702	pick-up	0	22
83082	2020-06-22 13:20:49	2020-06-22	14	[{"id_menu":2,"count":1}]	32506	delivery	5	19
83083	2020-06-22 13:21:50	2020-06-22	12	[{"id_menu":3,"count":1}]	5204	delivery	5	17
83084	2020-06-22 13:25:28	2020-06-22	17	[{"id_menu":4,"count":1}]	32631	delivery	5	22
83085	2020-06-22 13:28:19	2020-06-22	14	[{"id_menu":2,"count":1}]	32524	delivery	5	19
83086	2020-06-22 13:32:04	2020-06-22	17	[{"id_menu":4,"count":1}]	32459	delivery	5	22
83087	2020-06-22 13:36:56	2020-06-22	17	[{"id_menu":4,"count":1}]	32442	pick-up	0	17
83088	2020-06-22 13:42:25	2020-06-22	9	[{"id_menu":7,"count":1}]	31157	delivery	5	14
83089	2020-06-22 13:45:35	2020-06-22	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	32424	delivery	5	22
83090	2020-06-22 13:55:34	2020-06-22	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	971	pick-up	0	17
83091	2020-06-22 13:55:53	2020-06-22	12	[{"id_menu":3,"count":1}]	32462	delivery	5	17
83092	2020-06-22 14:01:24	2020-06-22	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	23457	delivery	5	26
83093	2020-06-22 14:02:48	2020-06-22	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	30044	delivery	5	39
83094	2020-06-22 14:03:27	2020-06-22	14	[{"id_menu":2,"count":1}]	16246	pick-up	0	14
83095	2020-06-22 14:04:50	2020-06-22	14	[{"id_menu":2,"count":1}]	32543	delivery	5	19
83096	2020-06-22 14:06:23	2020-06-22	14	[{"id_menu":2,"count":2}]	32585	pick-up	0	14
83097	2020-06-22 14:13:10	2020-06-22	9	[{"id_menu":6,"count":1}]	25346	pick-up	0	9
83098	2020-06-22 14:13:11	2020-06-22	9	[{"id_menu":6,"count":1}]	18189	pick-up	0	9
83099	2020-06-22 14:13:32	2020-06-22	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	32480	pick-up	0	29
83100	2020-06-22 14:13:40	2020-06-22	17	[{"id_menu":4,"count":1}]	11801	pick-up	0	17
83101	2020-06-22 14:16:51	2020-06-22	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	12882	delivery	5	31
83102	2020-06-22 14:18:31	2020-06-22	12	[{"id_menu":3,"count":1}]	10580	pick-up	0	12
83103	2020-06-22 14:19:48	2020-06-22	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3952	delivery	5	40
83104	2020-06-22 14:21:38	2020-06-22	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	24496	delivery	5	30
83105	2020-06-22 14:24:21	2020-06-22	8	[{"id_menu":5,"count":1}]	12187	delivery	5	13
83106	2020-06-22 14:39:53	2020-06-22	9	[{"id_menu":6,"count":1}]	10417	delivery	5	14
83107	2020-06-22 14:40:20	2020-06-22	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	32523	delivery	5	48
83108	2020-06-22 14:42:01	2020-06-22	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	24190	delivery	5	39
83109	2020-06-22 14:45:32	2020-06-22	9	[{"id_menu":7,"count":1}]	9813	pick-up	0	9
83110	2020-06-22 14:48:03	2020-06-22	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	15899	delivery	5	31
83111	2020-06-22 14:48:53	2020-06-22	17	[{"id_menu":4,"count":1}]	32476	delivery	5	22
83112	2020-06-22 14:49:21	2020-06-22	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	16357	delivery	5	26
83113	2020-06-22 14:49:31	2020-06-22	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	27183	delivery	5	26
83114	2020-06-22 14:51:07	2020-06-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	26292	delivery	5	28
83115	2020-06-22 14:53:51	2020-06-22	9	[{"id_menu":7,"count":2}]	841	pick-up	0	9
83116	2020-06-22 14:58:39	2020-06-22	12	[{"id_menu":3,"count":1}]	31015	delivery	5	17
83117	2020-06-22 14:59:45	2020-06-22	12	[{"id_menu":3,"count":1}]	13496	delivery	5	17
83118	2020-06-22 15:03:03	2020-06-22	12	[{"id_menu":1,"count":1}]	575	pick-up	0	12
83119	2020-06-22 15:04:35	2020-06-22	17	[{"id_menu":4,"count":1}]	26930	delivery	5	22
83120	2020-06-22 15:06:31	2020-06-22	9	[{"id_menu":7,"count":1}]	4454	delivery	5	14
83121	2020-06-22 15:09:16	2020-06-22	14	[{"id_menu":2,"count":3}]	32553	delivery	5	19
83122	2020-06-22 15:13:42	2020-06-22	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22053	pick-up	0	30
83123	2020-06-22 15:17:28	2020-06-22	8	[{"id_menu":5,"count":1}]	11868	delivery	5	13
83124	2020-06-22 15:25:58	2020-06-22	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5971	delivery	5	43
83125	2020-06-22 15:28:11	2020-06-22	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	32551	delivery	5	27
83126	2020-06-22 15:30:00	2020-06-22	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	7540	delivery	5	37
83127	2020-06-22 15:30:39	2020-06-22	9	[{"id_menu":7,"count":1}]	21606	pick-up	0	9
83128	2020-06-22 15:41:01	2020-06-22	9	[{"id_menu":7,"count":1}]	13503	delivery	5	14
83129	2020-06-22 15:41:17	2020-06-22	9	[{"id_menu":7,"count":1}]	32605	delivery	5	14
83130	2020-06-22 15:42:11	2020-06-22	12	[{"id_menu":3,"count":1}]	3659	pick-up	0	12
83131	2020-06-22 15:46:28	2020-06-22	9	[{"id_menu":7,"count":1}]	23705	delivery	5	14
83132	2020-06-22 15:47:47	2020-06-22	14	[{"id_menu":2,"count":1}]	3778	delivery	5	19
83133	2020-06-22 15:51:16	2020-06-22	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	21736	delivery	5	35
83134	2020-06-22 16:02:27	2020-06-22	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	5360	delivery	5	26
83135	2020-06-22 16:03:48	2020-06-22	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	32624	delivery	5	30
83136	2020-06-22 16:04:24	2020-06-22	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	32626	delivery	5	26
83137	2020-06-22 16:04:29	2020-06-22	14	[{"id_menu":2,"count":1}]	13328	delivery	5	19
83138	2020-06-22 16:06:23	2020-06-22	9	[{"id_menu":6,"count":1}]	27368	delivery	5	14
83139	2020-06-22 16:06:26	2020-06-22	9	[{"id_menu":6,"count":1}]	16328	delivery	5	14
83140	2020-06-22 16:08:09	2020-06-22	12	[{"id_menu":1,"count":1}]	12838	delivery	5	17
83141	2020-06-22 16:09:09	2020-06-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9350	delivery	5	22
83142	2020-06-22 16:13:09	2020-06-22	9	[{"id_menu":7,"count":1}]	28208	delivery	5	14
83143	2020-06-22 16:13:55	2020-06-22	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":3}]	21894	delivery	5	34
83144	2020-06-22 16:14:57	2020-06-22	9	[{"id_menu":6,"count":1}]	2806	delivery	5	14
83145	2020-06-22 16:16:03	2020-06-22	9	[{"id_menu":7,"count":1}]	32489	delivery	5	14
83146	2020-06-22 16:20:46	2020-06-22	12	[{"id_menu":1,"count":1}]	8764	delivery	5	17
83147	2020-06-22 16:23:20	2020-06-22	9	[{"id_menu":6,"count":1}]	32590	delivery	5	14
83148	2020-06-22 16:23:48	2020-06-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6510	delivery	5	23
83149	2020-06-22 16:23:59	2020-06-22	12	[{"id_menu":1,"count":1}]	12472	pick-up	0	12
83150	2020-06-22 16:27:15	2020-06-22	32	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	32570	delivery	5	37
83151	2020-06-22 16:27:55	2020-06-22	9	[{"id_menu":7,"count":1}]	9749	pick-up	0	9
83152	2020-06-22 16:29:35	2020-06-22	9	[{"id_menu":7,"count":1}]	23148	delivery	5	14
83153	2020-06-22 16:35:46	2020-06-22	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	32482	delivery	5	26
83154	2020-06-22 16:36:13	2020-06-22	9	[{"id_menu":6,"count":1}]	11192	delivery	5	14
83155	2020-06-22 16:39:52	2020-06-22	12	[{"id_menu":3,"count":1}]	5098	delivery	5	17
83156	2020-06-22 16:40:41	2020-06-22	12	[{"id_menu":1,"count":1}]	12367	pick-up	0	12
83157	2020-06-22 16:55:23	2020-06-22	9	[{"id_menu":6,"count":1}]	32496	delivery	5	14
83158	2020-06-22 16:57:59	2020-06-22	8	[{"id_menu":5,"count":1}]	11156	delivery	5	13
83159	2020-06-22 17:04:25	2020-06-22	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16793	delivery	5	57
83160	2020-06-22 17:07:20	2020-06-22	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	32567	delivery	5	26
83161	2020-06-22 17:07:32	2020-06-22	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	24202	delivery	5	26
83162	2020-06-22 17:11:25	2020-06-22	9	[{"id_menu":7,"count":1}]	8380	delivery	5	14
83163	2020-06-22 17:11:26	2020-06-22	9	[{"id_menu":7,"count":1}]	10612	delivery	5	14
83164	2020-06-22 17:14:43	2020-06-22	14	[{"id_menu":2,"count":1}]	6851	pick-up	0	14
83165	2020-06-22 17:15:20	2020-06-22	9	[{"id_menu":6,"count":1}]	32546	delivery	5	14
83166	2020-06-22 17:21:59	2020-06-22	8	[{"id_menu":5,"count":1}]	32597	delivery	5	13
83167	2020-06-22 17:29:43	2020-06-22	9	[{"id_menu":7,"count":1}]	340	delivery	5	14
83168	2020-06-22 17:31:47	2020-06-22	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31575	delivery	5	52
83169	2020-06-22 17:32:01	2020-06-22	12	[{"id_menu":3,"count":1}]	5332	pick-up	0	12
83170	2020-06-22 17:33:09	2020-06-22	9	[{"id_menu":7,"count":1}]	32473	delivery	5	14
83171	2020-06-22 17:40:49	2020-06-22	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	12218	delivery	5	26
83172	2020-06-22 17:43:13	2020-06-22	12	[{"id_menu":3,"count":1}]	22624	delivery	5	17
83173	2020-06-22 17:48:00	2020-06-22	12	[{"id_menu":3,"count":1}]	12503	delivery	5	17
83174	2020-06-22 17:48:13	2020-06-22	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	32458	pick-up	0	21
83175	2020-06-22 17:49:38	2020-06-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32514	delivery	5	23
83176	2020-06-22 17:49:46	2020-06-22	12	[{"id_menu":1,"count":1}]	16803	delivery	5	17
83177	2020-06-22 17:50:02	2020-06-22	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	20108	delivery	5	31
83178	2020-06-22 17:52:40	2020-06-22	17	[{"id_menu":4,"count":1}]	20970	pick-up	0	17
83179	2020-06-22 17:59:34	2020-06-22	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	21877	pick-up	0	26
83180	2020-06-22 18:00:09	2020-06-22	12	[{"id_menu":1,"count":1}]	32133	pick-up	0	12
83181	2020-06-22 18:00:10	2020-06-22	9	[{"id_menu":7,"count":1}]	7138	delivery	5	14
83182	2020-06-22 18:05:25	2020-06-22	9	[{"id_menu":7,"count":1}]	16898	delivery	5	14
83183	2020-06-22 18:12:06	2020-06-22	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	32621	delivery	5	23
83184	2020-06-22 18:16:21	2020-06-22	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	32557	delivery	5	26
83185	2020-06-22 18:18:15	2020-06-22	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	32600	delivery	5	43
83186	2020-06-22 18:19:56	2020-06-22	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	32478	delivery	5	27
83187	2020-06-22 18:21:09	2020-06-22	17	[{"id_menu":4,"count":1}]	32463	delivery	5	22
83188	2020-06-22 18:21:56	2020-06-22	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	32601	delivery	5	34
83189	2020-06-22 18:27:37	2020-06-22	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	11296	delivery	5	34
83190	2020-06-22 18:28:15	2020-06-22	9	[{"id_menu":7,"count":1}]	3335	pick-up	0	9
83191	2020-06-22 18:32:21	2020-06-22	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1233	pick-up	0	26
83192	2020-06-22 18:35:19	2020-06-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	23488	pick-up	0	23
83193	2020-06-22 18:37:40	2020-06-22	17	[{"id_menu":4,"count":1}]	2250	delivery	5	22
83194	2020-06-22 18:39:00	2020-06-22	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	24192	pick-up	0	26
83195	2020-06-22 18:41:25	2020-06-22	12	[{"id_menu":1,"count":1}]	11444	delivery	5	17
83196	2020-06-22 18:46:02	2020-06-22	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	29078	delivery	5	34
83197	2020-06-22 18:46:53	2020-06-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	30137	delivery	5	22
83198	2020-06-22 19:07:31	2020-06-22	17	[{"id_menu":4,"count":1}]	32438	delivery	5	22
83199	2020-06-22 19:10:40	2020-06-22	12	[{"id_menu":1,"count":1}]	32558	delivery	5	17
83200	2020-06-22 19:11:29	2020-06-22	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32434	delivery	5	51
83201	2020-06-22 19:23:34	2020-06-22	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	12387	pick-up	0	25
83202	2020-06-22 19:26:40	2020-06-22	8	[{"id_menu":5,"count":1}]	23025	delivery	5	13
83203	2020-06-22 19:27:15	2020-06-22	12	[{"id_menu":3,"count":1}]	3536	delivery	5	17
83204	2020-06-22 19:29:40	2020-06-22	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	5025	delivery	5	26
83205	2020-06-22 19:33:30	2020-06-22	12	[{"id_menu":3,"count":1}]	26680	delivery	5	17
83206	2020-06-22 19:33:38	2020-06-22	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	10292	delivery	5	34
83207	2020-06-22 19:35:26	2020-06-22	9	[{"id_menu":7,"count":1}]	6824	delivery	5	14
83208	2020-06-22 19:40:51	2020-06-22	9	[{"id_menu":6,"count":1}]	32511	delivery	5	14
83209	2020-06-22 19:42:56	2020-06-22	12	[{"id_menu":1,"count":1}]	285	pick-up	0	12
83210	2020-06-22 19:45:35	2020-06-22	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6604	delivery	5	40
83211	2020-06-22 19:46:22	2020-06-22	12	[{"id_menu":1,"count":1}]	32423	delivery	5	17
83212	2020-06-22 19:46:22	2020-06-22	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	23014	delivery	5	23
83213	2020-06-22 19:49:02	2020-06-22	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	29154	delivery	5	31
83214	2020-06-22 20:23:16	2020-06-22	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5141	pick-up	0	38
83215	2020-06-22 20:31:20	2020-06-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	24950	pick-up	0	23
83216	2020-06-22 20:37:32	2020-06-22	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	22167	delivery	5	38
83217	2020-06-22 20:38:14	2020-06-22	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	5526	pick-up	0	26
83218	2020-06-22 20:38:33	2020-06-22	12	[{"id_menu":1,"count":1}]	3091	delivery	5	17
83219	2020-06-22 20:41:51	2020-06-22	12	[{"id_menu":3,"count":2}]	32632	delivery	5	17
83220	2020-06-22 20:43:36	2020-06-22	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	30945	delivery	5	39
83221	2020-06-22 20:43:53	2020-06-22	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1917	pick-up	0	20
83222	2020-06-22 20:44:29	2020-06-22	17	[{"id_menu":4,"count":1}]	32502	delivery	5	22
83223	2020-06-22 20:48:11	2020-06-22	9	[{"id_menu":6,"count":1}]	9902	delivery	5	14
83224	2020-06-22 21:01:58	2020-06-22	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	26724	pick-up	0	29
83225	2020-06-22 21:05:48	2020-06-22	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	20017	delivery	5	44
83226	2020-06-22 21:13:26	2020-06-22	9	[{"id_menu":6,"count":1}]	13866	delivery	5	14
83227	2020-06-22 21:17:48	2020-06-22	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	6361	delivery	5	28
83228	2020-06-22 21:20:49	2020-06-22	9	[{"id_menu":6,"count":1}]	4822	delivery	5	14
83229	2020-06-22 21:30:56	2020-06-22	12	[{"id_menu":1,"count":1}]	32467	delivery	5	17
83230	2020-06-22 21:37:06	2020-06-22	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	15155	delivery	5	28
83231	2020-06-22 21:38:45	2020-06-22	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16569	delivery	5	34
83232	2020-06-22 21:42:16	2020-06-22	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25003	delivery	5	35
83233	2020-06-22 21:49:44	2020-06-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1263	pick-up	0	18
83234	2020-06-22 21:53:17	2020-06-22	9	[{"id_menu":6,"count":1}]	32604	delivery	5	14
83235	2020-06-22 21:53:53	2020-06-22	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	21717	delivery	5	34
83236	2020-06-22 21:56:02	2020-06-22	8	[{"id_menu":5,"count":1}]	9296	delivery	5	13
83237	2020-06-22 21:57:44	2020-06-22	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	32598	delivery	5	26
83238	2020-06-22 21:59:20	2020-06-22	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	32428	delivery	5	43
83239	2020-06-22 22:05:26	2020-06-22	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32613	delivery	5	35
83240	2020-06-22 22:08:12	2020-06-22	14	[{"id_menu":2,"count":1}]	15189	delivery	5	19
83241	2020-06-22 22:09:41	2020-06-22	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	32579	delivery	5	40
83242	2020-06-22 22:10:26	2020-06-22	9	[{"id_menu":7,"count":1}]	5630	delivery	5	14
83243	2020-06-22 22:15:10	2020-06-22	12	[{"id_menu":1,"count":1}]	32548	delivery	5	17
83244	2020-06-22 22:20:25	2020-06-22	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	30911	delivery	5	37
83245	2020-06-22 22:22:30	2020-06-22	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	16692	delivery	5	34
83246	2020-06-22 22:25:16	2020-06-22	9	[{"id_menu":7,"count":1}]	9426	delivery	5	14
83247	2020-06-22 22:36:32	2020-06-22	9	[{"id_menu":7,"count":1}]	3968	delivery	5	14
83248	2020-06-22 22:39:25	2020-06-22	12	[{"id_menu":1,"count":1}]	4971	delivery	5	17
83249	2020-06-22 22:41:24	2020-06-22	9	[{"id_menu":6,"count":1}]	21541	delivery	5	14
83250	2020-06-22 22:44:15	2020-06-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32580	delivery	5	23
83251	2020-06-22 22:51:25	2020-06-22	8	[{"id_menu":5,"count":1}]	17691	pick-up	0	8
83252	2020-06-22 22:55:36	2020-06-22	8	[{"id_menu":5,"count":1}]	9904	delivery	5	13
83253	2020-06-22 22:56:05	2020-06-22	14	[{"id_menu":2,"count":1}]	32606	delivery	5	19
83254	2020-06-22 23:02:34	2020-06-22	17	[{"id_menu":4,"count":1}]	19300	delivery	5	22
83255	2020-06-22 23:09:07	2020-06-22	17	[{"id_menu":4,"count":2}]	5975	delivery	5	22
83256	2020-06-22 23:13:46	2020-06-22	12	[{"id_menu":3,"count":1}]	1918	pick-up	0	12
83257	2020-06-22 23:14:47	2020-06-22	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	32490	delivery	5	34
83258	2020-06-22 23:15:36	2020-06-22	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	32453	delivery	5	26
83259	2020-06-22 23:25:20	2020-06-22	9	[{"id_menu":7,"count":1}]	32575	delivery	5	14
83260	2020-06-22 23:31:52	2020-06-22	14	[{"id_menu":2,"count":1}]	2753	delivery	5	19
83261	2020-06-22 23:32:51	2020-06-22	12	[{"id_menu":3,"count":1}]	6206	delivery	5	17
83262	2020-06-22 23:33:07	2020-06-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	32426	delivery	5	28
83263	2020-06-22 23:35:04	2020-06-22	9	[{"id_menu":7,"count":1}]	30118	delivery	5	14
83264	2020-06-22 23:37:31	2020-06-22	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32512	delivery	5	48
83265	2020-06-22 23:39:52	2020-06-22	12	[{"id_menu":1,"count":1}]	338	pick-up	0	12
83266	2020-06-22 23:56:34	2020-06-22	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1369	pick-up	0	20
83267	2020-06-22 23:57:49	2020-06-22	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	28183	delivery	5	57
83268	2020-06-22 23:59:08	2020-06-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20890	delivery	5	22
83269	2020-06-23 00:00:04	2020-06-23	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	8494	delivery	5	27
83270	2020-06-23 00:03:00	2020-06-23	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8357	delivery	5	31
83271	2020-06-23 00:06:56	2020-06-23	17	[{"id_menu":4,"count":1}]	24310	pick-up	0	17
83272	2020-06-23 00:09:14	2020-06-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	32690	pick-up	0	26
83273	2020-06-23 00:10:38	2020-06-23	9	[{"id_menu":7,"count":1}]	8632	pick-up	0	9
83274	2020-06-23 00:14:41	2020-06-23	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	32748	delivery	5	34
83275	2020-06-23 00:19:56	2020-06-23	9	[{"id_menu":6,"count":1}]	20179	delivery	5	14
83276	2020-06-23 00:28:23	2020-06-23	12	[{"id_menu":1,"count":1}]	32692	delivery	5	17
83277	2020-06-23 00:32:52	2020-06-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	32667	delivery	5	28
83278	2020-06-23 00:37:19	2020-06-23	9	[{"id_menu":7,"count":1}]	28521	delivery	5	14
83279	2020-06-23 00:39:05	2020-06-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4768	delivery	5	23
83280	2020-06-23 00:39:19	2020-06-23	12	[{"id_menu":3,"count":1}]	32732	delivery	5	17
83281	2020-06-23 00:43:31	2020-06-23	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	32779	delivery	5	40
83282	2020-06-23 00:44:49	2020-06-23	12	[{"id_menu":3,"count":2}]	4192	delivery	5	17
83283	2020-06-23 00:45:02	2020-06-23	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	13537	pick-up	0	20
83284	2020-06-23 00:46:41	2020-06-23	14	[{"id_menu":2,"count":2}]	14710	pick-up	0	14
83285	2020-06-23 00:47:22	2020-06-23	14	[{"id_menu":2,"count":1}]	27199	delivery	5	19
83286	2020-06-23 00:59:02	2020-06-23	9	[{"id_menu":7,"count":1}]	5570	delivery	5	14
83287	2020-06-23 01:01:36	2020-06-23	9	[{"id_menu":7,"count":1}]	28896	delivery	5	14
83288	2020-06-23 01:13:58	2020-06-23	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	32799	delivery	5	39
83289	2020-06-23 01:18:37	2020-06-23	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12847	delivery	5	53
83290	2020-06-23 01:24:10	2020-06-23	12	[{"id_menu":3,"count":1}]	32655	delivery	5	17
83291	2020-06-23 01:24:11	2020-06-23	9	[{"id_menu":7,"count":1}]	32762	delivery	5	14
83292	2020-06-23 01:24:23	2020-06-23	9	[{"id_menu":7,"count":1}]	20910	delivery	5	14
83293	2020-06-23 01:27:31	2020-06-23	9	[{"id_menu":7,"count":1}]	18085	delivery	5	14
83294	2020-06-23 01:31:59	2020-06-23	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	27657	delivery	5	36
83295	2020-06-23 01:35:17	2020-06-23	12	[{"id_menu":3,"count":1}]	32783	delivery	5	17
83296	2020-06-23 01:36:23	2020-06-23	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	32744	delivery	5	25
83297	2020-06-23 01:41:43	2020-06-23	12	[{"id_menu":1,"count":1}]	32715	delivery	5	17
83298	2020-06-23 01:47:03	2020-06-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":3}]	18759	delivery	5	31
83299	2020-06-23 01:47:58	2020-06-23	12	[{"id_menu":3,"count":1}]	7297	pick-up	0	12
83300	2020-06-23 01:52:09	2020-06-23	8	[{"id_menu":5,"count":1}]	31945	delivery	5	13
83301	2020-06-23 01:54:46	2020-06-23	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	32735	pick-up	0	35
83302	2020-06-23 02:01:40	2020-06-23	9	[{"id_menu":6,"count":1}]	3614	pick-up	0	9
83303	2020-06-23 02:01:42	2020-06-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8958	delivery	5	23
83304	2020-06-23 02:01:47	2020-06-23	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	32658	delivery	5	45
83305	2020-06-23 02:04:56	2020-06-23	12	[{"id_menu":3,"count":1}]	17551	delivery	5	17
83306	2020-06-23 02:06:19	2020-06-23	9	[{"id_menu":6,"count":1}]	26874	delivery	5	14
83307	2020-06-23 02:09:49	2020-06-23	9	[{"id_menu":7,"count":1}]	17995	pick-up	0	9
83308	2020-06-23 02:12:30	2020-06-23	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	19957	pick-up	0	20
83309	2020-06-23 02:14:22	2020-06-23	8	[{"id_menu":5,"count":1}]	32750	delivery	5	13
83310	2020-06-23 02:16:20	2020-06-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	14768	delivery	5	22
83311	2020-06-23 02:16:21	2020-06-23	17	[{"id_menu":5,"count":3},{"id_menu":6,"count":1}]	22507	delivery	5	22
83312	2020-06-23 02:19:40	2020-06-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17777	pick-up	0	26
83313	2020-06-23 02:21:30	2020-06-23	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	27299	pick-up	0	29
83314	2020-06-23 02:22:36	2020-06-23	14	[{"id_menu":2,"count":1}]	32810	pick-up	0	14
83315	2020-06-23 02:24:48	2020-06-23	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	32125	delivery	5	26
83316	2020-06-23 02:26:13	2020-06-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	11380	pick-up	0	21
83317	2020-06-23 02:27:19	2020-06-23	12	[{"id_menu":3,"count":1}]	32796	pick-up	0	12
83318	2020-06-23 02:29:24	2020-06-23	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	20391	delivery	5	26
83319	2020-06-23 02:31:37	2020-06-23	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7078	delivery	5	34
83320	2020-06-23 02:33:14	2020-06-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	32756	delivery	5	23
83321	2020-06-23 02:34:35	2020-06-23	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	4995	pick-up	0	21
83322	2020-06-23 02:38:12	2020-06-23	17	[{"id_menu":4,"count":1}]	11189	delivery	5	22
83323	2020-06-23 02:48:29	2020-06-23	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	16534	delivery	5	25
83324	2020-06-23 02:49:33	2020-06-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22863	delivery	5	23
83325	2020-06-23 02:58:25	2020-06-23	9	[{"id_menu":6,"count":2}]	32033	delivery	5	14
83326	2020-06-23 02:59:01	2020-06-23	9	[{"id_menu":7,"count":1}]	30634	pick-up	0	9
83327	2020-06-23 03:10:26	2020-06-23	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32668	delivery	5	34
83328	2020-06-23 03:10:30	2020-06-23	9	[{"id_menu":7,"count":1}]	11006	delivery	5	14
83329	2020-06-23 03:13:30	2020-06-23	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32743	delivery	5	36
83330	2020-06-23 03:15:49	2020-06-23	12	[{"id_menu":3,"count":1}]	5179	delivery	5	17
83331	2020-06-23 03:26:46	2020-06-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	13185	delivery	5	28
83332	2020-06-23 03:38:18	2020-06-23	14	[{"id_menu":2,"count":1}]	18965	pick-up	0	14
83333	2020-06-23 03:39:22	2020-06-23	14	[{"id_menu":2,"count":1}]	7530	delivery	5	19
83334	2020-06-23 03:41:01	2020-06-23	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	32805	delivery	5	25
83335	2020-06-23 03:41:39	2020-06-23	8	[{"id_menu":5,"count":1}]	32419	delivery	5	13
83336	2020-06-23 03:49:37	2020-06-23	8	[{"id_menu":5,"count":1}]	23863	delivery	5	13
83337	2020-06-23 03:52:51	2020-06-23	8	[{"id_menu":5,"count":1}]	28662	delivery	5	13
83338	2020-06-23 04:01:22	2020-06-23	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	32737	delivery	5	34
83339	2020-06-23 04:02:16	2020-06-23	14	[{"id_menu":2,"count":1}]	29193	delivery	5	19
83340	2020-06-23 04:07:35	2020-06-23	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	32792	delivery	5	43
83341	2020-06-23 04:08:45	2020-06-23	12	[{"id_menu":1,"count":1}]	9101	delivery	5	17
83342	2020-06-23 04:09:42	2020-06-23	17	[{"id_menu":4,"count":1}]	16850	delivery	5	22
83343	2020-06-23 04:10:36	2020-06-23	9	[{"id_menu":7,"count":1}]	26776	delivery	5	14
83344	2020-06-23 04:11:23	2020-06-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	29958	delivery	5	26
83345	2020-06-23 04:11:38	2020-06-23	17	[{"id_menu":4,"count":1}]	8595	delivery	5	22
83346	2020-06-23 04:17:56	2020-06-23	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	32641	delivery	5	34
83347	2020-06-23 04:21:15	2020-06-23	14	[{"id_menu":2,"count":1}]	23920	delivery	5	19
83348	2020-06-23 04:21:37	2020-06-23	12	[{"id_menu":1,"count":1}]	23214	delivery	5	17
83349	2020-06-23 04:24:52	2020-06-23	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	14566	delivery	5	27
83350	2020-06-23 04:26:56	2020-06-23	9	[{"id_menu":7,"count":1}]	32197	delivery	5	14
83351	2020-06-23 04:27:34	2020-06-23	12	[{"id_menu":3,"count":1}]	13155	delivery	5	17
83352	2020-06-23 04:27:40	2020-06-23	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	32765	delivery	5	31
83353	2020-06-23 04:29:30	2020-06-23	12	[{"id_menu":1,"count":1}]	18309	pick-up	0	12
83354	2020-06-23 04:38:02	2020-06-23	14	[{"id_menu":2,"count":1}]	25001	delivery	5	19
83355	2020-06-23 04:42:35	2020-06-23	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6301	pick-up	0	29
83356	2020-06-23 04:43:05	2020-06-23	9	[{"id_menu":6,"count":1}]	25526	delivery	5	14
83357	2020-06-23 04:43:16	2020-06-23	9	[{"id_menu":6,"count":1}]	2158	pick-up	0	9
83358	2020-06-23 04:43:56	2020-06-23	8	[{"id_menu":5,"count":2}]	20386	pick-up	0	8
83359	2020-06-23 04:50:13	2020-06-23	12	[{"id_menu":3,"count":1}]	2222	pick-up	0	12
83360	2020-06-23 04:54:46	2020-06-23	8	[{"id_menu":5,"count":1}]	1680	delivery	5	13
83361	2020-06-23 04:57:19	2020-06-23	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	602	delivery	5	34
83362	2020-06-23 05:03:14	2020-06-23	14	[{"id_menu":2,"count":1}]	22643	delivery	5	19
83363	2020-06-23 05:05:20	2020-06-23	9	[{"id_menu":6,"count":1}]	20773	delivery	5	14
83364	2020-06-23 05:06:26	2020-06-23	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	32664	delivery	5	40
83365	2020-06-23 05:39:24	2020-06-23	17	[{"id_menu":4,"count":1}]	20669	delivery	5	22
83366	2020-06-23 05:40:33	2020-06-23	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13994	delivery	5	53
83367	2020-06-23 05:42:48	2020-06-23	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	11284	delivery	5	26
83368	2020-06-23 05:49:02	2020-06-23	9	[{"id_menu":7,"count":1}]	23856	delivery	5	14
83369	2020-06-23 05:50:59	2020-06-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21950	delivery	5	22
83370	2020-06-23 05:55:47	2020-06-23	9	[{"id_menu":6,"count":1}]	7669	delivery	5	14
83371	2020-06-23 05:56:01	2020-06-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	32758	delivery	5	28
83372	2020-06-23 05:57:41	2020-06-23	9	[{"id_menu":7,"count":1}]	29001	pick-up	0	9
83373	2020-06-23 06:01:59	2020-06-23	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	19752	pick-up	0	29
83374	2020-06-23 06:17:30	2020-06-23	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	32807	delivery	5	43
83375	2020-06-23 06:20:59	2020-06-23	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	11601	pick-up	0	26
83376	2020-06-23 06:21:34	2020-06-23	8	[{"id_menu":5,"count":1}]	32721	delivery	5	13
83377	2020-06-23 06:26:22	2020-06-23	9	[{"id_menu":7,"count":1}]	32653	delivery	5	14
83378	2020-06-23 06:27:01	2020-06-23	17	[{"id_menu":4,"count":1}]	12315	delivery	5	22
83379	2020-06-23 06:33:40	2020-06-23	8	[{"id_menu":5,"count":1}]	32663	delivery	5	13
83380	2020-06-23 06:35:43	2020-06-23	9	[{"id_menu":6,"count":2}]	32629	delivery	5	14
83381	2020-06-23 06:38:33	2020-06-23	17	[{"id_menu":4,"count":1}]	31766	delivery	5	22
83382	2020-06-23 06:40:48	2020-06-23	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5232	pick-up	0	26
83383	2020-06-23 06:43:44	2020-06-23	9	[{"id_menu":7,"count":1}]	1247	delivery	5	14
83384	2020-06-23 06:51:54	2020-06-23	12	[{"id_menu":1,"count":1}]	20451	delivery	5	17
83385	2020-06-23 06:54:33	2020-06-23	9	[{"id_menu":7,"count":1}]	27052	delivery	5	14
83386	2020-06-23 06:54:36	2020-06-23	9	[{"id_menu":6,"count":1}]	20335	delivery	5	14
83387	2020-06-23 06:55:07	2020-06-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	32798	delivery	5	26
83388	2020-06-23 06:55:41	2020-06-23	9	[{"id_menu":6,"count":2}]	9373	delivery	5	14
83389	2020-06-23 07:00:09	2020-06-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8874	delivery	5	28
83390	2020-06-23 07:06:52	2020-06-23	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	28718	delivery	5	45
83391	2020-06-23 07:08:14	2020-06-23	9	[{"id_menu":6,"count":1}]	6276	delivery	5	14
83392	2020-06-23 07:10:32	2020-06-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	19278	delivery	5	22
83393	2020-06-23 07:13:53	2020-06-23	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	32776	delivery	5	40
83394	2020-06-23 07:21:09	2020-06-23	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1833	delivery	5	27
83395	2020-06-23 07:21:15	2020-06-23	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	28880	delivery	5	29
83396	2020-06-23 07:21:40	2020-06-23	8	[{"id_menu":5,"count":1}]	1618	pick-up	0	8
83397	2020-06-23 07:26:53	2020-06-23	9	[{"id_menu":7,"count":1}]	15113	delivery	5	14
83398	2020-06-23 07:30:28	2020-06-23	9	[{"id_menu":7,"count":2}]	17455	delivery	5	14
83399	2020-06-23 07:34:58	2020-06-23	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	32180	delivery	5	38
83400	2020-06-23 07:42:57	2020-06-23	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	26299	delivery	5	39
83401	2020-06-23 07:45:00	2020-06-23	12	[{"id_menu":1,"count":1}]	32706	delivery	5	17
83402	2020-06-23 07:47:00	2020-06-23	9	[{"id_menu":6,"count":1}]	18425	pick-up	0	9
83403	2020-06-23 07:50:04	2020-06-23	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9807	delivery	5	56
83404	2020-06-23 07:52:47	2020-06-23	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	30891	delivery	5	34
83405	2020-06-23 07:54:00	2020-06-23	17	[{"id_menu":4,"count":1}]	23831	pick-up	0	17
83406	2020-06-23 07:55:08	2020-06-23	12	[{"id_menu":3,"count":1}]	32787	pick-up	0	12
83407	2020-06-23 07:58:12	2020-06-23	17	[{"id_menu":4,"count":1}]	19817	delivery	5	22
83408	2020-06-23 08:03:23	2020-06-23	12	[{"id_menu":3,"count":1}]	2881	pick-up	0	12
83409	2020-06-23 08:03:53	2020-06-23	9	[{"id_menu":7,"count":1}]	6258	delivery	5	14
83410	2020-06-23 08:04:40	2020-06-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32738	delivery	5	22
83411	2020-06-23 08:04:48	2020-06-23	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	26660	delivery	5	36
83412	2020-06-23 08:06:27	2020-06-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32704	delivery	5	23
83413	2020-06-23 08:08:49	2020-06-23	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	12648	pick-up	0	26
83414	2020-06-23 08:11:05	2020-06-23	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32702	delivery	5	35
83415	2020-06-23 08:13:58	2020-06-23	17	[{"id_menu":4,"count":1}]	26930	delivery	5	22
83416	2020-06-23 08:19:12	2020-06-23	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8517	delivery	5	39
83417	2020-06-23 08:19:26	2020-06-23	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	21151	delivery	5	30
83418	2020-06-23 08:20:22	2020-06-23	14	[{"id_menu":2,"count":1}]	12391	delivery	5	19
83419	2020-06-23 08:20:36	2020-06-23	8	[{"id_menu":5,"count":1}]	25282	pick-up	0	8
83420	2020-06-23 08:20:40	2020-06-23	17	[{"id_menu":4,"count":1}]	4157	pick-up	0	17
83421	2020-06-23 08:25:51	2020-06-23	9	[{"id_menu":6,"count":1}]	32764	delivery	5	14
83422	2020-06-23 08:26:04	2020-06-23	9	[{"id_menu":6,"count":1}]	32695	delivery	5	14
83423	2020-06-23 08:26:45	2020-06-23	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	32811	delivery	5	36
83424	2020-06-23 08:32:28	2020-06-23	14	[{"id_menu":2,"count":1}]	18731	delivery	5	19
83425	2020-06-23 08:34:05	2020-06-23	14	[{"id_menu":2,"count":1}]	31091	delivery	5	19
83426	2020-06-23 08:34:34	2020-06-23	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30312	delivery	5	48
83427	2020-06-23 08:38:36	2020-06-23	12	[{"id_menu":1,"count":1}]	23349	pick-up	0	12
83428	2020-06-23 08:39:28	2020-06-23	14	[{"id_menu":2,"count":1}]	14862	delivery	5	19
83429	2020-06-23 08:41:04	2020-06-23	9	[{"id_menu":7,"count":1}]	6166	delivery	5	14
83430	2020-06-23 08:45:35	2020-06-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	25544	delivery	5	31
83431	2020-06-23 08:48:51	2020-06-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14095	delivery	5	22
83432	2020-06-23 08:50:49	2020-06-23	17	[{"id_menu":4,"count":1}]	14410	delivery	5	22
83433	2020-06-23 08:52:10	2020-06-23	12	[{"id_menu":1,"count":1}]	32747	delivery	5	17
83434	2020-06-23 08:52:27	2020-06-23	9	[{"id_menu":7,"count":1}]	22443	delivery	5	14
83435	2020-06-23 08:55:09	2020-06-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7686	delivery	5	36
83436	2020-06-23 08:56:07	2020-06-23	8	[{"id_menu":5,"count":1}]	6232	pick-up	0	8
83437	2020-06-23 08:59:19	2020-06-23	12	[{"id_menu":3,"count":1}]	32666	pick-up	0	12
83438	2020-06-23 09:04:34	2020-06-23	12	[{"id_menu":1,"count":1}]	32697	delivery	5	17
83439	2020-06-23 09:06:26	2020-06-23	8	[{"id_menu":5,"count":1}]	9428	delivery	5	13
83440	2020-06-23 09:12:40	2020-06-23	14	[{"id_menu":2,"count":1}]	32717	delivery	5	19
83441	2020-06-23 09:13:20	2020-06-23	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4644	pick-up	0	22
83442	2020-06-23 09:13:25	2020-06-23	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	27488	pick-up	0	29
83443	2020-06-23 09:13:57	2020-06-23	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	32782	delivery	5	40
83444	2020-06-23 09:15:38	2020-06-23	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	32723	delivery	5	25
83445	2020-06-23 09:17:29	2020-06-23	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3205	pick-up	0	26
83446	2020-06-23 09:19:51	2020-06-23	9	[{"id_menu":6,"count":1}]	32802	delivery	5	14
83447	2020-06-23 09:25:32	2020-06-23	14	[{"id_menu":2,"count":1}]	32685	delivery	5	19
83448	2020-06-23 09:25:40	2020-06-23	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32794	delivery	5	35
83449	2020-06-23 09:28:12	2020-06-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32684	delivery	5	23
83450	2020-06-23 09:29:53	2020-06-23	17	[{"id_menu":4,"count":1}]	31479	delivery	5	22
83451	2020-06-23 09:39:19	2020-06-23	17	[{"id_menu":4,"count":1}]	32686	delivery	5	22
83452	2020-06-23 09:43:48	2020-06-23	14	[{"id_menu":2,"count":1}]	32681	delivery	5	19
83453	2020-06-23 09:51:44	2020-06-23	14	[{"id_menu":2,"count":1}]	32718	delivery	5	19
83454	2020-06-23 09:57:48	2020-06-23	9	[{"id_menu":6,"count":1}]	11296	delivery	5	14
83455	2020-06-23 09:58:49	2020-06-23	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32801	delivery	5	51
83456	2020-06-23 09:59:16	2020-06-23	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	32672	delivery	5	37
83457	2020-06-23 10:02:47	2020-06-23	22	[{"id_menu":2,"count":3},{"id_menu":5,"count":1}]	31988	delivery	5	27
83458	2020-06-23 10:03:05	2020-06-23	12	[{"id_menu":3,"count":1}]	4814	delivery	5	17
83459	2020-06-23 10:04:35	2020-06-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	32652	pick-up	0	23
83460	2020-06-23 10:04:44	2020-06-23	14	[{"id_menu":2,"count":1}]	32720	delivery	5	19
83461	2020-06-23 10:06:16	2020-06-23	8	[{"id_menu":5,"count":1}]	28125	delivery	5	13
83462	2020-06-23 10:13:52	2020-06-23	14	[{"id_menu":2,"count":1}]	7727	delivery	5	19
83463	2020-06-23 10:14:09	2020-06-23	17	[{"id_menu":4,"count":1}]	2229	pick-up	0	17
83464	2020-06-23 10:16:14	2020-06-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	19476	pick-up	0	26
83465	2020-06-23 10:17:45	2020-06-23	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8782	delivery	5	35
83466	2020-06-23 10:20:33	2020-06-23	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32772	delivery	5	52
83467	2020-06-23 10:21:05	2020-06-23	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21741	delivery	5	39
83468	2020-06-23 10:22:06	2020-06-23	9	[{"id_menu":7,"count":1}]	24283	delivery	5	14
83469	2020-06-23 10:33:10	2020-06-23	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	683	pick-up	0	26
83470	2020-06-23 10:37:02	2020-06-23	9	[{"id_menu":7,"count":1}]	16845	delivery	5	14
83471	2020-06-23 10:37:57	2020-06-23	9	[{"id_menu":7,"count":1}]	32634	delivery	5	14
83472	2020-06-23 10:43:20	2020-06-23	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	27193	delivery	5	27
83473	2020-06-23 10:51:15	2020-06-23	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16538	delivery	5	45
83474	2020-06-23 10:54:20	2020-06-23	9	[{"id_menu":7,"count":1}]	2007	pick-up	0	9
83475	2020-06-23 10:55:17	2020-06-23	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22060	delivery	5	22
83476	2020-06-23 10:57:05	2020-06-23	12	[{"id_menu":1,"count":1}]	10420	delivery	5	17
83477	2020-06-23 10:58:00	2020-06-23	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	20802	pick-up	0	23
83478	2020-06-23 11:02:49	2020-06-23	9	[{"id_menu":7,"count":2}]	7818	delivery	5	14
83479	2020-06-23 11:04:35	2020-06-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	32791	pick-up	0	26
83480	2020-06-23 11:04:49	2020-06-23	12	[{"id_menu":3,"count":1}]	27964	delivery	5	17
83481	2020-06-23 11:05:24	2020-06-23	14	[{"id_menu":2,"count":1}]	7841	pick-up	0	14
83482	2020-06-23 11:10:18	2020-06-23	17	[{"id_menu":4,"count":1}]	32771	delivery	5	22
83483	2020-06-23 11:12:20	2020-06-23	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20774	delivery	5	34
83484	2020-06-23 11:14:15	2020-06-23	9	[{"id_menu":6,"count":1}]	32636	delivery	5	14
83485	2020-06-23 11:14:51	2020-06-23	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4428	delivery	5	40
83486	2020-06-23 11:14:59	2020-06-23	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	32675	delivery	5	39
83487	2020-06-23 11:16:21	2020-06-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	27289	delivery	5	31
83488	2020-06-23 11:21:30	2020-06-23	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	23986	delivery	5	43
83489	2020-06-23 11:23:04	2020-06-23	8	[{"id_menu":5,"count":1}]	32800	delivery	5	13
83490	2020-06-23 11:23:08	2020-06-23	12	[{"id_menu":3,"count":1}]	10340	delivery	5	17
83491	2020-06-23 11:29:01	2020-06-23	12	[{"id_menu":3,"count":1}]	32769	delivery	5	17
83492	2020-06-23 11:47:05	2020-06-23	8	[{"id_menu":5,"count":1}]	21079	delivery	5	13
83493	2020-06-23 11:52:49	2020-06-23	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	17059	delivery	5	26
83494	2020-06-23 11:52:54	2020-06-23	9	[{"id_menu":7,"count":1}]	32790	delivery	5	14
83495	2020-06-23 11:54:10	2020-06-23	8	[{"id_menu":5,"count":1}]	3353	delivery	5	13
83496	2020-06-23 11:54:41	2020-06-23	9	[{"id_menu":6,"count":1}]	4166	pick-up	0	9
83497	2020-06-23 12:07:36	2020-06-23	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	19144	pick-up	0	21
83498	2020-06-23 12:08:00	2020-06-23	9	[{"id_menu":7,"count":1}]	14364	pick-up	0	9
83499	2020-06-23 12:09:17	2020-06-23	8	[{"id_menu":5,"count":1}]	3153	delivery	5	13
83500	2020-06-23 12:09:19	2020-06-23	12	[{"id_menu":1,"count":1}]	18784	delivery	5	17
83501	2020-06-23 12:09:41	2020-06-23	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	32698	delivery	5	30
83502	2020-06-23 12:09:45	2020-06-23	9	[{"id_menu":6,"count":1}]	25684	delivery	5	14
83503	2020-06-23 12:14:17	2020-06-23	8	[{"id_menu":5,"count":1}]	15326	delivery	5	13
83504	2020-06-23 12:20:13	2020-06-23	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	32696	delivery	5	52
83505	2020-06-23 12:22:49	2020-06-23	17	[{"id_menu":4,"count":1}]	7705	pick-up	0	17
83506	2020-06-23 12:33:59	2020-06-23	12	[{"id_menu":3,"count":1}]	14284	pick-up	0	12
83507	2020-06-23 12:36:04	2020-06-23	9	[{"id_menu":6,"count":1}]	4300	pick-up	0	9
83508	2020-06-23 12:39:06	2020-06-23	12	[{"id_menu":1,"count":1}]	5236	delivery	5	17
83509	2020-06-23 12:45:55	2020-06-23	17	[{"id_menu":4,"count":1}]	7811	delivery	5	22
83510	2020-06-23 12:46:19	2020-06-23	8	[{"id_menu":5,"count":1}]	1979	pick-up	0	8
83511	2020-06-23 12:49:46	2020-06-23	17	[{"id_menu":4,"count":1}]	12502	pick-up	0	17
83512	2020-06-23 12:51:14	2020-06-23	9	[{"id_menu":7,"count":3}]	24350	pick-up	0	9
83513	2020-06-23 12:52:32	2020-06-23	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	4710	delivery	5	29
83514	2020-06-23 12:56:04	2020-06-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	8720	delivery	5	26
83515	2020-06-23 13:02:01	2020-06-23	8	[{"id_menu":5,"count":1}]	9402	pick-up	0	8
83516	2020-06-23 13:06:29	2020-06-23	14	[{"id_menu":2,"count":1}]	11523	delivery	5	19
83517	2020-06-23 13:07:12	2020-06-23	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	32673	delivery	5	26
83518	2020-06-23 13:10:01	2020-06-23	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3534	delivery	5	26
83519	2020-06-23 13:10:23	2020-06-23	8	[{"id_menu":5,"count":2}]	32638	delivery	5	13
83520	2020-06-23 13:19:05	2020-06-23	17	[{"id_menu":4,"count":1}]	4060	delivery	5	22
83521	2020-06-23 13:25:22	2020-06-23	8	[{"id_menu":5,"count":1}]	24555	delivery	5	13
83522	2020-06-23 13:27:34	2020-06-23	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	24632	delivery	5	31
83523	2020-06-23 13:29:40	2020-06-23	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	22725	delivery	5	22
83524	2020-06-23 13:37:23	2020-06-23	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	29612	delivery	5	57
83525	2020-06-23 13:37:35	2020-06-23	9	[{"id_menu":6,"count":1}]	32784	delivery	5	14
83526	2020-06-23 13:37:59	2020-06-23	12	[{"id_menu":1,"count":1}]	12019	pick-up	0	12
83527	2020-06-23 13:38:21	2020-06-23	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	14618	delivery	5	26
83528	2020-06-23 13:41:13	2020-06-23	9	[{"id_menu":7,"count":1}]	32637	delivery	5	14
83529	2020-06-23 13:44:40	2020-06-23	17	[{"id_menu":4,"count":1}]	32146	delivery	5	22
83530	2020-06-23 13:44:47	2020-06-23	9	[{"id_menu":7,"count":1}]	10104	delivery	5	14
83531	2020-06-23 13:59:25	2020-06-23	8	[{"id_menu":5,"count":1}]	10855	pick-up	0	8
83532	2020-06-23 14:03:18	2020-06-23	12	[{"id_menu":1,"count":1}]	14969	pick-up	0	12
83533	2020-06-23 14:09:56	2020-06-23	17	[{"id_menu":4,"count":1}]	15042	delivery	5	22
83534	2020-06-23 14:11:04	2020-06-23	9	[{"id_menu":6,"count":1}]	31523	delivery	5	14
83535	2020-06-23 14:13:13	2020-06-23	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3004	delivery	5	49
83536	2020-06-23 14:17:50	2020-06-23	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	11040	pick-up	0	26
83537	2020-06-23 14:22:58	2020-06-23	17	[{"id_menu":4,"count":1}]	686	delivery	5	22
83538	2020-06-23 14:27:59	2020-06-23	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1526	delivery	5	37
83539	2020-06-23 14:30:15	2020-06-23	12	[{"id_menu":1,"count":1}]	32694	pick-up	0	12
83540	2020-06-23 14:32:08	2020-06-23	9	[{"id_menu":6,"count":1}]	8777	delivery	5	14
83541	2020-06-23 14:34:34	2020-06-23	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	25685	delivery	5	31
83542	2020-06-23 14:38:34	2020-06-23	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	32555	delivery	5	25
83543	2020-06-23 14:40:30	2020-06-23	14	[{"id_menu":2,"count":1}]	11005	pick-up	0	14
83544	2020-06-23 14:55:36	2020-06-23	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	32693	delivery	5	34
83545	2020-06-23 14:56:07	2020-06-23	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28691	delivery	5	53
83546	2020-06-23 14:58:15	2020-06-23	17	[{"id_menu":4,"count":1}]	32654	delivery	5	22
83547	2020-06-23 15:16:13	2020-06-23	12	[{"id_menu":3,"count":1}]	29429	delivery	5	17
83548	2020-06-23 15:17:28	2020-06-23	14	[{"id_menu":2,"count":1}]	1255	delivery	5	19
83549	2020-06-23 15:19:02	2020-06-23	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	18149	delivery	5	30
83550	2020-06-23 15:19:50	2020-06-23	12	[{"id_menu":1,"count":1}]	14252	pick-up	0	12
83551	2020-06-23 15:23:57	2020-06-23	12	[{"id_menu":3,"count":1}]	4629	pick-up	0	12
83552	2020-06-23 15:26:01	2020-06-23	9	[{"id_menu":6,"count":1}]	32643	delivery	5	14
83553	2020-06-23 15:26:42	2020-06-23	9	[{"id_menu":6,"count":1}]	7772	pick-up	0	9
83554	2020-06-23 15:29:07	2020-06-23	17	[{"id_menu":4,"count":1}]	3931	pick-up	0	17
83555	2020-06-23 15:30:51	2020-06-23	12	[{"id_menu":3,"count":1}]	23406	delivery	5	17
83556	2020-06-23 15:32:22	2020-06-23	9	[{"id_menu":6,"count":1}]	32761	delivery	5	14
83557	2020-06-23 15:33:11	2020-06-23	14	[{"id_menu":2,"count":1}]	32808	pick-up	0	14
83558	2020-06-23 15:38:57	2020-06-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	32699	delivery	5	26
83559	2020-06-23 15:46:33	2020-06-23	12	[{"id_menu":3,"count":1}]	13567	delivery	5	17
83560	2020-06-23 15:53:13	2020-06-23	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	17295	pick-up	0	29
83561	2020-06-23 15:54:55	2020-06-23	12	[{"id_menu":1,"count":1}]	11809	pick-up	0	12
83562	2020-06-23 15:56:48	2020-06-23	12	[{"id_menu":3,"count":1}]	17669	delivery	5	17
83563	2020-06-23 15:57:22	2020-06-23	14	[{"id_menu":2,"count":1}]	270	pick-up	0	14
83564	2020-06-23 15:57:46	2020-06-23	17	[{"id_menu":4,"count":1}]	7017	pick-up	0	17
83565	2020-06-23 16:04:41	2020-06-23	9	[{"id_menu":7,"count":2}]	8355	pick-up	0	9
83566	2020-06-23 16:05:19	2020-06-23	9	[{"id_menu":6,"count":1}]	32804	delivery	5	14
83567	2020-06-23 16:07:01	2020-06-23	8	[{"id_menu":5,"count":1}]	30504	delivery	5	13
83568	2020-06-23 16:08:52	2020-06-23	17	[{"id_menu":5,"count":3},{"id_menu":6,"count":1}]	10625	delivery	5	22
83569	2020-06-23 16:22:47	2020-06-23	17	[{"id_menu":4,"count":1}]	15895	delivery	5	22
83570	2020-06-23 16:24:26	2020-06-23	9	[{"id_menu":6,"count":1}]	15026	pick-up	0	9
83571	2020-06-23 16:25:16	2020-06-23	17	[{"id_menu":4,"count":2}]	5306	pick-up	0	17
83572	2020-06-23 16:29:59	2020-06-23	12	[{"id_menu":1,"count":1}]	10692	pick-up	0	12
83573	2020-06-23 16:31:08	2020-06-23	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9289	delivery	5	53
83574	2020-06-23 16:32:28	2020-06-23	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	2176	pick-up	0	21
83575	2020-06-23 16:35:44	2020-06-23	9	[{"id_menu":7,"count":2}]	16587	delivery	5	14
83576	2020-06-23 16:37:34	2020-06-23	14	[{"id_menu":2,"count":1}]	3790	delivery	5	19
83577	2020-06-23 16:41:20	2020-06-23	17	[{"id_menu":4,"count":1}]	1989	pick-up	0	17
83578	2020-06-23 16:45:29	2020-06-23	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3069	pick-up	0	38
83579	2020-06-23 16:47:32	2020-06-23	9	[{"id_menu":6,"count":1}]	20114	delivery	5	14
83580	2020-06-23 16:48:37	2020-06-23	17	[{"id_menu":4,"count":1}]	31006	pick-up	0	17
83581	2020-06-23 16:48:54	2020-06-23	17	[{"id_menu":4,"count":1}]	1108	delivery	5	22
83582	2020-06-23 16:49:04	2020-06-23	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	23190	delivery	5	39
83583	2020-06-23 16:53:19	2020-06-23	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32677	delivery	5	36
83584	2020-06-23 16:54:22	2020-06-23	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	30777	delivery	5	26
83585	2020-06-23 17:00:15	2020-06-23	14	[{"id_menu":2,"count":1}]	15752	pick-up	0	14
83586	2020-06-23 17:03:17	2020-06-23	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9002	delivery	5	34
83587	2020-06-23 17:03:45	2020-06-23	9	[{"id_menu":7,"count":1}]	32729	delivery	5	14
83588	2020-06-23 17:16:54	2020-06-23	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15030	delivery	5	35
83589	2020-06-23 17:18:32	2020-06-23	9	[{"id_menu":6,"count":1}]	22644	delivery	5	14
83590	2020-06-23 17:21:31	2020-06-23	9	[{"id_menu":6,"count":1}]	32754	delivery	5	14
83591	2020-06-23 17:23:45	2020-06-23	8	[{"id_menu":5,"count":1}]	32773	delivery	5	13
83592	2020-06-23 17:24:35	2020-06-23	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	32739	delivery	5	29
83593	2020-06-23 17:29:02	2020-06-23	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1970	delivery	5	30
83594	2020-06-23 17:30:31	2020-06-23	8	[{"id_menu":5,"count":1}]	5663	delivery	5	13
83595	2020-06-23 17:34:00	2020-06-23	8	[{"id_menu":5,"count":1}]	5794	delivery	5	13
83596	2020-06-23 17:37:56	2020-06-23	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	12807	delivery	5	26
83597	2020-06-23 17:40:09	2020-06-23	9	[{"id_menu":6,"count":1}]	24421	delivery	5	14
83598	2020-06-23 17:40:33	2020-06-23	14	[{"id_menu":2,"count":1}]	28987	delivery	5	19
83599	2020-06-23 17:41:21	2020-06-23	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23292	delivery	5	35
83600	2020-06-23 17:46:06	2020-06-23	9	[{"id_menu":7,"count":1}]	32661	delivery	5	14
83601	2020-06-23 17:46:50	2020-06-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	32676	delivery	5	36
83602	2020-06-23 17:49:34	2020-06-23	14	[{"id_menu":2,"count":1}]	7151	pick-up	0	14
83603	2020-06-23 17:52:05	2020-06-23	8	[{"id_menu":5,"count":1}]	32665	pick-up	0	8
83604	2020-06-23 17:55:14	2020-06-23	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	5426	delivery	5	31
83605	2020-06-23 17:57:07	2020-06-23	17	[{"id_menu":4,"count":1}]	18810	pick-up	0	17
83606	2020-06-23 17:59:04	2020-06-23	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	32689	delivery	5	25
83607	2020-06-23 18:01:44	2020-06-23	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16860	delivery	5	35
83608	2020-06-23 18:02:50	2020-06-23	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10433	delivery	5	45
83609	2020-06-23 18:04:49	2020-06-23	14	[{"id_menu":2,"count":3}]	17911	delivery	5	19
83610	2020-06-23 18:08:28	2020-06-23	9	[{"id_menu":7,"count":1}]	19480	delivery	5	14
83611	2020-06-23 18:08:59	2020-06-23	9	[{"id_menu":6,"count":1}]	20091	delivery	5	14
83612	2020-06-23 18:10:54	2020-06-23	8	[{"id_menu":5,"count":1}]	17422	delivery	5	13
83613	2020-06-23 18:14:39	2020-06-23	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	359	pick-up	0	43
83614	2020-06-23 18:17:28	2020-06-23	12	[{"id_menu":3,"count":1}]	17360	delivery	5	17
83615	2020-06-23 18:20:36	2020-06-23	17	[{"id_menu":4,"count":1}]	32722	delivery	5	22
83616	2020-06-23 18:21:20	2020-06-23	8	[{"id_menu":5,"count":1}]	32763	delivery	5	13
83617	2020-06-23 18:21:35	2020-06-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22529	delivery	5	23
83618	2020-06-23 18:23:19	2020-06-23	14	[{"id_menu":2,"count":1}]	26739	pick-up	0	14
83619	2020-06-23 18:29:12	2020-06-23	9	[{"id_menu":7,"count":1}]	14676	delivery	5	14
83620	2020-06-23 18:34:49	2020-06-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13746	delivery	5	31
83621	2020-06-23 18:34:53	2020-06-23	14	[{"id_menu":2,"count":1}]	32679	delivery	5	19
83622	2020-06-23 18:38:53	2020-06-23	9	[{"id_menu":7,"count":1}]	32766	delivery	5	14
83623	2020-06-23 18:41:32	2020-06-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	32797	delivery	5	31
83624	2020-06-23 18:42:32	2020-06-23	17	[{"id_menu":4,"count":2}]	19598	pick-up	0	17
83625	2020-06-23 18:49:50	2020-06-23	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	32707	delivery	5	22
83626	2020-06-23 18:53:19	2020-06-23	12	[{"id_menu":1,"count":1}]	17501	pick-up	0	12
83627	2020-06-23 18:53:38	2020-06-23	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	32708	delivery	5	30
83628	2020-06-23 18:54:56	2020-06-23	14	[{"id_menu":2,"count":1}]	32709	delivery	5	19
83629	2020-06-23 18:57:53	2020-06-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25287	delivery	5	23
83630	2020-06-23 19:00:11	2020-06-23	9	[{"id_menu":6,"count":1}]	25021	delivery	5	14
83631	2020-06-23 19:02:09	2020-06-23	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	32716	delivery	5	34
83632	2020-06-23 19:04:06	2020-06-23	9	[{"id_menu":6,"count":1}]	32786	delivery	5	14
83633	2020-06-23 19:05:03	2020-06-23	9	[{"id_menu":6,"count":1}]	4976	pick-up	0	9
83634	2020-06-23 19:06:26	2020-06-23	8	[{"id_menu":5,"count":1}]	3827	pick-up	0	8
83635	2020-06-23 19:06:45	2020-06-23	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	32731	delivery	5	36
83636	2020-06-23 19:07:48	2020-06-23	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	32647	delivery	5	43
83637	2020-06-23 19:11:57	2020-06-23	9	[{"id_menu":7,"count":1}]	32656	delivery	5	14
83638	2020-06-23 19:12:42	2020-06-23	9	[{"id_menu":6,"count":1}]	32712	pick-up	0	9
83639	2020-06-23 19:13:32	2020-06-23	12	[{"id_menu":3,"count":1}]	4161	pick-up	0	12
83640	2020-06-23 19:21:51	2020-06-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	32674	delivery	5	36
83641	2020-06-23 19:24:04	2020-06-23	17	[{"id_menu":4,"count":2}]	6941	delivery	5	22
83642	2020-06-23 19:29:53	2020-06-23	9	[{"id_menu":6,"count":1}]	16295	delivery	5	14
83643	2020-06-23 19:34:12	2020-06-23	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32642	delivery	5	34
83644	2020-06-23 19:35:43	2020-06-23	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":2}]	2173	pick-up	0	17
83645	2020-06-23 19:41:33	2020-06-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	27059	delivery	5	28
83646	2020-06-23 19:51:01	2020-06-23	9	[{"id_menu":7,"count":1}]	1357	pick-up	0	9
83647	2020-06-23 19:51:07	2020-06-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	32649	delivery	5	36
83648	2020-06-23 19:58:05	2020-06-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2089	pick-up	0	17
83649	2020-06-23 19:59:37	2020-06-23	12	[{"id_menu":1,"count":1}]	3248	pick-up	0	12
83650	2020-06-23 20:00:29	2020-06-23	12	[{"id_menu":1,"count":1}]	27627	delivery	5	17
83651	2020-06-23 20:07:12	2020-06-23	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13005	delivery	5	48
83652	2020-06-23 20:07:47	2020-06-23	9	[{"id_menu":7,"count":1}]	5799	pick-up	0	9
83653	2020-06-23 20:09:40	2020-06-23	8	[{"id_menu":5,"count":1}]	32687	delivery	5	13
83654	2020-06-23 20:11:27	2020-06-23	9	[{"id_menu":6,"count":1}]	9089	delivery	5	14
83655	2020-06-23 20:14:06	2020-06-23	8	[{"id_menu":5,"count":1}]	28903	pick-up	0	8
83656	2020-06-23 20:14:38	2020-06-23	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	6487	pick-up	0	22
83657	2020-06-23 20:16:45	2020-06-23	9	[{"id_menu":6,"count":1}]	2474	pick-up	0	9
83658	2020-06-23 20:17:18	2020-06-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	32343	delivery	5	26
83659	2020-06-23 20:19:16	2020-06-23	9	[{"id_menu":6,"count":1}]	4624	pick-up	0	9
83660	2020-06-23 20:20:06	2020-06-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	32404	delivery	5	26
83661	2020-06-23 20:27:47	2020-06-23	14	[{"id_menu":2,"count":1}]	12263	pick-up	0	14
83662	2020-06-23 20:37:41	2020-06-23	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	76	pick-up	0	24
83663	2020-06-23 20:39:52	2020-06-23	9	[{"id_menu":7,"count":1}]	4665	delivery	5	14
83664	2020-06-23 20:43:54	2020-06-23	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7058	pick-up	0	25
83665	2020-06-23 20:48:57	2020-06-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1025	delivery	5	28
83666	2020-06-23 20:48:58	2020-06-23	17	[{"id_menu":4,"count":1}]	32726	delivery	5	22
83667	2020-06-23 20:51:41	2020-06-23	8	[{"id_menu":5,"count":1}]	5979	delivery	5	13
83668	2020-06-23 20:59:20	2020-06-23	12	[{"id_menu":1,"count":1}]	17172	delivery	5	17
83669	2020-06-23 21:00:18	2020-06-23	12	[{"id_menu":3,"count":1}]	227	delivery	5	17
83670	2020-06-23 21:01:41	2020-06-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	32657	delivery	5	28
83671	2020-06-23 21:08:41	2020-06-23	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	32768	delivery	5	31
83672	2020-06-23 21:11:07	2020-06-23	14	[{"id_menu":2,"count":1}]	15814	delivery	5	19
83673	2020-06-23 21:11:41	2020-06-23	9	[{"id_menu":6,"count":1}]	32777	delivery	5	14
83674	2020-06-23 21:14:08	2020-06-23	14	[{"id_menu":2,"count":1}]	23839	delivery	5	19
83675	2020-06-23 21:15:55	2020-06-23	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	12894	delivery	5	40
83676	2020-06-23 21:24:57	2020-06-23	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	28814	delivery	5	29
83677	2020-06-23 21:28:46	2020-06-23	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	32733	delivery	5	23
83678	2020-06-23 21:32:08	2020-06-23	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2054	pick-up	0	26
83679	2020-06-23 21:33:03	2020-06-23	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	32741	delivery	5	31
83680	2020-06-23 21:35:17	2020-06-23	14	[{"id_menu":2,"count":1}]	21485	pick-up	0	14
83681	2020-06-23 21:45:36	2020-06-23	9	[{"id_menu":7,"count":1}]	3302	pick-up	0	9
83682	2020-06-23 21:51:45	2020-06-23	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	3996	delivery	5	28
83683	2020-06-23 21:53:53	2020-06-23	12	[{"id_menu":1,"count":1}]	32635	delivery	5	17
83684	2020-06-23 21:56:30	2020-06-23	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32778	delivery	5	35
83685	2020-06-23 22:01:03	2020-06-23	14	[{"id_menu":2,"count":1}]	15568	delivery	5	19
83686	2020-06-23 22:06:31	2020-06-23	9	[{"id_menu":6,"count":1}]	25124	delivery	5	14
83687	2020-06-23 22:10:44	2020-06-23	14	[{"id_menu":2,"count":1}]	2869	pick-up	0	14
83688	2020-06-23 22:12:24	2020-06-23	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	22939	delivery	5	30
83689	2020-06-23 22:13:54	2020-06-23	12	[{"id_menu":1,"count":2}]	32770	pick-up	0	12
83690	2020-06-23 22:17:22	2020-06-23	9	[{"id_menu":7,"count":1}]	27668	delivery	5	14
83691	2020-06-23 22:20:06	2020-06-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	32639	delivery	5	31
83692	2020-06-23 22:20:34	2020-06-23	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19098	delivery	5	22
83693	2020-06-23 22:20:47	2020-06-23	14	[{"id_menu":2,"count":1}]	4927	delivery	5	19
83694	2020-06-23 22:20:56	2020-06-23	9	[{"id_menu":6,"count":2}]	18710	delivery	5	14
83695	2020-06-23 22:21:44	2020-06-23	9	[{"id_menu":7,"count":1}]	32753	delivery	5	14
83696	2020-06-23 22:25:04	2020-06-23	14	[{"id_menu":2,"count":1}]	32644	delivery	5	19
83697	2020-06-23 22:28:54	2020-06-23	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	32683	delivery	5	43
83698	2020-06-23 22:28:55	2020-06-23	12	[{"id_menu":1,"count":1}]	26493	delivery	5	17
83699	2020-06-23 22:30:10	2020-06-23	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25611	delivery	5	35
83700	2020-06-23 22:32:25	2020-06-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	29494	delivery	5	22
83701	2020-06-23 22:37:16	2020-06-23	14	[{"id_menu":2,"count":1}]	232	pick-up	0	14
83702	2020-06-23 22:37:18	2020-06-23	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	32700	delivery	5	34
83703	2020-06-23 22:37:27	2020-06-23	17	[{"id_menu":4,"count":1}]	11181	delivery	5	22
83704	2020-06-23 22:39:06	2020-06-23	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18906	delivery	5	48
83705	2020-06-23 22:40:19	2020-06-23	8	[{"id_menu":5,"count":1}]	22214	pick-up	0	8
83706	2020-06-23 22:40:57	2020-06-23	12	[{"id_menu":3,"count":1}]	10400	pick-up	0	12
83707	2020-06-23 22:47:22	2020-06-23	12	[{"id_menu":1,"count":1}]	779	pick-up	0	12
83708	2020-06-23 22:54:43	2020-06-23	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1996	pick-up	0	29
83709	2020-06-23 22:55:04	2020-06-23	9	[{"id_menu":6,"count":1}]	5292	pick-up	0	9
83710	2020-06-23 22:57:38	2020-06-23	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14453	delivery	5	43
83711	2020-06-23 23:13:47	2020-06-23	25	[{"id_menu":4,"count":3},{"id_menu":5,"count":1}]	29949	delivery	5	30
83712	2020-06-23 23:13:51	2020-06-23	8	[{"id_menu":5,"count":1}]	32728	delivery	5	13
83713	2020-06-23 23:15:47	2020-06-23	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23064	delivery	5	22
83714	2020-06-23 23:27:10	2020-06-23	14	[{"id_menu":2,"count":1}]	2926	delivery	5	19
83715	2020-06-23 23:31:07	2020-06-23	29	[{"id_menu":1,"count":3},{"id_menu":4,"count":1}]	32645	pick-up	0	29
83716	2020-06-23 23:34:38	2020-06-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22464	pick-up	0	18
83717	2020-06-23 23:41:16	2020-06-23	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28127	delivery	5	39
83718	2020-06-23 23:41:51	2020-06-23	9	[{"id_menu":7,"count":1}]	10354	delivery	5	14
83719	2020-06-23 23:43:12	2020-06-23	12	[{"id_menu":3,"count":1}]	32751	delivery	5	17
83720	2020-06-23 23:43:26	2020-06-23	14	[{"id_menu":2,"count":1}]	32670	delivery	5	19
83721	2020-06-23 23:45:10	2020-06-23	17	[{"id_menu":4,"count":1}]	23948	delivery	5	22
83722	2020-06-23 23:46:25	2020-06-23	14	[{"id_menu":2,"count":1}]	25543	delivery	5	19
83723	2020-06-23 23:50:44	2020-06-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14002	pick-up	0	17
83724	2020-06-23 23:51:41	2020-06-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3297	delivery	5	22
83725	2020-06-23 23:56:00	2020-06-23	9	[{"id_menu":7,"count":1}]	32662	delivery	5	14
83726	2020-06-23 23:57:20	2020-06-23	12	[{"id_menu":1,"count":1}]	32703	delivery	5	17
83727	2020-06-23 23:58:21	2020-06-23	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	32746	delivery	5	26
83728	2020-06-24 00:00:00	2020-06-24	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	1662	delivery	5	36
83729	2020-06-24 00:00:32	2020-06-24	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	32870	delivery	5	34
83730	2020-06-24 00:01:03	2020-06-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	3749	delivery	5	23
83731	2020-06-24 00:02:17	2020-06-24	17	[{"id_menu":4,"count":1}]	3806	delivery	5	22
83732	2020-06-24 00:02:59	2020-06-24	9	[{"id_menu":6,"count":1}]	13731	pick-up	0	9
83733	2020-06-24 00:03:35	2020-06-24	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32847	delivery	5	37
83734	2020-06-24 00:05:58	2020-06-24	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32953	delivery	5	35
83735	2020-06-24 00:07:17	2020-06-24	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	12485	pick-up	0	21
83736	2020-06-24 00:09:21	2020-06-24	9	[{"id_menu":7,"count":1}]	24975	delivery	5	14
83737	2020-06-24 00:17:43	2020-06-24	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	33012	delivery	5	26
83738	2020-06-24 00:18:42	2020-06-24	9	[{"id_menu":6,"count":1}]	13557	delivery	5	14
83739	2020-06-24 00:27:00	2020-06-24	9	[{"id_menu":7,"count":1}]	18299	delivery	5	14
83740	2020-06-24 00:27:09	2020-06-24	12	[{"id_menu":3,"count":1}]	16416	pick-up	0	12
83741	2020-06-24 00:32:53	2020-06-24	8	[{"id_menu":5,"count":1}]	32835	delivery	5	13
83742	2020-06-24 00:47:35	2020-06-24	9	[{"id_menu":7,"count":1}]	32878	delivery	5	14
83743	2020-06-24 00:49:31	2020-06-24	9	[{"id_menu":6,"count":1}]	31454	delivery	5	14
83744	2020-06-24 00:56:27	2020-06-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	32842	delivery	5	23
83745	2020-06-24 01:00:03	2020-06-24	17	[{"id_menu":4,"count":1}]	29116	delivery	5	22
83746	2020-06-24 01:00:37	2020-06-24	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	23901	delivery	5	36
83747	2020-06-24 01:00:55	2020-06-24	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	33001	delivery	5	43
83748	2020-06-24 01:02:52	2020-06-24	9	[{"id_menu":6,"count":1}]	12678	delivery	5	14
83749	2020-06-24 01:09:53	2020-06-24	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	14160	delivery	5	37
83750	2020-06-24 01:11:06	2020-06-24	9	[{"id_menu":6,"count":1}]	7156	pick-up	0	9
83751	2020-06-24 01:11:39	2020-06-24	12	[{"id_menu":1,"count":1}]	7017	pick-up	0	12
83752	2020-06-24 01:12:46	2020-06-24	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	32944	delivery	5	35
83753	2020-06-24 01:18:45	2020-06-24	12	[{"id_menu":1,"count":1}]	24216	delivery	5	17
83754	2020-06-24 01:20:46	2020-06-24	12	[{"id_menu":1,"count":1}]	29992	delivery	5	17
83755	2020-06-24 01:21:19	2020-06-24	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	32959	delivery	5	31
83756	2020-06-24 01:22:05	2020-06-24	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	10867	pick-up	0	35
83757	2020-06-24 01:24:58	2020-06-24	12	[{"id_menu":3,"count":1}]	22900	delivery	5	17
83758	2020-06-24 01:26:01	2020-06-24	8	[{"id_menu":5,"count":1}]	17861	pick-up	0	8
83759	2020-06-24 01:27:33	2020-06-24	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16806	delivery	5	22
83760	2020-06-24 01:29:18	2020-06-24	9	[{"id_menu":7,"count":1}]	32880	delivery	5	14
83761	2020-06-24 01:29:31	2020-06-24	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	29336	delivery	5	43
83762	2020-06-24 01:30:19	2020-06-24	14	[{"id_menu":2,"count":1}]	2838	delivery	5	19
83763	2020-06-24 01:36:09	2020-06-24	17	[{"id_menu":4,"count":1}]	1659	pick-up	0	17
83764	2020-06-24 01:37:41	2020-06-24	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	32981	delivery	5	25
83765	2020-06-24 01:37:48	2020-06-24	9	[{"id_menu":6,"count":1}]	32935	delivery	5	14
83766	2020-06-24 01:39:53	2020-06-24	23	[{"id_menu":2,"count":3},{"id_menu":7,"count":1}]	30591	delivery	5	28
83767	2020-06-24 01:41:19	2020-06-24	9	[{"id_menu":7,"count":1}]	24049	delivery	5	14
83768	2020-06-24 01:43:13	2020-06-24	9	[{"id_menu":6,"count":1}]	11670	delivery	5	14
83769	2020-06-24 01:47:10	2020-06-24	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	29381	delivery	5	25
83770	2020-06-24 01:50:41	2020-06-24	17	[{"id_menu":4,"count":1}]	32937	pick-up	0	17
83771	2020-06-24 01:52:33	2020-06-24	8	[{"id_menu":5,"count":1}]	30204	delivery	5	13
83772	2020-06-24 01:53:40	2020-06-24	12	[{"id_menu":1,"count":1}]	32992	pick-up	0	12
83773	2020-06-24 01:56:42	2020-06-24	9	[{"id_menu":6,"count":1}]	23697	delivery	5	14
83774	2020-06-24 01:58:06	2020-06-24	17	[{"id_menu":4,"count":1}]	32887	delivery	5	22
83775	2020-06-24 02:02:05	2020-06-24	9	[{"id_menu":6,"count":1}]	32917	delivery	5	14
83776	2020-06-24 02:06:00	2020-06-24	9	[{"id_menu":6,"count":2}]	13256	pick-up	0	9
83777	2020-06-24 02:09:42	2020-06-24	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	32894	delivery	5	26
83778	2020-06-24 02:10:22	2020-06-24	12	[{"id_menu":1,"count":1}]	9148	delivery	5	17
83779	2020-06-24 02:12:40	2020-06-24	9	[{"id_menu":7,"count":1}]	2190	pick-up	0	9
83780	2020-06-24 02:16:33	2020-06-24	9	[{"id_menu":7,"count":1}]	22422	pick-up	0	9
83781	2020-06-24 02:19:40	2020-06-24	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	32906	delivery	5	35
83782	2020-06-24 02:27:47	2020-06-24	9	[{"id_menu":7,"count":1}]	32849	delivery	5	14
83783	2020-06-24 02:28:33	2020-06-24	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2931	delivery	5	31
83784	2020-06-24 02:29:25	2020-06-24	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	29164	delivery	5	39
83785	2020-06-24 02:29:36	2020-06-24	8	[{"id_menu":5,"count":1}]	15752	delivery	5	13
83786	2020-06-24 02:31:06	2020-06-24	8	[{"id_menu":5,"count":1}]	32960	delivery	5	13
83787	2020-06-24 02:32:40	2020-06-24	17	[{"id_menu":4,"count":1}]	21109	delivery	5	22
83788	2020-06-24 02:35:41	2020-06-24	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6080	delivery	5	45
83789	2020-06-24 02:36:52	2020-06-24	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	32903	delivery	5	45
83790	2020-06-24 02:37:58	2020-06-24	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	21161	delivery	5	57
83791	2020-06-24 02:39:09	2020-06-24	12	[{"id_menu":3,"count":1}]	25295	pick-up	0	12
83792	2020-06-24 02:42:49	2020-06-24	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27000	delivery	5	48
83793	2020-06-24 02:43:16	2020-06-24	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	32955	delivery	5	36
83794	2020-06-24 02:47:40	2020-06-24	17	[{"id_menu":4,"count":1}]	28274	delivery	5	22
83795	2020-06-24 02:55:03	2020-06-24	17	[{"id_menu":4,"count":1}]	32958	delivery	5	22
83796	2020-06-24 02:55:13	2020-06-24	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	32909	delivery	5	26
83797	2020-06-24 02:55:52	2020-06-24	9	[{"id_menu":7,"count":1}]	4486	pick-up	0	9
83798	2020-06-24 03:01:52	2020-06-24	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	32945	delivery	5	22
83799	2020-06-24 03:05:09	2020-06-24	9	[{"id_menu":6,"count":1}]	16972	pick-up	0	9
83800	2020-06-24 03:11:30	2020-06-24	17	[{"id_menu":4,"count":1}]	32925	delivery	5	22
83801	2020-06-24 03:11:54	2020-06-24	17	[{"id_menu":4,"count":1}]	11681	pick-up	0	17
83802	2020-06-24 03:20:42	2020-06-24	17	[{"id_menu":4,"count":1}]	13164	delivery	5	22
83803	2020-06-24 03:21:07	2020-06-24	14	[{"id_menu":2,"count":1}]	32915	pick-up	0	14
83804	2020-06-24 03:21:11	2020-06-24	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7697	delivery	5	57
83805	2020-06-24 03:22:38	2020-06-24	17	[{"id_menu":4,"count":1}]	2415	pick-up	0	17
83806	2020-06-24 03:27:28	2020-06-24	9	[{"id_menu":7,"count":1}]	32985	delivery	5	14
83807	2020-06-24 03:31:22	2020-06-24	9	[{"id_menu":7,"count":1}]	8148	pick-up	0	9
83808	2020-06-24 03:32:30	2020-06-24	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	27970	delivery	5	23
83809	2020-06-24 03:32:42	2020-06-24	9	[{"id_menu":6,"count":1}]	33010	delivery	5	14
83810	2020-06-24 03:40:56	2020-06-24	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	17776	delivery	5	22
83811	2020-06-24 03:41:45	2020-06-24	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	5267	delivery	5	31
83812	2020-06-24 03:46:34	2020-06-24	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10461	delivery	5	34
83813	2020-06-24 03:55:22	2020-06-24	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	20706	delivery	5	45
83814	2020-06-24 03:56:12	2020-06-24	9	[{"id_menu":7,"count":1}]	32913	delivery	5	14
83815	2020-06-24 03:57:14	2020-06-24	8	[{"id_menu":5,"count":1}]	32956	delivery	5	13
83816	2020-06-24 03:59:07	2020-06-24	8	[{"id_menu":5,"count":1}]	16826	delivery	5	13
83817	2020-06-24 04:02:29	2020-06-24	12	[{"id_menu":3,"count":1}]	17649	pick-up	0	12
83818	2020-06-24 04:03:25	2020-06-24	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9809	delivery	5	51
83819	2020-06-24 04:10:12	2020-06-24	12	[{"id_menu":3,"count":1}]	15883	pick-up	0	12
83820	2020-06-24 04:12:04	2020-06-24	12	[{"id_menu":1,"count":1}]	14064	delivery	5	17
83821	2020-06-24 04:13:05	2020-06-24	12	[{"id_menu":1,"count":1}]	7551	delivery	5	17
83822	2020-06-24 04:13:08	2020-06-24	9	[{"id_menu":7,"count":1}]	23057	delivery	5	14
83823	2020-06-24 04:19:28	2020-06-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32819	delivery	5	23
83824	2020-06-24 04:19:52	2020-06-24	14	[{"id_menu":2,"count":1}]	2618	pick-up	0	14
83825	2020-06-24 04:25:00	2020-06-24	8	[{"id_menu":5,"count":1}]	32820	delivery	5	13
83826	2020-06-24 04:26:01	2020-06-24	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	32931	delivery	5	34
83827	2020-06-24 04:38:02	2020-06-24	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5423	delivery	5	43
83828	2020-06-24 04:45:20	2020-06-24	12	[{"id_menu":1,"count":1}]	4024	delivery	5	17
83829	2020-06-24 04:48:13	2020-06-24	9	[{"id_menu":6,"count":1}]	7175	delivery	5	14
83830	2020-06-24 04:48:26	2020-06-24	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	28669	delivery	5	27
83831	2020-06-24 04:48:43	2020-06-24	17	[{"id_menu":4,"count":1}]	21634	pick-up	0	17
83832	2020-06-24 04:50:31	2020-06-24	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	5930	delivery	5	39
83833	2020-06-24 04:54:22	2020-06-24	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	32893	delivery	5	26
83834	2020-06-24 04:57:13	2020-06-24	14	[{"id_menu":2,"count":1}]	23258	delivery	5	19
83835	2020-06-24 05:05:35	2020-06-24	9	[{"id_menu":7,"count":1}]	21774	delivery	5	14
83836	2020-06-24 05:07:06	2020-06-24	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4546	pick-up	0	22
83837	2020-06-24 05:08:59	2020-06-24	12	[{"id_menu":3,"count":1}]	29728	delivery	5	17
83838	2020-06-24 05:14:40	2020-06-24	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	29094	delivery	5	40
83839	2020-06-24 05:16:23	2020-06-24	17	[{"id_menu":4,"count":1}]	9519	delivery	5	22
83840	2020-06-24 05:17:44	2020-06-24	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6640	delivery	5	22
83841	2020-06-24 05:23:52	2020-06-24	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7813	delivery	5	39
83842	2020-06-24 05:24:39	2020-06-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20545	delivery	5	22
83843	2020-06-24 05:25:31	2020-06-24	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	13203	delivery	5	31
83844	2020-06-24 05:27:51	2020-06-24	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28631	delivery	5	34
83845	2020-06-24 05:30:03	2020-06-24	12	[{"id_menu":1,"count":1}]	23040	pick-up	0	12
83846	2020-06-24 05:34:41	2020-06-24	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1344	delivery	5	34
83847	2020-06-24 05:52:29	2020-06-24	9	[{"id_menu":6,"count":1}]	17620	delivery	5	14
83848	2020-06-24 05:53:18	2020-06-24	9	[{"id_menu":7,"count":1}]	3459	pick-up	0	9
83849	2020-06-24 05:53:52	2020-06-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28007	delivery	5	23
83850	2020-06-24 05:55:07	2020-06-24	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	32922	delivery	5	31
83851	2020-06-24 05:56:13	2020-06-24	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4817	pick-up	0	51
83852	2020-06-24 05:57:19	2020-06-24	12	[{"id_menu":1,"count":1}]	32982	pick-up	0	12
83853	2020-06-24 05:57:56	2020-06-24	14	[{"id_menu":2,"count":1}]	25872	delivery	5	19
83854	2020-06-24 05:58:31	2020-06-24	12	[{"id_menu":1,"count":1}]	32810	pick-up	0	12
83855	2020-06-24 05:59:24	2020-06-24	12	[{"id_menu":1,"count":1}]	8379	delivery	5	17
83856	2020-06-24 06:05:15	2020-06-24	17	[{"id_menu":4,"count":1}]	17875	pick-up	0	17
83857	2020-06-24 06:05:26	2020-06-24	8	[{"id_menu":5,"count":1}]	20117	delivery	5	13
83858	2020-06-24 06:06:49	2020-06-24	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	13482	delivery	5	22
83859	2020-06-24 06:07:37	2020-06-24	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	173	pick-up	0	31
83860	2020-06-24 06:07:52	2020-06-24	14	[{"id_menu":2,"count":1}]	15082	pick-up	0	14
83861	2020-06-24 06:08:22	2020-06-24	9	[{"id_menu":7,"count":1}]	4300	pick-up	0	9
83862	2020-06-24 06:10:16	2020-06-24	9	[{"id_menu":6,"count":1}]	11317	delivery	5	14
83863	2020-06-24 06:11:43	2020-06-24	12	[{"id_menu":1,"count":1}]	32889	delivery	5	17
83864	2020-06-24 06:12:58	2020-06-24	12	[{"id_menu":3,"count":1}]	20673	delivery	5	17
83865	2020-06-24 06:14:02	2020-06-24	17	[{"id_menu":4,"count":1}]	20989	pick-up	0	17
83866	2020-06-24 06:15:30	2020-06-24	17	[{"id_menu":4,"count":1}]	8303	pick-up	0	17
83867	2020-06-24 06:16:13	2020-06-24	9	[{"id_menu":7,"count":1}]	13728	delivery	5	14
83868	2020-06-24 06:21:10	2020-06-24	9	[{"id_menu":6,"count":1}]	32973	delivery	5	14
83869	2020-06-24 06:22:19	2020-06-24	8	[{"id_menu":5,"count":1}]	32831	delivery	5	13
83870	2020-06-24 06:25:46	2020-06-24	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	32900	delivery	5	36
83871	2020-06-24 06:29:02	2020-06-24	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	22966	delivery	5	40
83872	2020-06-24 06:30:23	2020-06-24	9	[{"id_menu":6,"count":2}]	3514	pick-up	0	9
83873	2020-06-24 06:32:11	2020-06-24	8	[{"id_menu":5,"count":1}]	2089	pick-up	0	8
83874	2020-06-24 06:32:16	2020-06-24	12	[{"id_menu":1,"count":1}]	32946	pick-up	0	12
83875	2020-06-24 06:33:15	2020-06-24	17	[{"id_menu":4,"count":2}]	32012	delivery	5	22
83876	2020-06-24 06:37:05	2020-06-24	9	[{"id_menu":6,"count":1}]	21425	delivery	5	14
83877	2020-06-24 06:38:41	2020-06-24	12	[{"id_menu":3,"count":1}]	32896	delivery	5	17
83878	2020-06-24 06:39:01	2020-06-24	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	15299	delivery	5	29
83879	2020-06-24 06:39:58	2020-06-24	14	[{"id_menu":2,"count":1}]	722	delivery	5	19
83880	2020-06-24 06:42:09	2020-06-24	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	4031	pick-up	0	20
83881	2020-06-24 06:42:42	2020-06-24	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	32936	pick-up	0	26
83882	2020-06-24 06:44:19	2020-06-24	9	[{"id_menu":6,"count":1}]	11380	pick-up	0	9
83883	2020-06-24 06:48:43	2020-06-24	9	[{"id_menu":7,"count":1}]	32823	delivery	5	14
83884	2020-06-24 06:49:49	2020-06-24	17	[{"id_menu":4,"count":1}]	32846	pick-up	0	17
83885	2020-06-24 06:52:01	2020-06-24	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32590	delivery	5	37
83886	2020-06-24 06:54:11	2020-06-24	9	[{"id_menu":7,"count":1}]	32907	delivery	5	14
83887	2020-06-24 06:54:27	2020-06-24	14	[{"id_menu":2,"count":1}]	32951	pick-up	0	14
83888	2020-06-24 06:55:03	2020-06-24	12	[{"id_menu":3,"count":1}]	27438	delivery	5	17
83889	2020-06-24 06:59:34	2020-06-24	12	[{"id_menu":1,"count":1}]	436	pick-up	0	12
83890	2020-06-24 06:59:35	2020-06-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7410	pick-up	0	26
83891	2020-06-24 07:04:14	2020-06-24	12	[{"id_menu":1,"count":1}]	2897	pick-up	0	12
83892	2020-06-24 07:07:03	2020-06-24	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	4293	delivery	5	26
83893	2020-06-24 07:10:53	2020-06-24	9	[{"id_menu":6,"count":1}]	2972	pick-up	0	9
83894	2020-06-24 07:15:44	2020-06-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8358	pick-up	0	17
83895	2020-06-24 07:17:13	2020-06-24	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	31523	delivery	5	27
83896	2020-06-24 07:17:15	2020-06-24	9	[{"id_menu":7,"count":1}]	32993	delivery	5	14
83897	2020-06-24 07:19:12	2020-06-24	9	[{"id_menu":6,"count":1}]	32940	delivery	5	14
83898	2020-06-24 07:20:24	2020-06-24	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	32284	delivery	5	43
83899	2020-06-24 07:21:06	2020-06-24	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	32972	delivery	5	44
83900	2020-06-24 07:21:47	2020-06-24	17	[{"id_menu":4,"count":1}]	3115	pick-up	0	17
83901	2020-06-24 07:22:24	2020-06-24	9	[{"id_menu":6,"count":1}]	33024	delivery	5	14
83902	2020-06-24 07:33:21	2020-06-24	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19953	delivery	5	31
83903	2020-06-24 07:37:11	2020-06-24	9	[{"id_menu":7,"count":1}]	32949	delivery	5	14
83904	2020-06-24 07:40:41	2020-06-24	9	[{"id_menu":6,"count":1}]	32968	delivery	5	14
83905	2020-06-24 07:43:33	2020-06-24	17	[{"id_menu":4,"count":1}]	32882	delivery	5	22
83906	2020-06-24 07:43:40	2020-06-24	8	[{"id_menu":5,"count":1}]	24594	delivery	5	13
83907	2020-06-24 07:44:37	2020-06-24	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	17363	delivery	5	29
83908	2020-06-24 07:48:00	2020-06-24	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	12180	delivery	5	44
83909	2020-06-24 07:50:44	2020-06-24	14	[{"id_menu":2,"count":1}]	6037	pick-up	0	14
83910	2020-06-24 07:50:48	2020-06-24	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	9846	delivery	5	26
83911	2020-06-24 07:55:05	2020-06-24	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	33017	delivery	5	39
83912	2020-06-24 07:58:17	2020-06-24	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	4652	pick-up	0	23
83913	2020-06-24 07:58:36	2020-06-24	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32977	delivery	5	52
83914	2020-06-24 08:04:11	2020-06-24	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32918	delivery	5	34
83915	2020-06-24 08:06:26	2020-06-24	14	[{"id_menu":2,"count":1}]	5814	delivery	5	19
83916	2020-06-24 08:08:00	2020-06-24	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2497	delivery	5	31
83917	2020-06-24 08:11:18	2020-06-24	14	[{"id_menu":2,"count":1}]	2702	pick-up	0	14
83918	2020-06-24 08:12:30	2020-06-24	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6516	delivery	5	40
83919	2020-06-24 08:14:22	2020-06-24	14	[{"id_menu":2,"count":1}]	2127	delivery	5	19
83920	2020-06-24 08:14:39	2020-06-24	14	[{"id_menu":2,"count":1}]	16434	delivery	5	19
83921	2020-06-24 08:15:56	2020-06-24	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	32832	delivery	5	26
83922	2020-06-24 08:15:56	2020-06-24	14	[{"id_menu":2,"count":1}]	31903	pick-up	0	14
83923	2020-06-24 08:16:11	2020-06-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	676	pick-up	0	18
83924	2020-06-24 08:16:44	2020-06-24	8	[{"id_menu":5,"count":1}]	33003	delivery	5	13
83925	2020-06-24 08:17:40	2020-06-24	14	[{"id_menu":2,"count":1}]	17819	delivery	5	19
83926	2020-06-24 08:24:14	2020-06-24	17	[{"id_menu":4,"count":1}]	25575	delivery	5	22
83927	2020-06-24 08:24:58	2020-06-24	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	26459	pick-up	0	40
83928	2020-06-24 08:26:07	2020-06-24	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	32837	delivery	5	34
83929	2020-06-24 08:32:46	2020-06-24	8	[{"id_menu":5,"count":1}]	32997	delivery	5	13
83930	2020-06-24 08:33:50	2020-06-24	14	[{"id_menu":2,"count":1}]	3997	delivery	5	19
83931	2020-06-24 08:37:58	2020-06-24	12	[{"id_menu":3,"count":1}]	2943	delivery	5	17
83932	2020-06-24 08:48:28	2020-06-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	32930	delivery	5	31
83933	2020-06-24 08:49:12	2020-06-24	9	[{"id_menu":7,"count":1}]	16702	delivery	5	14
83934	2020-06-24 08:50:51	2020-06-24	9	[{"id_menu":6,"count":1}]	32500	pick-up	0	9
83935	2020-06-24 08:51:58	2020-06-24	9	[{"id_menu":7,"count":1}]	24668	pick-up	0	9
83936	2020-06-24 08:53:21	2020-06-24	17	[{"id_menu":4,"count":1}]	5019	delivery	5	22
83937	2020-06-24 08:55:20	2020-06-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	32888	delivery	5	22
83938	2020-06-24 08:55:36	2020-06-24	14	[{"id_menu":2,"count":1}]	32891	pick-up	0	14
83939	2020-06-24 08:59:23	2020-06-24	9	[{"id_menu":6,"count":1}]	10153	pick-up	0	9
83940	2020-06-24 09:02:00	2020-06-24	17	[{"id_menu":4,"count":1}]	33007	delivery	5	22
83941	2020-06-24 09:02:20	2020-06-24	14	[{"id_menu":2,"count":1}]	20334	delivery	5	19
83942	2020-06-24 09:09:13	2020-06-24	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	32883	delivery	5	31
83943	2020-06-24 09:09:50	2020-06-24	9	[{"id_menu":7,"count":1}]	27376	delivery	5	14
83944	2020-06-24 09:13:12	2020-06-24	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	32863	delivery	5	26
83945	2020-06-24 09:14:00	2020-06-24	14	[{"id_menu":2,"count":1}]	33022	pick-up	0	14
83946	2020-06-24 09:15:19	2020-06-24	8	[{"id_menu":5,"count":1}]	10007	pick-up	0	8
83947	2020-06-24 09:15:52	2020-06-24	14	[{"id_menu":2,"count":1}]	13035	delivery	5	19
83948	2020-06-24 09:17:06	2020-06-24	9	[{"id_menu":6,"count":1}]	29348	pick-up	0	9
83949	2020-06-24 09:20:32	2020-06-24	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3205	pick-up	0	21
83950	2020-06-24 09:21:25	2020-06-24	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3950	delivery	5	31
83951	2020-06-24 09:29:05	2020-06-24	9	[{"id_menu":6,"count":1}]	30973	delivery	5	14
83952	2020-06-24 09:30:16	2020-06-24	9	[{"id_menu":7,"count":1}]	32836	delivery	5	14
83953	2020-06-24 09:31:30	2020-06-24	17	[{"id_menu":4,"count":1}]	71	pick-up	0	17
83954	2020-06-24 09:32:04	2020-06-24	12	[{"id_menu":3,"count":1}]	19622	delivery	5	17
83955	2020-06-24 09:33:16	2020-06-24	12	[{"id_menu":3,"count":1}]	9886	pick-up	0	12
83956	2020-06-24 09:38:24	2020-06-24	8	[{"id_menu":5,"count":1}]	32850	delivery	5	13
83957	2020-06-24 09:40:15	2020-06-24	9	[{"id_menu":7,"count":1}]	26292	delivery	5	14
83958	2020-06-24 09:41:54	2020-06-24	14	[{"id_menu":2,"count":1}]	7746	pick-up	0	14
83959	2020-06-24 09:45:58	2020-06-24	9	[{"id_menu":6,"count":1}]	28927	pick-up	0	9
83960	2020-06-24 09:50:20	2020-06-24	9	[{"id_menu":7,"count":1}]	32821	delivery	5	14
83961	2020-06-24 09:53:36	2020-06-24	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32921	delivery	5	34
83962	2020-06-24 09:55:18	2020-06-24	9	[{"id_menu":6,"count":1}]	32999	delivery	5	14
83963	2020-06-24 10:08:15	2020-06-24	14	[{"id_menu":2,"count":1}]	5613	delivery	5	19
83964	2020-06-24 10:08:21	2020-06-24	12	[{"id_menu":3,"count":2}]	20697	delivery	5	17
83965	2020-06-24 10:13:38	2020-06-24	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	32886	delivery	5	27
83966	2020-06-24 10:15:07	2020-06-24	8	[{"id_menu":5,"count":1}]	32828	delivery	5	13
83967	2020-06-24 10:15:08	2020-06-24	12	[{"id_menu":1,"count":2}]	4948	delivery	5	17
83968	2020-06-24 10:17:17	2020-06-24	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	16141	delivery	5	44
83969	2020-06-24 10:23:31	2020-06-24	9	[{"id_menu":6,"count":1}]	11039	delivery	5	14
83970	2020-06-24 10:24:40	2020-06-24	14	[{"id_menu":2,"count":1}]	27577	pick-up	0	14
83971	2020-06-24 10:24:51	2020-06-24	9	[{"id_menu":6,"count":1}]	32858	delivery	5	14
83972	2020-06-24 10:26:07	2020-06-24	17	[{"id_menu":4,"count":1}]	4681	pick-up	0	17
83973	2020-06-24 10:31:37	2020-06-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16729	delivery	5	31
83974	2020-06-24 10:31:41	2020-06-24	9	[{"id_menu":6,"count":1}]	30660	pick-up	0	9
83975	2020-06-24 10:33:24	2020-06-24	8	[{"id_menu":5,"count":1}]	19962	delivery	5	13
83976	2020-06-24 10:34:06	2020-06-24	9	[{"id_menu":7,"count":1}]	27087	delivery	5	14
83977	2020-06-24 10:37:24	2020-06-24	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	32825	delivery	5	26
83978	2020-06-24 10:38:05	2020-06-24	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	32881	delivery	5	30
83979	2020-06-24 10:40:00	2020-06-24	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	32939	pick-up	0	21
83980	2020-06-24 10:41:11	2020-06-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	33000	delivery	5	28
83981	2020-06-24 10:42:16	2020-06-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	32859	delivery	5	22
83982	2020-06-24 10:42:28	2020-06-24	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	19537	delivery	5	43
83983	2020-06-24 10:43:07	2020-06-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	32908	delivery	5	22
83984	2020-06-24 10:44:24	2020-06-24	12	[{"id_menu":3,"count":1}]	26370	pick-up	0	12
83985	2020-06-24 10:46:21	2020-06-24	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	32990	delivery	5	48
83986	2020-06-24 10:52:13	2020-06-24	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	14025	pick-up	0	47
83987	2020-06-24 10:55:44	2020-06-24	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	7582	delivery	5	26
83988	2020-06-24 10:57:34	2020-06-24	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	16228	pick-up	0	33
83989	2020-06-24 10:58:43	2020-06-24	8	[{"id_menu":5,"count":2}]	5427	pick-up	0	8
83990	2020-06-24 11:06:45	2020-06-24	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17358	delivery	5	45
83991	2020-06-24 11:10:50	2020-06-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	26520	delivery	5	28
83992	2020-06-24 11:12:01	2020-06-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	32910	delivery	5	22
83993	2020-06-24 11:14:37	2020-06-24	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9103	delivery	5	31
83994	2020-06-24 11:21:00	2020-06-24	14	[{"id_menu":2,"count":1}]	11156	delivery	5	19
83995	2020-06-24 11:25:57	2020-06-24	14	[{"id_menu":2,"count":1}]	33002	pick-up	0	14
83996	2020-06-24 11:28:11	2020-06-24	9	[{"id_menu":7,"count":1}]	32865	delivery	5	14
83997	2020-06-24 11:32:06	2020-06-24	9	[{"id_menu":7,"count":1}]	32976	delivery	5	14
83998	2020-06-24 11:32:39	2020-06-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32978	delivery	5	23
83999	2020-06-24 11:33:03	2020-06-24	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	20747	pick-up	0	21
84000	2020-06-24 11:38:37	2020-06-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	33006	delivery	5	28
84001	2020-06-24 11:41:42	2020-06-24	9	[{"id_menu":6,"count":1}]	21553	pick-up	0	9
84002	2020-06-24 11:52:05	2020-06-24	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15740	delivery	5	36
84003	2020-06-24 11:52:15	2020-06-24	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	33005	delivery	5	46
84004	2020-06-24 11:59:57	2020-06-24	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	32834	delivery	5	34
84005	2020-06-24 12:00:34	2020-06-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	32966	delivery	5	28
84006	2020-06-24 12:04:26	2020-06-24	8	[{"id_menu":5,"count":1}]	4782	delivery	5	13
84007	2020-06-24 12:09:15	2020-06-24	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":3}]	32892	delivery	5	26
84008	2020-06-24 12:11:11	2020-06-24	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1092	pick-up	0	24
84009	2020-06-24 12:11:43	2020-06-24	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2231	delivery	5	34
84010	2020-06-24 12:15:20	2020-06-24	9	[{"id_menu":6,"count":1}]	7060	delivery	5	14
84011	2020-06-24 12:15:57	2020-06-24	9	[{"id_menu":6,"count":1}]	32979	delivery	5	14
84012	2020-06-24 12:16:00	2020-06-24	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	32877	delivery	5	34
84013	2020-06-24 12:20:18	2020-06-24	9	[{"id_menu":6,"count":1}]	32948	delivery	5	14
84014	2020-06-24 12:22:03	2020-06-24	12	[{"id_menu":1,"count":1}]	33018	delivery	5	17
84015	2020-06-24 12:24:46	2020-06-24	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	9077	delivery	5	26
84016	2020-06-24 12:27:33	2020-06-24	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4356	pick-up	0	26
84017	2020-06-24 12:37:16	2020-06-24	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	32844	delivery	5	43
84018	2020-06-24 12:38:30	2020-06-24	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1015	pick-up	0	21
84019	2020-06-24 12:38:44	2020-06-24	9	[{"id_menu":7,"count":1}]	6489	pick-up	0	9
84020	2020-06-24 12:43:37	2020-06-24	9	[{"id_menu":7,"count":1}]	32812	delivery	5	14
84021	2020-06-24 12:44:53	2020-06-24	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	20899	delivery	5	26
84022	2020-06-24 12:47:54	2020-06-24	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	3467	delivery	5	36
84023	2020-06-24 12:52:06	2020-06-24	12	[{"id_menu":1,"count":1}]	1241	pick-up	0	12
84024	2020-06-24 12:52:36	2020-06-24	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	32924	delivery	5	38
84025	2020-06-24 12:54:01	2020-06-24	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	28505	delivery	5	44
84026	2020-06-24 12:58:07	2020-06-24	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	32851	delivery	5	43
84027	2020-06-24 12:59:24	2020-06-24	14	[{"id_menu":2,"count":1}]	2241	delivery	5	19
84028	2020-06-24 13:00:11	2020-06-24	8	[{"id_menu":5,"count":1}]	32950	delivery	5	13
84029	2020-06-24 13:03:16	2020-06-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	32868	delivery	5	22
84030	2020-06-24 13:03:43	2020-06-24	9	[{"id_menu":7,"count":1}]	32884	delivery	5	14
84031	2020-06-24 13:04:11	2020-06-24	14	[{"id_menu":2,"count":1}]	18348	delivery	5	19
84032	2020-06-24 13:06:44	2020-06-24	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	32680	delivery	5	23
84033	2020-06-24 13:08:49	2020-06-24	9	[{"id_menu":6,"count":1}]	31821	delivery	5	14
84034	2020-06-24 13:12:46	2020-06-24	17	[{"id_menu":4,"count":1}]	2891	pick-up	0	17
84035	2020-06-24 13:14:35	2020-06-24	8	[{"id_menu":5,"count":1}]	33008	delivery	5	13
84036	2020-06-24 13:14:43	2020-06-24	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	24092	delivery	5	23
84037	2020-06-24 13:16:18	2020-06-24	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	21038	delivery	5	30
84038	2020-06-24 13:18:09	2020-06-24	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	33021	delivery	5	27
84039	2020-06-24 13:18:41	2020-06-24	17	[{"id_menu":4,"count":1}]	2306	pick-up	0	17
84040	2020-06-24 13:20:03	2020-06-24	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	32933	delivery	5	43
84041	2020-06-24 13:20:21	2020-06-24	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	21671	delivery	5	25
84042	2020-06-24 13:23:59	2020-06-24	8	[{"id_menu":5,"count":1}]	2130	pick-up	0	8
84043	2020-06-24 13:26:14	2020-06-24	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32954	delivery	5	34
84044	2020-06-24 13:28:11	2020-06-24	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	32941	delivery	5	42
84045	2020-06-24 13:32:34	2020-06-24	12	[{"id_menu":3,"count":1}]	27215	delivery	5	17
84046	2020-06-24 13:38:22	2020-06-24	9	[{"id_menu":7,"count":1}]	25254	delivery	5	14
84047	2020-06-24 13:39:27	2020-06-24	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	20976	delivery	5	34
84048	2020-06-24 13:39:58	2020-06-24	12	[{"id_menu":1,"count":1}]	16560	delivery	5	17
84049	2020-06-24 13:43:48	2020-06-24	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	23807	delivery	5	31
84050	2020-06-24 13:44:25	2020-06-24	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	33023	delivery	5	34
84051	2020-06-24 13:44:48	2020-06-24	9	[{"id_menu":7,"count":1}]	32987	delivery	5	14
84052	2020-06-24 13:47:57	2020-06-24	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	32876	delivery	5	27
84053	2020-06-24 13:49:59	2020-06-24	17	[{"id_menu":4,"count":1}]	20121	delivery	5	22
84054	2020-06-24 13:53:36	2020-06-24	12	[{"id_menu":3,"count":1}]	1396	pick-up	0	12
84055	2020-06-24 13:56:01	2020-06-24	12	[{"id_menu":1,"count":1}]	15262	delivery	5	17
84056	2020-06-24 13:57:15	2020-06-24	17	[{"id_menu":4,"count":1}]	1905	delivery	5	22
84057	2020-06-24 13:58:34	2020-06-24	8	[{"id_menu":5,"count":1}]	1004	pick-up	0	8
84058	2020-06-24 13:59:36	2020-06-24	12	[{"id_menu":3,"count":1}]	28391	delivery	5	17
84059	2020-06-24 14:06:11	2020-06-24	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	32866	delivery	5	36
84060	2020-06-24 14:07:30	2020-06-24	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	21256	pick-up	0	35
84061	2020-06-24 14:08:55	2020-06-24	17	[{"id_menu":4,"count":1}]	33019	delivery	5	22
84062	2020-06-24 14:13:13	2020-06-24	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	10683	delivery	5	31
84063	2020-06-24 14:16:57	2020-06-24	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	11779	pick-up	0	26
84064	2020-06-24 14:20:10	2020-06-24	9	[{"id_menu":6,"count":1}]	3399	pick-up	0	9
84065	2020-06-24 14:21:14	2020-06-24	9	[{"id_menu":7,"count":1}]	9728	delivery	5	14
84066	2020-06-24 14:22:49	2020-06-24	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	6074	pick-up	0	21
84067	2020-06-24 14:23:02	2020-06-24	9	[{"id_menu":6,"count":1}]	11552	delivery	5	14
84068	2020-06-24 14:23:54	2020-06-24	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22364	delivery	5	53
84069	2020-06-24 14:24:53	2020-06-24	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	15973	delivery	5	34
84070	2020-06-24 14:25:37	2020-06-24	9	[{"id_menu":6,"count":1}]	24112	delivery	5	14
84071	2020-06-24 14:33:32	2020-06-24	9	[{"id_menu":6,"count":1}]	23589	delivery	5	14
84072	2020-06-24 14:34:56	2020-06-24	9	[{"id_menu":6,"count":1}]	32838	pick-up	0	9
84073	2020-06-24 14:36:51	2020-06-24	12	[{"id_menu":1,"count":1}]	32856	delivery	5	17
84074	2020-06-24 14:39:58	2020-06-24	8	[{"id_menu":5,"count":1}]	23986	delivery	5	13
84075	2020-06-24 14:45:54	2020-06-24	9	[{"id_menu":7,"count":2}]	17289	delivery	5	14
84076	2020-06-24 14:49:42	2020-06-24	17	[{"id_menu":4,"count":1}]	1968	pick-up	0	17
84077	2020-06-24 14:52:40	2020-06-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	16633	delivery	5	28
84078	2020-06-24 14:56:16	2020-06-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	32983	delivery	5	22
84079	2020-06-24 14:58:16	2020-06-24	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	32919	delivery	5	23
84080	2020-06-24 15:09:06	2020-06-24	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	8899	delivery	5	34
84081	2020-06-24 15:09:53	2020-06-24	8	[{"id_menu":5,"count":2}]	6697	pick-up	0	8
84082	2020-06-24 15:12:40	2020-06-24	9	[{"id_menu":7,"count":2}]	32911	delivery	5	14
84083	2020-06-24 15:14:40	2020-06-24	8	[{"id_menu":5,"count":3}]	29555	delivery	5	13
84084	2020-06-24 15:16:10	2020-06-24	17	[{"id_menu":4,"count":1}]	32914	delivery	5	22
84085	2020-06-24 15:17:42	2020-06-24	14	[{"id_menu":2,"count":1}]	11314	pick-up	0	14
84086	2020-06-24 15:27:04	2020-06-24	14	[{"id_menu":2,"count":1}]	245	pick-up	0	14
84087	2020-06-24 15:30:51	2020-06-24	9	[{"id_menu":6,"count":1}]	14326	pick-up	0	9
84088	2020-06-24 15:34:03	2020-06-24	8	[{"id_menu":5,"count":1}]	32975	delivery	5	13
84089	2020-06-24 15:38:00	2020-06-24	12	[{"id_menu":3,"count":1}]	32830	delivery	5	17
84090	2020-06-24 15:43:47	2020-06-24	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	26624	delivery	5	42
84091	2020-06-24 15:45:55	2020-06-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3931	pick-up	0	26
84092	2020-06-24 15:52:44	2020-06-24	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19285	delivery	5	43
84093	2020-06-24 15:54:42	2020-06-24	17	[{"id_menu":4,"count":1}]	2277	pick-up	0	17
84094	2020-06-24 15:54:57	2020-06-24	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13227	delivery	5	36
84095	2020-06-24 15:58:39	2020-06-24	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	2312	delivery	5	25
84096	2020-06-24 15:59:33	2020-06-24	17	[{"id_menu":4,"count":1}]	32897	pick-up	0	17
84097	2020-06-24 16:00:19	2020-06-24	9	[{"id_menu":7,"count":1}]	13078	delivery	5	14
84098	2020-06-24 16:06:14	2020-06-24	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	32995	delivery	5	25
84099	2020-06-24 16:08:22	2020-06-24	9	[{"id_menu":6,"count":1}]	32902	delivery	5	14
84100	2020-06-24 16:16:11	2020-06-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	7857	delivery	5	22
84101	2020-06-24 16:17:28	2020-06-24	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	20434	delivery	5	23
84102	2020-06-24 16:17:48	2020-06-24	8	[{"id_menu":5,"count":1}]	27716	delivery	5	13
84103	2020-06-24 16:19:56	2020-06-24	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	30584	delivery	5	30
84104	2020-06-24 16:22:20	2020-06-24	9	[{"id_menu":6,"count":1}]	2384	pick-up	0	9
84105	2020-06-24 16:24:49	2020-06-24	8	[{"id_menu":5,"count":1}]	22164	delivery	5	13
84106	2020-06-24 16:25:40	2020-06-24	9	[{"id_menu":7,"count":1}]	26061	delivery	5	14
84107	2020-06-24 16:26:27	2020-06-24	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	22678	delivery	5	55
84108	2020-06-24 16:27:47	2020-06-24	14	[{"id_menu":2,"count":1}]	32984	delivery	5	19
84109	2020-06-24 16:31:17	2020-06-24	9	[{"id_menu":6,"count":1}]	21308	pick-up	0	9
84110	2020-06-24 16:31:37	2020-06-24	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4184	pick-up	0	25
84111	2020-06-24 16:35:22	2020-06-24	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	32879	delivery	5	40
84112	2020-06-24 16:35:42	2020-06-24	17	[{"id_menu":4,"count":1}]	1819	delivery	5	22
84113	2020-06-24 16:35:48	2020-06-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14581	delivery	5	31
84114	2020-06-24 16:36:00	2020-06-24	12	[{"id_menu":1,"count":1}]	32920	delivery	5	17
84115	2020-06-24 16:36:23	2020-06-24	14	[{"id_menu":2,"count":1}]	32839	delivery	5	19
84116	2020-06-24 16:37:15	2020-06-24	12	[{"id_menu":3,"count":2}]	32816	delivery	5	17
84117	2020-06-24 16:38:19	2020-06-24	9	[{"id_menu":7,"count":1}]	32885	pick-up	0	9
84118	2020-06-24 16:44:09	2020-06-24	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	10515	delivery	5	26
84119	2020-06-24 16:44:42	2020-06-24	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	32952	delivery	5	26
84120	2020-06-24 16:55:22	2020-06-24	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13474	delivery	5	39
84121	2020-06-24 16:57:45	2020-06-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12836	delivery	5	22
84122	2020-06-24 16:58:37	2020-06-24	9	[{"id_menu":6,"count":1}]	4168	pick-up	0	9
84123	2020-06-24 17:00:03	2020-06-24	12	[{"id_menu":3,"count":1}]	15668	delivery	5	17
84124	2020-06-24 17:02:30	2020-06-24	12	[{"id_menu":1,"count":1}]	33011	delivery	5	17
84125	2020-06-24 17:02:50	2020-06-24	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	24914	delivery	5	40
84126	2020-06-24 17:04:30	2020-06-24	9	[{"id_menu":6,"count":1}]	6539	pick-up	0	9
84127	2020-06-24 17:06:39	2020-06-24	17	[{"id_menu":4,"count":1}]	9191	pick-up	0	17
84128	2020-06-24 17:08:22	2020-06-24	14	[{"id_menu":2,"count":1}]	27863	pick-up	0	14
84129	2020-06-24 17:08:32	2020-06-24	9	[{"id_menu":7,"count":1}]	16587	delivery	5	14
84130	2020-06-24 17:13:36	2020-06-24	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32871	delivery	5	36
84131	2020-06-24 17:16:10	2020-06-24	12	[{"id_menu":3,"count":1}]	2072	pick-up	0	12
84132	2020-06-24 17:17:37	2020-06-24	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32841	delivery	5	40
84133	2020-06-24 17:18:08	2020-06-24	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25982	delivery	5	39
84134	2020-06-24 17:19:10	2020-06-24	8	[{"id_menu":5,"count":1}]	32843	delivery	5	13
84135	2020-06-24 17:19:24	2020-06-24	14	[{"id_menu":2,"count":1}]	13400	pick-up	0	14
84136	2020-06-24 17:21:03	2020-06-24	9	[{"id_menu":6,"count":1}]	25767	delivery	5	14
84137	2020-06-24 17:23:12	2020-06-24	8	[{"id_menu":5,"count":1}]	33015	pick-up	0	8
84138	2020-06-24 17:26:39	2020-06-24	12	[{"id_menu":3,"count":1}]	13475	delivery	5	17
84139	2020-06-24 17:27:49	2020-06-24	17	[{"id_menu":4,"count":1}]	31920	delivery	5	22
84140	2020-06-24 17:30:01	2020-06-24	12	[{"id_menu":1,"count":1}]	15172	pick-up	0	12
84141	2020-06-24 17:33:09	2020-06-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32864	delivery	5	23
84142	2020-06-24 17:35:01	2020-06-24	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11783	delivery	5	22
84143	2020-06-24 17:35:23	2020-06-24	9	[{"id_menu":7,"count":1}]	32860	delivery	5	14
84144	2020-06-24 17:36:00	2020-06-24	8	[{"id_menu":5,"count":1}]	802	pick-up	0	8
84145	2020-06-24 17:41:01	2020-06-24	9	[{"id_menu":6,"count":1}]	8418	delivery	5	14
84146	2020-06-24 17:41:53	2020-06-24	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":3}]	33004	pick-up	0	24
84147	2020-06-24 17:42:21	2020-06-24	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	17012	delivery	5	26
84148	2020-06-24 17:46:23	2020-06-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	294	pick-up	0	23
84149	2020-06-24 17:48:44	2020-06-24	8	[{"id_menu":5,"count":1}]	32814	delivery	5	13
84150	2020-06-24 17:49:29	2020-06-24	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10853	pick-up	0	17
84151	2020-06-24 17:49:41	2020-06-24	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	22239	delivery	5	29
84152	2020-06-24 17:49:53	2020-06-24	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33016	delivery	5	35
84153	2020-06-24 17:50:29	2020-06-24	9	[{"id_menu":6,"count":2}]	27366	delivery	5	14
84154	2020-06-24 17:51:48	2020-06-24	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32852	delivery	5	34
84155	2020-06-24 17:53:27	2020-06-24	14	[{"id_menu":2,"count":1}]	16508	delivery	5	19
84156	2020-06-24 17:54:14	2020-06-24	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	32641	delivery	5	40
84157	2020-06-24 18:00:19	2020-06-24	9	[{"id_menu":7,"count":1}]	13502	pick-up	0	9
84158	2020-06-24 18:01:07	2020-06-24	17	[{"id_menu":4,"count":1}]	32899	pick-up	0	17
84159	2020-06-24 18:02:06	2020-06-24	12	[{"id_menu":3,"count":1}]	1674	pick-up	0	12
84160	2020-06-24 18:02:32	2020-06-24	9	[{"id_menu":7,"count":1}]	15760	delivery	5	14
84161	2020-06-24 18:04:58	2020-06-24	9	[{"id_menu":7,"count":1}]	19190	delivery	5	14
84162	2020-06-24 18:06:43	2020-06-24	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13225	delivery	5	34
84163	2020-06-24 18:07:44	2020-06-24	9	[{"id_menu":7,"count":1}]	1233	pick-up	0	9
84164	2020-06-24 18:08:37	2020-06-24	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	4880	delivery	5	31
84165	2020-06-24 18:10:12	2020-06-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30500	delivery	5	23
84166	2020-06-24 18:12:24	2020-06-24	17	[{"id_menu":4,"count":1}]	1956	pick-up	0	17
84167	2020-06-24 18:12:56	2020-06-24	9	[{"id_menu":6,"count":1}]	12110	delivery	5	14
84168	2020-06-24 18:13:36	2020-06-24	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2823	delivery	5	26
84169	2020-06-24 18:16:47	2020-06-24	17	[{"id_menu":4,"count":1}]	29019	delivery	5	22
84170	2020-06-24 18:18:51	2020-06-24	9	[{"id_menu":6,"count":1}]	8068	delivery	5	14
84171	2020-06-24 18:23:23	2020-06-24	14	[{"id_menu":2,"count":1}]	5338	pick-up	0	14
84172	2020-06-24 18:24:18	2020-06-24	12	[{"id_menu":1,"count":1}]	14133	delivery	5	17
84173	2020-06-24 18:26:52	2020-06-24	9	[{"id_menu":6,"count":1}]	27148	delivery	5	14
84174	2020-06-24 18:30:13	2020-06-24	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	32980	delivery	5	26
84175	2020-06-24 18:33:07	2020-06-24	12	[{"id_menu":3,"count":1}]	142	pick-up	0	12
84176	2020-06-24 18:33:43	2020-06-24	12	[{"id_menu":3,"count":1}]	23618	delivery	5	17
84177	2020-06-24 18:36:53	2020-06-24	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	32938	delivery	5	34
84178	2020-06-24 18:36:57	2020-06-24	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	32818	pick-up	0	21
84179	2020-06-24 18:37:02	2020-06-24	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	28952	pick-up	0	41
84180	2020-06-24 18:37:35	2020-06-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	21527	delivery	5	31
84181	2020-06-24 18:40:25	2020-06-24	9	[{"id_menu":6,"count":1}]	26438	delivery	5	14
84182	2020-06-24 18:40:35	2020-06-24	14	[{"id_menu":2,"count":1}]	1493	pick-up	0	14
84183	2020-06-24 18:46:15	2020-06-24	17	[{"id_menu":4,"count":1}]	16959	pick-up	0	17
84184	2020-06-24 18:46:30	2020-06-24	17	[{"id_menu":4,"count":1}]	16644	delivery	5	22
84185	2020-06-24 18:46:57	2020-06-24	9	[{"id_menu":7,"count":1}]	27962	delivery	5	14
84186	2020-06-24 18:49:50	2020-06-24	9	[{"id_menu":7,"count":1}]	32986	delivery	5	14
84187	2020-06-24 18:52:44	2020-06-24	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	32965	delivery	5	31
84188	2020-06-24 18:54:00	2020-06-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20965	delivery	5	23
84189	2020-06-24 19:04:34	2020-06-24	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5770	pick-up	0	26
84190	2020-06-24 19:06:17	2020-06-24	8	[{"id_menu":5,"count":1}]	6987	pick-up	0	8
84191	2020-06-24 19:07:00	2020-06-24	14	[{"id_menu":2,"count":1}]	33009	delivery	5	19
84192	2020-06-24 19:11:57	2020-06-24	8	[{"id_menu":5,"count":1}]	32817	delivery	5	13
84193	2020-06-24 19:12:26	2020-06-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	22700	delivery	5	31
84194	2020-06-24 19:15:40	2020-06-24	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	28872	delivery	5	36
84195	2020-06-24 19:22:24	2020-06-24	8	[{"id_menu":5,"count":1}]	32916	delivery	5	13
84196	2020-06-24 19:24:43	2020-06-24	17	[{"id_menu":4,"count":1}]	32840	delivery	5	22
84197	2020-06-24 19:25:09	2020-06-24	9	[{"id_menu":6,"count":1}]	32943	delivery	5	14
84198	2020-06-24 19:28:38	2020-06-24	9	[{"id_menu":7,"count":1}]	32926	delivery	5	14
84199	2020-06-24 19:29:17	2020-06-24	9	[{"id_menu":6,"count":1}]	32119	delivery	5	14
84200	2020-06-24 19:34:32	2020-06-24	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	6600	pick-up	0	21
84201	2020-06-24 19:35:56	2020-06-24	12	[{"id_menu":1,"count":1}]	18581	delivery	5	17
84202	2020-06-24 19:36:18	2020-06-24	9	[{"id_menu":6,"count":1}]	15738	delivery	5	14
84203	2020-06-24 19:37:18	2020-06-24	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	5811	pick-up	0	20
84204	2020-06-24 19:38:10	2020-06-24	12	[{"id_menu":3,"count":1}]	25965	delivery	5	17
84205	2020-06-24 19:38:59	2020-06-24	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	32998	delivery	5	30
84206	2020-06-24 19:40:12	2020-06-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	13644	delivery	5	23
84207	2020-06-24 19:40:40	2020-06-24	9	[{"id_menu":6,"count":2}]	10740	delivery	5	14
84208	2020-06-24 19:43:23	2020-06-24	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	32974	delivery	5	40
84209	2020-06-24 19:45:19	2020-06-24	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20928	delivery	5	49
84210	2020-06-24 19:45:52	2020-06-24	12	[{"id_menu":1,"count":1}]	3420	delivery	5	17
84211	2020-06-24 19:46:06	2020-06-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2413	delivery	5	22
84212	2020-06-24 19:59:22	2020-06-24	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	7280	delivery	5	22
84213	2020-06-24 19:59:57	2020-06-24	9	[{"id_menu":6,"count":1}]	24295	delivery	5	14
84214	2020-06-24 20:00:15	2020-06-24	9	[{"id_menu":6,"count":1}]	32989	delivery	5	14
84215	2020-06-24 20:03:18	2020-06-24	9	[{"id_menu":7,"count":1}]	16501	pick-up	0	9
84216	2020-06-24 20:04:31	2020-06-24	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	17951	delivery	5	30
84217	2020-06-24 20:05:47	2020-06-24	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	32932	delivery	5	31
84218	2020-06-24 20:12:57	2020-06-24	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	32898	pick-up	0	29
84219	2020-06-24 20:15:41	2020-06-24	12	[{"id_menu":1,"count":1}]	33014	delivery	5	17
84220	2020-06-24 20:19:32	2020-06-24	17	[{"id_menu":4,"count":1}]	19570	delivery	5	22
84221	2020-06-24 20:21:21	2020-06-24	9	[{"id_menu":7,"count":1}]	3057	pick-up	0	9
84222	2020-06-24 20:21:31	2020-06-24	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":2}]	32962	delivery	5	36
84223	2020-06-24 20:23:45	2020-06-24	9	[{"id_menu":6,"count":1}]	640	pick-up	0	9
84224	2020-06-24 20:27:21	2020-06-24	9	[{"id_menu":6,"count":1}]	33020	delivery	5	14
84225	2020-06-24 20:34:15	2020-06-24	9	[{"id_menu":7,"count":1}]	6946	delivery	5	14
84226	2020-06-24 20:35:29	2020-06-24	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1106	pick-up	0	21
84227	2020-06-24 20:35:43	2020-06-24	12	[{"id_menu":1,"count":1}]	29514	pick-up	0	12
84228	2020-06-24 20:37:09	2020-06-24	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	7688	pick-up	0	26
84229	2020-06-24 20:40:16	2020-06-24	8	[{"id_menu":5,"count":1}]	4647	delivery	5	13
84230	2020-06-24 20:42:29	2020-06-24	9	[{"id_menu":6,"count":1}]	32905	delivery	5	14
84231	2020-06-24 20:51:06	2020-06-24	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	22332	delivery	5	35
84232	2020-06-24 20:56:54	2020-06-24	12	[{"id_menu":1,"count":1}]	9030	delivery	5	17
84233	2020-06-24 20:59:32	2020-06-24	17	[{"id_menu":4,"count":1}]	10951	delivery	5	22
84234	2020-06-24 21:01:49	2020-06-24	8	[{"id_menu":5,"count":1}]	4447	delivery	5	13
84235	2020-06-24 21:06:20	2020-06-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32991	delivery	5	23
84236	2020-06-24 21:17:41	2020-06-24	9	[{"id_menu":7,"count":1}]	14273	delivery	5	14
84237	2020-06-24 21:21:34	2020-06-24	9	[{"id_menu":6,"count":1}]	11766	pick-up	0	9
84238	2020-06-24 21:24:31	2020-06-24	9	[{"id_menu":7,"count":2}]	32854	delivery	5	14
84239	2020-06-24 21:24:37	2020-06-24	8	[{"id_menu":5,"count":1}]	7587	pick-up	0	8
84240	2020-06-24 21:28:02	2020-06-24	9	[{"id_menu":7,"count":1}]	32848	pick-up	0	9
84241	2020-06-24 21:28:31	2020-06-24	9	[{"id_menu":7,"count":1}]	17041	pick-up	0	9
84242	2020-06-24 21:28:54	2020-06-24	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	32869	delivery	5	25
84243	2020-06-24 21:29:20	2020-06-24	12	[{"id_menu":1,"count":1}]	6779	delivery	5	17
84244	2020-06-24 21:29:45	2020-06-24	12	[{"id_menu":1,"count":1}]	11634	delivery	5	17
84245	2020-06-24 21:30:09	2020-06-24	17	[{"id_menu":4,"count":1}]	14290	delivery	5	22
84246	2020-06-24 21:34:11	2020-06-24	8	[{"id_menu":5,"count":1}]	5486	delivery	5	13
84247	2020-06-24 21:36:17	2020-06-24	17	[{"id_menu":4,"count":1}]	28960	pick-up	0	17
84248	2020-06-24 21:39:24	2020-06-24	12	[{"id_menu":3,"count":1}]	3480	pick-up	0	12
84249	2020-06-24 21:40:23	2020-06-24	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	32901	pick-up	0	29
84250	2020-06-24 21:41:30	2020-06-24	12	[{"id_menu":3,"count":1}]	28628	pick-up	0	12
84251	2020-06-24 21:42:34	2020-06-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	9284	delivery	5	23
84252	2020-06-24 21:48:25	2020-06-24	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	27066	delivery	5	31
84253	2020-06-24 21:48:42	2020-06-24	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	32957	delivery	5	31
84254	2020-06-24 21:54:08	2020-06-24	17	[{"id_menu":4,"count":1}]	20754	pick-up	0	17
84255	2020-06-24 21:54:48	2020-06-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32928	delivery	5	23
84256	2020-06-24 21:55:25	2020-06-24	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	23843	delivery	5	27
84257	2020-06-24 21:56:24	2020-06-24	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	32970	delivery	5	34
84258	2020-06-24 22:06:39	2020-06-24	9	[{"id_menu":6,"count":1}]	4883	delivery	5	14
84259	2020-06-24 22:09:19	2020-06-24	9	[{"id_menu":6,"count":2}]	6915	delivery	5	14
84260	2020-06-24 22:14:35	2020-06-24	8	[{"id_menu":5,"count":1}]	26348	pick-up	0	8
84261	2020-06-24 22:20:48	2020-06-24	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	22478	pick-up	0	26
84262	2020-06-24 22:28:56	2020-06-24	9	[{"id_menu":6,"count":1}]	29334	delivery	5	14
84263	2020-06-24 22:29:06	2020-06-24	14	[{"id_menu":2,"count":1}]	32996	delivery	5	19
84264	2020-06-24 22:30:22	2020-06-24	17	[{"id_menu":4,"count":1}]	15194	pick-up	0	17
84265	2020-06-24 22:31:49	2020-06-24	9	[{"id_menu":7,"count":1}]	16530	delivery	5	14
84266	2020-06-24 22:31:49	2020-06-24	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	31181	delivery	5	39
84267	2020-06-24 22:35:50	2020-06-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	32873	pick-up	0	17
84268	2020-06-24 22:40:27	2020-06-24	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	32857	delivery	5	34
84269	2020-06-24 22:42:13	2020-06-24	9	[{"id_menu":7,"count":1}]	32827	delivery	5	14
84270	2020-06-24 22:46:39	2020-06-24	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	33013	delivery	5	34
84271	2020-06-24 22:46:54	2020-06-24	12	[{"id_menu":3,"count":1}]	3304	pick-up	0	12
84272	2020-06-24 22:47:35	2020-06-24	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	20558	delivery	5	40
84273	2020-06-24 22:49:58	2020-06-24	12	[{"id_menu":3,"count":1}]	15187	delivery	5	17
84274	2020-06-24 22:51:00	2020-06-24	14	[{"id_menu":2,"count":1}]	32861	delivery	5	19
84275	2020-06-24 22:54:18	2020-06-24	9	[{"id_menu":6,"count":1}]	32524	delivery	5	14
84276	2020-06-24 22:55:50	2020-06-24	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1531	delivery	5	29
84277	2020-06-24 22:59:02	2020-06-24	17	[{"id_menu":4,"count":1}]	4100	delivery	5	22
84278	2020-06-24 23:00:47	2020-06-24	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	9562	pick-up	0	21
84279	2020-06-24 23:02:49	2020-06-24	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	6406	delivery	5	26
84280	2020-06-24 23:07:40	2020-06-24	12	[{"id_menu":1,"count":1}]	30961	delivery	5	17
84281	2020-06-24 23:08:38	2020-06-24	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	581	delivery	5	47
84282	2020-06-24 23:19:21	2020-06-24	17	[{"id_menu":4,"count":1}]	22019	pick-up	0	17
84283	2020-06-24 23:19:24	2020-06-24	12	[{"id_menu":1,"count":1}]	32853	pick-up	0	12
84284	2020-06-24 23:19:40	2020-06-24	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	32867	delivery	5	39
84285	2020-06-24 23:20:03	2020-06-24	8	[{"id_menu":5,"count":1}]	12327	delivery	5	13
84286	2020-06-24 23:22:04	2020-06-24	12	[{"id_menu":1,"count":1}]	32862	delivery	5	17
84287	2020-06-24 23:24:04	2020-06-24	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":3}]	6328	pick-up	0	21
84288	2020-06-24 23:26:23	2020-06-24	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	28841	pick-up	0	38
84289	2020-06-24 23:27:01	2020-06-24	33	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	6546	delivery	5	38
84290	2020-06-24 23:27:24	2020-06-24	12	[{"id_menu":1,"count":1}]	5730	delivery	5	17
84291	2020-06-24 23:32:54	2020-06-24	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	27808	delivery	5	34
84292	2020-06-24 23:34:02	2020-06-24	8	[{"id_menu":5,"count":1}]	17667	delivery	5	13
84293	2020-06-24 23:34:42	2020-06-24	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	11172	delivery	5	25
84294	2020-06-24 23:35:04	2020-06-24	17	[{"id_menu":4,"count":1}]	10718	delivery	5	22
84295	2020-06-24 23:39:24	2020-06-24	17	[{"id_menu":4,"count":1}]	5472	delivery	5	22
84296	2020-06-24 23:40:33	2020-06-24	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	23571	pick-up	0	17
84297	2020-06-24 23:40:35	2020-06-24	9	[{"id_menu":6,"count":2}]	23612	delivery	5	14
84298	2020-06-24 23:43:11	2020-06-24	9	[{"id_menu":7,"count":1}]	10077	delivery	5	14
84299	2020-06-24 23:44:45	2020-06-24	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32988	delivery	5	40
84300	2020-06-24 23:45:12	2020-06-24	17	[{"id_menu":4,"count":1}]	7571	pick-up	0	17
84301	2020-06-24 23:45:25	2020-06-24	8	[{"id_menu":5,"count":1}]	21923	delivery	5	13
84302	2020-06-24 23:45:28	2020-06-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32872	delivery	5	23
84303	2020-06-24 23:47:42	2020-06-24	14	[{"id_menu":2,"count":1}]	28576	delivery	5	19
84304	2020-06-24 23:50:40	2020-06-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16592	delivery	5	23
84305	2020-06-24 23:50:45	2020-06-24	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	11334	pick-up	0	24
84306	2020-06-24 23:51:38	2020-06-24	12	[{"id_menu":3,"count":1}]	32890	delivery	5	17
84307	2020-06-24 23:52:07	2020-06-24	9	[{"id_menu":6,"count":1}]	8817	delivery	5	14
84308	2020-06-24 23:54:02	2020-06-24	9	[{"id_menu":6,"count":1}]	32947	delivery	5	14
84309	2020-06-25 00:02:34	2020-06-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	33115	delivery	5	22
84310	2020-06-25 00:05:30	2020-06-25	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	33145	delivery	5	36
84311	2020-06-25 00:05:53	2020-06-25	9	[{"id_menu":7,"count":1}]	33100	delivery	5	14
84312	2020-06-25 00:07:09	2020-06-25	14	[{"id_menu":2,"count":1}]	33030	pick-up	0	14
84313	2020-06-25 00:07:11	2020-06-25	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	467	pick-up	0	29
84314	2020-06-25 00:13:33	2020-06-25	12	[{"id_menu":3,"count":1}]	7632	delivery	5	17
84315	2020-06-25 00:14:09	2020-06-25	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	21552	delivery	5	39
84316	2020-06-25 00:21:33	2020-06-25	12	[{"id_menu":3,"count":1}]	27530	pick-up	0	12
84317	2020-06-25 00:22:22	2020-06-25	12	[{"id_menu":1,"count":2}]	1679	pick-up	0	12
84318	2020-06-25 00:22:37	2020-06-25	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	33124	delivery	5	30
84319	2020-06-25 00:22:47	2020-06-25	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	33034	delivery	5	22
84320	2020-06-25 00:22:57	2020-06-25	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	23704	delivery	5	26
84321	2020-06-25 00:23:35	2020-06-25	17	[{"id_menu":4,"count":1}]	8863	delivery	5	22
84322	2020-06-25 00:26:23	2020-06-25	14	[{"id_menu":2,"count":1}]	4725	delivery	5	19
84323	2020-06-25 00:27:16	2020-06-25	12	[{"id_menu":3,"count":1}]	33076	delivery	5	17
84324	2020-06-25 00:27:23	2020-06-25	9	[{"id_menu":6,"count":1}]	2559	delivery	5	14
84325	2020-06-25 00:28:18	2020-06-25	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	28391	delivery	5	25
84326	2020-06-25 00:29:53	2020-06-25	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	33050	delivery	5	43
84327	2020-06-25 00:31:13	2020-06-25	8	[{"id_menu":5,"count":1}]	32341	delivery	5	13
84328	2020-06-25 00:32:39	2020-06-25	17	[{"id_menu":4,"count":1}]	16466	pick-up	0	17
84329	2020-06-25 00:33:48	2020-06-25	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33062	delivery	5	40
84330	2020-06-25 00:36:30	2020-06-25	9	[{"id_menu":6,"count":1}]	29290	delivery	5	14
84331	2020-06-25 00:37:24	2020-06-25	9	[{"id_menu":6,"count":1}]	21532	delivery	5	14
84332	2020-06-25 00:37:36	2020-06-25	12	[{"id_menu":3,"count":1}]	33202	delivery	5	17
84333	2020-06-25 00:37:54	2020-06-25	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	16148	delivery	5	28
84334	2020-06-25 00:39:18	2020-06-25	8	[{"id_menu":5,"count":1}]	24880	delivery	5	13
84335	2020-06-25 00:39:19	2020-06-25	9	[{"id_menu":7,"count":1}]	33069	delivery	5	14
84336	2020-06-25 00:46:32	2020-06-25	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	33060	delivery	5	31
84337	2020-06-25 00:46:34	2020-06-25	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	14558	delivery	5	34
84338	2020-06-25 00:46:48	2020-06-25	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	33111	delivery	5	43
84339	2020-06-25 00:47:54	2020-06-25	9	[{"id_menu":7,"count":1}]	33108	delivery	5	14
84340	2020-06-25 00:48:36	2020-06-25	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12666	delivery	5	36
84341	2020-06-25 00:51:05	2020-06-25	8	[{"id_menu":5,"count":1}]	33236	delivery	5	13
84342	2020-06-25 00:54:27	2020-06-25	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	22429	delivery	5	37
84343	2020-06-25 00:56:11	2020-06-25	17	[{"id_menu":4,"count":1}]	12098	delivery	5	22
84344	2020-06-25 00:56:43	2020-06-25	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	6496	delivery	5	31
84345	2020-06-25 00:58:48	2020-06-25	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	33090	delivery	5	43
84346	2020-06-25 00:58:51	2020-06-25	12	[{"id_menu":3,"count":1}]	33119	pick-up	0	12
84347	2020-06-25 01:02:18	2020-06-25	17	[{"id_menu":4,"count":1}]	6892	delivery	5	22
84348	2020-06-25 01:02:37	2020-06-25	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	25340	delivery	5	39
84349	2020-06-25 01:06:50	2020-06-25	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	19893	pick-up	0	20
84350	2020-06-25 01:08:56	2020-06-25	9	[{"id_menu":7,"count":1}]	33051	delivery	5	14
84351	2020-06-25 01:11:23	2020-06-25	12	[{"id_menu":1,"count":1}]	33260	delivery	5	17
84352	2020-06-25 01:12:05	2020-06-25	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12810	delivery	5	43
84353	2020-06-25 01:16:45	2020-06-25	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19642	delivery	5	35
84354	2020-06-25 01:18:08	2020-06-25	8	[{"id_menu":5,"count":1}]	7306	pick-up	0	8
84355	2020-06-25 01:21:36	2020-06-25	9	[{"id_menu":6,"count":1}]	24001	delivery	5	14
84356	2020-06-25 01:24:19	2020-06-25	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33138	delivery	5	31
84357	2020-06-25 01:24:53	2020-06-25	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	33132	delivery	5	40
84358	2020-06-25 01:29:55	2020-06-25	12	[{"id_menu":3,"count":1}]	15829	pick-up	0	12
84359	2020-06-25 01:31:59	2020-06-25	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	33242	pick-up	0	40
84360	2020-06-25 01:35:01	2020-06-25	12	[{"id_menu":1,"count":3}]	33206	delivery	5	17
84361	2020-06-25 01:44:25	2020-06-25	12	[{"id_menu":1,"count":1}]	15560	delivery	5	17
84362	2020-06-25 01:44:49	2020-06-25	8	[{"id_menu":5,"count":1}]	29194	delivery	5	13
84363	2020-06-25 01:45:06	2020-06-25	14	[{"id_menu":2,"count":1}]	33270	delivery	5	19
84364	2020-06-25 01:46:29	2020-06-25	14	[{"id_menu":2,"count":1}]	20473	delivery	5	19
84365	2020-06-25 01:47:39	2020-06-25	12	[{"id_menu":1,"count":1}]	33179	delivery	5	17
84366	2020-06-25 01:48:08	2020-06-25	9	[{"id_menu":6,"count":1}]	20544	delivery	5	14
84367	2020-06-25 01:49:00	2020-06-25	9	[{"id_menu":7,"count":2}]	33177	delivery	5	14
84368	2020-06-25 01:52:11	2020-06-25	9	[{"id_menu":6,"count":1}]	33226	delivery	5	14
84369	2020-06-25 01:55:32	2020-06-25	14	[{"id_menu":2,"count":1}]	33059	delivery	5	19
84370	2020-06-25 01:55:51	2020-06-25	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	33185	delivery	5	22
84371	2020-06-25 01:58:10	2020-06-25	9	[{"id_menu":6,"count":1}]	33168	delivery	5	14
84372	2020-06-25 01:58:46	2020-06-25	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	22074	delivery	5	22
84373	2020-06-25 02:01:35	2020-06-25	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33121	delivery	5	45
84374	2020-06-25 02:05:09	2020-06-25	9	[{"id_menu":7,"count":1}]	32722	delivery	5	14
84375	2020-06-25 02:08:51	2020-06-25	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3711	pick-up	0	34
84376	2020-06-25 02:08:54	2020-06-25	14	[{"id_menu":2,"count":2}]	7297	pick-up	0	14
84377	2020-06-25 02:09:37	2020-06-25	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	25192	delivery	5	45
84378	2020-06-25 02:13:37	2020-06-25	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	33123	delivery	5	51
84379	2020-06-25 02:14:22	2020-06-25	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	19046	delivery	5	26
84380	2020-06-25 02:19:01	2020-06-25	12	[{"id_menu":1,"count":1}]	21352	delivery	5	17
84381	2020-06-25 02:19:25	2020-06-25	9	[{"id_menu":7,"count":1}]	33230	delivery	5	14
84382	2020-06-25 02:21:12	2020-06-25	12	[{"id_menu":1,"count":1}]	14192	pick-up	0	12
84383	2020-06-25 02:22:47	2020-06-25	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2089	pick-up	0	26
84384	2020-06-25 02:25:29	2020-06-25	14	[{"id_menu":2,"count":1}]	23512	delivery	5	19
84385	2020-06-25 02:25:32	2020-06-25	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1321	delivery	5	26
84386	2020-06-25 02:25:57	2020-06-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	20368	delivery	5	28
84387	2020-06-25 02:32:13	2020-06-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18722	delivery	5	23
84388	2020-06-25 02:32:16	2020-06-25	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	22542	delivery	5	30
84389	2020-06-25 02:33:02	2020-06-25	12	[{"id_menu":3,"count":1}]	33152	delivery	5	17
84390	2020-06-25 02:33:38	2020-06-25	9	[{"id_menu":7,"count":1}]	13945	pick-up	0	9
84391	2020-06-25 02:37:52	2020-06-25	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11059	delivery	5	40
84392	2020-06-25 02:39:44	2020-06-25	12	[{"id_menu":1,"count":1}]	7051	delivery	5	17
84393	2020-06-25 02:40:22	2020-06-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9898	pick-up	0	17
84394	2020-06-25 02:40:55	2020-06-25	9	[{"id_menu":7,"count":1}]	18348	pick-up	0	9
84395	2020-06-25 02:41:16	2020-06-25	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	22425	delivery	5	26
84396	2020-06-25 02:42:41	2020-06-25	12	[{"id_menu":1,"count":1}]	33264	delivery	5	17
84397	2020-06-25 02:44:53	2020-06-25	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	26068	delivery	5	34
84398	2020-06-25 02:48:52	2020-06-25	9	[{"id_menu":7,"count":1}]	33093	delivery	5	14
84399	2020-06-25 02:54:02	2020-06-25	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	9784	delivery	5	26
84400	2020-06-25 03:00:00	2020-06-25	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6664	delivery	5	22
84401	2020-06-25 03:04:52	2020-06-25	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	33126	pick-up	0	21
84402	2020-06-25 03:05:53	2020-06-25	14	[{"id_menu":2,"count":1}]	32944	delivery	5	19
84403	2020-06-25 03:09:17	2020-06-25	9	[{"id_menu":6,"count":1}]	31888	delivery	5	14
84404	2020-06-25 03:13:18	2020-06-25	9	[{"id_menu":6,"count":1}]	33231	pick-up	0	9
84405	2020-06-25 03:18:18	2020-06-25	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	33203	delivery	5	34
84406	2020-06-25 03:26:53	2020-06-25	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	7150	pick-up	0	21
84407	2020-06-25 03:27:20	2020-06-25	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	33052	delivery	5	25
84408	2020-06-25 03:29:25	2020-06-25	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	9496	delivery	5	29
84409	2020-06-25 03:31:30	2020-06-25	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	33159	delivery	5	34
84410	2020-06-25 03:31:42	2020-06-25	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28535	delivery	5	37
84411	2020-06-25 03:32:35	2020-06-25	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	17852	delivery	5	31
84412	2020-06-25 03:33:56	2020-06-25	8	[{"id_menu":5,"count":1}]	21366	delivery	5	13
84413	2020-06-25 03:35:44	2020-06-25	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	26392	delivery	5	34
84414	2020-06-25 03:35:46	2020-06-25	9	[{"id_menu":7,"count":1}]	5303	delivery	5	14
84415	2020-06-25 03:37:28	2020-06-25	17	[{"id_menu":4,"count":1}]	17280	pick-up	0	17
84416	2020-06-25 03:40:49	2020-06-25	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33038	delivery	5	35
84417	2020-06-25 03:41:32	2020-06-25	12	[{"id_menu":1,"count":1}]	32936	pick-up	0	12
84418	2020-06-25 03:42:23	2020-06-25	17	[{"id_menu":4,"count":1}]	17390	delivery	5	22
84419	2020-06-25 03:48:01	2020-06-25	17	[{"id_menu":4,"count":1}]	31453	delivery	5	22
84420	2020-06-25 03:55:12	2020-06-25	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	649	pick-up	0	24
84421	2020-06-25 03:58:53	2020-06-25	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33158	delivery	5	31
84422	2020-06-25 04:00:03	2020-06-25	9	[{"id_menu":6,"count":1}]	33200	delivery	5	14
84423	2020-06-25 04:00:59	2020-06-25	9	[{"id_menu":7,"count":1}]	23289	delivery	5	14
84424	2020-06-25 04:04:23	2020-06-25	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	18491	delivery	5	34
84425	2020-06-25 04:04:48	2020-06-25	14	[{"id_menu":2,"count":1}]	29627	delivery	5	19
84426	2020-06-25 04:05:39	2020-06-25	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33057	delivery	5	35
84427	2020-06-25 04:11:16	2020-06-25	14	[{"id_menu":2,"count":2}]	25130	pick-up	0	14
84428	2020-06-25 04:12:19	2020-06-25	14	[{"id_menu":2,"count":2}]	3935	delivery	5	19
84429	2020-06-25 04:12:29	2020-06-25	14	[{"id_menu":2,"count":1}]	33249	delivery	5	19
84430	2020-06-25 04:25:57	2020-06-25	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	33237	delivery	5	43
84431	2020-06-25 04:26:27	2020-06-25	9	[{"id_menu":7,"count":1}]	11124	pick-up	0	9
84432	2020-06-25 04:28:58	2020-06-25	8	[{"id_menu":5,"count":1}]	33088	delivery	5	13
84433	2020-06-25 04:31:16	2020-06-25	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	33262	delivery	5	28
84434	2020-06-25 04:38:18	2020-06-25	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	23590	delivery	5	28
84435	2020-06-25 04:42:28	2020-06-25	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	6941	pick-up	0	29
84436	2020-06-25 04:43:05	2020-06-25	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23041	delivery	5	35
84437	2020-06-25 04:47:43	2020-06-25	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	33254	pick-up	0	29
84438	2020-06-25 04:51:50	2020-06-25	9	[{"id_menu":7,"count":1}]	23544	delivery	5	14
84439	2020-06-25 04:51:57	2020-06-25	9	[{"id_menu":6,"count":2}]	3012	pick-up	0	9
84440	2020-06-25 04:54:23	2020-06-25	8	[{"id_menu":5,"count":1}]	33263	delivery	5	13
84441	2020-06-25 04:55:39	2020-06-25	9	[{"id_menu":7,"count":1}]	6842	pick-up	0	9
84442	2020-06-25 04:57:00	2020-06-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	33116	delivery	5	31
84443	2020-06-25 04:57:49	2020-06-25	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2929	delivery	5	45
84444	2020-06-25 05:02:12	2020-06-25	9	[{"id_menu":6,"count":1}]	33033	delivery	5	14
84445	2020-06-25 05:07:26	2020-06-25	14	[{"id_menu":2,"count":1}]	33027	pick-up	0	14
84446	2020-06-25 05:08:13	2020-06-25	12	[{"id_menu":1,"count":1}]	4090	pick-up	0	12
84447	2020-06-25 05:12:12	2020-06-25	14	[{"id_menu":2,"count":1}]	33078	delivery	5	19
84448	2020-06-25 05:14:28	2020-06-25	12	[{"id_menu":3,"count":1}]	33228	delivery	5	17
84449	2020-06-25 05:14:58	2020-06-25	9	[{"id_menu":7,"count":1}]	14239	pick-up	0	9
84450	2020-06-25 05:16:15	2020-06-25	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	33110	delivery	5	30
84451	2020-06-25 05:17:35	2020-06-25	9	[{"id_menu":6,"count":1}]	11822	delivery	5	14
84452	2020-06-25 05:17:55	2020-06-25	17	[{"id_menu":4,"count":1}]	17138	delivery	5	22
84453	2020-06-25 05:20:55	2020-06-25	14	[{"id_menu":2,"count":1}]	10655	delivery	5	19
84454	2020-06-25 05:21:32	2020-06-25	17	[{"id_menu":4,"count":1}]	33256	delivery	5	22
84455	2020-06-25 05:22:03	2020-06-25	9	[{"id_menu":7,"count":1}]	33239	delivery	5	14
84456	2020-06-25 05:30:27	2020-06-25	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	17501	pick-up	0	24
84457	2020-06-25 05:31:56	2020-06-25	14	[{"id_menu":2,"count":1}]	9103	delivery	5	19
84458	2020-06-25 05:32:44	2020-06-25	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	30216	delivery	5	40
84459	2020-06-25 05:36:14	2020-06-25	9	[{"id_menu":6,"count":1}]	25946	delivery	5	14
84460	2020-06-25 05:36:52	2020-06-25	14	[{"id_menu":2,"count":1}]	33221	delivery	5	19
84461	2020-06-25 05:38:43	2020-06-25	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	827	pick-up	0	20
84462	2020-06-25 05:39:06	2020-06-25	9	[{"id_menu":7,"count":1}]	10580	pick-up	0	9
84463	2020-06-25 05:39:49	2020-06-25	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	33094	delivery	5	46
84464	2020-06-25 05:45:05	2020-06-25	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	33080	delivery	5	43
84465	2020-06-25 05:46:56	2020-06-25	12	[{"id_menu":3,"count":1}]	31148	delivery	5	17
84466	2020-06-25 05:47:22	2020-06-25	14	[{"id_menu":2,"count":2}]	12663	pick-up	0	14
84467	2020-06-25 05:51:05	2020-06-25	17	[{"id_menu":4,"count":1}]	33186	delivery	5	22
84468	2020-06-25 06:04:58	2020-06-25	17	[{"id_menu":4,"count":1}]	7835	pick-up	0	17
84469	2020-06-25 06:05:41	2020-06-25	12	[{"id_menu":1,"count":1}]	25086	delivery	5	17
84470	2020-06-25 06:07:37	2020-06-25	17	[{"id_menu":4,"count":1}]	33184	delivery	5	22
84471	2020-06-25 06:09:16	2020-06-25	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	2178	delivery	5	29
84472	2020-06-25 06:11:07	2020-06-25	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	5292	pick-up	0	21
84473	2020-06-25 06:13:06	2020-06-25	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	21333	delivery	5	30
84474	2020-06-25 06:20:53	2020-06-25	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	15604	delivery	5	23
84475	2020-06-25 06:22:58	2020-06-25	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	33114	delivery	5	22
84476	2020-06-25 06:23:32	2020-06-25	8	[{"id_menu":5,"count":1}]	33053	delivery	5	13
84477	2020-06-25 06:25:21	2020-06-25	8	[{"id_menu":5,"count":1}]	33153	pick-up	0	8
84478	2020-06-25 06:27:41	2020-06-25	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	33175	delivery	5	38
84479	2020-06-25 06:29:50	2020-06-25	14	[{"id_menu":2,"count":1}]	24485	pick-up	0	14
84480	2020-06-25 06:32:53	2020-06-25	12	[{"id_menu":1,"count":1}]	33098	delivery	5	17
84481	2020-06-25 06:33:22	2020-06-25	14	[{"id_menu":2,"count":1}]	33104	delivery	5	19
84482	2020-06-25 06:35:31	2020-06-25	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26467	delivery	5	40
84483	2020-06-25 06:40:12	2020-06-25	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	33215	delivery	5	34
84484	2020-06-25 06:42:16	2020-06-25	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	33164	delivery	5	40
84485	2020-06-25 06:43:19	2020-06-25	12	[{"id_menu":1,"count":1}]	33195	delivery	5	17
84486	2020-06-25 06:45:15	2020-06-25	9	[{"id_menu":6,"count":1}]	33252	delivery	5	14
84487	2020-06-25 06:49:08	2020-06-25	8	[{"id_menu":5,"count":1}]	25535	delivery	5	13
84488	2020-06-25 06:52:29	2020-06-25	9	[{"id_menu":6,"count":2}]	20063	delivery	5	14
84489	2020-06-25 06:53:03	2020-06-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	19749	delivery	5	23
84490	2020-06-25 06:54:11	2020-06-25	12	[{"id_menu":1,"count":1}]	33044	delivery	5	17
84491	2020-06-25 06:57:18	2020-06-25	12	[{"id_menu":3,"count":1}]	12791	pick-up	0	12
84492	2020-06-25 06:58:35	2020-06-25	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	33137	delivery	5	39
84493	2020-06-25 06:59:11	2020-06-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20691	pick-up	0	17
84494	2020-06-25 06:59:47	2020-06-25	9	[{"id_menu":7,"count":1}]	19020	delivery	5	14
84495	2020-06-25 07:00:35	2020-06-25	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	32950	delivery	5	31
84496	2020-06-25 07:01:08	2020-06-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	33165	delivery	5	31
84497	2020-06-25 07:02:17	2020-06-25	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	33097	delivery	5	23
84498	2020-06-25 07:15:31	2020-06-25	17	[{"id_menu":4,"count":1}]	6928	delivery	5	22
84499	2020-06-25 07:16:21	2020-06-25	14	[{"id_menu":2,"count":1}]	1935	pick-up	0	14
84500	2020-06-25 07:18:39	2020-06-25	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	25116	delivery	5	30
84501	2020-06-25 07:21:23	2020-06-25	9	[{"id_menu":7,"count":2}]	4594	delivery	5	14
84502	2020-06-25 07:23:39	2020-06-25	12	[{"id_menu":1,"count":1}]	18098	delivery	5	17
84503	2020-06-25 07:24:01	2020-06-25	8	[{"id_menu":5,"count":1}]	33077	delivery	5	13
84504	2020-06-25 07:24:21	2020-06-25	12	[{"id_menu":1,"count":1}]	7200	pick-up	0	12
84505	2020-06-25 07:29:33	2020-06-25	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	510	pick-up	0	31
84506	2020-06-25 07:31:07	2020-06-25	12	[{"id_menu":1,"count":1}]	5094	pick-up	0	12
84507	2020-06-25 07:31:13	2020-06-25	9	[{"id_menu":6,"count":1}]	7361	pick-up	0	9
84508	2020-06-25 07:33:16	2020-06-25	17	[{"id_menu":4,"count":1}]	12849	delivery	5	22
84509	2020-06-25 07:34:37	2020-06-25	12	[{"id_menu":3,"count":1}]	28056	delivery	5	17
84510	2020-06-25 07:37:23	2020-06-25	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	23822	delivery	5	44
84511	2020-06-25 07:39:22	2020-06-25	9	[{"id_menu":6,"count":1}]	28335	delivery	5	14
84512	2020-06-25 07:41:11	2020-06-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	33212	delivery	5	28
84513	2020-06-25 07:41:29	2020-06-25	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	8983	delivery	5	27
84514	2020-06-25 07:48:42	2020-06-25	14	[{"id_menu":2,"count":1}]	33174	pick-up	0	14
84515	2020-06-25 07:51:12	2020-06-25	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	27964	delivery	5	27
84516	2020-06-25 08:00:10	2020-06-25	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	22529	delivery	5	27
84517	2020-06-25 08:00:19	2020-06-25	12	[{"id_menu":1,"count":1}]	33190	delivery	5	17
84518	2020-06-25 08:02:56	2020-06-25	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	32627	delivery	5	28
84519	2020-06-25 08:06:54	2020-06-25	17	[{"id_menu":4,"count":1}]	22777	delivery	5	22
84520	2020-06-25 08:07:06	2020-06-25	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	33039	delivery	5	26
84521	2020-06-25 08:08:05	2020-06-25	21	[{"id_menu":1,"count":3},{"id_menu":6,"count":1}]	6271	delivery	5	26
84522	2020-06-25 08:09:34	2020-06-25	12	[{"id_menu":1,"count":1}]	11503	delivery	5	17
84523	2020-06-25 08:09:42	2020-06-25	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33036	delivery	5	37
84524	2020-06-25 08:13:07	2020-06-25	9	[{"id_menu":7,"count":1}]	33255	delivery	5	14
84525	2020-06-25 08:15:00	2020-06-25	12	[{"id_menu":1,"count":1}]	27565	delivery	5	17
84526	2020-06-25 08:17:13	2020-06-25	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26187	delivery	5	37
84527	2020-06-25 08:19:28	2020-06-25	9	[{"id_menu":6,"count":1}]	2197	pick-up	0	9
84528	2020-06-25 08:21:20	2020-06-25	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":2}]	33063	delivery	5	26
84529	2020-06-25 08:25:47	2020-06-25	9	[{"id_menu":7,"count":1}]	14379	delivery	5	14
84530	2020-06-25 08:27:05	2020-06-25	9	[{"id_menu":6,"count":1}]	33099	pick-up	0	9
84531	2020-06-25 08:27:51	2020-06-25	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	12290	delivery	5	22
84532	2020-06-25 08:29:28	2020-06-25	9	[{"id_menu":7,"count":1}]	19566	delivery	5	14
84533	2020-06-25 08:29:48	2020-06-25	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	33028	delivery	5	28
84534	2020-06-25 08:32:55	2020-06-25	9	[{"id_menu":6,"count":1}]	100	pick-up	0	9
84535	2020-06-25 08:33:47	2020-06-25	9	[{"id_menu":6,"count":1}]	33054	delivery	5	14
84536	2020-06-25 08:34:30	2020-06-25	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2272	delivery	5	54
84537	2020-06-25 08:36:07	2020-06-25	9	[{"id_menu":6,"count":1}]	12551	delivery	5	14
84538	2020-06-25 08:37:53	2020-06-25	12	[{"id_menu":1,"count":1}]	26541	delivery	5	17
84539	2020-06-25 08:38:03	2020-06-25	14	[{"id_menu":2,"count":1}]	22977	delivery	5	19
84540	2020-06-25 08:38:08	2020-06-25	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	13187	delivery	5	26
84541	2020-06-25 08:42:26	2020-06-25	9	[{"id_menu":6,"count":1}]	4534	delivery	5	14
84542	2020-06-25 08:44:50	2020-06-25	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33224	delivery	5	31
84543	2020-06-25 08:46:06	2020-06-25	9	[{"id_menu":6,"count":1}]	12280	delivery	5	14
84544	2020-06-25 08:47:52	2020-06-25	12	[{"id_menu":1,"count":1}]	26836	delivery	5	17
84545	2020-06-25 08:50:00	2020-06-25	8	[{"id_menu":5,"count":1}]	31549	delivery	5	13
84546	2020-06-25 08:52:15	2020-06-25	9	[{"id_menu":7,"count":2}]	33127	delivery	5	14
84547	2020-06-25 08:59:04	2020-06-25	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	3871	pick-up	0	21
84548	2020-06-25 09:04:55	2020-06-25	9	[{"id_menu":6,"count":1}]	33134	delivery	5	14
84549	2020-06-25 09:09:40	2020-06-25	30	[{"id_menu":3,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33140	delivery	5	35
84550	2020-06-25 09:09:59	2020-06-25	12	[{"id_menu":1,"count":1}]	33136	delivery	5	17
84551	2020-06-25 09:10:05	2020-06-25	14	[{"id_menu":2,"count":1}]	7261	delivery	5	19
84552	2020-06-25 09:10:29	2020-06-25	12	[{"id_menu":1,"count":1}]	33166	delivery	5	17
84553	2020-06-25 09:15:43	2020-06-25	49	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	33071	delivery	5	54
84554	2020-06-25 09:17:13	2020-06-25	14	[{"id_menu":2,"count":1}]	27965	delivery	5	19
84555	2020-06-25 09:17:40	2020-06-25	14	[{"id_menu":2,"count":1}]	18170	pick-up	0	14
84556	2020-06-25 09:17:45	2020-06-25	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	17431	delivery	5	40
84557	2020-06-25 09:17:46	2020-06-25	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	22898	delivery	5	34
84558	2020-06-25 09:21:08	2020-06-25	14	[{"id_menu":2,"count":1}]	13731	pick-up	0	14
84559	2020-06-25 09:21:30	2020-06-25	9	[{"id_menu":7,"count":1}]	29471	delivery	5	14
84560	2020-06-25 09:24:14	2020-06-25	9	[{"id_menu":6,"count":1}]	33161	delivery	5	14
84561	2020-06-25 09:27:29	2020-06-25	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	30420	delivery	5	48
84562	2020-06-25 09:28:04	2020-06-25	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	33240	delivery	5	22
84563	2020-06-25 09:31:28	2020-06-25	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	27466	delivery	5	26
84564	2020-06-25 09:32:24	2020-06-25	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	15816	pick-up	0	31
84565	2020-06-25 09:33:37	2020-06-25	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	33144	delivery	5	36
84566	2020-06-25 09:34:40	2020-06-25	14	[{"id_menu":2,"count":1}]	2672	delivery	5	19
84567	2020-06-25 09:35:02	2020-06-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2399	pick-up	0	23
84568	2020-06-25 09:35:03	2020-06-25	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	33083	delivery	5	43
84569	2020-06-25 09:35:48	2020-06-25	14	[{"id_menu":2,"count":1}]	1720	pick-up	0	14
84570	2020-06-25 09:39:09	2020-06-25	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33031	delivery	5	43
84571	2020-06-25 09:42:39	2020-06-25	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	32270	delivery	5	48
84572	2020-06-25 09:46:58	2020-06-25	9	[{"id_menu":7,"count":1}]	24773	delivery	5	14
84573	2020-06-25 09:50:27	2020-06-25	14	[{"id_menu":2,"count":1}]	10142	delivery	5	19
84574	2020-06-25 09:51:36	2020-06-25	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	23229	delivery	5	26
84575	2020-06-25 09:53:51	2020-06-25	17	[{"id_menu":4,"count":1}]	33259	delivery	5	22
84576	2020-06-25 09:54:47	2020-06-25	14	[{"id_menu":2,"count":1}]	20882	delivery	5	19
84577	2020-06-25 09:57:45	2020-06-25	12	[{"id_menu":3,"count":1}]	19056	delivery	5	17
84578	2020-06-25 10:04:16	2020-06-25	14	[{"id_menu":2,"count":1}]	9859	pick-up	0	14
84579	2020-06-25 10:04:52	2020-06-25	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	13122	delivery	5	26
84580	2020-06-25 10:06:36	2020-06-25	17	[{"id_menu":4,"count":1}]	6790	pick-up	0	17
84581	2020-06-25 10:07:24	2020-06-25	9	[{"id_menu":7,"count":1}]	33191	delivery	5	14
84582	2020-06-25 10:07:29	2020-06-25	9	[{"id_menu":6,"count":1}]	718	delivery	5	14
84583	2020-06-25 10:08:41	2020-06-25	14	[{"id_menu":2,"count":1}]	788	pick-up	0	14
84584	2020-06-25 10:11:18	2020-06-25	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	29163	delivery	5	31
84585	2020-06-25 10:13:12	2020-06-25	12	[{"id_menu":1,"count":1}]	33040	delivery	5	17
84586	2020-06-25 10:13:22	2020-06-25	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	33163	delivery	5	39
84587	2020-06-25 10:13:32	2020-06-25	9	[{"id_menu":7,"count":1}]	466	delivery	5	14
84588	2020-06-25 10:14:08	2020-06-25	12	[{"id_menu":1,"count":2}]	11225	pick-up	0	12
84589	2020-06-25 10:18:04	2020-06-25	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	33148	delivery	5	46
84590	2020-06-25 10:19:14	2020-06-25	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15347	delivery	5	57
84591	2020-06-25 10:19:45	2020-06-25	9	[{"id_menu":6,"count":1}]	4176	delivery	5	14
84592	2020-06-25 10:23:15	2020-06-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	20145	delivery	5	31
84593	2020-06-25 10:23:43	2020-06-25	8	[{"id_menu":5,"count":1}]	27580	pick-up	0	8
84594	2020-06-25 10:24:00	2020-06-25	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	27927	delivery	5	34
84595	2020-06-25 10:24:53	2020-06-25	9	[{"id_menu":7,"count":1}]	2966	pick-up	0	9
84596	2020-06-25 10:26:07	2020-06-25	9	[{"id_menu":7,"count":2}]	33151	delivery	5	14
84597	2020-06-25 10:27:47	2020-06-25	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	19363	delivery	5	26
84598	2020-06-25 10:33:07	2020-06-25	17	[{"id_menu":4,"count":1}]	9026	delivery	5	22
84599	2020-06-25 10:37:09	2020-06-25	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	8341	pick-up	0	20
84600	2020-06-25 10:38:02	2020-06-25	17	[{"id_menu":4,"count":1}]	33198	delivery	5	22
84601	2020-06-25 10:44:13	2020-06-25	17	[{"id_menu":4,"count":1}]	1656	pick-up	0	17
84602	2020-06-25 10:46:53	2020-06-25	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	31172	delivery	5	36
84603	2020-06-25 10:51:44	2020-06-25	8	[{"id_menu":5,"count":1}]	12111	delivery	5	13
84604	2020-06-25 11:00:25	2020-06-25	9	[{"id_menu":6,"count":1}]	17742	delivery	5	14
84605	2020-06-25 11:01:19	2020-06-25	8	[{"id_menu":5,"count":1}]	26275	pick-up	0	8
84606	2020-06-25 11:03:42	2020-06-25	12	[{"id_menu":3,"count":1}]	9314	delivery	5	17
84607	2020-06-25 11:04:19	2020-06-25	8	[{"id_menu":5,"count":1}]	12364	delivery	5	13
84608	2020-06-25 11:05:32	2020-06-25	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":3}]	33192	delivery	5	26
84609	2020-06-25 11:06:01	2020-06-25	17	[{"id_menu":4,"count":1}]	31850	delivery	5	22
84610	2020-06-25 11:08:54	2020-06-25	12	[{"id_menu":1,"count":1}]	2161	pick-up	0	12
84611	2020-06-25 11:09:36	2020-06-25	9	[{"id_menu":7,"count":1}]	3864	pick-up	0	9
84612	2020-06-25 11:10:23	2020-06-25	17	[{"id_menu":4,"count":1}]	24462	delivery	5	22
84613	2020-06-25 11:15:32	2020-06-25	17	[{"id_menu":4,"count":1}]	351	pick-up	0	17
84614	2020-06-25 11:17:58	2020-06-25	17	[{"id_menu":4,"count":1}]	1020	delivery	5	22
84615	2020-06-25 11:18:29	2020-06-25	14	[{"id_menu":2,"count":1}]	33214	delivery	5	19
84616	2020-06-25 11:19:11	2020-06-25	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	33043	delivery	5	26
84617	2020-06-25 11:20:56	2020-06-25	12	[{"id_menu":1,"count":1}]	1435	pick-up	0	12
84618	2020-06-25 11:21:28	2020-06-25	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	33156	delivery	5	26
84619	2020-06-25 11:22:01	2020-06-25	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	33129	delivery	5	26
84620	2020-06-25 11:23:24	2020-06-25	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	33267	delivery	5	48
84621	2020-06-25 11:23:41	2020-06-25	8	[{"id_menu":5,"count":1}]	33081	delivery	5	13
84622	2020-06-25 11:30:40	2020-06-25	9	[{"id_menu":7,"count":1}]	8726	delivery	5	14
84623	2020-06-25 11:32:08	2020-06-25	9	[{"id_menu":7,"count":1}]	5687	pick-up	0	9
84624	2020-06-25 11:33:16	2020-06-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15183	delivery	5	23
84625	2020-06-25 11:33:56	2020-06-25	14	[{"id_menu":2,"count":1}]	24996	pick-up	0	14
84626	2020-06-25 11:34:30	2020-06-25	14	[{"id_menu":2,"count":1}]	2092	delivery	5	19
84627	2020-06-25 11:35:39	2020-06-25	9	[{"id_menu":7,"count":1}]	6182	pick-up	0	9
84628	2020-06-25 11:37:13	2020-06-25	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	33210	pick-up	0	25
84629	2020-06-25 11:39:54	2020-06-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	29922	delivery	5	31
84630	2020-06-25 11:39:59	2020-06-25	8	[{"id_menu":5,"count":2}]	33160	delivery	5	13
84631	2020-06-25 11:50:08	2020-06-25	12	[{"id_menu":3,"count":1}]	21357	pick-up	0	12
84632	2020-06-25 11:56:29	2020-06-25	9	[{"id_menu":7,"count":1}]	16056	delivery	5	14
84633	2020-06-25 12:00:45	2020-06-25	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	33117	delivery	5	56
84634	2020-06-25 12:02:01	2020-06-25	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16231	delivery	5	34
84635	2020-06-25 12:03:09	2020-06-25	14	[{"id_menu":2,"count":1}]	1393	delivery	5	19
84636	2020-06-25 12:03:14	2020-06-25	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	30251	delivery	5	39
84637	2020-06-25 12:10:03	2020-06-25	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	33142	delivery	5	40
84638	2020-06-25 12:13:02	2020-06-25	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13932	delivery	5	39
84639	2020-06-25 12:15:03	2020-06-25	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	2829	pick-up	0	24
84640	2020-06-25 12:21:15	2020-06-25	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	26919	delivery	5	39
84641	2020-06-25 12:21:17	2020-06-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	24396	pick-up	0	23
84642	2020-06-25 12:21:39	2020-06-25	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	29093	pick-up	0	23
84643	2020-06-25 12:23:37	2020-06-25	12	[{"id_menu":3,"count":1}]	33176	delivery	5	17
84644	2020-06-25 12:36:58	2020-06-25	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29849	delivery	5	52
84645	2020-06-25 12:38:33	2020-06-25	46	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	17248	delivery	5	51
84646	2020-06-25 12:41:04	2020-06-25	9	[{"id_menu":7,"count":1}]	33107	delivery	5	14
84647	2020-06-25 12:41:41	2020-06-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	33218	delivery	5	22
84648	2020-06-25 12:41:46	2020-06-25	17	[{"id_menu":4,"count":1}]	25279	pick-up	0	17
84649	2020-06-25 12:43:10	2020-06-25	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9321	delivery	5	48
84650	2020-06-25 12:43:58	2020-06-25	12	[{"id_menu":3,"count":2}]	10520	delivery	5	17
84651	2020-06-25 12:45:58	2020-06-25	17	[{"id_menu":4,"count":1}]	33122	delivery	5	22
84652	2020-06-25 12:47:15	2020-06-25	14	[{"id_menu":2,"count":1}]	9319	delivery	5	19
84653	2020-06-25 12:47:31	2020-06-25	8	[{"id_menu":5,"count":1}]	33208	delivery	5	13
84654	2020-06-25 12:51:11	2020-06-25	12	[{"id_menu":1,"count":1}]	2822	pick-up	0	12
84655	2020-06-25 12:56:58	2020-06-25	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	33118	delivery	5	31
84656	2020-06-25 12:57:44	2020-06-25	8	[{"id_menu":5,"count":1}]	31587	delivery	5	13
84657	2020-06-25 13:01:11	2020-06-25	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	17341	delivery	5	25
84658	2020-06-25 13:04:03	2020-06-25	17	[{"id_menu":4,"count":2}]	33112	pick-up	0	17
84659	2020-06-25 13:07:09	2020-06-25	9	[{"id_menu":6,"count":1}]	17210	delivery	5	14
84660	2020-06-25 13:07:14	2020-06-25	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	30154	pick-up	0	43
84661	2020-06-25 13:19:17	2020-06-25	17	[{"id_menu":4,"count":1}]	24332	delivery	5	22
84662	2020-06-25 13:21:07	2020-06-25	9	[{"id_menu":7,"count":1}]	21918	delivery	5	14
84663	2020-06-25 13:22:53	2020-06-25	9	[{"id_menu":7,"count":2}]	33146	delivery	5	14
84664	2020-06-25 13:24:30	2020-06-25	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8009	delivery	5	40
84665	2020-06-25 13:25:22	2020-06-25	9	[{"id_menu":7,"count":1}]	25685	delivery	5	14
84666	2020-06-25 13:29:16	2020-06-25	14	[{"id_menu":2,"count":1}]	4867	pick-up	0	14
84667	2020-06-25 13:31:02	2020-06-25	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	33204	delivery	5	45
84668	2020-06-25 13:31:44	2020-06-25	9	[{"id_menu":6,"count":1}]	2587	delivery	5	14
84669	2020-06-25 13:36:55	2020-06-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	33219	delivery	5	28
84670	2020-06-25 13:41:31	2020-06-25	14	[{"id_menu":2,"count":1}]	30519	pick-up	0	14
84671	2020-06-25 13:43:44	2020-06-25	9	[{"id_menu":6,"count":1}]	33257	delivery	5	14
84672	2020-06-25 13:45:09	2020-06-25	12	[{"id_menu":3,"count":1}]	33109	delivery	5	17
84673	2020-06-25 13:45:36	2020-06-25	17	[{"id_menu":4,"count":1}]	33095	pick-up	0	17
84674	2020-06-25 13:46:59	2020-06-25	12	[{"id_menu":1,"count":1}]	26970	pick-up	0	12
84675	2020-06-25 13:48:45	2020-06-25	14	[{"id_menu":2,"count":1}]	78	pick-up	0	14
84676	2020-06-25 13:53:23	2020-06-25	9	[{"id_menu":6,"count":1}]	14564	delivery	5	14
84677	2020-06-25 13:55:11	2020-06-25	12	[{"id_menu":1,"count":1}]	28431	delivery	5	17
84678	2020-06-25 13:58:42	2020-06-25	9	[{"id_menu":6,"count":1}]	7227	delivery	5	14
84679	2020-06-25 13:59:26	2020-06-25	8	[{"id_menu":5,"count":1}]	16018	pick-up	0	8
84680	2020-06-25 14:00:12	2020-06-25	8	[{"id_menu":5,"count":1}]	33180	pick-up	0	8
84681	2020-06-25 14:01:05	2020-06-25	9	[{"id_menu":6,"count":1}]	26523	delivery	5	14
84682	2020-06-25 14:04:18	2020-06-25	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	11732	pick-up	0	26
84683	2020-06-25 14:05:52	2020-06-25	9	[{"id_menu":6,"count":1}]	33135	delivery	5	14
84684	2020-06-25 14:06:01	2020-06-25	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	30790	delivery	5	34
84685	2020-06-25 14:06:37	2020-06-25	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	13942	delivery	5	36
84686	2020-06-25 14:10:02	2020-06-25	9	[{"id_menu":7,"count":1}]	33101	delivery	5	14
84687	2020-06-25 14:11:57	2020-06-25	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5467	delivery	5	31
84688	2020-06-25 14:12:39	2020-06-25	9	[{"id_menu":7,"count":1}]	7008	pick-up	0	9
84689	2020-06-25 14:18:05	2020-06-25	9	[{"id_menu":7,"count":1}]	4695	delivery	5	14
84690	2020-06-25 14:18:11	2020-06-25	8	[{"id_menu":5,"count":1}]	13713	delivery	5	13
84691	2020-06-25 14:20:17	2020-06-25	9	[{"id_menu":7,"count":2}]	18222	delivery	5	14
84692	2020-06-25 14:25:11	2020-06-25	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	33045	delivery	5	35
84693	2020-06-25 14:26:07	2020-06-25	8	[{"id_menu":5,"count":1}]	30626	delivery	5	13
84694	2020-06-25 14:26:10	2020-06-25	12	[{"id_menu":1,"count":2}]	22847	pick-up	0	12
84695	2020-06-25 14:27:59	2020-06-25	8	[{"id_menu":5,"count":1}]	15776	delivery	5	13
84696	2020-06-25 14:37:09	2020-06-25	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	33243	delivery	5	25
84697	2020-06-25 14:40:06	2020-06-25	14	[{"id_menu":2,"count":1}]	12643	delivery	5	19
84698	2020-06-25 14:45:39	2020-06-25	9	[{"id_menu":7,"count":1}]	33173	delivery	5	14
84699	2020-06-25 14:46:09	2020-06-25	17	[{"id_menu":4,"count":1}]	1973	pick-up	0	17
84700	2020-06-25 14:48:07	2020-06-25	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	33172	delivery	5	45
84701	2020-06-25 14:48:57	2020-06-25	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2715	delivery	5	27
84702	2020-06-25 14:49:20	2020-06-25	9	[{"id_menu":6,"count":1}]	5946	delivery	5	14
84703	2020-06-25 14:51:40	2020-06-25	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	33032	delivery	5	25
84704	2020-06-25 14:51:49	2020-06-25	8	[{"id_menu":5,"count":1}]	5306	pick-up	0	8
84705	2020-06-25 14:53:19	2020-06-25	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	32515	delivery	5	38
84706	2020-06-25 14:55:49	2020-06-25	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	26581	delivery	5	34
84707	2020-06-25 14:57:57	2020-06-25	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":3}]	33065	delivery	5	26
84708	2020-06-25 14:59:44	2020-06-25	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16290	delivery	5	39
84709	2020-06-25 15:00:43	2020-06-25	8	[{"id_menu":5,"count":2}]	33197	delivery	5	13
84710	2020-06-25 15:00:48	2020-06-25	12	[{"id_menu":1,"count":1}]	13994	delivery	5	17
84711	2020-06-25 15:04:03	2020-06-25	12	[{"id_menu":1,"count":1}]	10050	pick-up	0	12
84712	2020-06-25 15:04:04	2020-06-25	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	30732	delivery	5	45
84713	2020-06-25 15:04:04	2020-06-25	14	[{"id_menu":2,"count":1}]	13768	delivery	5	19
84781	2020-06-25 18:08:09	2020-06-25	17	[{"id_menu":4,"count":1}]	6675	delivery	5	22
84714	2020-06-25 15:04:29	2020-06-25	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	31157	delivery	5	45
84715	2020-06-25 15:05:46	2020-06-25	12	[{"id_menu":1,"count":1}]	33131	delivery	5	17
84716	2020-06-25 15:06:38	2020-06-25	14	[{"id_menu":2,"count":2}]	4207	pick-up	0	14
84717	2020-06-25 15:08:59	2020-06-25	8	[{"id_menu":5,"count":1}]	33073	delivery	5	13
84718	2020-06-25 15:11:21	2020-06-25	12	[{"id_menu":3,"count":1}]	11714	pick-up	0	12
84719	2020-06-25 15:15:18	2020-06-25	9	[{"id_menu":6,"count":1}]	126	pick-up	0	9
84720	2020-06-25 15:20:29	2020-06-25	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3850	delivery	5	45
84721	2020-06-25 15:27:43	2020-06-25	9	[{"id_menu":6,"count":1}]	33162	delivery	5	14
84722	2020-06-25 15:30:50	2020-06-25	12	[{"id_menu":1,"count":1}]	1467	delivery	5	17
84723	2020-06-25 15:31:47	2020-06-25	14	[{"id_menu":2,"count":1}]	33199	delivery	5	19
84724	2020-06-25 15:34:20	2020-06-25	9	[{"id_menu":6,"count":1}]	33064	delivery	5	14
84725	2020-06-25 15:35:40	2020-06-25	12	[{"id_menu":3,"count":1}]	8148	delivery	5	17
84726	2020-06-25 15:37:35	2020-06-25	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	14290	pick-up	0	31
84727	2020-06-25 15:40:21	2020-06-25	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	33155	delivery	5	38
84728	2020-06-25 15:40:22	2020-06-25	14	[{"id_menu":2,"count":2}]	33196	pick-up	0	14
84729	2020-06-25 15:41:28	2020-06-25	8	[{"id_menu":5,"count":1}]	33271	delivery	5	13
84730	2020-06-25 15:42:24	2020-06-25	14	[{"id_menu":2,"count":1}]	33217	delivery	5	19
84731	2020-06-25 15:42:40	2020-06-25	9	[{"id_menu":7,"count":1}]	23322	delivery	5	14
84732	2020-06-25 15:43:52	2020-06-25	9	[{"id_menu":6,"count":1}]	8443	delivery	5	14
84733	2020-06-25 15:45:42	2020-06-25	9	[{"id_menu":7,"count":1}]	8860	delivery	5	14
84734	2020-06-25 15:47:49	2020-06-25	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	17164	delivery	5	25
84735	2020-06-25 15:53:50	2020-06-25	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	11761	delivery	5	22
84736	2020-06-25 15:58:47	2020-06-25	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	10632	pick-up	0	24
84737	2020-06-25 16:01:38	2020-06-25	17	[{"id_menu":4,"count":1}]	10194	pick-up	0	17
84738	2020-06-25 16:02:56	2020-06-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1021	delivery	5	28
84739	2020-06-25 16:05:19	2020-06-25	17	[{"id_menu":4,"count":1}]	4192	delivery	5	22
84740	2020-06-25 16:06:29	2020-06-25	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	31267	pick-up	0	43
84741	2020-06-25 16:09:13	2020-06-25	9	[{"id_menu":7,"count":1}]	1258	pick-up	0	9
84742	2020-06-25 16:09:38	2020-06-25	9	[{"id_menu":6,"count":2}]	17209	delivery	5	14
84743	2020-06-25 16:11:55	2020-06-25	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	33167	delivery	5	30
84744	2020-06-25 16:12:22	2020-06-25	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	33245	delivery	5	31
84745	2020-06-25 16:13:29	2020-06-25	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	25615	delivery	5	36
84746	2020-06-25 16:14:39	2020-06-25	9	[{"id_menu":6,"count":1}]	33091	delivery	5	14
84747	2020-06-25 16:15:06	2020-06-25	9	[{"id_menu":6,"count":1}]	13199	pick-up	0	9
84748	2020-06-25 16:15:43	2020-06-25	8	[{"id_menu":5,"count":1}]	14903	pick-up	0	8
84749	2020-06-25 16:18:07	2020-06-25	17	[{"id_menu":4,"count":1}]	33106	delivery	5	22
84750	2020-06-25 16:24:10	2020-06-25	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	33251	delivery	5	39
84751	2020-06-25 16:30:22	2020-06-25	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	33201	delivery	5	31
84752	2020-06-25 16:31:56	2020-06-25	14	[{"id_menu":2,"count":1}]	29695	delivery	5	19
84753	2020-06-25 16:34:09	2020-06-25	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	27623	delivery	5	30
84754	2020-06-25 16:34:11	2020-06-25	12	[{"id_menu":1,"count":2}]	10676	delivery	5	17
84755	2020-06-25 16:37:23	2020-06-25	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	28261	delivery	5	34
84756	2020-06-25 16:38:00	2020-06-25	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	23682	delivery	5	43
84757	2020-06-25 16:39:29	2020-06-25	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1120	delivery	5	26
84758	2020-06-25 16:41:49	2020-06-25	8	[{"id_menu":5,"count":1}]	341	delivery	5	13
84759	2020-06-25 16:46:39	2020-06-25	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7390	delivery	5	31
84760	2020-06-25 16:48:10	2020-06-25	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7158	delivery	5	36
84761	2020-06-25 16:48:35	2020-06-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	19712	delivery	5	23
84762	2020-06-25 16:51:27	2020-06-25	14	[{"id_menu":2,"count":1}]	5325	delivery	5	19
84763	2020-06-25 16:53:11	2020-06-25	9	[{"id_menu":6,"count":1}]	22478	delivery	5	14
84764	2020-06-25 16:55:56	2020-06-25	17	[{"id_menu":4,"count":1}]	33066	delivery	5	22
84765	2020-06-25 16:56:54	2020-06-25	9	[{"id_menu":6,"count":1}]	33130	delivery	5	14
84766	2020-06-25 17:01:55	2020-06-25	8	[{"id_menu":5,"count":1}]	33096	delivery	5	13
84767	2020-06-25 17:10:03	2020-06-25	9	[{"id_menu":7,"count":1}]	1568	pick-up	0	9
84768	2020-06-25 17:15:33	2020-06-25	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	227	pick-up	0	29
84769	2020-06-25 17:35:42	2020-06-25	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	33253	delivery	5	43
84770	2020-06-25 17:38:15	2020-06-25	8	[{"id_menu":5,"count":1}]	33133	delivery	5	13
84771	2020-06-25 17:41:00	2020-06-25	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	27944	delivery	5	27
84772	2020-06-25 17:41:26	2020-06-25	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	27410	delivery	5	31
84773	2020-06-25 17:41:55	2020-06-25	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	33026	delivery	5	37
84774	2020-06-25 17:47:28	2020-06-25	17	[{"id_menu":4,"count":1}]	22209	delivery	5	22
84775	2020-06-25 17:49:51	2020-06-25	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":2}]	33048	delivery	5	22
84776	2020-06-25 17:53:56	2020-06-25	9	[{"id_menu":7,"count":1}]	18343	delivery	5	14
84777	2020-06-25 17:59:11	2020-06-25	12	[{"id_menu":1,"count":1}]	33268	delivery	5	17
84778	2020-06-25 18:01:24	2020-06-25	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	21896	delivery	5	29
84779	2020-06-25 18:03:45	2020-06-25	17	[{"id_menu":4,"count":1}]	10281	pick-up	0	17
84780	2020-06-25 18:04:22	2020-06-25	8	[{"id_menu":5,"count":1}]	19627	delivery	5	13
84782	2020-06-25 18:09:24	2020-06-25	9	[{"id_menu":7,"count":1}]	5561	delivery	5	14
84783	2020-06-25 18:09:26	2020-06-25	17	[{"id_menu":4,"count":2}]	23876	delivery	5	22
84784	2020-06-25 18:13:57	2020-06-25	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	11789	delivery	5	42
84785	2020-06-25 18:15:35	2020-06-25	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	28628	pick-up	0	40
84786	2020-06-25 18:19:02	2020-06-25	8	[{"id_menu":5,"count":1}]	4035	delivery	5	13
84787	2020-06-25 18:19:20	2020-06-25	9	[{"id_menu":7,"count":1}]	33092	delivery	5	14
84788	2020-06-25 18:20:47	2020-06-25	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6152	delivery	5	36
84789	2020-06-25 18:21:23	2020-06-25	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	30126	delivery	5	45
84790	2020-06-25 18:24:36	2020-06-25	14	[{"id_menu":2,"count":1}]	3617	pick-up	0	14
84791	2020-06-25 18:29:47	2020-06-25	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7598	delivery	5	40
84792	2020-06-25 18:31:14	2020-06-25	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	6248	pick-up	0	22
84793	2020-06-25 18:35:03	2020-06-25	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	25115	delivery	5	40
84794	2020-06-25 18:35:17	2020-06-25	14	[{"id_menu":2,"count":1}]	33056	delivery	5	19
84795	2020-06-25 18:35:56	2020-06-25	12	[{"id_menu":3,"count":1}]	33157	delivery	5	17
84796	2020-06-25 18:36:18	2020-06-25	12	[{"id_menu":1,"count":1}]	27411	delivery	5	17
84797	2020-06-25 18:36:55	2020-06-25	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	33150	delivery	5	45
84798	2020-06-25 18:38:14	2020-06-25	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	33025	delivery	5	38
84799	2020-06-25 18:39:23	2020-06-25	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	33105	delivery	5	30
84800	2020-06-25 18:42:03	2020-06-25	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	31013	delivery	5	40
84801	2020-06-25 18:42:59	2020-06-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17085	delivery	5	22
84802	2020-06-25 18:43:08	2020-06-25	8	[{"id_menu":5,"count":1}]	33193	delivery	5	13
84803	2020-06-25 18:44:45	2020-06-25	14	[{"id_menu":2,"count":1}]	3854	delivery	5	19
84804	2020-06-25 18:45:35	2020-06-25	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	33075	delivery	5	34
84805	2020-06-25 18:45:53	2020-06-25	17	[{"id_menu":4,"count":1}]	2446	pick-up	0	17
84806	2020-06-25 18:47:14	2020-06-25	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	33087	delivery	5	25
84807	2020-06-25 18:47:42	2020-06-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	16025	delivery	5	28
84808	2020-06-25 18:50:31	2020-06-25	14	[{"id_menu":2,"count":1}]	9043	pick-up	0	14
84809	2020-06-25 18:52:09	2020-06-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9701	delivery	5	28
84810	2020-06-25 18:52:21	2020-06-25	14	[{"id_menu":2,"count":1}]	30401	delivery	5	19
84811	2020-06-25 18:52:23	2020-06-25	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	33209	delivery	5	22
84812	2020-06-25 18:52:27	2020-06-25	9	[{"id_menu":6,"count":1}]	10802	delivery	5	14
84813	2020-06-25 18:53:39	2020-06-25	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	12673	delivery	5	31
84814	2020-06-25 18:56:45	2020-06-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	33171	delivery	5	22
84815	2020-06-25 18:57:26	2020-06-25	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22649	delivery	5	53
84816	2020-06-25 18:59:34	2020-06-25	12	[{"id_menu":1,"count":1}]	10433	delivery	5	17
84817	2020-06-25 19:02:31	2020-06-25	9	[{"id_menu":6,"count":1}]	22149	delivery	5	14
84818	2020-06-25 19:09:10	2020-06-25	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	33170	delivery	5	28
84819	2020-06-25 19:10:40	2020-06-25	14	[{"id_menu":2,"count":1}]	6787	delivery	5	19
84820	2020-06-25 19:10:44	2020-06-25	9	[{"id_menu":6,"count":1}]	30625	delivery	5	14
84821	2020-06-25 19:11:03	2020-06-25	12	[{"id_menu":1,"count":1}]	21887	delivery	5	17
84822	2020-06-25 19:11:28	2020-06-25	8	[{"id_menu":5,"count":1}]	18979	delivery	5	13
84823	2020-06-25 19:11:53	2020-06-25	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	27881	delivery	5	43
84824	2020-06-25 19:17:48	2020-06-25	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	25577	delivery	5	42
84825	2020-06-25 19:20:38	2020-06-25	9	[{"id_menu":6,"count":1}]	11757	delivery	5	14
84826	2020-06-25 19:22:47	2020-06-25	17	[{"id_menu":4,"count":1}]	23661	pick-up	0	17
84827	2020-06-25 19:25:54	2020-06-25	9	[{"id_menu":7,"count":1}]	16810	pick-up	0	9
84828	2020-06-25 19:26:26	2020-06-25	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9578	delivery	5	48
84829	2020-06-25 19:29:46	2020-06-25	12	[{"id_menu":3,"count":1}]	13242	delivery	5	17
84830	2020-06-25 19:29:48	2020-06-25	9	[{"id_menu":7,"count":1}]	29557	delivery	5	14
84831	2020-06-25 19:29:56	2020-06-25	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	33182	delivery	5	26
84832	2020-06-25 19:35:27	2020-06-25	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	12205	pick-up	0	20
84833	2020-06-25 19:36:19	2020-06-25	9	[{"id_menu":7,"count":1}]	9507	delivery	5	14
84834	2020-06-25 19:36:53	2020-06-25	14	[{"id_menu":2,"count":1}]	33213	delivery	5	19
84835	2020-06-25 19:41:03	2020-06-25	14	[{"id_menu":2,"count":1}]	33047	delivery	5	19
84836	2020-06-25 19:41:40	2020-06-25	9	[{"id_menu":7,"count":1}]	31201	delivery	5	14
84837	2020-06-25 19:48:36	2020-06-25	9	[{"id_menu":6,"count":3}]	11735	delivery	5	14
84838	2020-06-25 19:58:01	2020-06-25	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	33194	delivery	5	36
84839	2020-06-25 20:01:30	2020-06-25	9	[{"id_menu":6,"count":1}]	987	pick-up	0	9
84840	2020-06-25 20:02:26	2020-06-25	8	[{"id_menu":5,"count":1}]	9278	delivery	5	13
84841	2020-06-25 20:05:05	2020-06-25	9	[{"id_menu":7,"count":1}]	10452	pick-up	0	9
84842	2020-06-25 20:07:18	2020-06-25	9	[{"id_menu":7,"count":1}]	1762	delivery	5	14
84843	2020-06-25 20:12:29	2020-06-25	12	[{"id_menu":3,"count":1}]	33241	pick-up	0	12
84844	2020-06-25 20:14:14	2020-06-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33248	delivery	5	23
84845	2020-06-25 20:15:17	2020-06-25	14	[{"id_menu":2,"count":2}]	14250	pick-up	0	14
84846	2020-06-25 20:15:40	2020-06-25	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	28393	delivery	5	40
84847	2020-06-25 20:17:49	2020-06-25	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	753	delivery	5	29
84848	2020-06-25 20:17:52	2020-06-25	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	33072	delivery	5	28
84849	2020-06-25 20:18:44	2020-06-25	9	[{"id_menu":7,"count":1}]	4890	delivery	5	14
84850	2020-06-25 20:21:19	2020-06-25	9	[{"id_menu":7,"count":1}]	33235	pick-up	0	9
84851	2020-06-25 20:22:26	2020-06-25	14	[{"id_menu":2,"count":1}]	12457	delivery	5	19
84852	2020-06-25 20:24:10	2020-06-25	9	[{"id_menu":7,"count":1}]	3180	delivery	5	14
84853	2020-06-25 20:30:06	2020-06-25	9	[{"id_menu":7,"count":1}]	14894	delivery	5	14
84854	2020-06-25 20:30:43	2020-06-25	9	[{"id_menu":6,"count":1}]	8054	delivery	5	14
84855	2020-06-25 20:32:38	2020-06-25	12	[{"id_menu":3,"count":1}]	6965	delivery	5	17
84856	2020-06-25 20:35:05	2020-06-25	14	[{"id_menu":2,"count":1}]	33220	pick-up	0	14
84857	2020-06-25 20:35:18	2020-06-25	17	[{"id_menu":4,"count":1}]	23890	pick-up	0	17
84858	2020-06-25 20:35:45	2020-06-25	9	[{"id_menu":6,"count":3}]	33187	delivery	5	14
84859	2020-06-25 20:42:21	2020-06-25	12	[{"id_menu":1,"count":1}]	3701	pick-up	0	12
84860	2020-06-25 20:46:23	2020-06-25	12	[{"id_menu":1,"count":1}]	16217	pick-up	0	12
84861	2020-06-25 20:58:27	2020-06-25	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	33181	delivery	5	36
84862	2020-06-25 20:59:59	2020-06-25	12	[{"id_menu":3,"count":1}]	2351	pick-up	0	12
84863	2020-06-25 21:00:15	2020-06-25	9	[{"id_menu":7,"count":1}]	33029	pick-up	0	9
84864	2020-06-25 21:00:36	2020-06-25	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	29107	delivery	5	26
84865	2020-06-25 21:04:58	2020-06-25	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1309	pick-up	0	35
84866	2020-06-25 21:05:13	2020-06-25	17	[{"id_menu":4,"count":1}]	9508	delivery	5	22
84867	2020-06-25 21:05:36	2020-06-25	9	[{"id_menu":7,"count":1}]	26891	pick-up	0	9
84868	2020-06-25 21:06:14	2020-06-25	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8448	pick-up	0	29
84869	2020-06-25 21:07:55	2020-06-25	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	8349	delivery	5	39
84870	2020-06-25 21:09:49	2020-06-25	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	29683	delivery	5	26
84871	2020-06-25 21:11:13	2020-06-25	9	[{"id_menu":7,"count":1}]	25852	delivery	5	14
84872	2020-06-25 21:12:39	2020-06-25	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	33147	delivery	5	39
84873	2020-06-25 21:12:44	2020-06-25	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	33227	delivery	5	45
84874	2020-06-25 21:26:46	2020-06-25	14	[{"id_menu":2,"count":1}]	33067	delivery	5	19
84875	2020-06-25 21:27:15	2020-06-25	12	[{"id_menu":3,"count":1}]	7387	delivery	5	17
84876	2020-06-25 21:31:14	2020-06-25	9	[{"id_menu":6,"count":1}]	8873	delivery	5	14
84877	2020-06-25 21:32:02	2020-06-25	17	[{"id_menu":4,"count":1}]	20754	pick-up	0	17
84878	2020-06-25 21:32:14	2020-06-25	9	[{"id_menu":6,"count":2}]	15350	delivery	5	14
84879	2020-06-25 21:34:05	2020-06-25	12	[{"id_menu":1,"count":1}]	33250	delivery	5	17
84880	2020-06-25 21:35:08	2020-06-25	9	[{"id_menu":7,"count":1}]	7174	delivery	5	14
84881	2020-06-25 21:35:33	2020-06-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	33258	delivery	5	28
84882	2020-06-25 21:38:21	2020-06-25	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	20566	delivery	5	43
84883	2020-06-25 21:40:23	2020-06-25	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	19773	delivery	5	43
84884	2020-06-25 21:40:26	2020-06-25	14	[{"id_menu":2,"count":1}]	7710	pick-up	0	14
84885	2020-06-25 21:43:38	2020-06-25	9	[{"id_menu":6,"count":1}]	33244	delivery	5	14
84886	2020-06-25 21:49:36	2020-06-25	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2442	pick-up	0	26
84887	2020-06-25 21:53:21	2020-06-25	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	33229	delivery	5	23
84888	2020-06-25 21:54:20	2020-06-25	8	[{"id_menu":5,"count":1}]	33070	delivery	5	13
84889	2020-06-25 21:55:00	2020-06-25	12	[{"id_menu":3,"count":1}]	15281	delivery	5	17
84890	2020-06-25 21:57:58	2020-06-25	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	33055	delivery	5	40
84891	2020-06-25 22:08:46	2020-06-25	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2860	pick-up	0	25
84892	2020-06-25 22:10:35	2020-06-25	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	33049	delivery	5	26
84893	2020-06-25 22:12:02	2020-06-25	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	16880	delivery	5	28
84894	2020-06-25 22:12:39	2020-06-25	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3870	pick-up	0	21
84895	2020-06-25 22:14:12	2020-06-25	12	[{"id_menu":3,"count":1}]	16550	pick-up	0	12
84896	2020-06-25 22:15:24	2020-06-25	8	[{"id_menu":5,"count":1}]	30390	delivery	5	13
84897	2020-06-25 22:20:56	2020-06-25	9	[{"id_menu":6,"count":1}]	8799	pick-up	0	9
84898	2020-06-25 22:21:38	2020-06-25	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	21848	delivery	5	28
84899	2020-06-25 22:25:44	2020-06-25	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	6277	delivery	5	48
84900	2020-06-25 22:25:52	2020-06-25	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	32720	pick-up	0	23
84901	2020-06-25 22:26:14	2020-06-25	9	[{"id_menu":6,"count":2}]	28799	delivery	5	14
84902	2020-06-25 22:31:44	2020-06-25	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	13922	delivery	5	31
84903	2020-06-25 22:32:58	2020-06-25	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	33084	delivery	5	38
84904	2020-06-25 22:33:14	2020-06-25	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	29226	delivery	5	26
84905	2020-06-25 22:37:02	2020-06-25	8	[{"id_menu":5,"count":1}]	31766	delivery	5	13
84906	2020-06-25 22:37:08	2020-06-25	9	[{"id_menu":7,"count":1}]	33074	delivery	5	14
84907	2020-06-25 22:38:02	2020-06-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15683	pick-up	0	26
84908	2020-06-25 22:43:44	2020-06-25	9	[{"id_menu":7,"count":1}]	1097	pick-up	0	9
84909	2020-06-25 22:47:18	2020-06-25	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	33058	delivery	5	26
84910	2020-06-25 22:51:22	2020-06-25	14	[{"id_menu":2,"count":1}]	20496	delivery	5	19
84911	2020-06-25 22:51:44	2020-06-25	9	[{"id_menu":7,"count":1}]	10514	delivery	5	14
84912	2020-06-25 22:52:16	2020-06-25	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	33103	delivery	5	27
84913	2020-06-25 22:59:08	2020-06-25	12	[{"id_menu":1,"count":1}]	8757	pick-up	0	12
84914	2020-06-25 23:00:15	2020-06-25	14	[{"id_menu":2,"count":1}]	8900	pick-up	0	14
84915	2020-06-25 23:02:12	2020-06-25	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	33247	delivery	5	26
84916	2020-06-25 23:04:41	2020-06-25	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	33246	delivery	5	36
84917	2020-06-25 23:05:41	2020-06-25	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	7734	delivery	5	52
84918	2020-06-25 23:12:41	2020-06-25	9	[{"id_menu":6,"count":1}]	4060	delivery	5	14
84919	2020-06-25 23:18:19	2020-06-25	12	[{"id_menu":1,"count":1}]	11730	delivery	5	17
84920	2020-06-25 23:21:51	2020-06-25	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	22035	delivery	5	36
84921	2020-06-25 23:25:03	2020-06-25	9	[{"id_menu":7,"count":1}]	9312	delivery	5	14
84922	2020-06-25 23:26:31	2020-06-25	14	[{"id_menu":2,"count":1}]	33265	pick-up	0	14
84923	2020-06-25 23:28:36	2020-06-25	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	33149	delivery	5	43
84924	2020-06-25 23:30:33	2020-06-25	12	[{"id_menu":3,"count":1}]	2591	delivery	5	17
84925	2020-06-25 23:31:25	2020-06-25	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	33139	delivery	5	34
84926	2020-06-25 23:32:08	2020-06-25	12	[{"id_menu":3,"count":1}]	16926	delivery	5	17
84927	2020-06-25 23:34:33	2020-06-25	14	[{"id_menu":2,"count":1}]	25548	pick-up	0	14
84928	2020-06-25 23:34:47	2020-06-25	8	[{"id_menu":5,"count":1}]	26526	pick-up	0	8
84929	2020-06-25 23:36:19	2020-06-25	9	[{"id_menu":7,"count":1}]	14190	pick-up	0	9
84930	2020-06-25 23:37:50	2020-06-25	8	[{"id_menu":5,"count":1}]	33225	delivery	5	13
84931	2020-06-25 23:38:42	2020-06-25	12	[{"id_menu":1,"count":1}]	16774	delivery	5	17
84932	2020-06-25 23:38:43	2020-06-25	9	[{"id_menu":7,"count":2}]	1481	delivery	5	14
84933	2020-06-25 23:39:34	2020-06-25	8	[{"id_menu":5,"count":1}]	28283	pick-up	0	8
84934	2020-06-25 23:40:30	2020-06-25	14	[{"id_menu":2,"count":1}]	33205	delivery	5	19
84935	2020-06-25 23:45:40	2020-06-25	12	[{"id_menu":1,"count":1}]	28125	delivery	5	17
84936	2020-06-25 23:45:42	2020-06-25	9	[{"id_menu":6,"count":1}]	4920	pick-up	0	9
84937	2020-06-25 23:45:44	2020-06-25	8	[{"id_menu":5,"count":1}]	19664	pick-up	0	8
84938	2020-06-25 23:46:04	2020-06-25	9	[{"id_menu":7,"count":1}]	24767	pick-up	0	9
84939	2020-06-25 23:47:28	2020-06-25	12	[{"id_menu":3,"count":1}]	6530	delivery	5	17
84940	2020-06-25 23:47:42	2020-06-25	17	[{"id_menu":4,"count":1}]	1409	pick-up	0	17
84941	2020-06-25 23:48:12	2020-06-25	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	33189	delivery	5	36
84942	2020-06-25 23:49:30	2020-06-25	9	[{"id_menu":6,"count":1}]	33125	delivery	5	14
84943	2020-06-25 23:53:11	2020-06-25	9	[{"id_menu":6,"count":1}]	2333	delivery	5	14
84944	2020-06-25 23:53:12	2020-06-25	12	[{"id_menu":1,"count":1}]	4684	pick-up	0	12
84945	2020-06-25 23:53:57	2020-06-25	12	[{"id_menu":1,"count":1}]	22942	delivery	5	17
84946	2020-06-25 23:57:57	2020-06-25	14	[{"id_menu":2,"count":1}]	26186	delivery	5	19
84947	2020-06-25 23:59:58	2020-06-25	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6113	delivery	5	45
84948	2020-06-26 00:01:45	2020-06-26	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20749	delivery	5	35
84949	2020-06-26 00:02:28	2020-06-26	14	[{"id_menu":2,"count":1}]	6243	pick-up	0	14
84950	2020-06-26 00:05:59	2020-06-26	14	[{"id_menu":2,"count":1}]	33389	pick-up	0	14
84951	2020-06-26 00:12:51	2020-06-26	9	[{"id_menu":6,"count":1}]	4747	delivery	5	14
84952	2020-06-26 00:25:11	2020-06-26	8	[{"id_menu":5,"count":1}]	20222	delivery	5	13
84953	2020-06-26 00:28:13	2020-06-26	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8061	delivery	5	31
84954	2020-06-26 00:32:33	2020-06-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	11413	delivery	5	28
84955	2020-06-26 00:38:52	2020-06-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	33435	delivery	5	28
84956	2020-06-26 00:44:24	2020-06-26	9	[{"id_menu":6,"count":1}]	33279	delivery	5	14
84957	2020-06-26 00:46:00	2020-06-26	9	[{"id_menu":7,"count":1}]	13094	delivery	5	14
84958	2020-06-26 00:49:28	2020-06-26	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	3604	pick-up	0	29
84959	2020-06-26 00:51:50	2020-06-26	8	[{"id_menu":5,"count":1}]	33302	delivery	5	13
84960	2020-06-26 00:54:34	2020-06-26	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	19612	delivery	5	40
84961	2020-06-26 00:59:50	2020-06-26	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	23093	delivery	5	31
84962	2020-06-26 01:01:00	2020-06-26	12	[{"id_menu":3,"count":1}]	31661	delivery	5	17
84963	2020-06-26 01:05:29	2020-06-26	9	[{"id_menu":6,"count":1}]	23321	delivery	5	14
84964	2020-06-26 01:07:23	2020-06-26	8	[{"id_menu":5,"count":1}]	5840	delivery	5	13
84965	2020-06-26 01:11:15	2020-06-26	12	[{"id_menu":3,"count":1}]	27703	delivery	5	17
84966	2020-06-26 01:13:45	2020-06-26	9	[{"id_menu":6,"count":1}]	30202	delivery	5	14
84967	2020-06-26 01:16:06	2020-06-26	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	33290	delivery	5	40
84968	2020-06-26 01:17:06	2020-06-26	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5106	delivery	5	57
84969	2020-06-26 01:22:40	2020-06-26	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	21799	delivery	5	23
84970	2020-06-26 01:27:14	2020-06-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	3251	delivery	5	26
84971	2020-06-26 01:27:30	2020-06-26	14	[{"id_menu":2,"count":1}]	24996	pick-up	0	14
84972	2020-06-26 01:27:35	2020-06-26	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	33337	delivery	5	43
84973	2020-06-26 01:29:24	2020-06-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	17784	delivery	5	26
84974	2020-06-26 01:29:46	2020-06-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	33449	delivery	5	31
84975	2020-06-26 01:32:06	2020-06-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	33377	delivery	5	22
84976	2020-06-26 01:32:33	2020-06-26	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	29164	delivery	5	26
84977	2020-06-26 01:33:08	2020-06-26	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33405	delivery	5	37
84978	2020-06-26 01:35:04	2020-06-26	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	33465	delivery	5	30
84979	2020-06-26 01:39:37	2020-06-26	17	[{"id_menu":4,"count":1}]	6342	pick-up	0	17
84980	2020-06-26 01:39:52	2020-06-26	9	[{"id_menu":6,"count":1}]	20223	delivery	5	14
84981	2020-06-26 01:44:18	2020-06-26	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7186	pick-up	0	25
84982	2020-06-26 01:45:12	2020-06-26	12	[{"id_menu":3,"count":1}]	27861	pick-up	0	12
84983	2020-06-26 01:52:51	2020-06-26	9	[{"id_menu":7,"count":1}]	33342	delivery	5	14
84984	2020-06-26 01:54:06	2020-06-26	17	[{"id_menu":4,"count":1}]	15123	delivery	5	22
84985	2020-06-26 01:58:50	2020-06-26	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	11286	delivery	5	36
84986	2020-06-26 02:03:41	2020-06-26	12	[{"id_menu":1,"count":1}]	19686	delivery	5	17
84987	2020-06-26 02:04:18	2020-06-26	9	[{"id_menu":7,"count":1}]	7053	delivery	5	14
84988	2020-06-26 02:05:10	2020-06-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	33370	delivery	5	22
84989	2020-06-26 02:08:41	2020-06-26	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	33328	delivery	5	34
84990	2020-06-26 02:10:38	2020-06-26	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	33353	delivery	5	31
84991	2020-06-26 02:12:48	2020-06-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	22572	delivery	5	28
84992	2020-06-26 02:14:00	2020-06-26	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	33301	delivery	5	31
84993	2020-06-26 02:14:59	2020-06-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	26227	pick-up	0	17
84994	2020-06-26 02:18:24	2020-06-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	29354	delivery	5	28
84995	2020-06-26 02:19:39	2020-06-26	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	33338	delivery	5	40
84996	2020-06-26 02:22:19	2020-06-26	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	26520	delivery	5	22
84997	2020-06-26 02:22:41	2020-06-26	9	[{"id_menu":7,"count":3}]	14378	pick-up	0	9
84998	2020-06-26 02:31:48	2020-06-26	14	[{"id_menu":2,"count":1}]	10301	delivery	5	19
84999	2020-06-26 02:32:24	2020-06-26	9	[{"id_menu":6,"count":1}]	33284	delivery	5	14
85000	2020-06-26 02:35:48	2020-06-26	9	[{"id_menu":6,"count":1}]	33454	delivery	5	14
85001	2020-06-26 02:39:56	2020-06-26	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4655	delivery	5	45
85002	2020-06-26 02:43:23	2020-06-26	8	[{"id_menu":5,"count":1}]	14247	delivery	5	13
85003	2020-06-26 02:45:44	2020-06-26	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15428	delivery	5	37
85004	2020-06-26 02:45:46	2020-06-26	9	[{"id_menu":6,"count":3}]	12782	delivery	5	14
85005	2020-06-26 02:49:35	2020-06-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	10305	delivery	5	28
85006	2020-06-26 02:51:28	2020-06-26	8	[{"id_menu":5,"count":1}]	33482	delivery	5	13
85007	2020-06-26 02:52:04	2020-06-26	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	33281	delivery	5	38
85008	2020-06-26 02:52:44	2020-06-26	9	[{"id_menu":6,"count":1}]	13013	delivery	5	14
85009	2020-06-26 02:53:27	2020-06-26	12	[{"id_menu":1,"count":1}]	2821	pick-up	0	12
85010	2020-06-26 02:57:26	2020-06-26	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	13554	delivery	5	45
85011	2020-06-26 03:00:50	2020-06-26	9	[{"id_menu":6,"count":1}]	33430	delivery	5	14
85012	2020-06-26 03:01:15	2020-06-26	12	[{"id_menu":1,"count":2}]	14841	delivery	5	17
85013	2020-06-26 03:05:52	2020-06-26	17	[{"id_menu":4,"count":1}]	33433	delivery	5	22
85014	2020-06-26 03:06:47	2020-06-26	12	[{"id_menu":3,"count":1}]	33358	delivery	5	17
85015	2020-06-26 03:08:26	2020-06-26	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	27308	delivery	5	37
85016	2020-06-26 03:25:53	2020-06-26	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	33462	delivery	5	40
85017	2020-06-26 03:26:29	2020-06-26	9	[{"id_menu":6,"count":1}]	33459	delivery	5	14
85018	2020-06-26 03:29:22	2020-06-26	12	[{"id_menu":3,"count":1}]	2078	delivery	5	17
85019	2020-06-26 03:32:50	2020-06-26	9	[{"id_menu":6,"count":1}]	10796	delivery	5	14
85020	2020-06-26 03:38:46	2020-06-26	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	33307	delivery	5	31
85021	2020-06-26 03:45:01	2020-06-26	9	[{"id_menu":7,"count":1}]	33409	delivery	5	14
85022	2020-06-26 03:45:54	2020-06-26	14	[{"id_menu":2,"count":1}]	33489	delivery	5	19
85023	2020-06-26 03:48:01	2020-06-26	12	[{"id_menu":3,"count":1}]	24805	delivery	5	17
85024	2020-06-26 03:58:13	2020-06-26	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	33414	delivery	5	29
85025	2020-06-26 04:16:46	2020-06-26	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	33330	delivery	5	27
85026	2020-06-26 04:21:02	2020-06-26	17	[{"id_menu":4,"count":1}]	11543	delivery	5	22
85027	2020-06-26 04:24:24	2020-06-26	12	[{"id_menu":3,"count":1}]	33292	pick-up	0	12
85028	2020-06-26 04:30:45	2020-06-26	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	18021	delivery	5	25
85029	2020-06-26 04:31:18	2020-06-26	9	[{"id_menu":7,"count":2}]	29839	delivery	5	14
85030	2020-06-26 04:34:30	2020-06-26	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5768	delivery	5	31
85031	2020-06-26 04:37:59	2020-06-26	8	[{"id_menu":5,"count":2}]	33280	delivery	5	13
85032	2020-06-26 04:40:15	2020-06-26	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11180	delivery	5	43
85033	2020-06-26 04:41:17	2020-06-26	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	33478	delivery	5	36
85034	2020-06-26 04:42:55	2020-06-26	17	[{"id_menu":4,"count":1}]	6135	delivery	5	22
85035	2020-06-26 04:44:43	2020-06-26	12	[{"id_menu":3,"count":1}]	12760	delivery	5	17
85036	2020-06-26 04:51:22	2020-06-26	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	18225	delivery	5	40
85037	2020-06-26 04:52:57	2020-06-26	9	[{"id_menu":6,"count":1}]	33443	delivery	5	14
85038	2020-06-26 05:06:46	2020-06-26	9	[{"id_menu":7,"count":1}]	21114	pick-up	0	9
85039	2020-06-26 05:08:56	2020-06-26	14	[{"id_menu":2,"count":1}]	562	delivery	5	19
85040	2020-06-26 05:09:16	2020-06-26	9	[{"id_menu":6,"count":1}]	2398	pick-up	0	9
85041	2020-06-26 05:12:09	2020-06-26	8	[{"id_menu":5,"count":1}]	33423	delivery	5	13
85042	2020-06-26 05:15:21	2020-06-26	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	12449	delivery	5	27
85043	2020-06-26 05:18:40	2020-06-26	8	[{"id_menu":5,"count":1}]	33402	delivery	5	13
85044	2020-06-26 05:19:25	2020-06-26	9	[{"id_menu":6,"count":1}]	25703	delivery	5	14
85045	2020-06-26 05:22:21	2020-06-26	9	[{"id_menu":7,"count":1}]	497	pick-up	0	9
85046	2020-06-26 05:27:07	2020-06-26	14	[{"id_menu":2,"count":1}]	8658	delivery	5	19
85047	2020-06-26 05:28:34	2020-06-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10311	delivery	5	31
85048	2020-06-26 05:30:24	2020-06-26	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	16996	pick-up	0	25
85049	2020-06-26 05:36:28	2020-06-26	8	[{"id_menu":5,"count":1}]	33375	delivery	5	13
85050	2020-06-26 05:38:43	2020-06-26	12	[{"id_menu":3,"count":1}]	18724	delivery	5	17
85051	2020-06-26 05:41:45	2020-06-26	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	33436	delivery	5	52
85052	2020-06-26 05:53:14	2020-06-26	12	[{"id_menu":3,"count":1}]	15374	delivery	5	17
85053	2020-06-26 05:56:39	2020-06-26	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	33471	delivery	5	45
85054	2020-06-26 05:57:02	2020-06-26	14	[{"id_menu":2,"count":1}]	33476	delivery	5	19
85055	2020-06-26 05:59:03	2020-06-26	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	27543	delivery	5	25
85056	2020-06-26 05:59:53	2020-06-26	9	[{"id_menu":6,"count":1}]	33451	delivery	5	14
85057	2020-06-26 06:01:46	2020-06-26	14	[{"id_menu":2,"count":1}]	2085	pick-up	0	14
85058	2020-06-26 06:09:55	2020-06-26	17	[{"id_menu":4,"count":1}]	3894	delivery	5	22
85059	2020-06-26 06:11:16	2020-06-26	9	[{"id_menu":7,"count":1}]	1407	pick-up	0	9
85060	2020-06-26 06:14:49	2020-06-26	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	33388	delivery	5	36
85061	2020-06-26 06:17:10	2020-06-26	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	33381	delivery	5	30
85062	2020-06-26 06:17:41	2020-06-26	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1258	pick-up	0	21
85063	2020-06-26 06:17:48	2020-06-26	12	[{"id_menu":3,"count":1}]	4459	delivery	5	17
85064	2020-06-26 06:22:27	2020-06-26	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11624	delivery	5	53
85065	2020-06-26 06:22:46	2020-06-26	8	[{"id_menu":5,"count":1}]	16228	pick-up	0	8
85066	2020-06-26 06:26:32	2020-06-26	9	[{"id_menu":7,"count":1}]	16461	pick-up	0	9
85067	2020-06-26 06:27:22	2020-06-26	12	[{"id_menu":1,"count":1}]	9943	pick-up	0	12
85068	2020-06-26 06:27:54	2020-06-26	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	14081	pick-up	0	25
85069	2020-06-26 06:31:50	2020-06-26	8	[{"id_menu":5,"count":1}]	20598	pick-up	0	8
85070	2020-06-26 06:32:23	2020-06-26	17	[{"id_menu":4,"count":1}]	292	delivery	5	22
85071	2020-06-26 06:36:45	2020-06-26	9	[{"id_menu":7,"count":1}]	24041	pick-up	0	9
85072	2020-06-26 06:40:50	2020-06-26	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	19841	pick-up	0	29
85073	2020-06-26 06:41:09	2020-06-26	12	[{"id_menu":1,"count":1}]	6338	pick-up	0	12
85074	2020-06-26 06:42:56	2020-06-26	14	[{"id_menu":2,"count":2}]	14666	delivery	5	19
85075	2020-06-26 06:46:40	2020-06-26	9	[{"id_menu":7,"count":1}]	270	pick-up	0	9
85076	2020-06-26 06:52:10	2020-06-26	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11189	pick-up	0	26
85077	2020-06-26 06:52:22	2020-06-26	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	33331	delivery	5	40
85078	2020-06-26 06:57:52	2020-06-26	9	[{"id_menu":6,"count":1}]	22571	delivery	5	14
85079	2020-06-26 07:06:52	2020-06-26	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33312	delivery	5	54
85080	2020-06-26 07:08:55	2020-06-26	9	[{"id_menu":7,"count":4}]	33416	delivery	5	14
85081	2020-06-26 07:09:44	2020-06-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	33391	delivery	5	28
85082	2020-06-26 07:12:19	2020-06-26	9	[{"id_menu":6,"count":1}]	33438	delivery	5	14
85083	2020-06-26 07:13:55	2020-06-26	8	[{"id_menu":5,"count":1}]	33367	delivery	5	13
85084	2020-06-26 07:23:29	2020-06-26	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	33460	delivery	5	40
85085	2020-06-26 07:30:15	2020-06-26	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	8741	delivery	5	26
85086	2020-06-26 07:32:20	2020-06-26	12	[{"id_menu":1,"count":1}]	27862	pick-up	0	12
85087	2020-06-26 07:40:54	2020-06-26	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17206	delivery	5	31
85088	2020-06-26 07:42:56	2020-06-26	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	18128	pick-up	0	26
85089	2020-06-26 07:43:04	2020-06-26	14	[{"id_menu":2,"count":1}]	30287	delivery	5	19
85090	2020-06-26 07:45:31	2020-06-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	6039	delivery	5	26
85091	2020-06-26 07:46:59	2020-06-26	9	[{"id_menu":7,"count":1}]	7726	pick-up	0	9
85092	2020-06-26 07:48:55	2020-06-26	9	[{"id_menu":7,"count":1}]	33383	delivery	5	14
85093	2020-06-26 07:49:53	2020-06-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	33344	delivery	5	28
85094	2020-06-26 07:49:59	2020-06-26	9	[{"id_menu":7,"count":1}]	304	pick-up	0	9
85095	2020-06-26 07:50:33	2020-06-26	9	[{"id_menu":6,"count":1}]	3179	delivery	5	14
85096	2020-06-26 07:57:41	2020-06-26	8	[{"id_menu":5,"count":1}]	33360	delivery	5	13
85097	2020-06-26 07:58:33	2020-06-26	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25859	delivery	5	37
85098	2020-06-26 08:00:13	2020-06-26	9	[{"id_menu":6,"count":1}]	11754	delivery	5	14
85099	2020-06-26 08:01:55	2020-06-26	17	[{"id_menu":4,"count":1}]	33485	pick-up	0	17
85100	2020-06-26 08:05:40	2020-06-26	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2123	pick-up	0	20
85101	2020-06-26 08:09:44	2020-06-26	9	[{"id_menu":7,"count":2}]	24351	delivery	5	14
85102	2020-06-26 08:11:12	2020-06-26	14	[{"id_menu":2,"count":1}]	10391	delivery	5	19
85103	2020-06-26 08:14:58	2020-06-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14046	delivery	5	23
85104	2020-06-26 08:25:06	2020-06-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	25676	delivery	5	28
85105	2020-06-26 08:25:35	2020-06-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28631	delivery	5	22
85106	2020-06-26 08:32:21	2020-06-26	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	16966	delivery	5	31
85107	2020-06-26 08:43:05	2020-06-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	32369	delivery	5	22
85108	2020-06-26 08:43:50	2020-06-26	8	[{"id_menu":5,"count":1}]	19363	delivery	5	13
85109	2020-06-26 08:45:52	2020-06-26	17	[{"id_menu":4,"count":1}]	33343	delivery	5	22
85110	2020-06-26 08:49:56	2020-06-26	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	33500	delivery	5	25
85111	2020-06-26 08:52:46	2020-06-26	9	[{"id_menu":7,"count":1}]	27662	delivery	5	14
85112	2020-06-26 08:56:38	2020-06-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3350	delivery	5	22
85113	2020-06-26 08:59:11	2020-06-26	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	33351	delivery	5	34
85114	2020-06-26 08:59:34	2020-06-26	17	[{"id_menu":4,"count":1}]	6152	pick-up	0	17
85115	2020-06-26 08:59:47	2020-06-26	9	[{"id_menu":7,"count":1}]	29000	delivery	5	14
85116	2020-06-26 09:02:43	2020-06-26	8	[{"id_menu":5,"count":1}]	26646	delivery	5	13
85117	2020-06-26 09:05:38	2020-06-26	12	[{"id_menu":3,"count":1}]	3948	pick-up	0	12
85118	2020-06-26 09:11:50	2020-06-26	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	33445	delivery	5	30
85119	2020-06-26 09:13:32	2020-06-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33365	delivery	5	23
85120	2020-06-26 09:14:45	2020-06-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	33297	delivery	5	31
85121	2020-06-26 09:18:03	2020-06-26	9	[{"id_menu":7,"count":1}]	18868	delivery	5	14
85122	2020-06-26 09:28:08	2020-06-26	14	[{"id_menu":2,"count":1}]	24610	pick-up	0	14
85123	2020-06-26 09:31:58	2020-06-26	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	33339	delivery	5	40
85124	2020-06-26 09:32:21	2020-06-26	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23133	pick-up	0	44
85125	2020-06-26 09:34:57	2020-06-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11510	delivery	5	22
85126	2020-06-26 09:38:09	2020-06-26	17	[{"id_menu":4,"count":1}]	9587	delivery	5	22
85127	2020-06-26 09:43:23	2020-06-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	22130	delivery	5	28
85128	2020-06-26 09:45:14	2020-06-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2095	pick-up	0	17
85129	2020-06-26 09:45:33	2020-06-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	21290	pick-up	0	21
85130	2020-06-26 09:47:03	2020-06-26	12	[{"id_menu":1,"count":1}]	17835	delivery	5	17
85131	2020-06-26 09:47:51	2020-06-26	14	[{"id_menu":2,"count":1}]	31415	delivery	5	19
85132	2020-06-26 09:48:21	2020-06-26	9	[{"id_menu":7,"count":1}]	33335	delivery	5	14
85133	2020-06-26 09:51:25	2020-06-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32086	delivery	5	22
85134	2020-06-26 09:52:58	2020-06-26	9	[{"id_menu":6,"count":1}]	33379	pick-up	0	9
85135	2020-06-26 09:53:13	2020-06-26	8	[{"id_menu":5,"count":1}]	29480	delivery	5	13
85136	2020-06-26 10:02:39	2020-06-26	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	11708	delivery	5	31
85137	2020-06-26 10:07:17	2020-06-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7891	pick-up	0	17
85138	2020-06-26 10:07:43	2020-06-26	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	22626	pick-up	0	31
85139	2020-06-26 10:11:04	2020-06-26	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33371	delivery	5	35
85140	2020-06-26 10:14:13	2020-06-26	8	[{"id_menu":5,"count":1}]	33403	delivery	5	13
85141	2020-06-26 10:14:40	2020-06-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1466	pick-up	0	21
85142	2020-06-26 10:20:18	2020-06-26	14	[{"id_menu":2,"count":1}]	29917	delivery	5	19
85143	2020-06-26 10:26:48	2020-06-26	12	[{"id_menu":3,"count":2}]	16792	delivery	5	17
85144	2020-06-26 10:28:50	2020-06-26	17	[{"id_menu":4,"count":1}]	11150	delivery	5	22
85145	2020-06-26 10:29:12	2020-06-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	9483	pick-up	0	21
85146	2020-06-26 10:29:23	2020-06-26	12	[{"id_menu":1,"count":1}]	13497	delivery	5	17
85147	2020-06-26 10:31:01	2020-06-26	14	[{"id_menu":2,"count":1}]	33305	delivery	5	19
85148	2020-06-26 10:31:46	2020-06-26	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	33397	delivery	5	25
85149	2020-06-26 10:31:59	2020-06-26	14	[{"id_menu":2,"count":1}]	28514	delivery	5	19
85150	2020-06-26 10:32:02	2020-06-26	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	33274	delivery	5	27
85151	2020-06-26 10:35:59	2020-06-26	12	[{"id_menu":1,"count":1}]	33469	delivery	5	17
85152	2020-06-26 10:37:52	2020-06-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	4368	delivery	5	26
85153	2020-06-26 10:37:56	2020-06-26	9	[{"id_menu":6,"count":1}]	33442	delivery	5	14
85154	2020-06-26 10:39:02	2020-06-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	28542	delivery	5	28
85155	2020-06-26 10:40:21	2020-06-26	9	[{"id_menu":6,"count":1}]	33368	delivery	5	14
85156	2020-06-26 10:44:35	2020-06-26	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	16231	delivery	5	22
85157	2020-06-26 10:47:14	2020-06-26	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	33276	delivery	5	28
85158	2020-06-26 10:50:36	2020-06-26	17	[{"id_menu":4,"count":1}]	31480	delivery	5	22
85159	2020-06-26 10:51:33	2020-06-26	17	[{"id_menu":4,"count":1}]	33406	delivery	5	22
85160	2020-06-26 10:52:19	2020-06-26	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	13528	delivery	5	29
85161	2020-06-26 10:55:01	2020-06-26	14	[{"id_menu":2,"count":1}]	2107	delivery	5	19
85162	2020-06-26 10:56:30	2020-06-26	8	[{"id_menu":5,"count":1}]	3184	delivery	5	13
85163	2020-06-26 10:57:46	2020-06-26	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	30614	pick-up	0	38
85164	2020-06-26 10:59:13	2020-06-26	12	[{"id_menu":1,"count":1}]	21871	delivery	5	17
85165	2020-06-26 10:59:25	2020-06-26	12	[{"id_menu":1,"count":1}]	33420	delivery	5	17
85166	2020-06-26 10:59:50	2020-06-26	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	22124	delivery	5	40
85167	2020-06-26 11:05:19	2020-06-26	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	1636	delivery	5	26
85168	2020-06-26 11:05:51	2020-06-26	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	23729	pick-up	0	31
85169	2020-06-26 11:12:36	2020-06-26	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6090	delivery	5	31
85170	2020-06-26 11:13:33	2020-06-26	9	[{"id_menu":6,"count":1}]	1727	delivery	5	14
85171	2020-06-26 11:13:48	2020-06-26	14	[{"id_menu":2,"count":1}]	19052	pick-up	0	14
85172	2020-06-26 11:14:49	2020-06-26	12	[{"id_menu":1,"count":1}]	33311	delivery	5	17
85173	2020-06-26 11:16:19	2020-06-26	12	[{"id_menu":1,"count":1}]	25028	pick-up	0	12
85174	2020-06-26 11:20:49	2020-06-26	9	[{"id_menu":7,"count":1}]	559	delivery	5	14
85175	2020-06-26 11:21:40	2020-06-26	9	[{"id_menu":6,"count":1}]	10180	delivery	5	14
85176	2020-06-26 11:23:07	2020-06-26	8	[{"id_menu":5,"count":1}]	33376	delivery	5	13
85177	2020-06-26 11:25:56	2020-06-26	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	28623	delivery	5	27
85178	2020-06-26 11:28:46	2020-06-26	14	[{"id_menu":2,"count":1}]	1435	pick-up	0	14
85179	2020-06-26 11:29:13	2020-06-26	8	[{"id_menu":5,"count":1}]	33480	delivery	5	13
85180	2020-06-26 11:39:42	2020-06-26	12	[{"id_menu":1,"count":1}]	33461	delivery	5	17
85181	2020-06-26 11:54:17	2020-06-26	8	[{"id_menu":5,"count":1}]	33497	delivery	5	13
85182	2020-06-26 11:59:48	2020-06-26	12	[{"id_menu":1,"count":1}]	2577	delivery	5	17
85183	2020-06-26 12:00:17	2020-06-26	9	[{"id_menu":6,"count":1}]	33346	delivery	5	14
85184	2020-06-26 12:03:08	2020-06-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	16510	delivery	5	26
85185	2020-06-26 12:07:37	2020-06-26	9	[{"id_menu":6,"count":1}]	16155	pick-up	0	9
85186	2020-06-26 12:08:30	2020-06-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	32901	pick-up	0	17
85187	2020-06-26 12:09:02	2020-06-26	14	[{"id_menu":2,"count":1}]	33315	delivery	5	19
85188	2020-06-26 12:10:33	2020-06-26	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	18489	delivery	5	43
85189	2020-06-26 12:12:52	2020-06-26	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33419	delivery	5	37
85190	2020-06-26 12:13:18	2020-06-26	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	33322	delivery	5	26
85191	2020-06-26 12:13:20	2020-06-26	9	[{"id_menu":6,"count":1}]	10369	pick-up	0	9
85192	2020-06-26 12:15:35	2020-06-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	33374	delivery	5	22
85193	2020-06-26 12:18:28	2020-06-26	14	[{"id_menu":2,"count":1}]	28959	pick-up	0	14
85194	2020-06-26 12:18:55	2020-06-26	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	21599	pick-up	0	31
85195	2020-06-26 12:19:14	2020-06-26	12	[{"id_menu":1,"count":1}]	11878	delivery	5	17
85196	2020-06-26 12:26:13	2020-06-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8104	pick-up	0	26
85197	2020-06-26 12:31:13	2020-06-26	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	33484	delivery	5	30
85198	2020-06-26 12:33:23	2020-06-26	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	28174	delivery	5	27
85199	2020-06-26 12:34:37	2020-06-26	12	[{"id_menu":1,"count":1}]	28167	delivery	5	17
85200	2020-06-26 12:35:31	2020-06-26	17	[{"id_menu":4,"count":1}]	2590	pick-up	0	17
85201	2020-06-26 12:40:42	2020-06-26	9	[{"id_menu":7,"count":1}]	15177	delivery	5	14
85202	2020-06-26 12:44:55	2020-06-26	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22177	delivery	5	53
85203	2020-06-26 12:48:58	2020-06-26	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	27804	pick-up	0	32
85204	2020-06-26 12:51:22	2020-06-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	9025	delivery	5	28
85205	2020-06-26 12:52:39	2020-06-26	8	[{"id_menu":5,"count":1}]	26040	delivery	5	13
85206	2020-06-26 12:53:34	2020-06-26	9	[{"id_menu":6,"count":1}]	33350	pick-up	0	9
85207	2020-06-26 12:54:18	2020-06-26	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	13275	pick-up	0	26
85208	2020-06-26 12:54:20	2020-06-26	9	[{"id_menu":7,"count":1}]	11210	delivery	5	14
85209	2020-06-26 12:55:16	2020-06-26	8	[{"id_menu":5,"count":1}]	33321	delivery	5	13
85210	2020-06-26 12:58:45	2020-06-26	9	[{"id_menu":6,"count":1}]	33303	delivery	5	14
85211	2020-06-26 13:00:09	2020-06-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	33334	delivery	5	26
85212	2020-06-26 13:07:31	2020-06-26	14	[{"id_menu":2,"count":1}]	33313	pick-up	0	14
85213	2020-06-26 13:08:55	2020-06-26	17	[{"id_menu":4,"count":1}]	21552	delivery	5	22
85214	2020-06-26 13:09:40	2020-06-26	12	[{"id_menu":1,"count":1}]	4202	pick-up	0	12
85215	2020-06-26 13:10:25	2020-06-26	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	30909	pick-up	0	24
85216	2020-06-26 13:20:42	2020-06-26	14	[{"id_menu":2,"count":1}]	20851	delivery	5	19
85217	2020-06-26 13:21:46	2020-06-26	8	[{"id_menu":5,"count":1}]	7295	delivery	5	13
85218	2020-06-26 13:29:43	2020-06-26	9	[{"id_menu":6,"count":1}]	28849	delivery	5	14
85219	2020-06-26 13:31:22	2020-06-26	8	[{"id_menu":5,"count":1}]	18457	delivery	5	13
85220	2020-06-26 13:31:46	2020-06-26	17	[{"id_menu":4,"count":1}]	4692	delivery	5	22
85221	2020-06-26 13:37:28	2020-06-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4957	pick-up	0	23
85222	2020-06-26 13:38:02	2020-06-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	33277	delivery	5	28
85223	2020-06-26 13:40:17	2020-06-26	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11367	delivery	5	48
85224	2020-06-26 13:41:39	2020-06-26	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	28588	delivery	5	31
85225	2020-06-26 13:42:31	2020-06-26	8	[{"id_menu":5,"count":1}]	33359	pick-up	0	8
85226	2020-06-26 13:43:46	2020-06-26	8	[{"id_menu":5,"count":1}]	33327	delivery	5	13
85227	2020-06-26 13:44:14	2020-06-26	8	[{"id_menu":5,"count":1}]	33340	delivery	5	13
85228	2020-06-26 13:44:38	2020-06-26	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	22484	delivery	5	40
85229	2020-06-26 13:46:39	2020-06-26	9	[{"id_menu":6,"count":1}]	33412	delivery	5	14
85230	2020-06-26 13:51:33	2020-06-26	17	[{"id_menu":4,"count":1}]	4882	delivery	5	22
85231	2020-06-26 13:51:49	2020-06-26	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	20931	delivery	5	23
85232	2020-06-26 13:51:57	2020-06-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	33275	delivery	5	22
85233	2020-06-26 13:51:57	2020-06-26	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	15532	delivery	5	25
85234	2020-06-26 13:54:41	2020-06-26	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	9998	delivery	5	26
85235	2020-06-26 14:01:13	2020-06-26	9	[{"id_menu":6,"count":1}]	18486	delivery	5	14
85236	2020-06-26 14:11:53	2020-06-26	9	[{"id_menu":7,"count":1}]	13840	delivery	5	14
85237	2020-06-26 14:15:08	2020-06-26	12	[{"id_menu":3,"count":1}]	33452	delivery	5	17
85238	2020-06-26 14:17:13	2020-06-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24325	pick-up	0	17
85239	2020-06-26 14:18:59	2020-06-26	8	[{"id_menu":5,"count":1}]	5510	delivery	5	13
85240	2020-06-26 14:23:36	2020-06-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":3}]	33407	delivery	5	26
85241	2020-06-26 14:25:09	2020-06-26	14	[{"id_menu":2,"count":1}]	33293	pick-up	0	14
85242	2020-06-26 14:25:21	2020-06-26	9	[{"id_menu":7,"count":1}]	33298	delivery	5	14
85243	2020-06-26 14:25:58	2020-06-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14874	delivery	5	23
85244	2020-06-26 14:27:03	2020-06-26	14	[{"id_menu":2,"count":1}]	24477	delivery	5	19
85245	2020-06-26 14:34:29	2020-06-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	9747	delivery	5	28
85246	2020-06-26 14:41:10	2020-06-26	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17538	delivery	5	43
85247	2020-06-26 14:44:50	2020-06-26	9	[{"id_menu":7,"count":1}]	33326	delivery	5	14
85248	2020-06-26 14:46:24	2020-06-26	12	[{"id_menu":3,"count":1}]	671	delivery	5	17
85249	2020-06-26 14:47:18	2020-06-26	12	[{"id_menu":3,"count":1}]	5033	delivery	5	17
85250	2020-06-26 14:51:17	2020-06-26	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33504	delivery	5	31
85251	2020-06-26 14:51:44	2020-06-26	14	[{"id_menu":2,"count":1}]	33455	delivery	5	19
85252	2020-06-26 14:51:53	2020-06-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	20873	delivery	5	31
85253	2020-06-26 14:52:39	2020-06-26	9	[{"id_menu":6,"count":1}]	33318	delivery	5	14
85254	2020-06-26 14:59:23	2020-06-26	8	[{"id_menu":5,"count":1}]	25678	delivery	5	13
85255	2020-06-26 15:03:09	2020-06-26	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	33432	delivery	5	34
85256	2020-06-26 15:10:30	2020-06-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	33470	delivery	5	28
85257	2020-06-26 15:11:33	2020-06-26	12	[{"id_menu":1,"count":1}]	13762	pick-up	0	12
85258	2020-06-26 15:15:16	2020-06-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1093	delivery	5	31
85259	2020-06-26 15:15:27	2020-06-26	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33444	delivery	5	48
85260	2020-06-26 15:16:55	2020-06-26	14	[{"id_menu":2,"count":1}]	27044	delivery	5	19
85261	2020-06-26 15:17:25	2020-06-26	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	23461	pick-up	0	22
85262	2020-06-26 15:17:34	2020-06-26	9	[{"id_menu":6,"count":2}]	26323	delivery	5	14
85263	2020-06-26 15:21:00	2020-06-26	12	[{"id_menu":1,"count":1}]	19857	delivery	5	17
85264	2020-06-26 15:23:48	2020-06-26	12	[{"id_menu":3,"count":1}]	33401	delivery	5	17
85265	2020-06-26 15:25:22	2020-06-26	9	[{"id_menu":7,"count":1}]	24070	pick-up	0	9
85266	2020-06-26 15:34:35	2020-06-26	17	[{"id_menu":4,"count":1}]	33467	delivery	5	22
85267	2020-06-26 15:37:38	2020-06-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	31865	delivery	5	26
85268	2020-06-26 15:45:28	2020-06-26	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	25006	pick-up	0	20
85269	2020-06-26 15:45:31	2020-06-26	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32042	delivery	5	35
85270	2020-06-26 15:51:18	2020-06-26	14	[{"id_menu":2,"count":1}]	33450	pick-up	0	14
85271	2020-06-26 15:52:15	2020-06-26	8	[{"id_menu":5,"count":1}]	33387	pick-up	0	8
85272	2020-06-26 15:55:05	2020-06-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8427	delivery	5	31
85273	2020-06-26 15:55:15	2020-06-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	33486	delivery	5	23
85274	2020-06-26 15:56:08	2020-06-26	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6250	pick-up	0	39
85275	2020-06-26 15:57:24	2020-06-26	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	33447	delivery	5	34
85276	2020-06-26 16:00:23	2020-06-26	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	33490	delivery	5	26
85277	2020-06-26 16:03:00	2020-06-26	14	[{"id_menu":2,"count":1}]	2928	pick-up	0	14
85278	2020-06-26 16:03:49	2020-06-26	9	[{"id_menu":7,"count":1}]	33364	delivery	5	14
85279	2020-06-26 16:04:58	2020-06-26	12	[{"id_menu":3,"count":1}]	16964	pick-up	0	12
85280	2020-06-26 16:06:50	2020-06-26	9	[{"id_menu":7,"count":1}]	14618	delivery	5	14
85281	2020-06-26 16:10:28	2020-06-26	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	33380	delivery	5	30
85282	2020-06-26 16:12:52	2020-06-26	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33503	delivery	5	43
85283	2020-06-26 16:13:54	2020-06-26	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	26905	delivery	5	31
85284	2020-06-26 16:14:22	2020-06-26	8	[{"id_menu":5,"count":1}]	33378	delivery	5	13
85285	2020-06-26 16:15:09	2020-06-26	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33278	delivery	5	31
85286	2020-06-26 16:17:00	2020-06-26	9	[{"id_menu":6,"count":1}]	30183	delivery	5	14
85287	2020-06-26 16:24:31	2020-06-26	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	33395	delivery	5	45
85288	2020-06-26 16:25:06	2020-06-26	14	[{"id_menu":2,"count":1}]	29023	delivery	5	19
85289	2020-06-26 16:26:13	2020-06-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	9044	delivery	5	26
85290	2020-06-26 16:30:32	2020-06-26	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12854	delivery	5	45
85291	2020-06-26 16:38:05	2020-06-26	9	[{"id_menu":6,"count":1}]	24939	delivery	5	14
85292	2020-06-26 16:38:33	2020-06-26	12	[{"id_menu":3,"count":1}]	33323	delivery	5	17
85293	2020-06-26 16:38:57	2020-06-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	7766	pick-up	0	21
85294	2020-06-26 16:40:02	2020-06-26	12	[{"id_menu":3,"count":1}]	18239	pick-up	0	12
85295	2020-06-26 16:46:27	2020-06-26	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	7103	pick-up	0	20
85296	2020-06-26 16:47:26	2020-06-26	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2064	pick-up	0	25
85297	2020-06-26 16:55:56	2020-06-26	12	[{"id_menu":3,"count":1}]	33385	delivery	5	17
85298	2020-06-26 16:58:39	2020-06-26	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	28439	delivery	5	43
85299	2020-06-26 17:00:19	2020-06-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	25760	delivery	5	31
85300	2020-06-26 17:00:23	2020-06-26	12	[{"id_menu":1,"count":1}]	18737	delivery	5	17
85301	2020-06-26 17:04:23	2020-06-26	9	[{"id_menu":7,"count":1}]	33425	delivery	5	14
85302	2020-06-26 17:08:25	2020-06-26	17	[{"id_menu":4,"count":1}]	2513	delivery	5	22
85303	2020-06-26 17:09:39	2020-06-26	17	[{"id_menu":4,"count":1}]	33304	pick-up	0	17
85304	2020-06-26 17:11:56	2020-06-26	17	[{"id_menu":4,"count":1}]	9855	delivery	5	22
85305	2020-06-26 17:14:06	2020-06-26	9	[{"id_menu":7,"count":1}]	33363	delivery	5	14
85306	2020-06-26 17:17:40	2020-06-26	9	[{"id_menu":7,"count":1}]	29670	delivery	5	14
85307	2020-06-26 17:19:54	2020-06-26	14	[{"id_menu":2,"count":1}]	13028	delivery	5	19
85308	2020-06-26 17:22:35	2020-06-26	17	[{"id_menu":4,"count":1}]	33437	delivery	5	22
85309	2020-06-26 17:24:37	2020-06-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	17125	delivery	5	26
85310	2020-06-26 17:25:38	2020-06-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20249	delivery	5	23
85311	2020-06-26 17:27:05	2020-06-26	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30997	delivery	5	40
85312	2020-06-26 17:29:02	2020-06-26	9	[{"id_menu":7,"count":1}]	21606	delivery	5	14
85313	2020-06-26 17:36:26	2020-06-26	37	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	29856	delivery	5	42
85314	2020-06-26 17:39:55	2020-06-26	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	24422	delivery	5	27
85315	2020-06-26 17:40:24	2020-06-26	9	[{"id_menu":6,"count":1}]	21834	delivery	5	14
85316	2020-06-26 17:44:28	2020-06-26	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	22982	delivery	5	26
85317	2020-06-26 17:44:30	2020-06-26	17	[{"id_menu":4,"count":1}]	25447	delivery	5	22
85318	2020-06-26 17:47:36	2020-06-26	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16635	delivery	5	34
85319	2020-06-26 17:48:10	2020-06-26	14	[{"id_menu":2,"count":1}]	5141	delivery	5	19
85320	2020-06-26 17:54:04	2020-06-26	8	[{"id_menu":5,"count":1}]	27107	delivery	5	13
85321	2020-06-26 17:55:34	2020-06-26	9	[{"id_menu":7,"count":1}]	18341	delivery	5	14
85322	2020-06-26 17:57:26	2020-06-26	9	[{"id_menu":6,"count":1}]	33309	delivery	5	14
85323	2020-06-26 18:00:48	2020-06-26	12	[{"id_menu":1,"count":1}]	33316	delivery	5	17
85324	2020-06-26 18:08:01	2020-06-26	9	[{"id_menu":6,"count":1}]	14831	delivery	5	14
85325	2020-06-26 18:10:59	2020-06-26	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	33319	delivery	5	43
85326	2020-06-26 18:11:34	2020-06-26	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	21764	delivery	5	36
85327	2020-06-26 18:16:36	2020-06-26	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	33464	delivery	5	36
85328	2020-06-26 18:18:16	2020-06-26	9	[{"id_menu":7,"count":1}]	8240	pick-up	0	9
85329	2020-06-26 18:19:57	2020-06-26	12	[{"id_menu":1,"count":1}]	12228	delivery	5	17
85330	2020-06-26 18:24:20	2020-06-26	17	[{"id_menu":4,"count":1}]	74	delivery	5	22
85331	2020-06-26 18:26:22	2020-06-26	17	[{"id_menu":4,"count":1}]	13802	delivery	5	22
85332	2020-06-26 18:26:31	2020-06-26	14	[{"id_menu":2,"count":1}]	3593	pick-up	0	14
85333	2020-06-26 18:26:43	2020-06-26	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	285	pick-up	0	35
85334	2020-06-26 18:27:11	2020-06-26	9	[{"id_menu":6,"count":1}]	5988	pick-up	0	9
85335	2020-06-26 18:27:26	2020-06-26	12	[{"id_menu":1,"count":1}]	13324	delivery	5	17
85336	2020-06-26 18:28:45	2020-06-26	14	[{"id_menu":2,"count":1}]	33494	delivery	5	19
85337	2020-06-26 18:29:28	2020-06-26	12	[{"id_menu":3,"count":1}]	3631	delivery	5	17
85338	2020-06-26 18:31:18	2020-06-26	9	[{"id_menu":7,"count":1}]	33355	delivery	5	14
85339	2020-06-26 18:34:05	2020-06-26	12	[{"id_menu":1,"count":1}]	2352	delivery	5	17
85340	2020-06-26 18:35:27	2020-06-26	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	21813	delivery	5	31
85341	2020-06-26 18:41:34	2020-06-26	17	[{"id_menu":4,"count":1}]	16858	delivery	5	22
85342	2020-06-26 18:43:09	2020-06-26	8	[{"id_menu":5,"count":2}]	14903	pick-up	0	8
85343	2020-06-26 18:46:44	2020-06-26	14	[{"id_menu":2,"count":1}]	11672	delivery	5	19
85344	2020-06-26 18:49:19	2020-06-26	14	[{"id_menu":2,"count":2}]	4649	delivery	5	19
85345	2020-06-26 18:49:22	2020-06-26	17	[{"id_menu":4,"count":1}]	1654	pick-up	0	17
85346	2020-06-26 18:51:12	2020-06-26	12	[{"id_menu":3,"count":1}]	11998	delivery	5	17
85347	2020-06-26 18:57:05	2020-06-26	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22713	delivery	5	35
85348	2020-06-26 18:57:42	2020-06-26	9	[{"id_menu":6,"count":1}]	7848	pick-up	0	9
85349	2020-06-26 18:57:49	2020-06-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18094	pick-up	0	17
85350	2020-06-26 18:58:56	2020-06-26	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	19678	delivery	5	40
85351	2020-06-26 18:59:01	2020-06-26	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	29429	delivery	5	29
85352	2020-06-26 19:01:45	2020-06-26	38	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6444	delivery	5	43
85353	2020-06-26 19:07:46	2020-06-26	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	33492	delivery	5	31
85354	2020-06-26 19:08:28	2020-06-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	33456	delivery	5	26
85355	2020-06-26 19:13:18	2020-06-26	14	[{"id_menu":2,"count":1}]	32297	pick-up	0	14
85356	2020-06-26 19:14:43	2020-06-26	8	[{"id_menu":5,"count":1}]	33394	delivery	5	13
85357	2020-06-26 19:14:55	2020-06-26	12	[{"id_menu":1,"count":1}]	13732	pick-up	0	12
85358	2020-06-26 19:17:43	2020-06-26	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	33289	delivery	5	31
85359	2020-06-26 19:18:42	2020-06-26	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":3}]	33483	delivery	5	30
85360	2020-06-26 19:19:09	2020-06-26	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	12185	delivery	5	36
85361	2020-06-26 19:19:16	2020-06-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	33487	delivery	5	26
85362	2020-06-26 19:23:36	2020-06-26	9	[{"id_menu":7,"count":1}]	31571	delivery	5	14
85363	2020-06-26 19:24:08	2020-06-26	9	[{"id_menu":7,"count":1}]	20091	delivery	5	14
85364	2020-06-26 19:24:57	2020-06-26	17	[{"id_menu":4,"count":1}]	28545	delivery	5	22
85365	2020-06-26 19:32:52	2020-06-26	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	23405	delivery	5	48
85366	2020-06-26 19:35:12	2020-06-26	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	33453	delivery	5	45
85367	2020-06-26 19:37:55	2020-06-26	14	[{"id_menu":2,"count":1}]	33491	pick-up	0	14
85368	2020-06-26 19:38:55	2020-06-26	9	[{"id_menu":6,"count":1}]	33498	delivery	5	14
85369	2020-06-26 19:41:15	2020-06-26	9	[{"id_menu":6,"count":1}]	33426	delivery	5	14
85370	2020-06-26 19:42:02	2020-06-26	14	[{"id_menu":2,"count":1}]	33354	delivery	5	19
85371	2020-06-26 19:42:45	2020-06-26	9	[{"id_menu":6,"count":1}]	30469	delivery	5	14
85372	2020-06-26 19:45:53	2020-06-26	8	[{"id_menu":5,"count":1}]	33472	delivery	5	13
85373	2020-06-26 19:47:57	2020-06-26	9	[{"id_menu":6,"count":1}]	4023	delivery	5	14
85374	2020-06-26 19:48:44	2020-06-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18666	delivery	5	22
85375	2020-06-26 19:50:08	2020-06-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4909	delivery	5	28
85376	2020-06-26 19:51:16	2020-06-26	9	[{"id_menu":6,"count":1}]	33294	delivery	5	14
85377	2020-06-26 19:55:44	2020-06-26	14	[{"id_menu":2,"count":1}]	23835	delivery	5	19
85378	2020-06-26 19:57:06	2020-06-26	17	[{"id_menu":4,"count":1}]	17138	pick-up	0	17
85379	2020-06-26 19:57:13	2020-06-26	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	27993	delivery	5	26
85380	2020-06-26 20:01:20	2020-06-26	9	[{"id_menu":6,"count":1}]	5758	pick-up	0	9
85381	2020-06-26 20:01:21	2020-06-26	14	[{"id_menu":2,"count":2}]	33372	delivery	5	19
85382	2020-06-26 20:11:28	2020-06-26	12	[{"id_menu":3,"count":1}]	28489	delivery	5	17
85383	2020-06-26 20:12:14	2020-06-26	9	[{"id_menu":6,"count":1}]	4154	delivery	5	14
85384	2020-06-26 20:18:31	2020-06-26	9	[{"id_menu":7,"count":1}]	33499	pick-up	0	9
85385	2020-06-26 20:19:16	2020-06-26	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	33300	delivery	5	34
85386	2020-06-26 20:22:04	2020-06-26	12	[{"id_menu":1,"count":1}]	2891	pick-up	0	12
85387	2020-06-26 20:23:33	2020-06-26	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	9075	delivery	5	31
85388	2020-06-26 20:23:50	2020-06-26	14	[{"id_menu":2,"count":1}]	25180	delivery	5	19
85389	2020-06-26 20:24:35	2020-06-26	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	33428	pick-up	0	29
85390	2020-06-26 20:31:47	2020-06-26	9	[{"id_menu":6,"count":1}]	6633	delivery	5	14
85391	2020-06-26 20:32:07	2020-06-26	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	15997	delivery	5	28
85392	2020-06-26 20:33:59	2020-06-26	12	[{"id_menu":1,"count":1}]	30592	delivery	5	17
85393	2020-06-26 20:34:28	2020-06-26	9	[{"id_menu":7,"count":1}]	33332	delivery	5	14
85394	2020-06-26 20:35:08	2020-06-26	14	[{"id_menu":2,"count":1}]	10580	delivery	5	19
85395	2020-06-26 20:35:22	2020-06-26	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	6934	delivery	5	52
85396	2020-06-26 20:35:49	2020-06-26	9	[{"id_menu":7,"count":1}]	33440	delivery	5	14
85397	2020-06-26 20:38:22	2020-06-26	12	[{"id_menu":3,"count":1}]	33317	delivery	5	17
85398	2020-06-26 20:40:54	2020-06-26	8	[{"id_menu":5,"count":1}]	10421	delivery	5	13
85399	2020-06-26 20:49:42	2020-06-26	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1015	delivery	5	26
85400	2020-06-26 20:53:07	2020-06-26	8	[{"id_menu":5,"count":1}]	25527	delivery	5	13
85401	2020-06-26 20:54:24	2020-06-26	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	29211	delivery	5	25
85402	2020-06-26 20:54:35	2020-06-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	33366	delivery	5	28
85403	2020-06-26 20:56:30	2020-06-26	14	[{"id_menu":2,"count":1}]	20867	delivery	5	19
85404	2020-06-26 20:57:02	2020-06-26	14	[{"id_menu":2,"count":1}]	601	pick-up	0	14
85405	2020-06-26 20:57:27	2020-06-26	12	[{"id_menu":1,"count":1}]	2276	pick-up	0	12
85406	2020-06-26 21:00:35	2020-06-26	9	[{"id_menu":6,"count":1}]	33413	delivery	5	14
85407	2020-06-26 21:01:42	2020-06-26	17	[{"id_menu":4,"count":1}]	33488	pick-up	0	17
85408	2020-06-26 21:02:30	2020-06-26	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2207	pick-up	0	20
85409	2020-06-26 21:10:43	2020-06-26	17	[{"id_menu":4,"count":1}]	10381	pick-up	0	17
85410	2020-06-26 21:17:02	2020-06-26	17	[{"id_menu":4,"count":1}]	2429	pick-up	0	17
85411	2020-06-26 21:17:14	2020-06-26	12	[{"id_menu":1,"count":1}]	15686	pick-up	0	12
85412	2020-06-26 21:20:33	2020-06-26	12	[{"id_menu":1,"count":1}]	20573	delivery	5	17
85413	2020-06-26 21:21:27	2020-06-26	9	[{"id_menu":6,"count":1}]	24277	delivery	5	14
85414	2020-06-26 21:26:32	2020-06-26	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19623	delivery	5	52
85415	2020-06-26 21:27:51	2020-06-26	17	[{"id_menu":4,"count":1}]	13307	delivery	5	22
85416	2020-06-26 21:32:49	2020-06-26	9	[{"id_menu":6,"count":1}]	33398	delivery	5	14
85417	2020-06-26 21:41:58	2020-06-26	12	[{"id_menu":1,"count":1}]	1885	delivery	5	17
85418	2020-06-26 21:42:50	2020-06-26	12	[{"id_menu":3,"count":1}]	33299	delivery	5	17
85419	2020-06-26 21:43:11	2020-06-26	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15334	delivery	5	35
85420	2020-06-26 21:48:17	2020-06-26	9	[{"id_menu":7,"count":1}]	20949	pick-up	0	9
85421	2020-06-26 21:49:50	2020-06-26	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	33384	delivery	5	35
85422	2020-06-26 21:49:52	2020-06-26	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	23286	delivery	5	35
85423	2020-06-26 21:50:27	2020-06-26	9	[{"id_menu":6,"count":1}]	33333	delivery	5	14
85424	2020-06-26 21:56:53	2020-06-26	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	33396	delivery	5	39
85425	2020-06-26 21:57:02	2020-06-26	17	[{"id_menu":4,"count":1}]	33505	delivery	5	22
85426	2020-06-26 21:57:57	2020-06-26	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	19955	delivery	5	26
85427	2020-06-26 21:58:08	2020-06-26	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	8609	pick-up	0	21
85428	2020-06-26 21:59:43	2020-06-26	9	[{"id_menu":7,"count":1}]	9603	delivery	5	14
85429	2020-06-26 22:00:09	2020-06-26	14	[{"id_menu":2,"count":1}]	30108	pick-up	0	14
85430	2020-06-26 22:01:32	2020-06-26	14	[{"id_menu":2,"count":1}]	18940	delivery	5	19
85431	2020-06-26 22:01:37	2020-06-26	9	[{"id_menu":6,"count":1}]	33393	delivery	5	14
85432	2020-06-26 22:03:39	2020-06-26	14	[{"id_menu":2,"count":1}]	33286	delivery	5	19
85433	2020-06-26 22:05:35	2020-06-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33310	delivery	5	23
85434	2020-06-26 22:07:23	2020-06-26	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22865	delivery	5	34
85435	2020-06-26 22:09:01	2020-06-26	12	[{"id_menu":1,"count":1}]	33427	pick-up	0	12
85436	2020-06-26 22:12:12	2020-06-26	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	33417	delivery	5	40
85437	2020-06-26 22:13:01	2020-06-26	12	[{"id_menu":1,"count":1}]	33325	pick-up	0	12
85438	2020-06-26 22:14:59	2020-06-26	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27973	delivery	5	40
85439	2020-06-26 22:16:56	2020-06-26	9	[{"id_menu":6,"count":1}]	1441	pick-up	0	9
85440	2020-06-26 22:18:53	2020-06-26	9	[{"id_menu":6,"count":1}]	10064	delivery	5	14
85441	2020-06-26 22:19:21	2020-06-26	14	[{"id_menu":2,"count":1}]	33475	delivery	5	19
85442	2020-06-26 22:19:36	2020-06-26	17	[{"id_menu":4,"count":1}]	33287	delivery	5	22
85443	2020-06-26 22:20:32	2020-06-26	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	13763	delivery	5	26
85444	2020-06-26 22:20:56	2020-06-26	17	[{"id_menu":4,"count":1}]	5094	pick-up	0	17
85445	2020-06-26 22:23:41	2020-06-26	17	[{"id_menu":4,"count":1}]	33341	delivery	5	22
85446	2020-06-26 22:31:00	2020-06-26	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33477	delivery	5	45
85447	2020-06-26 22:32:51	2020-06-26	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	12296	pick-up	0	29
85448	2020-06-26 22:35:19	2020-06-26	12	[{"id_menu":1,"count":1}]	33382	delivery	5	17
85449	2020-06-26 22:40:15	2020-06-26	9	[{"id_menu":7,"count":1}]	21866	delivery	5	14
85450	2020-06-26 22:43:29	2020-06-26	9	[{"id_menu":6,"count":1}]	10954	pick-up	0	9
85451	2020-06-26 22:46:51	2020-06-26	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	33424	delivery	5	45
85452	2020-06-26 22:48:53	2020-06-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	27431	pick-up	0	21
85453	2020-06-26 22:50:05	2020-06-26	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2196	pick-up	0	21
85454	2020-06-26 22:51:25	2020-06-26	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5531	delivery	5	35
85455	2020-06-26 22:54:12	2020-06-26	12	[{"id_menu":1,"count":1}]	12184	pick-up	0	12
85456	2020-06-26 22:54:27	2020-06-26	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	15565	pick-up	0	24
85457	2020-06-26 22:57:33	2020-06-26	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20241	delivery	5	31
85458	2020-06-26 23:01:13	2020-06-26	9	[{"id_menu":7,"count":1}]	2367	pick-up	0	9
85459	2020-06-26 23:01:53	2020-06-26	17	[{"id_menu":4,"count":3}]	13387	delivery	5	22
85460	2020-06-26 23:02:57	2020-06-26	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4764	delivery	5	30
85461	2020-06-26 23:04:28	2020-06-26	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	33415	delivery	5	36
85462	2020-06-26 23:07:57	2020-06-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	33418	delivery	5	26
85463	2020-06-26 23:09:37	2020-06-26	12	[{"id_menu":1,"count":2}]	9465	delivery	5	17
85464	2020-06-26 23:15:04	2020-06-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	33429	delivery	5	22
85465	2020-06-26 23:16:49	2020-06-26	9	[{"id_menu":7,"count":1}]	15052	pick-up	0	9
85466	2020-06-26 23:21:00	2020-06-26	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	18870	delivery	5	40
85467	2020-06-26 23:23:00	2020-06-26	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	10331	delivery	5	43
85468	2020-06-26 23:24:26	2020-06-26	9	[{"id_menu":6,"count":1}]	24058	delivery	5	14
85469	2020-06-26 23:24:53	2020-06-26	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	33474	delivery	5	31
85470	2020-06-26 23:26:32	2020-06-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4181	delivery	5	28
85471	2020-06-26 23:28:58	2020-06-26	17	[{"id_menu":4,"count":1}]	33247	delivery	5	22
85472	2020-06-26 23:35:23	2020-06-26	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4834	delivery	5	40
85473	2020-06-26 23:41:35	2020-06-26	14	[{"id_menu":2,"count":1}]	33352	delivery	5	19
85474	2020-06-26 23:44:10	2020-06-26	9	[{"id_menu":6,"count":1}]	585	delivery	5	14
85475	2020-06-26 23:44:24	2020-06-26	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15266	delivery	5	39
85476	2020-06-26 23:46:00	2020-06-26	12	[{"id_menu":3,"count":1}]	6235	pick-up	0	12
85477	2020-06-26 23:47:12	2020-06-26	8	[{"id_menu":5,"count":1}]	21502	delivery	5	13
85478	2020-06-26 23:51:53	2020-06-26	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	12009	delivery	5	26
85479	2020-06-26 23:52:30	2020-06-26	8	[{"id_menu":5,"count":1}]	26400	delivery	5	13
85480	2020-06-26 23:52:51	2020-06-26	9	[{"id_menu":7,"count":1}]	31572	delivery	5	14
85481	2020-06-26 23:56:52	2020-06-26	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33308	delivery	5	35
85482	2020-06-26 23:57:23	2020-06-26	14	[{"id_menu":2,"count":1}]	32162	delivery	5	19
85483	2020-06-26 23:57:33	2020-06-26	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	32911	delivery	5	26
85484	2020-06-26 23:59:25	2020-06-26	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	20366	delivery	5	37
85485	2020-06-26 23:59:34	2020-06-26	12	[{"id_menu":3,"count":1}]	33495	pick-up	0	12
85486	2020-06-27 00:08:13	2020-06-27	9	[{"id_menu":6,"count":1}]	33673	delivery	5	14
85487	2020-06-27 00:10:25	2020-06-27	9	[{"id_menu":6,"count":1}]	15679	delivery	5	14
85488	2020-06-27 00:11:54	2020-06-27	9	[{"id_menu":6,"count":1}]	10798	delivery	5	14
85489	2020-06-27 00:13:13	2020-06-27	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	33551	delivery	5	26
85490	2020-06-27 00:13:42	2020-06-27	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	18127	delivery	5	34
85491	2020-06-27 00:14:10	2020-06-27	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	33583	delivery	5	26
85492	2020-06-27 00:14:17	2020-06-27	9	[{"id_menu":6,"count":1}]	467	pick-up	0	9
85493	2020-06-27 00:14:27	2020-06-27	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	33554	delivery	5	26
85494	2020-06-27 00:16:25	2020-06-27	14	[{"id_menu":2,"count":1}]	33704	pick-up	0	14
85495	2020-06-27 00:19:24	2020-06-27	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	3785	delivery	5	25
85496	2020-06-27 00:20:13	2020-06-27	12	[{"id_menu":1,"count":1}]	8555	delivery	5	17
85497	2020-06-27 00:21:23	2020-06-27	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":3}]	9838	delivery	5	28
85498	2020-06-27 00:24:02	2020-06-27	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	29408	delivery	5	22
85499	2020-06-27 00:24:42	2020-06-27	9	[{"id_menu":7,"count":1}]	16826	delivery	5	14
85500	2020-06-27 00:28:46	2020-06-27	17	[{"id_menu":4,"count":1}]	14641	delivery	5	22
85501	2020-06-27 00:30:39	2020-06-27	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16565	delivery	5	36
85502	2020-06-27 00:32:11	2020-06-27	9	[{"id_menu":7,"count":1}]	29607	pick-up	0	9
85503	2020-06-27 00:32:32	2020-06-27	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	11187	delivery	5	26
85504	2020-06-27 00:32:53	2020-06-27	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3650	pick-up	0	26
85505	2020-06-27 00:33:21	2020-06-27	9	[{"id_menu":7,"count":1}]	16528	delivery	5	14
85506	2020-06-27 00:33:48	2020-06-27	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	29824	delivery	5	31
85507	2020-06-27 00:34:12	2020-06-27	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24059	delivery	5	34
85508	2020-06-27 00:34:23	2020-06-27	12	[{"id_menu":3,"count":1}]	20931	delivery	5	17
85509	2020-06-27 00:35:13	2020-06-27	17	[{"id_menu":4,"count":1}]	33615	delivery	5	22
85510	2020-06-27 00:41:17	2020-06-27	34	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	33729	delivery	5	39
85511	2020-06-27 00:43:36	2020-06-27	9	[{"id_menu":6,"count":1}]	33668	delivery	5	14
85512	2020-06-27 00:52:55	2020-06-27	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2403	pick-up	0	22
85513	2020-06-27 00:54:05	2020-06-27	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33651	delivery	5	31
85514	2020-06-27 01:00:46	2020-06-27	9	[{"id_menu":6,"count":2}]	33593	delivery	5	14
85515	2020-06-27 01:01:27	2020-06-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	33611	delivery	5	22
85516	2020-06-27 01:01:43	2020-06-27	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	972	delivery	5	25
85517	2020-06-27 01:03:11	2020-06-27	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	14025	pick-up	0	26
85518	2020-06-27 01:03:41	2020-06-27	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	33510	delivery	5	26
85519	2020-06-27 01:04:46	2020-06-27	14	[{"id_menu":2,"count":1}]	4496	pick-up	0	14
85520	2020-06-27 01:11:39	2020-06-27	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	3413	delivery	5	25
85521	2020-06-27 01:13:50	2020-06-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7328	pick-up	0	31
85522	2020-06-27 01:14:04	2020-06-27	17	[{"id_menu":4,"count":1}]	15187	delivery	5	22
85523	2020-06-27 01:16:03	2020-06-27	12	[{"id_menu":3,"count":1}]	33721	delivery	5	17
85524	2020-06-27 01:17:13	2020-06-27	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	5417	delivery	5	39
85525	2020-06-27 01:18:29	2020-06-27	14	[{"id_menu":2,"count":1}]	10850	pick-up	0	14
85526	2020-06-27 01:22:46	2020-06-27	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	11887	pick-up	0	39
85527	2020-06-27 01:22:51	2020-06-27	14	[{"id_menu":2,"count":1}]	11251	delivery	5	19
85528	2020-06-27 01:23:17	2020-06-27	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	33563	delivery	5	26
85529	2020-06-27 01:24:59	2020-06-27	17	[{"id_menu":4,"count":1}]	27479	delivery	5	22
85530	2020-06-27 01:26:47	2020-06-27	12	[{"id_menu":1,"count":1}]	29052	pick-up	0	12
85531	2020-06-27 01:27:25	2020-06-27	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	33644	delivery	5	37
85532	2020-06-27 01:28:56	2020-06-27	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14363	delivery	5	40
85533	2020-06-27 01:32:06	2020-06-27	9	[{"id_menu":6,"count":1}]	33643	delivery	5	14
85534	2020-06-27 01:32:20	2020-06-27	14	[{"id_menu":2,"count":1}]	4729	delivery	5	19
85535	2020-06-27 01:36:48	2020-06-27	9	[{"id_menu":6,"count":1}]	17652	delivery	5	14
85536	2020-06-27 01:45:03	2020-06-27	12	[{"id_menu":3,"count":1}]	33692	delivery	5	17
85537	2020-06-27 01:45:05	2020-06-27	12	[{"id_menu":3,"count":1}]	16367	delivery	5	17
85538	2020-06-27 01:45:47	2020-06-27	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	19300	pick-up	0	21
85539	2020-06-27 01:46:16	2020-06-27	17	[{"id_menu":4,"count":1}]	32860	pick-up	0	17
85540	2020-06-27 01:47:23	2020-06-27	9	[{"id_menu":7,"count":1}]	25915	pick-up	0	9
85541	2020-06-27 01:47:31	2020-06-27	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33620	delivery	5	47
85542	2020-06-27 01:50:23	2020-06-27	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	33727	delivery	5	34
85543	2020-06-27 01:52:51	2020-06-27	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3168	pick-up	0	22
85544	2020-06-27 01:54:05	2020-06-27	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4578	pick-up	0	26
85545	2020-06-27 01:55:23	2020-06-27	9	[{"id_menu":6,"count":1}]	33684	delivery	5	14
85546	2020-06-27 01:56:07	2020-06-27	9	[{"id_menu":6,"count":1}]	24581	delivery	5	14
85547	2020-06-27 01:57:53	2020-06-27	8	[{"id_menu":5,"count":1}]	7801	delivery	5	13
85548	2020-06-27 01:58:53	2020-06-27	17	[{"id_menu":4,"count":1}]	391	delivery	5	22
85549	2020-06-27 01:59:24	2020-06-27	9	[{"id_menu":7,"count":1}]	33713	delivery	5	14
85550	2020-06-27 02:01:38	2020-06-27	14	[{"id_menu":2,"count":1}]	18320	pick-up	0	14
85551	2020-06-27 02:01:48	2020-06-27	17	[{"id_menu":4,"count":1}]	7550	pick-up	0	17
85552	2020-06-27 02:03:57	2020-06-27	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	33596	delivery	5	26
85553	2020-06-27 02:03:58	2020-06-27	14	[{"id_menu":2,"count":1}]	33708	pick-up	0	14
85554	2020-06-27 02:05:02	2020-06-27	8	[{"id_menu":5,"count":1}]	5351	delivery	5	13
85555	2020-06-27 02:08:59	2020-06-27	9	[{"id_menu":7,"count":1}]	33649	delivery	5	14
85556	2020-06-27 02:12:54	2020-06-27	14	[{"id_menu":2,"count":1}]	13501	delivery	5	19
85557	2020-06-27 02:14:13	2020-06-27	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	2426	pick-up	0	20
85558	2020-06-27 02:15:00	2020-06-27	17	[{"id_menu":4,"count":1}]	10679	pick-up	0	17
85559	2020-06-27 02:17:39	2020-06-27	14	[{"id_menu":2,"count":2}]	33624	delivery	5	19
85560	2020-06-27 02:18:16	2020-06-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	20657	delivery	5	28
85561	2020-06-27 02:20:05	2020-06-27	17	[{"id_menu":4,"count":1}]	18351	delivery	5	22
85562	2020-06-27 02:20:16	2020-06-27	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	33613	delivery	5	25
85563	2020-06-27 02:24:47	2020-06-27	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8937	delivery	5	43
85564	2020-06-27 02:25:35	2020-06-27	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8601	delivery	5	31
85565	2020-06-27 02:27:35	2020-06-27	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	33663	delivery	5	31
85566	2020-06-27 02:27:51	2020-06-27	9	[{"id_menu":7,"count":1}]	12913	delivery	5	14
85567	2020-06-27 02:31:17	2020-06-27	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	10764	delivery	5	26
85568	2020-06-27 02:33:44	2020-06-27	8	[{"id_menu":5,"count":1}]	1860	pick-up	0	8
85569	2020-06-27 02:36:25	2020-06-27	14	[{"id_menu":2,"count":1}]	13352	delivery	5	19
85570	2020-06-27 02:38:01	2020-06-27	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	24621	delivery	5	30
85571	2020-06-27 02:38:56	2020-06-27	14	[{"id_menu":2,"count":1}]	14216	delivery	5	19
85572	2020-06-27 02:41:06	2020-06-27	9	[{"id_menu":6,"count":1}]	14024	delivery	5	14
85573	2020-06-27 02:41:36	2020-06-27	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5427	pick-up	0	52
85574	2020-06-27 02:42:38	2020-06-27	8	[{"id_menu":5,"count":1}]	27833	delivery	5	13
85575	2020-06-27 02:45:13	2020-06-27	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	33598	delivery	5	36
85576	2020-06-27 02:47:36	2020-06-27	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20573	delivery	5	31
85577	2020-06-27 02:50:58	2020-06-27	14	[{"id_menu":2,"count":1}]	21970	delivery	5	19
85578	2020-06-27 02:53:41	2020-06-27	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	33512	delivery	5	43
85579	2020-06-27 02:54:19	2020-06-27	8	[{"id_menu":5,"count":1}]	33015	delivery	5	13
85580	2020-06-27 02:54:50	2020-06-27	9	[{"id_menu":6,"count":1}]	10898	delivery	5	14
85581	2020-06-27 02:56:59	2020-06-27	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	33720	delivery	5	35
85582	2020-06-27 03:00:27	2020-06-27	9	[{"id_menu":7,"count":1}]	33580	delivery	5	14
85583	2020-06-27 03:00:30	2020-06-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	33619	delivery	5	28
85584	2020-06-27 03:01:41	2020-06-27	9	[{"id_menu":6,"count":1}]	31856	delivery	5	14
85585	2020-06-27 03:01:48	2020-06-27	9	[{"id_menu":7,"count":1}]	33710	delivery	5	14
85586	2020-06-27 03:01:56	2020-06-27	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	7573	delivery	5	40
85587	2020-06-27 03:02:49	2020-06-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33549	delivery	5	23
85588	2020-06-27 03:03:33	2020-06-27	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1918	pick-up	0	23
85589	2020-06-27 03:03:35	2020-06-27	8	[{"id_menu":5,"count":1}]	33511	delivery	5	13
85590	2020-06-27 03:05:12	2020-06-27	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	33716	delivery	5	38
85591	2020-06-27 03:07:47	2020-06-27	9	[{"id_menu":6,"count":1}]	13393	delivery	5	14
85592	2020-06-27 03:16:36	2020-06-27	12	[{"id_menu":3,"count":1}]	19272	pick-up	0	12
85593	2020-06-27 03:17:11	2020-06-27	9	[{"id_menu":6,"count":1}]	33589	delivery	5	14
85594	2020-06-27 03:17:18	2020-06-27	8	[{"id_menu":5,"count":1}]	32009	delivery	5	13
85595	2020-06-27 03:18:25	2020-06-27	9	[{"id_menu":7,"count":1}]	33547	delivery	5	14
85596	2020-06-27 03:18:27	2020-06-27	8	[{"id_menu":5,"count":1}]	10954	pick-up	0	8
85597	2020-06-27 03:21:40	2020-06-27	14	[{"id_menu":2,"count":1}]	8887	pick-up	0	14
85598	2020-06-27 03:28:41	2020-06-27	9	[{"id_menu":6,"count":1}]	29193	delivery	5	14
85599	2020-06-27 03:32:30	2020-06-27	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":2}]	33671	delivery	5	31
85600	2020-06-27 03:32:41	2020-06-27	17	[{"id_menu":4,"count":1}]	32934	delivery	5	22
85601	2020-06-27 03:37:35	2020-06-27	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1152	pick-up	0	21
85602	2020-06-27 03:41:31	2020-06-27	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	14123	delivery	5	22
85603	2020-06-27 03:42:51	2020-06-27	8	[{"id_menu":5,"count":1}]	33233	delivery	5	13
85604	2020-06-27 03:45:12	2020-06-27	14	[{"id_menu":2,"count":1}]	20136	pick-up	0	14
85605	2020-06-27 03:45:21	2020-06-27	14	[{"id_menu":2,"count":1}]	33568	delivery	5	19
85606	2020-06-27 03:48:00	2020-06-27	55	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	10994	delivery	5	60
85607	2020-06-27 03:49:49	2020-06-27	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7752	delivery	5	37
85608	2020-06-27 03:50:10	2020-06-27	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10422	delivery	5	30
85609	2020-06-27 03:50:52	2020-06-27	9	[{"id_menu":6,"count":1}]	27360	delivery	5	14
85610	2020-06-27 03:54:38	2020-06-27	8	[{"id_menu":5,"count":1}]	33576	delivery	5	13
85611	2020-06-27 03:56:24	2020-06-27	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	18919	delivery	5	29
85612	2020-06-27 03:58:18	2020-06-27	12	[{"id_menu":1,"count":1}]	33700	delivery	5	17
85613	2020-06-27 03:59:17	2020-06-27	9	[{"id_menu":6,"count":1}]	24950	pick-up	0	9
85614	2020-06-27 04:02:31	2020-06-27	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13677	pick-up	0	17
85615	2020-06-27 04:12:17	2020-06-27	12	[{"id_menu":3,"count":1}]	33636	delivery	5	17
85616	2020-06-27 04:14:17	2020-06-27	9	[{"id_menu":7,"count":1}]	13014	delivery	5	14
85617	2020-06-27 04:15:05	2020-06-27	9	[{"id_menu":6,"count":1}]	24777	delivery	5	14
85618	2020-06-27 04:17:02	2020-06-27	17	[{"id_menu":4,"count":1}]	31533	delivery	5	22
85619	2020-06-27 04:20:47	2020-06-27	8	[{"id_menu":5,"count":1}]	27039	pick-up	0	8
85620	2020-06-27 04:20:58	2020-06-27	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	33654	delivery	5	34
85621	2020-06-27 04:28:04	2020-06-27	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	26317	delivery	5	31
85622	2020-06-27 04:29:02	2020-06-27	9	[{"id_menu":6,"count":1}]	2916	delivery	5	14
85623	2020-06-27 04:34:14	2020-06-27	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	32315	delivery	5	23
85624	2020-06-27 04:35:56	2020-06-27	8	[{"id_menu":5,"count":1}]	33660	delivery	5	13
85625	2020-06-27 04:36:40	2020-06-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4983	delivery	5	36
85626	2020-06-27 04:38:46	2020-06-27	14	[{"id_menu":2,"count":1}]	12593	pick-up	0	14
85627	2020-06-27 04:39:03	2020-06-27	12	[{"id_menu":1,"count":1}]	24752	delivery	5	17
85628	2020-06-27 04:39:32	2020-06-27	12	[{"id_menu":3,"count":1}]	33212	delivery	5	17
85629	2020-06-27 04:39:36	2020-06-27	12	[{"id_menu":3,"count":1}]	7901	delivery	5	17
85630	2020-06-27 04:43:36	2020-06-27	12	[{"id_menu":1,"count":1}]	33545	delivery	5	17
85631	2020-06-27 04:50:24	2020-06-27	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	21241	delivery	5	31
85632	2020-06-27 04:54:01	2020-06-27	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	4100	delivery	5	22
85633	2020-06-27 04:55:36	2020-06-27	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	33546	delivery	5	29
85634	2020-06-27 04:56:19	2020-06-27	14	[{"id_menu":2,"count":1}]	3293	delivery	5	19
85635	2020-06-27 04:59:55	2020-06-27	9	[{"id_menu":7,"count":1}]	10598	delivery	5	14
85636	2020-06-27 05:01:44	2020-06-27	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	18839	pick-up	0	21
85637	2020-06-27 05:03:11	2020-06-27	17	[{"id_menu":4,"count":2}]	25799	delivery	5	22
85638	2020-06-27 05:05:47	2020-06-27	8	[{"id_menu":5,"count":1}]	28927	delivery	5	13
85639	2020-06-27 05:06:28	2020-06-27	9	[{"id_menu":7,"count":1}]	26602	delivery	5	14
85640	2020-06-27 05:07:49	2020-06-27	9	[{"id_menu":7,"count":1}]	33517	delivery	5	14
85641	2020-06-27 05:08:57	2020-06-27	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1424	pick-up	0	26
85642	2020-06-27 05:10:12	2020-06-27	9	[{"id_menu":7,"count":1}]	33621	delivery	5	14
85643	2020-06-27 05:13:17	2020-06-27	12	[{"id_menu":1,"count":1}]	5311	delivery	5	17
85644	2020-06-27 05:13:22	2020-06-27	9	[{"id_menu":7,"count":1}]	3447	pick-up	0	9
85645	2020-06-27 05:19:13	2020-06-27	12	[{"id_menu":1,"count":1}]	17408	delivery	5	17
85646	2020-06-27 05:19:36	2020-06-27	14	[{"id_menu":2,"count":1}]	33655	delivery	5	19
85647	2020-06-27 05:19:45	2020-06-27	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	33622	delivery	5	22
85648	2020-06-27 05:26:35	2020-06-27	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	33675	delivery	5	26
85649	2020-06-27 05:28:59	2020-06-27	12	[{"id_menu":1,"count":1}]	13317	pick-up	0	12
85650	2020-06-27 05:31:23	2020-06-27	14	[{"id_menu":2,"count":1}]	1815	pick-up	0	14
85651	2020-06-27 05:31:25	2020-06-27	9	[{"id_menu":6,"count":1}]	32572	delivery	5	14
85652	2020-06-27 05:32:32	2020-06-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	10509	delivery	5	28
85653	2020-06-27 05:33:58	2020-06-27	9	[{"id_menu":7,"count":1}]	3197	delivery	5	14
85654	2020-06-27 05:36:11	2020-06-27	8	[{"id_menu":5,"count":1}]	22128	delivery	5	13
85655	2020-06-27 05:37:03	2020-06-27	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	33566	delivery	5	34
85656	2020-06-27 05:38:28	2020-06-27	12	[{"id_menu":3,"count":2}]	6685	delivery	5	17
85657	2020-06-27 05:43:25	2020-06-27	9	[{"id_menu":6,"count":1}]	4223	pick-up	0	9
85658	2020-06-27 05:43:29	2020-06-27	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	33640	delivery	5	27
85659	2020-06-27 05:43:39	2020-06-27	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	33	pick-up	0	20
85660	2020-06-27 05:48:38	2020-06-27	9	[{"id_menu":7,"count":1}]	20475	delivery	5	14
85661	2020-06-27 05:48:49	2020-06-27	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	33542	delivery	5	26
85662	2020-06-27 05:49:12	2020-06-27	12	[{"id_menu":1,"count":1}]	24760	delivery	5	17
85663	2020-06-27 05:50:57	2020-06-27	12	[{"id_menu":3,"count":1}]	33639	delivery	5	17
85664	2020-06-27 05:51:22	2020-06-27	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	33581	delivery	5	31
85665	2020-06-27 05:52:24	2020-06-27	12	[{"id_menu":3,"count":1}]	23105	delivery	5	17
85666	2020-06-27 05:55:40	2020-06-27	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	33715	delivery	5	27
85667	2020-06-27 05:57:53	2020-06-27	8	[{"id_menu":5,"count":2}]	33605	delivery	5	13
85668	2020-06-27 06:02:19	2020-06-27	14	[{"id_menu":2,"count":1}]	66	delivery	5	19
85669	2020-06-27 06:04:08	2020-06-27	8	[{"id_menu":5,"count":1}]	33572	delivery	5	13
85670	2020-06-27 06:05:41	2020-06-27	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	17948	delivery	5	31
85671	2020-06-27 06:06:37	2020-06-27	14	[{"id_menu":2,"count":1}]	10452	pick-up	0	14
85672	2020-06-27 06:07:00	2020-06-27	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	9779	delivery	5	40
85673	2020-06-27 06:09:43	2020-06-27	8	[{"id_menu":5,"count":1}]	33731	delivery	5	13
85674	2020-06-27 06:15:14	2020-06-27	12	[{"id_menu":1,"count":1}]	18369	pick-up	0	12
85675	2020-06-27 06:16:21	2020-06-27	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20823	delivery	5	48
85676	2020-06-27 06:16:31	2020-06-27	12	[{"id_menu":3,"count":1}]	33529	delivery	5	17
85677	2020-06-27 06:23:34	2020-06-27	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	16840	delivery	5	26
85678	2020-06-27 06:24:08	2020-06-27	9	[{"id_menu":7,"count":1}]	33607	delivery	5	14
85679	2020-06-27 06:26:24	2020-06-27	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	27343	delivery	5	26
85680	2020-06-27 06:27:24	2020-06-27	14	[{"id_menu":2,"count":1}]	29255	delivery	5	19
85681	2020-06-27 06:27:44	2020-06-27	8	[{"id_menu":5,"count":1}]	30329	pick-up	0	8
85682	2020-06-27 06:27:55	2020-06-27	9	[{"id_menu":6,"count":1}]	10495	delivery	5	14
85683	2020-06-27 06:29:30	2020-06-27	17	[{"id_menu":4,"count":1}]	20408	pick-up	0	17
85684	2020-06-27 06:30:42	2020-06-27	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	33557	delivery	5	38
85685	2020-06-27 06:36:26	2020-06-27	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	33707	delivery	5	34
85686	2020-06-27 06:37:53	2020-06-27	9	[{"id_menu":7,"count":1}]	15864	delivery	5	14
85687	2020-06-27 06:38:46	2020-06-27	12	[{"id_menu":1,"count":1}]	33570	delivery	5	17
85688	2020-06-27 06:39:04	2020-06-27	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	33537	delivery	5	25
85689	2020-06-27 06:39:44	2020-06-27	9	[{"id_menu":7,"count":1}]	27549	delivery	5	14
85690	2020-06-27 06:41:15	2020-06-27	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14711	delivery	5	53
85691	2020-06-27 06:42:46	2020-06-27	14	[{"id_menu":2,"count":1}]	33734	delivery	5	19
85692	2020-06-27 06:46:14	2020-06-27	8	[{"id_menu":5,"count":1}]	18707	delivery	5	13
85693	2020-06-27 06:46:32	2020-06-27	8	[{"id_menu":5,"count":1}]	26944	delivery	5	13
85694	2020-06-27 06:56:38	2020-06-27	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	6327	pick-up	0	21
85695	2020-06-27 06:58:16	2020-06-27	14	[{"id_menu":2,"count":1}]	32566	delivery	5	19
85696	2020-06-27 07:00:08	2020-06-27	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	33635	delivery	5	36
85697	2020-06-27 07:00:31	2020-06-27	9	[{"id_menu":6,"count":1}]	24018	pick-up	0	9
85698	2020-06-27 07:03:18	2020-06-27	9	[{"id_menu":6,"count":1}]	33567	delivery	5	14
85699	2020-06-27 07:05:15	2020-06-27	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	16411	delivery	5	31
85700	2020-06-27 07:07:43	2020-06-27	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	26361	delivery	5	52
85701	2020-06-27 07:09:13	2020-06-27	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	11798	delivery	5	31
85702	2020-06-27 07:09:31	2020-06-27	12	[{"id_menu":3,"count":1}]	16923	delivery	5	17
85703	2020-06-27 07:10:28	2020-06-27	9	[{"id_menu":7,"count":1}]	8559	delivery	5	14
85704	2020-06-27 07:12:40	2020-06-27	12	[{"id_menu":1,"count":1}]	7921	pick-up	0	12
85705	2020-06-27 07:14:08	2020-06-27	12	[{"id_menu":1,"count":1}]	21808	pick-up	0	12
85706	2020-06-27 07:19:47	2020-06-27	9	[{"id_menu":7,"count":1}]	33625	delivery	5	14
85707	2020-06-27 07:21:08	2020-06-27	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	31104	delivery	5	44
85708	2020-06-27 07:22:45	2020-06-27	17	[{"id_menu":4,"count":1}]	1523	pick-up	0	17
85709	2020-06-27 07:38:02	2020-06-27	9	[{"id_menu":7,"count":1}]	30428	delivery	5	14
85710	2020-06-27 07:38:54	2020-06-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	13950	pick-up	0	31
85711	2020-06-27 07:40:42	2020-06-27	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33524	delivery	5	40
85712	2020-06-27 07:43:36	2020-06-27	9	[{"id_menu":6,"count":2}]	33647	pick-up	0	9
85713	2020-06-27 07:43:42	2020-06-27	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	20782	pick-up	0	26
85714	2020-06-27 07:46:51	2020-06-27	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	11334	pick-up	0	21
85715	2020-06-27 07:48:04	2020-06-27	12	[{"id_menu":3,"count":2}]	7627	delivery	5	17
85716	2020-06-27 07:48:10	2020-06-27	8	[{"id_menu":5,"count":1}]	31876	pick-up	0	8
85717	2020-06-27 07:48:12	2020-06-27	9	[{"id_menu":6,"count":1}]	25284	delivery	5	14
85718	2020-06-27 07:52:30	2020-06-27	12	[{"id_menu":3,"count":1}]	33719	pick-up	0	12
85719	2020-06-27 07:55:06	2020-06-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	5654	delivery	5	36
85720	2020-06-27 07:56:03	2020-06-27	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33585	delivery	5	52
85721	2020-06-27 08:00:12	2020-06-27	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	33623	delivery	5	34
85722	2020-06-27 08:03:00	2020-06-27	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33578	delivery	5	47
85723	2020-06-27 08:03:42	2020-06-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	33676	delivery	5	36
85724	2020-06-27 08:03:47	2020-06-27	12	[{"id_menu":1,"count":1}]	5758	pick-up	0	12
85725	2020-06-27 08:04:43	2020-06-27	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	26461	delivery	5	36
85726	2020-06-27 08:06:49	2020-06-27	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	33664	delivery	5	31
85727	2020-06-27 08:07:16	2020-06-27	12	[{"id_menu":1,"count":1}]	16218	delivery	5	17
85728	2020-06-27 08:07:18	2020-06-27	14	[{"id_menu":2,"count":1}]	19313	pick-up	0	14
85729	2020-06-27 08:12:17	2020-06-27	9	[{"id_menu":7,"count":1}]	30205	delivery	5	14
85730	2020-06-27 08:17:42	2020-06-27	9	[{"id_menu":6,"count":1}]	17135	delivery	5	14
85731	2020-06-27 08:17:44	2020-06-27	17	[{"id_menu":4,"count":2}]	4486	pick-up	0	17
85732	2020-06-27 08:19:47	2020-06-27	8	[{"id_menu":5,"count":1}]	23449	delivery	5	13
85733	2020-06-27 08:19:53	2020-06-27	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	29036	delivery	5	51
85734	2020-06-27 08:20:10	2020-06-27	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10502	delivery	5	40
85735	2020-06-27 08:20:13	2020-06-27	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	33601	delivery	5	56
85736	2020-06-27 08:20:40	2020-06-27	8	[{"id_menu":5,"count":1}]	5550	delivery	5	13
85737	2020-06-27 08:21:58	2020-06-27	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	33652	delivery	5	53
85738	2020-06-27 08:22:03	2020-06-27	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	27752	delivery	5	34
85739	2020-06-27 08:25:05	2020-06-27	9	[{"id_menu":7,"count":1}]	6883	delivery	5	14
85740	2020-06-27 08:27:25	2020-06-27	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	25929	delivery	5	31
85741	2020-06-27 08:27:28	2020-06-27	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1563	pick-up	0	39
85742	2020-06-27 08:29:22	2020-06-27	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	30106	delivery	5	34
85743	2020-06-27 08:29:23	2020-06-27	9	[{"id_menu":6,"count":1}]	33533	delivery	5	14
85744	2020-06-27 08:29:43	2020-06-27	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	33653	delivery	5	45
85745	2020-06-27 08:30:47	2020-06-27	12	[{"id_menu":1,"count":1}]	12823	delivery	5	17
85746	2020-06-27 08:33:23	2020-06-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	33672	delivery	5	23
85747	2020-06-27 08:34:45	2020-06-27	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33669	delivery	5	49
85748	2020-06-27 08:36:21	2020-06-27	12	[{"id_menu":3,"count":1}]	1568	delivery	5	17
85749	2020-06-27 08:38:31	2020-06-27	8	[{"id_menu":5,"count":1}]	2200	delivery	5	13
85750	2020-06-27 08:39:43	2020-06-27	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	33508	delivery	5	28
85751	2020-06-27 08:40:15	2020-06-27	9	[{"id_menu":6,"count":1}]	21888	delivery	5	14
85752	2020-06-27 08:45:08	2020-06-27	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	13758	delivery	5	27
85753	2020-06-27 08:58:14	2020-06-27	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	12061	delivery	5	31
85754	2020-06-27 09:00:09	2020-06-27	8	[{"id_menu":5,"count":1}]	22084	delivery	5	13
85755	2020-06-27 09:00:12	2020-06-27	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1729	pick-up	0	20
85756	2020-06-27 09:03:31	2020-06-27	8	[{"id_menu":5,"count":1}]	6546	delivery	5	13
85757	2020-06-27 09:04:13	2020-06-27	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15171	delivery	5	39
85758	2020-06-27 09:08:14	2020-06-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33661	delivery	5	23
85759	2020-06-27 09:08:52	2020-06-27	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	6987	delivery	5	31
85760	2020-06-27 09:09:19	2020-06-27	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	10125	delivery	5	30
85761	2020-06-27 09:11:29	2020-06-27	8	[{"id_menu":5,"count":1}]	23287	delivery	5	13
85762	2020-06-27 09:12:13	2020-06-27	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	33689	pick-up	0	24
85763	2020-06-27 09:16:55	2020-06-27	12	[{"id_menu":1,"count":1}]	14181	pick-up	0	12
85764	2020-06-27 09:20:50	2020-06-27	17	[{"id_menu":4,"count":1}]	156	pick-up	0	17
85765	2020-06-27 09:21:04	2020-06-27	17	[{"id_menu":4,"count":1}]	33626	delivery	5	22
85766	2020-06-27 09:23:49	2020-06-27	9	[{"id_menu":7,"count":1}]	33698	pick-up	0	9
85767	2020-06-27 09:27:02	2020-06-27	9	[{"id_menu":6,"count":1}]	17520	delivery	5	14
85768	2020-06-27 09:27:29	2020-06-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	5077	delivery	5	36
85769	2020-06-27 09:29:24	2020-06-27	17	[{"id_menu":4,"count":2}]	33670	pick-up	0	17
85770	2020-06-27 09:30:18	2020-06-27	17	[{"id_menu":4,"count":2}]	32187	delivery	5	22
85771	2020-06-27 09:30:27	2020-06-27	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17714	delivery	5	57
85772	2020-06-27 09:32:19	2020-06-27	12	[{"id_menu":3,"count":1}]	359	delivery	5	17
85773	2020-06-27 09:33:00	2020-06-27	9	[{"id_menu":6,"count":1}]	13392	delivery	5	14
85774	2020-06-27 09:33:03	2020-06-27	9	[{"id_menu":7,"count":1}]	28112	delivery	5	14
85775	2020-06-27 09:33:06	2020-06-27	9	[{"id_menu":6,"count":1}]	9414	pick-up	0	9
85776	2020-06-27 09:34:40	2020-06-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	12578	pick-up	0	31
85777	2020-06-27 09:39:28	2020-06-27	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14389	delivery	5	48
85778	2020-06-27 09:41:35	2020-06-27	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1093	pick-up	0	29
85779	2020-06-27 09:42:27	2020-06-27	9	[{"id_menu":6,"count":1}]	33531	delivery	5	14
85780	2020-06-27 09:46:44	2020-06-27	14	[{"id_menu":2,"count":1}]	18940	delivery	5	19
85781	2020-06-27 09:47:26	2020-06-27	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	20016	delivery	5	23
85782	2020-06-27 09:48:01	2020-06-27	9	[{"id_menu":7,"count":1}]	30812	delivery	5	14
85783	2020-06-27 09:51:02	2020-06-27	9	[{"id_menu":6,"count":1}]	31930	delivery	5	14
85784	2020-06-27 09:52:19	2020-06-27	12	[{"id_menu":3,"count":1}]	33538	delivery	5	17
85785	2020-06-27 09:57:25	2020-06-27	9	[{"id_menu":7,"count":1}]	13446	delivery	5	14
85786	2020-06-27 10:04:05	2020-06-27	9	[{"id_menu":7,"count":1}]	32846	delivery	5	14
85787	2020-06-27 10:06:42	2020-06-27	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	25823	delivery	5	26
85788	2020-06-27 10:08:20	2020-06-27	9	[{"id_menu":7,"count":1}]	15453	delivery	5	14
85789	2020-06-27 10:08:26	2020-06-27	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	21771	delivery	5	26
85790	2020-06-27 10:14:25	2020-06-27	14	[{"id_menu":2,"count":1}]	14284	delivery	5	19
85791	2020-06-27 10:18:13	2020-06-27	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22468	delivery	5	22
85792	2020-06-27 10:19:15	2020-06-27	9	[{"id_menu":6,"count":1}]	33687	delivery	5	14
85793	2020-06-27 10:21:33	2020-06-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24759	delivery	5	23
85794	2020-06-27 10:22:25	2020-06-27	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18658	delivery	5	39
85795	2020-06-27 10:29:22	2020-06-27	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	30088	delivery	5	39
85796	2020-06-27 10:30:03	2020-06-27	14	[{"id_menu":2,"count":1}]	31716	delivery	5	19
85797	2020-06-27 10:30:47	2020-06-27	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6277	pick-up	0	30
85798	2020-06-27 10:31:51	2020-06-27	8	[{"id_menu":5,"count":1}]	5570	delivery	5	13
85799	2020-06-27 10:42:40	2020-06-27	14	[{"id_menu":2,"count":1}]	9059	pick-up	0	14
85800	2020-06-27 10:43:19	2020-06-27	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	18900	delivery	5	28
85801	2020-06-27 10:45:49	2020-06-27	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	33610	delivery	5	43
85802	2020-06-27 10:46:00	2020-06-27	12	[{"id_menu":1,"count":1}]	33648	delivery	5	17
85803	2020-06-27 10:47:53	2020-06-27	9	[{"id_menu":7,"count":1}]	33641	delivery	5	14
85804	2020-06-27 10:48:43	2020-06-27	8	[{"id_menu":5,"count":1}]	27432	delivery	5	13
85805	2020-06-27 10:49:26	2020-06-27	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	33688	delivery	5	26
85806	2020-06-27 10:50:04	2020-06-27	12	[{"id_menu":3,"count":1}]	21697	delivery	5	17
85807	2020-06-27 10:51:14	2020-06-27	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	26621	delivery	5	34
85808	2020-06-27 10:55:04	2020-06-27	12	[{"id_menu":1,"count":1}]	8151	delivery	5	17
85809	2020-06-27 10:56:38	2020-06-27	9	[{"id_menu":7,"count":1}]	31378	delivery	5	14
85810	2020-06-27 10:57:19	2020-06-27	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	33701	delivery	5	31
85811	2020-06-27 10:57:37	2020-06-27	8	[{"id_menu":5,"count":1}]	33558	delivery	5	13
85812	2020-06-27 11:00:59	2020-06-27	9	[{"id_menu":6,"count":2}]	16216	delivery	5	14
85813	2020-06-27 11:01:34	2020-06-27	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	33714	delivery	5	26
85814	2020-06-27 11:03:07	2020-06-27	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	33612	delivery	5	43
85815	2020-06-27 11:05:03	2020-06-27	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	11806	delivery	5	44
85816	2020-06-27 11:07:33	2020-06-27	14	[{"id_menu":2,"count":1}]	28445	delivery	5	19
85817	2020-06-27 11:08:57	2020-06-27	12	[{"id_menu":1,"count":1}]	802	delivery	5	17
85818	2020-06-27 11:10:37	2020-06-27	9	[{"id_menu":6,"count":2}]	33662	delivery	5	14
85819	2020-06-27 11:11:10	2020-06-27	9	[{"id_menu":6,"count":1}]	27749	delivery	5	14
85820	2020-06-27 11:11:40	2020-06-27	9	[{"id_menu":7,"count":1}]	33577	delivery	5	14
85821	2020-06-27 11:12:38	2020-06-27	9	[{"id_menu":7,"count":1}]	11367	delivery	5	14
85822	2020-06-27 11:15:20	2020-06-27	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	32550	delivery	5	22
85823	2020-06-27 11:15:39	2020-06-27	9	[{"id_menu":6,"count":1}]	23504	delivery	5	14
85824	2020-06-27 11:16:37	2020-06-27	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	33712	delivery	5	52
85825	2020-06-27 11:18:15	2020-06-27	8	[{"id_menu":5,"count":1}]	33540	delivery	5	13
85826	2020-06-27 11:18:24	2020-06-27	17	[{"id_menu":4,"count":1}]	23481	delivery	5	22
85827	2020-06-27 11:18:54	2020-06-27	17	[{"id_menu":4,"count":1}]	25633	delivery	5	22
85828	2020-06-27 11:19:30	2020-06-27	9	[{"id_menu":6,"count":1}]	7122	delivery	5	14
85829	2020-06-27 11:19:34	2020-06-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	33587	delivery	5	22
85830	2020-06-27 11:19:50	2020-06-27	9	[{"id_menu":7,"count":1}]	33690	delivery	5	14
85831	2020-06-27 11:26:41	2020-06-27	12	[{"id_menu":1,"count":1}]	33556	delivery	5	17
85832	2020-06-27 11:27:14	2020-06-27	9	[{"id_menu":6,"count":1}]	20774	delivery	5	14
85833	2020-06-27 11:27:28	2020-06-27	14	[{"id_menu":2,"count":1}]	12429	pick-up	0	14
85834	2020-06-27 11:27:31	2020-06-27	12	[{"id_menu":1,"count":2}]	5430	pick-up	0	12
85835	2020-06-27 11:32:39	2020-06-27	8	[{"id_menu":5,"count":1}]	9533	delivery	5	13
85836	2020-06-27 11:36:39	2020-06-27	12	[{"id_menu":1,"count":1}]	12541	pick-up	0	12
85837	2020-06-27 11:38:31	2020-06-27	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	28440	pick-up	0	24
85838	2020-06-27 11:41:34	2020-06-27	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1985	delivery	5	42
85839	2020-06-27 11:42:10	2020-06-27	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	26126	delivery	5	34
85840	2020-06-27 11:42:14	2020-06-27	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	27066	delivery	5	26
85841	2020-06-27 11:42:33	2020-06-27	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	29763	delivery	5	26
85842	2020-06-27 11:45:02	2020-06-27	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	19453	delivery	5	36
85843	2020-06-27 11:48:10	2020-06-27	14	[{"id_menu":2,"count":1}]	33642	delivery	5	19
85844	2020-06-27 11:51:09	2020-06-27	9	[{"id_menu":7,"count":1}]	33618	pick-up	0	9
85845	2020-06-27 11:53:24	2020-06-27	9	[{"id_menu":7,"count":1}]	5509	delivery	5	14
85846	2020-06-27 11:54:55	2020-06-27	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	11651	delivery	5	28
85847	2020-06-27 11:57:03	2020-06-27	9	[{"id_menu":7,"count":1}]	9514	delivery	5	14
85848	2020-06-27 12:03:49	2020-06-27	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	12081	delivery	5	26
85849	2020-06-27 12:04:44	2020-06-27	14	[{"id_menu":2,"count":1}]	33562	delivery	5	19
85850	2020-06-27 12:09:45	2020-06-27	12	[{"id_menu":1,"count":1}]	16217	pick-up	0	12
85851	2020-06-27 12:13:38	2020-06-27	17	[{"id_menu":4,"count":1}]	28880	delivery	5	22
85852	2020-06-27 12:14:56	2020-06-27	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	431	pick-up	0	26
85853	2020-06-27 12:17:03	2020-06-27	9	[{"id_menu":6,"count":1}]	31780	delivery	5	14
85854	2020-06-27 12:17:08	2020-06-27	17	[{"id_menu":4,"count":1}]	48	pick-up	0	17
85855	2020-06-27 12:20:35	2020-06-27	9	[{"id_menu":7,"count":1}]	541	pick-up	0	9
85856	2020-06-27 12:20:47	2020-06-27	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2320	delivery	5	43
85857	2020-06-27 12:23:56	2020-06-27	9	[{"id_menu":6,"count":1}]	11543	delivery	5	14
85858	2020-06-27 12:24:24	2020-06-27	14	[{"id_menu":2,"count":2}]	17412	delivery	5	19
85859	2020-06-27 12:29:16	2020-06-27	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3135	delivery	5	34
85860	2020-06-27 12:32:22	2020-06-27	12	[{"id_menu":3,"count":1}]	16246	pick-up	0	12
85861	2020-06-27 12:34:04	2020-06-27	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	22321	delivery	5	34
85862	2020-06-27 12:34:13	2020-06-27	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":2}]	5024	delivery	5	27
85863	2020-06-27 12:35:11	2020-06-27	8	[{"id_menu":5,"count":1}]	31117	delivery	5	13
85864	2020-06-27 12:35:29	2020-06-27	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	25516	pick-up	0	26
85865	2020-06-27 12:39:30	2020-06-27	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7796	delivery	5	31
85866	2020-06-27 12:39:55	2020-06-27	9	[{"id_menu":6,"count":1}]	33571	pick-up	0	9
85867	2020-06-27 12:41:02	2020-06-27	8	[{"id_menu":5,"count":1}]	30413	delivery	5	13
85868	2020-06-27 12:43:32	2020-06-27	14	[{"id_menu":2,"count":1}]	4714	pick-up	0	14
85869	2020-06-27 12:47:30	2020-06-27	14	[{"id_menu":2,"count":1}]	19256	pick-up	0	14
85870	2020-06-27 12:48:19	2020-06-27	17	[{"id_menu":4,"count":1}]	3909	pick-up	0	17
85871	2020-06-27 12:53:26	2020-06-27	17	[{"id_menu":4,"count":1}]	33646	delivery	5	22
85872	2020-06-27 12:57:59	2020-06-27	12	[{"id_menu":1,"count":1}]	1143	pick-up	0	12
85873	2020-06-27 12:59:44	2020-06-27	8	[{"id_menu":5,"count":1}]	28113	pick-up	0	8
85874	2020-06-27 13:00:35	2020-06-27	12	[{"id_menu":1,"count":1}]	33709	delivery	5	17
85875	2020-06-27 13:01:06	2020-06-27	9	[{"id_menu":6,"count":1}]	4479	pick-up	0	9
85876	2020-06-27 13:01:23	2020-06-27	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	32268	delivery	5	29
85877	2020-06-27 13:02:24	2020-06-27	17	[{"id_menu":4,"count":1}]	4005	pick-up	0	17
85878	2020-06-27 13:02:37	2020-06-27	12	[{"id_menu":3,"count":1}]	33616	delivery	5	17
85879	2020-06-27 13:02:46	2020-06-27	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	10721	delivery	5	25
85880	2020-06-27 13:02:50	2020-06-27	17	[{"id_menu":4,"count":1}]	6046	pick-up	0	17
85881	2020-06-27 13:03:06	2020-06-27	8	[{"id_menu":5,"count":1}]	17227	delivery	5	13
85882	2020-06-27 13:03:07	2020-06-27	9	[{"id_menu":6,"count":1}]	33603	delivery	5	14
85883	2020-06-27 13:03:59	2020-06-27	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33609	delivery	5	31
85884	2020-06-27 13:04:41	2020-06-27	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1104	pick-up	0	24
85885	2020-06-27 13:07:59	2020-06-27	14	[{"id_menu":2,"count":1}]	16325	delivery	5	19
85886	2020-06-27 13:09:13	2020-06-27	12	[{"id_menu":3,"count":1}]	28225	pick-up	0	12
85887	2020-06-27 13:10:17	2020-06-27	9	[{"id_menu":6,"count":1}]	26201	pick-up	0	9
85888	2020-06-27 13:12:15	2020-06-27	12	[{"id_menu":1,"count":1}]	25161	pick-up	0	12
85889	2020-06-27 13:13:48	2020-06-27	12	[{"id_menu":3,"count":1}]	9112	pick-up	0	12
85890	2020-06-27 13:14:54	2020-06-27	9	[{"id_menu":6,"count":1}]	33696	delivery	5	14
85891	2020-06-27 13:15:15	2020-06-27	14	[{"id_menu":2,"count":1}]	4577	pick-up	0	14
85892	2020-06-27 13:20:32	2020-06-27	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	33604	delivery	5	43
85893	2020-06-27 13:21:11	2020-06-27	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	9873	delivery	5	25
85894	2020-06-27 13:21:25	2020-06-27	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	33521	delivery	5	45
85895	2020-06-27 13:22:58	2020-06-27	12	[{"id_menu":1,"count":1}]	21726	delivery	5	17
85896	2020-06-27 13:24:38	2020-06-27	9	[{"id_menu":6,"count":1}]	33659	delivery	5	14
85897	2020-06-27 13:30:35	2020-06-27	9	[{"id_menu":7,"count":1}]	33586	pick-up	0	9
85898	2020-06-27 13:30:48	2020-06-27	9	[{"id_menu":6,"count":1}]	14326	pick-up	0	9
85899	2020-06-27 13:32:27	2020-06-27	17	[{"id_menu":4,"count":1}]	25346	delivery	5	22
85900	2020-06-27 13:33:04	2020-06-27	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	15686	delivery	5	31
85901	2020-06-27 13:33:14	2020-06-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33679	delivery	5	23
85902	2020-06-27 13:33:30	2020-06-27	12	[{"id_menu":3,"count":1}]	18051	delivery	5	17
85903	2020-06-27 13:36:26	2020-06-27	8	[{"id_menu":5,"count":1}]	12827	delivery	5	13
85904	2020-06-27 13:38:26	2020-06-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	33658	delivery	5	36
85905	2020-06-27 13:42:52	2020-06-27	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	27533	delivery	5	27
85906	2020-06-27 13:47:41	2020-06-27	17	[{"id_menu":4,"count":1}]	33548	delivery	5	22
85907	2020-06-27 13:48:45	2020-06-27	14	[{"id_menu":2,"count":1}]	33632	delivery	5	19
85908	2020-06-27 13:50:04	2020-06-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	33667	pick-up	0	23
85909	2020-06-27 13:53:55	2020-06-27	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33634	delivery	5	31
85910	2020-06-27 13:56:53	2020-06-27	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	27329	delivery	5	34
85911	2020-06-27 13:57:14	2020-06-27	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	4605	delivery	5	34
85912	2020-06-27 13:58:07	2020-06-27	12	[{"id_menu":3,"count":1}]	15125	delivery	5	17
85913	2020-06-27 14:01:19	2020-06-27	9	[{"id_menu":6,"count":1}]	33599	delivery	5	14
85914	2020-06-27 14:01:53	2020-06-27	9	[{"id_menu":7,"count":1}]	15618	delivery	5	14
85915	2020-06-27 14:02:18	2020-06-27	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33569	delivery	5	40
85916	2020-06-27 14:02:55	2020-06-27	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	27873	delivery	5	35
85917	2020-06-27 14:05:44	2020-06-27	9	[{"id_menu":6,"count":1}]	33681	delivery	5	14
85918	2020-06-27 14:11:55	2020-06-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3327	delivery	5	36
85919	2020-06-27 14:13:10	2020-06-27	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	33574	delivery	5	56
85920	2020-06-27 14:14:27	2020-06-27	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6176	pick-up	0	40
85921	2020-06-27 14:16:38	2020-06-27	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	33702	delivery	5	34
85922	2020-06-27 14:18:48	2020-06-27	12	[{"id_menu":3,"count":1}]	33628	delivery	5	17
85923	2020-06-27 14:20:57	2020-06-27	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11089	delivery	5	43
85924	2020-06-27 14:31:19	2020-06-27	9	[{"id_menu":7,"count":1}]	25061	delivery	5	14
85925	2020-06-27 14:31:25	2020-06-27	8	[{"id_menu":5,"count":1}]	25650	delivery	5	13
85926	2020-06-27 14:31:48	2020-06-27	9	[{"id_menu":6,"count":1}]	33678	delivery	5	14
85927	2020-06-27 14:33:15	2020-06-27	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	33518	delivery	5	40
85928	2020-06-27 14:36:14	2020-06-27	9	[{"id_menu":7,"count":1}]	33680	delivery	5	14
85929	2020-06-27 14:36:31	2020-06-27	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9303	pick-up	0	25
85930	2020-06-27 14:36:45	2020-06-27	9	[{"id_menu":7,"count":1}]	33703	delivery	5	14
85931	2020-06-27 14:37:03	2020-06-27	14	[{"id_menu":2,"count":2}]	3621	pick-up	0	14
85932	2020-06-27 14:38:05	2020-06-27	8	[{"id_menu":5,"count":1}]	32270	delivery	5	13
85933	2020-06-27 14:40:01	2020-06-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	10828	pick-up	0	31
85934	2020-06-27 14:43:27	2020-06-27	12	[{"id_menu":3,"count":1}]	1760	pick-up	0	12
85935	2020-06-27 14:44:22	2020-06-27	14	[{"id_menu":2,"count":1}]	33516	pick-up	0	14
85936	2020-06-27 14:45:29	2020-06-27	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2728	pick-up	0	29
85937	2020-06-27 14:46:07	2020-06-27	12	[{"id_menu":1,"count":2}]	33665	delivery	5	17
85938	2020-06-27 14:47:56	2020-06-27	12	[{"id_menu":3,"count":1}]	10957	delivery	5	17
85939	2020-06-27 14:50:33	2020-06-27	9	[{"id_menu":6,"count":2}]	33594	delivery	5	14
85940	2020-06-27 14:52:08	2020-06-27	12	[{"id_menu":1,"count":1}]	33536	delivery	5	17
85941	2020-06-27 14:52:20	2020-06-27	9	[{"id_menu":7,"count":1}]	31280	delivery	5	14
85942	2020-06-27 14:52:58	2020-06-27	9	[{"id_menu":6,"count":1}]	8573	delivery	5	14
85943	2020-06-27 14:53:38	2020-06-27	17	[{"id_menu":4,"count":1}]	660	pick-up	0	17
85944	2020-06-27 14:54:50	2020-06-27	8	[{"id_menu":5,"count":1}]	21386	delivery	5	13
85945	2020-06-27 14:55:25	2020-06-27	9	[{"id_menu":7,"count":1}]	4998	delivery	5	14
85946	2020-06-27 14:59:07	2020-06-27	17	[{"id_menu":4,"count":1}]	33725	delivery	5	22
85947	2020-06-27 15:02:59	2020-06-27	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	33677	delivery	5	31
85948	2020-06-27 15:03:31	2020-06-27	12	[{"id_menu":3,"count":1}]	33522	pick-up	0	12
85949	2020-06-27 15:06:22	2020-06-27	9	[{"id_menu":6,"count":1}]	15022	delivery	5	14
85950	2020-06-27 15:07:03	2020-06-27	8	[{"id_menu":5,"count":1}]	3040	delivery	5	13
85951	2020-06-27 15:07:45	2020-06-27	41	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	33705	delivery	5	46
85952	2020-06-27 15:10:26	2020-06-27	12	[{"id_menu":1,"count":1}]	12635	delivery	5	17
85953	2020-06-27 15:12:00	2020-06-27	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	11039	delivery	5	26
85954	2020-06-27 15:12:04	2020-06-27	17	[{"id_menu":4,"count":1}]	21899	pick-up	0	17
85955	2020-06-27 15:12:10	2020-06-27	12	[{"id_menu":1,"count":1}]	1118	pick-up	0	12
85956	2020-06-27 15:14:13	2020-06-27	12	[{"id_menu":1,"count":1}]	2254	delivery	5	17
85957	2020-06-27 15:14:38	2020-06-27	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	19883	delivery	5	28
85958	2020-06-27 15:20:03	2020-06-27	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	33694	delivery	5	28
85959	2020-06-27 15:21:42	2020-06-27	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13815	delivery	5	43
85960	2020-06-27 15:24:20	2020-06-27	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	33602	delivery	5	34
85961	2020-06-27 15:24:44	2020-06-27	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	33600	delivery	5	23
85962	2020-06-27 15:26:58	2020-06-27	8	[{"id_menu":5,"count":1}]	2201	delivery	5	13
85963	2020-06-27 15:27:54	2020-06-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3407	delivery	5	22
85964	2020-06-27 15:31:52	2020-06-27	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	33534	delivery	5	37
85965	2020-06-27 15:32:31	2020-06-27	9	[{"id_menu":7,"count":1}]	30051	pick-up	0	9
85966	2020-06-27 15:35:38	2020-06-27	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":3}]	25043	delivery	5	26
85967	2020-06-27 15:43:53	2020-06-27	8	[{"id_menu":5,"count":1}]	13857	delivery	5	13
85968	2020-06-27 15:44:29	2020-06-27	9	[{"id_menu":7,"count":1}]	16749	delivery	5	14
85969	2020-06-27 15:45:01	2020-06-27	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1864	pick-up	0	21
85970	2020-06-27 15:46:27	2020-06-27	12	[{"id_menu":3,"count":1}]	2659	pick-up	0	12
85971	2020-06-27 15:53:44	2020-06-27	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	11904	pick-up	0	29
85972	2020-06-27 15:55:40	2020-06-27	12	[{"id_menu":3,"count":1}]	33509	delivery	5	17
85973	2020-06-27 16:01:15	2020-06-27	9	[{"id_menu":7,"count":1}]	13337	pick-up	0	9
85974	2020-06-27 16:04:40	2020-06-27	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	33579	delivery	5	26
85975	2020-06-27 16:05:19	2020-06-27	8	[{"id_menu":5,"count":1}]	9700	delivery	5	13
85976	2020-06-27 16:06:50	2020-06-27	12	[{"id_menu":1,"count":1}]	15321	delivery	5	17
85977	2020-06-27 16:07:22	2020-06-27	9	[{"id_menu":6,"count":2}]	33718	delivery	5	14
85978	2020-06-27 16:07:42	2020-06-27	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	18831	delivery	5	26
85979	2020-06-27 16:08:18	2020-06-27	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	11361	delivery	5	31
85980	2020-06-27 16:08:55	2020-06-27	9	[{"id_menu":7,"count":1}]	33590	delivery	5	14
85981	2020-06-27 16:11:46	2020-06-27	12	[{"id_menu":3,"count":1}]	33728	pick-up	0	12
85982	2020-06-27 16:19:58	2020-06-27	12	[{"id_menu":3,"count":1}]	2442	pick-up	0	12
85983	2020-06-27 16:21:26	2020-06-27	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26793	delivery	5	52
85984	2020-06-27 16:21:34	2020-06-27	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	33544	delivery	5	48
85985	2020-06-27 16:23:37	2020-06-27	14	[{"id_menu":2,"count":1}]	27427	delivery	5	19
85986	2020-06-27 16:25:08	2020-06-27	14	[{"id_menu":2,"count":1}]	33552	delivery	5	19
85987	2020-06-27 16:29:46	2020-06-27	9	[{"id_menu":6,"count":1}]	26738	delivery	5	14
85988	2020-06-27 16:31:13	2020-06-27	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17172	pick-up	0	26
85989	2020-06-27 16:33:20	2020-06-27	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	33247	delivery	5	34
85990	2020-06-27 16:35:46	2020-06-27	8	[{"id_menu":5,"count":1}]	32706	delivery	5	13
85991	2020-06-27 16:37:49	2020-06-27	14	[{"id_menu":2,"count":1}]	708	delivery	5	19
85992	2020-06-27 16:41:42	2020-06-27	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33657	delivery	5	31
85993	2020-06-27 16:46:09	2020-06-27	12	[{"id_menu":1,"count":1}]	27991	delivery	5	17
85994	2020-06-27 16:48:07	2020-06-27	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	24729	delivery	5	31
85995	2020-06-27 16:48:32	2020-06-27	12	[{"id_menu":1,"count":1}]	17086	delivery	5	17
85996	2020-06-27 16:50:23	2020-06-27	12	[{"id_menu":3,"count":1}]	24853	pick-up	0	12
85997	2020-06-27 16:51:22	2020-06-27	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	20950	delivery	5	25
85998	2020-06-27 16:51:46	2020-06-27	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	15622	delivery	5	38
85999	2020-06-27 16:54:23	2020-06-27	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	19603	delivery	5	28
86000	2020-06-27 16:55:51	2020-06-27	14	[{"id_menu":2,"count":1}]	11745	delivery	5	19
86001	2020-06-27 16:57:29	2020-06-27	12	[{"id_menu":1,"count":1}]	12430	delivery	5	17
86002	2020-06-27 16:58:11	2020-06-27	9	[{"id_menu":6,"count":2}]	33683	delivery	5	14
86003	2020-06-27 16:58:53	2020-06-27	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	17326	delivery	5	36
86004	2020-06-27 16:59:18	2020-06-27	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	15817	pick-up	0	26
86005	2020-06-27 17:03:29	2020-06-27	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	23588	pick-up	0	21
86006	2020-06-27 17:04:01	2020-06-27	12	[{"id_menu":3,"count":1}]	11073	pick-up	0	12
86007	2020-06-27 17:04:36	2020-06-27	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	33597	delivery	5	43
86008	2020-06-27 17:06:20	2020-06-27	14	[{"id_menu":2,"count":1}]	31963	pick-up	0	14
86009	2020-06-27 17:06:51	2020-06-27	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	6097	pick-up	0	20
86010	2020-06-27 17:09:44	2020-06-27	17	[{"id_menu":4,"count":1}]	33595	delivery	5	22
86011	2020-06-27 17:12:07	2020-06-27	14	[{"id_menu":2,"count":1}]	33513	pick-up	0	14
86012	2020-06-27 17:13:23	2020-06-27	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15504	delivery	5	35
86013	2020-06-27 17:13:55	2020-06-27	8	[{"id_menu":5,"count":1}]	3074	delivery	5	13
86014	2020-06-27 17:17:00	2020-06-27	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	33520	delivery	5	28
86015	2020-06-27 17:19:08	2020-06-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	33608	delivery	5	22
86016	2020-06-27 17:19:19	2020-06-27	8	[{"id_menu":5,"count":2}]	33630	delivery	5	13
86017	2020-06-27 17:20:26	2020-06-27	9	[{"id_menu":6,"count":1}]	13609	delivery	5	14
86018	2020-06-27 17:20:40	2020-06-27	12	[{"id_menu":1,"count":1}]	4190	delivery	5	17
86019	2020-06-27 17:21:46	2020-06-27	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	33543	delivery	5	26
86020	2020-06-27 17:25:26	2020-06-27	9	[{"id_menu":6,"count":1}]	15776	delivery	5	14
86021	2020-06-27 17:26:15	2020-06-27	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	27130	delivery	5	26
86022	2020-06-27 17:26:35	2020-06-27	17	[{"id_menu":4,"count":1}]	4629	delivery	5	22
86023	2020-06-27 17:28:30	2020-06-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":3}]	28693	delivery	5	36
86024	2020-06-27 17:31:35	2020-06-27	8	[{"id_menu":5,"count":1}]	3198	pick-up	0	8
86025	2020-06-27 17:34:14	2020-06-27	9	[{"id_menu":7,"count":2}]	12955	delivery	5	14
86026	2020-06-27 17:34:31	2020-06-27	9	[{"id_menu":7,"count":1}]	4735	pick-up	0	9
86027	2020-06-27 17:35:11	2020-06-27	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	15907	pick-up	0	29
86028	2020-06-27 17:35:52	2020-06-27	9	[{"id_menu":7,"count":1}]	26541	delivery	5	14
86029	2020-06-27 17:35:54	2020-06-27	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	13313	delivery	5	39
86030	2020-06-27 17:38:56	2020-06-27	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	32342	delivery	5	39
86031	2020-06-27 17:39:29	2020-06-27	12	[{"id_menu":3,"count":1}]	14519	pick-up	0	12
86032	2020-06-27 17:40:18	2020-06-27	8	[{"id_menu":5,"count":1}]	33650	delivery	5	13
86033	2020-06-27 17:40:44	2020-06-27	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	22606	delivery	5	22
86034	2020-06-27 17:40:55	2020-06-27	17	[{"id_menu":4,"count":1}]	13041	delivery	5	22
86035	2020-06-27 17:43:20	2020-06-27	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	32956	delivery	5	40
86036	2020-06-27 17:44:36	2020-06-27	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	30304	pick-up	0	25
86037	2020-06-27 17:48:35	2020-06-27	12	[{"id_menu":1,"count":1}]	229	pick-up	0	12
86038	2020-06-27 17:49:32	2020-06-27	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	7249	delivery	5	27
86039	2020-06-27 17:50:04	2020-06-27	9	[{"id_menu":7,"count":1}]	22390	delivery	5	14
86040	2020-06-27 17:50:20	2020-06-27	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	33695	delivery	5	36
86041	2020-06-27 17:52:59	2020-06-27	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	1346	delivery	5	26
86042	2020-06-27 17:53:48	2020-06-27	9	[{"id_menu":6,"count":1}]	10058	delivery	5	14
86043	2020-06-27 17:54:30	2020-06-27	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4829	delivery	5	39
86044	2020-06-27 17:59:11	2020-06-27	14	[{"id_menu":2,"count":1}]	44	pick-up	0	14
86045	2020-06-27 17:59:32	2020-06-27	12	[{"id_menu":1,"count":1}]	4874	pick-up	0	12
86046	2020-06-27 18:00:13	2020-06-27	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	30688	delivery	5	26
86047	2020-06-27 18:02:00	2020-06-27	9	[{"id_menu":7,"count":1}]	33717	delivery	5	14
86048	2020-06-27 18:02:45	2020-06-27	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	33627	delivery	5	39
86049	2020-06-27 18:04:04	2020-06-27	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2373	pick-up	0	25
86050	2020-06-27 18:04:35	2020-06-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":3}]	33539	delivery	5	36
86051	2020-06-27 18:09:12	2020-06-27	12	[{"id_menu":1,"count":1}]	33699	delivery	5	17
86052	2020-06-27 18:11:47	2020-06-27	9	[{"id_menu":6,"count":1}]	33592	delivery	5	14
86053	2020-06-27 18:13:04	2020-06-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	26874	delivery	5	28
86054	2020-06-27 18:13:19	2020-06-27	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18230	delivery	5	52
86055	2020-06-27 18:15:27	2020-06-27	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13819	delivery	5	53
86056	2020-06-27 18:19:17	2020-06-27	8	[{"id_menu":5,"count":1}]	33559	delivery	5	13
86057	2020-06-27 18:20:33	2020-06-27	14	[{"id_menu":2,"count":1}]	4054	pick-up	0	14
86058	2020-06-27 18:22:37	2020-06-27	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	33656	delivery	5	28
86059	2020-06-27 18:24:14	2020-06-27	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	33637	delivery	5	28
86060	2020-06-27 18:28:16	2020-06-27	9	[{"id_menu":7,"count":1}]	33686	delivery	5	14
86061	2020-06-27 18:30:49	2020-06-27	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6150	delivery	5	35
86062	2020-06-27 18:32:19	2020-06-27	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14954	delivery	5	48
86063	2020-06-27 18:37:12	2020-06-27	14	[{"id_menu":2,"count":1}]	25750	pick-up	0	14
86064	2020-06-27 18:37:44	2020-06-27	8	[{"id_menu":5,"count":3}]	33722	delivery	5	13
86065	2020-06-27 18:38:17	2020-06-27	12	[{"id_menu":1,"count":2}]	4658	delivery	5	17
86066	2020-06-27 18:39:25	2020-06-27	9	[{"id_menu":6,"count":1}]	16994	delivery	5	14
86067	2020-06-27 18:40:52	2020-06-27	17	[{"id_menu":4,"count":1}]	8726	delivery	5	22
86068	2020-06-27 18:41:29	2020-06-27	8	[{"id_menu":5,"count":1}]	33582	delivery	5	13
86069	2020-06-27 18:44:00	2020-06-27	17	[{"id_menu":4,"count":1}]	14981	pick-up	0	17
86070	2020-06-27 18:44:52	2020-06-27	17	[{"id_menu":4,"count":1}]	5313	pick-up	0	17
86071	2020-06-27 18:45:44	2020-06-27	9	[{"id_menu":7,"count":1}]	33573	pick-up	0	9
86072	2020-06-27 18:46:34	2020-06-27	9	[{"id_menu":6,"count":1}]	9191	pick-up	0	9
86073	2020-06-27 18:47:22	2020-06-27	8	[{"id_menu":5,"count":1}]	27508	delivery	5	13
86074	2020-06-27 18:48:10	2020-06-27	9	[{"id_menu":7,"count":1}]	33638	delivery	5	14
86075	2020-06-27 18:48:46	2020-06-27	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	33723	delivery	5	39
86076	2020-06-27 18:49:41	2020-06-27	12	[{"id_menu":3,"count":1}]	33153	pick-up	0	12
86077	2020-06-27 18:53:03	2020-06-27	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	32144	delivery	5	25
86078	2020-06-27 18:53:45	2020-06-27	9	[{"id_menu":6,"count":1}]	23008	delivery	5	14
86079	2020-06-27 18:56:00	2020-06-27	8	[{"id_menu":5,"count":1}]	33591	delivery	5	13
86080	2020-06-27 18:57:13	2020-06-27	17	[{"id_menu":4,"count":1}]	906	delivery	5	22
86081	2020-06-27 18:59:08	2020-06-27	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	33617	delivery	5	31
86082	2020-06-27 19:03:20	2020-06-27	9	[{"id_menu":7,"count":1}]	12615	delivery	5	14
86083	2020-06-27 19:04:49	2020-06-27	9	[{"id_menu":6,"count":1}]	13940	pick-up	0	9
86084	2020-06-27 19:05:37	2020-06-27	37	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	16181	delivery	5	42
86085	2020-06-27 19:06:05	2020-06-27	14	[{"id_menu":2,"count":1}]	3260	pick-up	0	14
86086	2020-06-27 19:06:51	2020-06-27	8	[{"id_menu":5,"count":1}]	9322	delivery	5	13
86087	2020-06-27 19:14:13	2020-06-27	12	[{"id_menu":3,"count":1}]	17815	delivery	5	17
86088	2020-06-27 19:17:07	2020-06-27	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1555	pick-up	0	26
86089	2020-06-27 19:18:29	2020-06-27	14	[{"id_menu":2,"count":1}]	33526	delivery	5	19
86090	2020-06-27 19:19:55	2020-06-27	9	[{"id_menu":7,"count":1}]	33711	delivery	5	14
86091	2020-06-27 19:23:13	2020-06-27	9	[{"id_menu":7,"count":1}]	33507	delivery	5	14
86092	2020-06-27 19:28:13	2020-06-27	9	[{"id_menu":7,"count":1}]	15017	delivery	5	14
86093	2020-06-27 19:28:27	2020-06-27	9	[{"id_menu":6,"count":1}]	14331	delivery	5	14
86094	2020-06-27 19:32:07	2020-06-27	12	[{"id_menu":3,"count":1}]	20132	delivery	5	17
86095	2020-06-27 19:35:42	2020-06-27	12	[{"id_menu":3,"count":2}]	30678	delivery	5	17
86096	2020-06-27 19:36:39	2020-06-27	14	[{"id_menu":2,"count":1}]	13042	delivery	5	19
86097	2020-06-27 19:37:32	2020-06-27	14	[{"id_menu":2,"count":1}]	6156	pick-up	0	14
86098	2020-06-27 19:38:04	2020-06-27	9	[{"id_menu":6,"count":1}]	9995	delivery	5	14
86099	2020-06-27 19:43:26	2020-06-27	9	[{"id_menu":7,"count":1}]	11146	pick-up	0	9
86100	2020-06-27 19:47:43	2020-06-27	14	[{"id_menu":2,"count":1}]	33527	delivery	5	19
86101	2020-06-27 19:51:48	2020-06-27	9	[{"id_menu":6,"count":1}]	4090	pick-up	0	9
86102	2020-06-27 19:52:01	2020-06-27	8	[{"id_menu":5,"count":1}]	2446	pick-up	0	8
86103	2020-06-27 19:53:59	2020-06-27	12	[{"id_menu":3,"count":1}]	22126	delivery	5	17
86104	2020-06-27 19:54:20	2020-06-27	8	[{"id_menu":5,"count":1}]	33149	delivery	5	13
86105	2020-06-27 19:54:33	2020-06-27	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	8314	delivery	5	34
86106	2020-06-27 19:58:13	2020-06-27	9	[{"id_menu":6,"count":1}]	9616	delivery	5	14
86107	2020-06-27 20:00:54	2020-06-27	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	33706	delivery	5	45
86108	2020-06-27 20:04:31	2020-06-27	14	[{"id_menu":2,"count":2}]	2573	pick-up	0	14
86109	2020-06-27 20:07:09	2020-06-27	9	[{"id_menu":6,"count":1}]	23892	delivery	5	14
86110	2020-06-27 20:09:35	2020-06-27	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	7566	pick-up	0	21
86111	2020-06-27 20:14:09	2020-06-27	17	[{"id_menu":4,"count":1}]	151	pick-up	0	17
86112	2020-06-27 20:15:05	2020-06-27	9	[{"id_menu":6,"count":1}]	33606	pick-up	0	9
86113	2020-06-27 20:16:28	2020-06-27	14	[{"id_menu":2,"count":1}]	24731	delivery	5	19
86114	2020-06-27 20:20:46	2020-06-27	14	[{"id_menu":2,"count":2}]	33523	delivery	5	19
86115	2020-06-27 20:22:30	2020-06-27	9	[{"id_menu":6,"count":1}]	33555	delivery	5	14
86116	2020-06-27 20:22:46	2020-06-27	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	3647	pick-up	0	34
86117	2020-06-27 20:23:05	2020-06-27	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	33514	delivery	5	36
86118	2020-06-27 20:23:09	2020-06-27	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1266	pick-up	0	31
86119	2020-06-27 20:23:38	2020-06-27	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	33564	delivery	5	51
86120	2020-06-27 20:25:49	2020-06-27	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21426	delivery	5	49
86121	2020-06-27 20:28:20	2020-06-27	17	[{"id_menu":4,"count":1}]	33535	pick-up	0	17
86122	2020-06-27 20:29:48	2020-06-27	9	[{"id_menu":7,"count":1}]	11681	pick-up	0	9
86123	2020-06-27 20:29:48	2020-06-27	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	26000	delivery	5	34
86124	2020-06-27 20:31:04	2020-06-27	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8118	delivery	5	31
86125	2020-06-27 20:33:06	2020-06-27	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	33575	delivery	5	39
86126	2020-06-27 20:33:24	2020-06-27	8	[{"id_menu":5,"count":1}]	33629	delivery	5	13
86127	2020-06-27 20:38:51	2020-06-27	9	[{"id_menu":7,"count":1}]	33560	delivery	5	14
86128	2020-06-27 20:41:10	2020-06-27	9	[{"id_menu":6,"count":1}]	26519	delivery	5	14
86129	2020-06-27 20:42:32	2020-06-27	9	[{"id_menu":7,"count":1}]	29127	delivery	5	14
86130	2020-06-27 20:42:54	2020-06-27	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	4869	pick-up	0	32
86131	2020-06-27 20:43:47	2020-06-27	14	[{"id_menu":2,"count":1}]	20126	delivery	5	19
86132	2020-06-27 20:48:20	2020-06-27	8	[{"id_menu":5,"count":1}]	31650	delivery	5	13
86133	2020-06-27 20:48:35	2020-06-27	14	[{"id_menu":2,"count":1}]	2529	pick-up	0	14
86134	2020-06-27 20:50:35	2020-06-27	14	[{"id_menu":2,"count":1}]	32468	pick-up	0	14
86135	2020-06-27 20:52:55	2020-06-27	12	[{"id_menu":1,"count":1}]	27224	delivery	5	17
86136	2020-06-27 20:53:51	2020-06-27	17	[{"id_menu":4,"count":1}]	32048	delivery	5	22
86137	2020-06-27 20:57:05	2020-06-27	17	[{"id_menu":4,"count":1}]	14396	delivery	5	22
86138	2020-06-27 21:00:21	2020-06-27	14	[{"id_menu":2,"count":1}]	33633	delivery	5	19
86139	2020-06-27 21:00:37	2020-06-27	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	16340	delivery	5	34
86140	2020-06-27 21:02:00	2020-06-27	8	[{"id_menu":5,"count":1}]	27018	delivery	5	13
86141	2020-06-27 21:02:22	2020-06-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1541	pick-up	0	23
86142	2020-06-27 21:04:52	2020-06-27	12	[{"id_menu":1,"count":1}]	33565	delivery	5	17
86143	2020-06-27 21:05:28	2020-06-27	21	[{"id_menu":1,"count":3},{"id_menu":6,"count":1}]	584	delivery	5	26
86144	2020-06-27 21:07:16	2020-06-27	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	14031	delivery	5	37
86145	2020-06-27 21:09:42	2020-06-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	30261	delivery	5	28
86146	2020-06-27 21:12:06	2020-06-27	8	[{"id_menu":5,"count":1}]	8240	pick-up	0	8
86147	2020-06-27 21:16:31	2020-06-27	8	[{"id_menu":5,"count":1}]	18239	pick-up	0	8
86148	2020-06-27 21:20:24	2020-06-27	9	[{"id_menu":6,"count":1}]	11389	delivery	5	14
86149	2020-06-27 21:20:25	2020-06-27	17	[{"id_menu":4,"count":1}]	25321	delivery	5	22
86150	2020-06-27 21:21:23	2020-06-27	9	[{"id_menu":7,"count":1}]	19989	delivery	5	14
86151	2020-06-27 21:21:33	2020-06-27	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22959	delivery	5	43
86152	2020-06-27 21:21:54	2020-06-27	12	[{"id_menu":3,"count":1}]	11992	pick-up	0	12
86153	2020-06-27 21:22:16	2020-06-27	14	[{"id_menu":2,"count":1}]	33553	delivery	5	19
86154	2020-06-27 21:25:28	2020-06-27	9	[{"id_menu":6,"count":1}]	26423	delivery	5	14
86155	2020-06-27 21:26:32	2020-06-27	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7931	pick-up	0	40
86156	2020-06-27 21:29:35	2020-06-27	8	[{"id_menu":5,"count":1}]	33682	delivery	5	13
86157	2020-06-27 21:33:17	2020-06-27	17	[{"id_menu":4,"count":1}]	16680	delivery	5	22
86158	2020-06-27 21:33:31	2020-06-27	9	[{"id_menu":7,"count":1}]	6094	delivery	5	14
86159	2020-06-27 21:34:12	2020-06-27	12	[{"id_menu":1,"count":2}]	33532	delivery	5	17
86160	2020-06-27 21:38:30	2020-06-27	9	[{"id_menu":6,"count":1}]	28986	delivery	5	14
86161	2020-06-27 21:42:43	2020-06-27	8	[{"id_menu":5,"count":1}]	33693	delivery	5	13
86162	2020-06-27 21:46:03	2020-06-27	17	[{"id_menu":4,"count":1}]	121	delivery	5	22
86163	2020-06-27 21:48:16	2020-06-27	9	[{"id_menu":6,"count":1}]	12474	delivery	5	14
86164	2020-06-27 21:48:21	2020-06-27	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	18312	delivery	5	57
86165	2020-06-27 21:51:33	2020-06-27	9	[{"id_menu":6,"count":1}]	33541	delivery	5	14
86166	2020-06-27 21:51:44	2020-06-27	9	[{"id_menu":6,"count":1}]	9319	delivery	5	14
86167	2020-06-27 21:52:21	2020-06-27	17	[{"id_menu":4,"count":1}]	17614	pick-up	0	17
86168	2020-06-27 21:52:57	2020-06-27	9	[{"id_menu":6,"count":1}]	28377	pick-up	0	9
86169	2020-06-27 21:53:02	2020-06-27	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11076	delivery	5	45
86170	2020-06-27 21:54:52	2020-06-27	9	[{"id_menu":6,"count":2}]	33730	pick-up	0	9
86171	2020-06-27 21:55:03	2020-06-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1697	pick-up	0	23
86172	2020-06-27 21:58:05	2020-06-27	12	[{"id_menu":1,"count":1}]	4206	pick-up	0	12
86173	2020-06-27 21:58:28	2020-06-27	8	[{"id_menu":5,"count":1}]	26860	pick-up	0	8
86174	2020-06-27 22:01:21	2020-06-27	9	[{"id_menu":7,"count":1}]	33550	delivery	5	14
86175	2020-06-27 22:02:16	2020-06-27	14	[{"id_menu":2,"count":1}]	24779	delivery	5	19
86176	2020-06-27 22:04:18	2020-06-27	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	33685	delivery	5	26
86177	2020-06-27 22:05:01	2020-06-27	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	10196	delivery	5	25
86178	2020-06-27 22:10:23	2020-06-27	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	10330	delivery	5	28
86179	2020-06-27 22:13:13	2020-06-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11254	delivery	5	22
86180	2020-06-27 22:13:33	2020-06-27	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18422	pick-up	0	41
86181	2020-06-27 22:21:15	2020-06-27	9	[{"id_menu":6,"count":1}]	8885	pick-up	0	9
86182	2020-06-27 22:21:53	2020-06-27	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	15200	delivery	5	38
86183	2020-06-27 22:26:06	2020-06-27	9	[{"id_menu":6,"count":1}]	33584	pick-up	0	9
86184	2020-06-27 22:30:05	2020-06-27	12	[{"id_menu":3,"count":1}]	1640	delivery	5	17
86185	2020-06-27 22:30:31	2020-06-27	12	[{"id_menu":3,"count":2}]	33614	pick-up	0	12
86186	2020-06-27 22:35:32	2020-06-27	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	33561	delivery	5	31
86187	2020-06-27 22:35:50	2020-06-27	8	[{"id_menu":5,"count":1}]	26897	delivery	5	13
86188	2020-06-27 22:38:39	2020-06-27	12	[{"id_menu":3,"count":1}]	29252	pick-up	0	12
86189	2020-06-27 22:39:08	2020-06-27	12	[{"id_menu":3,"count":1}]	33525	delivery	5	17
86190	2020-06-27 22:44:08	2020-06-27	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	15866	pick-up	0	24
86191	2020-06-27 22:47:34	2020-06-27	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23036	delivery	5	35
86192	2020-06-27 22:48:36	2020-06-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5236	delivery	5	22
86193	2020-06-27 22:48:41	2020-06-27	9	[{"id_menu":7,"count":1}]	14114	delivery	5	14
86194	2020-06-27 22:55:53	2020-06-27	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20815	delivery	5	39
86195	2020-06-27 22:57:56	2020-06-27	12	[{"id_menu":3,"count":1}]	33588	delivery	5	17
86196	2020-06-27 23:05:23	2020-06-27	8	[{"id_menu":5,"count":2}]	26507	delivery	5	13
86197	2020-06-27 23:06:10	2020-06-27	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	23318	delivery	5	36
86198	2020-06-27 23:09:16	2020-06-27	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	28244	delivery	5	28
86199	2020-06-27 23:13:17	2020-06-27	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16339	delivery	5	35
86200	2020-06-27 23:15:50	2020-06-27	14	[{"id_menu":2,"count":1}]	9449	delivery	5	19
86201	2020-06-27 23:16:42	2020-06-27	8	[{"id_menu":5,"count":1}]	33645	delivery	5	13
86202	2020-06-27 23:19:51	2020-06-27	9	[{"id_menu":7,"count":1}]	27727	delivery	5	14
86203	2020-06-27 23:24:54	2020-06-27	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24085	delivery	5	53
86204	2020-06-27 23:27:15	2020-06-27	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	33528	delivery	5	27
86205	2020-06-27 23:29:53	2020-06-27	14	[{"id_menu":2,"count":1}]	2681	delivery	5	19
86206	2020-06-27 23:30:59	2020-06-27	14	[{"id_menu":2,"count":1}]	7821	delivery	5	19
86207	2020-06-27 23:31:09	2020-06-27	17	[{"id_menu":4,"count":1}]	29458	pick-up	0	17
86208	2020-06-27 23:31:56	2020-06-27	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	33724	pick-up	0	22
86209	2020-06-27 23:34:37	2020-06-27	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	14289	delivery	5	31
86210	2020-06-27 23:35:50	2020-06-27	9	[{"id_menu":6,"count":1}]	17701	delivery	5	14
86211	2020-06-27 23:36:53	2020-06-27	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	30349	delivery	5	28
86212	2020-06-27 23:38:55	2020-06-27	17	[{"id_menu":4,"count":1}]	30649	delivery	5	22
86213	2020-06-27 23:39:08	2020-06-27	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	23016	delivery	5	31
86214	2020-06-27 23:39:42	2020-06-27	12	[{"id_menu":3,"count":1}]	17895	delivery	5	17
86215	2020-06-27 23:40:49	2020-06-27	8	[{"id_menu":5,"count":1}]	33631	pick-up	0	8
86216	2020-06-27 23:44:43	2020-06-27	8	[{"id_menu":5,"count":1}]	33733	delivery	5	13
86217	2020-06-27 23:45:13	2020-06-27	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	33519	delivery	5	57
86218	2020-06-27 23:49:59	2020-06-27	17	[{"id_menu":4,"count":1}]	100	pick-up	0	17
86219	2020-06-27 23:50:15	2020-06-27	12	[{"id_menu":3,"count":1}]	33691	delivery	5	17
86220	2020-06-27 23:51:18	2020-06-27	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17572	delivery	5	52
86221	2020-06-27 23:53:16	2020-06-27	12	[{"id_menu":3,"count":1}]	21806	pick-up	0	12
86222	2020-06-27 23:54:07	2020-06-27	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	14068	delivery	5	28
86223	2020-06-27 23:54:13	2020-06-27	17	[{"id_menu":4,"count":1}]	18042	delivery	5	22
86224	2020-06-27 23:54:33	2020-06-27	14	[{"id_menu":2,"count":1}]	33530	delivery	5	19
86225	2020-06-27 23:54:52	2020-06-27	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	14501	pick-up	0	24
86226	2020-06-27 23:56:56	2020-06-27	14	[{"id_menu":2,"count":1}]	19035	delivery	5	19
86227	2020-06-27 23:59:24	2020-06-27	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17472	delivery	5	45
86228	2020-06-28 00:00:38	2020-06-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33913	delivery	5	23
86229	2020-06-28 00:01:30	2020-06-28	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	16165	pick-up	0	21
86230	2020-06-28 00:01:44	2020-06-28	12	[{"id_menu":3,"count":1}]	33942	delivery	5	17
86231	2020-06-28 00:04:34	2020-06-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5674	delivery	5	31
86232	2020-06-28 00:06:41	2020-06-28	17	[{"id_menu":4,"count":1}]	2187	pick-up	0	17
86233	2020-06-28 00:07:20	2020-06-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	33960	delivery	5	31
86234	2020-06-28 00:09:04	2020-06-28	8	[{"id_menu":5,"count":1}]	33866	pick-up	0	8
86235	2020-06-28 00:09:46	2020-06-28	9	[{"id_menu":7,"count":1}]	12142	delivery	5	14
86236	2020-06-28 00:09:56	2020-06-28	8	[{"id_menu":5,"count":1}]	33747	pick-up	0	8
86237	2020-06-28 00:10:31	2020-06-28	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23933	delivery	5	37
86238	2020-06-28 00:11:05	2020-06-28	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	33789	delivery	5	34
86239	2020-06-28 00:11:41	2020-06-28	20	[{"id_menu":1,"count":3},{"id_menu":5,"count":1}]	3785	pick-up	0	20
86240	2020-06-28 00:11:42	2020-06-28	17	[{"id_menu":4,"count":1}]	1491	delivery	5	22
86241	2020-06-28 00:12:50	2020-06-28	12	[{"id_menu":3,"count":1}]	15187	delivery	5	17
86242	2020-06-28 00:15:23	2020-06-28	17	[{"id_menu":4,"count":1}]	3810	delivery	5	22
86243	2020-06-28 00:16:43	2020-06-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	33871	delivery	5	22
86244	2020-06-28 00:17:34	2020-06-28	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	15197	delivery	5	34
86245	2020-06-28 00:18:05	2020-06-28	12	[{"id_menu":1,"count":1}]	264	pick-up	0	12
86246	2020-06-28 00:20:15	2020-06-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	33952	delivery	5	22
86247	2020-06-28 00:21:17	2020-06-28	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	17056	delivery	5	26
86248	2020-06-28 00:23:42	2020-06-28	9	[{"id_menu":6,"count":1}]	2159	pick-up	0	9
86249	2020-06-28 00:24:32	2020-06-28	9	[{"id_menu":7,"count":1}]	19346	delivery	5	14
86250	2020-06-28 00:26:23	2020-06-28	12	[{"id_menu":1,"count":1}]	3611	delivery	5	17
86251	2020-06-28 00:28:48	2020-06-28	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	33852	delivery	5	26
86252	2020-06-28 00:29:34	2020-06-28	9	[{"id_menu":7,"count":1}]	28979	delivery	5	14
86253	2020-06-28 00:29:49	2020-06-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1044	pick-up	0	23
86254	2020-06-28 00:30:09	2020-06-28	12	[{"id_menu":3,"count":1}]	5058	delivery	5	17
86255	2020-06-28 00:31:08	2020-06-28	9	[{"id_menu":7,"count":1}]	14879	delivery	5	14
86256	2020-06-28 00:34:51	2020-06-28	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	24590	delivery	5	25
86257	2020-06-28 00:38:39	2020-06-28	9	[{"id_menu":6,"count":1}]	33135	delivery	5	14
86258	2020-06-28 00:42:00	2020-06-28	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	456	delivery	5	46
86259	2020-06-28 00:42:57	2020-06-28	9	[{"id_menu":7,"count":1}]	9653	delivery	5	14
86260	2020-06-28 00:43:24	2020-06-28	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20232	delivery	5	36
86261	2020-06-28 00:45:21	2020-06-28	9	[{"id_menu":6,"count":1}]	33759	delivery	5	14
86262	2020-06-28 00:48:54	2020-06-28	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	33768	delivery	5	34
86263	2020-06-28 00:50:02	2020-06-28	12	[{"id_menu":3,"count":1}]	2516	pick-up	0	12
86264	2020-06-28 00:50:11	2020-06-28	9	[{"id_menu":6,"count":1}]	10819	pick-up	0	9
86265	2020-06-28 00:50:45	2020-06-28	9	[{"id_menu":6,"count":2}]	12287	delivery	5	14
86266	2020-06-28 00:54:13	2020-06-28	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	14284	delivery	5	26
86267	2020-06-28 00:54:14	2020-06-28	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	4436	pick-up	0	29
86268	2020-06-28 00:55:52	2020-06-28	17	[{"id_menu":4,"count":1}]	4283	delivery	5	22
86269	2020-06-28 00:58:19	2020-06-28	9	[{"id_menu":7,"count":1}]	6202	pick-up	0	9
86270	2020-06-28 00:58:28	2020-06-28	9	[{"id_menu":7,"count":1}]	5171	delivery	5	14
86271	2020-06-28 01:00:49	2020-06-28	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	27044	pick-up	0	21
86272	2020-06-28 01:03:24	2020-06-28	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	33934	delivery	5	30
86273	2020-06-28 01:04:24	2020-06-28	8	[{"id_menu":5,"count":1}]	33894	delivery	5	13
86274	2020-06-28 01:07:50	2020-06-28	9	[{"id_menu":6,"count":1}]	12292	delivery	5	14
86275	2020-06-28 01:07:59	2020-06-28	9	[{"id_menu":6,"count":1}]	33885	delivery	5	14
86276	2020-06-28 01:08:06	2020-06-28	14	[{"id_menu":2,"count":1}]	27885	delivery	5	19
86277	2020-06-28 01:08:42	2020-06-28	8	[{"id_menu":5,"count":1}]	27985	delivery	5	13
86278	2020-06-28 01:12:30	2020-06-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9453	delivery	5	31
86279	2020-06-28 01:13:22	2020-06-28	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1155	delivery	5	31
86280	2020-06-28 01:15:52	2020-06-28	9	[{"id_menu":7,"count":1}]	7516	pick-up	0	9
86281	2020-06-28 01:16:40	2020-06-28	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17309	delivery	5	34
86282	2020-06-28 01:16:40	2020-06-28	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33884	delivery	5	31
86283	2020-06-28 01:17:14	2020-06-28	14	[{"id_menu":2,"count":1}]	2613	pick-up	0	14
86284	2020-06-28 01:17:56	2020-06-28	17	[{"id_menu":4,"count":1}]	797	delivery	5	22
86285	2020-06-28 01:18:35	2020-06-28	17	[{"id_menu":4,"count":1}]	6342	pick-up	0	17
86286	2020-06-28 01:18:58	2020-06-28	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	32548	delivery	5	36
86287	2020-06-28 01:19:33	2020-06-28	9	[{"id_menu":6,"count":1}]	28576	pick-up	0	9
86288	2020-06-28 01:22:56	2020-06-28	17	[{"id_menu":4,"count":1}]	29226	pick-up	0	17
86289	2020-06-28 01:25:25	2020-06-28	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	3314	pick-up	0	21
86290	2020-06-28 01:31:05	2020-06-28	12	[{"id_menu":1,"count":1}]	33772	delivery	5	17
86291	2020-06-28 01:31:34	2020-06-28	8	[{"id_menu":5,"count":1}]	8532	delivery	5	13
86292	2020-06-28 01:35:49	2020-06-28	14	[{"id_menu":2,"count":1}]	4193	pick-up	0	14
86293	2020-06-28 01:36:33	2020-06-28	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	10844	delivery	5	46
86294	2020-06-28 01:39:31	2020-06-28	9	[{"id_menu":7,"count":1}]	920	delivery	5	14
86295	2020-06-28 01:42:48	2020-06-28	8	[{"id_menu":5,"count":1}]	33749	pick-up	0	8
86296	2020-06-28 01:43:19	2020-06-28	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33957	delivery	5	40
86297	2020-06-28 01:43:20	2020-06-28	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	10988	pick-up	0	21
86298	2020-06-28 01:45:09	2020-06-28	17	[{"id_menu":4,"count":2}]	15500	delivery	5	22
86299	2020-06-28 01:45:17	2020-06-28	9	[{"id_menu":7,"count":1}]	33829	delivery	5	14
86300	2020-06-28 01:46:31	2020-06-28	12	[{"id_menu":3,"count":1}]	8845	delivery	5	17
86301	2020-06-28 01:47:16	2020-06-28	17	[{"id_menu":4,"count":1}]	33941	delivery	5	22
86302	2020-06-28 01:48:00	2020-06-28	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	4652	pick-up	0	21
86303	2020-06-28 01:50:53	2020-06-28	9	[{"id_menu":6,"count":1}]	33946	delivery	5	14
86304	2020-06-28 01:51:28	2020-06-28	9	[{"id_menu":7,"count":1}]	26826	delivery	5	14
86305	2020-06-28 01:52:49	2020-06-28	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33766	delivery	5	43
86306	2020-06-28 01:53:48	2020-06-28	14	[{"id_menu":2,"count":1}]	33816	delivery	5	19
86307	2020-06-28 01:56:40	2020-06-28	8	[{"id_menu":5,"count":1}]	2507	delivery	5	13
86308	2020-06-28 01:56:51	2020-06-28	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	12203	delivery	5	26
86309	2020-06-28 01:57:24	2020-06-28	12	[{"id_menu":3,"count":1}]	27577	delivery	5	17
86310	2020-06-28 01:58:27	2020-06-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27651	delivery	5	23
86311	2020-06-28 02:00:20	2020-06-28	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20044	delivery	5	43
86312	2020-06-28 02:01:35	2020-06-28	12	[{"id_menu":1,"count":1}]	14841	delivery	5	17
86313	2020-06-28 02:03:02	2020-06-28	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	33809	delivery	5	28
86314	2020-06-28 02:08:53	2020-06-28	8	[{"id_menu":5,"count":2}]	27931	delivery	5	13
86315	2020-06-28 02:10:04	2020-06-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	92	pick-up	0	26
86316	2020-06-28 02:10:21	2020-06-28	9	[{"id_menu":6,"count":1}]	29042	pick-up	0	9
86317	2020-06-28 02:10:49	2020-06-28	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	29939	delivery	5	45
86318	2020-06-28 02:12:16	2020-06-28	17	[{"id_menu":4,"count":1}]	22503	delivery	5	22
86319	2020-06-28 02:13:12	2020-06-28	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	33796	delivery	5	37
86320	2020-06-28 02:14:03	2020-06-28	9	[{"id_menu":7,"count":1}]	24045	delivery	5	14
86321	2020-06-28 02:15:17	2020-06-28	14	[{"id_menu":2,"count":1}]	22110	pick-up	0	14
86322	2020-06-28 02:15:43	2020-06-28	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	24652	delivery	5	26
86323	2020-06-28 02:16:26	2020-06-28	12	[{"id_menu":3,"count":1}]	7463	pick-up	0	12
86324	2020-06-28 02:20:56	2020-06-28	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	21859	delivery	5	31
86325	2020-06-28 02:25:06	2020-06-28	8	[{"id_menu":5,"count":1}]	7020	delivery	5	13
86326	2020-06-28 02:26:33	2020-06-28	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	13951	pick-up	0	20
86327	2020-06-28 02:27:11	2020-06-28	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	13984	pick-up	0	21
86328	2020-06-28 02:27:19	2020-06-28	9	[{"id_menu":6,"count":1}]	33841	delivery	5	14
86329	2020-06-28 02:33:12	2020-06-28	8	[{"id_menu":5,"count":1}]	4424	delivery	5	13
86330	2020-06-28 02:33:19	2020-06-28	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	33821	delivery	5	26
86331	2020-06-28 02:35:32	2020-06-28	17	[{"id_menu":4,"count":1}]	33870	delivery	5	22
86332	2020-06-28 02:36:24	2020-06-28	17	[{"id_menu":4,"count":1}]	33351	delivery	5	22
86333	2020-06-28 02:38:30	2020-06-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	33823	delivery	5	31
86334	2020-06-28 02:38:30	2020-06-28	9	[{"id_menu":6,"count":1}]	33938	delivery	5	14
86335	2020-06-28 02:38:38	2020-06-28	8	[{"id_menu":5,"count":1}]	8397	delivery	5	13
86336	2020-06-28 02:42:11	2020-06-28	12	[{"id_menu":3,"count":1}]	12439	delivery	5	17
86337	2020-06-28 02:43:32	2020-06-28	12	[{"id_menu":1,"count":1}]	30764	delivery	5	17
86338	2020-06-28 02:47:02	2020-06-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23504	delivery	5	23
86339	2020-06-28 02:48:29	2020-06-28	9	[{"id_menu":6,"count":1}]	33763	delivery	5	14
86340	2020-06-28 02:53:09	2020-06-28	9	[{"id_menu":6,"count":1}]	2374	pick-up	0	9
86341	2020-06-28 02:56:50	2020-06-28	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	33892	delivery	5	57
86342	2020-06-28 02:56:51	2020-06-28	14	[{"id_menu":2,"count":1}]	8185	pick-up	0	14
86343	2020-06-28 02:58:41	2020-06-28	9	[{"id_menu":7,"count":1}]	1114	delivery	5	14
86344	2020-06-28 02:59:07	2020-06-28	8	[{"id_menu":5,"count":2}]	22015	delivery	5	13
86345	2020-06-28 03:03:58	2020-06-28	9	[{"id_menu":6,"count":1}]	33750	delivery	5	14
86346	2020-06-28 03:12:27	2020-06-28	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	31697	delivery	5	27
86347	2020-06-28 03:14:31	2020-06-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14734	pick-up	0	18
86348	2020-06-28 03:22:22	2020-06-28	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	980	pick-up	0	23
86349	2020-06-28 03:22:26	2020-06-28	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	6939	delivery	5	26
86350	2020-06-28 03:22:57	2020-06-28	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	33842	delivery	5	39
86351	2020-06-28 03:23:04	2020-06-28	17	[{"id_menu":4,"count":1}]	3916	pick-up	0	17
86352	2020-06-28 03:23:52	2020-06-28	9	[{"id_menu":6,"count":1}]	33828	delivery	5	14
86353	2020-06-28 03:24:16	2020-06-28	12	[{"id_menu":3,"count":1}]	12139	pick-up	0	12
86354	2020-06-28 03:24:40	2020-06-28	14	[{"id_menu":2,"count":2}]	12467	delivery	5	19
86355	2020-06-28 03:25:31	2020-06-28	9	[{"id_menu":6,"count":1}]	33812	delivery	5	14
86356	2020-06-28 03:28:19	2020-06-28	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	27452	delivery	5	26
86357	2020-06-28 03:29:59	2020-06-28	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	2384	pick-up	0	24
86358	2020-06-28 03:30:45	2020-06-28	9	[{"id_menu":6,"count":1}]	8872	delivery	5	14
86359	2020-06-28 03:32:26	2020-06-28	9	[{"id_menu":6,"count":1}]	10772	pick-up	0	9
86360	2020-06-28 03:33:20	2020-06-28	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	30745	delivery	5	31
86361	2020-06-28 03:35:29	2020-06-28	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33738	delivery	5	31
86362	2020-06-28 03:36:49	2020-06-28	9	[{"id_menu":6,"count":1}]	25165	delivery	5	14
86363	2020-06-28 03:37:20	2020-06-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16282	pick-up	0	26
86364	2020-06-28 03:37:28	2020-06-28	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	33744	pick-up	0	26
86365	2020-06-28 03:37:57	2020-06-28	9	[{"id_menu":6,"count":1}]	5817	delivery	5	14
86366	2020-06-28 03:41:08	2020-06-28	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	31421	delivery	5	40
86367	2020-06-28 03:42:21	2020-06-28	14	[{"id_menu":2,"count":1}]	7070	delivery	5	19
86368	2020-06-28 03:42:26	2020-06-28	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	32839	delivery	5	30
86369	2020-06-28 03:43:06	2020-06-28	14	[{"id_menu":2,"count":1}]	33918	delivery	5	19
86370	2020-06-28 03:44:52	2020-06-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	1742	delivery	5	28
86371	2020-06-28 03:47:15	2020-06-28	9	[{"id_menu":6,"count":1}]	33777	delivery	5	14
86372	2020-06-28 03:47:19	2020-06-28	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	33769	delivery	5	40
86373	2020-06-28 03:48:27	2020-06-28	17	[{"id_menu":4,"count":1}]	17779	delivery	5	22
86374	2020-06-28 03:50:13	2020-06-28	17	[{"id_menu":4,"count":1}]	1375	pick-up	0	17
86375	2020-06-28 03:50:38	2020-06-28	9	[{"id_menu":6,"count":1}]	13497	pick-up	0	9
86376	2020-06-28 03:51:50	2020-06-28	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	868	pick-up	0	21
86377	2020-06-28 03:51:58	2020-06-28	9	[{"id_menu":6,"count":3}]	33824	delivery	5	14
86378	2020-06-28 03:56:42	2020-06-28	8	[{"id_menu":5,"count":1}]	33850	delivery	5	13
86379	2020-06-28 03:58:35	2020-06-28	9	[{"id_menu":6,"count":1}]	30423	delivery	5	14
86380	2020-06-28 04:01:09	2020-06-28	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	10101	delivery	5	31
86381	2020-06-28 04:01:36	2020-06-28	17	[{"id_menu":4,"count":1}]	31790	pick-up	0	17
86382	2020-06-28 04:02:45	2020-06-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6039	pick-up	0	23
86383	2020-06-28 04:07:09	2020-06-28	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	7957	pick-up	0	21
86384	2020-06-28 04:07:59	2020-06-28	12	[{"id_menu":3,"count":1}]	33837	delivery	5	17
86385	2020-06-28 04:09:10	2020-06-28	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14698	delivery	5	34
86386	2020-06-28 04:09:57	2020-06-28	12	[{"id_menu":1,"count":1}]	16111	delivery	5	17
86387	2020-06-28 04:10:05	2020-06-28	17	[{"id_menu":4,"count":1}]	9868	delivery	5	22
86388	2020-06-28 04:11:18	2020-06-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	32789	delivery	5	31
86389	2020-06-28 04:11:37	2020-06-28	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	33833	delivery	5	36
86390	2020-06-28 04:13:36	2020-06-28	14	[{"id_menu":2,"count":1}]	19711	pick-up	0	14
86391	2020-06-28 04:16:30	2020-06-28	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	20931	delivery	5	23
86392	2020-06-28 04:19:06	2020-06-28	12	[{"id_menu":1,"count":1}]	20907	delivery	5	17
86393	2020-06-28 04:19:32	2020-06-28	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	33888	delivery	5	26
86394	2020-06-28 04:20:10	2020-06-28	8	[{"id_menu":5,"count":1}]	18666	delivery	5	13
86395	2020-06-28 04:20:58	2020-06-28	8	[{"id_menu":5,"count":1}]	21649	delivery	5	13
86396	2020-06-28 04:21:56	2020-06-28	8	[{"id_menu":5,"count":1}]	33853	delivery	5	13
86397	2020-06-28 04:23:47	2020-06-28	8	[{"id_menu":5,"count":1}]	4455	delivery	5	13
86398	2020-06-28 04:30:11	2020-06-28	9	[{"id_menu":6,"count":3}]	26479	delivery	5	14
86399	2020-06-28 04:30:49	2020-06-28	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	11495	delivery	5	26
86400	2020-06-28 04:30:53	2020-06-28	9	[{"id_menu":6,"count":1}]	4486	pick-up	0	9
86401	2020-06-28 04:34:11	2020-06-28	17	[{"id_menu":4,"count":1}]	20623	delivery	5	22
86402	2020-06-28 04:35:13	2020-06-28	17	[{"id_menu":4,"count":1}]	33813	delivery	5	22
86403	2020-06-28 04:35:22	2020-06-28	8	[{"id_menu":5,"count":1}]	16115	delivery	5	13
86404	2020-06-28 04:36:28	2020-06-28	9	[{"id_menu":6,"count":1}]	29490	delivery	5	14
86405	2020-06-28 04:36:55	2020-06-28	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	17150	delivery	5	31
86406	2020-06-28 04:36:55	2020-06-28	9	[{"id_menu":6,"count":1}]	1422	delivery	5	14
86407	2020-06-28 04:38:35	2020-06-28	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	23623	delivery	5	43
86408	2020-06-28 04:39:51	2020-06-28	8	[{"id_menu":5,"count":1}]	33935	delivery	5	13
86409	2020-06-28 04:40:45	2020-06-28	17	[{"id_menu":4,"count":1}]	14758	delivery	5	22
86410	2020-06-28 04:43:02	2020-06-28	9	[{"id_menu":6,"count":1}]	33867	delivery	5	14
86411	2020-06-28 04:44:30	2020-06-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25574	delivery	5	22
86412	2020-06-28 04:47:38	2020-06-28	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	33805	delivery	5	43
86413	2020-06-28 04:49:24	2020-06-28	9	[{"id_menu":7,"count":2}]	20916	delivery	5	14
86414	2020-06-28 04:50:51	2020-06-28	9	[{"id_menu":6,"count":1}]	2417	delivery	5	14
86415	2020-06-28 04:52:58	2020-06-28	9	[{"id_menu":6,"count":1}]	33904	delivery	5	14
86416	2020-06-28 04:55:31	2020-06-28	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	13528	pick-up	0	29
86417	2020-06-28 04:57:52	2020-06-28	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	33779	delivery	5	27
86418	2020-06-28 04:58:33	2020-06-28	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33761	delivery	5	48
86419	2020-06-28 04:58:55	2020-06-28	14	[{"id_menu":2,"count":1}]	32402	pick-up	0	14
86420	2020-06-28 04:59:56	2020-06-28	9	[{"id_menu":6,"count":1}]	33839	delivery	5	14
86421	2020-06-28 05:01:57	2020-06-28	8	[{"id_menu":5,"count":1}]	3493	delivery	5	13
86422	2020-06-28 05:04:09	2020-06-28	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2850	pick-up	0	29
86423	2020-06-28 05:10:48	2020-06-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	522	pick-up	0	18
86424	2020-06-28 05:12:17	2020-06-28	9	[{"id_menu":7,"count":1}]	28236	delivery	5	14
86425	2020-06-28 05:13:01	2020-06-28	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	12231	delivery	5	28
86426	2020-06-28 05:13:41	2020-06-28	8	[{"id_menu":5,"count":1}]	15577	delivery	5	13
86427	2020-06-28 05:14:42	2020-06-28	12	[{"id_menu":1,"count":1}]	15715	pick-up	0	12
86428	2020-06-28 05:16:14	2020-06-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	18445	delivery	5	28
86429	2020-06-28 05:16:17	2020-06-28	9	[{"id_menu":6,"count":1}]	26621	delivery	5	14
86430	2020-06-28 05:20:28	2020-06-28	14	[{"id_menu":2,"count":1}]	33937	delivery	5	19
86431	2020-06-28 05:20:57	2020-06-28	9	[{"id_menu":7,"count":1}]	25852	pick-up	0	9
86432	2020-06-28 05:21:43	2020-06-28	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	17778	delivery	5	43
86433	2020-06-28 05:22:22	2020-06-28	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	16226	pick-up	0	29
86434	2020-06-28 05:23:04	2020-06-28	9	[{"id_menu":6,"count":1}]	25921	delivery	5	14
86435	2020-06-28 05:24:24	2020-06-28	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	33785	delivery	5	26
86436	2020-06-28 05:24:57	2020-06-28	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	33915	delivery	5	26
86437	2020-06-28 05:29:35	2020-06-28	8	[{"id_menu":5,"count":1}]	24704	pick-up	0	8
86438	2020-06-28 05:32:17	2020-06-28	14	[{"id_menu":2,"count":1}]	6046	pick-up	0	14
86439	2020-06-28 05:34:36	2020-06-28	8	[{"id_menu":5,"count":1}]	27282	delivery	5	13
86440	2020-06-28 05:35:03	2020-06-28	9	[{"id_menu":6,"count":1}]	26484	delivery	5	14
86441	2020-06-28 05:36:40	2020-06-28	9	[{"id_menu":7,"count":1}]	33808	delivery	5	14
86442	2020-06-28 05:36:57	2020-06-28	8	[{"id_menu":5,"count":1}]	627	pick-up	0	8
86443	2020-06-28 05:39:46	2020-06-28	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	29543	delivery	5	26
86444	2020-06-28 05:40:26	2020-06-28	12	[{"id_menu":1,"count":1}]	33845	delivery	5	17
86445	2020-06-28 05:42:24	2020-06-28	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	15244	delivery	5	35
86446	2020-06-28 05:52:54	2020-06-28	8	[{"id_menu":5,"count":1}]	23614	delivery	5	13
86447	2020-06-28 05:53:14	2020-06-28	9	[{"id_menu":7,"count":1}]	18556	delivery	5	14
86448	2020-06-28 05:56:36	2020-06-28	8	[{"id_menu":5,"count":1}]	33916	delivery	5	13
86449	2020-06-28 05:57:33	2020-06-28	14	[{"id_menu":2,"count":1}]	33770	delivery	5	19
86450	2020-06-28 06:01:05	2020-06-28	9	[{"id_menu":7,"count":1}]	33878	delivery	5	14
86451	2020-06-28 06:07:21	2020-06-28	17	[{"id_menu":4,"count":1}]	30269	delivery	5	22
86452	2020-06-28 06:07:34	2020-06-28	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	33877	delivery	5	27
86453	2020-06-28 06:07:55	2020-06-28	12	[{"id_menu":3,"count":1}]	22214	delivery	5	17
86454	2020-06-28 06:09:33	2020-06-28	9	[{"id_menu":7,"count":1}]	23797	pick-up	0	9
86455	2020-06-28 06:12:27	2020-06-28	37	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	31125	delivery	5	42
86456	2020-06-28 06:15:08	2020-06-28	9	[{"id_menu":7,"count":1}]	33900	delivery	5	14
86457	2020-06-28 06:16:33	2020-06-28	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33907	delivery	5	37
86458	2020-06-28 06:19:37	2020-06-28	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15048	delivery	5	36
86459	2020-06-28 06:20:33	2020-06-28	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	4962	delivery	5	23
86460	2020-06-28 06:26:05	2020-06-28	9	[{"id_menu":6,"count":1}]	17366	delivery	5	14
86461	2020-06-28 06:27:29	2020-06-28	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	33927	delivery	5	43
86462	2020-06-28 06:27:51	2020-06-28	12	[{"id_menu":1,"count":1}]	2895	delivery	5	17
86463	2020-06-28 06:29:20	2020-06-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11152	delivery	5	22
86464	2020-06-28 06:29:35	2020-06-28	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	26271	pick-up	0	29
86465	2020-06-28 06:29:57	2020-06-28	14	[{"id_menu":2,"count":1}]	26395	delivery	5	19
86466	2020-06-28 06:30:00	2020-06-28	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	33939	delivery	5	38
86467	2020-06-28 06:34:23	2020-06-28	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	15750	delivery	5	38
86468	2020-06-28 06:35:08	2020-06-28	17	[{"id_menu":4,"count":1}]	7900	delivery	5	22
86469	2020-06-28 06:36:06	2020-06-28	17	[{"id_menu":4,"count":1}]	6593	delivery	5	22
86470	2020-06-28 06:37:15	2020-06-28	12	[{"id_menu":1,"count":1}]	30496	pick-up	0	12
86471	2020-06-28 06:38:27	2020-06-28	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	24311	delivery	5	27
86472	2020-06-28 06:38:30	2020-06-28	9	[{"id_menu":6,"count":1}]	33742	delivery	5	14
86473	2020-06-28 06:39:13	2020-06-28	8	[{"id_menu":5,"count":1}]	8615	delivery	5	13
86474	2020-06-28 06:42:26	2020-06-28	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12446	delivery	5	37
86475	2020-06-28 06:42:53	2020-06-28	8	[{"id_menu":5,"count":1}]	33814	delivery	5	13
86476	2020-06-28 06:44:05	2020-06-28	9	[{"id_menu":7,"count":1}]	24266	delivery	5	14
86477	2020-06-28 06:45:19	2020-06-28	9	[{"id_menu":6,"count":1}]	14290	pick-up	0	9
86478	2020-06-28 06:45:19	2020-06-28	9	[{"id_menu":7,"count":1}]	24890	pick-up	0	9
86479	2020-06-28 06:47:07	2020-06-28	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	23755	delivery	5	27
86480	2020-06-28 06:47:44	2020-06-28	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2699	delivery	5	43
86481	2020-06-28 06:52:04	2020-06-28	9	[{"id_menu":7,"count":1}]	11812	delivery	5	14
86482	2020-06-28 06:54:17	2020-06-28	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32278	delivery	5	35
86483	2020-06-28 06:59:18	2020-06-28	9	[{"id_menu":6,"count":4}]	33881	delivery	5	14
86484	2020-06-28 07:00:27	2020-06-28	17	[{"id_menu":4,"count":1}]	33920	delivery	5	22
86485	2020-06-28 07:07:19	2020-06-28	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	4075	pick-up	0	26
86486	2020-06-28 07:09:08	2020-06-28	8	[{"id_menu":5,"count":1}]	33947	delivery	5	13
86487	2020-06-28 07:11:24	2020-06-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	23906	pick-up	0	26
86488	2020-06-28 07:11:34	2020-06-28	12	[{"id_menu":3,"count":1}]	3285	delivery	5	17
86489	2020-06-28 07:11:52	2020-06-28	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	33765	delivery	5	40
86490	2020-06-28 07:12:03	2020-06-28	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	26967	pick-up	0	31
86491	2020-06-28 07:12:50	2020-06-28	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	33865	delivery	5	40
86492	2020-06-28 07:15:50	2020-06-28	9	[{"id_menu":6,"count":1}]	18425	pick-up	0	9
86493	2020-06-28 07:17:22	2020-06-28	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	11367	delivery	5	25
86494	2020-06-28 07:26:47	2020-06-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24755	delivery	5	22
86495	2020-06-28 07:29:53	2020-06-28	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	33857	delivery	5	37
86496	2020-06-28 07:31:03	2020-06-28	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3064	delivery	5	43
86497	2020-06-28 07:31:50	2020-06-28	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	10508	delivery	5	36
86498	2020-06-28 07:32:10	2020-06-28	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	20215	pick-up	0	21
86499	2020-06-28 07:34:06	2020-06-28	9	[{"id_menu":6,"count":1}]	33753	delivery	5	14
86500	2020-06-28 07:37:59	2020-06-28	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	30554	delivery	5	25
86501	2020-06-28 07:38:02	2020-06-28	17	[{"id_menu":4,"count":1}]	20258	pick-up	0	17
86502	2020-06-28 07:39:14	2020-06-28	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6341	delivery	5	48
86503	2020-06-28 07:41:17	2020-06-28	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	18460	delivery	5	37
86504	2020-06-28 07:41:22	2020-06-28	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	27981	delivery	5	40
86505	2020-06-28 07:41:49	2020-06-28	12	[{"id_menu":1,"count":1}]	33820	delivery	5	17
86506	2020-06-28 07:43:49	2020-06-28	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	13413	delivery	5	40
86507	2020-06-28 07:43:56	2020-06-28	9	[{"id_menu":7,"count":1}]	33827	pick-up	0	9
86508	2020-06-28 07:44:22	2020-06-28	9	[{"id_menu":6,"count":1}]	19474	pick-up	0	9
86509	2020-06-28 07:51:52	2020-06-28	14	[{"id_menu":2,"count":1}]	22766	delivery	5	19
86510	2020-06-28 07:53:31	2020-06-28	14	[{"id_menu":2,"count":1}]	15990	delivery	5	19
86511	2020-06-28 07:55:15	2020-06-28	8	[{"id_menu":5,"count":1}]	33860	delivery	5	13
86512	2020-06-28 07:56:15	2020-06-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32014	delivery	5	22
86513	2020-06-28 07:56:40	2020-06-28	8	[{"id_menu":5,"count":1}]	33958	delivery	5	13
86514	2020-06-28 08:00:56	2020-06-28	14	[{"id_menu":2,"count":1}]	10495	delivery	5	19
86515	2020-06-28 08:01:54	2020-06-28	8	[{"id_menu":5,"count":1}]	33919	delivery	5	13
86516	2020-06-28 08:04:07	2020-06-28	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1942	delivery	5	34
86517	2020-06-28 08:05:13	2020-06-28	9	[{"id_menu":7,"count":1}]	2366	delivery	5	14
86518	2020-06-28 08:05:16	2020-06-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18061	delivery	5	22
86519	2020-06-28 08:05:17	2020-06-28	12	[{"id_menu":3,"count":1}]	17520	pick-up	0	12
86520	2020-06-28 08:05:56	2020-06-28	9	[{"id_menu":6,"count":1}]	11288	delivery	5	14
86521	2020-06-28 08:06:39	2020-06-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	33807	delivery	5	22
86522	2020-06-28 08:08:14	2020-06-28	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	30077	delivery	5	36
86523	2020-06-28 08:09:57	2020-06-28	9	[{"id_menu":6,"count":1}]	32861	delivery	5	14
86524	2020-06-28 08:10:05	2020-06-28	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16952	delivery	5	45
86525	2020-06-28 08:10:22	2020-06-28	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	33912	delivery	5	34
86526	2020-06-28 08:10:50	2020-06-28	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	31437	delivery	5	44
86527	2020-06-28 08:11:29	2020-06-28	14	[{"id_menu":2,"count":1}]	33936	delivery	5	19
86528	2020-06-28 08:15:03	2020-06-28	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25459	delivery	5	31
86529	2020-06-28 08:16:02	2020-06-28	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	33568	delivery	5	43
86530	2020-06-28 08:16:18	2020-06-28	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	7247	pick-up	0	29
86531	2020-06-28 08:17:18	2020-06-28	9	[{"id_menu":6,"count":1}]	32485	delivery	5	14
86532	2020-06-28 08:18:24	2020-06-28	9	[{"id_menu":7,"count":1}]	8799	pick-up	0	9
86533	2020-06-28 08:23:51	2020-06-28	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1951	delivery	5	31
86534	2020-06-28 08:26:29	2020-06-28	9	[{"id_menu":6,"count":1}]	33854	delivery	5	14
86535	2020-06-28 08:27:27	2020-06-28	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	33801	delivery	5	34
86536	2020-06-28 08:28:11	2020-06-28	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	11321	delivery	5	37
86537	2020-06-28 08:28:45	2020-06-28	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	16432	delivery	5	26
86538	2020-06-28 08:31:38	2020-06-28	14	[{"id_menu":2,"count":2}]	9531	pick-up	0	14
86539	2020-06-28 08:33:21	2020-06-28	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	33959	delivery	5	26
86540	2020-06-28 08:35:33	2020-06-28	8	[{"id_menu":5,"count":1}]	21184	pick-up	0	8
86541	2020-06-28 08:36:06	2020-06-28	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	27072	delivery	5	25
86542	2020-06-28 08:39:25	2020-06-28	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	33755	delivery	5	26
86543	2020-06-28 08:41:22	2020-06-28	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	26686	delivery	5	34
86544	2020-06-28 08:43:35	2020-06-28	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	33116	delivery	5	26
86545	2020-06-28 08:47:23	2020-06-28	17	[{"id_menu":4,"count":1}]	23157	delivery	5	22
86546	2020-06-28 08:48:04	2020-06-28	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	16779	delivery	5	30
86547	2020-06-28 08:49:27	2020-06-28	12	[{"id_menu":3,"count":1}]	2249	pick-up	0	12
86548	2020-06-28 08:51:00	2020-06-28	14	[{"id_menu":2,"count":1}]	9907	pick-up	0	14
86549	2020-06-28 08:51:36	2020-06-28	9	[{"id_menu":6,"count":1}]	33792	delivery	5	14
86550	2020-06-28 09:01:34	2020-06-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19401	delivery	5	22
86551	2020-06-28 09:02:01	2020-06-28	14	[{"id_menu":2,"count":1}]	6719	delivery	5	19
86552	2020-06-28 09:04:01	2020-06-28	12	[{"id_menu":1,"count":2}]	8702	delivery	5	17
86553	2020-06-28 09:04:22	2020-06-28	12	[{"id_menu":3,"count":1}]	9446	delivery	5	17
86554	2020-06-28 09:04:38	2020-06-28	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	25211	delivery	5	45
86555	2020-06-28 09:05:33	2020-06-28	9	[{"id_menu":6,"count":1}]	13432	delivery	5	14
86556	2020-06-28 09:06:31	2020-06-28	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	33917	delivery	5	37
86557	2020-06-28 09:07:19	2020-06-28	14	[{"id_menu":2,"count":1}]	33378	delivery	5	19
86558	2020-06-28 09:08:53	2020-06-28	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	4161	delivery	5	29
86559	2020-06-28 09:12:03	2020-06-28	14	[{"id_menu":2,"count":1}]	37	pick-up	0	14
86560	2020-06-28 09:12:58	2020-06-28	12	[{"id_menu":3,"count":1}]	33909	delivery	5	17
86561	2020-06-28 09:13:37	2020-06-28	9	[{"id_menu":6,"count":1}]	21595	pick-up	0	9
86562	2020-06-28 09:14:19	2020-06-28	17	[{"id_menu":4,"count":1}]	33740	delivery	5	22
86563	2020-06-28 09:15:21	2020-06-28	9	[{"id_menu":7,"count":1}]	33840	delivery	5	14
86564	2020-06-28 09:18:41	2020-06-28	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":2}]	27846	delivery	5	26
86565	2020-06-28 09:19:35	2020-06-28	12	[{"id_menu":1,"count":1}]	33846	delivery	5	17
86566	2020-06-28 09:20:53	2020-06-28	8	[{"id_menu":5,"count":1}]	24733	delivery	5	13
86567	2020-06-28 09:21:43	2020-06-28	9	[{"id_menu":7,"count":1}]	25190	pick-up	0	9
86568	2020-06-28 09:27:51	2020-06-28	12	[{"id_menu":3,"count":1}]	707	pick-up	0	12
86569	2020-06-28 09:30:14	2020-06-28	12	[{"id_menu":3,"count":1}]	8757	delivery	5	17
86570	2020-06-28 09:33:07	2020-06-28	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19771	delivery	5	37
86571	2020-06-28 09:34:13	2020-06-28	14	[{"id_menu":2,"count":2}]	33928	delivery	5	19
86572	2020-06-28 09:35:05	2020-06-28	9	[{"id_menu":7,"count":1}]	31880	delivery	5	14
86573	2020-06-28 09:38:21	2020-06-28	12	[{"id_menu":3,"count":1}]	1262	delivery	5	17
86574	2020-06-28 09:40:13	2020-06-28	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	172	pick-up	0	23
86575	2020-06-28 09:40:48	2020-06-28	9	[{"id_menu":6,"count":1}]	12424	delivery	5	14
86576	2020-06-28 09:43:40	2020-06-28	12	[{"id_menu":3,"count":1}]	20926	delivery	5	17
86577	2020-06-28 09:44:39	2020-06-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33815	delivery	5	23
86578	2020-06-28 09:46:34	2020-06-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	844	delivery	5	28
86579	2020-06-28 09:46:49	2020-06-28	9	[{"id_menu":6,"count":1}]	32954	delivery	5	14
86580	2020-06-28 09:51:05	2020-06-28	9	[{"id_menu":6,"count":1}]	33806	delivery	5	14
86581	2020-06-28 09:53:18	2020-06-28	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	33843	delivery	5	26
86582	2020-06-28 09:54:22	2020-06-28	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	33872	delivery	5	53
86583	2020-06-28 09:54:56	2020-06-28	14	[{"id_menu":2,"count":1}]	12954	delivery	5	19
86584	2020-06-28 09:55:59	2020-06-28	9	[{"id_menu":7,"count":1}]	8583	delivery	5	14
86585	2020-06-28 09:56:31	2020-06-28	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	33835	delivery	5	28
86586	2020-06-28 09:59:21	2020-06-28	14	[{"id_menu":2,"count":1}]	10019	pick-up	0	14
86587	2020-06-28 09:59:50	2020-06-28	12	[{"id_menu":3,"count":1}]	30125	delivery	5	17
86588	2020-06-28 10:02:41	2020-06-28	9	[{"id_menu":7,"count":1}]	31967	delivery	5	14
86589	2020-06-28 10:03:23	2020-06-28	9	[{"id_menu":6,"count":1}]	1457	delivery	5	14
86590	2020-06-28 10:03:36	2020-06-28	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6393	delivery	5	36
86591	2020-06-28 10:05:15	2020-06-28	17	[{"id_menu":4,"count":1}]	3287	pick-up	0	17
86592	2020-06-28 10:06:14	2020-06-28	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18683	delivery	5	48
86593	2020-06-28 10:06:22	2020-06-28	12	[{"id_menu":3,"count":1}]	15044	delivery	5	17
86594	2020-06-28 10:07:21	2020-06-28	8	[{"id_menu":5,"count":1}]	33774	delivery	5	13
86595	2020-06-28 10:13:34	2020-06-28	17	[{"id_menu":4,"count":1}]	33921	delivery	5	22
86596	2020-06-28 10:16:07	2020-06-28	8	[{"id_menu":5,"count":1}]	33803	delivery	5	13
86597	2020-06-28 10:16:48	2020-06-28	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	22581	delivery	5	34
86598	2020-06-28 10:16:57	2020-06-28	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	29004	delivery	5	37
86599	2020-06-28 10:17:06	2020-06-28	17	[{"id_menu":4,"count":1}]	6633	delivery	5	22
86600	2020-06-28 10:18:39	2020-06-28	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	12468	delivery	5	44
86601	2020-06-28 10:21:26	2020-06-28	12	[{"id_menu":3,"count":1}]	24767	pick-up	0	12
86602	2020-06-28 10:23:27	2020-06-28	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	26077	delivery	5	35
86603	2020-06-28 10:24:27	2020-06-28	12	[{"id_menu":1,"count":1}]	33780	delivery	5	17
86604	2020-06-28 10:25:32	2020-06-28	14	[{"id_menu":2,"count":1}]	22516	delivery	5	19
86605	2020-06-28 10:26:23	2020-06-28	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	33844	delivery	5	36
86606	2020-06-28 10:26:28	2020-06-28	9	[{"id_menu":7,"count":1}]	26039	delivery	5	14
86607	2020-06-28 10:29:18	2020-06-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8994	delivery	5	31
86608	2020-06-28 10:29:25	2020-06-28	9	[{"id_menu":6,"count":2}]	3443	delivery	5	14
86609	2020-06-28 10:30:51	2020-06-28	9	[{"id_menu":7,"count":1}]	25332	delivery	5	14
86610	2020-06-28 10:31:20	2020-06-28	17	[{"id_menu":4,"count":1}]	32234	delivery	5	22
86611	2020-06-28 10:31:49	2020-06-28	17	[{"id_menu":4,"count":1}]	33951	delivery	5	22
86612	2020-06-28 10:37:36	2020-06-28	14	[{"id_menu":2,"count":2}]	15216	pick-up	0	14
86613	2020-06-28 10:38:00	2020-06-28	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14311	delivery	5	37
86614	2020-06-28 10:42:46	2020-06-28	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	33743	delivery	5	22
86615	2020-06-28 10:44:30	2020-06-28	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	33752	delivery	5	35
86616	2020-06-28 10:46:58	2020-06-28	14	[{"id_menu":2,"count":1}]	29988	pick-up	0	14
86617	2020-06-28 10:48:25	2020-06-28	12	[{"id_menu":3,"count":1}]	22070	delivery	5	17
86618	2020-06-28 10:49:43	2020-06-28	9	[{"id_menu":7,"count":1}]	17948	delivery	5	14
86619	2020-06-28 10:50:04	2020-06-28	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	23832	delivery	5	39
86620	2020-06-28 10:50:32	2020-06-28	12	[{"id_menu":1,"count":1}]	33832	delivery	5	17
86621	2020-06-28 10:50:36	2020-06-28	12	[{"id_menu":1,"count":1}]	3293	delivery	5	17
86622	2020-06-28 10:51:18	2020-06-28	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17973	delivery	5	31
86623	2020-06-28 10:52:39	2020-06-28	9	[{"id_menu":7,"count":1}]	8588	delivery	5	14
86624	2020-06-28 10:53:23	2020-06-28	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	15042	delivery	5	26
86625	2020-06-28 10:55:17	2020-06-28	14	[{"id_menu":2,"count":1}]	118	pick-up	0	14
86626	2020-06-28 10:56:26	2020-06-28	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	30136	delivery	5	26
86627	2020-06-28 10:57:38	2020-06-28	9	[{"id_menu":6,"count":1}]	33898	delivery	5	14
86628	2020-06-28 10:58:15	2020-06-28	12	[{"id_menu":1,"count":1}]	19380	delivery	5	17
86629	2020-06-28 10:58:43	2020-06-28	12	[{"id_menu":3,"count":1}]	1134	delivery	5	17
86630	2020-06-28 10:59:20	2020-06-28	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	15728	delivery	5	25
86631	2020-06-28 10:59:34	2020-06-28	14	[{"id_menu":2,"count":1}]	14054	pick-up	0	14
86632	2020-06-28 11:00:17	2020-06-28	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	33856	delivery	5	45
86633	2020-06-28 11:01:47	2020-06-28	12	[{"id_menu":3,"count":1}]	9362	delivery	5	17
86634	2020-06-28 11:04:24	2020-06-28	8	[{"id_menu":5,"count":1}]	18758	pick-up	0	8
86635	2020-06-28 11:06:26	2020-06-28	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	8375	delivery	5	26
86636	2020-06-28 11:08:36	2020-06-28	9	[{"id_menu":7,"count":1}]	20744	delivery	5	14
86637	2020-06-28 11:09:15	2020-06-28	12	[{"id_menu":1,"count":1}]	33890	delivery	5	17
86638	2020-06-28 11:10:18	2020-06-28	9	[{"id_menu":7,"count":1}]	33788	delivery	5	14
86639	2020-06-28 11:10:35	2020-06-28	12	[{"id_menu":3,"count":1}]	33751	pick-up	0	12
86640	2020-06-28 11:15:40	2020-06-28	12	[{"id_menu":1,"count":1}]	33953	pick-up	0	12
86641	2020-06-28 11:17:05	2020-06-28	14	[{"id_menu":2,"count":1}]	2567	pick-up	0	14
86642	2020-06-28 11:28:09	2020-06-28	9	[{"id_menu":6,"count":1}]	25061	delivery	5	14
86643	2020-06-28 11:28:24	2020-06-28	9	[{"id_menu":6,"count":2}]	33945	delivery	5	14
86644	2020-06-28 11:29:53	2020-06-28	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	33874	delivery	5	36
86645	2020-06-28 11:31:37	2020-06-28	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19303	delivery	5	48
86646	2020-06-28 11:33:48	2020-06-28	30	[{"id_menu":3,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5024	delivery	5	35
86647	2020-06-28 11:34:33	2020-06-28	38	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	6097	pick-up	0	38
86648	2020-06-28 11:35:35	2020-06-28	8	[{"id_menu":5,"count":1}]	17091	delivery	5	13
86649	2020-06-28 11:36:33	2020-06-28	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	265	pick-up	0	31
86650	2020-06-28 11:37:27	2020-06-28	12	[{"id_menu":3,"count":1}]	25279	pick-up	0	12
86651	2020-06-28 11:38:59	2020-06-28	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	33893	delivery	5	53
86652	2020-06-28 11:39:01	2020-06-28	14	[{"id_menu":2,"count":1}]	33889	pick-up	0	14
86653	2020-06-28 11:40:48	2020-06-28	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	33906	pick-up	0	31
86654	2020-06-28 11:41:10	2020-06-28	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1147	pick-up	0	22
86655	2020-06-28 11:41:14	2020-06-28	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	33876	delivery	5	36
86656	2020-06-28 11:44:32	2020-06-28	9	[{"id_menu":7,"count":1}]	18781	delivery	5	14
86657	2020-06-28 11:47:55	2020-06-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	33883	delivery	5	28
86658	2020-06-28 11:48:36	2020-06-28	12	[{"id_menu":1,"count":1}]	9122	delivery	5	17
86659	2020-06-28 11:51:38	2020-06-28	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	19922	delivery	5	29
86660	2020-06-28 11:51:45	2020-06-28	14	[{"id_menu":2,"count":1}]	3579	delivery	5	19
86661	2020-06-28 11:52:06	2020-06-28	8	[{"id_menu":5,"count":1}]	33869	delivery	5	13
86662	2020-06-28 11:53:26	2020-06-28	9	[{"id_menu":7,"count":1}]	33923	delivery	5	14
86663	2020-06-28 11:56:49	2020-06-28	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33764	delivery	5	35
86664	2020-06-28 12:01:06	2020-06-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	25992	delivery	5	22
86665	2020-06-28 12:01:39	2020-06-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11709	delivery	5	31
86666	2020-06-28 12:02:38	2020-06-28	8	[{"id_menu":5,"count":1}]	33932	pick-up	0	8
86667	2020-06-28 12:02:45	2020-06-28	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31508	delivery	5	39
86668	2020-06-28 12:03:10	2020-06-28	17	[{"id_menu":4,"count":1}]	8123	delivery	5	22
86669	2020-06-28 12:09:41	2020-06-28	12	[{"id_menu":1,"count":1}]	9358	pick-up	0	12
86670	2020-06-28 12:13:40	2020-06-28	17	[{"id_menu":4,"count":1}]	8458	pick-up	0	17
86671	2020-06-28 12:15:25	2020-06-28	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	33831	delivery	5	48
86672	2020-06-28 12:15:48	2020-06-28	14	[{"id_menu":2,"count":1}]	13570	delivery	5	19
86673	2020-06-28 12:17:51	2020-06-28	8	[{"id_menu":5,"count":3}]	24074	pick-up	0	8
86674	2020-06-28 12:20:34	2020-06-28	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1539	pick-up	0	29
86675	2020-06-28 12:22:17	2020-06-28	9	[{"id_menu":7,"count":1}]	21999	delivery	5	14
86676	2020-06-28 12:27:11	2020-06-28	9	[{"id_menu":6,"count":2}]	2183	pick-up	0	9
86677	2020-06-28 12:29:11	2020-06-28	9	[{"id_menu":6,"count":2}]	8737	delivery	5	14
86678	2020-06-28 12:29:57	2020-06-28	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	11932	delivery	5	34
86679	2020-06-28 12:29:57	2020-06-28	9	[{"id_menu":6,"count":1}]	4119	delivery	5	14
86680	2020-06-28 12:30:53	2020-06-28	12	[{"id_menu":1,"count":1}]	3414	pick-up	0	12
86681	2020-06-28 12:31:00	2020-06-28	9	[{"id_menu":7,"count":1}]	22177	delivery	5	14
86682	2020-06-28 12:31:48	2020-06-28	12	[{"id_menu":1,"count":2}]	8595	pick-up	0	12
86683	2020-06-28 12:31:50	2020-06-28	17	[{"id_menu":4,"count":1}]	16485	pick-up	0	17
86684	2020-06-28 12:32:05	2020-06-28	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8329	delivery	5	53
86685	2020-06-28 12:32:11	2020-06-28	14	[{"id_menu":2,"count":1}]	32906	delivery	5	19
86686	2020-06-28 12:36:38	2020-06-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1053	pick-up	0	23
86687	2020-06-28 12:37:05	2020-06-28	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	33849	delivery	5	31
86688	2020-06-28 12:43:08	2020-06-28	12	[{"id_menu":3,"count":1}]	33944	delivery	5	17
86689	2020-06-28 12:44:21	2020-06-28	17	[{"id_menu":4,"count":1}]	14010	pick-up	0	17
86690	2020-06-28 12:44:46	2020-06-28	8	[{"id_menu":5,"count":1}]	33922	delivery	5	13
86691	2020-06-28 12:47:58	2020-06-28	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1276	pick-up	0	23
86692	2020-06-28 12:49:30	2020-06-28	17	[{"id_menu":4,"count":1}]	33783	delivery	5	22
86693	2020-06-28 12:50:01	2020-06-28	12	[{"id_menu":1,"count":1}]	2885	delivery	5	17
86694	2020-06-28 12:50:02	2020-06-28	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	33784	delivery	5	27
86695	2020-06-28 12:51:32	2020-06-28	9	[{"id_menu":7,"count":1}]	33760	delivery	5	14
86696	2020-06-28 12:55:01	2020-06-28	17	[{"id_menu":4,"count":1}]	10330	pick-up	0	17
86697	2020-06-28 12:56:51	2020-06-28	17	[{"id_menu":4,"count":1}]	17138	delivery	5	22
86698	2020-06-28 12:57:25	2020-06-28	12	[{"id_menu":1,"count":1}]	7709	delivery	5	17
86699	2020-06-28 12:57:57	2020-06-28	8	[{"id_menu":5,"count":1}]	44	pick-up	0	8
86700	2020-06-28 12:58:05	2020-06-28	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33933	delivery	5	35
86701	2020-06-28 12:58:28	2020-06-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	33926	delivery	5	31
86702	2020-06-28 13:03:00	2020-06-28	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9321	delivery	5	36
86703	2020-06-28 13:03:30	2020-06-28	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	22293	delivery	5	48
86704	2020-06-28 13:05:16	2020-06-28	17	[{"id_menu":4,"count":1}]	5808	pick-up	0	17
86705	2020-06-28 13:05:39	2020-06-28	8	[{"id_menu":5,"count":1}]	11038	delivery	5	13
86706	2020-06-28 13:07:44	2020-06-28	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	26899	delivery	5	40
86707	2020-06-28 13:09:42	2020-06-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	33800	delivery	5	31
86708	2020-06-28 13:10:33	2020-06-28	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4967	delivery	5	44
86709	2020-06-28 13:12:45	2020-06-28	9	[{"id_menu":7,"count":1}]	27429	pick-up	0	9
86710	2020-06-28 13:13:24	2020-06-28	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	33153	pick-up	0	20
86711	2020-06-28 13:14:35	2020-06-28	8	[{"id_menu":5,"count":1}]	33887	delivery	5	13
86712	2020-06-28 13:18:35	2020-06-28	8	[{"id_menu":5,"count":1}]	33757	delivery	5	13
86713	2020-06-28 13:20:09	2020-06-28	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	14252	pick-up	0	23
86714	2020-06-28 13:24:15	2020-06-28	17	[{"id_menu":4,"count":1}]	13901	delivery	5	22
86715	2020-06-28 13:24:23	2020-06-28	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	21667	delivery	5	25
86716	2020-06-28 13:26:19	2020-06-28	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	13082	delivery	5	26
86717	2020-06-28 13:27:08	2020-06-28	9	[{"id_menu":6,"count":1}]	15953	delivery	5	14
86718	2020-06-28 13:31:45	2020-06-28	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	28413	delivery	5	28
86719	2020-06-28 13:31:46	2020-06-28	12	[{"id_menu":3,"count":1}]	6816	delivery	5	17
86720	2020-06-28 13:32:47	2020-06-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	8783	delivery	5	31
86721	2020-06-28 13:37:22	2020-06-28	9	[{"id_menu":7,"count":1}]	10389	pick-up	0	9
86722	2020-06-28 13:40:02	2020-06-28	9	[{"id_menu":6,"count":1}]	33822	delivery	5	14
86723	2020-06-28 13:41:29	2020-06-28	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	16114	pick-up	0	25
86724	2020-06-28 13:43:34	2020-06-28	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	6480	delivery	5	45
86725	2020-06-28 13:44:28	2020-06-28	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	10359	delivery	5	28
86726	2020-06-28 13:44:58	2020-06-28	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	14788	delivery	5	39
86727	2020-06-28 13:47:05	2020-06-28	9	[{"id_menu":7,"count":1}]	32128	delivery	5	14
86728	2020-06-28 13:49:51	2020-06-28	9	[{"id_menu":7,"count":1}]	19443	delivery	5	14
86729	2020-06-28 13:51:20	2020-06-28	9	[{"id_menu":6,"count":1}]	5189	delivery	5	14
86730	2020-06-28 13:56:37	2020-06-28	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	24081	delivery	5	36
86731	2020-06-28 13:58:11	2020-06-28	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	16590	delivery	5	31
86732	2020-06-28 14:00:37	2020-06-28	9	[{"id_menu":7,"count":1}]	26483	delivery	5	14
86733	2020-06-28 14:03:08	2020-06-28	12	[{"id_menu":3,"count":1}]	33859	delivery	5	17
86734	2020-06-28 14:05:00	2020-06-28	9	[{"id_menu":6,"count":1}]	29204	delivery	5	14
86735	2020-06-28 14:05:47	2020-06-28	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3071	delivery	5	34
86736	2020-06-28 14:08:13	2020-06-28	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1988	pick-up	0	29
86737	2020-06-28 14:08:54	2020-06-28	12	[{"id_menu":3,"count":1}]	343	pick-up	0	12
86738	2020-06-28 14:09:43	2020-06-28	9	[{"id_menu":6,"count":1}]	29308	delivery	5	14
86739	2020-06-28 14:11:05	2020-06-28	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	33955	pick-up	0	21
86740	2020-06-28 14:14:04	2020-06-28	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	21066	delivery	5	34
86741	2020-06-28 14:15:20	2020-06-28	9	[{"id_menu":6,"count":1}]	865	delivery	5	14
86742	2020-06-28 14:16:23	2020-06-28	14	[{"id_menu":2,"count":1}]	12836	pick-up	0	14
86743	2020-06-28 14:20:49	2020-06-28	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4521	delivery	5	34
86744	2020-06-28 14:24:40	2020-06-28	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	33901	delivery	5	40
86745	2020-06-28 14:25:50	2020-06-28	8	[{"id_menu":5,"count":1}]	15851	pick-up	0	8
86746	2020-06-28 14:27:35	2020-06-28	9	[{"id_menu":7,"count":1}]	33838	pick-up	0	9
86747	2020-06-28 14:33:50	2020-06-28	9	[{"id_menu":7,"count":1}]	23949	delivery	5	14
86748	2020-06-28 14:35:25	2020-06-28	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	6	pick-up	0	32
86749	2020-06-28 14:36:22	2020-06-28	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33802	delivery	5	31
86750	2020-06-28 14:42:30	2020-06-28	9	[{"id_menu":6,"count":1}]	33793	delivery	5	14
86751	2020-06-28 14:51:55	2020-06-28	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33930	delivery	5	40
86752	2020-06-28 14:52:14	2020-06-28	9	[{"id_menu":7,"count":1}]	23394	delivery	5	14
86753	2020-06-28 14:52:18	2020-06-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	31442	pick-up	0	17
86754	2020-06-28 14:52:43	2020-06-28	9	[{"id_menu":7,"count":1}]	3864	pick-up	0	9
86755	2020-06-28 14:53:13	2020-06-28	17	[{"id_menu":4,"count":1}]	30406	pick-up	0	17
86756	2020-06-28 14:53:16	2020-06-28	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	33847	delivery	5	26
86757	2020-06-28 14:54:19	2020-06-28	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	28531	delivery	5	31
86758	2020-06-28 14:55:30	2020-06-28	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	24129	pick-up	0	25
86759	2020-06-28 14:57:14	2020-06-28	12	[{"id_menu":3,"count":1}]	17614	delivery	5	17
86760	2020-06-28 14:58:09	2020-06-28	12	[{"id_menu":3,"count":1}]	4800	delivery	5	17
86761	2020-06-28 15:00:01	2020-06-28	14	[{"id_menu":2,"count":1}]	18476	delivery	5	19
86762	2020-06-28 15:00:29	2020-06-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	7579	delivery	5	31
86763	2020-06-28 15:01:45	2020-06-28	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	12994	delivery	5	43
86764	2020-06-28 15:02:26	2020-06-28	14	[{"id_menu":2,"count":1}]	12359	delivery	5	19
86765	2020-06-28 15:04:00	2020-06-28	9	[{"id_menu":6,"count":1}]	19750	delivery	5	14
86766	2020-06-28 15:04:11	2020-06-28	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	16406	pick-up	0	20
86767	2020-06-28 15:06:19	2020-06-28	12	[{"id_menu":3,"count":1}]	26116	delivery	5	17
86768	2020-06-28 15:10:37	2020-06-28	8	[{"id_menu":5,"count":1}]	7462	delivery	5	13
86769	2020-06-28 15:10:51	2020-06-28	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10159	delivery	5	37
86770	2020-06-28 15:11:57	2020-06-28	14	[{"id_menu":2,"count":2}]	29134	delivery	5	19
86771	2020-06-28 15:12:56	2020-06-28	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	33880	pick-up	0	21
86772	2020-06-28 15:16:45	2020-06-28	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	15791	pick-up	0	22
86773	2020-06-28 15:17:41	2020-06-28	14	[{"id_menu":2,"count":1}]	2176	pick-up	0	14
86774	2020-06-28 15:19:13	2020-06-28	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	7297	pick-up	0	22
86775	2020-06-28 15:24:20	2020-06-28	14	[{"id_menu":2,"count":1}]	10209	pick-up	0	14
86776	2020-06-28 15:26:02	2020-06-28	9	[{"id_menu":6,"count":1}]	33775	delivery	5	14
86777	2020-06-28 15:26:58	2020-06-28	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	33819	delivery	5	26
86778	2020-06-28 15:30:01	2020-06-28	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	6284	delivery	5	43
86779	2020-06-28 15:40:07	2020-06-28	14	[{"id_menu":2,"count":1}]	32298	delivery	5	19
86780	2020-06-28 15:48:01	2020-06-28	8	[{"id_menu":5,"count":1}]	8407	pick-up	0	8
86781	2020-06-28 15:48:15	2020-06-28	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	33791	delivery	5	31
86782	2020-06-28 15:50:22	2020-06-28	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7712	delivery	5	31
86783	2020-06-28 15:51:32	2020-06-28	17	[{"id_menu":4,"count":1}]	33458	pick-up	0	17
86784	2020-06-28 15:54:36	2020-06-28	9	[{"id_menu":7,"count":1}]	20302	delivery	5	14
86785	2020-06-28 15:56:15	2020-06-28	9	[{"id_menu":6,"count":1}]	8517	delivery	5	14
86786	2020-06-28 15:57:03	2020-06-28	14	[{"id_menu":2,"count":1}]	2364	pick-up	0	14
86787	2020-06-28 15:59:28	2020-06-28	12	[{"id_menu":1,"count":1}]	33794	pick-up	0	12
86788	2020-06-28 16:02:00	2020-06-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7996	delivery	5	22
86789	2020-06-28 16:02:36	2020-06-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	22843	delivery	5	31
86790	2020-06-28 16:04:37	2020-06-28	9	[{"id_menu":7,"count":1}]	33925	pick-up	0	9
86791	2020-06-28 16:08:43	2020-06-28	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	18438	delivery	5	36
86792	2020-06-28 16:10:21	2020-06-28	9	[{"id_menu":6,"count":1}]	28174	delivery	5	14
86793	2020-06-28 16:11:30	2020-06-28	9	[{"id_menu":6,"count":1}]	33748	delivery	5	14
86794	2020-06-28 16:14:26	2020-06-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1920	delivery	5	23
86795	2020-06-28 16:14:38	2020-06-28	9	[{"id_menu":7,"count":1}]	33754	delivery	5	14
86796	2020-06-28 16:15:38	2020-06-28	9	[{"id_menu":6,"count":1}]	12419	delivery	5	14
86797	2020-06-28 16:17:03	2020-06-28	9	[{"id_menu":6,"count":1}]	27035	delivery	5	14
86798	2020-06-28 16:20:04	2020-06-28	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	26213	delivery	5	39
86799	2020-06-28 16:21:41	2020-06-28	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	15443	delivery	5	38
86800	2020-06-28 16:22:31	2020-06-28	9	[{"id_menu":6,"count":1}]	17051	delivery	5	14
86801	2020-06-28 16:22:41	2020-06-28	8	[{"id_menu":5,"count":1}]	3467	delivery	5	13
86802	2020-06-28 16:23:10	2020-06-28	8	[{"id_menu":5,"count":1}]	143	pick-up	0	8
86803	2020-06-28 16:25:50	2020-06-28	12	[{"id_menu":1,"count":1}]	934	pick-up	0	12
86804	2020-06-28 16:29:07	2020-06-28	9	[{"id_menu":7,"count":1}]	33756	delivery	5	14
86805	2020-06-28 16:30:18	2020-06-28	9	[{"id_menu":6,"count":1}]	25360	delivery	5	14
86806	2020-06-28 16:34:07	2020-06-28	17	[{"id_menu":4,"count":1}]	33895	delivery	5	22
86807	2020-06-28 16:35:38	2020-06-28	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	14987	delivery	5	27
86808	2020-06-28 16:37:59	2020-06-28	14	[{"id_menu":2,"count":1}]	33741	delivery	5	19
86809	2020-06-28 16:39:20	2020-06-28	17	[{"id_menu":4,"count":1}]	3057	delivery	5	22
86810	2020-06-28 16:41:37	2020-06-28	8	[{"id_menu":5,"count":1}]	32152	pick-up	0	8
86811	2020-06-28 16:45:18	2020-06-28	9	[{"id_menu":6,"count":2}]	5060	pick-up	0	9
86812	2020-06-28 16:45:39	2020-06-28	12	[{"id_menu":3,"count":1}]	20457	delivery	5	17
86813	2020-06-28 16:47:18	2020-06-28	9	[{"id_menu":6,"count":1}]	6200	delivery	5	14
86814	2020-06-28 16:48:10	2020-06-28	14	[{"id_menu":2,"count":1}]	14463	delivery	5	19
86815	2020-06-28 16:50:15	2020-06-28	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	18067	delivery	5	45
86816	2020-06-28 16:52:17	2020-06-28	12	[{"id_menu":1,"count":1}]	33811	delivery	5	17
86817	2020-06-28 16:52:57	2020-06-28	9	[{"id_menu":6,"count":1}]	33891	delivery	5	14
86818	2020-06-28 16:56:08	2020-06-28	9	[{"id_menu":6,"count":1}]	33735	delivery	5	14
86819	2020-06-28 16:57:02	2020-06-28	9	[{"id_menu":7,"count":1}]	9467	pick-up	0	9
86820	2020-06-28 16:57:27	2020-06-28	9	[{"id_menu":7,"count":2}]	33736	delivery	5	14
86821	2020-06-28 16:58:11	2020-06-28	12	[{"id_menu":1,"count":1}]	314	delivery	5	17
86822	2020-06-28 16:59:38	2020-06-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	7526	delivery	5	28
86823	2020-06-28 16:59:55	2020-06-28	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	16240	delivery	5	36
86824	2020-06-28 17:00:37	2020-06-28	9	[{"id_menu":6,"count":2}]	1423	pick-up	0	9
86825	2020-06-28 17:00:57	2020-06-28	8	[{"id_menu":5,"count":1}]	10070	delivery	5	13
86826	2020-06-28 17:04:43	2020-06-28	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28856	delivery	5	40
86827	2020-06-28 17:13:56	2020-06-28	12	[{"id_menu":1,"count":1}]	14039	delivery	5	17
86828	2020-06-28 17:14:13	2020-06-28	9	[{"id_menu":6,"count":1}]	1533	pick-up	0	9
86829	2020-06-28 17:16:01	2020-06-28	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3764	delivery	5	39
86830	2020-06-28 17:17:55	2020-06-28	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	33949	delivery	5	30
86831	2020-06-28 17:19:52	2020-06-28	8	[{"id_menu":5,"count":1}]	33864	delivery	5	13
86832	2020-06-28 17:20:20	2020-06-28	8	[{"id_menu":5,"count":1}]	10914	delivery	5	13
86833	2020-06-28 17:21:21	2020-06-28	9	[{"id_menu":7,"count":1}]	18170	pick-up	0	9
86834	2020-06-28 17:23:47	2020-06-28	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	13429	pick-up	0	20
86835	2020-06-28 17:26:06	2020-06-28	17	[{"id_menu":4,"count":1}]	28929	pick-up	0	17
86836	2020-06-28 17:26:55	2020-06-28	14	[{"id_menu":2,"count":1}]	15385	pick-up	0	14
86837	2020-06-28 17:27:14	2020-06-28	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	33737	pick-up	0	48
86838	2020-06-28 17:27:19	2020-06-28	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33861	delivery	5	40
86839	2020-06-28 17:28:05	2020-06-28	14	[{"id_menu":2,"count":1}]	33782	pick-up	0	14
86840	2020-06-28 17:28:14	2020-06-28	8	[{"id_menu":5,"count":1}]	24337	delivery	5	13
86841	2020-06-28 17:28:30	2020-06-28	9	[{"id_menu":7,"count":1}]	31655	delivery	5	14
86842	2020-06-28 17:30:16	2020-06-28	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	32900	delivery	5	26
86843	2020-06-28 17:36:09	2020-06-28	12	[{"id_menu":3,"count":1}]	11317	delivery	5	17
86844	2020-06-28 17:36:51	2020-06-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9423	pick-up	0	18
86845	2020-06-28 17:40:15	2020-06-28	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	25420	delivery	5	25
86846	2020-06-28 17:44:25	2020-06-28	9	[{"id_menu":7,"count":1}]	33817	delivery	5	14
86847	2020-06-28 17:45:33	2020-06-28	12	[{"id_menu":3,"count":1}]	29852	pick-up	0	12
86848	2020-06-28 17:46:27	2020-06-28	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	32141	pick-up	0	31
86849	2020-06-28 17:46:35	2020-06-28	9	[{"id_menu":7,"count":4}]	16660	delivery	5	14
86850	2020-06-28 17:47:35	2020-06-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22971	delivery	5	23
86851	2020-06-28 17:48:54	2020-06-28	12	[{"id_menu":1,"count":1}]	20879	pick-up	0	12
86852	2020-06-28 17:55:13	2020-06-28	8	[{"id_menu":5,"count":1}]	6876	delivery	5	13
86853	2020-06-28 17:55:46	2020-06-28	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1293	delivery	5	44
86854	2020-06-28 17:55:55	2020-06-28	9	[{"id_menu":6,"count":1}]	3048	pick-up	0	9
86855	2020-06-28 17:56:30	2020-06-28	9	[{"id_menu":7,"count":1}]	33911	pick-up	0	9
86856	2020-06-28 17:58:51	2020-06-28	8	[{"id_menu":5,"count":1}]	16369	delivery	5	13
86857	2020-06-28 17:59:33	2020-06-28	17	[{"id_menu":4,"count":1}]	9989	pick-up	0	17
86858	2020-06-28 18:00:24	2020-06-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	15113	delivery	5	28
86859	2020-06-28 18:00:27	2020-06-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24659	delivery	5	22
86860	2020-06-28 18:01:22	2020-06-28	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	24061	delivery	5	42
86861	2020-06-28 18:01:34	2020-06-28	8	[{"id_menu":5,"count":1}]	33868	delivery	5	13
86862	2020-06-28 18:03:13	2020-06-28	17	[{"id_menu":4,"count":1}]	27113	delivery	5	22
86863	2020-06-28 18:04:37	2020-06-28	9	[{"id_menu":6,"count":1}]	16059	delivery	5	14
86864	2020-06-28 18:04:50	2020-06-28	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31181	delivery	5	34
86865	2020-06-28 18:07:03	2020-06-28	14	[{"id_menu":2,"count":1}]	12031	pick-up	0	14
86866	2020-06-28 18:07:49	2020-06-28	14	[{"id_menu":2,"count":1}]	623	delivery	5	19
86867	2020-06-28 18:08:28	2020-06-28	14	[{"id_menu":2,"count":1}]	28633	delivery	5	19
86868	2020-06-28 18:11:51	2020-06-28	14	[{"id_menu":2,"count":1}]	33795	delivery	5	19
86869	2020-06-28 18:14:09	2020-06-28	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	33830	delivery	5	30
86870	2020-06-28 18:15:18	2020-06-28	9	[{"id_menu":6,"count":1}]	29263	delivery	5	14
86871	2020-06-28 18:15:38	2020-06-28	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	8716	pick-up	0	21
86872	2020-06-28 18:15:59	2020-06-28	9	[{"id_menu":6,"count":1}]	33848	delivery	5	14
86873	2020-06-28 18:17:12	2020-06-28	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	33948	pick-up	0	35
86874	2020-06-28 18:19:23	2020-06-28	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	33858	delivery	5	42
86875	2020-06-28 18:19:34	2020-06-28	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17980	delivery	5	36
86876	2020-06-28 18:22:53	2020-06-28	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3604	delivery	5	31
86877	2020-06-28 18:23:05	2020-06-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	33810	delivery	5	31
86878	2020-06-28 18:23:54	2020-06-28	9	[{"id_menu":6,"count":1}]	26078	delivery	5	14
86879	2020-06-28 18:25:54	2020-06-28	17	[{"id_menu":4,"count":1}]	33943	delivery	5	22
86880	2020-06-28 18:26:41	2020-06-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2585	pick-up	0	18
86881	2020-06-28 18:29:55	2020-06-28	9	[{"id_menu":6,"count":1}]	23461	pick-up	0	9
86882	2020-06-28 18:31:49	2020-06-28	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	8177	delivery	5	26
86883	2020-06-28 18:32:51	2020-06-28	9	[{"id_menu":6,"count":1}]	33908	delivery	5	14
86884	2020-06-28 18:35:39	2020-06-28	12	[{"id_menu":3,"count":1}]	25276	pick-up	0	12
86885	2020-06-28 18:35:40	2020-06-28	14	[{"id_menu":2,"count":1}]	892	delivery	5	19
86886	2020-06-28 18:38:11	2020-06-28	8	[{"id_menu":5,"count":1}]	12020	delivery	5	13
86887	2020-06-28 18:41:28	2020-06-28	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	33799	delivery	5	29
86888	2020-06-28 18:48:37	2020-06-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20815	delivery	5	22
86889	2020-06-28 18:50:01	2020-06-28	12	[{"id_menu":3,"count":1}]	33745	delivery	5	17
86890	2020-06-28 18:51:03	2020-06-28	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	21387	pick-up	0	23
86891	2020-06-28 18:51:16	2020-06-28	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	13253	pick-up	0	21
86892	2020-06-28 18:51:19	2020-06-28	14	[{"id_menu":2,"count":2}]	11434	delivery	5	19
86893	2020-06-28 18:54:39	2020-06-28	12	[{"id_menu":1,"count":1}]	33078	delivery	5	17
86894	2020-06-28 18:57:07	2020-06-28	9	[{"id_menu":6,"count":1}]	33787	delivery	5	14
86895	2020-06-28 18:57:37	2020-06-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	24945	delivery	5	22
86896	2020-06-28 18:58:37	2020-06-28	14	[{"id_menu":2,"count":1}]	33384	delivery	5	19
86897	2020-06-28 18:58:59	2020-06-28	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	10751	delivery	5	35
86898	2020-06-28 18:59:51	2020-06-28	8	[{"id_menu":5,"count":1}]	19510	delivery	5	13
86899	2020-06-28 19:01:22	2020-06-28	8	[{"id_menu":5,"count":1}]	33762	delivery	5	13
86900	2020-06-28 19:02:00	2020-06-28	9	[{"id_menu":6,"count":1}]	33746	delivery	5	14
86901	2020-06-28 19:02:27	2020-06-28	14	[{"id_menu":2,"count":1}]	16692	delivery	5	19
86902	2020-06-28 19:05:13	2020-06-28	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	33804	delivery	5	42
86903	2020-06-28 19:06:52	2020-06-28	17	[{"id_menu":4,"count":1}]	5760	pick-up	0	17
86904	2020-06-28 19:10:43	2020-06-28	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	33950	delivery	5	36
86905	2020-06-28 19:13:33	2020-06-28	9	[{"id_menu":6,"count":1}]	4227	delivery	5	14
86906	2020-06-28 19:13:43	2020-06-28	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	16342	pick-up	0	26
86907	2020-06-28 19:15:14	2020-06-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":3}]	33778	delivery	5	23
86908	2020-06-28 19:16:50	2020-06-28	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33905	delivery	5	48
86909	2020-06-28 19:17:50	2020-06-28	17	[{"id_menu":4,"count":1}]	58	pick-up	0	17
86910	2020-06-28 19:20:04	2020-06-28	14	[{"id_menu":2,"count":1}]	33940	delivery	5	19
86911	2020-06-28 19:25:46	2020-06-28	9	[{"id_menu":6,"count":1}]	9729	delivery	5	14
86912	2020-06-28 19:28:06	2020-06-28	49	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	33771	delivery	5	54
86913	2020-06-28 19:28:35	2020-06-28	9	[{"id_menu":6,"count":1}]	33786	delivery	5	14
86914	2020-06-28 19:30:19	2020-06-28	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	32631	delivery	5	25
86915	2020-06-28 19:32:23	2020-06-28	8	[{"id_menu":5,"count":1}]	24282	delivery	5	13
86916	2020-06-28 19:32:46	2020-06-28	17	[{"id_menu":4,"count":1}]	31467	delivery	5	22
86917	2020-06-28 19:33:29	2020-06-28	8	[{"id_menu":5,"count":1}]	14028	delivery	5	13
86918	2020-06-28 19:36:02	2020-06-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	15183	delivery	5	28
86919	2020-06-28 19:36:37	2020-06-28	9	[{"id_menu":7,"count":1}]	27782	delivery	5	14
86920	2020-06-28 19:38:09	2020-06-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10832	delivery	5	31
86921	2020-06-28 19:39:12	2020-06-28	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	3628	pick-up	0	24
86922	2020-06-28 19:39:44	2020-06-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3277	delivery	5	31
86923	2020-06-28 19:41:03	2020-06-28	17	[{"id_menu":4,"count":1}]	8057	pick-up	0	17
86924	2020-06-28 19:42:39	2020-06-28	9	[{"id_menu":7,"count":1}]	33903	delivery	5	14
86925	2020-06-28 19:48:41	2020-06-28	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	33954	delivery	5	40
86926	2020-06-28 19:48:41	2020-06-28	9	[{"id_menu":7,"count":1}]	31013	delivery	5	14
86927	2020-06-28 19:53:33	2020-06-28	12	[{"id_menu":3,"count":1}]	22109	delivery	5	17
86928	2020-06-28 19:54:58	2020-06-28	9	[{"id_menu":6,"count":1}]	33790	delivery	5	14
86929	2020-06-28 19:56:27	2020-06-28	9	[{"id_menu":6,"count":1}]	33914	delivery	5	14
86930	2020-06-28 19:57:32	2020-06-28	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	33818	pick-up	0	29
86931	2020-06-28 19:57:42	2020-06-28	14	[{"id_menu":2,"count":2}]	10526	delivery	5	19
86932	2020-06-28 19:57:45	2020-06-28	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	23571	delivery	5	26
86933	2020-06-28 20:00:24	2020-06-28	9	[{"id_menu":7,"count":1}]	18716	delivery	5	14
86934	2020-06-28 20:01:55	2020-06-28	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	585	delivery	5	42
86935	2020-06-28 20:02:27	2020-06-28	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	33825	delivery	5	26
86936	2020-06-28 20:03:06	2020-06-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	33797	delivery	5	22
86937	2020-06-28 20:05:55	2020-06-28	9	[{"id_menu":7,"count":1}]	748	delivery	5	14
86938	2020-06-28 20:06:17	2020-06-28	12	[{"id_menu":3,"count":1}]	16110	pick-up	0	12
86939	2020-06-28 20:08:38	2020-06-28	17	[{"id_menu":4,"count":1}]	8211	delivery	5	22
86940	2020-06-28 20:08:45	2020-06-28	14	[{"id_menu":2,"count":1}]	6430	delivery	5	19
86941	2020-06-28 20:09:25	2020-06-28	14	[{"id_menu":2,"count":1}]	33863	delivery	5	19
86942	2020-06-28 20:11:46	2020-06-28	14	[{"id_menu":2,"count":1}]	550	delivery	5	19
86943	2020-06-28 20:22:41	2020-06-28	12	[{"id_menu":3,"count":1}]	28056	pick-up	0	12
86944	2020-06-28 20:24:59	2020-06-28	9	[{"id_menu":7,"count":2}]	1649	pick-up	0	9
86945	2020-06-28 20:28:08	2020-06-28	17	[{"id_menu":4,"count":1}]	9348	delivery	5	22
86946	2020-06-28 20:29:16	2020-06-28	14	[{"id_menu":2,"count":1}]	24192	pick-up	0	14
86947	2020-06-28 20:31:19	2020-06-28	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7264	delivery	5	42
86948	2020-06-28 20:32:16	2020-06-28	9	[{"id_menu":7,"count":1}]	11755	delivery	5	14
86949	2020-06-28 20:35:39	2020-06-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1781	pick-up	0	23
86950	2020-06-28 20:41:02	2020-06-28	12	[{"id_menu":3,"count":1}]	33826	delivery	5	17
86951	2020-06-28 20:41:32	2020-06-28	9	[{"id_menu":6,"count":1}]	33834	delivery	5	14
86952	2020-06-28 20:48:17	2020-06-28	9	[{"id_menu":6,"count":1}]	33739	delivery	5	14
86953	2020-06-28 20:48:52	2020-06-28	12	[{"id_menu":1,"count":1}]	285	pick-up	0	12
86954	2020-06-28 20:50:51	2020-06-28	17	[{"id_menu":4,"count":1}]	33873	delivery	5	22
86955	2020-06-28 20:50:52	2020-06-28	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	28736	delivery	5	30
86956	2020-06-28 20:54:35	2020-06-28	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	33956	delivery	5	45
86957	2020-06-28 20:55:54	2020-06-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4453	pick-up	0	26
86958	2020-06-28 20:56:21	2020-06-28	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14475	delivery	5	40
86959	2020-06-28 20:56:40	2020-06-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	471	delivery	5	31
86960	2020-06-28 20:57:45	2020-06-28	9	[{"id_menu":7,"count":1}]	21029	pick-up	0	9
86961	2020-06-28 20:59:57	2020-06-28	9	[{"id_menu":7,"count":1}]	33444	delivery	5	14
86962	2020-06-28 21:00:18	2020-06-28	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	33899	delivery	5	26
86963	2020-06-28 21:04:26	2020-06-28	12	[{"id_menu":3,"count":1}]	5972	delivery	5	17
86964	2020-06-28 21:05:42	2020-06-28	8	[{"id_menu":5,"count":1}]	31653	delivery	5	13
86965	2020-06-28 21:06:24	2020-06-28	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7455	delivery	5	30
86966	2020-06-28 21:07:42	2020-06-28	14	[{"id_menu":2,"count":1}]	33931	delivery	5	19
86967	2020-06-28 21:09:34	2020-06-28	12	[{"id_menu":1,"count":1}]	33851	delivery	5	17
86968	2020-06-28 21:09:44	2020-06-28	17	[{"id_menu":4,"count":1}]	11464	delivery	5	22
86969	2020-06-28 21:09:53	2020-06-28	9	[{"id_menu":6,"count":1}]	23143	delivery	5	14
86970	2020-06-28 21:16:49	2020-06-28	9	[{"id_menu":7,"count":1}]	33773	delivery	5	14
86971	2020-06-28 21:17:32	2020-06-28	8	[{"id_menu":5,"count":1}]	2377	pick-up	0	8
86972	2020-06-28 21:18:38	2020-06-28	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	33776	delivery	5	22
86973	2020-06-28 21:20:21	2020-06-28	12	[{"id_menu":1,"count":1}]	14954	delivery	5	17
86974	2020-06-28 21:21:07	2020-06-28	12	[{"id_menu":1,"count":1}]	27308	delivery	5	17
86975	2020-06-28 21:24:25	2020-06-28	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	33798	pick-up	0	25
86976	2020-06-28 21:28:44	2020-06-28	9	[{"id_menu":7,"count":1}]	20495	delivery	5	14
86977	2020-06-28 21:31:01	2020-06-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9324	delivery	5	28
86978	2020-06-28 21:33:17	2020-06-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4177	delivery	5	31
86979	2020-06-28 21:33:46	2020-06-28	9	[{"id_menu":7,"count":1}]	2123	pick-up	0	9
86980	2020-06-28 21:37:40	2020-06-28	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	33875	delivery	5	22
86981	2020-06-28 21:41:49	2020-06-28	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	996	pick-up	0	31
86982	2020-06-28 21:45:19	2020-06-28	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	31117	delivery	5	31
86983	2020-06-28 21:47:50	2020-06-28	12	[{"id_menu":3,"count":2}]	3220	delivery	5	17
86984	2020-06-28 21:47:51	2020-06-28	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	18932	pick-up	0	21
86985	2020-06-28 21:50:05	2020-06-28	9	[{"id_menu":7,"count":3}]	10043	delivery	5	14
86986	2020-06-28 21:52:56	2020-06-28	17	[{"id_menu":4,"count":1}]	33897	delivery	5	22
86987	2020-06-28 21:53:53	2020-06-28	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2310	pick-up	0	29
86988	2020-06-28 21:54:38	2020-06-28	9	[{"id_menu":6,"count":1}]	33929	delivery	5	14
86989	2020-06-28 21:56:51	2020-06-28	9	[{"id_menu":6,"count":1}]	5935	delivery	5	14
86990	2020-06-28 21:57:15	2020-06-28	8	[{"id_menu":5,"count":1}]	18976	delivery	5	13
86991	2020-06-28 21:57:57	2020-06-28	9	[{"id_menu":6,"count":1}]	29198	delivery	5	14
86992	2020-06-28 21:59:53	2020-06-28	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	22784	pick-up	0	37
86993	2020-06-28 22:00:27	2020-06-28	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	22749	delivery	5	26
86994	2020-06-28 22:01:02	2020-06-28	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	10812	delivery	5	28
86995	2020-06-28 22:03:32	2020-06-28	17	[{"id_menu":4,"count":1}]	8303	delivery	5	22
86996	2020-06-28 22:05:17	2020-06-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29877	delivery	5	23
86997	2020-06-28 22:07:23	2020-06-28	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	22237	delivery	5	36
86998	2020-06-28 22:09:34	2020-06-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	17876	delivery	5	28
86999	2020-06-28 22:12:42	2020-06-28	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18893	delivery	5	36
87000	2020-06-28 22:17:57	2020-06-28	9	[{"id_menu":6,"count":1}]	33924	delivery	5	14
87001	2020-06-28 22:18:36	2020-06-28	8	[{"id_menu":5,"count":1}]	18525	pick-up	0	8
87002	2020-06-28 22:20:49	2020-06-28	9	[{"id_menu":6,"count":1}]	27778	delivery	5	14
87003	2020-06-28 22:22:06	2020-06-28	12	[{"id_menu":1,"count":1}]	18616	delivery	5	17
87004	2020-06-28 22:22:38	2020-06-28	14	[{"id_menu":2,"count":1}]	33882	delivery	5	19
87005	2020-06-28 22:24:27	2020-06-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22324	delivery	5	23
87006	2020-06-28 22:24:55	2020-06-28	12	[{"id_menu":1,"count":1}]	22753	delivery	5	17
87007	2020-06-28 22:25:57	2020-06-28	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	33902	delivery	5	51
87008	2020-06-28 22:26:31	2020-06-28	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	33836	delivery	5	36
87009	2020-06-28 22:28:48	2020-06-28	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	8834	delivery	5	31
87010	2020-06-28 22:29:52	2020-06-28	8	[{"id_menu":5,"count":1}]	16883	pick-up	0	8
87011	2020-06-28 22:31:08	2020-06-28	14	[{"id_menu":2,"count":1}]	29623	delivery	5	19
87012	2020-06-28 22:31:09	2020-06-28	9	[{"id_menu":7,"count":1}]	18936	delivery	5	14
87013	2020-06-28 22:31:11	2020-06-28	9	[{"id_menu":6,"count":1}]	33879	delivery	5	14
87014	2020-06-28 22:32:12	2020-06-28	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	8398	delivery	5	27
87015	2020-06-28 22:37:06	2020-06-28	12	[{"id_menu":3,"count":1}]	9569	delivery	5	17
87016	2020-06-28 22:37:43	2020-06-28	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	17527	delivery	5	26
87017	2020-06-28 22:37:50	2020-06-28	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	10744	delivery	5	35
87018	2020-06-28 22:40:20	2020-06-28	12	[{"id_menu":1,"count":1}]	14710	pick-up	0	12
87019	2020-06-28 22:42:23	2020-06-28	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	14258	pick-up	0	29
87020	2020-06-28 22:44:05	2020-06-28	9	[{"id_menu":7,"count":1}]	4200	delivery	5	14
87021	2020-06-28 22:49:42	2020-06-28	12	[{"id_menu":1,"count":1}]	33862	delivery	5	17
87022	2020-06-28 22:52:40	2020-06-28	9	[{"id_menu":7,"count":2}]	8743	delivery	5	14
87023	2020-06-28 22:52:41	2020-06-28	9	[{"id_menu":7,"count":2}]	29635	delivery	5	14
87024	2020-06-28 22:55:27	2020-06-28	14	[{"id_menu":2,"count":1}]	19978	delivery	5	19
87025	2020-06-28 22:56:54	2020-06-28	9	[{"id_menu":6,"count":1}]	26145	delivery	5	14
87026	2020-06-28 23:01:00	2020-06-28	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31183	delivery	5	53
87027	2020-06-28 23:02:22	2020-06-28	9	[{"id_menu":6,"count":1}]	33781	delivery	5	14
87028	2020-06-28 23:04:25	2020-06-28	14	[{"id_menu":2,"count":1}]	33767	delivery	5	19
87029	2020-06-28 23:10:29	2020-06-28	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	3780	pick-up	0	21
87030	2020-06-28 23:11:15	2020-06-28	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	32774	delivery	5	44
87031	2020-06-28 23:12:38	2020-06-28	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29052	delivery	5	40
87032	2020-06-28 23:12:58	2020-06-28	9	[{"id_menu":6,"count":1}]	5717	delivery	5	14
87033	2020-06-28 23:13:52	2020-06-28	17	[{"id_menu":4,"count":1}]	4804	delivery	5	22
87034	2020-06-28 23:15:05	2020-06-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6080	delivery	5	31
87035	2020-06-28 23:16:20	2020-06-28	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	9737	delivery	5	26
87036	2020-06-28 23:18:48	2020-06-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	29017	delivery	5	31
87037	2020-06-28 23:20:00	2020-06-28	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	32381	delivery	5	45
87038	2020-06-28 23:22:27	2020-06-28	12	[{"id_menu":1,"count":1}]	32985	delivery	5	17
87039	2020-06-28 23:24:48	2020-06-28	12	[{"id_menu":1,"count":1}]	20770	delivery	5	17
87040	2020-06-28 23:27:02	2020-06-28	9	[{"id_menu":6,"count":1}]	33896	delivery	5	14
87041	2020-06-28 23:27:34	2020-06-28	17	[{"id_menu":4,"count":1}]	19911	pick-up	0	17
87042	2020-06-28 23:33:22	2020-06-28	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	15422	delivery	5	40
87043	2020-06-28 23:38:15	2020-06-28	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	33910	pick-up	0	52
87044	2020-06-28 23:38:49	2020-06-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17067	delivery	5	22
87045	2020-06-28 23:41:30	2020-06-28	14	[{"id_menu":2,"count":1}]	28148	delivery	5	19
87046	2020-06-28 23:43:24	2020-06-28	9	[{"id_menu":6,"count":1}]	14532	delivery	5	14
87047	2020-06-28 23:43:56	2020-06-28	9	[{"id_menu":7,"count":1}]	23812	delivery	5	14
87048	2020-06-28 23:44:05	2020-06-28	9	[{"id_menu":6,"count":1}]	33758	pick-up	0	9
87049	2020-06-28 23:45:20	2020-06-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	29956	delivery	5	23
87050	2020-06-28 23:47:08	2020-06-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11051	delivery	5	23
87051	2020-06-28 23:51:59	2020-06-28	17	[{"id_menu":4,"count":1}]	28720	delivery	5	22
87052	2020-06-28 23:55:37	2020-06-28	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	33855	delivery	5	44
87053	2020-06-28 23:55:59	2020-06-28	17	[{"id_menu":4,"count":1}]	32838	delivery	5	22
87054	2020-06-28 23:56:12	2020-06-28	9	[{"id_menu":7,"count":1}]	24100	delivery	5	14
87055	2020-06-29 00:06:51	2020-06-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	34127	delivery	5	27
87056	2020-06-29 00:14:24	2020-06-29	17	[{"id_menu":4,"count":1}]	20806	pick-up	0	17
87057	2020-06-29 00:23:28	2020-06-29	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	12539	delivery	5	42
87058	2020-06-29 00:25:33	2020-06-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	20289	delivery	5	22
87059	2020-06-29 00:28:59	2020-06-29	9	[{"id_menu":6,"count":3}]	34133	pick-up	0	9
87060	2020-06-29 00:33:04	2020-06-29	8	[{"id_menu":5,"count":1}]	34068	delivery	5	13
87061	2020-06-29 00:44:59	2020-06-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	33964	pick-up	0	26
87062	2020-06-29 00:51:33	2020-06-29	9	[{"id_menu":7,"count":1}]	34172	delivery	5	14
87063	2020-06-29 00:52:04	2020-06-29	26	[{"id_menu":2,"count":3},{"id_menu":3,"count":1}]	27488	pick-up	0	26
87064	2020-06-29 00:56:45	2020-06-29	14	[{"id_menu":2,"count":1}]	15372	delivery	5	19
87065	2020-06-29 01:00:07	2020-06-29	12	[{"id_menu":1,"count":1}]	34063	delivery	5	17
87066	2020-06-29 01:06:53	2020-06-29	9	[{"id_menu":7,"count":1}]	1855	pick-up	0	9
87067	2020-06-29 01:08:05	2020-06-29	8	[{"id_menu":5,"count":1}]	34179	delivery	5	13
87068	2020-06-29 01:12:47	2020-06-29	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	34091	pick-up	0	39
87069	2020-06-29 01:15:11	2020-06-29	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	26810	delivery	5	38
87070	2020-06-29 01:18:31	2020-06-29	8	[{"id_menu":5,"count":1}]	5707	delivery	5	13
87071	2020-06-29 01:18:46	2020-06-29	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	33390	delivery	5	26
87072	2020-06-29 01:23:14	2020-06-29	9	[{"id_menu":6,"count":1}]	20034	delivery	5	14
87073	2020-06-29 01:24:35	2020-06-29	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	19488	delivery	5	40
87074	2020-06-29 01:25:27	2020-06-29	9	[{"id_menu":7,"count":1}]	1239	delivery	5	14
87075	2020-06-29 01:27:42	2020-06-29	9	[{"id_menu":7,"count":1}]	31147	delivery	5	14
87076	2020-06-29 01:28:38	2020-06-29	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	11680	delivery	5	48
87077	2020-06-29 01:32:01	2020-06-29	8	[{"id_menu":5,"count":1}]	33989	delivery	5	13
87078	2020-06-29 01:34:22	2020-06-29	14	[{"id_menu":2,"count":1}]	10434	delivery	5	19
87079	2020-06-29 01:37:34	2020-06-29	9	[{"id_menu":7,"count":1}]	27790	delivery	5	14
87080	2020-06-29 01:44:14	2020-06-29	9	[{"id_menu":7,"count":1}]	27572	delivery	5	14
87081	2020-06-29 01:46:36	2020-06-29	9	[{"id_menu":7,"count":1}]	27545	delivery	5	14
87082	2020-06-29 01:52:16	2020-06-29	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	15225	delivery	5	25
87083	2020-06-29 01:54:22	2020-06-29	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	34119	delivery	5	34
87084	2020-06-29 01:58:01	2020-06-29	9	[{"id_menu":7,"count":1}]	6835	delivery	5	14
87085	2020-06-29 01:59:27	2020-06-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":3}]	34163	delivery	5	26
87086	2020-06-29 02:13:42	2020-06-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2173	pick-up	0	23
87087	2020-06-29 02:14:19	2020-06-29	14	[{"id_menu":2,"count":1}]	33991	delivery	5	19
87088	2020-06-29 02:17:06	2020-06-29	14	[{"id_menu":2,"count":1}]	33976	pick-up	0	14
87089	2020-06-29 02:17:11	2020-06-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	33970	delivery	5	22
87090	2020-06-29 02:19:43	2020-06-29	9	[{"id_menu":6,"count":1}]	30867	delivery	5	14
87091	2020-06-29 02:20:20	2020-06-29	9	[{"id_menu":6,"count":1}]	34041	delivery	5	14
87092	2020-06-29 02:25:15	2020-06-29	12	[{"id_menu":3,"count":1}]	33971	delivery	5	17
87093	2020-06-29 02:27:25	2020-06-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	22227	pick-up	0	23
87094	2020-06-29 02:28:22	2020-06-29	9	[{"id_menu":6,"count":1}]	2373	pick-up	0	9
87095	2020-06-29 02:31:43	2020-06-29	9	[{"id_menu":6,"count":1}]	28928	delivery	5	14
87096	2020-06-29 02:32:28	2020-06-29	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30507	delivery	5	31
87097	2020-06-29 02:34:14	2020-06-29	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15092	delivery	5	40
87098	2020-06-29 02:35:58	2020-06-29	9	[{"id_menu":7,"count":1}]	33438	delivery	5	14
87099	2020-06-29 02:52:50	2020-06-29	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	15488	delivery	5	39
87100	2020-06-29 02:57:17	2020-06-29	12	[{"id_menu":1,"count":1}]	17914	pick-up	0	12
87101	2020-06-29 02:58:14	2020-06-29	17	[{"id_menu":4,"count":1}]	33997	delivery	5	22
87102	2020-06-29 02:58:31	2020-06-29	17	[{"id_menu":4,"count":1}]	6176	pick-up	0	17
87103	2020-06-29 03:01:50	2020-06-29	14	[{"id_menu":2,"count":1}]	3228	pick-up	0	14
87104	2020-06-29 03:05:53	2020-06-29	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	33218	delivery	5	30
87105	2020-06-29 03:07:36	2020-06-29	12	[{"id_menu":1,"count":2}]	33984	delivery	5	17
87106	2020-06-29 03:10:14	2020-06-29	8	[{"id_menu":5,"count":1}]	20549	pick-up	0	8
87107	2020-06-29 03:17:14	2020-06-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	30225	delivery	5	22
87108	2020-06-29 03:17:53	2020-06-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	204	delivery	5	28
87109	2020-06-29 03:18:15	2020-06-29	12	[{"id_menu":3,"count":1}]	26514	delivery	5	17
87110	2020-06-29 03:19:45	2020-06-29	14	[{"id_menu":2,"count":1}]	34075	delivery	5	19
87111	2020-06-29 03:20:10	2020-06-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	34167	delivery	5	22
87112	2020-06-29 03:31:07	2020-06-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	34131	delivery	5	22
87113	2020-06-29 03:34:33	2020-06-29	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	34174	delivery	5	40
87114	2020-06-29 03:39:44	2020-06-29	17	[{"id_menu":4,"count":1}]	9682	pick-up	0	17
87115	2020-06-29 03:46:37	2020-06-29	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	33996	delivery	5	46
87116	2020-06-29 03:47:58	2020-06-29	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25757	delivery	5	31
87117	2020-06-29 04:04:33	2020-06-29	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	6074	pick-up	0	26
87118	2020-06-29 04:06:58	2020-06-29	9	[{"id_menu":6,"count":1}]	721	pick-up	0	9
87119	2020-06-29 04:08:04	2020-06-29	12	[{"id_menu":3,"count":1}]	19394	delivery	5	17
87120	2020-06-29 04:08:43	2020-06-29	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	33975	delivery	5	22
87121	2020-06-29 04:09:45	2020-06-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34156	pick-up	0	18
87122	2020-06-29 04:25:50	2020-06-29	8	[{"id_menu":5,"count":1}]	4021	pick-up	0	8
87123	2020-06-29 04:28:42	2020-06-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17072	delivery	5	31
87124	2020-06-29 04:36:01	2020-06-29	9	[{"id_menu":7,"count":1}]	34153	delivery	5	14
87125	2020-06-29 04:42:59	2020-06-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	33792	delivery	5	22
87126	2020-06-29 04:43:37	2020-06-29	9	[{"id_menu":7,"count":1}]	18392	delivery	5	14
87127	2020-06-29 04:46:12	2020-06-29	12	[{"id_menu":1,"count":2}]	34066	delivery	5	17
87128	2020-06-29 04:46:43	2020-06-29	9	[{"id_menu":7,"count":1}]	8192	pick-up	0	9
87129	2020-06-29 04:51:15	2020-06-29	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	34171	delivery	5	36
87130	2020-06-29 04:52:42	2020-06-29	8	[{"id_menu":5,"count":1}]	13193	pick-up	0	8
87131	2020-06-29 04:57:00	2020-06-29	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	21703	delivery	5	31
87132	2020-06-29 04:58:37	2020-06-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12772	delivery	5	36
87133	2020-06-29 04:59:32	2020-06-29	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4699	delivery	5	48
87134	2020-06-29 05:04:11	2020-06-29	8	[{"id_menu":5,"count":1}]	34141	delivery	5	13
87135	2020-06-29 05:08:09	2020-06-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31905	delivery	5	23
87136	2020-06-29 05:10:42	2020-06-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	25984	delivery	5	27
87137	2020-06-29 05:12:29	2020-06-29	17	[{"id_menu":4,"count":1}]	20462	delivery	5	22
87138	2020-06-29 05:13:11	2020-06-29	8	[{"id_menu":5,"count":2}]	34013	delivery	5	13
87139	2020-06-29 05:25:57	2020-06-29	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	21701	delivery	5	38
87140	2020-06-29 05:28:59	2020-06-29	14	[{"id_menu":2,"count":1}]	26445	pick-up	0	14
87141	2020-06-29 05:32:45	2020-06-29	9	[{"id_menu":7,"count":1}]	28712	pick-up	0	9
87142	2020-06-29 05:34:01	2020-06-29	9	[{"id_menu":6,"count":1}]	5930	delivery	5	14
87143	2020-06-29 05:35:20	2020-06-29	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	27002	delivery	5	40
87144	2020-06-29 05:35:53	2020-06-29	8	[{"id_menu":5,"count":1}]	4222	delivery	5	13
87145	2020-06-29 05:43:21	2020-06-29	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	30891	delivery	5	26
87146	2020-06-29 05:47:16	2020-06-29	9	[{"id_menu":7,"count":1}]	29555	delivery	5	14
87147	2020-06-29 05:49:02	2020-06-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	26028	delivery	5	28
87148	2020-06-29 05:49:06	2020-06-29	14	[{"id_menu":2,"count":1}]	4218	delivery	5	19
87149	2020-06-29 05:49:40	2020-06-29	9	[{"id_menu":7,"count":1}]	4206	delivery	5	14
87150	2020-06-29 06:02:32	2020-06-29	9	[{"id_menu":6,"count":1}]	34067	delivery	5	14
87151	2020-06-29 06:02:38	2020-06-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	23285	pick-up	0	26
87152	2020-06-29 06:10:19	2020-06-29	9	[{"id_menu":7,"count":1}]	34087	delivery	5	14
87153	2020-06-29 06:12:25	2020-06-29	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	34101	delivery	5	51
87154	2020-06-29 06:14:27	2020-06-29	14	[{"id_menu":2,"count":1}]	29358	delivery	5	19
87155	2020-06-29 06:17:06	2020-06-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	11465	pick-up	0	23
87156	2020-06-29 06:23:55	2020-06-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	33987	delivery	5	22
87157	2020-06-29 06:24:43	2020-06-29	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	10127	delivery	5	25
87158	2020-06-29 06:26:14	2020-06-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	29223	delivery	5	31
87159	2020-06-29 06:27:12	2020-06-29	9	[{"id_menu":7,"count":3}]	16712	delivery	5	14
87160	2020-06-29 06:27:58	2020-06-29	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8795	delivery	5	34
87161	2020-06-29 06:38:45	2020-06-29	14	[{"id_menu":2,"count":1}]	29476	delivery	5	19
87162	2020-06-29 06:39:03	2020-06-29	9	[{"id_menu":6,"count":1}]	29645	pick-up	0	9
87163	2020-06-29 06:46:54	2020-06-29	8	[{"id_menu":5,"count":1}]	34110	delivery	5	13
87164	2020-06-29 06:52:01	2020-06-29	17	[{"id_menu":4,"count":1}]	5355	pick-up	0	17
87165	2020-06-29 06:53:17	2020-06-29	9	[{"id_menu":6,"count":1}]	19277	pick-up	0	9
87166	2020-06-29 06:53:29	2020-06-29	14	[{"id_menu":2,"count":2}]	34037	delivery	5	19
87167	2020-06-29 06:55:01	2020-06-29	9	[{"id_menu":7,"count":1}]	5240	pick-up	0	9
87168	2020-06-29 06:56:54	2020-06-29	9	[{"id_menu":7,"count":1}]	21751	delivery	5	14
87169	2020-06-29 06:59:32	2020-06-29	8	[{"id_menu":5,"count":1}]	24125	delivery	5	13
87170	2020-06-29 07:06:06	2020-06-29	9	[{"id_menu":6,"count":2}]	32131	delivery	5	14
87171	2020-06-29 07:12:06	2020-06-29	9	[{"id_menu":7,"count":1}]	16088	delivery	5	14
87172	2020-06-29 07:17:28	2020-06-29	12	[{"id_menu":3,"count":1}]	2425	pick-up	0	12
87173	2020-06-29 07:23:41	2020-06-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	519	pick-up	0	26
87174	2020-06-29 07:26:42	2020-06-29	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	29258	delivery	5	53
87175	2020-06-29 07:27:07	2020-06-29	14	[{"id_menu":2,"count":1}]	34072	delivery	5	19
87176	2020-06-29 07:29:46	2020-06-29	12	[{"id_menu":1,"count":1}]	27348	delivery	5	17
87177	2020-06-29 07:31:17	2020-06-29	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	34008	delivery	5	53
87178	2020-06-29 07:43:49	2020-06-29	14	[{"id_menu":2,"count":1}]	34028	pick-up	0	14
87179	2020-06-29 07:44:41	2020-06-29	9	[{"id_menu":7,"count":1}]	6326	delivery	5	14
87180	2020-06-29 07:52:17	2020-06-29	9	[{"id_menu":6,"count":1}]	34109	delivery	5	14
87181	2020-06-29 08:03:25	2020-06-29	9	[{"id_menu":7,"count":1}]	34116	delivery	5	14
87182	2020-06-29 08:06:30	2020-06-29	14	[{"id_menu":2,"count":1}]	12009	delivery	5	19
87183	2020-06-29 08:07:40	2020-06-29	17	[{"id_menu":4,"count":1}]	34011	pick-up	0	17
87184	2020-06-29 08:08:59	2020-06-29	12	[{"id_menu":3,"count":1}]	3172	pick-up	0	12
87185	2020-06-29 08:13:36	2020-06-29	12	[{"id_menu":1,"count":1}]	15319	delivery	5	17
87186	2020-06-29 08:15:11	2020-06-29	12	[{"id_menu":1,"count":1}]	23104	delivery	5	17
87187	2020-06-29 08:21:33	2020-06-29	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	28640	delivery	5	35
87188	2020-06-29 08:30:25	2020-06-29	17	[{"id_menu":4,"count":1}]	33994	delivery	5	22
87189	2020-06-29 08:32:43	2020-06-29	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	27619	pick-up	0	31
87190	2020-06-29 08:35:40	2020-06-29	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	23058	delivery	5	39
87191	2020-06-29 08:52:47	2020-06-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7934	delivery	5	31
87192	2020-06-29 08:54:30	2020-06-29	8	[{"id_menu":5,"count":1}]	812	delivery	5	13
87193	2020-06-29 09:06:45	2020-06-29	14	[{"id_menu":2,"count":1}]	7211	delivery	5	19
87194	2020-06-29 09:08:29	2020-06-29	9	[{"id_menu":6,"count":1}]	15284	delivery	5	14
87195	2020-06-29 09:16:39	2020-06-29	12	[{"id_menu":3,"count":1}]	13643	delivery	5	17
87196	2020-06-29 09:17:39	2020-06-29	9	[{"id_menu":7,"count":1}]	34079	delivery	5	14
87197	2020-06-29 09:25:57	2020-06-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	34032	pick-up	0	21
87198	2020-06-29 09:27:00	2020-06-29	12	[{"id_menu":3,"count":1}]	3532	pick-up	0	12
87199	2020-06-29 09:28:06	2020-06-29	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	21680	delivery	5	25
87200	2020-06-29 09:36:39	2020-06-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	19893	delivery	5	27
87201	2020-06-29 09:39:21	2020-06-29	17	[{"id_menu":4,"count":1}]	34027	delivery	5	22
87202	2020-06-29 09:44:58	2020-06-29	17	[{"id_menu":4,"count":1}]	23676	delivery	5	22
87203	2020-06-29 09:46:46	2020-06-29	12	[{"id_menu":1,"count":1}]	25676	delivery	5	17
87204	2020-06-29 09:49:34	2020-06-29	9	[{"id_menu":7,"count":1}]	34084	delivery	5	14
87205	2020-06-29 09:54:09	2020-06-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12132	delivery	5	36
87206	2020-06-29 09:55:34	2020-06-29	9	[{"id_menu":7,"count":1}]	3146	pick-up	0	9
87207	2020-06-29 09:57:54	2020-06-29	12	[{"id_menu":3,"count":1}]	10947	pick-up	0	12
87208	2020-06-29 10:02:47	2020-06-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31927	delivery	5	23
87209	2020-06-29 10:08:30	2020-06-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34166	delivery	5	23
87210	2020-06-29 10:09:09	2020-06-29	9	[{"id_menu":6,"count":1}]	33167	delivery	5	14
87211	2020-06-29 10:15:42	2020-06-29	17	[{"id_menu":4,"count":1}]	33879	delivery	5	22
87212	2020-06-29 10:16:29	2020-06-29	9	[{"id_menu":6,"count":1}]	13132	delivery	5	14
87213	2020-06-29 10:20:56	2020-06-29	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	34081	delivery	5	27
87214	2020-06-29 10:21:30	2020-06-29	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10989	pick-up	0	25
87215	2020-06-29 10:28:29	2020-06-29	14	[{"id_menu":2,"count":1}]	34080	delivery	5	19
87216	2020-06-29 10:30:30	2020-06-29	8	[{"id_menu":5,"count":1}]	34139	delivery	5	13
87217	2020-06-29 10:42:40	2020-06-29	9	[{"id_menu":6,"count":1}]	15906	delivery	5	14
87218	2020-06-29 10:43:50	2020-06-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	28482	delivery	5	26
87219	2020-06-29 10:51:09	2020-06-29	12	[{"id_menu":1,"count":1}]	34085	delivery	5	17
87220	2020-06-29 10:53:55	2020-06-29	9	[{"id_menu":6,"count":1}]	24423	delivery	5	14
87221	2020-06-29 10:56:00	2020-06-29	9	[{"id_menu":7,"count":1}]	26883	delivery	5	14
87222	2020-06-29 11:00:04	2020-06-29	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	34105	delivery	5	45
87223	2020-06-29 11:02:40	2020-06-29	17	[{"id_menu":4,"count":1}]	24407	delivery	5	22
87224	2020-06-29 11:04:07	2020-06-29	9	[{"id_menu":7,"count":1}]	9909	delivery	5	14
87225	2020-06-29 11:07:05	2020-06-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	26255	delivery	5	28
87226	2020-06-29 11:09:18	2020-06-29	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	33965	delivery	5	39
87227	2020-06-29 11:12:15	2020-06-29	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	34029	pick-up	0	20
87228	2020-06-29 11:21:29	2020-06-29	12	[{"id_menu":1,"count":1}]	401	pick-up	0	12
87229	2020-06-29 11:26:34	2020-06-29	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	4240	delivery	5	31
87230	2020-06-29 11:31:26	2020-06-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	29856	delivery	5	26
87231	2020-06-29 11:32:54	2020-06-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	33982	delivery	5	36
87232	2020-06-29 11:34:28	2020-06-29	17	[{"id_menu":4,"count":1}]	11940	pick-up	0	17
87233	2020-06-29 11:41:31	2020-06-29	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	34021	delivery	5	25
87234	2020-06-29 11:47:25	2020-06-29	17	[{"id_menu":4,"count":1}]	1278	pick-up	0	17
87235	2020-06-29 11:48:20	2020-06-29	12	[{"id_menu":1,"count":1}]	2320	pick-up	0	12
87236	2020-06-29 11:50:28	2020-06-29	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34122	delivery	5	40
87237	2020-06-29 11:51:33	2020-06-29	9	[{"id_menu":7,"count":1}]	8105	delivery	5	14
87238	2020-06-29 11:56:29	2020-06-29	9	[{"id_menu":7,"count":1}]	19207	delivery	5	14
87239	2020-06-29 11:57:51	2020-06-29	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	22916	delivery	5	45
87240	2020-06-29 12:03:13	2020-06-29	9	[{"id_menu":6,"count":1}]	34076	delivery	5	14
87241	2020-06-29 12:04:23	2020-06-29	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	15701	pick-up	0	21
87242	2020-06-29 12:06:37	2020-06-29	14	[{"id_menu":2,"count":1}]	24034	delivery	5	19
87243	2020-06-29 12:15:27	2020-06-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	34074	delivery	5	31
87244	2020-06-29 12:16:23	2020-06-29	8	[{"id_menu":5,"count":1}]	15297	delivery	5	13
87245	2020-06-29 12:18:11	2020-06-29	14	[{"id_menu":2,"count":1}]	13238	delivery	5	19
87246	2020-06-29 12:20:53	2020-06-29	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	29106	delivery	5	31
87247	2020-06-29 12:27:03	2020-06-29	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	24499	delivery	5	25
87248	2020-06-29 12:27:37	2020-06-29	14	[{"id_menu":2,"count":1}]	2217	pick-up	0	14
87249	2020-06-29 12:40:20	2020-06-29	9	[{"id_menu":6,"count":1}]	34049	delivery	5	14
87250	2020-06-29 12:40:55	2020-06-29	14	[{"id_menu":2,"count":1}]	25299	delivery	5	19
87251	2020-06-29 12:42:43	2020-06-29	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	29590	delivery	5	48
87252	2020-06-29 12:44:49	2020-06-29	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	11390	delivery	5	29
87253	2020-06-29 12:48:01	2020-06-29	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	34100	delivery	5	35
87254	2020-06-29 12:51:09	2020-06-29	9	[{"id_menu":6,"count":1}]	17999	delivery	5	14
87255	2020-06-29 13:02:48	2020-06-29	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	16264	pick-up	0	26
87256	2020-06-29 13:05:53	2020-06-29	9	[{"id_menu":6,"count":1}]	34018	delivery	5	14
87257	2020-06-29 13:06:00	2020-06-29	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	27649	delivery	5	25
87258	2020-06-29 13:08:22	2020-06-29	12	[{"id_menu":1,"count":1}]	34115	delivery	5	17
87259	2020-06-29 13:09:22	2020-06-29	12	[{"id_menu":1,"count":1}]	25982	delivery	5	17
87260	2020-06-29 13:09:36	2020-06-29	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	20852	delivery	5	40
87261	2020-06-29 13:15:28	2020-06-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5038	delivery	5	36
87262	2020-06-29 13:17:48	2020-06-29	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	34097	delivery	5	31
87263	2020-06-29 13:18:06	2020-06-29	17	[{"id_menu":4,"count":1}]	8774	pick-up	0	17
87264	2020-06-29 13:18:32	2020-06-29	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	34048	pick-up	0	25
87265	2020-06-29 13:19:17	2020-06-29	9	[{"id_menu":7,"count":1}]	34019	delivery	5	14
87266	2020-06-29 13:23:27	2020-06-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	34148	delivery	5	22
87267	2020-06-29 13:29:00	2020-06-29	17	[{"id_menu":4,"count":1}]	24041	pick-up	0	17
87268	2020-06-29 13:39:49	2020-06-29	9	[{"id_menu":7,"count":1}]	8726	delivery	5	14
87269	2020-06-29 13:41:33	2020-06-29	17	[{"id_menu":4,"count":1}]	33980	delivery	5	22
87270	2020-06-29 13:41:39	2020-06-29	9	[{"id_menu":6,"count":1}]	34140	pick-up	0	9
87271	2020-06-29 13:45:14	2020-06-29	12	[{"id_menu":1,"count":1}]	5520	pick-up	0	12
87272	2020-06-29 13:46:39	2020-06-29	49	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	33972	pick-up	0	49
87273	2020-06-29 14:04:23	2020-06-29	9	[{"id_menu":7,"count":1}]	34023	delivery	5	14
87274	2020-06-29 14:05:26	2020-06-29	12	[{"id_menu":1,"count":1}]	1101	pick-up	0	12
87275	2020-06-29 14:08:37	2020-06-29	9	[{"id_menu":6,"count":1}]	34015	delivery	5	14
87276	2020-06-29 14:09:25	2020-06-29	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	28431	pick-up	0	21
87277	2020-06-29 14:11:47	2020-06-29	12	[{"id_menu":1,"count":1}]	17096	delivery	5	17
87278	2020-06-29 14:12:03	2020-06-29	8	[{"id_menu":5,"count":1}]	30777	delivery	5	13
87279	2020-06-29 14:14:36	2020-06-29	9	[{"id_menu":7,"count":1}]	19143	delivery	5	14
87280	2020-06-29 14:14:50	2020-06-29	9	[{"id_menu":7,"count":1}]	2967	pick-up	0	9
87281	2020-06-29 14:28:12	2020-06-29	17	[{"id_menu":4,"count":1}]	15907	pick-up	0	17
87282	2020-06-29 14:29:15	2020-06-29	8	[{"id_menu":5,"count":1}]	12127	delivery	5	13
87283	2020-06-29 14:29:45	2020-06-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15320	delivery	5	36
87284	2020-06-29 14:34:39	2020-06-29	12	[{"id_menu":3,"count":1}]	33776	delivery	5	17
87285	2020-06-29 14:36:00	2020-06-29	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	25774	delivery	5	22
87286	2020-06-29 14:43:34	2020-06-29	12	[{"id_menu":3,"count":1}]	11363	delivery	5	17
87287	2020-06-29 14:48:47	2020-06-29	9	[{"id_menu":7,"count":1}]	13984	pick-up	0	9
87288	2020-06-29 14:49:24	2020-06-29	8	[{"id_menu":5,"count":1}]	15499	delivery	5	13
87289	2020-06-29 14:49:48	2020-06-29	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22527	delivery	5	47
87290	2020-06-29 14:56:48	2020-06-29	38	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17668	pick-up	0	38
87291	2020-06-29 14:57:27	2020-06-29	8	[{"id_menu":5,"count":1}]	31906	delivery	5	13
87292	2020-06-29 14:59:36	2020-06-29	8	[{"id_menu":5,"count":1}]	24414	delivery	5	13
87293	2020-06-29 15:01:03	2020-06-29	17	[{"id_menu":4,"count":1}]	89	pick-up	0	17
87294	2020-06-29 15:01:41	2020-06-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	31466	delivery	5	27
87295	2020-06-29 15:04:39	2020-06-29	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	25195	delivery	5	38
87296	2020-06-29 15:10:47	2020-06-29	14	[{"id_menu":2,"count":1}]	24703	delivery	5	19
87297	2020-06-29 15:21:49	2020-06-29	14	[{"id_menu":2,"count":1}]	28357	pick-up	0	14
87298	2020-06-29 15:29:29	2020-06-29	8	[{"id_menu":5,"count":2}]	31353	delivery	5	13
87299	2020-06-29 15:46:04	2020-06-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	17253	delivery	5	27
87300	2020-06-29 15:47:36	2020-06-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	41	pick-up	0	21
87301	2020-06-29 16:01:18	2020-06-29	9	[{"id_menu":6,"count":1}]	5952	delivery	5	14
87302	2020-06-29 16:02:13	2020-06-29	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	11001	pick-up	0	29
87303	2020-06-29 16:03:35	2020-06-29	14	[{"id_menu":2,"count":1}]	3160	pick-up	0	14
87304	2020-06-29 16:04:23	2020-06-29	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25102	delivery	5	49
87305	2020-06-29 16:13:24	2020-06-29	9	[{"id_menu":6,"count":1}]	27586	delivery	5	14
87306	2020-06-29 16:14:03	2020-06-29	9	[{"id_menu":6,"count":1}]	20109	delivery	5	14
87307	2020-06-29 16:16:15	2020-06-29	8	[{"id_menu":5,"count":1}]	34034	delivery	5	13
87308	2020-06-29 16:19:55	2020-06-29	12	[{"id_menu":3,"count":1}]	34082	delivery	5	17
87309	2020-06-29 16:27:10	2020-06-29	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	34007	delivery	5	31
87310	2020-06-29 16:28:53	2020-06-29	9	[{"id_menu":6,"count":1}]	21760	delivery	5	14
87311	2020-06-29 16:29:31	2020-06-29	9	[{"id_menu":6,"count":1}]	20365	delivery	5	14
87312	2020-06-29 16:35:43	2020-06-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	34003	delivery	5	28
87313	2020-06-29 16:36:02	2020-06-29	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	28263	delivery	5	25
87314	2020-06-29 16:38:10	2020-06-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	29906	delivery	5	28
87315	2020-06-29 16:38:38	2020-06-29	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	21021	delivery	5	36
87316	2020-06-29 16:38:59	2020-06-29	8	[{"id_menu":5,"count":1}]	12388	delivery	5	13
87317	2020-06-29 16:40:15	2020-06-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10596	delivery	5	22
87318	2020-06-29 16:46:20	2020-06-29	9	[{"id_menu":7,"count":1}]	17022	delivery	5	14
87319	2020-06-29 16:48:19	2020-06-29	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	18557	pick-up	0	33
87320	2020-06-29 16:48:59	2020-06-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15944	delivery	5	31
87321	2020-06-29 16:50:28	2020-06-29	9	[{"id_menu":7,"count":1}]	27959	delivery	5	14
87322	2020-06-29 16:53:07	2020-06-29	17	[{"id_menu":4,"count":1}]	23225	pick-up	0	17
87323	2020-06-29 16:54:08	2020-06-29	9	[{"id_menu":7,"count":1}]	20511	delivery	5	14
87324	2020-06-29 16:55:30	2020-06-29	21	[{"id_menu":1,"count":3},{"id_menu":6,"count":1}]	33969	delivery	5	26
87325	2020-06-29 16:56:30	2020-06-29	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	71	delivery	5	31
87326	2020-06-29 17:01:12	2020-06-29	9	[{"id_menu":7,"count":1}]	27474	delivery	5	14
87327	2020-06-29 17:05:26	2020-06-29	9	[{"id_menu":6,"count":1}]	17145	delivery	5	14
87328	2020-06-29 17:07:48	2020-06-29	12	[{"id_menu":3,"count":1}]	1834	pick-up	0	12
87329	2020-06-29 17:08:01	2020-06-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23296	delivery	5	22
87330	2020-06-29 17:30:30	2020-06-29	9	[{"id_menu":6,"count":1}]	33541	delivery	5	14
87331	2020-06-29 17:35:07	2020-06-29	14	[{"id_menu":2,"count":1}]	34161	delivery	5	19
87332	2020-06-29 17:37:15	2020-06-29	14	[{"id_menu":2,"count":1}]	19270	pick-up	0	14
87333	2020-06-29 17:38:14	2020-06-29	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	24449	delivery	5	26
87334	2020-06-29 17:39:43	2020-06-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	24849	delivery	5	31
87335	2020-06-29 17:44:27	2020-06-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	34014	delivery	5	23
87336	2020-06-29 17:45:42	2020-06-29	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20251	delivery	5	46
87337	2020-06-29 17:53:33	2020-06-29	9	[{"id_menu":6,"count":1}]	5643	delivery	5	14
87338	2020-06-29 17:59:59	2020-06-29	14	[{"id_menu":2,"count":1}]	34035	delivery	5	19
87339	2020-06-29 18:11:53	2020-06-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	34098	delivery	5	26
87340	2020-06-29 18:12:12	2020-06-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	34056	delivery	5	26
87341	2020-06-29 18:12:13	2020-06-29	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14211	delivery	5	31
87342	2020-06-29 18:12:27	2020-06-29	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	33947	delivery	5	29
87343	2020-06-29 18:24:48	2020-06-29	12	[{"id_menu":3,"count":1}]	23709	delivery	5	17
87344	2020-06-29 18:28:22	2020-06-29	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":2}]	16420	delivery	5	26
87345	2020-06-29 18:28:59	2020-06-29	9	[{"id_menu":6,"count":1}]	5479	delivery	5	14
87346	2020-06-29 18:34:24	2020-06-29	14	[{"id_menu":2,"count":1}]	34059	delivery	5	19
87347	2020-06-29 18:35:56	2020-06-29	12	[{"id_menu":1,"count":1}]	30704	pick-up	0	12
87348	2020-06-29 18:39:54	2020-06-29	9	[{"id_menu":7,"count":1}]	34052	pick-up	0	9
87349	2020-06-29 18:40:31	2020-06-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24638	delivery	5	36
87350	2020-06-29 18:43:26	2020-06-29	9	[{"id_menu":6,"count":1}]	6842	pick-up	0	9
87351	2020-06-29 18:45:11	2020-06-29	14	[{"id_menu":2,"count":1}]	351	delivery	5	19
87352	2020-06-29 18:45:36	2020-06-29	9	[{"id_menu":6,"count":1}]	33990	delivery	5	14
87353	2020-06-29 18:46:30	2020-06-29	30	[{"id_menu":1,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26737	delivery	5	35
87354	2020-06-29 18:47:15	2020-06-29	12	[{"id_menu":3,"count":1}]	22788	delivery	5	17
87355	2020-06-29 18:50:34	2020-06-29	8	[{"id_menu":5,"count":1}]	23061	delivery	5	13
87356	2020-06-29 19:01:11	2020-06-29	9	[{"id_menu":6,"count":1}]	34033	delivery	5	14
87357	2020-06-29 19:01:14	2020-06-29	9	[{"id_menu":6,"count":1}]	34136	delivery	5	14
87358	2020-06-29 19:03:19	2020-06-29	8	[{"id_menu":5,"count":1}]	7499	delivery	5	13
87359	2020-06-29 19:03:53	2020-06-29	12	[{"id_menu":1,"count":1}]	33963	delivery	5	17
87360	2020-06-29 19:09:38	2020-06-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1776	delivery	5	22
87361	2020-06-29 19:09:52	2020-06-29	9	[{"id_menu":7,"count":1}]	34155	delivery	5	14
87362	2020-06-29 19:15:36	2020-06-29	12	[{"id_menu":1,"count":1}]	2798	delivery	5	17
87363	2020-06-29 19:19:19	2020-06-29	12	[{"id_menu":3,"count":1}]	8380	delivery	5	17
87364	2020-06-29 19:36:27	2020-06-29	17	[{"id_menu":4,"count":1}]	7510	pick-up	0	17
87365	2020-06-29 19:37:50	2020-06-29	8	[{"id_menu":5,"count":1}]	1893	pick-up	0	8
87366	2020-06-29 19:42:33	2020-06-29	14	[{"id_menu":2,"count":1}]	34154	delivery	5	19
87367	2020-06-29 19:48:06	2020-06-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	34045	delivery	5	26
87368	2020-06-29 19:50:11	2020-06-29	9	[{"id_menu":6,"count":1}]	21515	pick-up	0	9
87369	2020-06-29 19:51:48	2020-06-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	34026	delivery	5	28
87370	2020-06-29 20:05:24	2020-06-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	3597	delivery	5	28
87371	2020-06-29 20:17:51	2020-06-29	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6429	delivery	5	51
87372	2020-06-29 20:20:37	2020-06-29	17	[{"id_menu":4,"count":1}]	2517	pick-up	0	17
87373	2020-06-29 20:23:10	2020-06-29	12	[{"id_menu":1,"count":1}]	8743	delivery	5	17
87374	2020-06-29 20:24:42	2020-06-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4912	delivery	5	22
87375	2020-06-29 20:30:03	2020-06-29	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	4570	delivery	5	26
87376	2020-06-29 20:33:25	2020-06-29	14	[{"id_menu":2,"count":1}]	34083	pick-up	0	14
87377	2020-06-29 20:33:46	2020-06-29	12	[{"id_menu":3,"count":1}]	34150	delivery	5	17
87378	2020-06-29 20:34:39	2020-06-29	9	[{"id_menu":6,"count":1}]	2941	pick-up	0	9
87379	2020-06-29 20:45:47	2020-06-29	12	[{"id_menu":1,"count":1}]	5303	pick-up	0	12
87380	2020-06-29 20:48:26	2020-06-29	9	[{"id_menu":7,"count":4}]	17025	delivery	5	14
87381	2020-06-29 20:49:49	2020-06-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	34102	delivery	5	26
87382	2020-06-29 20:52:59	2020-06-29	12	[{"id_menu":1,"count":1}]	15465	delivery	5	17
87383	2020-06-29 20:54:24	2020-06-29	9	[{"id_menu":7,"count":2}]	33900	delivery	5	14
87384	2020-06-29 20:58:22	2020-06-29	9	[{"id_menu":7,"count":1}]	14862	delivery	5	14
87385	2020-06-29 21:05:09	2020-06-29	9	[{"id_menu":6,"count":1}]	34126	pick-up	0	9
87386	2020-06-29 21:06:34	2020-06-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15000	delivery	5	31
87387	2020-06-29 21:07:02	2020-06-29	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	8666	pick-up	0	21
87388	2020-06-29 21:07:11	2020-06-29	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	34025	delivery	5	48
87389	2020-06-29 21:11:08	2020-06-29	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33961	delivery	5	54
87390	2020-06-29 21:11:28	2020-06-29	17	[{"id_menu":4,"count":1}]	11216	delivery	5	22
87391	2020-06-29 21:28:46	2020-06-29	17	[{"id_menu":4,"count":1}]	14870	delivery	5	22
87392	2020-06-29 21:31:10	2020-06-29	9	[{"id_menu":6,"count":1}]	11518	delivery	5	14
87393	2020-06-29 21:32:43	2020-06-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	34020	delivery	5	23
87394	2020-06-29 21:36:02	2020-06-29	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	29601	delivery	5	25
87395	2020-06-29 21:40:17	2020-06-29	12	[{"id_menu":3,"count":2}]	3961	pick-up	0	12
87396	2020-06-29 21:42:49	2020-06-29	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5906	delivery	5	43
87397	2020-06-29 21:51:28	2020-06-29	14	[{"id_menu":2,"count":1}]	34086	delivery	5	19
87398	2020-06-29 21:58:00	2020-06-29	17	[{"id_menu":4,"count":1}]	30170	delivery	5	22
87399	2020-06-29 22:03:20	2020-06-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6812	delivery	5	28
87400	2020-06-29 22:04:49	2020-06-29	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	34064	delivery	5	39
87401	2020-06-29 22:04:51	2020-06-29	12	[{"id_menu":3,"count":1}]	13159	delivery	5	17
87402	2020-06-29 22:07:56	2020-06-29	9	[{"id_menu":7,"count":1}]	18588	delivery	5	14
87403	2020-06-29 22:12:09	2020-06-29	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	7900	delivery	5	40
87404	2020-06-29 22:18:44	2020-06-29	9	[{"id_menu":6,"count":1}]	34143	delivery	5	14
87405	2020-06-29 22:21:42	2020-06-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	24018	delivery	5	27
87406	2020-06-29 22:21:52	2020-06-29	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	20165	delivery	5	25
87407	2020-06-29 22:23:27	2020-06-29	8	[{"id_menu":5,"count":1}]	34159	delivery	5	13
87408	2020-06-29 22:23:34	2020-06-29	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	34000	delivery	5	39
87409	2020-06-29 22:25:51	2020-06-29	9	[{"id_menu":7,"count":1}]	10091	delivery	5	14
87410	2020-06-29 22:26:17	2020-06-29	14	[{"id_menu":2,"count":1}]	14525	delivery	5	19
87411	2020-06-29 22:27:44	2020-06-29	9	[{"id_menu":6,"count":1}]	8160	delivery	5	14
87412	2020-06-29 22:30:23	2020-06-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	34173	delivery	5	23
87413	2020-06-29 22:33:02	2020-06-29	17	[{"id_menu":4,"count":1}]	34165	delivery	5	22
87414	2020-06-29 22:34:19	2020-06-29	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34113	delivery	5	31
87415	2020-06-29 22:36:45	2020-06-29	8	[{"id_menu":5,"count":1}]	21585	delivery	5	13
87416	2020-06-29 22:36:46	2020-06-29	12	[{"id_menu":3,"count":1}]	30678	delivery	5	17
87417	2020-06-29 22:44:33	2020-06-29	14	[{"id_menu":2,"count":1}]	3757	pick-up	0	14
87418	2020-06-29 22:53:43	2020-06-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	866	pick-up	0	21
87419	2020-06-29 22:56:58	2020-06-29	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	6811	delivery	5	40
87420	2020-06-29 23:01:02	2020-06-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	10226	delivery	5	28
87421	2020-06-29 23:06:10	2020-06-29	14	[{"id_menu":2,"count":1}]	34039	delivery	5	19
87422	2020-06-29 23:11:23	2020-06-29	9	[{"id_menu":7,"count":2}]	17863	delivery	5	14
87423	2020-06-29 23:11:32	2020-06-29	12	[{"id_menu":1,"count":1}]	10798	pick-up	0	12
87424	2020-06-29 23:22:05	2020-06-29	9	[{"id_menu":6,"count":1}]	1228	delivery	5	14
87425	2020-06-29 23:22:35	2020-06-29	14	[{"id_menu":2,"count":1}]	8437	pick-up	0	14
87426	2020-06-29 23:25:40	2020-06-29	9	[{"id_menu":7,"count":1}]	16810	pick-up	0	9
87427	2020-06-29 23:29:40	2020-06-29	8	[{"id_menu":5,"count":1}]	27997	delivery	5	13
87428	2020-06-29 23:34:23	2020-06-29	8	[{"id_menu":5,"count":1}]	34132	delivery	5	13
87429	2020-06-29 23:38:12	2020-06-29	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	627	delivery	5	42
87430	2020-06-29 23:42:46	2020-06-29	12	[{"id_menu":1,"count":1}]	7122	delivery	5	17
87431	2020-06-29 23:48:25	2020-06-29	14	[{"id_menu":2,"count":1}]	21860	pick-up	0	14
87432	2020-06-29 23:52:35	2020-06-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	34118	delivery	5	28
87433	2020-06-29 23:59:15	2020-06-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	31374	pick-up	0	17
87434	2020-06-29 23:59:17	2020-06-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2124	pick-up	0	22
87435	2020-06-30 00:02:48	2020-06-30	9	[{"id_menu":7,"count":1}]	34200	delivery	5	14
87436	2020-06-30 00:11:53	2020-06-30	14	[{"id_menu":2,"count":1}]	34357	delivery	5	19
87437	2020-06-30 00:15:28	2020-06-30	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	3343	delivery	5	22
87438	2020-06-30 00:20:56	2020-06-30	14	[{"id_menu":2,"count":1}]	19646	delivery	5	19
87439	2020-06-30 00:21:14	2020-06-30	9	[{"id_menu":6,"count":1}]	34254	delivery	5	14
87440	2020-06-30 00:23:24	2020-06-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	30534	pick-up	0	26
87441	2020-06-30 00:24:24	2020-06-30	12	[{"id_menu":1,"count":1}]	34229	delivery	5	17
87442	2020-06-30 00:27:37	2020-06-30	14	[{"id_menu":2,"count":2}]	34306	delivery	5	19
87443	2020-06-30 00:30:49	2020-06-30	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2917	pick-up	0	26
87444	2020-06-30 00:38:57	2020-06-30	9	[{"id_menu":7,"count":1}]	914	delivery	5	14
87445	2020-06-30 00:41:29	2020-06-30	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	21848	delivery	5	36
87446	2020-06-30 00:42:07	2020-06-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8048	pick-up	0	23
87447	2020-06-30 00:44:10	2020-06-30	14	[{"id_menu":2,"count":1}]	34323	delivery	5	19
87448	2020-06-30 00:46:15	2020-06-30	17	[{"id_menu":4,"count":1}]	9404	pick-up	0	17
87449	2020-06-30 00:46:17	2020-06-30	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	111	pick-up	0	21
87450	2020-06-30 00:46:49	2020-06-30	12	[{"id_menu":3,"count":1}]	19181	pick-up	0	12
87451	2020-06-30 00:50:08	2020-06-30	12	[{"id_menu":3,"count":1}]	34271	delivery	5	17
87452	2020-06-30 00:51:17	2020-06-30	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	22723	delivery	5	36
87453	2020-06-30 00:55:04	2020-06-30	9	[{"id_menu":7,"count":1}]	12623	pick-up	0	9
87454	2020-06-30 00:56:52	2020-06-30	8	[{"id_menu":5,"count":1}]	30500	delivery	5	13
87455	2020-06-30 01:02:55	2020-06-30	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34196	delivery	5	35
87456	2020-06-30 01:14:10	2020-06-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	19948	pick-up	0	23
87457	2020-06-30 01:17:16	2020-06-30	14	[{"id_menu":2,"count":1}]	1382	pick-up	0	14
87458	2020-06-30 01:19:36	2020-06-30	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	26826	delivery	5	30
87459	2020-06-30 01:20:25	2020-06-30	8	[{"id_menu":5,"count":1}]	10280	delivery	5	13
87460	2020-06-30 01:22:52	2020-06-30	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	15958	delivery	5	43
87461	2020-06-30 01:24:36	2020-06-30	12	[{"id_menu":1,"count":1}]	6301	pick-up	0	12
87462	2020-06-30 01:25:31	2020-06-30	14	[{"id_menu":2,"count":2}]	4540	pick-up	0	14
87463	2020-06-30 01:26:49	2020-06-30	12	[{"id_menu":3,"count":1}]	17329	pick-up	0	12
87464	2020-06-30 01:27:22	2020-06-30	9	[{"id_menu":6,"count":1}]	34275	delivery	5	14
87465	2020-06-30 01:38:28	2020-06-30	9	[{"id_menu":7,"count":2}]	34273	delivery	5	14
87466	2020-06-30 01:40:19	2020-06-30	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	34204	delivery	5	28
87467	2020-06-30 01:42:07	2020-06-30	9	[{"id_menu":7,"count":1}]	14175	delivery	5	14
87468	2020-06-30 01:43:51	2020-06-30	12	[{"id_menu":1,"count":1}]	4057	delivery	5	17
87469	2020-06-30 01:45:40	2020-06-30	14	[{"id_menu":2,"count":1}]	9614	delivery	5	19
87470	2020-06-30 01:50:52	2020-06-30	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	24037	delivery	5	56
87471	2020-06-30 01:54:49	2020-06-30	12	[{"id_menu":3,"count":1}]	34189	delivery	5	17
87472	2020-06-30 02:03:56	2020-06-30	9	[{"id_menu":6,"count":1}]	34259	delivery	5	14
87473	2020-06-30 02:04:32	2020-06-30	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29208	delivery	5	52
87474	2020-06-30 02:06:30	2020-06-30	12	[{"id_menu":3,"count":1}]	7431	delivery	5	17
87475	2020-06-30 02:07:58	2020-06-30	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16253	delivery	5	40
87476	2020-06-30 02:11:51	2020-06-30	17	[{"id_menu":4,"count":1}]	1998	pick-up	0	17
87477	2020-06-30 02:21:52	2020-06-30	17	[{"id_menu":4,"count":1}]	14554	delivery	5	22
87478	2020-06-30 02:23:37	2020-06-30	9	[{"id_menu":7,"count":1}]	13881	delivery	5	14
87479	2020-06-30 02:27:36	2020-06-30	17	[{"id_menu":4,"count":1}]	8382	delivery	5	22
87480	2020-06-30 02:30:09	2020-06-30	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	34219	delivery	5	25
87481	2020-06-30 02:32:51	2020-06-30	17	[{"id_menu":4,"count":1}]	34234	delivery	5	22
87482	2020-06-30 02:34:49	2020-06-30	9	[{"id_menu":7,"count":1}]	28959	pick-up	0	9
87483	2020-06-30 02:37:14	2020-06-30	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	9995	pick-up	0	21
87484	2020-06-30 02:37:58	2020-06-30	9	[{"id_menu":6,"count":1}]	34186	delivery	5	14
87485	2020-06-30 02:39:16	2020-06-30	9	[{"id_menu":7,"count":1}]	24888	delivery	5	14
87486	2020-06-30 02:39:35	2020-06-30	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	34276	delivery	5	40
87487	2020-06-30 02:46:36	2020-06-30	14	[{"id_menu":2,"count":1}]	9377	delivery	5	19
87488	2020-06-30 02:53:12	2020-06-30	9	[{"id_menu":7,"count":1}]	2897	pick-up	0	9
87489	2020-06-30 02:53:45	2020-06-30	12	[{"id_menu":3,"count":1}]	34184	delivery	5	17
87490	2020-06-30 02:55:50	2020-06-30	9	[{"id_menu":6,"count":1}]	34247	delivery	5	14
87491	2020-06-30 03:08:17	2020-06-30	8	[{"id_menu":5,"count":1}]	34382	delivery	5	13
87492	2020-06-30 03:10:29	2020-06-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3621	pick-up	0	23
87493	2020-06-30 03:15:07	2020-06-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	34315	delivery	5	27
87494	2020-06-30 03:18:04	2020-06-30	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	34310	delivery	5	45
87495	2020-06-30 03:18:35	2020-06-30	9	[{"id_menu":6,"count":1}]	5649	delivery	5	14
87496	2020-06-30 03:19:32	2020-06-30	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	22207	delivery	5	48
87497	2020-06-30 03:19:52	2020-06-30	17	[{"id_menu":4,"count":1}]	11152	delivery	5	22
87498	2020-06-30 03:20:07	2020-06-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	34268	delivery	5	31
87499	2020-06-30 03:23:18	2020-06-30	9	[{"id_menu":6,"count":1}]	15428	delivery	5	14
87500	2020-06-30 03:25:02	2020-06-30	12	[{"id_menu":1,"count":1}]	1781	pick-up	0	12
87501	2020-06-30 03:31:47	2020-06-30	17	[{"id_menu":4,"count":1}]	34220	delivery	5	22
87502	2020-06-30 03:32:14	2020-06-30	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18692	delivery	5	39
87503	2020-06-30 03:42:02	2020-06-30	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	10341	delivery	5	26
87504	2020-06-30 03:45:47	2020-06-30	9	[{"id_menu":6,"count":1}]	24718	pick-up	0	9
87505	2020-06-30 03:46:42	2020-06-30	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	1832	pick-up	0	25
87506	2020-06-30 03:47:00	2020-06-30	8	[{"id_menu":5,"count":1}]	34212	delivery	5	13
87507	2020-06-30 03:51:15	2020-06-30	14	[{"id_menu":2,"count":1}]	22061	delivery	5	19
87508	2020-06-30 03:56:14	2020-06-30	9	[{"id_menu":6,"count":1}]	34210	delivery	5	14
87509	2020-06-30 03:58:10	2020-06-30	8	[{"id_menu":5,"count":1}]	22485	delivery	5	13
87510	2020-06-30 04:03:51	2020-06-30	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	2807	pick-up	0	32
87511	2020-06-30 04:07:40	2020-06-30	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	29306	delivery	5	22
87512	2020-06-30 04:12:47	2020-06-30	8	[{"id_menu":5,"count":1}]	11858	delivery	5	13
87513	2020-06-30 04:15:15	2020-06-30	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	34238	delivery	5	45
87514	2020-06-30 04:17:31	2020-06-30	9	[{"id_menu":6,"count":1}]	34286	delivery	5	14
87515	2020-06-30 04:20:08	2020-06-30	17	[{"id_menu":4,"count":1}]	25320	pick-up	0	17
87516	2020-06-30 04:23:45	2020-06-30	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12143	delivery	5	37
87517	2020-06-30 04:24:05	2020-06-30	12	[{"id_menu":3,"count":1}]	34340	delivery	5	17
87518	2020-06-30 04:25:28	2020-06-30	12	[{"id_menu":1,"count":2}]	1612	pick-up	0	12
87519	2020-06-30 04:26:10	2020-06-30	9	[{"id_menu":7,"count":1}]	313	pick-up	0	9
87520	2020-06-30 04:28:13	2020-06-30	9	[{"id_menu":6,"count":3}]	22252	delivery	5	14
87521	2020-06-30 04:28:25	2020-06-30	14	[{"id_menu":2,"count":1}]	2641	pick-up	0	14
87522	2020-06-30 04:30:07	2020-06-30	14	[{"id_menu":2,"count":1}]	6962	delivery	5	19
87523	2020-06-30 04:30:56	2020-06-30	14	[{"id_menu":2,"count":1}]	8600	delivery	5	19
87524	2020-06-30 04:40:36	2020-06-30	14	[{"id_menu":2,"count":1}]	21170	delivery	5	19
87525	2020-06-30 04:41:20	2020-06-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	30258	delivery	5	22
87526	2020-06-30 04:41:29	2020-06-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3651	pick-up	0	18
87527	2020-06-30 04:41:30	2020-06-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14742	delivery	5	23
87528	2020-06-30 04:43:44	2020-06-30	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	4658	delivery	5	34
87529	2020-06-30 04:48:41	2020-06-30	9	[{"id_menu":7,"count":1}]	1096	pick-up	0	9
87530	2020-06-30 04:50:02	2020-06-30	14	[{"id_menu":2,"count":1}]	1424	pick-up	0	14
87531	2020-06-30 04:57:53	2020-06-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	14719	delivery	5	28
87532	2020-06-30 05:08:09	2020-06-30	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	32406	delivery	5	26
87533	2020-06-30 05:09:06	2020-06-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	34223	delivery	5	27
87534	2020-06-30 05:09:35	2020-06-30	9	[{"id_menu":7,"count":1}]	34328	delivery	5	14
87535	2020-06-30 05:10:44	2020-06-30	17	[{"id_menu":4,"count":1}]	24404	delivery	5	22
87536	2020-06-30 05:11:13	2020-06-30	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	993	pick-up	0	26
87537	2020-06-30 05:16:11	2020-06-30	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	34358	pick-up	0	38
87538	2020-06-30 05:20:54	2020-06-30	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	12448	delivery	5	31
87539	2020-06-30 05:25:36	2020-06-30	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	15488	delivery	5	30
87540	2020-06-30 05:25:52	2020-06-30	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	21244	delivery	5	31
87541	2020-06-30 05:28:17	2020-06-30	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1337	delivery	5	26
87542	2020-06-30 05:29:33	2020-06-30	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2832	delivery	5	43
87543	2020-06-30 05:31:00	2020-06-30	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34239	delivery	5	31
87544	2020-06-30 05:31:02	2020-06-30	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14305	delivery	5	36
87545	2020-06-30 05:32:50	2020-06-30	9	[{"id_menu":6,"count":1}]	8323	pick-up	0	9
87546	2020-06-30 05:35:37	2020-06-30	9	[{"id_menu":7,"count":1}]	34218	pick-up	0	9
87547	2020-06-30 05:38:34	2020-06-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1582	pick-up	0	18
87548	2020-06-30 05:39:35	2020-06-30	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28692	delivery	5	39
87549	2020-06-30 05:41:14	2020-06-30	9	[{"id_menu":6,"count":1}]	1076	pick-up	0	9
87550	2020-06-30 05:46:04	2020-06-30	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1899	delivery	5	29
87551	2020-06-30 05:49:27	2020-06-30	8	[{"id_menu":5,"count":1}]	13335	pick-up	0	8
87552	2020-06-30 05:52:57	2020-06-30	12	[{"id_menu":3,"count":1}]	13100	delivery	5	17
87553	2020-06-30 05:57:32	2020-06-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7529	delivery	5	22
87554	2020-06-30 06:00:55	2020-06-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	34333	delivery	5	31
87555	2020-06-30 06:01:11	2020-06-30	14	[{"id_menu":2,"count":1}]	34285	delivery	5	19
87556	2020-06-30 06:04:12	2020-06-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	14090	delivery	5	28
87557	2020-06-30 06:09:54	2020-06-30	12	[{"id_menu":1,"count":1}]	34301	pick-up	0	12
87558	2020-06-30 06:12:56	2020-06-30	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	34365	delivery	5	45
87559	2020-06-30 06:14:00	2020-06-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	34343	delivery	5	22
87560	2020-06-30 06:17:40	2020-06-30	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	32063	pick-up	0	26
87561	2020-06-30 06:22:54	2020-06-30	17	[{"id_menu":4,"count":1}]	20338	delivery	5	22
87562	2020-06-30 06:23:53	2020-06-30	12	[{"id_menu":3,"count":1}]	2858	delivery	5	17
87563	2020-06-30 06:30:39	2020-06-30	12	[{"id_menu":3,"count":1}]	10455	delivery	5	17
87564	2020-06-30 06:37:35	2020-06-30	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	34342	delivery	5	40
87565	2020-06-30 06:37:37	2020-06-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	29214	delivery	5	26
87566	2020-06-30 06:38:53	2020-06-30	9	[{"id_menu":6,"count":1}]	22014	delivery	5	14
87567	2020-06-30 06:51:05	2020-06-30	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	27405	delivery	5	34
87568	2020-06-30 06:58:17	2020-06-30	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	23660	delivery	5	26
87569	2020-06-30 07:06:16	2020-06-30	9	[{"id_menu":6,"count":1}]	8054	delivery	5	14
87570	2020-06-30 07:06:52	2020-06-30	9	[{"id_menu":7,"count":1}]	14396	delivery	5	14
87571	2020-06-30 07:12:44	2020-06-30	12	[{"id_menu":3,"count":1}]	34270	delivery	5	17
87572	2020-06-30 07:13:43	2020-06-30	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7453	delivery	5	39
87573	2020-06-30 07:13:58	2020-06-30	9	[{"id_menu":6,"count":1}]	17780	delivery	5	14
87574	2020-06-30 07:17:11	2020-06-30	8	[{"id_menu":5,"count":1}]	10500	delivery	5	13
87575	2020-06-30 07:20:15	2020-06-30	12	[{"id_menu":3,"count":1}]	34303	delivery	5	17
87576	2020-06-30 07:23:59	2020-06-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17809	delivery	5	31
87577	2020-06-30 07:26:49	2020-06-30	9	[{"id_menu":6,"count":1}]	12129	pick-up	0	9
87578	2020-06-30 07:28:59	2020-06-30	8	[{"id_menu":5,"count":1}]	5558	delivery	5	13
87579	2020-06-30 07:30:38	2020-06-30	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	30032	delivery	5	45
87580	2020-06-30 07:31:51	2020-06-30	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12022	delivery	5	48
87581	2020-06-30 07:38:39	2020-06-30	9	[{"id_menu":6,"count":1}]	16768	delivery	5	14
87582	2020-06-30 07:40:35	2020-06-30	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1306	delivery	5	34
87583	2020-06-30 07:43:11	2020-06-30	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29197	delivery	5	40
87584	2020-06-30 07:49:14	2020-06-30	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	34336	delivery	5	22
87585	2020-06-30 07:50:34	2020-06-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	14896	delivery	5	26
87586	2020-06-30 07:53:10	2020-06-30	12	[{"id_menu":3,"count":1}]	4798	delivery	5	17
87587	2020-06-30 08:03:06	2020-06-30	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	34363	delivery	5	36
87588	2020-06-30 08:05:44	2020-06-30	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	19216	delivery	5	36
87589	2020-06-30 08:13:04	2020-06-30	46	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	22367	delivery	5	51
87590	2020-06-30 08:23:58	2020-06-30	9	[{"id_menu":7,"count":1}]	407	pick-up	0	9
87591	2020-06-30 08:27:29	2020-06-30	9	[{"id_menu":6,"count":1}]	14068	delivery	5	14
87592	2020-06-30 08:30:09	2020-06-30	12	[{"id_menu":3,"count":1}]	34299	delivery	5	17
87593	2020-06-30 08:37:59	2020-06-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	177	delivery	5	28
87594	2020-06-30 08:43:31	2020-06-30	8	[{"id_menu":5,"count":1}]	3909	delivery	5	13
87595	2020-06-30 08:48:13	2020-06-30	12	[{"id_menu":3,"count":1}]	25337	delivery	5	17
87596	2020-06-30 08:52:31	2020-06-30	17	[{"id_menu":4,"count":1}]	16438	delivery	5	22
87597	2020-06-30 08:53:00	2020-06-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	25215	pick-up	0	21
87598	2020-06-30 08:56:16	2020-06-30	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	16230	delivery	5	22
87599	2020-06-30 08:57:27	2020-06-30	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	28439	delivery	5	28
87600	2020-06-30 08:59:53	2020-06-30	9	[{"id_menu":6,"count":1}]	5963	pick-up	0	9
87601	2020-06-30 09:02:38	2020-06-30	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	16829	pick-up	0	29
87602	2020-06-30 09:05:33	2020-06-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	23835	delivery	5	28
87603	2020-06-30 09:08:18	2020-06-30	14	[{"id_menu":2,"count":1}]	2511	pick-up	0	14
87604	2020-06-30 09:11:27	2020-06-30	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18951	delivery	5	39
87605	2020-06-30 09:14:35	2020-06-30	17	[{"id_menu":4,"count":1}]	22043	delivery	5	22
87606	2020-06-30 09:17:11	2020-06-30	14	[{"id_menu":2,"count":1}]	34346	delivery	5	19
87607	2020-06-30 09:19:29	2020-06-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3114	delivery	5	28
87608	2020-06-30 09:19:48	2020-06-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	34384	pick-up	0	26
87609	2020-06-30 09:20:57	2020-06-30	8	[{"id_menu":5,"count":1}]	1756	delivery	5	13
87610	2020-06-30 09:25:15	2020-06-30	46	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	11768	pick-up	0	46
87611	2020-06-30 09:26:21	2020-06-30	9	[{"id_menu":6,"count":2}]	34386	delivery	5	14
87612	2020-06-30 09:28:43	2020-06-30	9	[{"id_menu":7,"count":1}]	8747	pick-up	0	9
87613	2020-06-30 09:31:12	2020-06-30	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21989	delivery	5	31
87614	2020-06-30 09:32:28	2020-06-30	8	[{"id_menu":5,"count":1}]	34316	delivery	5	13
87615	2020-06-30 09:41:35	2020-06-30	9	[{"id_menu":7,"count":1}]	21757	delivery	5	14
87616	2020-06-30 09:43:53	2020-06-30	14	[{"id_menu":2,"count":2}]	34269	delivery	5	19
87617	2020-06-30 09:44:28	2020-06-30	14	[{"id_menu":2,"count":1}]	34263	delivery	5	19
87618	2020-06-30 09:44:35	2020-06-30	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	26461	delivery	5	26
87619	2020-06-30 09:46:45	2020-06-30	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	34359	delivery	5	26
87620	2020-06-30 09:49:56	2020-06-30	12	[{"id_menu":1,"count":1}]	34226	pick-up	0	12
87621	2020-06-30 09:50:19	2020-06-30	14	[{"id_menu":2,"count":1}]	6145	delivery	5	19
87622	2020-06-30 09:51:34	2020-06-30	9	[{"id_menu":6,"count":1}]	12836	delivery	5	14
87623	2020-06-30 09:54:06	2020-06-30	17	[{"id_menu":4,"count":1}]	34355	delivery	5	22
87624	2020-06-30 09:56:09	2020-06-30	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	28441	delivery	5	43
87625	2020-06-30 09:58:05	2020-06-30	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	34338	delivery	5	22
87626	2020-06-30 10:11:13	2020-06-30	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	10577	delivery	5	31
87627	2020-06-30 10:15:28	2020-06-30	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1780	pick-up	0	31
87628	2020-06-30 10:15:55	2020-06-30	8	[{"id_menu":5,"count":1}]	2729	delivery	5	13
87629	2020-06-30 10:16:29	2020-06-30	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	23101	delivery	5	31
87630	2020-06-30 10:18:29	2020-06-30	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3358	delivery	5	43
87631	2020-06-30 10:21:22	2020-06-30	17	[{"id_menu":4,"count":1}]	34283	pick-up	0	17
87632	2020-06-30 10:26:38	2020-06-30	17	[{"id_menu":4,"count":1}]	22530	delivery	5	22
87633	2020-06-30 10:32:44	2020-06-30	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	12212	pick-up	0	20
87634	2020-06-30 10:34:29	2020-06-30	8	[{"id_menu":5,"count":1}]	30154	pick-up	0	8
87635	2020-06-30 10:36:07	2020-06-30	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	34308	delivery	5	48
87636	2020-06-30 10:36:59	2020-06-30	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	24168	delivery	5	57
87637	2020-06-30 10:41:02	2020-06-30	14	[{"id_menu":2,"count":1}]	34289	delivery	5	19
87638	2020-06-30 10:42:42	2020-06-30	14	[{"id_menu":2,"count":2}]	4411	pick-up	0	14
87639	2020-06-30 10:42:47	2020-06-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	34227	delivery	5	22
87640	2020-06-30 10:43:04	2020-06-30	17	[{"id_menu":4,"count":1}]	34261	delivery	5	22
87641	2020-06-30 10:49:27	2020-06-30	9	[{"id_menu":7,"count":1}]	34298	delivery	5	14
87642	2020-06-30 10:50:28	2020-06-30	14	[{"id_menu":2,"count":1}]	25420	delivery	5	19
87643	2020-06-30 10:53:52	2020-06-30	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	26742	delivery	5	26
87644	2020-06-30 10:56:13	2020-06-30	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	34250	delivery	5	34
87645	2020-06-30 10:56:29	2020-06-30	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8823	delivery	5	40
87646	2020-06-30 10:57:07	2020-06-30	9	[{"id_menu":6,"count":1}]	7901	delivery	5	14
87647	2020-06-30 10:59:06	2020-06-30	12	[{"id_menu":1,"count":1}]	2951	delivery	5	17
87648	2020-06-30 10:59:42	2020-06-30	9	[{"id_menu":6,"count":1}]	13220	delivery	5	14
87649	2020-06-30 11:00:44	2020-06-30	9	[{"id_menu":7,"count":2}]	15271	delivery	5	14
87650	2020-06-30 11:03:42	2020-06-30	12	[{"id_menu":3,"count":1}]	34293	delivery	5	17
87651	2020-06-30 11:06:06	2020-06-30	14	[{"id_menu":2,"count":1}]	28030	delivery	5	19
87652	2020-06-30 11:12:14	2020-06-30	17	[{"id_menu":4,"count":1}]	34352	delivery	5	22
87653	2020-06-30 11:12:26	2020-06-30	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	34371	delivery	5	25
87654	2020-06-30 11:15:26	2020-06-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9227	delivery	5	31
87655	2020-06-30 11:15:35	2020-06-30	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31164	delivery	5	40
87656	2020-06-30 11:15:43	2020-06-30	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	15906	delivery	5	40
87657	2020-06-30 11:17:56	2020-06-30	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19111	delivery	5	31
87658	2020-06-30 11:18:33	2020-06-30	9	[{"id_menu":6,"count":1}]	30976	pick-up	0	9
87659	2020-06-30 11:19:44	2020-06-30	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	34235	delivery	5	36
87660	2020-06-30 11:24:23	2020-06-30	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	5306	pick-up	0	29
87661	2020-06-30 11:28:11	2020-06-30	17	[{"id_menu":4,"count":1}]	20237	delivery	5	22
87662	2020-06-30 11:28:52	2020-06-30	9	[{"id_menu":6,"count":1}]	27723	delivery	5	14
87663	2020-06-30 11:39:17	2020-06-30	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	34356	delivery	5	34
87664	2020-06-30 11:39:23	2020-06-30	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	25142	pick-up	0	20
87665	2020-06-30 11:41:08	2020-06-30	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	34185	delivery	5	34
87666	2020-06-30 11:42:42	2020-06-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	34201	delivery	5	28
87667	2020-06-30 11:43:55	2020-06-30	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	293	delivery	5	22
87668	2020-06-30 11:49:28	2020-06-30	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	34256	delivery	5	39
87669	2020-06-30 11:52:37	2020-06-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	26493	delivery	5	22
87670	2020-06-30 11:59:29	2020-06-30	12	[{"id_menu":1,"count":1}]	34233	delivery	5	17
87671	2020-06-30 11:59:49	2020-06-30	12	[{"id_menu":1,"count":2}]	8180	pick-up	0	12
87672	2020-06-30 12:00:35	2020-06-30	9	[{"id_menu":6,"count":1}]	13268	delivery	5	14
87673	2020-06-30 12:03:56	2020-06-30	9	[{"id_menu":6,"count":1}]	34288	delivery	5	14
87674	2020-06-30 12:04:02	2020-06-30	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	6898	delivery	5	29
87675	2020-06-30 12:10:12	2020-06-30	9	[{"id_menu":7,"count":1}]	34278	delivery	5	14
87676	2020-06-30 12:14:45	2020-06-30	14	[{"id_menu":2,"count":1}]	34367	pick-up	0	14
87677	2020-06-30 12:15:58	2020-06-30	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	16496	pick-up	0	21
87678	2020-06-30 12:18:17	2020-06-30	12	[{"id_menu":3,"count":1}]	34240	delivery	5	17
87679	2020-06-30 12:18:30	2020-06-30	14	[{"id_menu":2,"count":1}]	18754	delivery	5	19
87680	2020-06-30 12:38:43	2020-06-30	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	29787	delivery	5	45
87681	2020-06-30 12:48:48	2020-06-30	9	[{"id_menu":7,"count":1}]	34302	delivery	5	14
87682	2020-06-30 12:49:52	2020-06-30	12	[{"id_menu":3,"count":1}]	5654	delivery	5	17
87683	2020-06-30 12:50:16	2020-06-30	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	34242	pick-up	0	20
87684	2020-06-30 12:52:06	2020-06-30	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12191	delivery	5	36
87685	2020-06-30 12:59:12	2020-06-30	17	[{"id_menu":4,"count":1}]	12248	delivery	5	22
87686	2020-06-30 12:59:21	2020-06-30	12	[{"id_menu":1,"count":1}]	12024	delivery	5	17
87687	2020-06-30 13:06:59	2020-06-30	17	[{"id_menu":4,"count":1}]	34300	delivery	5	22
87688	2020-06-30 13:09:24	2020-06-30	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	27907	delivery	5	45
87689	2020-06-30 13:11:58	2020-06-30	14	[{"id_menu":2,"count":1}]	5483	delivery	5	19
87690	2020-06-30 13:23:34	2020-06-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23964	delivery	5	23
87691	2020-06-30 13:33:03	2020-06-30	9	[{"id_menu":6,"count":1}]	34373	delivery	5	14
87692	2020-06-30 13:33:32	2020-06-30	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11587	pick-up	0	31
87693	2020-06-30 13:34:28	2020-06-30	14	[{"id_menu":2,"count":1}]	17116	delivery	5	19
87694	2020-06-30 13:34:45	2020-06-30	9	[{"id_menu":7,"count":1}]	6404	delivery	5	14
87695	2020-06-30 13:40:45	2020-06-30	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4063	pick-up	0	29
87696	2020-06-30 13:52:03	2020-06-30	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":3}]	11210	delivery	5	25
87697	2020-06-30 13:52:49	2020-06-30	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	16657	delivery	5	30
87698	2020-06-30 13:56:08	2020-06-30	14	[{"id_menu":2,"count":1}]	5927	delivery	5	19
87699	2020-06-30 14:13:58	2020-06-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	18891	delivery	5	28
87700	2020-06-30 14:14:52	2020-06-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7206	delivery	5	28
87701	2020-06-30 14:15:01	2020-06-30	9	[{"id_menu":7,"count":1}]	578	delivery	5	14
87702	2020-06-30 14:21:45	2020-06-30	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	34209	delivery	5	22
87703	2020-06-30 14:21:50	2020-06-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	26706	delivery	5	26
87704	2020-06-30 14:23:15	2020-06-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	34361	delivery	5	28
87705	2020-06-30 14:25:12	2020-06-30	17	[{"id_menu":4,"count":1}]	21483	pick-up	0	17
87706	2020-06-30 14:35:11	2020-06-30	12	[{"id_menu":1,"count":1}]	13863	delivery	5	17
87707	2020-06-30 14:35:43	2020-06-30	17	[{"id_menu":4,"count":1}]	33465	delivery	5	22
87708	2020-06-30 14:37:24	2020-06-30	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	30124	delivery	5	36
87709	2020-06-30 14:40:58	2020-06-30	8	[{"id_menu":5,"count":1}]	6201	delivery	5	13
87710	2020-06-30 14:44:09	2020-06-30	17	[{"id_menu":4,"count":1}]	17704	delivery	5	22
87711	2020-06-30 14:44:15	2020-06-30	9	[{"id_menu":6,"count":1}]	17906	delivery	5	14
87712	2020-06-30 14:48:24	2020-06-30	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8993	delivery	5	43
87713	2020-06-30 14:53:09	2020-06-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19826	delivery	5	23
87714	2020-06-30 14:56:20	2020-06-30	12	[{"id_menu":1,"count":1}]	15069	delivery	5	17
87715	2020-06-30 14:56:32	2020-06-30	9	[{"id_menu":7,"count":1}]	18980	delivery	5	14
87716	2020-06-30 15:03:50	2020-06-30	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	34327	pick-up	0	31
87717	2020-06-30 15:07:01	2020-06-30	12	[{"id_menu":1,"count":1}]	4072	pick-up	0	12
87718	2020-06-30 15:08:51	2020-06-30	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	29064	pick-up	0	26
87719	2020-06-30 15:09:43	2020-06-30	17	[{"id_menu":4,"count":2}]	3148	pick-up	0	17
87720	2020-06-30 15:09:57	2020-06-30	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24344	pick-up	0	29
87721	2020-06-30 15:13:44	2020-06-30	9	[{"id_menu":6,"count":1}]	34297	delivery	5	14
87722	2020-06-30 15:14:37	2020-06-30	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16711	delivery	5	37
87723	2020-06-30 15:14:56	2020-06-30	9	[{"id_menu":7,"count":1}]	7631	pick-up	0	9
87724	2020-06-30 15:16:50	2020-06-30	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	32312	delivery	5	46
87725	2020-06-30 15:17:47	2020-06-30	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	34331	delivery	5	56
87726	2020-06-30 15:18:08	2020-06-30	9	[{"id_menu":7,"count":1}]	33482	delivery	5	14
87727	2020-06-30 15:22:11	2020-06-30	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":2}]	34320	delivery	5	26
87728	2020-06-30 15:28:01	2020-06-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	30379	delivery	5	28
87729	2020-06-30 15:30:36	2020-06-30	14	[{"id_menu":2,"count":1}]	8521	pick-up	0	14
87730	2020-06-30 15:37:47	2020-06-30	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	19366	delivery	5	29
87731	2020-06-30 15:38:26	2020-06-30	8	[{"id_menu":5,"count":1}]	34377	delivery	5	13
87732	2020-06-30 15:38:29	2020-06-30	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	34260	delivery	5	44
87733	2020-06-30 15:45:00	2020-06-30	14	[{"id_menu":2,"count":1}]	34243	pick-up	0	14
87734	2020-06-30 15:46:20	2020-06-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	34312	delivery	5	22
87735	2020-06-30 15:47:15	2020-06-30	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	22547	delivery	5	48
87736	2020-06-30 15:48:26	2020-06-30	9	[{"id_menu":6,"count":1}]	1158	delivery	5	14
87737	2020-06-30 15:48:39	2020-06-30	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34195	delivery	5	37
87738	2020-06-30 15:49:44	2020-06-30	14	[{"id_menu":2,"count":3}]	20133	pick-up	0	14
87739	2020-06-30 15:54:05	2020-06-30	9	[{"id_menu":7,"count":1}]	5911	delivery	5	14
87740	2020-06-30 15:54:17	2020-06-30	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	29851	delivery	5	26
87741	2020-06-30 15:58:58	2020-06-30	8	[{"id_menu":5,"count":1}]	25499	delivery	5	13
87742	2020-06-30 16:04:24	2020-06-30	9	[{"id_menu":6,"count":1}]	34237	delivery	5	14
87743	2020-06-30 16:05:10	2020-06-30	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	24220	delivery	5	30
87744	2020-06-30 16:08:53	2020-06-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	34194	delivery	5	23
87745	2020-06-30 16:09:12	2020-06-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	34214	delivery	5	28
87746	2020-06-30 16:13:04	2020-06-30	14	[{"id_menu":2,"count":1}]	20413	pick-up	0	14
87747	2020-06-30 16:14:32	2020-06-30	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	21187	delivery	5	40
87748	2020-06-30 16:25:40	2020-06-30	12	[{"id_menu":3,"count":1}]	4186	delivery	5	17
87749	2020-06-30 16:25:57	2020-06-30	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23284	delivery	5	35
87750	2020-06-30 16:29:58	2020-06-30	9	[{"id_menu":7,"count":2}]	15284	delivery	5	14
87751	2020-06-30 16:30:27	2020-06-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	34231	delivery	5	22
87752	2020-06-30 16:34:40	2020-06-30	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	34375	delivery	5	31
87753	2020-06-30 16:41:00	2020-06-30	9	[{"id_menu":6,"count":1}]	15104	delivery	5	14
87754	2020-06-30 16:47:20	2020-06-30	12	[{"id_menu":3,"count":1}]	34267	delivery	5	17
87755	2020-06-30 16:48:22	2020-06-30	17	[{"id_menu":4,"count":1}]	29226	pick-up	0	17
87756	2020-06-30 16:50:52	2020-06-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	21968	delivery	5	31
87757	2020-06-30 16:50:54	2020-06-30	8	[{"id_menu":5,"count":1}]	32473	delivery	5	13
87758	2020-06-30 16:55:07	2020-06-30	8	[{"id_menu":5,"count":1}]	26686	delivery	5	13
87759	2020-06-30 16:56:51	2020-06-30	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	34266	delivery	5	40
87760	2020-06-30 16:58:21	2020-06-30	8	[{"id_menu":5,"count":1}]	34372	delivery	5	13
87761	2020-06-30 16:58:24	2020-06-30	14	[{"id_menu":2,"count":1}]	14129	delivery	5	19
87762	2020-06-30 17:00:15	2020-06-30	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34230	delivery	5	31
87763	2020-06-30 17:00:23	2020-06-30	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	34311	delivery	5	25
87764	2020-06-30 17:01:08	2020-06-30	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17666	delivery	5	35
87765	2020-06-30 17:07:16	2020-06-30	9	[{"id_menu":6,"count":1}]	34350	delivery	5	14
87766	2020-06-30 17:10:02	2020-06-30	17	[{"id_menu":4,"count":1}]	34322	pick-up	0	17
87767	2020-06-30 17:15:48	2020-06-30	9	[{"id_menu":6,"count":2}]	15957	delivery	5	14
87768	2020-06-30 17:22:49	2020-06-30	9	[{"id_menu":6,"count":1}]	1143	pick-up	0	9
87769	2020-06-30 17:23:01	2020-06-30	9	[{"id_menu":7,"count":1}]	26947	delivery	5	14
87770	2020-06-30 17:24:31	2020-06-30	14	[{"id_menu":2,"count":1}]	34264	delivery	5	19
87771	2020-06-30 17:25:52	2020-06-30	9	[{"id_menu":7,"count":1}]	15217	delivery	5	14
87772	2020-06-30 17:25:56	2020-06-30	9	[{"id_menu":6,"count":1}]	17041	pick-up	0	9
87773	2020-06-30 17:26:57	2020-06-30	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	18119	delivery	5	34
87774	2020-06-30 17:27:39	2020-06-30	12	[{"id_menu":3,"count":1}]	837	delivery	5	17
87775	2020-06-30 17:28:38	2020-06-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	31148	delivery	5	28
87776	2020-06-30 17:33:22	2020-06-30	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	23037	delivery	5	56
87777	2020-06-30 17:36:52	2020-06-30	17	[{"id_menu":4,"count":1}]	3116	pick-up	0	17
87778	2020-06-30 17:40:13	2020-06-30	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	21813	delivery	5	37
87779	2020-06-30 17:41:31	2020-06-30	9	[{"id_menu":6,"count":1}]	34206	delivery	5	14
87780	2020-06-30 17:47:58	2020-06-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	34213	delivery	5	27
87781	2020-06-30 17:48:32	2020-06-30	17	[{"id_menu":4,"count":1}]	29864	pick-up	0	17
87782	2020-06-30 17:49:51	2020-06-30	14	[{"id_menu":2,"count":2}]	9193	pick-up	0	14
87783	2020-06-30 17:52:26	2020-06-30	9	[{"id_menu":6,"count":2}]	13673	delivery	5	14
87784	2020-06-30 17:58:53	2020-06-30	12	[{"id_menu":3,"count":1}]	30687	pick-up	0	12
87785	2020-06-30 18:02:03	2020-06-30	9	[{"id_menu":6,"count":1}]	4908	delivery	5	14
87786	2020-06-30 18:02:17	2020-06-30	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	27321	pick-up	0	26
87787	2020-06-30 18:08:59	2020-06-30	17	[{"id_menu":4,"count":2}]	34368	pick-up	0	17
87788	2020-06-30 18:18:47	2020-06-30	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2519	pick-up	0	21
87789	2020-06-30 18:22:41	2020-06-30	14	[{"id_menu":2,"count":2}]	17067	delivery	5	19
87790	2020-06-30 18:26:44	2020-06-30	17	[{"id_menu":4,"count":1}]	34374	delivery	5	22
87791	2020-06-30 18:28:35	2020-06-30	12	[{"id_menu":1,"count":1}]	4248	delivery	5	17
87792	2020-06-30 18:34:39	2020-06-30	14	[{"id_menu":2,"count":1}]	2012	delivery	5	19
87793	2020-06-30 18:36:30	2020-06-30	14	[{"id_menu":2,"count":1}]	34339	delivery	5	19
87794	2020-06-30 18:37:18	2020-06-30	34	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	24948	delivery	5	39
87795	2020-06-30 18:38:47	2020-06-30	12	[{"id_menu":3,"count":1}]	34192	delivery	5	17
87796	2020-06-30 18:40:29	2020-06-30	9	[{"id_menu":6,"count":1}]	4462	pick-up	0	9
87797	2020-06-30 18:40:37	2020-06-30	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34307	delivery	5	31
87798	2020-06-30 18:41:15	2020-06-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2446	delivery	5	31
87799	2020-06-30 18:44:18	2020-06-30	17	[{"id_menu":4,"count":1}]	34318	delivery	5	22
87800	2020-06-30 18:49:44	2020-06-30	9	[{"id_menu":7,"count":1}]	9737	delivery	5	14
87801	2020-06-30 18:51:08	2020-06-30	8	[{"id_menu":5,"count":1}]	2443	pick-up	0	8
87802	2020-06-30 18:54:41	2020-06-30	14	[{"id_menu":2,"count":1}]	34292	delivery	5	19
87803	2020-06-30 18:55:33	2020-06-30	14	[{"id_menu":2,"count":1}]	26556	delivery	5	19
87804	2020-06-30 18:56:30	2020-06-30	9	[{"id_menu":6,"count":1}]	20147	delivery	5	14
87805	2020-06-30 19:03:02	2020-06-30	17	[{"id_menu":4,"count":1}]	3507	pick-up	0	17
87806	2020-06-30 19:07:10	2020-06-30	8	[{"id_menu":5,"count":1}]	28874	delivery	5	13
87807	2020-06-30 19:08:59	2020-06-30	9	[{"id_menu":7,"count":1}]	34317	delivery	5	14
87808	2020-06-30 19:12:22	2020-06-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34180	delivery	5	23
87809	2020-06-30 19:12:49	2020-06-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	28089	delivery	5	22
87810	2020-06-30 19:16:31	2020-06-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	11239	delivery	5	27
87811	2020-06-30 19:28:32	2020-06-30	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	21640	delivery	5	26
87812	2020-06-30 19:31:41	2020-06-30	8	[{"id_menu":5,"count":1}]	34216	delivery	5	13
87813	2020-06-30 19:39:09	2020-06-30	12	[{"id_menu":3,"count":1}]	13083	pick-up	0	12
87814	2020-06-30 19:49:28	2020-06-30	14	[{"id_menu":2,"count":1}]	34207	delivery	5	19
87815	2020-06-30 19:50:53	2020-06-30	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	8151	delivery	5	31
87816	2020-06-30 19:57:44	2020-06-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	23298	delivery	5	22
87817	2020-06-30 20:01:32	2020-06-30	12	[{"id_menu":1,"count":1}]	8719	pick-up	0	12
87818	2020-06-30 20:02:56	2020-06-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	24135	delivery	5	26
87819	2020-06-30 20:04:01	2020-06-30	14	[{"id_menu":2,"count":1}]	238	pick-up	0	14
87820	2020-06-30 20:20:31	2020-06-30	9	[{"id_menu":6,"count":1}]	4169	delivery	5	14
87821	2020-06-30 20:21:03	2020-06-30	8	[{"id_menu":5,"count":1}]	8397	delivery	5	13
87822	2020-06-30 20:23:19	2020-06-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1914	pick-up	0	23
87823	2020-06-30 20:27:44	2020-06-30	8	[{"id_menu":5,"count":1}]	34236	delivery	5	13
87824	2020-06-30 20:27:45	2020-06-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	5478	pick-up	0	21
87825	2020-06-30 20:31:06	2020-06-30	8	[{"id_menu":5,"count":1}]	3690	delivery	5	13
87826	2020-06-30 20:31:53	2020-06-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	13537	pick-up	0	23
87827	2020-06-30 20:40:04	2020-06-30	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33909	delivery	5	37
87828	2020-06-30 20:41:19	2020-06-30	8	[{"id_menu":5,"count":2}]	9855	delivery	5	13
87829	2020-06-30 20:42:11	2020-06-30	14	[{"id_menu":2,"count":1}]	1927	pick-up	0	14
87830	2020-06-30 20:42:55	2020-06-30	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	34257	delivery	5	39
87831	2020-06-30 20:43:20	2020-06-30	17	[{"id_menu":4,"count":1}]	19007	delivery	5	22
87832	2020-06-30 20:51:52	2020-06-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	33789	delivery	5	22
87833	2020-06-30 20:52:30	2020-06-30	17	[{"id_menu":4,"count":2}]	654	delivery	5	22
87834	2020-06-30 20:52:39	2020-06-30	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24788	delivery	5	40
87835	2020-06-30 20:54:49	2020-06-30	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	12793	delivery	5	28
87836	2020-06-30 20:56:34	2020-06-30	9	[{"id_menu":6,"count":1}]	440	delivery	5	14
87837	2020-06-30 21:01:23	2020-06-30	9	[{"id_menu":7,"count":1}]	34215	delivery	5	14
87838	2020-06-30 21:04:15	2020-06-30	9	[{"id_menu":6,"count":1}]	13153	delivery	5	14
87839	2020-06-30 21:05:58	2020-06-30	9	[{"id_menu":7,"count":1}]	34258	pick-up	0	9
87840	2020-06-30 21:07:01	2020-06-30	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	34324	delivery	5	34
87841	2020-06-30 21:07:17	2020-06-30	12	[{"id_menu":1,"count":1}]	34290	delivery	5	17
87842	2020-06-30 21:08:33	2020-06-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	8807	delivery	5	27
87843	2020-06-30 21:14:05	2020-06-30	9	[{"id_menu":6,"count":1}]	10721	delivery	5	14
87844	2020-06-30 21:16:22	2020-06-30	14	[{"id_menu":2,"count":1}]	12772	delivery	5	19
87845	2020-06-30 21:20:10	2020-06-30	9	[{"id_menu":7,"count":1}]	1568	pick-up	0	9
87846	2020-06-30 21:35:28	2020-06-30	9	[{"id_menu":6,"count":1}]	30864	pick-up	0	9
87847	2020-06-30 21:35:55	2020-06-30	9	[{"id_menu":7,"count":1}]	6039	pick-up	0	9
87848	2020-06-30 21:41:14	2020-06-30	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	32611	delivery	5	31
87849	2020-06-30 21:41:35	2020-06-30	9	[{"id_menu":7,"count":1}]	34351	delivery	5	14
87850	2020-06-30 21:41:42	2020-06-30	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	30189	delivery	5	40
87851	2020-06-30 21:43:52	2020-06-30	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	29113	delivery	5	25
87852	2020-06-30 21:44:12	2020-06-30	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":2}]	26279	delivery	5	22
87853	2020-06-30 21:54:43	2020-06-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	34287	delivery	5	28
87854	2020-06-30 21:58:51	2020-06-30	17	[{"id_menu":4,"count":1}]	9673	delivery	5	22
87855	2020-06-30 22:03:08	2020-06-30	9	[{"id_menu":7,"count":1}]	24423	delivery	5	14
87856	2020-06-30 22:05:43	2020-06-30	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	34379	delivery	5	40
87857	2020-06-30 22:07:56	2020-06-30	14	[{"id_menu":2,"count":1}]	28361	pick-up	0	14
87858	2020-06-30 22:13:02	2020-06-30	9	[{"id_menu":6,"count":1}]	22983	delivery	5	14
87859	2020-06-30 22:16:22	2020-06-30	9	[{"id_menu":6,"count":1}]	30592	delivery	5	14
87860	2020-06-30 22:17:31	2020-06-30	9	[{"id_menu":7,"count":1}]	8573	delivery	5	14
87861	2020-06-30 22:22:02	2020-06-30	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19372	delivery	5	51
87862	2020-06-30 22:23:26	2020-06-30	8	[{"id_menu":5,"count":1}]	15447	delivery	5	13
87863	2020-06-30 22:26:51	2020-06-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	32507	delivery	5	31
87864	2020-06-30 22:29:48	2020-06-30	9	[{"id_menu":6,"count":1}]	34181	delivery	5	14
87865	2020-06-30 22:32:00	2020-06-30	12	[{"id_menu":1,"count":1}]	6137	pick-up	0	12
87866	2020-06-30 22:32:36	2020-06-30	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7638	delivery	5	43
87867	2020-06-30 22:35:06	2020-06-30	17	[{"id_menu":4,"count":1}]	34383	delivery	5	22
87868	2020-06-30 22:36:39	2020-06-30	12	[{"id_menu":1,"count":1}]	2072	pick-up	0	12
87869	2020-06-30 22:37:06	2020-06-30	9	[{"id_menu":6,"count":1}]	8078	delivery	5	14
87870	2020-06-30 22:47:24	2020-06-30	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	34325	delivery	5	30
87871	2020-06-30 22:48:25	2020-06-30	9	[{"id_menu":7,"count":1}]	997	pick-up	0	9
87872	2020-06-30 22:50:58	2020-06-30	9	[{"id_menu":6,"count":1}]	34225	delivery	5	14
87873	2020-06-30 22:52:29	2020-06-30	17	[{"id_menu":4,"count":1}]	34052	delivery	5	22
87874	2020-06-30 22:53:10	2020-06-30	12	[{"id_menu":1,"count":1}]	34294	delivery	5	17
87875	2020-06-30 22:54:31	2020-06-30	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	34313	delivery	5	34
87876	2020-06-30 22:54:49	2020-06-30	9	[{"id_menu":6,"count":1}]	4395	pick-up	0	9
87877	2020-06-30 22:59:25	2020-06-30	9	[{"id_menu":7,"count":1}]	34203	delivery	5	14
87878	2020-06-30 23:00:03	2020-06-30	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2139	pick-up	0	26
87879	2020-06-30 23:00:16	2020-06-30	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2048	pick-up	0	25
87880	2020-06-30 23:04:26	2020-06-30	17	[{"id_menu":4,"count":1}]	34197	pick-up	0	17
87881	2020-06-30 23:25:10	2020-06-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	856	pick-up	0	23
87882	2020-06-30 23:29:43	2020-06-30	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	15234	delivery	5	28
87883	2020-06-30 23:42:40	2020-06-30	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18102	delivery	5	35
87884	2020-06-30 23:43:56	2020-06-30	12	[{"id_menu":3,"count":1}]	34309	delivery	5	17
87885	2020-06-30 23:46:17	2020-06-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	34284	delivery	5	22
87886	2020-06-30 23:49:12	2020-06-30	17	[{"id_menu":4,"count":1}]	29833	delivery	5	22
87887	2020-06-30 23:49:43	2020-06-30	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	34253	delivery	5	39
87888	2020-06-30 23:51:05	2020-06-30	17	[{"id_menu":4,"count":1}]	34279	delivery	5	22
87889	2020-06-30 23:55:42	2020-06-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12690	pick-up	0	18
87890	2020-06-30 23:58:19	2020-06-30	12	[{"id_menu":1,"count":1}]	399	pick-up	0	12
87891	2020-06-30 23:58:50	2020-06-30	9	[{"id_menu":6,"count":1}]	22285	delivery	5	14
87892	2020-07-01 00:02:05	2020-07-01	9	[{"id_menu":7,"count":1}]	28073	delivery	5	14
87893	2020-07-01 00:06:35	2020-07-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	34561	delivery	5	31
87894	2020-07-01 00:12:25	2020-07-01	17	[{"id_menu":4,"count":2}]	655	pick-up	0	17
87895	2020-07-01 00:12:30	2020-07-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1970	delivery	5	28
87896	2020-07-01 00:15:54	2020-07-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9531	pick-up	0	17
87897	2020-07-01 00:20:28	2020-07-01	8	[{"id_menu":5,"count":1}]	15818	pick-up	0	8
87898	2020-07-01 00:20:52	2020-07-01	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18210	delivery	5	35
87899	2020-07-01 00:21:18	2020-07-01	9	[{"id_menu":7,"count":1}]	34581	delivery	5	14
87900	2020-07-01 00:22:49	2020-07-01	9	[{"id_menu":6,"count":1}]	14800	delivery	5	14
87901	2020-07-01 00:23:29	2020-07-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	34391	delivery	5	22
87902	2020-07-01 00:23:49	2020-07-01	17	[{"id_menu":4,"count":1}]	34533	pick-up	0	17
87903	2020-07-01 00:23:58	2020-07-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	22214	pick-up	0	31
87904	2020-07-01 00:25:45	2020-07-01	12	[{"id_menu":1,"count":1}]	173	pick-up	0	12
87905	2020-07-01 00:33:22	2020-07-01	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	34498	delivery	5	26
87906	2020-07-01 00:35:26	2020-07-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	34465	delivery	5	22
87907	2020-07-01 00:37:06	2020-07-01	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	34531	delivery	5	38
87908	2020-07-01 00:39:19	2020-07-01	14	[{"id_menu":2,"count":1}]	3755	pick-up	0	14
87909	2020-07-01 00:42:38	2020-07-01	17	[{"id_menu":4,"count":1}]	28327	delivery	5	22
87910	2020-07-01 00:47:04	2020-07-01	9	[{"id_menu":6,"count":1}]	34580	delivery	5	14
87911	2020-07-01 00:47:38	2020-07-01	12	[{"id_menu":1,"count":1}]	5232	pick-up	0	12
87912	2020-07-01 00:49:34	2020-07-01	9	[{"id_menu":6,"count":1}]	12997	delivery	5	14
87913	2020-07-01 00:50:10	2020-07-01	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7899	delivery	5	57
87914	2020-07-01 00:57:06	2020-07-01	8	[{"id_menu":5,"count":1}]	26869	delivery	5	13
87915	2020-07-01 00:58:04	2020-07-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	11653	delivery	5	23
87916	2020-07-01 00:58:31	2020-07-01	9	[{"id_menu":6,"count":1}]	5162	pick-up	0	9
87917	2020-07-01 01:00:02	2020-07-01	17	[{"id_menu":4,"count":1}]	34563	pick-up	0	17
87918	2020-07-01 01:00:16	2020-07-01	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	14904	pick-up	0	20
87919	2020-07-01 01:00:27	2020-07-01	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14668	delivery	5	34
87920	2020-07-01 01:09:45	2020-07-01	9	[{"id_menu":7,"count":1}]	3752	pick-up	0	9
87921	2020-07-01 01:16:08	2020-07-01	12	[{"id_menu":1,"count":1}]	23880	pick-up	0	12
87922	2020-07-01 01:17:43	2020-07-01	17	[{"id_menu":4,"count":1}]	34434	pick-up	0	17
87923	2020-07-01 01:18:28	2020-07-01	12	[{"id_menu":3,"count":1}]	887	delivery	5	17
87924	2020-07-01 01:20:10	2020-07-01	8	[{"id_menu":5,"count":2}]	4590	pick-up	0	8
87925	2020-07-01 01:21:16	2020-07-01	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	120	delivery	5	31
87926	2020-07-01 01:23:10	2020-07-01	14	[{"id_menu":2,"count":1}]	34516	delivery	5	19
87927	2020-07-01 01:25:00	2020-07-01	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	26417	delivery	5	55
87928	2020-07-01 01:27:06	2020-07-01	9	[{"id_menu":7,"count":1}]	34567	delivery	5	14
87929	2020-07-01 01:28:51	2020-07-01	12	[{"id_menu":1,"count":1}]	9082	pick-up	0	12
87930	2020-07-01 01:31:22	2020-07-01	12	[{"id_menu":3,"count":1}]	12194	delivery	5	17
87931	2020-07-01 01:32:21	2020-07-01	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15188	delivery	5	54
87932	2020-07-01 01:40:47	2020-07-01	8	[{"id_menu":5,"count":1}]	34467	delivery	5	13
87933	2020-07-01 01:47:31	2020-07-01	17	[{"id_menu":4,"count":2}]	34524	delivery	5	22
87934	2020-07-01 01:53:37	2020-07-01	9	[{"id_menu":6,"count":1}]	3512	pick-up	0	9
87935	2020-07-01 01:55:15	2020-07-01	12	[{"id_menu":3,"count":1}]	46	delivery	5	17
87936	2020-07-01 02:00:09	2020-07-01	17	[{"id_menu":4,"count":1}]	29760	pick-up	0	17
87937	2020-07-01 02:01:56	2020-07-01	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4592	delivery	5	35
87938	2020-07-01 02:04:36	2020-07-01	8	[{"id_menu":5,"count":1}]	20840	delivery	5	13
87939	2020-07-01 02:07:34	2020-07-01	9	[{"id_menu":6,"count":1}]	12011	delivery	5	14
87940	2020-07-01 02:10:08	2020-07-01	8	[{"id_menu":5,"count":1}]	34081	delivery	5	13
87941	2020-07-01 02:13:53	2020-07-01	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5965	pick-up	0	26
87942	2020-07-01 02:14:55	2020-07-01	14	[{"id_menu":2,"count":1}]	34487	delivery	5	19
87943	2020-07-01 02:15:08	2020-07-01	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	30704	delivery	5	34
87944	2020-07-01 02:16:22	2020-07-01	12	[{"id_menu":3,"count":1}]	489	pick-up	0	12
87945	2020-07-01 02:17:22	2020-07-01	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	5240	delivery	5	31
87946	2020-07-01 02:18:55	2020-07-01	14	[{"id_menu":2,"count":1}]	21568	delivery	5	19
87947	2020-07-01 02:19:25	2020-07-01	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5540	delivery	5	43
87948	2020-07-01 02:22:19	2020-07-01	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16898	delivery	5	35
87949	2020-07-01 02:24:20	2020-07-01	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	1332	delivery	5	25
87950	2020-07-01 02:28:16	2020-07-01	17	[{"id_menu":4,"count":1}]	20583	delivery	5	22
87951	2020-07-01 02:34:09	2020-07-01	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9311	delivery	5	42
87952	2020-07-01 02:34:42	2020-07-01	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	34585	delivery	5	45
87953	2020-07-01 02:35:58	2020-07-01	14	[{"id_menu":2,"count":1}]	34534	delivery	5	19
87954	2020-07-01 02:36:35	2020-07-01	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	34508	delivery	5	40
87955	2020-07-01 02:40:13	2020-07-01	9	[{"id_menu":7,"count":1}]	13810	delivery	5	14
87956	2020-07-01 02:41:18	2020-07-01	14	[{"id_menu":2,"count":1}]	30200	delivery	5	19
87957	2020-07-01 02:42:54	2020-07-01	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	873	delivery	5	44
87958	2020-07-01 02:42:58	2020-07-01	17	[{"id_menu":4,"count":1}]	18283	delivery	5	22
87959	2020-07-01 02:44:50	2020-07-01	9	[{"id_menu":6,"count":1}]	34517	delivery	5	14
87960	2020-07-01 02:45:06	2020-07-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	27863	pick-up	0	18
87961	2020-07-01 02:46:01	2020-07-01	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	34394	delivery	5	27
87962	2020-07-01 02:46:36	2020-07-01	14	[{"id_menu":2,"count":2}]	30003	delivery	5	19
87963	2020-07-01 02:48:43	2020-07-01	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	15394	pick-up	0	38
87964	2020-07-01 02:48:58	2020-07-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	32457	delivery	5	28
87965	2020-07-01 02:48:58	2020-07-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1838	delivery	5	31
87966	2020-07-01 02:49:23	2020-07-01	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	13636	delivery	5	22
87967	2020-07-01 02:50:06	2020-07-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	34538	delivery	5	28
87968	2020-07-01 02:55:09	2020-07-01	12	[{"id_menu":3,"count":1}]	30697	pick-up	0	12
87969	2020-07-01 02:56:30	2020-07-01	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	9759	delivery	5	31
87970	2020-07-01 02:57:00	2020-07-01	8	[{"id_menu":5,"count":1}]	26325	delivery	5	13
87971	2020-07-01 02:57:21	2020-07-01	17	[{"id_menu":4,"count":1}]	31930	delivery	5	22
87972	2020-07-01 02:59:55	2020-07-01	8	[{"id_menu":5,"count":1}]	34520	pick-up	0	8
87973	2020-07-01 03:00:39	2020-07-01	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	34433	delivery	5	48
87974	2020-07-01 03:06:49	2020-07-01	12	[{"id_menu":1,"count":1}]	34388	delivery	5	17
87975	2020-07-01 03:07:20	2020-07-01	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1093	pick-up	0	29
87976	2020-07-01 03:07:24	2020-07-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	26052	delivery	5	26
87977	2020-07-01 03:08:53	2020-07-01	17	[{"id_menu":4,"count":1}]	8980	delivery	5	22
87978	2020-07-01 03:11:24	2020-07-01	12	[{"id_menu":1,"count":1}]	32848	pick-up	0	12
87979	2020-07-01 03:15:48	2020-07-01	17	[{"id_menu":4,"count":1}]	8021	delivery	5	22
87980	2020-07-01 03:16:17	2020-07-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	34401	delivery	5	22
87981	2020-07-01 03:18:51	2020-07-01	9	[{"id_menu":6,"count":1}]	24802	delivery	5	14
87982	2020-07-01 03:20:17	2020-07-01	14	[{"id_menu":2,"count":1}]	5503	pick-up	0	14
87983	2020-07-01 03:20:36	2020-07-01	12	[{"id_menu":1,"count":2}]	34452	pick-up	0	12
87984	2020-07-01 03:23:24	2020-07-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7614	delivery	5	22
87985	2020-07-01 03:31:02	2020-07-01	12	[{"id_menu":3,"count":1}]	3788	pick-up	0	12
87986	2020-07-01 03:36:16	2020-07-01	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29929	delivery	5	54
87987	2020-07-01 03:38:54	2020-07-01	9	[{"id_menu":6,"count":1}]	19207	delivery	5	14
87988	2020-07-01 03:40:18	2020-07-01	9	[{"id_menu":6,"count":1}]	7512	delivery	5	14
87989	2020-07-01 03:42:14	2020-07-01	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	34497	delivery	5	34
87990	2020-07-01 03:49:13	2020-07-01	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2	pick-up	0	29
87991	2020-07-01 03:49:52	2020-07-01	9	[{"id_menu":6,"count":1}]	34474	delivery	5	14
87992	2020-07-01 03:53:07	2020-07-01	9	[{"id_menu":6,"count":1}]	34511	delivery	5	14
87993	2020-07-01 03:58:02	2020-07-01	9	[{"id_menu":6,"count":1}]	18491	delivery	5	14
87994	2020-07-01 04:02:41	2020-07-01	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	26959	delivery	5	38
87995	2020-07-01 04:04:24	2020-07-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29951	delivery	5	22
87996	2020-07-01 04:04:51	2020-07-01	9	[{"id_menu":6,"count":1}]	4195	pick-up	0	9
87997	2020-07-01 04:08:48	2020-07-01	9	[{"id_menu":6,"count":1}]	34453	delivery	5	14
87998	2020-07-01 04:15:17	2020-07-01	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12726	delivery	5	36
87999	2020-07-01 04:15:40	2020-07-01	12	[{"id_menu":3,"count":1}]	13068	pick-up	0	12
88000	2020-07-01 04:21:06	2020-07-01	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	34569	delivery	5	43
88001	2020-07-01 04:22:47	2020-07-01	12	[{"id_menu":1,"count":1}]	14283	pick-up	0	12
88002	2020-07-01 04:22:50	2020-07-01	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	4373	delivery	5	48
88003	2020-07-01 04:25:49	2020-07-01	17	[{"id_menu":4,"count":1}]	3784	delivery	5	22
88004	2020-07-01 04:26:09	2020-07-01	14	[{"id_menu":2,"count":1}]	19925	pick-up	0	14
88005	2020-07-01 04:26:25	2020-07-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	20203	delivery	5	26
88006	2020-07-01 04:27:28	2020-07-01	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	25749	delivery	5	30
88007	2020-07-01 04:28:39	2020-07-01	17	[{"id_menu":4,"count":1}]	34537	delivery	5	22
88008	2020-07-01 04:29:27	2020-07-01	9	[{"id_menu":7,"count":1}]	25061	delivery	5	14
88009	2020-07-01 04:30:57	2020-07-01	17	[{"id_menu":4,"count":1}]	627	delivery	5	22
88010	2020-07-01 04:31:40	2020-07-01	9	[{"id_menu":7,"count":1}]	33265	pick-up	0	9
88011	2020-07-01 04:31:43	2020-07-01	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	27581	delivery	5	28
88012	2020-07-01 04:34:35	2020-07-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	12783	delivery	5	26
88013	2020-07-01 04:36:01	2020-07-01	12	[{"id_menu":1,"count":1}]	1257	pick-up	0	12
88014	2020-07-01 04:36:06	2020-07-01	9	[{"id_menu":7,"count":1}]	16330	pick-up	0	9
88015	2020-07-01 04:38:28	2020-07-01	12	[{"id_menu":3,"count":1}]	34425	delivery	5	17
88016	2020-07-01 04:38:50	2020-07-01	12	[{"id_menu":3,"count":1}]	147	delivery	5	17
88017	2020-07-01 04:48:12	2020-07-01	17	[{"id_menu":4,"count":1}]	22087	delivery	5	22
88018	2020-07-01 04:49:32	2020-07-01	14	[{"id_menu":2,"count":2}]	15815	delivery	5	19
88019	2020-07-01 04:55:22	2020-07-01	14	[{"id_menu":2,"count":1}]	16206	delivery	5	19
88020	2020-07-01 04:57:41	2020-07-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	34421	pick-up	0	21
88021	2020-07-01 04:59:36	2020-07-01	14	[{"id_menu":2,"count":1}]	1445	pick-up	0	14
88022	2020-07-01 05:10:47	2020-07-01	17	[{"id_menu":4,"count":1}]	12139	delivery	5	22
88023	2020-07-01 05:13:48	2020-07-01	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10246	delivery	5	37
88024	2020-07-01 05:15:54	2020-07-01	9	[{"id_menu":7,"count":1}]	13791	delivery	5	14
88025	2020-07-01 05:16:25	2020-07-01	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	30298	delivery	5	31
88026	2020-07-01 05:18:31	2020-07-01	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	27083	delivery	5	43
88027	2020-07-01 05:20:27	2020-07-01	12	[{"id_menu":1,"count":1}]	22626	pick-up	0	12
88028	2020-07-01 05:20:36	2020-07-01	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	34578	delivery	5	43
88029	2020-07-01 05:20:46	2020-07-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9076	delivery	5	22
88030	2020-07-01 05:20:48	2020-07-01	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3634	pick-up	0	26
88031	2020-07-01 05:20:50	2020-07-01	12	[{"id_menu":1,"count":1}]	34541	delivery	5	17
88032	2020-07-01 05:23:27	2020-07-01	9	[{"id_menu":6,"count":1}]	34442	delivery	5	14
88033	2020-07-01 05:25:37	2020-07-01	9	[{"id_menu":7,"count":1}]	30233	pick-up	0	9
88034	2020-07-01 05:27:09	2020-07-01	17	[{"id_menu":4,"count":1}]	20920	delivery	5	22
88035	2020-07-01 05:29:45	2020-07-01	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	24298	delivery	5	34
88036	2020-07-01 05:31:49	2020-07-01	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	34443	pick-up	0	26
88037	2020-07-01 05:35:51	2020-07-01	9	[{"id_menu":6,"count":1}]	34560	delivery	5	14
88038	2020-07-01 05:36:12	2020-07-01	12	[{"id_menu":3,"count":1}]	15798	pick-up	0	12
88039	2020-07-01 05:36:55	2020-07-01	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34414	delivery	5	52
88040	2020-07-01 05:38:26	2020-07-01	9	[{"id_menu":6,"count":1}]	27148	delivery	5	14
88041	2020-07-01 05:40:29	2020-07-01	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	34494	delivery	5	26
88042	2020-07-01 05:43:34	2020-07-01	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	30557	delivery	5	34
88043	2020-07-01 05:46:50	2020-07-01	17	[{"id_menu":4,"count":1}]	28434	delivery	5	22
88044	2020-07-01 05:50:03	2020-07-01	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	8074	delivery	5	36
88045	2020-07-01 05:52:26	2020-07-01	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	12850	delivery	5	36
88046	2020-07-01 05:55:17	2020-07-01	9	[{"id_menu":6,"count":1}]	34521	delivery	5	14
88047	2020-07-01 05:57:07	2020-07-01	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5235	delivery	5	31
88048	2020-07-01 05:57:31	2020-07-01	8	[{"id_menu":5,"count":1}]	5974	delivery	5	13
88049	2020-07-01 05:58:58	2020-07-01	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	34418	delivery	5	45
88050	2020-07-01 05:59:35	2020-07-01	8	[{"id_menu":5,"count":1}]	15296	delivery	5	13
88051	2020-07-01 06:03:01	2020-07-01	14	[{"id_menu":2,"count":1}]	2691	delivery	5	19
88052	2020-07-01 06:05:29	2020-07-01	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	34450	pick-up	0	26
88053	2020-07-01 06:06:55	2020-07-01	8	[{"id_menu":5,"count":2}]	31075	delivery	5	13
88054	2020-07-01 06:10:54	2020-07-01	8	[{"id_menu":5,"count":1}]	17500	delivery	5	13
88055	2020-07-01 06:12:56	2020-07-01	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19721	delivery	5	40
88056	2020-07-01 06:13:10	2020-07-01	12	[{"id_menu":1,"count":1}]	33503	delivery	5	17
88057	2020-07-01 06:13:27	2020-07-01	8	[{"id_menu":5,"count":1}]	12401	delivery	5	13
88058	2020-07-01 06:17:07	2020-07-01	8	[{"id_menu":5,"count":1}]	34512	delivery	5	13
88059	2020-07-01 06:20:39	2020-07-01	9	[{"id_menu":6,"count":1}]	8300	pick-up	0	9
88060	2020-07-01 06:21:52	2020-07-01	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34428	delivery	5	31
88061	2020-07-01 06:23:49	2020-07-01	12	[{"id_menu":3,"count":1}]	29673	delivery	5	17
88062	2020-07-01 06:27:22	2020-07-01	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	23084	pick-up	0	26
88063	2020-07-01 06:30:58	2020-07-01	12	[{"id_menu":3,"count":1}]	1637	delivery	5	17
88064	2020-07-01 06:37:17	2020-07-01	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	34422	delivery	5	29
88065	2020-07-01 06:39:34	2020-07-01	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	34473	delivery	5	40
88066	2020-07-01 06:40:05	2020-07-01	12	[{"id_menu":1,"count":1}]	3997	delivery	5	17
88067	2020-07-01 06:42:04	2020-07-01	12	[{"id_menu":1,"count":1}]	14661	pick-up	0	12
88068	2020-07-01 06:47:24	2020-07-01	17	[{"id_menu":4,"count":1}]	5434	delivery	5	22
88069	2020-07-01 06:51:42	2020-07-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2770	delivery	5	36
88070	2020-07-01 06:52:00	2020-07-01	8	[{"id_menu":5,"count":1}]	34398	delivery	5	13
88071	2020-07-01 06:55:21	2020-07-01	8	[{"id_menu":5,"count":1}]	12991	delivery	5	13
88072	2020-07-01 07:01:25	2020-07-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	13622	delivery	5	26
88073	2020-07-01 07:03:23	2020-07-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	34502	delivery	5	22
88074	2020-07-01 07:04:59	2020-07-01	9	[{"id_menu":6,"count":1}]	34454	delivery	5	14
88075	2020-07-01 07:06:05	2020-07-01	14	[{"id_menu":2,"count":1}]	17028	delivery	5	19
88076	2020-07-01 07:07:54	2020-07-01	8	[{"id_menu":5,"count":1}]	31682	pick-up	0	8
88077	2020-07-01 07:08:35	2020-07-01	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	25403	pick-up	0	22
88078	2020-07-01 07:09:17	2020-07-01	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	34522	delivery	5	34
88079	2020-07-01 07:12:15	2020-07-01	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	34588	delivery	5	31
88080	2020-07-01 07:12:28	2020-07-01	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	22905	delivery	5	34
88081	2020-07-01 07:13:28	2020-07-01	9	[{"id_menu":7,"count":1}]	4859	delivery	5	14
88082	2020-07-01 07:14:32	2020-07-01	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	29513	delivery	5	39
88083	2020-07-01 07:15:18	2020-07-01	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21105	delivery	5	45
88084	2020-07-01 07:15:57	2020-07-01	14	[{"id_menu":2,"count":1}]	10871	delivery	5	19
88085	2020-07-01 07:16:24	2020-07-01	9	[{"id_menu":7,"count":1}]	32942	delivery	5	14
88086	2020-07-01 07:17:14	2020-07-01	14	[{"id_menu":2,"count":1}]	2450	pick-up	0	14
88087	2020-07-01 07:20:03	2020-07-01	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9078	pick-up	0	26
88088	2020-07-01 07:20:07	2020-07-01	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	26108	delivery	5	26
88089	2020-07-01 07:22:32	2020-07-01	8	[{"id_menu":5,"count":2}]	21657	delivery	5	13
88090	2020-07-01 07:22:56	2020-07-01	14	[{"id_menu":2,"count":1}]	30751	pick-up	0	14
88091	2020-07-01 07:24:39	2020-07-01	17	[{"id_menu":4,"count":1}]	20329	delivery	5	22
88092	2020-07-01 07:28:39	2020-07-01	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	34491	delivery	5	57
88093	2020-07-01 07:30:04	2020-07-01	9	[{"id_menu":6,"count":1}]	34426	delivery	5	14
88094	2020-07-01 07:30:38	2020-07-01	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	26988	delivery	5	40
88095	2020-07-01 07:33:02	2020-07-01	14	[{"id_menu":2,"count":2}]	21151	delivery	5	19
88096	2020-07-01 07:33:55	2020-07-01	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	31757	delivery	5	26
88097	2020-07-01 07:34:38	2020-07-01	9	[{"id_menu":7,"count":1}]	28581	delivery	5	14
88098	2020-07-01 07:35:57	2020-07-01	8	[{"id_menu":5,"count":1}]	34590	delivery	5	13
88099	2020-07-01 07:38:11	2020-07-01	12	[{"id_menu":1,"count":1}]	34551	pick-up	0	12
88100	2020-07-01 07:40:58	2020-07-01	17	[{"id_menu":4,"count":1}]	21366	delivery	5	22
88101	2020-07-01 07:44:05	2020-07-01	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	34545	delivery	5	45
88102	2020-07-01 07:44:29	2020-07-01	9	[{"id_menu":6,"count":1}]	17669	delivery	5	14
88103	2020-07-01 07:46:45	2020-07-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	19566	delivery	5	26
88104	2020-07-01 07:48:54	2020-07-01	17	[{"id_menu":4,"count":1}]	6990	pick-up	0	17
88105	2020-07-01 07:49:22	2020-07-01	9	[{"id_menu":7,"count":1}]	25108	delivery	5	14
88106	2020-07-01 07:50:38	2020-07-01	12	[{"id_menu":1,"count":1}]	2995	delivery	5	17
88107	2020-07-01 07:51:05	2020-07-01	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32506	delivery	5	34
88108	2020-07-01 07:54:09	2020-07-01	32	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	11756	delivery	5	37
88109	2020-07-01 07:57:52	2020-07-01	17	[{"id_menu":4,"count":1}]	24931	delivery	5	22
88110	2020-07-01 07:57:54	2020-07-01	17	[{"id_menu":4,"count":1}]	34564	delivery	5	22
88111	2020-07-01 07:58:57	2020-07-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1059	delivery	5	22
88112	2020-07-01 08:02:28	2020-07-01	8	[{"id_menu":5,"count":2}]	1055	pick-up	0	8
88113	2020-07-01 08:10:02	2020-07-01	9	[{"id_menu":6,"count":1}]	20598	delivery	5	14
88114	2020-07-01 08:13:17	2020-07-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	34573	delivery	5	28
88115	2020-07-01 08:15:45	2020-07-01	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5654	delivery	5	34
88116	2020-07-01 08:18:45	2020-07-01	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34463	delivery	5	37
88117	2020-07-01 08:18:59	2020-07-01	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34565	delivery	5	37
88118	2020-07-01 08:21:23	2020-07-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	30371	delivery	5	31
88119	2020-07-01 08:21:56	2020-07-01	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	18823	delivery	5	31
88120	2020-07-01 08:22:38	2020-07-01	8	[{"id_menu":5,"count":1}]	11983	delivery	5	13
88121	2020-07-01 08:24:19	2020-07-01	12	[{"id_menu":3,"count":1}]	34543	delivery	5	17
88122	2020-07-01 08:27:59	2020-07-01	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17833	delivery	5	57
88123	2020-07-01 08:28:17	2020-07-01	14	[{"id_menu":2,"count":1}]	9793	pick-up	0	14
88124	2020-07-01 08:29:42	2020-07-01	12	[{"id_menu":3,"count":1}]	25365	delivery	5	17
88125	2020-07-01 08:30:30	2020-07-01	12	[{"id_menu":3,"count":1}]	23593	delivery	5	17
88126	2020-07-01 08:32:11	2020-07-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5768	delivery	5	23
88127	2020-07-01 08:39:07	2020-07-01	8	[{"id_menu":5,"count":1}]	34397	delivery	5	13
88128	2020-07-01 08:42:14	2020-07-01	14	[{"id_menu":2,"count":1}]	19346	delivery	5	19
88129	2020-07-01 08:42:19	2020-07-01	9	[{"id_menu":6,"count":1}]	7193	delivery	5	14
88130	2020-07-01 08:42:26	2020-07-01	9	[{"id_menu":7,"count":1}]	34423	delivery	5	14
88131	2020-07-01 08:43:20	2020-07-01	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	34544	delivery	5	51
88132	2020-07-01 08:43:32	2020-07-01	14	[{"id_menu":2,"count":1}]	14451	pick-up	0	14
88133	2020-07-01 08:43:53	2020-07-01	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11822	delivery	5	39
88134	2020-07-01 08:45:00	2020-07-01	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	34486	delivery	5	23
88135	2020-07-01 08:45:07	2020-07-01	9	[{"id_menu":7,"count":1}]	33789	delivery	5	14
88136	2020-07-01 08:48:10	2020-07-01	12	[{"id_menu":3,"count":1}]	4643	delivery	5	17
88137	2020-07-01 08:49:01	2020-07-01	12	[{"id_menu":3,"count":1}]	4312	pick-up	0	12
88138	2020-07-01 08:51:57	2020-07-01	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	22966	delivery	5	40
88139	2020-07-01 08:53:41	2020-07-01	17	[{"id_menu":4,"count":1}]	34449	delivery	5	22
88140	2020-07-01 08:58:21	2020-07-01	12	[{"id_menu":1,"count":2}]	520	pick-up	0	12
88141	2020-07-01 08:59:40	2020-07-01	9	[{"id_menu":6,"count":1}]	13984	pick-up	0	9
88142	2020-07-01 09:12:06	2020-07-01	9	[{"id_menu":7,"count":1}]	34224	delivery	5	14
88143	2020-07-01 09:15:10	2020-07-01	17	[{"id_menu":4,"count":1}]	33216	delivery	5	22
88144	2020-07-01 09:15:35	2020-07-01	9	[{"id_menu":6,"count":1}]	8306	delivery	5	14
88145	2020-07-01 09:16:29	2020-07-01	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	19460	delivery	5	34
88146	2020-07-01 09:20:17	2020-07-01	14	[{"id_menu":2,"count":1}]	34566	pick-up	0	14
88147	2020-07-01 09:26:04	2020-07-01	9	[{"id_menu":7,"count":1}]	1900	delivery	5	14
88148	2020-07-01 09:34:41	2020-07-01	9	[{"id_menu":7,"count":1}]	10796	delivery	5	14
88149	2020-07-01 09:37:06	2020-07-01	12	[{"id_menu":3,"count":1}]	34455	delivery	5	17
88150	2020-07-01 09:37:25	2020-07-01	9	[{"id_menu":6,"count":1}]	11004	delivery	5	14
88151	2020-07-01 09:38:20	2020-07-01	9	[{"id_menu":7,"count":1}]	2517	pick-up	0	9
88152	2020-07-01 09:39:33	2020-07-01	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	15334	delivery	5	26
88153	2020-07-01 09:40:12	2020-07-01	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23102	delivery	5	36
88154	2020-07-01 09:43:56	2020-07-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	1657	delivery	5	26
88155	2020-07-01 09:47:32	2020-07-01	9	[{"id_menu":7,"count":1}]	14415	delivery	5	14
88156	2020-07-01 09:50:09	2020-07-01	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	34436	delivery	5	31
88157	2020-07-01 09:53:34	2020-07-01	55	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	34415	pick-up	0	55
88158	2020-07-01 09:56:00	2020-07-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11887	pick-up	0	26
88159	2020-07-01 10:03:35	2020-07-01	17	[{"id_menu":4,"count":1}]	15482	pick-up	0	17
88160	2020-07-01 10:04:23	2020-07-01	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	34479	delivery	5	40
88161	2020-07-01 10:05:09	2020-07-01	12	[{"id_menu":1,"count":1}]	34575	pick-up	0	12
88162	2020-07-01 10:07:27	2020-07-01	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1106	pick-up	0	20
88163	2020-07-01 10:08:41	2020-07-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34429	delivery	5	23
88164	2020-07-01 10:11:18	2020-07-01	8	[{"id_menu":5,"count":1}]	34400	delivery	5	13
88165	2020-07-01 10:11:23	2020-07-01	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	19923	delivery	5	25
88166	2020-07-01 10:17:23	2020-07-01	9	[{"id_menu":7,"count":2}]	32063	pick-up	0	9
88167	2020-07-01 10:18:28	2020-07-01	9	[{"id_menu":7,"count":1}]	4673	delivery	5	14
88168	2020-07-01 10:18:30	2020-07-01	12	[{"id_menu":3,"count":1}]	10729	delivery	5	17
88169	2020-07-01 10:22:36	2020-07-01	17	[{"id_menu":5,"count":3},{"id_menu":7,"count":1}]	23415	delivery	5	22
88170	2020-07-01 10:23:14	2020-07-01	8	[{"id_menu":5,"count":1}]	22136	delivery	5	13
88171	2020-07-01 10:26:44	2020-07-01	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	17127	delivery	5	26
88172	2020-07-01 10:27:48	2020-07-01	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	18390	delivery	5	40
88173	2020-07-01 10:29:48	2020-07-01	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	5649	delivery	5	26
88174	2020-07-01 10:30:02	2020-07-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4870	pick-up	0	23
88175	2020-07-01 10:31:39	2020-07-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1107	delivery	5	26
88176	2020-07-01 10:32:20	2020-07-01	12	[{"id_menu":1,"count":1}]	34412	delivery	5	17
88177	2020-07-01 10:36:00	2020-07-01	14	[{"id_menu":2,"count":1}]	20697	delivery	5	19
88178	2020-07-01 10:42:50	2020-07-01	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	10287	pick-up	0	29
88179	2020-07-01 10:47:59	2020-07-01	12	[{"id_menu":1,"count":1}]	16774	delivery	5	17
88180	2020-07-01 10:48:02	2020-07-01	9	[{"id_menu":7,"count":1}]	28802	delivery	5	14
88181	2020-07-01 10:50:07	2020-07-01	12	[{"id_menu":3,"count":2}]	34162	delivery	5	17
88182	2020-07-01 10:52:24	2020-07-01	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1122	delivery	5	31
88183	2020-07-01 10:52:49	2020-07-01	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	32789	pick-up	0	29
88184	2020-07-01 10:58:19	2020-07-01	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	2264	delivery	5	25
88185	2020-07-01 11:00:53	2020-07-01	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6516	pick-up	0	25
88186	2020-07-01 11:04:11	2020-07-01	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	18901	delivery	5	56
88187	2020-07-01 11:04:57	2020-07-01	9	[{"id_menu":6,"count":1}]	3416	pick-up	0	9
88188	2020-07-01 11:06:47	2020-07-01	12	[{"id_menu":1,"count":1}]	34475	delivery	5	17
88189	2020-07-01 11:07:43	2020-07-01	9	[{"id_menu":6,"count":1}]	34402	delivery	5	14
88190	2020-07-01 11:07:54	2020-07-01	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	34552	delivery	5	31
88191	2020-07-01 11:10:54	2020-07-01	14	[{"id_menu":2,"count":1}]	34476	pick-up	0	14
88192	2020-07-01 11:14:19	2020-07-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	34459	delivery	5	22
88193	2020-07-01 11:23:35	2020-07-01	9	[{"id_menu":7,"count":1}]	11170	delivery	5	14
88194	2020-07-01 11:23:37	2020-07-01	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	20711	delivery	5	34
88195	2020-07-01 11:28:52	2020-07-01	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24673	delivery	5	48
88196	2020-07-01 11:33:24	2020-07-01	9	[{"id_menu":6,"count":1}]	21386	delivery	5	14
88197	2020-07-01 11:40:06	2020-07-01	17	[{"id_menu":4,"count":1}]	3785	delivery	5	22
88198	2020-07-01 11:41:36	2020-07-01	17	[{"id_menu":4,"count":1}]	34568	delivery	5	22
88199	2020-07-01 11:41:49	2020-07-01	9	[{"id_menu":6,"count":1}]	19969	pick-up	0	9
88200	2020-07-01 11:42:16	2020-07-01	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	34488	pick-up	0	21
88201	2020-07-01 11:46:28	2020-07-01	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	34587	delivery	5	40
88202	2020-07-01 11:51:10	2020-07-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12017	delivery	5	23
88203	2020-07-01 11:53:18	2020-07-01	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	34513	delivery	5	43
88204	2020-07-01 11:57:20	2020-07-01	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	572	pick-up	0	29
88205	2020-07-01 12:00:00	2020-07-01	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	33001	delivery	5	30
88206	2020-07-01 12:03:26	2020-07-01	9	[{"id_menu":6,"count":1}]	34548	delivery	5	14
88207	2020-07-01 12:05:03	2020-07-01	17	[{"id_menu":4,"count":1}]	29480	pick-up	0	17
88208	2020-07-01 12:11:23	2020-07-01	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	28657	delivery	5	23
88209	2020-07-01 12:12:01	2020-07-01	9	[{"id_menu":6,"count":1}]	18879	delivery	5	14
88210	2020-07-01 12:12:11	2020-07-01	17	[{"id_menu":4,"count":1}]	34514	delivery	5	22
88211	2020-07-01 12:12:52	2020-07-01	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	22820	delivery	5	23
88212	2020-07-01 12:17:12	2020-07-01	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	16165	delivery	5	26
88213	2020-07-01 12:33:08	2020-07-01	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	12275	delivery	5	34
88214	2020-07-01 12:36:47	2020-07-01	9	[{"id_menu":6,"count":1}]	30883	delivery	5	14
88215	2020-07-01 12:37:26	2020-07-01	8	[{"id_menu":5,"count":1}]	34562	delivery	5	13
88216	2020-07-01 12:38:46	2020-07-01	9	[{"id_menu":6,"count":1}]	23804	delivery	5	14
88217	2020-07-01 12:39:38	2020-07-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	26186	delivery	5	22
88218	2020-07-01 12:40:03	2020-07-01	9	[{"id_menu":7,"count":1}]	27082	pick-up	0	9
88219	2020-07-01 12:40:34	2020-07-01	17	[{"id_menu":4,"count":1}]	34480	delivery	5	22
88220	2020-07-01 12:50:22	2020-07-01	17	[{"id_menu":4,"count":1}]	34441	delivery	5	22
88221	2020-07-01 12:51:15	2020-07-01	14	[{"id_menu":2,"count":1}]	29739	delivery	5	19
88222	2020-07-01 12:52:17	2020-07-01	12	[{"id_menu":1,"count":1}]	34416	delivery	5	17
88223	2020-07-01 12:54:24	2020-07-01	17	[{"id_menu":4,"count":1}]	34430	pick-up	0	17
88224	2020-07-01 12:55:46	2020-07-01	8	[{"id_menu":5,"count":1}]	28658	delivery	5	13
88225	2020-07-01 12:58:07	2020-07-01	12	[{"id_menu":1,"count":1}]	27257	pick-up	0	12
88226	2020-07-01 13:01:05	2020-07-01	12	[{"id_menu":1,"count":1}]	6095	delivery	5	17
88227	2020-07-01 13:01:46	2020-07-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34395	delivery	5	23
88228	2020-07-01 13:02:35	2020-07-01	9	[{"id_menu":6,"count":1}]	5350	delivery	5	14
88229	2020-07-01 13:04:57	2020-07-01	9	[{"id_menu":7,"count":1}]	16367	delivery	5	14
88230	2020-07-01 13:06:03	2020-07-01	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	34457	delivery	5	42
88231	2020-07-01 13:07:34	2020-07-01	17	[{"id_menu":4,"count":1}]	34515	delivery	5	22
88232	2020-07-01 13:07:43	2020-07-01	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	14671	pick-up	0	24
88233	2020-07-01 13:08:46	2020-07-01	9	[{"id_menu":6,"count":2}]	34483	delivery	5	14
88234	2020-07-01 13:12:51	2020-07-01	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	11113	delivery	5	25
88235	2020-07-01 13:16:26	2020-07-01	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	18622	delivery	5	26
88236	2020-07-01 13:16:32	2020-07-01	9	[{"id_menu":6,"count":1}]	9443	delivery	5	14
88237	2020-07-01 13:17:58	2020-07-01	9	[{"id_menu":6,"count":1}]	33664	delivery	5	14
88238	2020-07-01 13:22:37	2020-07-01	12	[{"id_menu":1,"count":1}]	4223	pick-up	0	12
88239	2020-07-01 13:26:48	2020-07-01	17	[{"id_menu":4,"count":1}]	31738	delivery	5	22
88240	2020-07-01 13:30:58	2020-07-01	17	[{"id_menu":4,"count":1}]	23928	delivery	5	22
88241	2020-07-01 13:34:13	2020-07-01	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3940	pick-up	0	41
88242	2020-07-01 13:35:41	2020-07-01	12	[{"id_menu":3,"count":2}]	19911	pick-up	0	12
88243	2020-07-01 13:35:50	2020-07-01	12	[{"id_menu":1,"count":1}]	34431	delivery	5	17
88244	2020-07-01 13:36:02	2020-07-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	34586	delivery	5	26
88245	2020-07-01 13:44:21	2020-07-01	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	34572	delivery	5	36
88246	2020-07-01 13:48:21	2020-07-01	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	10274	delivery	5	31
88247	2020-07-01 13:49:07	2020-07-01	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10540	delivery	5	39
88248	2020-07-01 13:51:42	2020-07-01	17	[{"id_menu":5,"count":3},{"id_menu":6,"count":1}]	30302	delivery	5	22
88249	2020-07-01 13:52:55	2020-07-01	14	[{"id_menu":2,"count":1}]	34495	delivery	5	19
88250	2020-07-01 13:54:59	2020-07-01	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	21936	delivery	5	26
88251	2020-07-01 13:55:11	2020-07-01	12	[{"id_menu":1,"count":1}]	34518	delivery	5	17
88252	2020-07-01 13:55:15	2020-07-01	12	[{"id_menu":3,"count":1}]	34410	pick-up	0	12
88253	2020-07-01 13:55:24	2020-07-01	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	9057	pick-up	0	22
88254	2020-07-01 13:59:30	2020-07-01	14	[{"id_menu":2,"count":1}]	20216	pick-up	0	14
88255	2020-07-01 14:05:14	2020-07-01	14	[{"id_menu":2,"count":1}]	11205	delivery	5	19
88256	2020-07-01 14:05:24	2020-07-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	5253	pick-up	0	21
88257	2020-07-01 14:06:32	2020-07-01	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18356	delivery	5	47
88258	2020-07-01 14:16:52	2020-07-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5876	delivery	5	22
88259	2020-07-01 14:18:41	2020-07-01	9	[{"id_menu":6,"count":1}]	5550	delivery	5	14
88260	2020-07-01 14:19:39	2020-07-01	12	[{"id_menu":3,"count":1}]	340	pick-up	0	12
88261	2020-07-01 14:25:48	2020-07-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	34481	delivery	5	28
88262	2020-07-01 14:26:00	2020-07-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	34437	delivery	5	26
88263	2020-07-01 14:30:34	2020-07-01	14	[{"id_menu":2,"count":1}]	34510	delivery	5	19
88264	2020-07-01 14:30:38	2020-07-01	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	34503	delivery	5	31
88265	2020-07-01 14:30:50	2020-07-01	8	[{"id_menu":5,"count":1}]	33376	delivery	5	13
88266	2020-07-01 14:32:33	2020-07-01	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	34462	delivery	5	34
88267	2020-07-01 14:37:02	2020-07-01	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	34550	delivery	5	29
88268	2020-07-01 14:38:29	2020-07-01	9	[{"id_menu":6,"count":1}]	34013	delivery	5	14
88269	2020-07-01 14:39:02	2020-07-01	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5570	delivery	5	36
88270	2020-07-01 14:39:39	2020-07-01	9	[{"id_menu":6,"count":1}]	11674	delivery	5	14
88271	2020-07-01 14:43:16	2020-07-01	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	34591	delivery	5	25
88272	2020-07-01 14:45:22	2020-07-01	9	[{"id_menu":7,"count":1}]	30095	delivery	5	14
88273	2020-07-01 14:45:45	2020-07-01	12	[{"id_menu":3,"count":1}]	34472	delivery	5	17
88274	2020-07-01 14:45:53	2020-07-01	9	[{"id_menu":6,"count":1}]	33180	pick-up	0	9
88275	2020-07-01 14:50:31	2020-07-01	8	[{"id_menu":5,"count":1}]	29956	delivery	5	13
88276	2020-07-01 14:51:22	2020-07-01	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	34536	pick-up	0	29
88277	2020-07-01 14:51:23	2020-07-01	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8068	pick-up	0	25
88278	2020-07-01 14:56:52	2020-07-01	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	34413	delivery	5	40
88279	2020-07-01 15:01:06	2020-07-01	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	34535	delivery	5	26
88280	2020-07-01 15:03:11	2020-07-01	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22721	delivery	5	31
88281	2020-07-01 15:03:54	2020-07-01	8	[{"id_menu":5,"count":1}]	9358	delivery	5	13
88282	2020-07-01 15:05:05	2020-07-01	8	[{"id_menu":5,"count":1}]	14475	delivery	5	13
88283	2020-07-01 15:05:45	2020-07-01	14	[{"id_menu":2,"count":1}]	187	pick-up	0	14
88284	2020-07-01 15:10:01	2020-07-01	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15540	delivery	5	34
88285	2020-07-01 15:10:20	2020-07-01	12	[{"id_menu":3,"count":1}]	3812	pick-up	0	12
88286	2020-07-01 15:20:42	2020-07-01	9	[{"id_menu":7,"count":1}]	9642	delivery	5	14
88287	2020-07-01 15:21:19	2020-07-01	9	[{"id_menu":7,"count":1}]	27802	delivery	5	14
88288	2020-07-01 15:21:52	2020-07-01	12	[{"id_menu":1,"count":1}]	18743	pick-up	0	12
88289	2020-07-01 15:23:21	2020-07-01	8	[{"id_menu":5,"count":1}]	34432	delivery	5	13
88290	2020-07-01 15:27:45	2020-07-01	9	[{"id_menu":6,"count":1}]	9185	delivery	5	14
88291	2020-07-01 15:28:35	2020-07-01	9	[{"id_menu":7,"count":1}]	18440	delivery	5	14
88292	2020-07-01 15:29:22	2020-07-01	14	[{"id_menu":2,"count":1}]	24510	delivery	5	19
88293	2020-07-01 15:29:48	2020-07-01	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	9081	delivery	5	34
88294	2020-07-01 15:35:09	2020-07-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25847	delivery	5	23
88295	2020-07-01 15:38:35	2020-07-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	30723	delivery	5	28
88296	2020-07-01 15:39:17	2020-07-01	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18996	delivery	5	34
88297	2020-07-01 15:43:50	2020-07-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2041	pick-up	0	31
88298	2020-07-01 15:44:40	2020-07-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	34420	delivery	5	23
88299	2020-07-01 15:45:48	2020-07-01	8	[{"id_menu":5,"count":2}]	21257	delivery	5	13
88300	2020-07-01 15:46:28	2020-07-01	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	4912	delivery	5	26
88301	2020-07-01 15:46:37	2020-07-01	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	28731	delivery	5	39
88302	2020-07-01 15:51:20	2020-07-01	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	20869	delivery	5	26
88303	2020-07-01 15:53:42	2020-07-01	9	[{"id_menu":7,"count":1}]	27436	delivery	5	14
88304	2020-07-01 15:58:00	2020-07-01	14	[{"id_menu":2,"count":1}]	6282	delivery	5	19
88305	2020-07-01 16:01:54	2020-07-01	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	5087	delivery	5	40
88306	2020-07-01 16:04:26	2020-07-01	9	[{"id_menu":6,"count":1}]	34554	delivery	5	14
88307	2020-07-01 16:04:50	2020-07-01	9	[{"id_menu":7,"count":1}]	14592	delivery	5	14
88308	2020-07-01 16:06:36	2020-07-01	17	[{"id_menu":4,"count":1}]	34478	delivery	5	22
88309	2020-07-01 16:10:08	2020-07-01	12	[{"id_menu":3,"count":1}]	34485	delivery	5	17
88310	2020-07-01 16:12:04	2020-07-01	17	[{"id_menu":4,"count":1}]	30400	delivery	5	22
88311	2020-07-01 16:12:11	2020-07-01	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24487	delivery	5	34
88312	2020-07-01 16:12:43	2020-07-01	9	[{"id_menu":6,"count":1}]	21800	delivery	5	14
88313	2020-07-01 16:13:24	2020-07-01	8	[{"id_menu":5,"count":1}]	15480	delivery	5	13
88314	2020-07-01 16:20:32	2020-07-01	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34539	delivery	5	47
88315	2020-07-01 16:22:28	2020-07-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	12754	pick-up	0	23
88316	2020-07-01 16:23:01	2020-07-01	8	[{"id_menu":5,"count":1}]	20922	pick-up	0	8
88317	2020-07-01 16:24:03	2020-07-01	14	[{"id_menu":2,"count":1}]	23978	delivery	5	19
88318	2020-07-01 16:29:09	2020-07-01	8	[{"id_menu":5,"count":1}]	34547	delivery	5	13
88319	2020-07-01 16:30:39	2020-07-01	17	[{"id_menu":4,"count":1}]	34584	delivery	5	22
88320	2020-07-01 16:37:11	2020-07-01	9	[{"id_menu":6,"count":1}]	31550	delivery	5	14
88321	2020-07-01 16:38:09	2020-07-01	8	[{"id_menu":5,"count":1}]	34505	delivery	5	13
88322	2020-07-01 16:40:22	2020-07-01	12	[{"id_menu":1,"count":1}]	2672	pick-up	0	12
88323	2020-07-01 16:41:23	2020-07-01	9	[{"id_menu":6,"count":1}]	4922	delivery	5	14
88324	2020-07-01 16:43:32	2020-07-01	26	[{"id_menu":4,"count":3},{"id_menu":7,"count":1}]	34555	delivery	5	31
88325	2020-07-01 16:48:33	2020-07-01	12	[{"id_menu":1,"count":1}]	11761	delivery	5	17
88326	2020-07-01 16:54:20	2020-07-01	9	[{"id_menu":6,"count":1}]	34540	delivery	5	14
88327	2020-07-01 16:54:43	2020-07-01	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	34571	delivery	5	22
88328	2020-07-01 16:57:06	2020-07-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	25965	delivery	5	23
88329	2020-07-01 16:57:36	2020-07-01	17	[{"id_menu":4,"count":1}]	26456	delivery	5	22
88330	2020-07-01 16:58:08	2020-07-01	9	[{"id_menu":6,"count":2}]	25033	delivery	5	14
88331	2020-07-01 17:00:22	2020-07-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	34509	delivery	5	28
88332	2020-07-01 17:06:58	2020-07-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9554	delivery	5	22
88333	2020-07-01 17:08:11	2020-07-01	12	[{"id_menu":3,"count":1}]	10463	delivery	5	17
88334	2020-07-01 17:09:42	2020-07-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6366	delivery	5	31
88335	2020-07-01 17:11:38	2020-07-01	9	[{"id_menu":6,"count":2}]	34546	delivery	5	14
88336	2020-07-01 17:13:40	2020-07-01	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31983	delivery	5	39
88337	2020-07-01 17:14:46	2020-07-01	8	[{"id_menu":5,"count":1}]	34583	delivery	5	13
88338	2020-07-01 17:15:41	2020-07-01	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23353	delivery	5	37
88339	2020-07-01 17:20:54	2020-07-01	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34482	delivery	5	54
88340	2020-07-01 17:24:18	2020-07-01	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	27770	delivery	5	25
88341	2020-07-01 17:26:57	2020-07-01	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	8081	delivery	5	48
88342	2020-07-01 17:27:10	2020-07-01	17	[{"id_menu":4,"count":1}]	2021	pick-up	0	17
88343	2020-07-01 17:27:29	2020-07-01	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	25877	delivery	5	25
88344	2020-07-01 17:29:35	2020-07-01	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	31351	pick-up	0	20
88345	2020-07-01 17:31:52	2020-07-01	12	[{"id_menu":1,"count":1}]	15883	pick-up	0	12
88346	2020-07-01 17:32:47	2020-07-01	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	31679	delivery	5	42
88347	2020-07-01 17:33:29	2020-07-01	17	[{"id_menu":4,"count":2}]	29611	delivery	5	22
88348	2020-07-01 17:33:43	2020-07-01	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	11244	pick-up	0	22
88349	2020-07-01 17:34:47	2020-07-01	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	34389	delivery	5	40
88350	2020-07-01 17:35:10	2020-07-01	17	[{"id_menu":4,"count":1}]	26446	delivery	5	22
88351	2020-07-01 17:38:05	2020-07-01	17	[{"id_menu":4,"count":1}]	20196	delivery	5	22
88352	2020-07-01 17:39:27	2020-07-01	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	25247	delivery	5	48
88353	2020-07-01 17:39:56	2020-07-01	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	20905	pick-up	0	29
88354	2020-07-01 17:40:28	2020-07-01	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	28138	delivery	5	43
88355	2020-07-01 17:43:33	2020-07-01	17	[{"id_menu":4,"count":1}]	20672	delivery	5	22
88356	2020-07-01 17:44:59	2020-07-01	9	[{"id_menu":7,"count":1}]	11446	pick-up	0	9
88357	2020-07-01 17:49:08	2020-07-01	9	[{"id_menu":7,"count":1}]	2641	pick-up	0	9
88358	2020-07-01 17:50:51	2020-07-01	17	[{"id_menu":4,"count":1}]	34444	delivery	5	22
88359	2020-07-01 17:59:46	2020-07-01	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33402	delivery	5	35
88360	2020-07-01 18:07:03	2020-07-01	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	5420	delivery	5	39
88361	2020-07-01 18:08:31	2020-07-01	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	6155	delivery	5	29
88362	2020-07-01 18:09:49	2020-07-01	14	[{"id_menu":2,"count":1}]	34408	delivery	5	19
88363	2020-07-01 18:21:09	2020-07-01	14	[{"id_menu":2,"count":1}]	12924	delivery	5	19
88364	2020-07-01 18:24:09	2020-07-01	9	[{"id_menu":6,"count":1}]	25607	delivery	5	14
88365	2020-07-01 18:24:51	2020-07-01	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16765	pick-up	0	29
88366	2020-07-01 18:25:29	2020-07-01	17	[{"id_menu":4,"count":1}]	34393	delivery	5	22
88367	2020-07-01 18:27:09	2020-07-01	12	[{"id_menu":1,"count":1}]	10870	delivery	5	17
88368	2020-07-01 18:28:15	2020-07-01	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	34469	delivery	5	36
88369	2020-07-01 18:29:46	2020-07-01	9	[{"id_menu":6,"count":1}]	12070	pick-up	0	9
88370	2020-07-01 18:29:49	2020-07-01	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	34451	pick-up	0	26
88371	2020-07-01 18:32:58	2020-07-01	14	[{"id_menu":2,"count":1}]	22865	delivery	5	19
88372	2020-07-01 18:33:24	2020-07-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	27920	pick-up	0	23
88373	2020-07-01 18:34:53	2020-07-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27720	delivery	5	22
88374	2020-07-01 18:37:22	2020-07-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4659	pick-up	0	23
88375	2020-07-01 18:39:45	2020-07-01	9	[{"id_menu":7,"count":2}]	34409	delivery	5	14
88376	2020-07-01 18:45:06	2020-07-01	9	[{"id_menu":7,"count":1}]	8735	delivery	5	14
88377	2020-07-01 18:47:41	2020-07-01	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11189	pick-up	0	29
88378	2020-07-01 18:49:17	2020-07-01	9	[{"id_menu":7,"count":1}]	34435	delivery	5	14
88379	2020-07-01 18:49:46	2020-07-01	8	[{"id_menu":5,"count":2}]	34262	pick-up	0	8
88380	2020-07-01 18:51:37	2020-07-01	9	[{"id_menu":6,"count":1}]	16434	pick-up	0	9
88381	2020-07-01 18:52:03	2020-07-01	9	[{"id_menu":6,"count":1}]	19177	delivery	5	14
88382	2020-07-01 18:52:23	2020-07-01	12	[{"id_menu":1,"count":1}]	34577	delivery	5	17
88383	2020-07-01 18:53:45	2020-07-01	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	23172	delivery	5	25
88384	2020-07-01 18:54:02	2020-07-01	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	34484	delivery	5	43
88385	2020-07-01 18:54:56	2020-07-01	9	[{"id_menu":6,"count":1}]	16000	delivery	5	14
88386	2020-07-01 19:03:04	2020-07-01	17	[{"id_menu":4,"count":1}]	23238	delivery	5	22
88387	2020-07-01 19:03:26	2020-07-01	9	[{"id_menu":6,"count":2}]	17330	delivery	5	14
88388	2020-07-01 19:04:16	2020-07-01	9	[{"id_menu":6,"count":1}]	30209	pick-up	0	9
88389	2020-07-01 19:04:39	2020-07-01	8	[{"id_menu":5,"count":1}]	3294	delivery	5	13
88390	2020-07-01 19:04:42	2020-07-01	9	[{"id_menu":6,"count":1}]	26268	delivery	5	14
88391	2020-07-01 19:04:47	2020-07-01	9	[{"id_menu":6,"count":3}]	12410	delivery	5	14
88392	2020-07-01 19:08:30	2020-07-01	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	34399	delivery	5	40
88393	2020-07-01 19:12:00	2020-07-01	17	[{"id_menu":5,"count":3},{"id_menu":6,"count":1}]	34532	delivery	5	22
88394	2020-07-01 19:14:51	2020-07-01	9	[{"id_menu":7,"count":1}]	34556	delivery	5	14
88395	2020-07-01 19:15:24	2020-07-01	14	[{"id_menu":2,"count":1}]	16418	delivery	5	19
88396	2020-07-01 19:17:10	2020-07-01	9	[{"id_menu":7,"count":1}]	5325	delivery	5	14
88397	2020-07-01 19:18:49	2020-07-01	12	[{"id_menu":3,"count":1}]	2821	pick-up	0	12
88398	2020-07-01 19:22:19	2020-07-01	9	[{"id_menu":6,"count":1}]	34035	delivery	5	14
88399	2020-07-01 19:26:55	2020-07-01	9	[{"id_menu":6,"count":1}]	10516	delivery	5	14
88400	2020-07-01 19:33:05	2020-07-01	17	[{"id_menu":4,"count":1}]	219	pick-up	0	17
88401	2020-07-01 19:33:47	2020-07-01	12	[{"id_menu":1,"count":1}]	34582	pick-up	0	12
88402	2020-07-01 19:34:09	2020-07-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	10558	delivery	5	28
88403	2020-07-01 19:36:26	2020-07-01	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2575	delivery	5	25
88404	2020-07-01 19:37:49	2020-07-01	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	34439	delivery	5	46
88405	2020-07-01 19:38:03	2020-07-01	8	[{"id_menu":5,"count":1}]	14238	delivery	5	13
88406	2020-07-01 19:38:49	2020-07-01	14	[{"id_menu":2,"count":1}]	34576	delivery	5	19
88407	2020-07-01 19:41:09	2020-07-01	8	[{"id_menu":5,"count":1}]	34519	delivery	5	13
88408	2020-07-01 19:42:15	2020-07-01	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	17385	delivery	5	43
88409	2020-07-01 19:47:10	2020-07-01	9	[{"id_menu":6,"count":1}]	14326	delivery	5	14
88410	2020-07-01 19:51:14	2020-07-01	17	[{"id_menu":4,"count":1}]	620	delivery	5	22
88411	2020-07-01 19:57:06	2020-07-01	9	[{"id_menu":6,"count":2}]	30662	delivery	5	14
88412	2020-07-01 19:57:22	2020-07-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	2854	delivery	5	31
88413	2020-07-01 20:01:15	2020-07-01	9	[{"id_menu":6,"count":1}]	884	delivery	5	14
88414	2020-07-01 20:03:52	2020-07-01	9	[{"id_menu":6,"count":1}]	4798	delivery	5	14
88415	2020-07-01 20:04:00	2020-07-01	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6050	delivery	5	34
88416	2020-07-01 20:04:50	2020-07-01	12	[{"id_menu":1,"count":1}]	7794	delivery	5	17
88417	2020-07-01 20:04:55	2020-07-01	9	[{"id_menu":7,"count":1}]	9965	delivery	5	14
88418	2020-07-01 20:07:04	2020-07-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	34419	delivery	5	22
88419	2020-07-01 20:11:18	2020-07-01	8	[{"id_menu":5,"count":1}]	34458	pick-up	0	8
88420	2020-07-01 20:15:23	2020-07-01	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	34447	delivery	5	46
88421	2020-07-01 20:23:18	2020-07-01	8	[{"id_menu":5,"count":1}]	17664	delivery	5	13
88422	2020-07-01 20:24:15	2020-07-01	12	[{"id_menu":1,"count":1}]	21703	delivery	5	17
88423	2020-07-01 20:25:25	2020-07-01	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	18102	delivery	5	40
88424	2020-07-01 20:27:04	2020-07-01	17	[{"id_menu":4,"count":2}]	22383	pick-up	0	17
88425	2020-07-01 20:29:26	2020-07-01	9	[{"id_menu":7,"count":1}]	31411	delivery	5	14
88426	2020-07-01 20:37:24	2020-07-01	9	[{"id_menu":6,"count":1}]	34466	delivery	5	14
88427	2020-07-01 20:39:33	2020-07-01	9	[{"id_menu":6,"count":1}]	11480	delivery	5	14
88428	2020-07-01 20:39:44	2020-07-01	17	[{"id_menu":4,"count":1}]	34557	delivery	5	22
88429	2020-07-01 20:41:38	2020-07-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	12089	delivery	5	23
88430	2020-07-01 20:44:08	2020-07-01	17	[{"id_menu":4,"count":1}]	34468	delivery	5	22
88431	2020-07-01 20:45:01	2020-07-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	397	delivery	5	28
88432	2020-07-01 20:45:24	2020-07-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	29001	pick-up	0	23
88433	2020-07-01 20:50:33	2020-07-01	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":2}]	23339	delivery	5	22
88434	2020-07-01 20:52:09	2020-07-01	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	980	pick-up	0	20
88435	2020-07-01 20:54:26	2020-07-01	9	[{"id_menu":6,"count":1}]	34448	delivery	5	14
88436	2020-07-01 20:55:32	2020-07-01	12	[{"id_menu":1,"count":1}]	34528	delivery	5	17
88437	2020-07-01 20:55:40	2020-07-01	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	27271	delivery	5	40
88438	2020-07-01 20:56:36	2020-07-01	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	34492	delivery	5	39
88439	2020-07-01 20:57:58	2020-07-01	9	[{"id_menu":6,"count":1}]	17606	delivery	5	14
88440	2020-07-01 21:03:45	2020-07-01	14	[{"id_menu":2,"count":1}]	1072	pick-up	0	14
88441	2020-07-01 21:05:23	2020-07-01	8	[{"id_menu":5,"count":1}]	34529	delivery	5	13
88442	2020-07-01 21:10:27	2020-07-01	9	[{"id_menu":6,"count":1}]	13502	pick-up	0	9
88443	2020-07-01 21:11:59	2020-07-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1819	delivery	5	22
88444	2020-07-01 21:15:00	2020-07-01	9	[{"id_menu":6,"count":2}]	34542	delivery	5	14
88445	2020-07-01 21:15:38	2020-07-01	8	[{"id_menu":5,"count":1}]	24367	delivery	5	13
88446	2020-07-01 21:16:24	2020-07-01	9	[{"id_menu":7,"count":1}]	6406	delivery	5	14
88447	2020-07-01 21:21:16	2020-07-01	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	34438	delivery	5	42
88448	2020-07-01 21:27:37	2020-07-01	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	25358	delivery	5	30
88449	2020-07-01 21:28:53	2020-07-01	26	[{"id_menu":4,"count":3},{"id_menu":7,"count":1}]	15528	pick-up	0	26
88450	2020-07-01 21:34:27	2020-07-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	24954	delivery	5	31
88451	2020-07-01 21:35:17	2020-07-01	14	[{"id_menu":2,"count":1}]	4841	delivery	5	19
88452	2020-07-01 21:36:12	2020-07-01	9	[{"id_menu":6,"count":1}]	34499	delivery	5	14
88453	2020-07-01 21:36:29	2020-07-01	14	[{"id_menu":2,"count":1}]	34525	delivery	5	19
88454	2020-07-01 21:40:53	2020-07-01	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	34396	delivery	5	23
88455	2020-07-01 21:43:19	2020-07-01	9	[{"id_menu":6,"count":1}]	34523	delivery	5	14
88456	2020-07-01 21:44:16	2020-07-01	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7008	pick-up	0	37
88457	2020-07-01 21:44:26	2020-07-01	14	[{"id_menu":2,"count":1}]	17353	pick-up	0	14
88458	2020-07-01 21:44:42	2020-07-01	12	[{"id_menu":1,"count":1}]	4326	pick-up	0	12
88459	2020-07-01 21:48:12	2020-07-01	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	10418	delivery	5	40
88460	2020-07-01 21:51:03	2020-07-01	9	[{"id_menu":7,"count":1}]	34417	delivery	5	14
88461	2020-07-01 21:52:49	2020-07-01	14	[{"id_menu":2,"count":1}]	34403	delivery	5	19
88462	2020-07-01 21:52:50	2020-07-01	12	[{"id_menu":3,"count":1}]	24263	delivery	5	17
88463	2020-07-01 21:53:01	2020-07-01	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	20681	delivery	5	40
88464	2020-07-01 21:53:40	2020-07-01	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	34504	delivery	5	26
88465	2020-07-01 21:56:22	2020-07-01	17	[{"id_menu":4,"count":1}]	23272	pick-up	0	17
88466	2020-07-01 21:56:55	2020-07-01	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34407	pick-up	0	32
88467	2020-07-01 22:02:12	2020-07-01	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15061	delivery	5	35
88468	2020-07-01 22:03:06	2020-07-01	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	25941	delivery	5	43
88469	2020-07-01 22:03:38	2020-07-01	26	[{"id_menu":1,"count":3},{"id_menu":2,"count":1}]	2302	delivery	5	31
88470	2020-07-01 22:05:12	2020-07-01	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	19931	pick-up	0	21
88471	2020-07-01 22:06:51	2020-07-01	12	[{"id_menu":3,"count":1}]	6762	delivery	5	17
88472	2020-07-01 22:08:33	2020-07-01	9	[{"id_menu":7,"count":1}]	32970	delivery	5	14
88473	2020-07-01 22:08:50	2020-07-01	22	[{"id_menu":2,"count":3},{"id_menu":5,"count":1}]	34574	delivery	5	27
88474	2020-07-01 22:14:08	2020-07-01	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	16386	delivery	5	27
88475	2020-07-01 22:22:19	2020-07-01	12	[{"id_menu":3,"count":1}]	10340	delivery	5	17
88476	2020-07-01 22:23:19	2020-07-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2651	pick-up	0	23
88477	2020-07-01 22:25:07	2020-07-01	9	[{"id_menu":7,"count":1}]	2602	pick-up	0	9
88478	2020-07-01 22:27:23	2020-07-01	9	[{"id_menu":7,"count":1}]	28646	delivery	5	14
88479	2020-07-01 22:33:37	2020-07-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	5161	delivery	5	36
88480	2020-07-01 22:35:36	2020-07-01	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23700	delivery	5	34
88481	2020-07-01 22:37:35	2020-07-01	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9978	delivery	5	48
88482	2020-07-01 22:39:47	2020-07-01	12	[{"id_menu":1,"count":1}]	1591	delivery	5	17
88483	2020-07-01 22:42:36	2020-07-01	9	[{"id_menu":7,"count":1}]	3407	delivery	5	14
88484	2020-07-01 22:50:56	2020-07-01	17	[{"id_menu":4,"count":1}]	9907	pick-up	0	17
88485	2020-07-01 22:53:36	2020-07-01	14	[{"id_menu":2,"count":1}]	12685	delivery	5	19
88486	2020-07-01 22:58:01	2020-07-01	17	[{"id_menu":4,"count":1}]	34489	delivery	5	22
88487	2020-07-01 22:58:33	2020-07-01	14	[{"id_menu":2,"count":1}]	34440	delivery	5	19
88488	2020-07-01 22:58:43	2020-07-01	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	34500	delivery	5	43
88555	2020-07-02 01:35:31	2020-07-02	9	[{"id_menu":7,"count":1}]	13238	delivery	5	14
88489	2020-07-01 22:59:36	2020-07-01	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	34527	delivery	5	43
88490	2020-07-01 23:02:02	2020-07-01	9	[{"id_menu":6,"count":1}]	15109	pick-up	0	9
88491	2020-07-01 23:04:11	2020-07-01	14	[{"id_menu":2,"count":1}]	34390	delivery	5	19
88492	2020-07-01 23:12:13	2020-07-01	9	[{"id_menu":6,"count":1}]	1555	delivery	5	14
88493	2020-07-01 23:12:24	2020-07-01	9	[{"id_menu":7,"count":1}]	6645	pick-up	0	9
88494	2020-07-01 23:13:46	2020-07-01	14	[{"id_menu":2,"count":1}]	28904	delivery	5	19
88495	2020-07-01 23:14:49	2020-07-01	9	[{"id_menu":6,"count":1}]	14519	pick-up	0	9
88496	2020-07-01 23:19:38	2020-07-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	20455	delivery	5	28
88497	2020-07-01 23:20:25	2020-07-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	34411	delivery	5	26
88498	2020-07-01 23:21:02	2020-07-01	14	[{"id_menu":2,"count":1}]	29092	delivery	5	19
88499	2020-07-01 23:25:53	2020-07-01	12	[{"id_menu":1,"count":1}]	18777	delivery	5	17
88500	2020-07-01 23:26:45	2020-07-01	12	[{"id_menu":1,"count":1}]	14969	pick-up	0	12
88501	2020-07-01 23:27:23	2020-07-01	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32313	delivery	5	35
88502	2020-07-01 23:29:14	2020-07-01	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	21069	delivery	5	30
88503	2020-07-01 23:30:55	2020-07-01	9	[{"id_menu":7,"count":1}]	34427	delivery	5	14
88504	2020-07-01 23:31:08	2020-07-01	9	[{"id_menu":7,"count":1}]	34405	delivery	5	14
88505	2020-07-01 23:31:38	2020-07-01	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15796	delivery	5	54
88506	2020-07-01 23:32:11	2020-07-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	13676	delivery	5	31
88507	2020-07-01 23:33:36	2020-07-01	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	10675	delivery	5	37
88508	2020-07-01 23:34:43	2020-07-01	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	34406	delivery	5	34
88509	2020-07-01 23:35:49	2020-07-01	9	[{"id_menu":6,"count":2}]	34579	delivery	5	14
88510	2020-07-01 23:36:32	2020-07-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	31032	delivery	5	23
88511	2020-07-01 23:44:53	2020-07-01	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	31006	pick-up	0	29
88512	2020-07-01 23:46:23	2020-07-01	12	[{"id_menu":3,"count":1}]	21690	delivery	5	17
88513	2020-07-01 23:50:37	2020-07-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	34471	delivery	5	26
88514	2020-07-01 23:56:06	2020-07-01	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	16967	pick-up	0	26
88515	2020-07-02 00:07:12	2020-07-02	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	27777	pick-up	0	31
88516	2020-07-02 00:08:15	2020-07-02	9	[{"id_menu":7,"count":1}]	1055	delivery	5	14
88517	2020-07-02 00:08:30	2020-07-02	17	[{"id_menu":4,"count":1}]	29202	delivery	5	22
88518	2020-07-02 00:10:13	2020-07-02	9	[{"id_menu":7,"count":1}]	729	delivery	5	14
88519	2020-07-02 00:10:56	2020-07-02	9	[{"id_menu":6,"count":1}]	33547	delivery	5	14
88520	2020-07-02 00:13:18	2020-07-02	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	18413	delivery	5	43
88521	2020-07-02 00:14:20	2020-07-02	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	18147	pick-up	0	26
88522	2020-07-02 00:20:43	2020-07-02	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	27258	delivery	5	29
88523	2020-07-02 00:24:01	2020-07-02	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	17994	delivery	5	31
88524	2020-07-02 00:27:04	2020-07-02	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34613	delivery	5	31
88525	2020-07-02 00:27:16	2020-07-02	8	[{"id_menu":5,"count":1}]	33945	delivery	5	13
88526	2020-07-02 00:27:17	2020-07-02	12	[{"id_menu":3,"count":1}]	21121	pick-up	0	12
88527	2020-07-02 00:27:28	2020-07-02	8	[{"id_menu":5,"count":1}]	34664	delivery	5	13
88528	2020-07-02 00:27:36	2020-07-02	17	[{"id_menu":4,"count":1}]	34653	delivery	5	22
88529	2020-07-02 00:27:52	2020-07-02	17	[{"id_menu":4,"count":1}]	34689	delivery	5	22
88530	2020-07-02 00:28:31	2020-07-02	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	34736	delivery	5	31
88531	2020-07-02 00:30:13	2020-07-02	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	26256	delivery	5	31
88532	2020-07-02 00:32:32	2020-07-02	14	[{"id_menu":2,"count":1}]	10381	delivery	5	19
88533	2020-07-02 00:34:39	2020-07-02	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	34601	delivery	5	31
88534	2020-07-02 00:43:26	2020-07-02	9	[{"id_menu":6,"count":1}]	19473	delivery	5	14
88535	2020-07-02 00:43:35	2020-07-02	14	[{"id_menu":2,"count":1}]	19075	pick-up	0	14
88536	2020-07-02 00:47:36	2020-07-02	14	[{"id_menu":2,"count":1}]	122	pick-up	0	14
88537	2020-07-02 00:50:42	2020-07-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13977	delivery	5	23
88538	2020-07-02 00:57:37	2020-07-02	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8705	delivery	5	28
88539	2020-07-02 00:58:38	2020-07-02	12	[{"id_menu":1,"count":1}]	34624	delivery	5	17
88540	2020-07-02 00:59:46	2020-07-02	12	[{"id_menu":1,"count":1}]	19516	pick-up	0	12
88541	2020-07-02 01:00:44	2020-07-02	14	[{"id_menu":2,"count":1}]	2228	pick-up	0	14
88542	2020-07-02 01:01:24	2020-07-02	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	34720	delivery	5	36
88543	2020-07-02 01:01:46	2020-07-02	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	34640	delivery	5	26
88544	2020-07-02 01:08:54	2020-07-02	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	34708	delivery	5	40
88545	2020-07-02 01:10:23	2020-07-02	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6128	delivery	5	39
88546	2020-07-02 01:19:07	2020-07-02	9	[{"id_menu":6,"count":1}]	6549	delivery	5	14
88547	2020-07-02 01:19:59	2020-07-02	12	[{"id_menu":1,"count":1}]	34671	delivery	5	17
88548	2020-07-02 01:21:51	2020-07-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12604	delivery	5	23
88549	2020-07-02 01:22:14	2020-07-02	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18603	delivery	5	40
88550	2020-07-02 01:25:11	2020-07-02	9	[{"id_menu":7,"count":1}]	2237	pick-up	0	9
88551	2020-07-02 01:25:14	2020-07-02	14	[{"id_menu":2,"count":1}]	2575	pick-up	0	14
88552	2020-07-02 01:25:35	2020-07-02	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	25273	pick-up	0	43
88553	2020-07-02 01:34:53	2020-07-02	9	[{"id_menu":7,"count":1}]	20183	delivery	5	14
88554	2020-07-02 01:35:16	2020-07-02	9	[{"id_menu":6,"count":1}]	34610	delivery	5	14
88556	2020-07-02 01:36:45	2020-07-02	9	[{"id_menu":7,"count":1}]	11488	delivery	5	14
88557	2020-07-02 01:36:57	2020-07-02	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19173	delivery	5	31
88558	2020-07-02 01:38:25	2020-07-02	14	[{"id_menu":2,"count":1}]	13645	delivery	5	19
88559	2020-07-02 01:39:41	2020-07-02	14	[{"id_menu":2,"count":1}]	11908	delivery	5	19
88560	2020-07-02 01:43:11	2020-07-02	9	[{"id_menu":7,"count":1}]	34628	delivery	5	14
88561	2020-07-02 01:43:45	2020-07-02	8	[{"id_menu":5,"count":2}]	880	delivery	5	13
88562	2020-07-02 01:44:21	2020-07-02	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	2313	pick-up	0	21
88563	2020-07-02 01:48:08	2020-07-02	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	17603	delivery	5	27
88564	2020-07-02 01:49:31	2020-07-02	8	[{"id_menu":5,"count":1}]	34747	pick-up	0	8
88565	2020-07-02 01:52:00	2020-07-02	9	[{"id_menu":6,"count":1}]	6516	pick-up	0	9
88566	2020-07-02 01:55:40	2020-07-02	17	[{"id_menu":4,"count":1}]	31655	delivery	5	22
88567	2020-07-02 01:56:23	2020-07-02	17	[{"id_menu":4,"count":1}]	22842	delivery	5	22
88568	2020-07-02 01:59:53	2020-07-02	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	12027	delivery	5	22
88569	2020-07-02 02:01:04	2020-07-02	9	[{"id_menu":6,"count":1}]	1905	delivery	5	14
88570	2020-07-02 02:03:28	2020-07-02	9	[{"id_menu":7,"count":2}]	24299	delivery	5	14
88571	2020-07-02 02:04:45	2020-07-02	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	34710	pick-up	0	21
88572	2020-07-02 02:08:01	2020-07-02	14	[{"id_menu":2,"count":1}]	21273	pick-up	0	14
88573	2020-07-02 02:08:15	2020-07-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	31134	pick-up	0	23
88574	2020-07-02 02:11:27	2020-07-02	12	[{"id_menu":3,"count":1}]	23100	pick-up	0	12
88575	2020-07-02 02:14:15	2020-07-02	14	[{"id_menu":2,"count":1}]	17041	pick-up	0	14
88576	2020-07-02 02:16:43	2020-07-02	9	[{"id_menu":7,"count":1}]	10261	delivery	5	14
88577	2020-07-02 02:17:40	2020-07-02	14	[{"id_menu":2,"count":1}]	4624	pick-up	0	14
88578	2020-07-02 02:20:30	2020-07-02	12	[{"id_menu":3,"count":1}]	3148	pick-up	0	12
88579	2020-07-02 02:21:58	2020-07-02	12	[{"id_menu":3,"count":1}]	34657	delivery	5	17
88580	2020-07-02 02:22:35	2020-07-02	9	[{"id_menu":6,"count":1}]	1085	pick-up	0	9
88581	2020-07-02 02:23:58	2020-07-02	9	[{"id_menu":7,"count":1}]	9939	delivery	5	14
88582	2020-07-02 02:26:01	2020-07-02	9	[{"id_menu":7,"count":1}]	34756	delivery	5	14
88583	2020-07-02 02:28:18	2020-07-02	8	[{"id_menu":5,"count":1}]	19455	pick-up	0	8
88584	2020-07-02 02:30:54	2020-07-02	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2401	pick-up	0	26
88585	2020-07-02 02:31:59	2020-07-02	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	27096	delivery	5	26
88586	2020-07-02 02:35:41	2020-07-02	9	[{"id_menu":6,"count":1}]	3943	delivery	5	14
88587	2020-07-02 02:36:28	2020-07-02	12	[{"id_menu":1,"count":1}]	25827	pick-up	0	12
88588	2020-07-02 02:36:50	2020-07-02	9	[{"id_menu":6,"count":1}]	27961	pick-up	0	9
88589	2020-07-02 02:37:55	2020-07-02	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	20452	pick-up	0	21
88590	2020-07-02 02:38:33	2020-07-02	8	[{"id_menu":5,"count":1}]	34654	delivery	5	13
88591	2020-07-02 02:39:09	2020-07-02	9	[{"id_menu":7,"count":1}]	34758	delivery	5	14
88592	2020-07-02 02:40:37	2020-07-02	12	[{"id_menu":1,"count":1}]	1875	delivery	5	17
88593	2020-07-02 02:41:34	2020-07-02	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	26152	delivery	5	34
88594	2020-07-02 02:44:41	2020-07-02	9	[{"id_menu":6,"count":1}]	34709	delivery	5	14
88595	2020-07-02 02:45:14	2020-07-02	9	[{"id_menu":7,"count":1}]	3812	delivery	5	14
88596	2020-07-02 02:50:41	2020-07-02	12	[{"id_menu":3,"count":1}]	34655	delivery	5	17
88597	2020-07-02 02:55:03	2020-07-02	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	12761	delivery	5	44
88598	2020-07-02 03:04:43	2020-07-02	17	[{"id_menu":4,"count":1}]	34662	delivery	5	22
88599	2020-07-02 03:09:15	2020-07-02	9	[{"id_menu":6,"count":1}]	34639	pick-up	0	9
88600	2020-07-02 03:09:57	2020-07-02	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	34440	pick-up	0	23
88601	2020-07-02 03:13:24	2020-07-02	9	[{"id_menu":7,"count":1}]	2868	delivery	5	14
88602	2020-07-02 03:15:37	2020-07-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	30255	delivery	5	22
88603	2020-07-02 03:16:52	2020-07-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24037	delivery	5	23
88604	2020-07-02 03:17:36	2020-07-02	12	[{"id_menu":3,"count":1}]	11806	delivery	5	17
88605	2020-07-02 03:21:36	2020-07-02	14	[{"id_menu":2,"count":1}]	1884	pick-up	0	14
88606	2020-07-02 03:28:39	2020-07-02	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	33602	delivery	5	26
88607	2020-07-02 03:29:59	2020-07-02	30	[{"id_menu":3,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34704	delivery	5	35
88608	2020-07-02 03:33:08	2020-07-02	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34754	delivery	5	40
88609	2020-07-02 03:33:57	2020-07-02	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	7068	delivery	5	31
88610	2020-07-02 03:35:52	2020-07-02	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	24942	delivery	5	39
88611	2020-07-02 03:37:18	2020-07-02	9	[{"id_menu":7,"count":1}]	11242	delivery	5	14
88612	2020-07-02 03:43:05	2020-07-02	9	[{"id_menu":7,"count":1}]	10007	pick-up	0	9
88613	2020-07-02 03:45:08	2020-07-02	17	[{"id_menu":4,"count":1}]	26110	delivery	5	22
88614	2020-07-02 03:45:35	2020-07-02	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	17194	pick-up	0	23
88615	2020-07-02 03:46:03	2020-07-02	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11464	delivery	5	34
88616	2020-07-02 03:52:25	2020-07-02	14	[{"id_menu":2,"count":1}]	13321	delivery	5	19
88617	2020-07-02 03:55:41	2020-07-02	17	[{"id_menu":4,"count":1}]	14679	pick-up	0	17
88618	2020-07-02 04:00:50	2020-07-02	12	[{"id_menu":1,"count":1}]	376	pick-up	0	12
88619	2020-07-02 04:06:28	2020-07-02	17	[{"id_menu":4,"count":1}]	7407	pick-up	0	17
88620	2020-07-02 04:10:26	2020-07-02	17	[{"id_menu":4,"count":1}]	31260	delivery	5	22
88621	2020-07-02 04:11:32	2020-07-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	12951	delivery	5	23
88622	2020-07-02 04:12:38	2020-07-02	8	[{"id_menu":5,"count":1}]	6282	pick-up	0	8
88623	2020-07-02 04:16:11	2020-07-02	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	34752	pick-up	0	20
88624	2020-07-02 04:17:29	2020-07-02	14	[{"id_menu":2,"count":1}]	11237	delivery	5	19
88625	2020-07-02 04:25:16	2020-07-02	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	34661	delivery	5	30
88626	2020-07-02 04:25:39	2020-07-02	17	[{"id_menu":4,"count":1}]	34632	delivery	5	22
88627	2020-07-02 04:27:03	2020-07-02	9	[{"id_menu":6,"count":1}]	34597	pick-up	0	9
88628	2020-07-02 04:28:50	2020-07-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	26385	delivery	5	28
88629	2020-07-02 04:31:05	2020-07-02	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	24943	delivery	5	26
88630	2020-07-02 04:32:59	2020-07-02	9	[{"id_menu":6,"count":1}]	31800	delivery	5	14
88631	2020-07-02 04:38:20	2020-07-02	9	[{"id_menu":6,"count":1}]	34618	delivery	5	14
88632	2020-07-02 04:42:38	2020-07-02	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	34711	delivery	5	34
88633	2020-07-02 04:46:56	2020-07-02	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16773	delivery	5	22
88634	2020-07-02 04:47:58	2020-07-02	17	[{"id_menu":4,"count":1}]	10918	pick-up	0	17
88635	2020-07-02 04:51:01	2020-07-02	8	[{"id_menu":5,"count":1}]	34774	delivery	5	13
88636	2020-07-02 04:51:21	2020-07-02	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2101	pick-up	0	30
88637	2020-07-02 04:51:35	2020-07-02	9	[{"id_menu":6,"count":2}]	20900	delivery	5	14
88638	2020-07-02 04:52:31	2020-07-02	12	[{"id_menu":1,"count":1}]	1531	pick-up	0	12
88639	2020-07-02 04:54:58	2020-07-02	17	[{"id_menu":4,"count":1}]	24990	delivery	5	22
88640	2020-07-02 04:57:52	2020-07-02	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	34767	delivery	5	40
88641	2020-07-02 04:57:57	2020-07-02	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	14508	delivery	5	44
88642	2020-07-02 04:58:53	2020-07-02	17	[{"id_menu":4,"count":1}]	2646	pick-up	0	17
88643	2020-07-02 04:59:22	2020-07-02	9	[{"id_menu":6,"count":1}]	32174	delivery	5	14
88644	2020-07-02 05:00:11	2020-07-02	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	3838	delivery	5	36
88645	2020-07-02 05:00:53	2020-07-02	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	34603	delivery	5	35
88646	2020-07-02 05:04:24	2020-07-02	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	1700	pick-up	0	35
88647	2020-07-02 05:08:00	2020-07-02	14	[{"id_menu":2,"count":2}]	600	pick-up	0	14
88648	2020-07-02 05:14:45	2020-07-02	17	[{"id_menu":4,"count":1}]	16335	pick-up	0	17
88649	2020-07-02 05:16:05	2020-07-02	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	34660	delivery	5	26
88650	2020-07-02 05:16:10	2020-07-02	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	9191	pick-up	0	20
88651	2020-07-02 05:17:06	2020-07-02	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21861	delivery	5	40
88652	2020-07-02 05:21:23	2020-07-02	9	[{"id_menu":7,"count":1}]	34678	delivery	5	14
88653	2020-07-02 05:24:39	2020-07-02	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	5385	delivery	5	31
88654	2020-07-02 05:25:13	2020-07-02	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	6664	delivery	5	34
88655	2020-07-02 05:44:31	2020-07-02	12	[{"id_menu":1,"count":1}]	34625	delivery	5	17
88656	2020-07-02 05:46:04	2020-07-02	14	[{"id_menu":2,"count":1}]	1839	pick-up	0	14
88657	2020-07-02 05:47:28	2020-07-02	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	7902	delivery	5	23
88658	2020-07-02 05:50:29	2020-07-02	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	9947	pick-up	0	24
88659	2020-07-02 05:52:12	2020-07-02	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	34645	delivery	5	40
88660	2020-07-02 05:57:18	2020-07-02	9	[{"id_menu":6,"count":1}]	34759	delivery	5	14
88661	2020-07-02 05:57:38	2020-07-02	12	[{"id_menu":1,"count":1}]	34619	delivery	5	17
88662	2020-07-02 05:58:23	2020-07-02	12	[{"id_menu":3,"count":1}]	24937	pick-up	0	12
88663	2020-07-02 06:00:07	2020-07-02	9	[{"id_menu":6,"count":1}]	3736	delivery	5	14
88664	2020-07-02 06:03:14	2020-07-02	9	[{"id_menu":6,"count":1}]	28643	delivery	5	14
88665	2020-07-02 06:03:21	2020-07-02	17	[{"id_menu":4,"count":1}]	29399	delivery	5	22
88666	2020-07-02 06:05:51	2020-07-02	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13613	pick-up	0	49
88667	2020-07-02 06:07:43	2020-07-02	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	34737	delivery	5	28
88668	2020-07-02 06:09:43	2020-07-02	9	[{"id_menu":7,"count":1}]	21694	pick-up	0	9
88669	2020-07-02 06:10:26	2020-07-02	17	[{"id_menu":4,"count":1}]	676	pick-up	0	17
88670	2020-07-02 06:12:56	2020-07-02	9	[{"id_menu":7,"count":1}]	18146	delivery	5	14
88671	2020-07-02 06:15:55	2020-07-02	9	[{"id_menu":7,"count":1}]	34690	delivery	5	14
88672	2020-07-02 06:16:18	2020-07-02	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	31579	delivery	5	48
88673	2020-07-02 06:19:14	2020-07-02	12	[{"id_menu":3,"count":1}]	15582	pick-up	0	12
88674	2020-07-02 06:23:23	2020-07-02	9	[{"id_menu":6,"count":2}]	28056	pick-up	0	9
88675	2020-07-02 06:24:28	2020-07-02	8	[{"id_menu":5,"count":1}]	4669	delivery	5	13
88676	2020-07-02 06:25:32	2020-07-02	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":2}]	3125	delivery	5	27
88677	2020-07-02 06:26:41	2020-07-02	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	15590	pick-up	0	21
88678	2020-07-02 06:27:39	2020-07-02	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	34733	delivery	5	26
88679	2020-07-02 06:28:05	2020-07-02	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	34728	pick-up	0	22
88680	2020-07-02 06:30:59	2020-07-02	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	34611	delivery	5	30
88681	2020-07-02 06:36:27	2020-07-02	9	[{"id_menu":7,"count":1}]	14354	delivery	5	14
88682	2020-07-02 06:42:34	2020-07-02	9	[{"id_menu":7,"count":1}]	34741	delivery	5	14
88683	2020-07-02 06:46:25	2020-07-02	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	34764	delivery	5	36
88684	2020-07-02 06:47:03	2020-07-02	9	[{"id_menu":6,"count":1}]	34738	delivery	5	14
88685	2020-07-02 06:47:44	2020-07-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	34686	delivery	5	22
88686	2020-07-02 06:51:47	2020-07-02	9	[{"id_menu":7,"count":2}]	9303	pick-up	0	9
88687	2020-07-02 06:54:40	2020-07-02	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34713	delivery	5	37
88688	2020-07-02 06:55:32	2020-07-02	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	27020	delivery	5	27
88689	2020-07-02 06:55:55	2020-07-02	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8101	delivery	5	53
88690	2020-07-02 06:55:55	2020-07-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10575	delivery	5	23
88691	2020-07-02 06:57:48	2020-07-02	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	22463	delivery	5	29
88692	2020-07-02 06:59:09	2020-07-02	12	[{"id_menu":3,"count":1}]	3013	delivery	5	17
88693	2020-07-02 07:02:13	2020-07-02	17	[{"id_menu":4,"count":1}]	27484	delivery	5	22
88694	2020-07-02 07:04:11	2020-07-02	14	[{"id_menu":2,"count":1}]	8061	delivery	5	19
88695	2020-07-02 07:08:08	2020-07-02	17	[{"id_menu":4,"count":1}]	24940	delivery	5	22
88696	2020-07-02 07:09:04	2020-07-02	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	34730	delivery	5	22
88697	2020-07-02 07:10:35	2020-07-02	12	[{"id_menu":1,"count":1}]	11239	pick-up	0	12
88698	2020-07-02 07:15:59	2020-07-02	9	[{"id_menu":6,"count":1}]	34703	delivery	5	14
88699	2020-07-02 07:22:12	2020-07-02	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	18405	delivery	5	36
88700	2020-07-02 07:25:43	2020-07-02	14	[{"id_menu":2,"count":1}]	10576	delivery	5	19
88701	2020-07-02 07:27:13	2020-07-02	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	24916	delivery	5	27
88702	2020-07-02 07:27:42	2020-07-02	9	[{"id_menu":6,"count":1}]	8563	delivery	5	14
88703	2020-07-02 07:34:54	2020-07-02	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	10203	pick-up	0	29
88704	2020-07-02 07:38:32	2020-07-02	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	28491	delivery	5	28
88705	2020-07-02 07:40:29	2020-07-02	14	[{"id_menu":2,"count":1}]	14398	delivery	5	19
88706	2020-07-02 07:44:16	2020-07-02	9	[{"id_menu":7,"count":2}]	17118	delivery	5	14
88707	2020-07-02 07:46:47	2020-07-02	17	[{"id_menu":4,"count":1}]	28967	delivery	5	22
88708	2020-07-02 07:48:53	2020-07-02	17	[{"id_menu":4,"count":1}]	12336	delivery	5	22
88709	2020-07-02 07:51:17	2020-07-02	17	[{"id_menu":4,"count":1}]	9639	pick-up	0	17
88710	2020-07-02 07:51:34	2020-07-02	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	11124	pick-up	0	31
88711	2020-07-02 07:56:42	2020-07-02	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	11301	delivery	5	48
88712	2020-07-02 08:00:56	2020-07-02	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	23124	delivery	5	36
88713	2020-07-02 08:03:28	2020-07-02	9	[{"id_menu":7,"count":1}]	34627	pick-up	0	9
88714	2020-07-02 08:04:03	2020-07-02	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	6171	delivery	5	34
88715	2020-07-02 08:04:45	2020-07-02	9	[{"id_menu":6,"count":1}]	19771	delivery	5	14
88716	2020-07-02 08:06:28	2020-07-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	34612	pick-up	0	23
88717	2020-07-02 08:11:07	2020-07-02	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1555	pick-up	0	43
88718	2020-07-02 08:13:45	2020-07-02	17	[{"id_menu":4,"count":1}]	248	pick-up	0	17
88719	2020-07-02 08:14:01	2020-07-02	14	[{"id_menu":2,"count":1}]	13904	delivery	5	19
88720	2020-07-02 08:16:17	2020-07-02	8	[{"id_menu":5,"count":1}]	34595	delivery	5	13
88721	2020-07-02 08:18:54	2020-07-02	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	22175	delivery	5	34
88722	2020-07-02 08:23:20	2020-07-02	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28894	delivery	5	51
88723	2020-07-02 08:31:39	2020-07-02	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	654	delivery	5	22
88724	2020-07-02 08:37:12	2020-07-02	12	[{"id_menu":3,"count":1}]	28131	delivery	5	17
88725	2020-07-02 08:37:52	2020-07-02	9	[{"id_menu":6,"count":1}]	9817	pick-up	0	9
88726	2020-07-02 08:46:16	2020-07-02	8	[{"id_menu":5,"count":1}]	34753	pick-up	0	8
88727	2020-07-02 08:46:20	2020-07-02	8	[{"id_menu":5,"count":1}]	6617	pick-up	0	8
88728	2020-07-02 08:49:27	2020-07-02	9	[{"id_menu":7,"count":1}]	34693	delivery	5	14
88729	2020-07-02 08:50:31	2020-07-02	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13410	pick-up	0	32
88730	2020-07-02 08:52:30	2020-07-02	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34650	delivery	5	35
88731	2020-07-02 08:53:40	2020-07-02	9	[{"id_menu":6,"count":1}]	34672	delivery	5	14
88732	2020-07-02 08:57:54	2020-07-02	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	17627	delivery	5	26
88733	2020-07-02 08:59:27	2020-07-02	12	[{"id_menu":3,"count":1}]	14480	delivery	5	17
88734	2020-07-02 08:59:34	2020-07-02	9	[{"id_menu":7,"count":2}]	3689	delivery	5	14
88735	2020-07-02 09:00:40	2020-07-02	9	[{"id_menu":7,"count":1}]	16550	pick-up	0	9
88736	2020-07-02 09:02:13	2020-07-02	8	[{"id_menu":5,"count":1}]	12497	delivery	5	13
88737	2020-07-02 09:07:20	2020-07-02	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	34682	delivery	5	34
88738	2020-07-02 09:10:14	2020-07-02	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17626	delivery	5	43
88739	2020-07-02 09:20:33	2020-07-02	14	[{"id_menu":2,"count":1}]	2217	pick-up	0	14
88740	2020-07-02 09:21:52	2020-07-02	9	[{"id_menu":7,"count":1}]	34760	delivery	5	14
88741	2020-07-02 09:22:58	2020-07-02	17	[{"id_menu":4,"count":1}]	34700	delivery	5	22
88742	2020-07-02 09:26:32	2020-07-02	14	[{"id_menu":2,"count":2}]	34773	pick-up	0	14
88743	2020-07-02 09:29:30	2020-07-02	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	19809	delivery	5	28
88744	2020-07-02 09:30:28	2020-07-02	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	8287	delivery	5	26
88745	2020-07-02 09:33:21	2020-07-02	14	[{"id_menu":2,"count":1}]	33561	delivery	5	19
88746	2020-07-02 09:35:02	2020-07-02	9	[{"id_menu":7,"count":1}]	34762	delivery	5	14
88747	2020-07-02 09:36:09	2020-07-02	9	[{"id_menu":7,"count":1}]	13062	delivery	5	14
88748	2020-07-02 09:37:13	2020-07-02	8	[{"id_menu":5,"count":1}]	23333	pick-up	0	8
88749	2020-07-02 09:39:47	2020-07-02	8	[{"id_menu":5,"count":2}]	20276	delivery	5	13
88750	2020-07-02 09:40:00	2020-07-02	9	[{"id_menu":6,"count":1}]	20597	delivery	5	14
88751	2020-07-02 09:41:40	2020-07-02	8	[{"id_menu":5,"count":1}]	27301	delivery	5	13
88752	2020-07-02 09:47:05	2020-07-02	8	[{"id_menu":5,"count":1}]	12624	pick-up	0	8
88753	2020-07-02 09:48:26	2020-07-02	9	[{"id_menu":7,"count":1}]	16091	delivery	5	14
88754	2020-07-02 09:50:52	2020-07-02	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	30614	pick-up	0	25
88755	2020-07-02 09:51:20	2020-07-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	34721	delivery	5	23
88756	2020-07-02 09:52:45	2020-07-02	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	34648	delivery	5	26
88757	2020-07-02 09:54:06	2020-07-02	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	14668	delivery	5	56
88758	2020-07-02 09:55:20	2020-07-02	12	[{"id_menu":1,"count":1}]	19969	pick-up	0	12
88759	2020-07-02 10:12:01	2020-07-02	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	34646	delivery	5	31
88760	2020-07-02 10:18:40	2020-07-02	14	[{"id_menu":2,"count":1}]	24733	delivery	5	19
88761	2020-07-02 10:28:02	2020-07-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13930	pick-up	0	26
88762	2020-07-02 10:30:04	2020-07-02	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":3}]	31420	delivery	5	26
88763	2020-07-02 10:31:47	2020-07-02	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	28768	delivery	5	38
88764	2020-07-02 10:32:24	2020-07-02	14	[{"id_menu":2,"count":1}]	9570	delivery	5	19
88765	2020-07-02 10:32:39	2020-07-02	43	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	14175	delivery	5	48
88766	2020-07-02 10:35:14	2020-07-02	9	[{"id_menu":6,"count":1}]	20782	pick-up	0	9
88767	2020-07-02 10:35:34	2020-07-02	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	34716	delivery	5	22
88768	2020-07-02 10:36:44	2020-07-02	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	17333	delivery	5	28
88769	2020-07-02 10:37:16	2020-07-02	9	[{"id_menu":6,"count":1}]	34656	delivery	5	14
88770	2020-07-02 10:41:49	2020-07-02	9	[{"id_menu":6,"count":1}]	21606	pick-up	0	9
88771	2020-07-02 10:42:06	2020-07-02	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	30761	delivery	5	46
88772	2020-07-02 10:47:13	2020-07-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	25369	delivery	5	31
88773	2020-07-02 10:49:34	2020-07-02	14	[{"id_menu":2,"count":1}]	26547	delivery	5	19
88774	2020-07-02 10:50:53	2020-07-02	9	[{"id_menu":7,"count":1}]	34643	delivery	5	14
88775	2020-07-02 10:52:58	2020-07-02	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2167	pick-up	0	21
88776	2020-07-02 11:00:23	2020-07-02	9	[{"id_menu":7,"count":1}]	11104	delivery	5	14
88777	2020-07-02 11:04:22	2020-07-02	9	[{"id_menu":6,"count":1}]	11663	delivery	5	14
88778	2020-07-02 11:05:25	2020-07-02	17	[{"id_menu":4,"count":1}]	34751	pick-up	0	17
88779	2020-07-02 11:06:37	2020-07-02	12	[{"id_menu":3,"count":1}]	7186	delivery	5	17
88780	2020-07-02 11:06:54	2020-07-02	14	[{"id_menu":2,"count":1}]	4837	delivery	5	19
88781	2020-07-02 11:12:06	2020-07-02	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	8561	pick-up	0	26
88782	2020-07-02 11:18:28	2020-07-02	17	[{"id_menu":4,"count":1}]	8295	delivery	5	22
88783	2020-07-02 11:19:54	2020-07-02	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	27062	delivery	5	30
88784	2020-07-02 11:20:05	2020-07-02	14	[{"id_menu":2,"count":1}]	14190	pick-up	0	14
88785	2020-07-02 11:20:39	2020-07-02	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12615	delivery	5	31
88786	2020-07-02 11:22:47	2020-07-02	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	26780	delivery	5	43
88787	2020-07-02 11:23:19	2020-07-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6243	pick-up	0	26
88788	2020-07-02 11:25:31	2020-07-02	12	[{"id_menu":1,"count":2}]	34636	pick-up	0	12
88789	2020-07-02 11:25:34	2020-07-02	17	[{"id_menu":4,"count":1}]	27862	pick-up	0	17
88790	2020-07-02 11:27:08	2020-07-02	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	34692	delivery	5	22
88791	2020-07-02 11:27:13	2020-07-02	12	[{"id_menu":3,"count":1}]	34744	delivery	5	17
88792	2020-07-02 11:30:07	2020-07-02	17	[{"id_menu":4,"count":1}]	15196	delivery	5	22
88793	2020-07-02 11:30:25	2020-07-02	8	[{"id_menu":5,"count":1}]	34761	delivery	5	13
88794	2020-07-02 11:40:02	2020-07-02	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32344	delivery	5	35
88795	2020-07-02 11:45:15	2020-07-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	26634	delivery	5	22
88796	2020-07-02 11:46:42	2020-07-02	12	[{"id_menu":3,"count":1}]	8702	delivery	5	17
88797	2020-07-02 11:47:09	2020-07-02	14	[{"id_menu":2,"count":1}]	1244	pick-up	0	14
88798	2020-07-02 11:47:13	2020-07-02	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	21578	delivery	5	36
88799	2020-07-02 11:48:23	2020-07-02	17	[{"id_menu":4,"count":1}]	10436	pick-up	0	17
88800	2020-07-02 11:50:45	2020-07-02	9	[{"id_menu":6,"count":1}]	34684	delivery	5	14
88801	2020-07-02 11:51:14	2020-07-02	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	34724	pick-up	0	38
88802	2020-07-02 11:53:10	2020-07-02	12	[{"id_menu":3,"count":1}]	5026	delivery	5	17
88803	2020-07-02 11:53:19	2020-07-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	23285	delivery	5	31
88804	2020-07-02 11:54:58	2020-07-02	14	[{"id_menu":2,"count":1}]	34641	delivery	5	19
88805	2020-07-02 12:01:34	2020-07-02	12	[{"id_menu":3,"count":1}]	20224	delivery	5	17
88806	2020-07-02 12:01:57	2020-07-02	14	[{"id_menu":2,"count":1}]	25319	delivery	5	19
88807	2020-07-02 12:02:10	2020-07-02	17	[{"id_menu":4,"count":1}]	9728	pick-up	0	17
88808	2020-07-02 12:04:17	2020-07-02	17	[{"id_menu":4,"count":1}]	34712	delivery	5	22
88809	2020-07-02 12:05:41	2020-07-02	12	[{"id_menu":3,"count":3}]	14491	delivery	5	17
88810	2020-07-02 12:06:44	2020-07-02	12	[{"id_menu":3,"count":1}]	10706	delivery	5	17
88811	2020-07-02 12:10:23	2020-07-02	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	11550	delivery	5	52
88812	2020-07-02 12:11:36	2020-07-02	12	[{"id_menu":1,"count":1}]	34727	delivery	5	17
88813	2020-07-02 12:11:51	2020-07-02	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	33795	delivery	5	45
88814	2020-07-02 12:13:31	2020-07-02	9	[{"id_menu":6,"count":1}]	10425	pick-up	0	9
88815	2020-07-02 12:15:54	2020-07-02	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30173	delivery	5	35
88816	2020-07-02 12:19:43	2020-07-02	14	[{"id_menu":2,"count":1}]	22442	delivery	5	19
88817	2020-07-02 12:20:09	2020-07-02	17	[{"id_menu":4,"count":1}]	34722	delivery	5	22
88818	2020-07-02 12:21:41	2020-07-02	12	[{"id_menu":3,"count":1}]	34635	delivery	5	17
88819	2020-07-02 12:23:02	2020-07-02	12	[{"id_menu":3,"count":1}]	34757	pick-up	0	12
88820	2020-07-02 12:24:49	2020-07-02	17	[{"id_menu":4,"count":1}]	11155	delivery	5	22
88821	2020-07-02 12:29:42	2020-07-02	17	[{"id_menu":4,"count":1}]	8183	delivery	5	22
88822	2020-07-02 12:30:26	2020-07-02	9	[{"id_menu":7,"count":2}]	28114	delivery	5	14
88823	2020-07-02 12:31:42	2020-07-02	8	[{"id_menu":5,"count":1}]	23834	delivery	5	13
88824	2020-07-02 12:32:40	2020-07-02	12	[{"id_menu":1,"count":1}]	34687	delivery	5	17
88825	2020-07-02 12:33:32	2020-07-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32571	delivery	5	22
88826	2020-07-02 12:36:47	2020-07-02	14	[{"id_menu":2,"count":1}]	13335	delivery	5	19
88827	2020-07-02 12:40:34	2020-07-02	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	34729	delivery	5	34
88828	2020-07-02 12:40:59	2020-07-02	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":2}]	5164	pick-up	0	29
88829	2020-07-02 12:41:14	2020-07-02	12	[{"id_menu":1,"count":1}]	2885	delivery	5	17
88830	2020-07-02 12:45:22	2020-07-02	9	[{"id_menu":7,"count":1}]	3054	pick-up	0	9
88831	2020-07-02 12:46:17	2020-07-02	9	[{"id_menu":6,"count":1}]	24947	delivery	5	14
88832	2020-07-02 12:46:24	2020-07-02	9	[{"id_menu":7,"count":1}]	34765	delivery	5	14
88833	2020-07-02 12:46:53	2020-07-02	14	[{"id_menu":2,"count":1}]	34673	delivery	5	19
88834	2020-07-02 12:47:32	2020-07-02	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	33492	delivery	5	36
88835	2020-07-02 12:50:06	2020-07-02	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	21097	delivery	5	39
88836	2020-07-02 13:00:29	2020-07-02	8	[{"id_menu":5,"count":1}]	34598	delivery	5	13
88837	2020-07-02 13:01:17	2020-07-02	14	[{"id_menu":2,"count":1}]	17036	pick-up	0	14
88838	2020-07-02 13:01:32	2020-07-02	14	[{"id_menu":2,"count":1}]	34755	delivery	5	19
88839	2020-07-02 13:05:40	2020-07-02	17	[{"id_menu":4,"count":1}]	29405	delivery	5	22
88840	2020-07-02 13:07:24	2020-07-02	8	[{"id_menu":5,"count":1}]	2107	delivery	5	13
88841	2020-07-02 13:14:03	2020-07-02	14	[{"id_menu":2,"count":1}]	3949	pick-up	0	14
88842	2020-07-02 13:16:21	2020-07-02	9	[{"id_menu":6,"count":1}]	6695	delivery	5	14
88843	2020-07-02 13:23:05	2020-07-02	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	27808	delivery	5	26
88844	2020-07-02 13:25:31	2020-07-02	17	[{"id_menu":4,"count":1}]	32186	delivery	5	22
88845	2020-07-02 13:26:48	2020-07-02	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	29691	delivery	5	28
88846	2020-07-02 13:39:52	2020-07-02	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	31595	delivery	5	30
88847	2020-07-02 13:46:09	2020-07-02	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	28952	delivery	5	28
88848	2020-07-02 13:47:43	2020-07-02	8	[{"id_menu":5,"count":1}]	34701	delivery	5	13
88849	2020-07-02 13:48:12	2020-07-02	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	33421	delivery	5	36
88850	2020-07-02 13:48:43	2020-07-02	9	[{"id_menu":7,"count":2}]	19097	delivery	5	14
88851	2020-07-02 13:48:55	2020-07-02	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	25169	delivery	5	26
88852	2020-07-02 13:48:58	2020-07-02	9	[{"id_menu":7,"count":3}]	34620	delivery	5	14
88853	2020-07-02 13:49:16	2020-07-02	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	961	pick-up	0	26
88854	2020-07-02 13:50:59	2020-07-02	12	[{"id_menu":3,"count":1}]	12205	pick-up	0	12
88855	2020-07-02 13:51:13	2020-07-02	12	[{"id_menu":1,"count":1}]	34726	delivery	5	17
88856	2020-07-02 13:52:28	2020-07-02	8	[{"id_menu":5,"count":1}]	10820	delivery	5	13
88857	2020-07-02 13:52:35	2020-07-02	9	[{"id_menu":6,"count":1}]	22327	delivery	5	14
88858	2020-07-02 13:55:33	2020-07-02	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5093	delivery	5	44
88859	2020-07-02 13:56:46	2020-07-02	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	34669	delivery	5	39
88860	2020-07-02 14:00:49	2020-07-02	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	26294	delivery	5	39
88861	2020-07-02 14:02:02	2020-07-02	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	34596	delivery	5	31
88862	2020-07-02 14:02:03	2020-07-02	9	[{"id_menu":7,"count":1}]	34768	delivery	5	14
88863	2020-07-02 14:03:31	2020-07-02	12	[{"id_menu":3,"count":1}]	10200	delivery	5	17
88864	2020-07-02 14:06:06	2020-07-02	8	[{"id_menu":5,"count":1}]	7173	pick-up	0	8
88865	2020-07-02 14:06:19	2020-07-02	9	[{"id_menu":6,"count":1}]	2995	delivery	5	14
88866	2020-07-02 14:09:02	2020-07-02	14	[{"id_menu":2,"count":1}]	20534	delivery	5	19
88867	2020-07-02 14:09:48	2020-07-02	12	[{"id_menu":1,"count":1}]	34677	delivery	5	17
88868	2020-07-02 14:11:38	2020-07-02	17	[{"id_menu":4,"count":1}]	34714	delivery	5	22
88869	2020-07-02 14:21:11	2020-07-02	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	26528	delivery	5	26
88870	2020-07-02 14:24:09	2020-07-02	12	[{"id_menu":1,"count":1}]	10948	pick-up	0	12
88871	2020-07-02 14:27:54	2020-07-02	14	[{"id_menu":2,"count":1}]	34647	delivery	5	19
88872	2020-07-02 14:32:06	2020-07-02	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	27701	delivery	5	35
88873	2020-07-02 14:34:04	2020-07-02	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30707	delivery	5	37
88874	2020-07-02 14:42:06	2020-07-02	8	[{"id_menu":5,"count":1}]	34707	delivery	5	13
88875	2020-07-02 14:42:17	2020-07-02	12	[{"id_menu":1,"count":1}]	30689	delivery	5	17
88876	2020-07-02 14:52:01	2020-07-02	12	[{"id_menu":1,"count":1}]	7330	delivery	5	17
88877	2020-07-02 14:53:40	2020-07-02	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	21868	delivery	5	26
88878	2020-07-02 14:54:12	2020-07-02	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	12546	delivery	5	28
88879	2020-07-02 15:01:00	2020-07-02	26	[{"id_menu":4,"count":3},{"id_menu":6,"count":1}]	34665	delivery	5	31
88880	2020-07-02 15:01:22	2020-07-02	8	[{"id_menu":5,"count":1}]	34688	delivery	5	13
88881	2020-07-02 15:06:07	2020-07-02	9	[{"id_menu":6,"count":1}]	34746	delivery	5	14
88882	2020-07-02 15:07:50	2020-07-02	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	6760	delivery	5	26
88883	2020-07-02 15:08:02	2020-07-02	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32153	delivery	5	45
88884	2020-07-02 15:08:34	2020-07-02	8	[{"id_menu":5,"count":1}]	9005	delivery	5	13
88885	2020-07-02 15:09:16	2020-07-02	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	34629	pick-up	0	25
88886	2020-07-02 15:09:22	2020-07-02	8	[{"id_menu":5,"count":1}]	15769	delivery	5	13
88887	2020-07-02 15:11:05	2020-07-02	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	34600	delivery	5	26
88888	2020-07-02 15:13:13	2020-07-02	9	[{"id_menu":6,"count":1}]	34668	delivery	5	14
88889	2020-07-02 15:13:14	2020-07-02	9	[{"id_menu":6,"count":1}]	7361	delivery	5	14
88890	2020-07-02 15:14:22	2020-07-02	9	[{"id_menu":6,"count":1}]	34763	delivery	5	14
88891	2020-07-02 15:19:59	2020-07-02	14	[{"id_menu":2,"count":2}]	34633	delivery	5	19
88892	2020-07-02 15:21:06	2020-07-02	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	30349	delivery	5	42
88893	2020-07-02 15:23:09	2020-07-02	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34698	delivery	5	48
88894	2020-07-02 15:25:38	2020-07-02	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	16505	delivery	5	36
88895	2020-07-02 15:25:43	2020-07-02	17	[{"id_menu":4,"count":2}]	9899	delivery	5	22
88896	2020-07-02 15:27:14	2020-07-02	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17691	pick-up	0	44
88897	2020-07-02 15:29:55	2020-07-02	14	[{"id_menu":2,"count":1}]	17277	delivery	5	19
88898	2020-07-02 15:33:16	2020-07-02	9	[{"id_menu":6,"count":1}]	34637	delivery	5	14
88899	2020-07-02 15:33:16	2020-07-02	12	[{"id_menu":3,"count":1}]	339	delivery	5	17
88900	2020-07-02 15:34:39	2020-07-02	8	[{"id_menu":5,"count":1}]	34207	delivery	5	13
88901	2020-07-02 15:35:53	2020-07-02	9	[{"id_menu":7,"count":1}]	7979	delivery	5	14
88902	2020-07-02 15:39:32	2020-07-02	12	[{"id_menu":1,"count":2}]	3006	delivery	5	17
88903	2020-07-02 15:41:59	2020-07-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9563	delivery	5	28
88904	2020-07-02 15:42:20	2020-07-02	12	[{"id_menu":1,"count":1}]	32468	delivery	5	17
88905	2020-07-02 15:46:26	2020-07-02	14	[{"id_menu":2,"count":2}]	33843	pick-up	0	14
88906	2020-07-02 15:54:37	2020-07-02	9	[{"id_menu":6,"count":1}]	13940	pick-up	0	9
88907	2020-07-02 15:55:48	2020-07-02	17	[{"id_menu":4,"count":1}]	27082	delivery	5	22
88908	2020-07-02 15:56:10	2020-07-02	8	[{"id_menu":5,"count":1}]	17914	delivery	5	13
88909	2020-07-02 15:59:32	2020-07-02	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	34609	delivery	5	48
88910	2020-07-02 16:09:32	2020-07-02	17	[{"id_menu":4,"count":1}]	12404	pick-up	0	17
88911	2020-07-02 16:13:02	2020-07-02	9	[{"id_menu":6,"count":3}]	13223	delivery	5	14
88912	2020-07-02 16:17:03	2020-07-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	17030	delivery	5	22
88913	2020-07-02 16:17:24	2020-07-02	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	34615	delivery	5	36
88914	2020-07-02 16:19:09	2020-07-02	12	[{"id_menu":3,"count":1}]	23792	delivery	5	17
88915	2020-07-02 16:26:00	2020-07-02	17	[{"id_menu":4,"count":1}]	34766	delivery	5	22
88916	2020-07-02 16:26:57	2020-07-02	17	[{"id_menu":4,"count":1}]	6383	delivery	5	22
88917	2020-07-02 16:29:37	2020-07-02	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	10095	delivery	5	40
88918	2020-07-02 16:30:10	2020-07-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	34680	delivery	5	22
88919	2020-07-02 16:31:53	2020-07-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29478	delivery	5	23
88920	2020-07-02 16:32:43	2020-07-02	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	34740	delivery	5	25
88921	2020-07-02 16:34:06	2020-07-02	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	8372	delivery	5	31
88922	2020-07-02 16:34:27	2020-07-02	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6950	pick-up	0	25
88923	2020-07-02 16:38:15	2020-07-02	9	[{"id_menu":7,"count":1}]	7436	delivery	5	14
88924	2020-07-02 16:39:21	2020-07-02	14	[{"id_menu":2,"count":1}]	4578	pick-up	0	14
88925	2020-07-02 16:42:01	2020-07-02	9	[{"id_menu":6,"count":1}]	8755	delivery	5	14
88926	2020-07-02 16:43:49	2020-07-02	12	[{"id_menu":3,"count":1}]	25559	delivery	5	17
88927	2020-07-02 16:45:09	2020-07-02	8	[{"id_menu":5,"count":1}]	31071	delivery	5	13
88928	2020-07-02 16:45:25	2020-07-02	9	[{"id_menu":7,"count":1}]	34606	delivery	5	14
88929	2020-07-02 16:46:37	2020-07-02	9	[{"id_menu":6,"count":1}]	31945	delivery	5	14
88930	2020-07-02 16:48:13	2020-07-02	12	[{"id_menu":3,"count":1}]	9893	delivery	5	17
88931	2020-07-02 16:55:53	2020-07-02	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	34679	delivery	5	29
88932	2020-07-02 16:56:37	2020-07-02	8	[{"id_menu":5,"count":1}]	29039	delivery	5	13
88933	2020-07-02 17:01:22	2020-07-02	12	[{"id_menu":3,"count":1}]	2106	delivery	5	17
88934	2020-07-02 17:03:26	2020-07-02	9	[{"id_menu":6,"count":1}]	23054	delivery	5	14
88935	2020-07-02 17:09:01	2020-07-02	8	[{"id_menu":5,"count":1}]	34622	pick-up	0	8
88936	2020-07-02 17:13:49	2020-07-02	12	[{"id_menu":3,"count":1}]	34621	delivery	5	17
88937	2020-07-02 17:14:14	2020-07-02	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	22963	delivery	5	40
88938	2020-07-02 17:14:39	2020-07-02	17	[{"id_menu":4,"count":1}]	3428	delivery	5	22
88939	2020-07-02 17:14:51	2020-07-02	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	18863	delivery	5	25
88940	2020-07-02 17:23:59	2020-07-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	12415	pick-up	0	23
88941	2020-07-02 17:24:26	2020-07-02	9	[{"id_menu":7,"count":1}]	11230	delivery	5	14
88942	2020-07-02 17:24:29	2020-07-02	9	[{"id_menu":7,"count":1}]	18422	pick-up	0	9
88943	2020-07-02 17:24:50	2020-07-02	9	[{"id_menu":6,"count":1}]	28392	delivery	5	14
88944	2020-07-02 17:28:03	2020-07-02	8	[{"id_menu":5,"count":1}]	1290	pick-up	0	8
88945	2020-07-02 17:31:15	2020-07-02	9	[{"id_menu":7,"count":2}]	9920	pick-up	0	9
88946	2020-07-02 17:31:26	2020-07-02	9	[{"id_menu":6,"count":1}]	2893	delivery	5	14
88947	2020-07-02 17:32:00	2020-07-02	8	[{"id_menu":5,"count":1}]	34290	delivery	5	13
88948	2020-07-02 17:37:53	2020-07-02	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	34739	delivery	5	31
88949	2020-07-02 17:45:09	2020-07-02	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	25621	delivery	5	22
88950	2020-07-02 17:49:13	2020-07-02	12	[{"id_menu":3,"count":1}]	14735	pick-up	0	12
88951	2020-07-02 17:51:37	2020-07-02	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	29622	delivery	5	34
88952	2020-07-02 17:54:13	2020-07-02	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19927	delivery	5	22
88953	2020-07-02 17:55:13	2020-07-02	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	34743	delivery	5	39
88954	2020-07-02 17:59:03	2020-07-02	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	34667	delivery	5	36
88955	2020-07-02 18:03:17	2020-07-02	9	[{"id_menu":6,"count":1}]	28469	delivery	5	14
88956	2020-07-02 18:03:47	2020-07-02	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	11004	delivery	5	36
88957	2020-07-02 18:05:20	2020-07-02	8	[{"id_menu":5,"count":1}]	34592	delivery	5	13
88958	2020-07-02 18:10:34	2020-07-02	9	[{"id_menu":7,"count":1}]	23188	delivery	5	14
88959	2020-07-02 18:13:40	2020-07-02	8	[{"id_menu":5,"count":1}]	18733	pick-up	0	8
88960	2020-07-02 18:13:49	2020-07-02	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	23521	pick-up	0	20
88961	2020-07-02 18:15:04	2020-07-02	8	[{"id_menu":5,"count":1}]	10033	delivery	5	13
88962	2020-07-02 18:16:34	2020-07-02	17	[{"id_menu":4,"count":1}]	12381	delivery	5	22
88963	2020-07-02 18:18:54	2020-07-02	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	34696	pick-up	0	22
88964	2020-07-02 18:23:30	2020-07-02	14	[{"id_menu":2,"count":1}]	20780	delivery	5	19
88965	2020-07-02 18:24:31	2020-07-02	9	[{"id_menu":7,"count":1}]	6371	pick-up	0	9
88966	2020-07-02 18:24:58	2020-07-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8939	delivery	5	31
88967	2020-07-02 18:28:59	2020-07-02	14	[{"id_menu":2,"count":1}]	2056	pick-up	0	14
88968	2020-07-02 18:29:12	2020-07-02	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6792	delivery	5	36
88969	2020-07-02 18:30:49	2020-07-02	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9597	delivery	5	37
88970	2020-07-02 18:31:21	2020-07-02	17	[{"id_menu":4,"count":1}]	13319	pick-up	0	17
88971	2020-07-02 18:32:05	2020-07-02	17	[{"id_menu":4,"count":1}]	34699	delivery	5	22
88972	2020-07-02 18:33:02	2020-07-02	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	764	delivery	5	23
88973	2020-07-02 18:34:32	2020-07-02	12	[{"id_menu":1,"count":1}]	34644	delivery	5	17
88974	2020-07-02 18:36:04	2020-07-02	14	[{"id_menu":2,"count":1}]	34723	delivery	5	19
88975	2020-07-02 18:38:29	2020-07-02	14	[{"id_menu":2,"count":1}]	34593	delivery	5	19
88976	2020-07-02 18:38:59	2020-07-02	8	[{"id_menu":5,"count":1}]	32347	delivery	5	13
88977	2020-07-02 18:39:18	2020-07-02	8	[{"id_menu":5,"count":2}]	32817	delivery	5	13
88978	2020-07-02 18:41:23	2020-07-02	9	[{"id_menu":7,"count":3}]	27180	delivery	5	14
88979	2020-07-02 18:42:35	2020-07-02	14	[{"id_menu":2,"count":1}]	1460	pick-up	0	14
88980	2020-07-02 18:49:52	2020-07-02	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	28181	delivery	5	28
88981	2020-07-02 18:50:15	2020-07-02	12	[{"id_menu":1,"count":1}]	34731	delivery	5	17
88982	2020-07-02 18:52:49	2020-07-02	14	[{"id_menu":2,"count":1}]	11642	delivery	5	19
88983	2020-07-02 18:53:07	2020-07-02	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	195	delivery	5	40
88984	2020-07-02 18:56:27	2020-07-02	8	[{"id_menu":5,"count":1}]	5046	delivery	5	13
88985	2020-07-02 19:02:22	2020-07-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	34772	delivery	5	31
88986	2020-07-02 19:05:42	2020-07-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2000	pick-up	0	26
88987	2020-07-02 19:07:02	2020-07-02	9	[{"id_menu":7,"count":1}]	23952	delivery	5	14
88988	2020-07-02 19:07:33	2020-07-02	9	[{"id_menu":6,"count":1}]	34599	delivery	5	14
88989	2020-07-02 19:10:44	2020-07-02	12	[{"id_menu":1,"count":1}]	21334	pick-up	0	12
88990	2020-07-02 19:10:57	2020-07-02	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11822	delivery	5	22
88991	2020-07-02 19:12:13	2020-07-02	12	[{"id_menu":1,"count":1}]	11844	delivery	5	17
88992	2020-07-02 19:13:54	2020-07-02	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	33667	pick-up	0	17
88993	2020-07-02 19:13:58	2020-07-02	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5271	delivery	5	45
88994	2020-07-02 19:14:15	2020-07-02	17	[{"id_menu":4,"count":1}]	30489	pick-up	0	17
88995	2020-07-02 19:14:51	2020-07-02	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	5811	delivery	5	29
88996	2020-07-02 19:17:14	2020-07-02	12	[{"id_menu":3,"count":1}]	25780	delivery	5	17
88997	2020-07-02 19:17:19	2020-07-02	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	28729	delivery	5	42
88998	2020-07-02 19:17:32	2020-07-02	14	[{"id_menu":2,"count":1}]	20387	delivery	5	19
88999	2020-07-02 19:17:54	2020-07-02	14	[{"id_menu":2,"count":1}]	34651	delivery	5	19
89000	2020-07-02 19:22:00	2020-07-02	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	27053	delivery	5	30
89001	2020-07-02 19:27:09	2020-07-02	8	[{"id_menu":5,"count":1}]	15962	delivery	5	13
89002	2020-07-02 19:27:59	2020-07-02	14	[{"id_menu":2,"count":1}]	27187	pick-up	0	14
89003	2020-07-02 19:28:18	2020-07-02	12	[{"id_menu":1,"count":1}]	8876	delivery	5	17
89004	2020-07-02 19:30:27	2020-07-02	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	6302	delivery	5	34
89005	2020-07-02 19:31:17	2020-07-02	9	[{"id_menu":7,"count":1}]	31618	pick-up	0	9
89006	2020-07-02 19:32:17	2020-07-02	9	[{"id_menu":7,"count":1}]	11563	delivery	5	14
89007	2020-07-02 19:35:31	2020-07-02	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	2477	pick-up	0	32
89008	2020-07-02 19:36:59	2020-07-02	14	[{"id_menu":2,"count":1}]	21277	delivery	5	19
89009	2020-07-02 19:44:57	2020-07-02	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24842	delivery	5	51
89010	2020-07-02 19:48:35	2020-07-02	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	477	pick-up	0	21
89011	2020-07-02 19:49:24	2020-07-02	8	[{"id_menu":5,"count":1}]	10331	pick-up	0	8
89012	2020-07-02 19:49:32	2020-07-02	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	23695	delivery	5	29
89013	2020-07-02 19:51:01	2020-07-02	12	[{"id_menu":3,"count":1}]	21678	pick-up	0	12
89014	2020-07-02 19:58:20	2020-07-02	9	[{"id_menu":6,"count":1}]	7428	delivery	5	14
89015	2020-07-02 19:59:15	2020-07-02	17	[{"id_menu":4,"count":1}]	12749	delivery	5	22
89016	2020-07-02 19:59:57	2020-07-02	14	[{"id_menu":2,"count":1}]	34732	delivery	5	19
89017	2020-07-02 20:03:26	2020-07-02	9	[{"id_menu":6,"count":1}]	3827	delivery	5	14
89018	2020-07-02 20:03:55	2020-07-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	19233	pick-up	0	23
89019	2020-07-02 20:06:05	2020-07-02	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	33755	delivery	5	25
89020	2020-07-02 20:07:12	2020-07-02	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	32300	delivery	5	43
89021	2020-07-02 20:08:48	2020-07-02	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	34091	pick-up	0	29
89022	2020-07-02 20:10:28	2020-07-02	9	[{"id_menu":6,"count":1}]	29670	delivery	5	14
89023	2020-07-02 20:11:00	2020-07-02	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	19102	delivery	5	31
89024	2020-07-02 20:13:25	2020-07-02	14	[{"id_menu":2,"count":1}]	32121	pick-up	0	14
89025	2020-07-02 20:19:58	2020-07-02	9	[{"id_menu":6,"count":1}]	9538	pick-up	0	9
89026	2020-07-02 20:23:10	2020-07-02	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	34674	delivery	5	28
89027	2020-07-02 20:23:23	2020-07-02	9	[{"id_menu":6,"count":1}]	16952	delivery	5	14
89028	2020-07-02 20:25:44	2020-07-02	9	[{"id_menu":7,"count":1}]	17653	delivery	5	14
89029	2020-07-02 20:30:13	2020-07-02	17	[{"id_menu":4,"count":1}]	3558	delivery	5	22
89030	2020-07-02 20:31:54	2020-07-02	9	[{"id_menu":7,"count":1}]	11455	delivery	5	14
89031	2020-07-02 20:32:03	2020-07-02	14	[{"id_menu":2,"count":1}]	4094	delivery	5	19
89032	2020-07-02 20:33:11	2020-07-02	12	[{"id_menu":3,"count":1}]	10457	delivery	5	17
89033	2020-07-02 20:34:21	2020-07-02	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1245	pick-up	0	25
89034	2020-07-02 20:36:01	2020-07-02	14	[{"id_menu":2,"count":1}]	11674	delivery	5	19
89035	2020-07-02 20:44:21	2020-07-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	30371	delivery	5	28
89036	2020-07-02 20:48:38	2020-07-02	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7989	delivery	5	35
89037	2020-07-02 20:48:54	2020-07-02	8	[{"id_menu":5,"count":1}]	17989	delivery	5	13
89038	2020-07-02 20:49:30	2020-07-02	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	34623	delivery	5	34
89039	2020-07-02 20:56:03	2020-07-02	8	[{"id_menu":5,"count":1}]	34683	delivery	5	13
89040	2020-07-02 20:57:42	2020-07-02	12	[{"id_menu":1,"count":1}]	34695	delivery	5	17
89041	2020-07-02 20:58:09	2020-07-02	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1669	delivery	5	26
89042	2020-07-02 20:58:24	2020-07-02	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":3}]	30991	delivery	5	22
89043	2020-07-02 20:58:26	2020-07-02	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	30736	delivery	5	37
89044	2020-07-02 20:59:44	2020-07-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25173	pick-up	0	17
89045	2020-07-02 21:00:10	2020-07-02	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	23380	delivery	5	25
89046	2020-07-02 21:00:44	2020-07-02	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	34630	delivery	5	22
89047	2020-07-02 21:00:59	2020-07-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1445	pick-up	0	17
89048	2020-07-02 21:01:00	2020-07-02	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2627	delivery	5	26
89049	2020-07-02 21:01:49	2020-07-02	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4363	pick-up	0	32
89050	2020-07-02 21:02:06	2020-07-02	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	34691	delivery	5	34
89051	2020-07-02 21:02:07	2020-07-02	12	[{"id_menu":3,"count":2}]	34594	pick-up	0	12
89052	2020-07-02 21:02:12	2020-07-02	14	[{"id_menu":2,"count":1}]	1582	pick-up	0	14
89053	2020-07-02 21:03:00	2020-07-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	34602	delivery	5	28
89054	2020-07-02 21:04:29	2020-07-02	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	34749	delivery	5	28
89055	2020-07-02 21:09:59	2020-07-02	9	[{"id_menu":7,"count":1}]	34706	delivery	5	14
89056	2020-07-02 21:10:18	2020-07-02	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32675	delivery	5	48
89057	2020-07-02 21:18:38	2020-07-02	9	[{"id_menu":7,"count":1}]	15679	delivery	5	14
89058	2020-07-02 21:20:31	2020-07-02	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12476	delivery	5	34
89059	2020-07-02 21:24:53	2020-07-02	14	[{"id_menu":2,"count":1}]	13767	pick-up	0	14
89060	2020-07-02 21:25:04	2020-07-02	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	20967	delivery	5	39
89061	2020-07-02 21:27:17	2020-07-02	12	[{"id_menu":3,"count":1}]	1228	pick-up	0	12
89062	2020-07-02 21:29:00	2020-07-02	12	[{"id_menu":1,"count":1}]	16114	pick-up	0	12
89063	2020-07-02 21:32:15	2020-07-02	17	[{"id_menu":4,"count":1}]	13885	delivery	5	22
89064	2020-07-02 21:33:56	2020-07-02	9	[{"id_menu":6,"count":1}]	30586	delivery	5	14
89065	2020-07-02 21:36:50	2020-07-02	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28564	delivery	5	35
89066	2020-07-02 21:37:12	2020-07-02	17	[{"id_menu":4,"count":1}]	3640	delivery	5	22
89067	2020-07-02 21:38:04	2020-07-02	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13475	delivery	5	36
89068	2020-07-02 21:39:05	2020-07-02	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	12664	delivery	5	26
89069	2020-07-02 21:41:13	2020-07-02	17	[{"id_menu":4,"count":1}]	24105	pick-up	0	17
89070	2020-07-02 21:41:45	2020-07-02	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	22338	pick-up	0	37
89071	2020-07-02 21:47:02	2020-07-02	12	[{"id_menu":1,"count":1}]	4650	pick-up	0	12
89072	2020-07-02 21:54:17	2020-07-02	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	34605	delivery	5	45
89073	2020-07-02 21:54:45	2020-07-02	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	7595	pick-up	0	26
89074	2020-07-02 21:55:38	2020-07-02	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34614	delivery	5	31
89075	2020-07-02 21:55:38	2020-07-02	9	[{"id_menu":7,"count":1}]	4090	delivery	5	14
89076	2020-07-02 21:57:37	2020-07-02	12	[{"id_menu":3,"count":1}]	9201	delivery	5	17
89077	2020-07-02 21:59:02	2020-07-02	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	26943	delivery	5	26
89078	2020-07-02 22:00:06	2020-07-02	8	[{"id_menu":5,"count":1}]	228	delivery	5	13
89079	2020-07-02 22:02:07	2020-07-02	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	8852	delivery	5	34
89080	2020-07-02 22:08:53	2020-07-02	9	[{"id_menu":7,"count":1}]	17068	delivery	5	14
89081	2020-07-02 22:09:13	2020-07-02	14	[{"id_menu":2,"count":2}]	28639	pick-up	0	14
89082	2020-07-02 22:09:31	2020-07-02	8	[{"id_menu":5,"count":1}]	34659	delivery	5	13
89083	2020-07-02 22:10:22	2020-07-02	9	[{"id_menu":7,"count":3}]	34681	delivery	5	14
89084	2020-07-02 22:12:37	2020-07-02	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	15246	delivery	5	29
89085	2020-07-02 22:13:38	2020-07-02	9	[{"id_menu":7,"count":2}]	466	delivery	5	14
89086	2020-07-02 22:14:58	2020-07-02	9	[{"id_menu":7,"count":1}]	5930	delivery	5	14
89087	2020-07-02 22:16:27	2020-07-02	12	[{"id_menu":1,"count":1}]	17259	pick-up	0	12
89088	2020-07-02 22:22:14	2020-07-02	14	[{"id_menu":2,"count":1}]	30567	delivery	5	19
89089	2020-07-02 22:24:55	2020-07-02	17	[{"id_menu":4,"count":1}]	4034	pick-up	0	17
89090	2020-07-02 22:28:58	2020-07-02	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	34450	delivery	5	22
89091	2020-07-02 22:31:10	2020-07-02	8	[{"id_menu":5,"count":1}]	2128	pick-up	0	8
89092	2020-07-02 22:33:30	2020-07-02	9	[{"id_menu":7,"count":1}]	9783	delivery	5	14
89093	2020-07-02 22:33:53	2020-07-02	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8813	delivery	5	31
89094	2020-07-02 22:35:57	2020-07-02	9	[{"id_menu":6,"count":1}]	30618	delivery	5	14
89095	2020-07-02 22:36:31	2020-07-02	9	[{"id_menu":6,"count":1}]	13303	delivery	5	14
89096	2020-07-02 22:39:57	2020-07-02	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	6277	delivery	5	40
89097	2020-07-02 22:40:48	2020-07-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5643	delivery	5	23
89098	2020-07-02 22:41:37	2020-07-02	9	[{"id_menu":6,"count":1}]	34685	delivery	5	14
89099	2020-07-02 22:41:57	2020-07-02	9	[{"id_menu":7,"count":1}]	29852	pick-up	0	9
89100	2020-07-02 22:42:59	2020-07-02	9	[{"id_menu":6,"count":1}]	11745	pick-up	0	9
89101	2020-07-02 22:45:26	2020-07-02	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	34697	delivery	5	22
89102	2020-07-02 22:46:32	2020-07-02	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	29233	delivery	5	40
89103	2020-07-02 22:46:36	2020-07-02	12	[{"id_menu":3,"count":1}]	34666	delivery	5	17
89104	2020-07-02 22:46:47	2020-07-02	14	[{"id_menu":2,"count":1}]	10264	pick-up	0	14
89105	2020-07-02 22:48:19	2020-07-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	5359	delivery	5	28
89106	2020-07-02 22:49:05	2020-07-02	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	34725	delivery	5	22
89107	2020-07-02 22:49:31	2020-07-02	8	[{"id_menu":5,"count":1}]	34694	pick-up	0	8
89108	2020-07-02 22:52:52	2020-07-02	14	[{"id_menu":2,"count":1}]	31789	delivery	5	19
89109	2020-07-02 22:56:46	2020-07-02	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	12075	delivery	5	28
89110	2020-07-02 22:57:45	2020-07-02	9	[{"id_menu":6,"count":2}]	3129	delivery	5	14
89111	2020-07-02 22:58:21	2020-07-02	9	[{"id_menu":6,"count":1}]	24240	delivery	5	14
89112	2020-07-02 23:01:17	2020-07-02	17	[{"id_menu":4,"count":1}]	15579	delivery	5	22
89113	2020-07-02 23:03:52	2020-07-02	12	[{"id_menu":3,"count":1}]	18090	delivery	5	17
89114	2020-07-02 23:05:59	2020-07-02	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	14093	delivery	5	28
89115	2020-07-02 23:12:26	2020-07-02	14	[{"id_menu":2,"count":1}]	23979	pick-up	0	14
89116	2020-07-02 23:14:36	2020-07-02	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7211	delivery	5	39
89117	2020-07-02 23:15:37	2020-07-02	9	[{"id_menu":7,"count":1}]	16155	pick-up	0	9
89118	2020-07-02 23:19:30	2020-07-02	8	[{"id_menu":5,"count":2}]	34742	delivery	5	13
89119	2020-07-02 23:21:19	2020-07-02	14	[{"id_menu":2,"count":2}]	30127	delivery	5	19
89120	2020-07-02 23:22:22	2020-07-02	9	[{"id_menu":7,"count":1}]	3916	pick-up	0	9
89121	2020-07-02 23:23:32	2020-07-02	14	[{"id_menu":2,"count":1}]	34735	delivery	5	19
89122	2020-07-02 23:24:57	2020-07-02	12	[{"id_menu":1,"count":1}]	29170	delivery	5	17
89123	2020-07-02 23:25:43	2020-07-02	9	[{"id_menu":7,"count":1}]	34675	delivery	5	14
89124	2020-07-02 23:28:39	2020-07-02	17	[{"id_menu":4,"count":1}]	13762	delivery	5	22
89125	2020-07-02 23:28:49	2020-07-02	14	[{"id_menu":2,"count":1}]	27811	pick-up	0	14
89126	2020-07-02 23:34:16	2020-07-02	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	9575	pick-up	0	34
89127	2020-07-02 23:36:36	2020-07-02	9	[{"id_menu":6,"count":1}]	34771	delivery	5	14
89128	2020-07-02 23:36:54	2020-07-02	9	[{"id_menu":6,"count":1}]	18980	pick-up	0	9
89129	2020-07-02 23:37:27	2020-07-02	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	34670	delivery	5	28
89130	2020-07-02 23:38:15	2020-07-02	17	[{"id_menu":4,"count":2}]	8529	pick-up	0	17
89131	2020-07-02 23:39:54	2020-07-02	17	[{"id_menu":4,"count":1}]	10968	pick-up	0	17
89132	2020-07-02 23:43:37	2020-07-02	9	[{"id_menu":6,"count":1}]	34769	delivery	5	14
89133	2020-07-02 23:44:03	2020-07-02	9	[{"id_menu":7,"count":1}]	13652	delivery	5	14
89134	2020-07-02 23:44:40	2020-07-02	9	[{"id_menu":6,"count":1}]	34748	delivery	5	14
89135	2020-07-02 23:45:24	2020-07-02	14	[{"id_menu":2,"count":1}]	16639	delivery	5	19
89136	2020-07-02 23:47:38	2020-07-02	14	[{"id_menu":2,"count":1}]	34705	delivery	5	19
89137	2020-07-02 23:47:41	2020-07-02	9	[{"id_menu":7,"count":1}]	19596	delivery	5	14
89138	2020-07-02 23:51:29	2020-07-02	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2623	pick-up	0	26
89139	2020-07-02 23:52:29	2020-07-02	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5474	pick-up	0	31
89140	2020-07-02 23:56:22	2020-07-02	14	[{"id_menu":2,"count":2}]	34649	delivery	5	19
89141	2020-07-03 00:01:33	2020-07-03	9	[{"id_menu":7,"count":1}]	22056	delivery	5	14
89142	2020-07-03 00:01:53	2020-07-03	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	34885	delivery	5	22
89143	2020-07-03 00:08:31	2020-07-03	17	[{"id_menu":4,"count":1}]	1497	pick-up	0	17
89144	2020-07-03 00:09:15	2020-07-03	14	[{"id_menu":2,"count":1}]	19258	delivery	5	19
89145	2020-07-03 00:09:25	2020-07-03	9	[{"id_menu":7,"count":1}]	33183	delivery	5	14
89146	2020-07-03 00:13:52	2020-07-03	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	10442	delivery	5	34
89147	2020-07-03 00:16:13	2020-07-03	9	[{"id_menu":6,"count":1}]	34984	delivery	5	14
89148	2020-07-03 00:19:09	2020-07-03	14	[{"id_menu":2,"count":1}]	5047	pick-up	0	14
89149	2020-07-03 00:19:51	2020-07-03	12	[{"id_menu":1,"count":1}]	34870	delivery	5	17
89150	2020-07-03 00:22:41	2020-07-03	14	[{"id_menu":2,"count":1}]	13062	delivery	5	19
89151	2020-07-03 00:29:55	2020-07-03	17	[{"id_menu":4,"count":1}]	34797	delivery	5	22
89152	2020-07-03 00:32:43	2020-07-03	8	[{"id_menu":5,"count":1}]	34909	delivery	5	13
89153	2020-07-03 00:35:01	2020-07-03	9	[{"id_menu":7,"count":1}]	14947	pick-up	0	9
89154	2020-07-03 00:35:08	2020-07-03	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1536	pick-up	0	52
89155	2020-07-03 00:40:48	2020-07-03	9	[{"id_menu":7,"count":1}]	1679	pick-up	0	9
89156	2020-07-03 00:42:02	2020-07-03	14	[{"id_menu":2,"count":1}]	1088	delivery	5	19
89157	2020-07-03 00:43:49	2020-07-03	14	[{"id_menu":2,"count":1}]	11342	delivery	5	19
89158	2020-07-03 00:44:37	2020-07-03	9	[{"id_menu":7,"count":1}]	34921	delivery	5	14
89159	2020-07-03 00:45:25	2020-07-03	14	[{"id_menu":2,"count":3}]	9359	delivery	5	19
89160	2020-07-03 00:50:46	2020-07-03	9	[{"id_menu":7,"count":1}]	27308	delivery	5	14
89161	2020-07-03 00:51:44	2020-07-03	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	34982	delivery	5	52
89162	2020-07-03 00:55:15	2020-07-03	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3102	pick-up	0	40
89163	2020-07-03 00:58:59	2020-07-03	12	[{"id_menu":3,"count":1}]	33943	pick-up	0	12
89164	2020-07-03 00:59:27	2020-07-03	9	[{"id_menu":6,"count":2}]	34942	delivery	5	14
89165	2020-07-03 01:00:44	2020-07-03	17	[{"id_menu":4,"count":1}]	3526	delivery	5	22
89166	2020-07-03 01:02:03	2020-07-03	9	[{"id_menu":6,"count":1}]	22014	delivery	5	14
89167	2020-07-03 01:06:41	2020-07-03	8	[{"id_menu":5,"count":1}]	13316	delivery	5	13
89168	2020-07-03 01:07:38	2020-07-03	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35004	delivery	5	35
89169	2020-07-03 01:08:32	2020-07-03	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	18982	delivery	5	40
89170	2020-07-03 01:10:15	2020-07-03	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9698	delivery	5	35
89171	2020-07-03 01:10:59	2020-07-03	9	[{"id_menu":6,"count":1}]	34985	delivery	5	14
89172	2020-07-03 01:12:15	2020-07-03	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	7983	delivery	5	34
89173	2020-07-03 01:15:04	2020-07-03	9	[{"id_menu":6,"count":1}]	9446	delivery	5	14
89174	2020-07-03 01:17:52	2020-07-03	17	[{"id_menu":4,"count":1}]	13441	delivery	5	22
89175	2020-07-03 01:18:14	2020-07-03	12	[{"id_menu":1,"count":1}]	34983	delivery	5	17
89176	2020-07-03 01:20:04	2020-07-03	9	[{"id_menu":7,"count":1}]	10491	delivery	5	14
89177	2020-07-03 01:22:10	2020-07-03	12	[{"id_menu":3,"count":1}]	18063	pick-up	0	12
89178	2020-07-03 01:22:16	2020-07-03	14	[{"id_menu":2,"count":1}]	35005	delivery	5	19
89179	2020-07-03 01:30:17	2020-07-03	9	[{"id_menu":6,"count":1}]	34954	delivery	5	14
89180	2020-07-03 01:31:38	2020-07-03	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	439	pick-up	0	22
89181	2020-07-03 01:31:55	2020-07-03	12	[{"id_menu":1,"count":1}]	34946	delivery	5	17
89182	2020-07-03 01:32:40	2020-07-03	14	[{"id_menu":2,"count":1}]	34922	pick-up	0	14
89183	2020-07-03 01:34:27	2020-07-03	14	[{"id_menu":2,"count":1}]	34847	delivery	5	19
89184	2020-07-03 01:36:09	2020-07-03	9	[{"id_menu":6,"count":1}]	34867	delivery	5	14
89185	2020-07-03 01:37:00	2020-07-03	17	[{"id_menu":4,"count":1}]	34803	delivery	5	22
89186	2020-07-03 01:43:12	2020-07-03	12	[{"id_menu":1,"count":1}]	23532	pick-up	0	12
89187	2020-07-03 01:45:36	2020-07-03	9	[{"id_menu":7,"count":1}]	34848	delivery	5	14
89188	2020-07-03 01:47:04	2020-07-03	39	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	34871	delivery	5	44
89189	2020-07-03 01:48:10	2020-07-03	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	21689	delivery	5	28
89190	2020-07-03 01:50:21	2020-07-03	12	[{"id_menu":1,"count":1}]	16081	delivery	5	17
89191	2020-07-03 01:51:56	2020-07-03	8	[{"id_menu":5,"count":1}]	32451	delivery	5	13
89192	2020-07-03 01:52:00	2020-07-03	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	34807	delivery	5	22
89193	2020-07-03 01:53:05	2020-07-03	12	[{"id_menu":1,"count":1}]	34839	pick-up	0	12
89194	2020-07-03 01:55:36	2020-07-03	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	34835	pick-up	0	17
89195	2020-07-03 02:06:58	2020-07-03	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2416	delivery	5	31
89196	2020-07-03 02:08:32	2020-07-03	9	[{"id_menu":7,"count":1}]	25568	delivery	5	14
89197	2020-07-03 02:08:38	2020-07-03	9	[{"id_menu":6,"count":1}]	12057	delivery	5	14
89198	2020-07-03 02:11:26	2020-07-03	17	[{"id_menu":4,"count":1}]	27863	delivery	5	22
89199	2020-07-03 02:12:47	2020-07-03	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	34845	delivery	5	22
89200	2020-07-03 02:17:55	2020-07-03	9	[{"id_menu":7,"count":1}]	34887	delivery	5	14
89201	2020-07-03 02:20:34	2020-07-03	8	[{"id_menu":5,"count":1}]	34918	delivery	5	13
89202	2020-07-03 02:22:54	2020-07-03	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	33378	delivery	5	22
89203	2020-07-03 02:23:34	2020-07-03	8	[{"id_menu":5,"count":1}]	21395	delivery	5	13
89204	2020-07-03 02:24:43	2020-07-03	9	[{"id_menu":7,"count":1}]	23519	delivery	5	14
89205	2020-07-03 02:26:25	2020-07-03	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	22407	delivery	5	42
89206	2020-07-03 02:27:10	2020-07-03	14	[{"id_menu":2,"count":1}]	7924	delivery	5	19
89207	2020-07-03 02:27:26	2020-07-03	9	[{"id_menu":6,"count":2}]	34963	delivery	5	14
89208	2020-07-03 02:29:28	2020-07-03	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2928	pick-up	0	23
89209	2020-07-03 02:32:22	2020-07-03	9	[{"id_menu":6,"count":1}]	32402	pick-up	0	9
89210	2020-07-03 02:33:45	2020-07-03	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	21703	delivery	5	30
89211	2020-07-03 02:34:18	2020-07-03	12	[{"id_menu":1,"count":1}]	19195	delivery	5	17
89212	2020-07-03 02:36:34	2020-07-03	8	[{"id_menu":5,"count":1}]	9728	pick-up	0	8
89213	2020-07-03 02:36:55	2020-07-03	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	34973	pick-up	0	26
89214	2020-07-03 02:42:06	2020-07-03	8	[{"id_menu":5,"count":1}]	7553	delivery	5	13
89215	2020-07-03 02:46:03	2020-07-03	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	10494	delivery	5	28
89216	2020-07-03 02:48:02	2020-07-03	9	[{"id_menu":7,"count":1}]	11666	delivery	5	14
89217	2020-07-03 02:50:28	2020-07-03	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	34892	delivery	5	27
89218	2020-07-03 02:52:10	2020-07-03	9	[{"id_menu":6,"count":1}]	2473	delivery	5	14
89219	2020-07-03 02:52:41	2020-07-03	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	20095	delivery	5	31
89220	2020-07-03 02:55:15	2020-07-03	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	16427	delivery	5	26
89221	2020-07-03 03:00:44	2020-07-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2153	delivery	5	31
89222	2020-07-03 03:03:29	2020-07-03	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	34927	delivery	5	30
89223	2020-07-03 03:03:32	2020-07-03	9	[{"id_menu":7,"count":1}]	2439	delivery	5	14
89224	2020-07-03 03:04:11	2020-07-03	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	29806	delivery	5	27
89225	2020-07-03 03:04:47	2020-07-03	8	[{"id_menu":5,"count":1}]	34901	delivery	5	13
89226	2020-07-03 03:04:53	2020-07-03	17	[{"id_menu":4,"count":1}]	7690	delivery	5	22
89227	2020-07-03 03:06:39	2020-07-03	14	[{"id_menu":2,"count":1}]	20729	delivery	5	19
89228	2020-07-03 03:08:01	2020-07-03	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	34831	delivery	5	39
89229	2020-07-03 03:08:41	2020-07-03	12	[{"id_menu":1,"count":1}]	34877	delivery	5	17
89230	2020-07-03 03:08:44	2020-07-03	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12707	delivery	5	39
89231	2020-07-03 03:11:09	2020-07-03	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	25172	delivery	5	40
89232	2020-07-03 03:11:49	2020-07-03	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	91	delivery	5	39
89233	2020-07-03 03:12:29	2020-07-03	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	34787	delivery	5	26
89234	2020-07-03 03:13:31	2020-07-03	9	[{"id_menu":7,"count":1}]	1107	pick-up	0	9
89235	2020-07-03 03:13:54	2020-07-03	12	[{"id_menu":3,"count":1}]	2426	delivery	5	17
89236	2020-07-03 03:14:33	2020-07-03	14	[{"id_menu":2,"count":1}]	27994	delivery	5	19
89237	2020-07-03 03:16:36	2020-07-03	39	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	16205	delivery	5	44
89238	2020-07-03 03:23:32	2020-07-03	17	[{"id_menu":4,"count":1}]	6773	delivery	5	22
89239	2020-07-03 03:29:22	2020-07-03	12	[{"id_menu":1,"count":1}]	34896	delivery	5	17
89240	2020-07-03 03:30:09	2020-07-03	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	27804	pick-up	0	39
89241	2020-07-03 03:30:52	2020-07-03	17	[{"id_menu":4,"count":1}]	7926	delivery	5	22
89242	2020-07-03 03:43:12	2020-07-03	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	10031	delivery	5	30
89243	2020-07-03 03:44:14	2020-07-03	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	34964	delivery	5	36
89244	2020-07-03 03:46:28	2020-07-03	9	[{"id_menu":6,"count":1}]	29696	delivery	5	14
89245	2020-07-03 03:48:31	2020-07-03	9	[{"id_menu":6,"count":1}]	1622	pick-up	0	9
89246	2020-07-03 03:49:07	2020-07-03	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	32403	delivery	5	43
89247	2020-07-03 03:50:38	2020-07-03	12	[{"id_menu":3,"count":1}]	34905	pick-up	0	12
89248	2020-07-03 03:52:03	2020-07-03	14	[{"id_menu":2,"count":1}]	3010	pick-up	0	14
89249	2020-07-03 03:53:21	2020-07-03	9	[{"id_menu":6,"count":1}]	22872	delivery	5	14
89250	2020-07-03 03:56:57	2020-07-03	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	19082	delivery	5	28
89251	2020-07-03 03:58:14	2020-07-03	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7000	delivery	5	35
89252	2020-07-03 04:07:00	2020-07-03	9	[{"id_menu":6,"count":1}]	26628	pick-up	0	9
89253	2020-07-03 04:07:12	2020-07-03	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31301	delivery	5	51
89254	2020-07-03 04:09:22	2020-07-03	12	[{"id_menu":1,"count":1}]	34977	delivery	5	17
89255	2020-07-03 04:10:05	2020-07-03	12	[{"id_menu":1,"count":1}]	10274	delivery	5	17
89256	2020-07-03 04:14:48	2020-07-03	9	[{"id_menu":7,"count":2}]	30712	delivery	5	14
89257	2020-07-03 04:15:14	2020-07-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	23052	delivery	5	31
89258	2020-07-03 04:16:40	2020-07-03	12	[{"id_menu":3,"count":1}]	17063	delivery	5	17
89259	2020-07-03 04:19:58	2020-07-03	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	34895	delivery	5	37
89260	2020-07-03 04:20:47	2020-07-03	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21290	delivery	5	40
89261	2020-07-03 04:21:08	2020-07-03	33	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	8673	delivery	5	38
89262	2020-07-03 04:32:06	2020-07-03	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10526	pick-up	0	35
89263	2020-07-03 04:39:06	2020-07-03	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4820	delivery	5	34
89264	2020-07-03 04:40:17	2020-07-03	9	[{"id_menu":7,"count":1}]	15093	delivery	5	14
89265	2020-07-03 04:43:18	2020-07-03	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	34876	pick-up	0	18
89266	2020-07-03 04:45:08	2020-07-03	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	5904	delivery	5	25
89267	2020-07-03 04:45:57	2020-07-03	12	[{"id_menu":1,"count":1}]	24620	pick-up	0	12
89268	2020-07-03 04:48:59	2020-07-03	8	[{"id_menu":5,"count":1}]	34812	delivery	5	13
89269	2020-07-03 04:50:14	2020-07-03	14	[{"id_menu":2,"count":1}]	15053	delivery	5	19
89270	2020-07-03 04:51:33	2020-07-03	9	[{"id_menu":7,"count":1}]	7190	delivery	5	14
89271	2020-07-03 04:52:47	2020-07-03	17	[{"id_menu":4,"count":1}]	17941	delivery	5	22
89272	2020-07-03 04:54:45	2020-07-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	33828	pick-up	0	23
89273	2020-07-03 04:56:45	2020-07-03	9	[{"id_menu":7,"count":1}]	11969	pick-up	0	9
89274	2020-07-03 04:58:13	2020-07-03	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	32960	delivery	5	48
89275	2020-07-03 05:07:01	2020-07-03	12	[{"id_menu":1,"count":2}]	12013	delivery	5	17
89276	2020-07-03 05:07:28	2020-07-03	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	34940	delivery	5	43
89277	2020-07-03 05:09:18	2020-07-03	9	[{"id_menu":6,"count":1}]	18374	pick-up	0	9
89278	2020-07-03 05:10:51	2020-07-03	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	4874	pick-up	0	35
89279	2020-07-03 05:11:31	2020-07-03	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	28836	delivery	5	40
89280	2020-07-03 05:14:39	2020-07-03	8	[{"id_menu":5,"count":1}]	9823	pick-up	0	8
89281	2020-07-03 05:16:39	2020-07-03	9	[{"id_menu":7,"count":1}]	7502	delivery	5	14
89282	2020-07-03 05:17:13	2020-07-03	9	[{"id_menu":6,"count":1}]	14523	delivery	5	14
89283	2020-07-03 05:21:34	2020-07-03	12	[{"id_menu":3,"count":1}]	29263	delivery	5	17
89284	2020-07-03 05:21:44	2020-07-03	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	34827	delivery	5	28
89285	2020-07-03 05:23:25	2020-07-03	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34850	delivery	5	23
89286	2020-07-03 05:37:01	2020-07-03	14	[{"id_menu":2,"count":1}]	34830	delivery	5	19
89287	2020-07-03 05:39:35	2020-07-03	9	[{"id_menu":7,"count":1}]	15029	pick-up	0	9
89288	2020-07-03 05:40:44	2020-07-03	9	[{"id_menu":6,"count":1}]	4309	delivery	5	14
89289	2020-07-03 05:43:16	2020-07-03	17	[{"id_menu":4,"count":1}]	31906	delivery	5	22
89290	2020-07-03 05:44:13	2020-07-03	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	34992	delivery	5	34
89291	2020-07-03 05:46:03	2020-07-03	9	[{"id_menu":7,"count":1}]	21223	delivery	5	14
89292	2020-07-03 05:47:05	2020-07-03	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	23083	delivery	5	34
89293	2020-07-03 05:49:38	2020-07-03	14	[{"id_menu":2,"count":1}]	14845	pick-up	0	14
89294	2020-07-03 05:50:22	2020-07-03	12	[{"id_menu":1,"count":1}]	7221	delivery	5	17
89295	2020-07-03 05:58:10	2020-07-03	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	29809	delivery	5	38
89296	2020-07-03 05:58:18	2020-07-03	17	[{"id_menu":4,"count":1}]	26713	delivery	5	22
89297	2020-07-03 05:59:18	2020-07-03	12	[{"id_menu":3,"count":1}]	19783	delivery	5	17
89298	2020-07-03 05:59:26	2020-07-03	9	[{"id_menu":7,"count":1}]	34971	delivery	5	14
89299	2020-07-03 06:04:08	2020-07-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	34816	delivery	5	28
89300	2020-07-03 06:05:13	2020-07-03	12	[{"id_menu":3,"count":1}]	34948	delivery	5	17
89301	2020-07-03 06:06:02	2020-07-03	37	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7152	delivery	5	42
89302	2020-07-03 06:06:18	2020-07-03	9	[{"id_menu":7,"count":1}]	34854	delivery	5	14
89303	2020-07-03 06:10:06	2020-07-03	14	[{"id_menu":2,"count":1}]	13535	delivery	5	19
89304	2020-07-03 06:10:37	2020-07-03	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	34997	delivery	5	28
89305	2020-07-03 06:19:32	2020-07-03	12	[{"id_menu":1,"count":1}]	4038	pick-up	0	12
89306	2020-07-03 06:20:14	2020-07-03	9	[{"id_menu":6,"count":1}]	1982	pick-up	0	9
89307	2020-07-03 06:31:36	2020-07-03	17	[{"id_menu":4,"count":1}]	17621	delivery	5	22
89308	2020-07-03 06:31:44	2020-07-03	17	[{"id_menu":4,"count":1}]	3286	delivery	5	22
89309	2020-07-03 06:31:44	2020-07-03	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	23518	delivery	5	45
89310	2020-07-03 06:33:39	2020-07-03	9	[{"id_menu":6,"count":1}]	15466	delivery	5	14
89311	2020-07-03 06:33:56	2020-07-03	9	[{"id_menu":6,"count":1}]	22562	delivery	5	14
89312	2020-07-03 06:34:06	2020-07-03	14	[{"id_menu":2,"count":1}]	7615	pick-up	0	14
89313	2020-07-03 06:37:14	2020-07-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	15788	delivery	5	28
89314	2020-07-03 06:40:00	2020-07-03	14	[{"id_menu":2,"count":1}]	34902	delivery	5	19
89315	2020-07-03 06:44:24	2020-07-03	8	[{"id_menu":5,"count":2}]	32601	delivery	5	13
89316	2020-07-03 06:50:25	2020-07-03	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3877	pick-up	0	40
89317	2020-07-03 06:53:46	2020-07-03	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34823	delivery	5	23
89318	2020-07-03 06:56:16	2020-07-03	12	[{"id_menu":3,"count":1}]	27600	delivery	5	17
89319	2020-07-03 06:58:38	2020-07-03	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	5110	delivery	5	31
89320	2020-07-03 06:58:51	2020-07-03	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	32579	delivery	5	28
89321	2020-07-03 07:02:13	2020-07-03	12	[{"id_menu":3,"count":1}]	34881	delivery	5	17
89322	2020-07-03 07:06:57	2020-07-03	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	34844	delivery	5	25
89323	2020-07-03 07:14:47	2020-07-03	9	[{"id_menu":6,"count":1}]	34838	delivery	5	14
89324	2020-07-03 07:14:53	2020-07-03	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	34828	delivery	5	29
89325	2020-07-03 07:15:18	2020-07-03	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	27202	delivery	5	27
89326	2020-07-03 07:17:58	2020-07-03	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	15548	delivery	5	38
89327	2020-07-03 07:18:01	2020-07-03	12	[{"id_menu":1,"count":1}]	34914	delivery	5	17
89328	2020-07-03 07:21:39	2020-07-03	9	[{"id_menu":6,"count":1}]	34778	delivery	5	14
89329	2020-07-03 07:24:35	2020-07-03	12	[{"id_menu":3,"count":1}]	11696	pick-up	0	12
89330	2020-07-03 07:27:31	2020-07-03	12	[{"id_menu":1,"count":1}]	11630	delivery	5	17
89331	2020-07-03 07:28:48	2020-07-03	8	[{"id_menu":5,"count":1}]	34935	delivery	5	13
89332	2020-07-03 07:29:00	2020-07-03	17	[{"id_menu":4,"count":1}]	34868	delivery	5	22
89333	2020-07-03 07:33:46	2020-07-03	9	[{"id_menu":7,"count":1}]	34991	delivery	5	14
89334	2020-07-03 07:37:59	2020-07-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	24441	pick-up	0	26
89335	2020-07-03 07:38:35	2020-07-03	9	[{"id_menu":6,"count":1}]	34860	delivery	5	14
89336	2020-07-03 07:42:00	2020-07-03	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10080	delivery	5	30
89337	2020-07-03 07:50:12	2020-07-03	9	[{"id_menu":7,"count":1}]	25852	pick-up	0	9
89338	2020-07-03 07:54:17	2020-07-03	12	[{"id_menu":1,"count":1}]	34819	delivery	5	17
89339	2020-07-03 07:54:54	2020-07-03	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	2781	pick-up	0	20
89340	2020-07-03 07:57:38	2020-07-03	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	34970	pick-up	0	24
89341	2020-07-03 08:00:06	2020-07-03	14	[{"id_menu":2,"count":1}]	4428	pick-up	0	14
89342	2020-07-03 08:04:51	2020-07-03	17	[{"id_menu":4,"count":1}]	34996	delivery	5	22
89343	2020-07-03 08:05:10	2020-07-03	12	[{"id_menu":1,"count":1}]	11034	delivery	5	17
89344	2020-07-03 08:06:19	2020-07-03	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34938	delivery	5	43
89345	2020-07-03 08:07:52	2020-07-03	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34920	delivery	5	23
89346	2020-07-03 08:11:32	2020-07-03	17	[{"id_menu":4,"count":1}]	25251	delivery	5	22
89347	2020-07-03 08:13:47	2020-07-03	8	[{"id_menu":5,"count":1}]	20308	delivery	5	13
89348	2020-07-03 08:14:30	2020-07-03	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	33240	delivery	5	22
89349	2020-07-03 08:16:55	2020-07-03	8	[{"id_menu":5,"count":1}]	11002	delivery	5	13
89350	2020-07-03 08:17:07	2020-07-03	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	14756	delivery	5	31
89351	2020-07-03 08:17:40	2020-07-03	17	[{"id_menu":4,"count":1}]	34943	pick-up	0	17
89352	2020-07-03 08:19:01	2020-07-03	12	[{"id_menu":1,"count":1}]	359	pick-up	0	12
89353	2020-07-03 08:21:04	2020-07-03	30	[{"id_menu":3,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10870	pick-up	0	30
89354	2020-07-03 08:22:08	2020-07-03	12	[{"id_menu":1,"count":1}]	3330	pick-up	0	12
89355	2020-07-03 08:25:54	2020-07-03	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	34949	delivery	5	28
89356	2020-07-03 08:38:18	2020-07-03	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	11896	pick-up	0	26
89357	2020-07-03 08:40:38	2020-07-03	9	[{"id_menu":6,"count":1}]	29227	delivery	5	14
89358	2020-07-03 08:42:12	2020-07-03	9	[{"id_menu":6,"count":1}]	17408	delivery	5	14
89359	2020-07-03 08:54:21	2020-07-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	23382	delivery	5	31
89360	2020-07-03 08:58:40	2020-07-03	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	10492	delivery	5	25
89361	2020-07-03 08:59:33	2020-07-03	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	24552	delivery	5	26
89362	2020-07-03 09:03:24	2020-07-03	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5839	pick-up	0	18
89363	2020-07-03 09:07:55	2020-07-03	8	[{"id_menu":5,"count":1}]	16859	pick-up	0	8
89364	2020-07-03 09:08:30	2020-07-03	9	[{"id_menu":6,"count":1}]	30647	delivery	5	14
89365	2020-07-03 09:10:25	2020-07-03	12	[{"id_menu":1,"count":1}]	34979	delivery	5	17
89366	2020-07-03 09:11:00	2020-07-03	14	[{"id_menu":2,"count":1}]	13256	pick-up	0	14
89367	2020-07-03 09:16:47	2020-07-03	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7189	pick-up	0	31
89368	2020-07-03 09:20:01	2020-07-03	14	[{"id_menu":2,"count":1}]	10880	pick-up	0	14
89369	2020-07-03 09:30:40	2020-07-03	12	[{"id_menu":1,"count":1}]	16621	delivery	5	17
89370	2020-07-03 09:44:14	2020-07-03	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9882	delivery	5	46
89371	2020-07-03 09:50:15	2020-07-03	12	[{"id_menu":1,"count":1}]	23504	delivery	5	17
89372	2020-07-03 09:52:18	2020-07-03	34	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	18658	delivery	5	39
89373	2020-07-03 09:52:18	2020-07-03	9	[{"id_menu":6,"count":1}]	34566	pick-up	0	9
89374	2020-07-03 09:53:43	2020-07-03	9	[{"id_menu":6,"count":1}]	11586	delivery	5	14
89375	2020-07-03 09:59:02	2020-07-03	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7253	delivery	5	48
89376	2020-07-03 10:00:25	2020-07-03	9	[{"id_menu":7,"count":1}]	32422	delivery	5	14
89377	2020-07-03 10:00:37	2020-07-03	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	25612	delivery	5	34
89378	2020-07-03 10:01:44	2020-07-03	12	[{"id_menu":1,"count":1}]	28747	delivery	5	17
89379	2020-07-03 10:03:28	2020-07-03	17	[{"id_menu":4,"count":1}]	9513	delivery	5	22
89380	2020-07-03 10:07:05	2020-07-03	9	[{"id_menu":6,"count":2}]	18901	delivery	5	14
89381	2020-07-03 10:11:07	2020-07-03	12	[{"id_menu":3,"count":1}]	28315	delivery	5	17
89382	2020-07-03 10:11:41	2020-07-03	37	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	34903	delivery	5	42
89383	2020-07-03 10:12:10	2020-07-03	9	[{"id_menu":6,"count":2}]	34951	delivery	5	14
89384	2020-07-03 10:13:38	2020-07-03	9	[{"id_menu":6,"count":2}]	1934	pick-up	0	9
89385	2020-07-03 10:14:40	2020-07-03	8	[{"id_menu":5,"count":1}]	34999	pick-up	0	8
89386	2020-07-03 10:15:16	2020-07-03	8	[{"id_menu":5,"count":1}]	20805	delivery	5	13
89387	2020-07-03 10:15:31	2020-07-03	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	34818	delivery	5	28
89388	2020-07-03 10:15:31	2020-07-03	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34274	delivery	5	23
89389	2020-07-03 10:17:36	2020-07-03	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	26911	pick-up	0	21
89390	2020-07-03 10:19:13	2020-07-03	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32006	delivery	5	49
89391	2020-07-03 10:24:40	2020-07-03	9	[{"id_menu":7,"count":1}]	8597	delivery	5	14
89392	2020-07-03 10:26:00	2020-07-03	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	19683	delivery	5	22
89393	2020-07-03 10:27:12	2020-07-03	17	[{"id_menu":4,"count":1}]	5361	pick-up	0	17
89394	2020-07-03 10:34:39	2020-07-03	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9989	pick-up	0	35
89395	2020-07-03 10:42:32	2020-07-03	8	[{"id_menu":5,"count":1}]	30937	delivery	5	13
89396	2020-07-03 10:44:16	2020-07-03	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	34804	delivery	5	27
89397	2020-07-03 10:57:40	2020-07-03	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	34915	delivery	5	40
89398	2020-07-03 10:58:30	2020-07-03	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	23390	delivery	5	40
89399	2020-07-03 11:01:38	2020-07-03	9	[{"id_menu":6,"count":1}]	26261	delivery	5	14
89400	2020-07-03 11:05:03	2020-07-03	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	27931	delivery	5	37
89401	2020-07-03 11:08:04	2020-07-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2367	pick-up	0	26
89402	2020-07-03 11:08:57	2020-07-03	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	32886	delivery	5	30
89403	2020-07-03 11:10:51	2020-07-03	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	34919	delivery	5	22
89404	2020-07-03 11:10:51	2020-07-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	27997	delivery	5	28
89405	2020-07-03 11:18:12	2020-07-03	9	[{"id_menu":6,"count":1}]	30233	pick-up	0	9
89406	2020-07-03 11:29:20	2020-07-03	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	4624	pick-up	0	35
89407	2020-07-03 11:30:56	2020-07-03	12	[{"id_menu":3,"count":1}]	34846	delivery	5	17
89408	2020-07-03 11:31:21	2020-07-03	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	34499	delivery	5	34
89409	2020-07-03 11:36:52	2020-07-03	12	[{"id_menu":1,"count":1}]	1605	pick-up	0	12
89410	2020-07-03 11:41:28	2020-07-03	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	20598	delivery	5	36
89411	2020-07-03 11:43:46	2020-07-03	17	[{"id_menu":4,"count":1}]	34799	delivery	5	22
89412	2020-07-03 11:44:06	2020-07-03	9	[{"id_menu":6,"count":1}]	34894	delivery	5	14
89413	2020-07-03 11:44:20	2020-07-03	12	[{"id_menu":3,"count":1}]	20196	delivery	5	17
89414	2020-07-03 11:46:27	2020-07-03	8	[{"id_menu":5,"count":1}]	11707	delivery	5	13
89415	2020-07-03 11:51:04	2020-07-03	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	25602	delivery	5	25
89416	2020-07-03 11:57:03	2020-07-03	9	[{"id_menu":7,"count":1}]	30981	delivery	5	14
89417	2020-07-03 11:57:12	2020-07-03	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2901	pick-up	0	18
89418	2020-07-03 11:57:38	2020-07-03	9	[{"id_menu":7,"count":1}]	34981	delivery	5	14
89419	2020-07-03 12:01:23	2020-07-03	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	9192	delivery	5	25
89420	2020-07-03 12:08:29	2020-07-03	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8796	delivery	5	34
89421	2020-07-03 12:12:19	2020-07-03	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	31661	pick-up	0	17
89422	2020-07-03 12:13:55	2020-07-03	14	[{"id_menu":2,"count":1}]	34789	delivery	5	19
89423	2020-07-03 12:21:05	2020-07-03	12	[{"id_menu":1,"count":1}]	34926	delivery	5	17
89424	2020-07-03 12:22:57	2020-07-03	9	[{"id_menu":7,"count":1}]	6513	delivery	5	14
89425	2020-07-03 12:24:02	2020-07-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	4595	pick-up	0	23
89426	2020-07-03 12:30:50	2020-07-03	8	[{"id_menu":5,"count":1}]	5509	delivery	5	13
89427	2020-07-03 12:31:08	2020-07-03	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	34889	delivery	5	25
89428	2020-07-03 12:32:33	2020-07-03	9	[{"id_menu":7,"count":1}]	30629	delivery	5	14
89429	2020-07-03 12:34:45	2020-07-03	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3708	delivery	5	31
89430	2020-07-03 12:36:15	2020-07-03	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	23512	delivery	5	45
89431	2020-07-03 12:36:40	2020-07-03	12	[{"id_menu":3,"count":1}]	10041	pick-up	0	12
89432	2020-07-03 12:39:10	2020-07-03	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	34508	delivery	5	27
89433	2020-07-03 12:39:23	2020-07-03	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	34893	delivery	5	40
89434	2020-07-03 12:45:06	2020-07-03	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	25286	delivery	5	26
89435	2020-07-03 12:45:20	2020-07-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	19498	delivery	5	31
89436	2020-07-03 12:48:09	2020-07-03	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	31117	delivery	5	43
89437	2020-07-03 12:49:33	2020-07-03	8	[{"id_menu":5,"count":1}]	22294	pick-up	0	8
89438	2020-07-03 12:50:17	2020-07-03	14	[{"id_menu":2,"count":1}]	15645	pick-up	0	14
89439	2020-07-03 12:52:07	2020-07-03	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	25954	pick-up	0	34
89440	2020-07-03 12:55:36	2020-07-03	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	34864	delivery	5	28
89441	2020-07-03 13:02:11	2020-07-03	8	[{"id_menu":5,"count":1}]	6019	delivery	5	13
89442	2020-07-03 13:02:14	2020-07-03	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15605	delivery	5	45
89443	2020-07-03 13:05:42	2020-07-03	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	17003	delivery	5	26
89444	2020-07-03 13:17:13	2020-07-03	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	5643	pick-up	0	31
89445	2020-07-03 13:17:51	2020-07-03	9	[{"id_menu":6,"count":1}]	34808	delivery	5	14
89446	2020-07-03 13:20:04	2020-07-03	17	[{"id_menu":4,"count":1}]	23886	pick-up	0	17
89447	2020-07-03 13:31:04	2020-07-03	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	34880	delivery	5	27
89448	2020-07-03 13:32:12	2020-07-03	12	[{"id_menu":1,"count":1}]	34908	pick-up	0	12
89449	2020-07-03 13:33:29	2020-07-03	8	[{"id_menu":5,"count":1}]	26557	delivery	5	13
89450	2020-07-03 13:34:57	2020-07-03	12	[{"id_menu":3,"count":1}]	33574	delivery	5	17
89451	2020-07-03 13:35:44	2020-07-03	9	[{"id_menu":7,"count":1}]	25022	delivery	5	14
89452	2020-07-03 13:37:49	2020-07-03	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	9343	delivery	5	36
89453	2020-07-03 13:39:42	2020-07-03	8	[{"id_menu":5,"count":1}]	34861	delivery	5	13
89454	2020-07-03 13:42:17	2020-07-03	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9097	pick-up	0	42
89455	2020-07-03 13:43:20	2020-07-03	14	[{"id_menu":2,"count":1}]	2227	pick-up	0	14
89456	2020-07-03 13:51:37	2020-07-03	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	20823	delivery	5	26
89457	2020-07-03 13:53:32	2020-07-03	14	[{"id_menu":2,"count":1}]	612	pick-up	0	14
89458	2020-07-03 14:03:48	2020-07-03	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27745	delivery	5	22
89459	2020-07-03 14:08:32	2020-07-03	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	9640	pick-up	0	20
89460	2020-07-03 14:10:47	2020-07-03	14	[{"id_menu":2,"count":1}]	34969	delivery	5	19
89461	2020-07-03 14:12:23	2020-07-03	14	[{"id_menu":2,"count":1}]	19514	pick-up	0	14
89462	2020-07-03 14:13:39	2020-07-03	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	15105	delivery	5	40
89463	2020-07-03 14:16:05	2020-07-03	8	[{"id_menu":5,"count":1}]	34987	delivery	5	13
89464	2020-07-03 14:20:15	2020-07-03	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	30841	delivery	5	40
89465	2020-07-03 14:21:01	2020-07-03	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	14123	delivery	5	38
89466	2020-07-03 14:23:19	2020-07-03	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	34975	delivery	5	48
89467	2020-07-03 14:27:25	2020-07-03	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	34783	delivery	5	31
89468	2020-07-03 14:27:30	2020-07-03	9	[{"id_menu":6,"count":1}]	34801	delivery	5	14
89469	2020-07-03 14:28:11	2020-07-03	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6515	delivery	5	23
89470	2020-07-03 14:28:29	2020-07-03	9	[{"id_menu":7,"count":1}]	34990	delivery	5	14
89471	2020-07-03 14:29:09	2020-07-03	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	34978	delivery	5	27
89472	2020-07-03 14:29:17	2020-07-03	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	34879	delivery	5	44
89473	2020-07-03 14:32:53	2020-07-03	12	[{"id_menu":1,"count":1}]	519	delivery	5	17
89474	2020-07-03 14:39:58	2020-07-03	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1653	pick-up	0	25
89475	2020-07-03 14:41:48	2020-07-03	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	33346	delivery	5	23
89476	2020-07-03 14:42:23	2020-07-03	9	[{"id_menu":7,"count":1}]	4917	delivery	5	14
89477	2020-07-03 14:43:56	2020-07-03	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	34785	delivery	5	25
89478	2020-07-03 14:45:40	2020-07-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9744	delivery	5	28
89479	2020-07-03 14:45:43	2020-07-03	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23307	delivery	5	43
89480	2020-07-03 14:49:06	2020-07-03	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	30454	pick-up	0	35
89481	2020-07-03 14:49:16	2020-07-03	8	[{"id_menu":5,"count":1}]	34777	delivery	5	13
89482	2020-07-03 14:49:39	2020-07-03	12	[{"id_menu":1,"count":1}]	3363	pick-up	0	12
89483	2020-07-03 14:50:49	2020-07-03	9	[{"id_menu":6,"count":1}]	34910	delivery	5	14
89484	2020-07-03 14:57:48	2020-07-03	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	34814	delivery	5	31
89485	2020-07-03 14:58:25	2020-07-03	9	[{"id_menu":6,"count":1}]	34817	delivery	5	14
89486	2020-07-03 15:00:31	2020-07-03	14	[{"id_menu":2,"count":1}]	476	pick-up	0	14
89487	2020-07-03 15:03:51	2020-07-03	14	[{"id_menu":2,"count":1}]	34822	pick-up	0	14
89488	2020-07-03 15:03:57	2020-07-03	12	[{"id_menu":1,"count":1}]	1685	delivery	5	17
89489	2020-07-03 15:04:29	2020-07-03	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	29287	delivery	5	36
89490	2020-07-03 15:04:57	2020-07-03	9	[{"id_menu":6,"count":1}]	20182	delivery	5	14
89491	2020-07-03 15:07:48	2020-07-03	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6586	delivery	5	22
89492	2020-07-03 15:09:01	2020-07-03	17	[{"id_menu":4,"count":1}]	552	pick-up	0	17
89493	2020-07-03 15:13:06	2020-07-03	9	[{"id_menu":7,"count":1}]	18375	delivery	5	14
89494	2020-07-03 15:15:49	2020-07-03	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	11152	delivery	5	26
89495	2020-07-03 15:18:25	2020-07-03	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34873	delivery	5	31
89496	2020-07-03 15:21:44	2020-07-03	9	[{"id_menu":6,"count":1}]	2630	pick-up	0	9
89497	2020-07-03 15:23:55	2020-07-03	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	16640	delivery	5	26
89498	2020-07-03 15:23:56	2020-07-03	9	[{"id_menu":7,"count":1}]	34829	delivery	5	14
89499	2020-07-03 15:24:53	2020-07-03	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	34976	delivery	5	31
89500	2020-07-03 15:30:56	2020-07-03	9	[{"id_menu":7,"count":1}]	2339	delivery	5	14
89501	2020-07-03 15:33:00	2020-07-03	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	11827	delivery	5	40
89502	2020-07-03 15:33:08	2020-07-03	14	[{"id_menu":2,"count":1}]	10876	delivery	5	19
89503	2020-07-03 15:33:40	2020-07-03	12	[{"id_menu":3,"count":1}]	13874	pick-up	0	12
89504	2020-07-03 15:35:07	2020-07-03	9	[{"id_menu":6,"count":3}]	26610	delivery	5	14
89505	2020-07-03 15:36:53	2020-07-03	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	14716	delivery	5	30
89506	2020-07-03 15:37:08	2020-07-03	17	[{"id_menu":4,"count":1}]	3618	delivery	5	22
89507	2020-07-03 15:41:26	2020-07-03	14	[{"id_menu":2,"count":1}]	34911	delivery	5	19
89508	2020-07-03 15:41:44	2020-07-03	9	[{"id_menu":7,"count":1}]	30165	delivery	5	14
89509	2020-07-03 15:45:06	2020-07-03	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	26393	pick-up	0	21
89510	2020-07-03 15:46:54	2020-07-03	9	[{"id_menu":7,"count":1}]	34998	delivery	5	14
89511	2020-07-03 15:47:19	2020-07-03	8	[{"id_menu":5,"count":1}]	35002	delivery	5	13
89512	2020-07-03 15:47:49	2020-07-03	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	34900	delivery	5	40
89513	2020-07-03 15:52:24	2020-07-03	9	[{"id_menu":6,"count":1}]	25204	delivery	5	14
89514	2020-07-03 15:53:19	2020-07-03	17	[{"id_menu":4,"count":1}]	23698	delivery	5	22
89515	2020-07-03 15:53:29	2020-07-03	14	[{"id_menu":2,"count":1}]	17809	delivery	5	19
89516	2020-07-03 15:54:41	2020-07-03	9	[{"id_menu":6,"count":1}]	13824	delivery	5	14
89517	2020-07-03 15:56:01	2020-07-03	12	[{"id_menu":1,"count":1}]	34833	delivery	5	17
89518	2020-07-03 15:56:02	2020-07-03	8	[{"id_menu":5,"count":1}]	21887	delivery	5	13
89519	2020-07-03 16:00:31	2020-07-03	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	34955	delivery	5	30
89520	2020-07-03 16:04:37	2020-07-03	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	34442	delivery	5	31
89521	2020-07-03 16:05:39	2020-07-03	8	[{"id_menu":5,"count":2}]	8382	delivery	5	13
89522	2020-07-03 16:07:25	2020-07-03	9	[{"id_menu":7,"count":1}]	34863	delivery	5	14
89523	2020-07-03 16:10:37	2020-07-03	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15109	delivery	5	22
89524	2020-07-03 16:11:26	2020-07-03	12	[{"id_menu":3,"count":1}]	34939	delivery	5	17
89525	2020-07-03 16:15:13	2020-07-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	19313	pick-up	0	23
89526	2020-07-03 16:18:24	2020-07-03	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	34974	delivery	5	44
89527	2020-07-03 16:19:41	2020-07-03	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	34958	delivery	5	43
89528	2020-07-03 16:21:43	2020-07-03	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34856	pick-up	0	18
89529	2020-07-03 16:22:02	2020-07-03	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	6729	delivery	5	25
89530	2020-07-03 16:25:41	2020-07-03	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	34832	delivery	5	26
89531	2020-07-03 16:26:10	2020-07-03	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	8666	pick-up	0	31
89532	2020-07-03 16:28:38	2020-07-03	9	[{"id_menu":7,"count":1}]	34907	pick-up	0	9
89533	2020-07-03 16:36:46	2020-07-03	12	[{"id_menu":3,"count":1}]	10253	pick-up	0	12
89534	2020-07-03 16:37:39	2020-07-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	34878	delivery	5	28
89535	2020-07-03 16:40:05	2020-07-03	17	[{"id_menu":4,"count":1}]	22951	delivery	5	22
89536	2020-07-03 16:41:31	2020-07-03	12	[{"id_menu":1,"count":1}]	3382	delivery	5	17
89537	2020-07-03 16:44:07	2020-07-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	22272	delivery	5	31
89538	2020-07-03 16:48:20	2020-07-03	12	[{"id_menu":3,"count":1}]	31010	delivery	5	17
89539	2020-07-03 16:49:53	2020-07-03	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	29657	delivery	5	40
89540	2020-07-03 16:49:59	2020-07-03	17	[{"id_menu":4,"count":1}]	32648	pick-up	0	17
89541	2020-07-03 16:50:38	2020-07-03	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11555	delivery	5	46
89542	2020-07-03 16:53:23	2020-07-03	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	30279	delivery	5	25
89543	2020-07-03 16:53:41	2020-07-03	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	8640	pick-up	0	31
89544	2020-07-03 16:54:12	2020-07-03	12	[{"id_menu":3,"count":1}]	34821	pick-up	0	12
89545	2020-07-03 16:57:05	2020-07-03	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	22890	delivery	5	40
89546	2020-07-03 17:01:59	2020-07-03	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	23986	delivery	5	31
89547	2020-07-03 17:05:37	2020-07-03	12	[{"id_menu":1,"count":1}]	18459	delivery	5	17
89548	2020-07-03 17:09:42	2020-07-03	9	[{"id_menu":6,"count":3}]	12498	delivery	5	14
89549	2020-07-03 17:17:00	2020-07-03	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	34993	delivery	5	34
89550	2020-07-03 17:19:01	2020-07-03	8	[{"id_menu":5,"count":1}]	15426	delivery	5	13
89551	2020-07-03 17:25:42	2020-07-03	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	765	delivery	5	28
89552	2020-07-03 17:34:30	2020-07-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	27772	pick-up	0	26
89553	2020-07-03 17:37:17	2020-07-03	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22472	delivery	5	22
89554	2020-07-03 17:37:56	2020-07-03	14	[{"id_menu":2,"count":1}]	634	pick-up	0	14
89555	2020-07-03 17:40:13	2020-07-03	14	[{"id_menu":2,"count":1}]	8109	pick-up	0	14
89556	2020-07-03 17:41:22	2020-07-03	12	[{"id_menu":3,"count":1}]	35003	delivery	5	17
89557	2020-07-03 17:42:15	2020-07-03	14	[{"id_menu":2,"count":3}]	29078	delivery	5	19
89558	2020-07-03 17:43:36	2020-07-03	9	[{"id_menu":6,"count":1}]	1935	pick-up	0	9
89559	2020-07-03 17:43:41	2020-07-03	8	[{"id_menu":5,"count":1}]	14136	delivery	5	13
89560	2020-07-03 17:46:45	2020-07-03	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34240	delivery	5	52
89561	2020-07-03 17:53:39	2020-07-03	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	34928	delivery	5	34
89562	2020-07-03 17:55:10	2020-07-03	9	[{"id_menu":7,"count":1}]	34913	delivery	5	14
89563	2020-07-03 17:56:02	2020-07-03	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	27187	delivery	5	42
89564	2020-07-03 17:57:08	2020-07-03	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	25526	pick-up	0	52
89565	2020-07-03 17:58:48	2020-07-03	17	[{"id_menu":4,"count":1}]	1343	delivery	5	22
89566	2020-07-03 17:59:33	2020-07-03	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	2512	pick-up	0	21
89567	2020-07-03 18:00:14	2020-07-03	9	[{"id_menu":6,"count":1}]	34883	delivery	5	14
89568	2020-07-03 18:04:07	2020-07-03	17	[{"id_menu":4,"count":1}]	19554	pick-up	0	17
89569	2020-07-03 18:05:57	2020-07-03	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	364	delivery	5	39
89570	2020-07-03 18:07:30	2020-07-03	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	9358	delivery	5	31
89571	2020-07-03 18:08:42	2020-07-03	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	34851	delivery	5	36
89572	2020-07-03 18:16:26	2020-07-03	9	[{"id_menu":6,"count":1}]	34959	delivery	5	14
89573	2020-07-03 18:18:40	2020-07-03	17	[{"id_menu":4,"count":1}]	28927	pick-up	0	17
89574	2020-07-03 18:29:05	2020-07-03	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	13399	delivery	5	31
89575	2020-07-03 18:30:33	2020-07-03	9	[{"id_menu":7,"count":1}]	16917	delivery	5	14
89576	2020-07-03 18:33:23	2020-07-03	9	[{"id_menu":6,"count":1}]	1050	pick-up	0	9
89577	2020-07-03 18:37:25	2020-07-03	9	[{"id_menu":6,"count":1}]	34874	delivery	5	14
89578	2020-07-03 18:38:49	2020-07-03	17	[{"id_menu":4,"count":1}]	30923	delivery	5	22
89579	2020-07-03 18:39:30	2020-07-03	14	[{"id_menu":2,"count":1}]	7332	delivery	5	19
89580	2020-07-03 18:40:45	2020-07-03	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8083	pick-up	0	37
89581	2020-07-03 18:42:41	2020-07-03	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	34244	delivery	5	45
89582	2020-07-03 18:51:33	2020-07-03	14	[{"id_menu":2,"count":2}]	33380	delivery	5	19
89583	2020-07-03 18:56:51	2020-07-03	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	18503	delivery	5	25
89584	2020-07-03 19:00:09	2020-07-03	12	[{"id_menu":1,"count":1}]	20391	pick-up	0	12
89585	2020-07-03 19:05:02	2020-07-03	14	[{"id_menu":2,"count":1}]	34866	delivery	5	19
89586	2020-07-03 19:06:02	2020-07-03	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	18112	delivery	5	43
89587	2020-07-03 19:07:22	2020-07-03	9	[{"id_menu":7,"count":1}]	2735	pick-up	0	9
89588	2020-07-03 19:08:07	2020-07-03	12	[{"id_menu":3,"count":1}]	34924	delivery	5	17
89589	2020-07-03 19:08:17	2020-07-03	17	[{"id_menu":4,"count":1}]	26846	pick-up	0	17
89590	2020-07-03 19:09:42	2020-07-03	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	26092	delivery	5	26
89591	2020-07-03 19:14:47	2020-07-03	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	34956	delivery	5	26
89592	2020-07-03 19:15:16	2020-07-03	17	[{"id_menu":4,"count":1}]	34855	pick-up	0	17
89593	2020-07-03 19:15:17	2020-07-03	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34891	delivery	5	52
89594	2020-07-03 19:18:12	2020-07-03	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	19280	delivery	5	40
89595	2020-07-03 19:19:43	2020-07-03	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	34826	pick-up	0	26
89596	2020-07-03 19:20:52	2020-07-03	9	[{"id_menu":7,"count":2}]	28320	delivery	5	14
89597	2020-07-03 19:22:25	2020-07-03	17	[{"id_menu":4,"count":1}]	28547	delivery	5	22
89598	2020-07-03 19:26:25	2020-07-03	9	[{"id_menu":7,"count":1}]	31480	delivery	5	14
89599	2020-07-03 19:26:46	2020-07-03	8	[{"id_menu":5,"count":1}]	3704	pick-up	0	8
89600	2020-07-03 19:27:14	2020-07-03	14	[{"id_menu":2,"count":1}]	14202	delivery	5	19
89601	2020-07-03 19:27:32	2020-07-03	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	34953	delivery	5	43
89602	2020-07-03 19:32:08	2020-07-03	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	8054	delivery	5	26
89603	2020-07-03 19:32:54	2020-07-03	9	[{"id_menu":7,"count":1}]	16419	delivery	5	14
89604	2020-07-03 19:33:18	2020-07-03	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34986	delivery	5	37
89605	2020-07-03 19:37:34	2020-07-03	9	[{"id_menu":6,"count":1}]	16122	delivery	5	14
89606	2020-07-03 19:38:52	2020-07-03	8	[{"id_menu":5,"count":1}]	24992	delivery	5	13
89607	2020-07-03 19:39:53	2020-07-03	9	[{"id_menu":7,"count":1}]	24332	delivery	5	14
89608	2020-07-03 19:40:44	2020-07-03	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	34782	delivery	5	39
89609	2020-07-03 19:45:17	2020-07-03	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	34945	pick-up	0	26
89610	2020-07-03 19:48:43	2020-07-03	17	[{"id_menu":4,"count":1}]	18228	pick-up	0	17
89611	2020-07-03 19:50:59	2020-07-03	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8609	delivery	5	49
89612	2020-07-03 19:51:32	2020-07-03	9	[{"id_menu":6,"count":1}]	24402	delivery	5	14
89613	2020-07-03 19:59:35	2020-07-03	9	[{"id_menu":7,"count":1}]	34967	delivery	5	14
89614	2020-07-03 20:03:37	2020-07-03	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	788	delivery	5	26
89615	2020-07-03 20:04:28	2020-07-03	17	[{"id_menu":4,"count":1}]	10589	pick-up	0	17
89616	2020-07-03 20:04:42	2020-07-03	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	11932	delivery	5	26
89617	2020-07-03 20:05:52	2020-07-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	24273	delivery	5	28
89618	2020-07-03 20:06:08	2020-07-03	12	[{"id_menu":3,"count":1}]	34795	delivery	5	17
89619	2020-07-03 20:06:24	2020-07-03	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	8968	delivery	5	43
89620	2020-07-03 20:12:30	2020-07-03	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	2618	pick-up	0	23
89621	2020-07-03 20:14:24	2020-07-03	8	[{"id_menu":5,"count":1}]	34820	delivery	5	13
89622	2020-07-03 20:15:41	2020-07-03	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	10550	delivery	5	43
89623	2020-07-03 20:16:36	2020-07-03	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	9876	delivery	5	26
89624	2020-07-03 20:17:15	2020-07-03	12	[{"id_menu":1,"count":1}]	4342	pick-up	0	12
89625	2020-07-03 20:17:17	2020-07-03	9	[{"id_menu":6,"count":1}]	34980	delivery	5	14
89626	2020-07-03 20:17:30	2020-07-03	9	[{"id_menu":6,"count":1}]	32255	delivery	5	14
89627	2020-07-03 20:23:07	2020-07-03	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	3224	pick-up	0	26
89628	2020-07-03 20:27:02	2020-07-03	8	[{"id_menu":5,"count":1}]	25471	delivery	5	13
89629	2020-07-03 20:32:46	2020-07-03	8	[{"id_menu":5,"count":1}]	14104	delivery	5	13
89630	2020-07-03 20:38:43	2020-07-03	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	30858	delivery	5	36
89631	2020-07-03 20:47:21	2020-07-03	8	[{"id_menu":5,"count":1}]	29453	delivery	5	13
89632	2020-07-03 20:48:56	2020-07-03	17	[{"id_menu":4,"count":1}]	34897	delivery	5	22
89633	2020-07-03 20:49:09	2020-07-03	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1366	pick-up	0	38
89634	2020-07-03 21:00:34	2020-07-03	14	[{"id_menu":2,"count":1}]	5527	delivery	5	19
89635	2020-07-03 21:04:17	2020-07-03	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	30153	delivery	5	45
89636	2020-07-03 21:06:47	2020-07-03	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	34862	delivery	5	40
89637	2020-07-03 21:07:14	2020-07-03	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	19566	delivery	5	26
89638	2020-07-03 21:09:01	2020-07-03	9	[{"id_menu":7,"count":1}]	12151	delivery	5	14
89639	2020-07-03 21:10:13	2020-07-03	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33464	delivery	5	45
89640	2020-07-03 21:10:25	2020-07-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1843	delivery	5	31
89641	2020-07-03 21:15:18	2020-07-03	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16041	delivery	5	31
89642	2020-07-03 21:15:46	2020-07-03	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26909	delivery	5	23
89643	2020-07-03 21:23:59	2020-07-03	12	[{"id_menu":3,"count":3}]	18479	delivery	5	17
89644	2020-07-03 21:27:00	2020-07-03	12	[{"id_menu":1,"count":1}]	34906	delivery	5	17
89645	2020-07-03 21:30:53	2020-07-03	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	25815	delivery	5	35
89646	2020-07-03 21:31:07	2020-07-03	12	[{"id_menu":3,"count":1}]	12990	delivery	5	17
89647	2020-07-03 21:36:15	2020-07-03	12	[{"id_menu":3,"count":1}]	18677	delivery	5	17
89648	2020-07-03 21:37:20	2020-07-03	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	31186	delivery	5	30
89649	2020-07-03 21:38:11	2020-07-03	17	[{"id_menu":4,"count":1}]	3018	pick-up	0	17
89650	2020-07-03 21:40:00	2020-07-03	12	[{"id_menu":1,"count":1}]	34966	pick-up	0	12
89651	2020-07-03 21:45:21	2020-07-03	14	[{"id_menu":2,"count":1}]	28230	pick-up	0	14
89652	2020-07-03 21:47:36	2020-07-03	8	[{"id_menu":5,"count":1}]	34899	delivery	5	13
89653	2020-07-03 21:49:09	2020-07-03	12	[{"id_menu":1,"count":1}]	29879	delivery	5	17
89654	2020-07-03 21:49:18	2020-07-03	17	[{"id_menu":4,"count":1}]	1262	pick-up	0	17
89655	2020-07-03 21:49:41	2020-07-03	9	[{"id_menu":6,"count":1}]	34786	delivery	5	14
89656	2020-07-03 21:49:49	2020-07-03	17	[{"id_menu":4,"count":1}]	23954	pick-up	0	17
89657	2020-07-03 21:50:03	2020-07-03	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	25352	delivery	5	34
89658	2020-07-03 21:59:20	2020-07-03	12	[{"id_menu":3,"count":1}]	34791	delivery	5	17
89659	2020-07-03 22:01:04	2020-07-03	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	13636	delivery	5	40
89660	2020-07-03 22:07:52	2020-07-03	14	[{"id_menu":2,"count":1}]	27029	delivery	5	19
89661	2020-07-03 22:11:56	2020-07-03	17	[{"id_menu":4,"count":1}]	14328	pick-up	0	17
89662	2020-07-03 22:14:51	2020-07-03	14	[{"id_menu":2,"count":1}]	27148	delivery	5	19
89663	2020-07-03 22:15:38	2020-07-03	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11985	delivery	5	31
89664	2020-07-03 22:19:29	2020-07-03	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9684	delivery	5	39
89665	2020-07-03 22:26:57	2020-07-03	14	[{"id_menu":2,"count":1}]	3701	pick-up	0	14
89666	2020-07-03 22:28:26	2020-07-03	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	31031	delivery	5	31
89667	2020-07-03 22:28:40	2020-07-03	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	34936	delivery	5	34
89668	2020-07-03 22:28:45	2020-07-03	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10639	delivery	5	30
89669	2020-07-03 22:29:25	2020-07-03	9	[{"id_menu":7,"count":1}]	34836	delivery	5	14
89670	2020-07-03 22:29:33	2020-07-03	14	[{"id_menu":2,"count":1}]	34825	pick-up	0	14
89671	2020-07-03 22:31:02	2020-07-03	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	34809	delivery	5	39
89672	2020-07-03 22:35:22	2020-07-03	9	[{"id_menu":6,"count":1}]	34934	pick-up	0	9
89673	2020-07-03 22:35:37	2020-07-03	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	15386	delivery	5	40
89674	2020-07-03 22:35:46	2020-07-03	12	[{"id_menu":3,"count":1}]	4453	pick-up	0	12
89675	2020-07-03 22:40:09	2020-07-03	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23587	delivery	5	43
89676	2020-07-03 22:42:25	2020-07-03	12	[{"id_menu":1,"count":1}]	20803	delivery	5	17
89677	2020-07-03 22:44:26	2020-07-03	8	[{"id_menu":5,"count":1}]	34805	delivery	5	13
89678	2020-07-03 22:44:31	2020-07-03	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	34917	delivery	5	27
89679	2020-07-03 22:44:37	2020-07-03	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	33546	pick-up	0	40
89680	2020-07-03 22:46:11	2020-07-03	14	[{"id_menu":2,"count":1}]	5551	pick-up	0	14
89681	2020-07-03 22:48:49	2020-07-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2189	pick-up	0	23
89682	2020-07-03 22:53:33	2020-07-03	9	[{"id_menu":7,"count":1}]	6617	pick-up	0	9
89683	2020-07-03 22:53:55	2020-07-03	17	[{"id_menu":4,"count":1}]	34944	delivery	5	22
89684	2020-07-03 22:54:01	2020-07-03	9	[{"id_menu":6,"count":1}]	34853	pick-up	0	9
89685	2020-07-03 23:03:49	2020-07-03	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	34815	delivery	5	22
89686	2020-07-03 23:04:00	2020-07-03	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	12274	pick-up	0	21
89687	2020-07-03 23:06:22	2020-07-03	12	[{"id_menu":3,"count":1}]	34930	pick-up	0	12
89688	2020-07-03 23:10:31	2020-07-03	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	34834	delivery	5	42
89689	2020-07-03 23:12:46	2020-07-03	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	21189	delivery	5	40
89690	2020-07-03 23:13:39	2020-07-03	14	[{"id_menu":2,"count":1}]	34813	delivery	5	19
89691	2020-07-03 23:14:53	2020-07-03	9	[{"id_menu":6,"count":1}]	34796	delivery	5	14
89692	2020-07-03 23:15:14	2020-07-03	12	[{"id_menu":3,"count":1}]	34793	delivery	5	17
89693	2020-07-03 23:18:57	2020-07-03	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	34776	delivery	5	26
89694	2020-07-03 23:19:20	2020-07-03	9	[{"id_menu":6,"count":1}]	34989	delivery	5	14
89695	2020-07-03 23:19:58	2020-07-03	9	[{"id_menu":7,"count":1}]	17911	delivery	5	14
89696	2020-07-03 23:21:34	2020-07-03	8	[{"id_menu":5,"count":1}]	34941	delivery	5	13
89697	2020-07-03 23:29:15	2020-07-03	9	[{"id_menu":6,"count":1}]	15750	delivery	5	14
89698	2020-07-03 23:35:15	2020-07-03	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	34872	delivery	5	29
89699	2020-07-03 23:36:03	2020-07-03	14	[{"id_menu":2,"count":1}]	13477	delivery	5	19
89700	2020-07-03 23:39:02	2020-07-03	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	34968	delivery	5	34
89701	2020-07-03 23:41:42	2020-07-03	8	[{"id_menu":5,"count":1}]	33348	delivery	5	13
89702	2020-07-03 23:42:59	2020-07-03	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	34852	delivery	5	45
89703	2020-07-03 23:43:38	2020-07-03	14	[{"id_menu":2,"count":1}]	34898	pick-up	0	14
89704	2020-07-03 23:47:22	2020-07-03	14	[{"id_menu":2,"count":1}]	17763	delivery	5	19
89705	2020-07-03 23:47:31	2020-07-03	12	[{"id_menu":3,"count":1}]	34810	delivery	5	17
89706	2020-07-03 23:47:53	2020-07-03	9	[{"id_menu":7,"count":1}]	13293	delivery	5	14
89707	2020-07-03 23:49:48	2020-07-03	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	34962	delivery	5	36
89708	2020-07-03 23:53:02	2020-07-03	12	[{"id_menu":3,"count":1}]	15216	pick-up	0	12
89709	2020-07-03 23:54:45	2020-07-03	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7119	pick-up	0	40
89710	2020-07-03 23:55:51	2020-07-03	12	[{"id_menu":3,"count":1}]	11672	delivery	5	17
89711	2020-07-03 23:56:56	2020-07-03	12	[{"id_menu":1,"count":2}]	9404	pick-up	0	12
89712	2020-07-03 23:58:22	2020-07-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4047	delivery	5	28
89713	2020-07-03 23:59:15	2020-07-03	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9603	delivery	5	40
89714	2020-07-04 00:00:53	2020-07-04	9	[{"id_menu":7,"count":1}]	14314	pick-up	0	9
89715	2020-07-04 00:04:04	2020-07-04	8	[{"id_menu":5,"count":1}]	35189	delivery	5	13
89716	2020-07-04 00:04:45	2020-07-04	9	[{"id_menu":6,"count":1}]	14480	pick-up	0	9
89717	2020-07-04 00:05:51	2020-07-04	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10769	pick-up	0	26
89718	2020-07-04 00:09:28	2020-07-04	9	[{"id_menu":6,"count":1}]	35079	delivery	5	14
89719	2020-07-04 00:11:07	2020-07-04	9	[{"id_menu":6,"count":1}]	35053	pick-up	0	9
89720	2020-07-04 00:12:26	2020-07-04	9	[{"id_menu":7,"count":2}]	2994	delivery	5	14
89721	2020-07-04 00:13:55	2020-07-04	12	[{"id_menu":1,"count":2}]	14871	pick-up	0	12
89722	2020-07-04 00:15:49	2020-07-04	9	[{"id_menu":7,"count":1}]	35052	delivery	5	14
89723	2020-07-04 00:18:58	2020-07-04	12	[{"id_menu":3,"count":1}]	1672	pick-up	0	12
89724	2020-07-04 00:22:03	2020-07-04	14	[{"id_menu":2,"count":1}]	10245	delivery	5	19
89725	2020-07-04 00:24:55	2020-07-04	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8492	delivery	5	31
89726	2020-07-04 00:25:45	2020-07-04	12	[{"id_menu":3,"count":1}]	35076	delivery	5	17
89727	2020-07-04 00:25:54	2020-07-04	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	23470	delivery	5	30
89728	2020-07-04 00:29:23	2020-07-04	8	[{"id_menu":5,"count":1}]	18341	delivery	5	13
89729	2020-07-04 00:29:33	2020-07-04	17	[{"id_menu":4,"count":2}]	4933	delivery	5	22
89730	2020-07-04 00:30:29	2020-07-04	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	15044	delivery	5	26
89731	2020-07-04 00:31:24	2020-07-04	9	[{"id_menu":6,"count":1}]	25141	pick-up	0	9
89732	2020-07-04 00:33:54	2020-07-04	9	[{"id_menu":7,"count":1}]	35039	delivery	5	14
89733	2020-07-04 00:34:07	2020-07-04	14	[{"id_menu":2,"count":1}]	35057	delivery	5	19
89734	2020-07-04 00:36:08	2020-07-04	17	[{"id_menu":4,"count":1}]	35014	pick-up	0	17
89735	2020-07-04 00:38:18	2020-07-04	12	[{"id_menu":3,"count":1}]	4108	delivery	5	17
89736	2020-07-04 00:38:59	2020-07-04	17	[{"id_menu":4,"count":1}]	35173	pick-up	0	17
89737	2020-07-04 00:40:28	2020-07-04	9	[{"id_menu":7,"count":1}]	11732	pick-up	0	9
89738	2020-07-04 00:42:05	2020-07-04	9	[{"id_menu":6,"count":1}]	17130	delivery	5	14
89739	2020-07-04 00:44:01	2020-07-04	9	[{"id_menu":6,"count":1}]	35108	pick-up	0	9
89740	2020-07-04 00:46:06	2020-07-04	12	[{"id_menu":3,"count":1}]	12078	delivery	5	17
89741	2020-07-04 00:47:10	2020-07-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	25692	delivery	5	28
89742	2020-07-04 00:48:46	2020-07-04	14	[{"id_menu":2,"count":1}]	2668	pick-up	0	14
89743	2020-07-04 00:49:38	2020-07-04	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	31888	delivery	5	45
89744	2020-07-04 00:52:05	2020-07-04	12	[{"id_menu":3,"count":1}]	19598	delivery	5	17
89745	2020-07-04 00:52:55	2020-07-04	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20774	delivery	5	31
89746	2020-07-04 00:53:12	2020-07-04	9	[{"id_menu":6,"count":1}]	35127	delivery	5	14
89747	2020-07-04 00:55:04	2020-07-04	12	[{"id_menu":1,"count":1}]	33076	delivery	5	17
89748	2020-07-04 00:56:54	2020-07-04	9	[{"id_menu":7,"count":1}]	28339	delivery	5	14
89749	2020-07-04 01:01:52	2020-07-04	14	[{"id_menu":2,"count":1}]	25100	delivery	5	19
89750	2020-07-04 01:04:41	2020-07-04	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	24699	delivery	5	36
89751	2020-07-04 01:18:42	2020-07-04	9	[{"id_menu":6,"count":1}]	1982	pick-up	0	9
89752	2020-07-04 01:20:44	2020-07-04	17	[{"id_menu":4,"count":1}]	3048	delivery	5	22
89753	2020-07-04 01:26:32	2020-07-04	8	[{"id_menu":5,"count":2}]	35156	delivery	5	13
89754	2020-07-04 01:27:12	2020-07-04	9	[{"id_menu":7,"count":1}]	903	pick-up	0	9
89755	2020-07-04 01:34:19	2020-07-04	12	[{"id_menu":3,"count":1}]	24428	delivery	5	17
89756	2020-07-04 01:34:57	2020-07-04	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	23540	delivery	5	25
89757	2020-07-04 01:40:07	2020-07-04	14	[{"id_menu":2,"count":1}]	35027	pick-up	0	14
89758	2020-07-04 01:40:15	2020-07-04	17	[{"id_menu":4,"count":2}]	2333	pick-up	0	17
89759	2020-07-04 01:40:45	2020-07-04	12	[{"id_menu":1,"count":1}]	28640	delivery	5	17
89760	2020-07-04 01:45:28	2020-07-04	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	26765	delivery	5	42
89761	2020-07-04 01:46:13	2020-07-04	9	[{"id_menu":6,"count":1}]	35041	delivery	5	14
89762	2020-07-04 01:47:24	2020-07-04	9	[{"id_menu":7,"count":1}]	26361	delivery	5	14
89763	2020-07-04 01:47:28	2020-07-04	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	35111	delivery	5	27
89764	2020-07-04 01:47:58	2020-07-04	12	[{"id_menu":3,"count":1}]	33828	delivery	5	17
89765	2020-07-04 01:48:26	2020-07-04	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	18392	delivery	5	36
89766	2020-07-04 01:49:24	2020-07-04	8	[{"id_menu":5,"count":1}]	26654	delivery	5	13
89767	2020-07-04 01:53:31	2020-07-04	9	[{"id_menu":6,"count":1}]	33717	delivery	5	14
89768	2020-07-04 01:55:29	2020-07-04	8	[{"id_menu":5,"count":1}]	35018	delivery	5	13
89769	2020-07-04 01:55:48	2020-07-04	8	[{"id_menu":5,"count":1}]	35010	delivery	5	13
89770	2020-07-04 02:01:46	2020-07-04	12	[{"id_menu":1,"count":1}]	15370	pick-up	0	12
89771	2020-07-04 02:02:02	2020-07-04	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14159	delivery	5	53
89772	2020-07-04 02:08:02	2020-07-04	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	31161	delivery	5	26
89773	2020-07-04 02:09:47	2020-07-04	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	8873	pick-up	0	26
89774	2020-07-04 02:10:51	2020-07-04	14	[{"id_menu":2,"count":1}]	6090	pick-up	0	14
89775	2020-07-04 02:15:49	2020-07-04	9	[{"id_menu":7,"count":1}]	16835	delivery	5	14
89776	2020-07-04 02:16:05	2020-07-04	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	35166	delivery	5	26
89777	2020-07-04 02:16:54	2020-07-04	9	[{"id_menu":6,"count":1}]	3128	pick-up	0	9
89778	2020-07-04 02:17:03	2020-07-04	8	[{"id_menu":5,"count":1}]	35135	delivery	5	13
89779	2020-07-04 02:22:53	2020-07-04	12	[{"id_menu":1,"count":1}]	15394	pick-up	0	12
89780	2020-07-04 02:23:28	2020-07-04	8	[{"id_menu":5,"count":1}]	21993	delivery	5	13
89781	2020-07-04 02:23:52	2020-07-04	17	[{"id_menu":4,"count":1}]	21592	delivery	5	22
89782	2020-07-04 02:27:31	2020-07-04	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3949	pick-up	0	18
89783	2020-07-04 02:28:05	2020-07-04	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	13994	delivery	5	26
89784	2020-07-04 02:34:42	2020-07-04	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	35187	delivery	5	34
89785	2020-07-04 02:36:31	2020-07-04	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	19476	pick-up	0	37
89786	2020-07-04 02:37:18	2020-07-04	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2238	pick-up	0	25
89787	2020-07-04 02:38:11	2020-07-04	9	[{"id_menu":7,"count":1}]	10227	delivery	5	14
89788	2020-07-04 02:41:02	2020-07-04	12	[{"id_menu":3,"count":1}]	35065	delivery	5	17
89789	2020-07-04 02:43:17	2020-07-04	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15291	delivery	5	22
89790	2020-07-04 02:45:57	2020-07-04	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22056	delivery	5	23
89791	2020-07-04 02:47:19	2020-07-04	12	[{"id_menu":3,"count":1}]	17062	delivery	5	17
89792	2020-07-04 02:48:19	2020-07-04	9	[{"id_menu":7,"count":1}]	4539	delivery	5	14
89793	2020-07-04 02:49:55	2020-07-04	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5779	pick-up	0	17
89794	2020-07-04 02:51:28	2020-07-04	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19729	pick-up	0	17
89795	2020-07-04 02:56:20	2020-07-04	17	[{"id_menu":4,"count":1}]	19011	pick-up	0	17
89796	2020-07-04 03:01:36	2020-07-04	12	[{"id_menu":3,"count":1}]	35016	pick-up	0	12
89797	2020-07-04 03:01:37	2020-07-04	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	33056	delivery	5	34
89798	2020-07-04 03:01:47	2020-07-04	9	[{"id_menu":7,"count":1}]	10354	delivery	5	14
89799	2020-07-04 03:04:46	2020-07-04	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	35176	delivery	5	22
89800	2020-07-04 03:05:32	2020-07-04	17	[{"id_menu":4,"count":1}]	1787	pick-up	0	17
89801	2020-07-04 03:10:51	2020-07-04	8	[{"id_menu":5,"count":1}]	18729	pick-up	0	8
89802	2020-07-04 03:10:56	2020-07-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1356	pick-up	0	23
89803	2020-07-04 03:12:16	2020-07-04	17	[{"id_menu":4,"count":1}]	9987	delivery	5	22
89804	2020-07-04 03:13:22	2020-07-04	9	[{"id_menu":6,"count":1}]	32316	delivery	5	14
89805	2020-07-04 03:14:01	2020-07-04	9	[{"id_menu":7,"count":1}]	5170	delivery	5	14
89806	2020-07-04 03:17:14	2020-07-04	8	[{"id_menu":5,"count":1}]	25317	pick-up	0	8
89807	2020-07-04 03:22:09	2020-07-04	9	[{"id_menu":7,"count":1}]	24505	delivery	5	14
89808	2020-07-04 03:23:50	2020-07-04	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	22350	delivery	5	34
89809	2020-07-04 03:25:23	2020-07-04	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27256	delivery	5	23
89810	2020-07-04 03:25:50	2020-07-04	9	[{"id_menu":7,"count":1}]	1461	pick-up	0	9
89811	2020-07-04 03:28:40	2020-07-04	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	25729	delivery	5	31
89812	2020-07-04 03:29:19	2020-07-04	12	[{"id_menu":1,"count":1}]	20725	delivery	5	17
89813	2020-07-04 03:38:44	2020-07-04	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	35048	delivery	5	31
89814	2020-07-04 03:41:33	2020-07-04	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21375	delivery	5	36
89815	2020-07-04 03:43:01	2020-07-04	9	[{"id_menu":6,"count":1}]	25912	delivery	5	14
89816	2020-07-04 03:46:16	2020-07-04	8	[{"id_menu":5,"count":1}]	35011	delivery	5	13
89817	2020-07-04 03:49:21	2020-07-04	12	[{"id_menu":3,"count":1}]	35116	delivery	5	17
89818	2020-07-04 03:53:16	2020-07-04	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35198	delivery	5	47
89819	2020-07-04 03:56:20	2020-07-04	14	[{"id_menu":2,"count":1}]	15671	delivery	5	19
89820	2020-07-04 03:56:21	2020-07-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	13634	delivery	5	28
89821	2020-07-04 03:57:34	2020-07-04	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	33311	delivery	5	26
89822	2020-07-04 03:59:23	2020-07-04	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35085	delivery	5	40
89823	2020-07-04 03:59:31	2020-07-04	17	[{"id_menu":4,"count":1}]	2572	pick-up	0	17
89824	2020-07-04 03:59:37	2020-07-04	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	22882	delivery	5	40
89825	2020-07-04 03:59:58	2020-07-04	9	[{"id_menu":6,"count":1}]	12201	delivery	5	14
89826	2020-07-04 04:00:34	2020-07-04	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	18945	delivery	5	37
89827	2020-07-04 04:06:44	2020-07-04	17	[{"id_menu":4,"count":1}]	9833	delivery	5	22
89828	2020-07-04 04:07:59	2020-07-04	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	35175	delivery	5	26
89829	2020-07-04 04:16:10	2020-07-04	9	[{"id_menu":6,"count":2}]	18936	delivery	5	14
89830	2020-07-04 04:17:28	2020-07-04	9	[{"id_menu":6,"count":1}]	15982	delivery	5	14
89831	2020-07-04 04:17:44	2020-07-04	12	[{"id_menu":1,"count":1}]	35115	delivery	5	17
89832	2020-07-04 04:18:28	2020-07-04	14	[{"id_menu":2,"count":1}]	13782	delivery	5	19
89833	2020-07-04 04:21:49	2020-07-04	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	203	delivery	5	26
89834	2020-07-04 04:23:01	2020-07-04	14	[{"id_menu":2,"count":1}]	10461	delivery	5	19
89835	2020-07-04 04:23:39	2020-07-04	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	20000	delivery	5	26
89836	2020-07-04 04:24:33	2020-07-04	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	9871	delivery	5	34
89837	2020-07-04 04:24:43	2020-07-04	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14354	delivery	5	45
89838	2020-07-04 04:27:12	2020-07-04	14	[{"id_menu":2,"count":1}]	35106	pick-up	0	14
89839	2020-07-04 04:30:54	2020-07-04	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	5095	delivery	5	40
89840	2020-07-04 04:31:46	2020-07-04	14	[{"id_menu":2,"count":1}]	2314	pick-up	0	14
89841	2020-07-04 04:32:57	2020-07-04	9	[{"id_menu":6,"count":1}]	35192	delivery	5	14
89842	2020-07-04 04:33:38	2020-07-04	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	73	pick-up	0	39
89843	2020-07-04 04:35:59	2020-07-04	14	[{"id_menu":2,"count":1}]	6331	delivery	5	19
89844	2020-07-04 04:37:10	2020-07-04	9	[{"id_menu":6,"count":1}]	35062	delivery	5	14
89845	2020-07-04 04:37:18	2020-07-04	9	[{"id_menu":7,"count":1}]	35093	delivery	5	14
89846	2020-07-04 04:40:43	2020-07-04	9	[{"id_menu":7,"count":1}]	23929	delivery	5	14
89847	2020-07-04 04:43:26	2020-07-04	9	[{"id_menu":7,"count":1}]	30604	delivery	5	14
89848	2020-07-04 04:43:43	2020-07-04	9	[{"id_menu":6,"count":1}]	2309	delivery	5	14
89849	2020-07-04 04:49:02	2020-07-04	12	[{"id_menu":1,"count":1}]	10063	pick-up	0	12
89850	2020-07-04 04:49:19	2020-07-04	9	[{"id_menu":7,"count":1}]	3461	pick-up	0	9
89851	2020-07-04 04:49:22	2020-07-04	12	[{"id_menu":3,"count":1}]	1713	pick-up	0	12
89852	2020-07-04 04:50:58	2020-07-04	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	16785	delivery	5	38
89853	2020-07-04 04:52:13	2020-07-04	12	[{"id_menu":3,"count":1}]	35045	delivery	5	17
89854	2020-07-04 04:55:11	2020-07-04	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	29098	delivery	5	29
89855	2020-07-04 04:55:48	2020-07-04	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	21543	delivery	5	26
89856	2020-07-04 05:01:23	2020-07-04	17	[{"id_menu":4,"count":3}]	23865	delivery	5	22
89857	2020-07-04 05:01:39	2020-07-04	9	[{"id_menu":7,"count":1}]	2511	pick-up	0	9
89858	2020-07-04 05:03:23	2020-07-04	12	[{"id_menu":3,"count":1}]	28448	delivery	5	17
89859	2020-07-04 05:05:53	2020-07-04	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	656	delivery	5	31
89860	2020-07-04 05:06:27	2020-07-04	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	31174	delivery	5	40
89861	2020-07-04 05:14:03	2020-07-04	9	[{"id_menu":7,"count":1}]	35066	delivery	5	14
89862	2020-07-04 05:15:58	2020-07-04	8	[{"id_menu":5,"count":1}]	7576	delivery	5	13
89863	2020-07-04 05:18:35	2020-07-04	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	35036	delivery	5	48
89864	2020-07-04 05:18:39	2020-07-04	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	35088	delivery	5	30
89865	2020-07-04 05:20:54	2020-07-04	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33746	delivery	5	40
89866	2020-07-04 05:22:37	2020-07-04	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	3100	delivery	5	26
89867	2020-07-04 05:30:18	2020-07-04	9	[{"id_menu":6,"count":1}]	6201	delivery	5	14
89868	2020-07-04 05:32:17	2020-07-04	14	[{"id_menu":2,"count":1}]	35153	delivery	5	19
89869	2020-07-04 05:33:26	2020-07-04	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12180	delivery	5	36
89870	2020-07-04 05:34:05	2020-07-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	35008	delivery	5	28
89871	2020-07-04 05:36:51	2020-07-04	14	[{"id_menu":2,"count":1}]	11038	delivery	5	19
89872	2020-07-04 05:50:01	2020-07-04	8	[{"id_menu":5,"count":1}]	4592	delivery	5	13
89873	2020-07-04 05:53:51	2020-07-04	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	11011	delivery	5	40
89874	2020-07-04 05:54:43	2020-07-04	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	35110	delivery	5	31
89875	2020-07-04 05:56:00	2020-07-04	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	24402	delivery	5	36
89876	2020-07-04 05:57:59	2020-07-04	14	[{"id_menu":2,"count":1}]	35138	pick-up	0	14
89877	2020-07-04 06:00:59	2020-07-04	17	[{"id_menu":4,"count":1}]	35078	delivery	5	22
89878	2020-07-04 06:04:44	2020-07-04	14	[{"id_menu":2,"count":1}]	35151	pick-up	0	14
89879	2020-07-04 06:12:50	2020-07-04	14	[{"id_menu":2,"count":1}]	35101	delivery	5	19
89880	2020-07-04 06:13:00	2020-07-04	9	[{"id_menu":7,"count":1}]	8845	delivery	5	14
89881	2020-07-04 06:13:38	2020-07-04	12	[{"id_menu":1,"count":1}]	35128	delivery	5	17
89882	2020-07-04 06:14:09	2020-07-04	9	[{"id_menu":7,"count":1}]	1337	delivery	5	14
89883	2020-07-04 06:14:50	2020-07-04	12	[{"id_menu":1,"count":1}]	32569	delivery	5	17
89884	2020-07-04 06:15:47	2020-07-04	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	19507	delivery	5	39
89885	2020-07-04 06:17:30	2020-07-04	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	35095	delivery	5	28
89886	2020-07-04 06:18:48	2020-07-04	9	[{"id_menu":6,"count":1}]	35107	delivery	5	14
89887	2020-07-04 06:20:34	2020-07-04	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16868	delivery	5	45
89888	2020-07-04 06:20:45	2020-07-04	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	7217	delivery	5	26
89889	2020-07-04 06:23:04	2020-07-04	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	8057	pick-up	0	21
89890	2020-07-04 06:23:49	2020-07-04	9	[{"id_menu":6,"count":1}]	35188	delivery	5	14
89891	2020-07-04 06:25:41	2020-07-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	35201	delivery	5	28
89892	2020-07-04 06:27:43	2020-07-04	8	[{"id_menu":5,"count":1}]	30534	pick-up	0	8
89893	2020-07-04 06:28:48	2020-07-04	14	[{"id_menu":2,"count":1}]	23946	delivery	5	19
89894	2020-07-04 06:29:49	2020-07-04	14	[{"id_menu":2,"count":1}]	15565	delivery	5	19
89895	2020-07-04 06:30:39	2020-07-04	9	[{"id_menu":6,"count":1}]	35125	delivery	5	14
89896	2020-07-04 06:32:54	2020-07-04	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	16285	delivery	5	26
89897	2020-07-04 06:33:31	2020-07-04	17	[{"id_menu":4,"count":1}]	35194	delivery	5	22
89898	2020-07-04 06:34:43	2020-07-04	12	[{"id_menu":1,"count":1}]	35067	pick-up	0	12
89899	2020-07-04 06:37:55	2020-07-04	8	[{"id_menu":5,"count":1}]	15743	delivery	5	13
89900	2020-07-04 06:38:43	2020-07-04	29	[{"id_menu":3,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21296	pick-up	0	29
89901	2020-07-04 06:40:25	2020-07-04	9	[{"id_menu":7,"count":2}]	979	pick-up	0	9
89902	2020-07-04 06:41:00	2020-07-04	12	[{"id_menu":3,"count":1}]	10495	delivery	5	17
89903	2020-07-04 06:42:49	2020-07-04	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3462	delivery	5	34
89904	2020-07-04 06:44:10	2020-07-04	12	[{"id_menu":3,"count":1}]	33461	pick-up	0	12
89905	2020-07-04 06:46:16	2020-07-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":3}]	11798	delivery	5	28
89906	2020-07-04 06:47:17	2020-07-04	17	[{"id_menu":4,"count":1}]	26065	pick-up	0	17
89907	2020-07-04 06:48:17	2020-07-04	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3313	pick-up	0	26
89908	2020-07-04 06:49:41	2020-07-04	14	[{"id_menu":2,"count":1}]	6756	pick-up	0	14
89909	2020-07-04 06:50:24	2020-07-04	8	[{"id_menu":5,"count":1}]	35086	delivery	5	13
89910	2020-07-04 06:54:25	2020-07-04	12	[{"id_menu":1,"count":1}]	13416	delivery	5	17
89911	2020-07-04 06:56:43	2020-07-04	17	[{"id_menu":4,"count":2}]	35118	delivery	5	22
89912	2020-07-04 06:59:21	2020-07-04	9	[{"id_menu":7,"count":1}]	32288	delivery	5	14
89913	2020-07-04 07:01:44	2020-07-04	17	[{"id_menu":4,"count":1}]	27161	pick-up	0	17
89914	2020-07-04 07:02:59	2020-07-04	14	[{"id_menu":2,"count":1}]	33484	delivery	5	19
89915	2020-07-04 07:04:07	2020-07-04	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11172	delivery	5	31
89916	2020-07-04 07:04:17	2020-07-04	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	611	delivery	5	25
89917	2020-07-04 07:05:10	2020-07-04	8	[{"id_menu":5,"count":1}]	35025	delivery	5	13
89918	2020-07-04 07:08:21	2020-07-04	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2367	pick-up	0	21
89919	2020-07-04 07:10:16	2020-07-04	12	[{"id_menu":1,"count":1}]	35070	delivery	5	17
89920	2020-07-04 07:10:23	2020-07-04	17	[{"id_menu":4,"count":1}]	2857	pick-up	0	17
89921	2020-07-04 07:12:13	2020-07-04	8	[{"id_menu":5,"count":1}]	35186	pick-up	0	8
89922	2020-07-04 07:18:02	2020-07-04	8	[{"id_menu":5,"count":1}]	35050	delivery	5	13
89923	2020-07-04 07:20:58	2020-07-04	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12053	delivery	5	22
89924	2020-07-04 07:21:38	2020-07-04	9	[{"id_menu":6,"count":1}]	2654	delivery	5	14
89925	2020-07-04 07:22:41	2020-07-04	12	[{"id_menu":1,"count":1}]	24116	pick-up	0	12
89926	2020-07-04 07:28:19	2020-07-04	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	35185	delivery	5	40
89927	2020-07-04 07:29:40	2020-07-04	9	[{"id_menu":6,"count":1}]	8726	delivery	5	14
89928	2020-07-04 07:29:51	2020-07-04	14	[{"id_menu":2,"count":1}]	2220	pick-up	0	14
89929	2020-07-04 07:30:39	2020-07-04	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	33787	delivery	5	36
89930	2020-07-04 07:31:30	2020-07-04	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6894	delivery	5	22
89931	2020-07-04 07:35:01	2020-07-04	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4836	delivery	5	34
89932	2020-07-04 07:37:37	2020-07-04	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16239	delivery	5	45
89933	2020-07-04 07:41:24	2020-07-04	8	[{"id_menu":5,"count":1}]	6838	delivery	5	13
89934	2020-07-04 07:44:12	2020-07-04	12	[{"id_menu":1,"count":1}]	2706	delivery	5	17
89935	2020-07-04 07:46:59	2020-07-04	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	17741	delivery	5	26
89936	2020-07-04 07:48:21	2020-07-04	8	[{"id_menu":5,"count":1}]	35075	delivery	5	13
89937	2020-07-04 07:52:01	2020-07-04	17	[{"id_menu":4,"count":1}]	35203	delivery	5	22
89938	2020-07-04 07:52:59	2020-07-04	12	[{"id_menu":1,"count":1}]	21898	pick-up	0	12
89939	2020-07-04 07:56:03	2020-07-04	9	[{"id_menu":7,"count":1}]	27076	delivery	5	14
89940	2020-07-04 07:56:20	2020-07-04	9	[{"id_menu":7,"count":1}]	35064	pick-up	0	9
89941	2020-07-04 08:02:30	2020-07-04	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2051	pick-up	0	29
89942	2020-07-04 08:07:46	2020-07-04	14	[{"id_menu":2,"count":1}]	35080	delivery	5	19
89943	2020-07-04 08:08:52	2020-07-04	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	35102	delivery	5	40
89944	2020-07-04 08:13:13	2020-07-04	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	35142	delivery	5	22
89945	2020-07-04 08:13:18	2020-07-04	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35132	delivery	5	37
89946	2020-07-04 08:13:27	2020-07-04	17	[{"id_menu":4,"count":1}]	35046	delivery	5	22
89947	2020-07-04 08:17:41	2020-07-04	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	35015	delivery	5	26
89948	2020-07-04 08:18:22	2020-07-04	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7764	delivery	5	56
89949	2020-07-04 08:19:06	2020-07-04	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8757	pick-up	0	25
89950	2020-07-04 08:19:29	2020-07-04	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	35022	delivery	5	44
89951	2020-07-04 08:20:19	2020-07-04	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":2}]	14332	delivery	5	22
89952	2020-07-04 08:20:58	2020-07-04	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	35168	pick-up	0	26
89953	2020-07-04 08:21:03	2020-07-04	9	[{"id_menu":6,"count":1}]	5639	pick-up	0	9
89954	2020-07-04 08:23:10	2020-07-04	17	[{"id_menu":4,"count":1}]	33698	pick-up	0	17
89955	2020-07-04 08:23:19	2020-07-04	8	[{"id_menu":5,"count":1}]	35051	delivery	5	13
89956	2020-07-04 08:23:47	2020-07-04	9	[{"id_menu":7,"count":1}]	13820	delivery	5	14
89957	2020-07-04 08:28:06	2020-07-04	17	[{"id_menu":4,"count":1}]	5781	delivery	5	22
89958	2020-07-04 08:31:26	2020-07-04	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	14783	delivery	5	40
89959	2020-07-04 08:31:50	2020-07-04	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23501	delivery	5	40
89960	2020-07-04 08:36:33	2020-07-04	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	18292	pick-up	0	29
89961	2020-07-04 08:40:46	2020-07-04	9	[{"id_menu":6,"count":1}]	28849	delivery	5	14
89962	2020-07-04 08:44:20	2020-07-04	14	[{"id_menu":2,"count":1}]	35013	delivery	5	19
89963	2020-07-04 08:44:22	2020-07-04	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2780	pick-up	0	37
89964	2020-07-04 08:45:17	2020-07-04	12	[{"id_menu":3,"count":1}]	35147	delivery	5	17
89965	2020-07-04 08:47:59	2020-07-04	9	[{"id_menu":6,"count":2}]	35058	delivery	5	14
89966	2020-07-04 08:48:05	2020-07-04	12	[{"id_menu":3,"count":1}]	8810	delivery	5	17
89967	2020-07-04 08:48:54	2020-07-04	12	[{"id_menu":1,"count":1}]	32868	delivery	5	17
89968	2020-07-04 08:50:14	2020-07-04	9	[{"id_menu":6,"count":1}]	7507	delivery	5	14
89969	2020-07-04 08:50:55	2020-07-04	9	[{"id_menu":6,"count":2}]	2468	pick-up	0	9
89970	2020-07-04 08:51:21	2020-07-04	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	30864	pick-up	0	21
89971	2020-07-04 08:54:38	2020-07-04	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	35124	delivery	5	26
89972	2020-07-04 08:56:33	2020-07-04	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32012	pick-up	0	32
89973	2020-07-04 08:58:21	2020-07-04	8	[{"id_menu":5,"count":1}]	12059	delivery	5	13
89974	2020-07-04 09:02:12	2020-07-04	12	[{"id_menu":1,"count":1}]	11893	delivery	5	17
89975	2020-07-04 09:05:54	2020-07-04	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	17463	delivery	5	25
89976	2020-07-04 09:06:37	2020-07-04	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6080	delivery	5	23
89977	2020-07-04 09:09:02	2020-07-04	9	[{"id_menu":6,"count":1}]	35133	delivery	5	14
89978	2020-07-04 09:11:05	2020-07-04	9	[{"id_menu":6,"count":1}]	35122	delivery	5	14
89979	2020-07-04 09:13:49	2020-07-04	12	[{"id_menu":3,"count":1}]	16603	delivery	5	17
89980	2020-07-04 09:18:05	2020-07-04	9	[{"id_menu":7,"count":1}]	15187	delivery	5	14
89981	2020-07-04 09:24:52	2020-07-04	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35073	delivery	5	43
89982	2020-07-04 09:26:47	2020-07-04	17	[{"id_menu":4,"count":1}]	35199	delivery	5	22
89983	2020-07-04 09:34:40	2020-07-04	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8867	delivery	5	51
89984	2020-07-04 09:35:44	2020-07-04	8	[{"id_menu":5,"count":1}]	17669	delivery	5	13
89985	2020-07-04 09:39:29	2020-07-04	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	9548	delivery	5	22
89986	2020-07-04 09:44:48	2020-07-04	14	[{"id_menu":2,"count":2}]	13193	delivery	5	19
89987	2020-07-04 09:47:18	2020-07-04	9	[{"id_menu":6,"count":1}]	3871	delivery	5	14
89988	2020-07-04 09:53:18	2020-07-04	8	[{"id_menu":5,"count":1}]	4140	delivery	5	13
89989	2020-07-04 09:53:44	2020-07-04	14	[{"id_menu":2,"count":1}]	35172	delivery	5	19
89990	2020-07-04 09:55:15	2020-07-04	23	[{"id_menu":2,"count":3},{"id_menu":6,"count":1}]	35047	delivery	5	28
89991	2020-07-04 09:56:34	2020-07-04	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":2}]	35099	delivery	5	26
89992	2020-07-04 09:58:30	2020-07-04	14	[{"id_menu":2,"count":1}]	35040	pick-up	0	14
89993	2020-07-04 10:02:55	2020-07-04	8	[{"id_menu":5,"count":1}]	19889	delivery	5	13
89994	2020-07-04 10:04:07	2020-07-04	9	[{"id_menu":7,"count":1}]	17631	pick-up	0	9
89995	2020-07-04 10:10:42	2020-07-04	17	[{"id_menu":4,"count":1}]	21688	delivery	5	22
89996	2020-07-04 10:13:46	2020-07-04	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	23108	pick-up	0	31
89997	2020-07-04 10:16:09	2020-07-04	17	[{"id_menu":4,"count":1}]	13394	delivery	5	22
89998	2020-07-04 10:19:14	2020-07-04	14	[{"id_menu":2,"count":1}]	35137	pick-up	0	14
89999	2020-07-04 10:24:30	2020-07-04	9	[{"id_menu":7,"count":1}]	6798	pick-up	0	9
90000	2020-07-04 10:26:03	2020-07-04	9	[{"id_menu":7,"count":1}]	3146	delivery	5	14
90001	2020-07-04 10:27:48	2020-07-04	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8287	delivery	5	51
90002	2020-07-04 10:30:08	2020-07-04	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	34015	delivery	5	22
90003	2020-07-04 10:30:23	2020-07-04	9	[{"id_menu":6,"count":1}]	5935	delivery	5	14
90004	2020-07-04 10:31:03	2020-07-04	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	28887	pick-up	0	31
90005	2020-07-04 10:31:23	2020-07-04	9	[{"id_menu":6,"count":1}]	1011	delivery	5	14
90006	2020-07-04 10:34:16	2020-07-04	8	[{"id_menu":5,"count":1}]	28380	delivery	5	13
90007	2020-07-04 10:36:29	2020-07-04	12	[{"id_menu":1,"count":1}]	34746	delivery	5	17
90008	2020-07-04 10:36:31	2020-07-04	9	[{"id_menu":6,"count":1}]	21457	delivery	5	14
90009	2020-07-04 10:37:18	2020-07-04	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	33057	delivery	5	34
90010	2020-07-04 10:38:04	2020-07-04	12	[{"id_menu":1,"count":1}]	35020	delivery	5	17
90011	2020-07-04 10:41:38	2020-07-04	30	[{"id_menu":1,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29159	delivery	5	35
90012	2020-07-04 10:51:27	2020-07-04	8	[{"id_menu":5,"count":1}]	1987	delivery	5	13
90013	2020-07-04 10:52:30	2020-07-04	9	[{"id_menu":7,"count":1}]	3752	pick-up	0	9
90014	2020-07-04 10:53:37	2020-07-04	9	[{"id_menu":7,"count":1}]	35120	pick-up	0	9
90015	2020-07-04 10:54:40	2020-07-04	12	[{"id_menu":1,"count":1}]	3260	pick-up	0	12
90016	2020-07-04 10:54:43	2020-07-04	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":2}]	30006	delivery	5	22
90017	2020-07-04 10:55:45	2020-07-04	9	[{"id_menu":6,"count":1}]	22584	delivery	5	14
90018	2020-07-04 10:57:26	2020-07-04	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	299	pick-up	0	31
90019	2020-07-04 10:57:32	2020-07-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	35205	delivery	5	28
90020	2020-07-04 11:01:26	2020-07-04	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	24785	delivery	5	43
90021	2020-07-04 11:03:07	2020-07-04	9	[{"id_menu":6,"count":1}]	11209	delivery	5	14
90022	2020-07-04 11:03:55	2020-07-04	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	8094	delivery	5	26
90023	2020-07-04 11:05:42	2020-07-04	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	35191	delivery	5	31
90024	2020-07-04 11:06:32	2020-07-04	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	7869	delivery	5	35
90025	2020-07-04 11:07:04	2020-07-04	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	35100	delivery	5	34
90026	2020-07-04 11:08:19	2020-07-04	17	[{"id_menu":4,"count":1}]	26622	delivery	5	22
90027	2020-07-04 11:11:03	2020-07-04	9	[{"id_menu":6,"count":1}]	22359	pick-up	0	9
90028	2020-07-04 11:12:22	2020-07-04	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	19600	delivery	5	31
90029	2020-07-04 11:12:55	2020-07-04	14	[{"id_menu":2,"count":1}]	35028	delivery	5	19
90030	2020-07-04 11:14:15	2020-07-04	12	[{"id_menu":1,"count":1}]	5094	delivery	5	17
90031	2020-07-04 11:15:49	2020-07-04	17	[{"id_menu":4,"count":1}]	29198	pick-up	0	17
90032	2020-07-04 11:16:43	2020-07-04	8	[{"id_menu":5,"count":1}]	7953	delivery	5	13
90033	2020-07-04 11:19:25	2020-07-04	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	35096	pick-up	0	21
90034	2020-07-04 11:19:32	2020-07-04	8	[{"id_menu":5,"count":1}]	15067	pick-up	0	8
90035	2020-07-04 11:19:33	2020-07-04	8	[{"id_menu":5,"count":1}]	31123	delivery	5	13
90036	2020-07-04 11:20:09	2020-07-04	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22216	delivery	5	39
90037	2020-07-04 11:20:10	2020-07-04	9	[{"id_menu":7,"count":1}]	26064	delivery	5	14
90038	2020-07-04 11:20:16	2020-07-04	12	[{"id_menu":3,"count":1}]	23928	delivery	5	17
90039	2020-07-04 11:21:02	2020-07-04	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	281	pick-up	0	20
90040	2020-07-04 11:21:43	2020-07-04	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	9051	delivery	5	31
90041	2020-07-04 11:22:41	2020-07-04	9	[{"id_menu":6,"count":1}]	24621	pick-up	0	9
90042	2020-07-04 11:23:35	2020-07-04	12	[{"id_menu":3,"count":1}]	135	delivery	5	17
90043	2020-07-04 11:24:21	2020-07-04	8	[{"id_menu":5,"count":1}]	35092	pick-up	0	8
90044	2020-07-04 11:24:28	2020-07-04	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	10870	pick-up	0	22
90045	2020-07-04 11:25:32	2020-07-04	12	[{"id_menu":3,"count":1}]	13458	delivery	5	17
90046	2020-07-04 11:27:33	2020-07-04	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	33605	delivery	5	26
90047	2020-07-04 11:28:29	2020-07-04	12	[{"id_menu":1,"count":1}]	13677	pick-up	0	12
90048	2020-07-04 11:31:01	2020-07-04	9	[{"id_menu":6,"count":1}]	15253	delivery	5	14
90049	2020-07-04 11:31:03	2020-07-04	9	[{"id_menu":6,"count":1}]	18313	delivery	5	14
90050	2020-07-04 11:31:38	2020-07-04	12	[{"id_menu":3,"count":1}]	23951	delivery	5	17
90051	2020-07-04 11:32:16	2020-07-04	8	[{"id_menu":5,"count":1}]	1670	pick-up	0	8
90052	2020-07-04 11:34:24	2020-07-04	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	17713	delivery	5	26
90053	2020-07-04 11:35:38	2020-07-04	8	[{"id_menu":5,"count":1}]	6202	delivery	5	13
90054	2020-07-04 11:38:21	2020-07-04	9	[{"id_menu":7,"count":1}]	5783	pick-up	0	9
90055	2020-07-04 11:38:59	2020-07-04	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	3400	delivery	5	25
90056	2020-07-04 11:39:20	2020-07-04	9	[{"id_menu":7,"count":1}]	32685	delivery	5	14
90057	2020-07-04 11:42:44	2020-07-04	14	[{"id_menu":2,"count":3}]	35069	delivery	5	19
90058	2020-07-04 11:43:41	2020-07-04	12	[{"id_menu":3,"count":1}]	2244	delivery	5	17
90059	2020-07-04 11:44:31	2020-07-04	17	[{"id_menu":4,"count":1}]	1334	delivery	5	22
90060	2020-07-04 11:45:14	2020-07-04	9	[{"id_menu":6,"count":1}]	27454	delivery	5	14
90061	2020-07-04 11:45:18	2020-07-04	8	[{"id_menu":5,"count":1}]	16611	delivery	5	13
90062	2020-07-04 11:45:44	2020-07-04	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	35038	delivery	5	36
90063	2020-07-04 11:46:38	2020-07-04	14	[{"id_menu":2,"count":1}]	8651	delivery	5	19
90064	2020-07-04 11:49:59	2020-07-04	9	[{"id_menu":6,"count":1}]	24770	delivery	5	14
90065	2020-07-04 11:50:35	2020-07-04	9	[{"id_menu":6,"count":1}]	8146	delivery	5	14
90066	2020-07-04 11:51:03	2020-07-04	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	27282	delivery	5	22
90067	2020-07-04 11:51:55	2020-07-04	9	[{"id_menu":7,"count":1}]	2570	pick-up	0	9
90068	2020-07-04 11:53:12	2020-07-04	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22485	delivery	5	34
90069	2020-07-04 11:54:20	2020-07-04	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5668	pick-up	0	18
90070	2020-07-04 11:56:09	2020-07-04	17	[{"id_menu":4,"count":1}]	585	delivery	5	22
90071	2020-07-04 11:59:04	2020-07-04	9	[{"id_menu":7,"count":1}]	262	pick-up	0	9
90072	2020-07-04 12:01:44	2020-07-04	14	[{"id_menu":2,"count":1}]	15217	delivery	5	19
90073	2020-07-04 12:03:05	2020-07-04	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8244	delivery	5	57
90074	2020-07-04 12:03:33	2020-07-04	17	[{"id_menu":4,"count":1}]	15971	delivery	5	22
90075	2020-07-04 12:07:38	2020-07-04	14	[{"id_menu":2,"count":1}]	4139	delivery	5	19
90076	2020-07-04 12:09:53	2020-07-04	12	[{"id_menu":3,"count":1}]	29464	delivery	5	17
90077	2020-07-04 12:11:28	2020-07-04	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	10349	delivery	5	23
90078	2020-07-04 12:13:29	2020-07-04	9	[{"id_menu":7,"count":1}]	10235	delivery	5	14
90079	2020-07-04 12:15:55	2020-07-04	8	[{"id_menu":5,"count":1}]	35136	delivery	5	13
90080	2020-07-04 12:16:18	2020-07-04	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	22407	delivery	5	34
90081	2020-07-04 12:19:56	2020-07-04	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	31576	delivery	5	31
90082	2020-07-04 12:22:14	2020-07-04	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	35021	delivery	5	25
90083	2020-07-04 12:27:04	2020-07-04	12	[{"id_menu":1,"count":1}]	2414	pick-up	0	12
90084	2020-07-04 12:28:38	2020-07-04	8	[{"id_menu":5,"count":1}]	29853	delivery	5	13
90085	2020-07-04 12:28:40	2020-07-04	12	[{"id_menu":1,"count":1}]	5232	pick-up	0	12
90086	2020-07-04 12:36:54	2020-07-04	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	35017	delivery	5	43
90087	2020-07-04 12:38:21	2020-07-04	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	35182	delivery	5	26
90088	2020-07-04 12:39:25	2020-07-04	17	[{"id_menu":4,"count":1}]	35123	delivery	5	22
90089	2020-07-04 12:45:07	2020-07-04	14	[{"id_menu":2,"count":2}]	13809	pick-up	0	14
90090	2020-07-04 12:45:27	2020-07-04	9	[{"id_menu":7,"count":2}]	35165	delivery	5	14
90091	2020-07-04 12:46:51	2020-07-04	9	[{"id_menu":6,"count":1}]	35170	delivery	5	14
90092	2020-07-04 12:48:37	2020-07-04	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5433	delivery	5	48
90093	2020-07-04 12:49:09	2020-07-04	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35105	delivery	5	35
90094	2020-07-04 12:51:25	2020-07-04	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	35074	delivery	5	36
90095	2020-07-04 12:56:29	2020-07-04	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	35026	delivery	5	26
90096	2020-07-04 12:57:42	2020-07-04	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2992	delivery	5	30
90097	2020-07-04 12:58:07	2020-07-04	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	15317	delivery	5	25
90098	2020-07-04 12:58:23	2020-07-04	14	[{"id_menu":2,"count":1}]	6341	delivery	5	19
90099	2020-07-04 13:02:31	2020-07-04	26	[{"id_menu":1,"count":3},{"id_menu":2,"count":1}]	35196	delivery	5	31
90100	2020-07-04 13:02:45	2020-07-04	8	[{"id_menu":5,"count":1}]	25299	delivery	5	13
90101	2020-07-04 13:03:07	2020-07-04	14	[{"id_menu":2,"count":2}]	6733	pick-up	0	14
90102	2020-07-04 13:05:19	2020-07-04	14	[{"id_menu":2,"count":1}]	3134	delivery	5	19
90103	2020-07-04 13:09:44	2020-07-04	8	[{"id_menu":5,"count":1}]	11973	delivery	5	13
90104	2020-07-04 13:11:01	2020-07-04	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	19768	pick-up	0	26
90105	2020-07-04 13:11:07	2020-07-04	14	[{"id_menu":2,"count":1}]	30204	pick-up	0	14
90106	2020-07-04 13:13:08	2020-07-04	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	24896	delivery	5	26
90107	2020-07-04 13:16:24	2020-07-04	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	35071	delivery	5	26
90108	2020-07-04 13:19:15	2020-07-04	9	[{"id_menu":7,"count":1}]	35152	delivery	5	14
90109	2020-07-04 13:20:03	2020-07-04	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6476	delivery	5	52
90110	2020-07-04 13:20:44	2020-07-04	8	[{"id_menu":5,"count":1}]	35112	delivery	5	13
90111	2020-07-04 13:21:45	2020-07-04	8	[{"id_menu":5,"count":1}]	16282	pick-up	0	8
90112	2020-07-04 13:24:05	2020-07-04	8	[{"id_menu":5,"count":1}]	35119	delivery	5	13
90113	2020-07-04 13:24:19	2020-07-04	14	[{"id_menu":2,"count":1}]	35131	pick-up	0	14
90114	2020-07-04 13:27:15	2020-07-04	8	[{"id_menu":5,"count":1}]	26290	delivery	5	13
90115	2020-07-04 13:28:55	2020-07-04	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29667	delivery	5	37
90116	2020-07-04 13:29:32	2020-07-04	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	23178	delivery	5	26
90117	2020-07-04 13:31:33	2020-07-04	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	35134	delivery	5	22
90118	2020-07-04 13:32:18	2020-07-04	8	[{"id_menu":5,"count":1}]	35202	delivery	5	13
90119	2020-07-04 13:32:51	2020-07-04	12	[{"id_menu":1,"count":1}]	35044	delivery	5	17
90120	2020-07-04 13:32:52	2020-07-04	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	35161	pick-up	0	26
90121	2020-07-04 13:34:18	2020-07-04	9	[{"id_menu":6,"count":1}]	35157	delivery	5	14
90122	2020-07-04 13:38:42	2020-07-04	8	[{"id_menu":5,"count":1}]	35035	delivery	5	13
90123	2020-07-04 13:39:18	2020-07-04	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	1600	pick-up	0	41
90124	2020-07-04 13:39:32	2020-07-04	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	35180	delivery	5	26
90125	2020-07-04 13:41:03	2020-07-04	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19161	delivery	5	23
90126	2020-07-04 13:43:41	2020-07-04	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	6958	delivery	5	31
90127	2020-07-04 13:45:30	2020-07-04	9	[{"id_menu":7,"count":1}]	2936	delivery	5	14
90128	2020-07-04 13:50:26	2020-07-04	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	18714	pick-up	0	22
90129	2020-07-04 13:50:32	2020-07-04	8	[{"id_menu":5,"count":1}]	26660	delivery	5	13
90130	2020-07-04 13:50:41	2020-07-04	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	17569	pick-up	0	35
90131	2020-07-04 13:52:06	2020-07-04	17	[{"id_menu":4,"count":1}]	22784	pick-up	0	17
90132	2020-07-04 13:53:07	2020-07-04	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	19005	pick-up	0	21
90133	2020-07-04 13:54:09	2020-07-04	9	[{"id_menu":6,"count":1}]	33651	delivery	5	14
90134	2020-07-04 13:54:21	2020-07-04	12	[{"id_menu":1,"count":1}]	13023	delivery	5	17
90135	2020-07-04 13:56:09	2020-07-04	12	[{"id_menu":1,"count":1}]	4829	delivery	5	17
90136	2020-07-04 13:58:12	2020-07-04	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12178	delivery	5	49
90137	2020-07-04 13:59:19	2020-07-04	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	35162	delivery	5	36
90138	2020-07-04 14:00:00	2020-07-04	9	[{"id_menu":6,"count":1}]	35146	delivery	5	14
90139	2020-07-04 14:01:03	2020-07-04	14	[{"id_menu":2,"count":1}]	27299	pick-up	0	14
90140	2020-07-04 14:04:33	2020-07-04	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	35098	delivery	5	26
90141	2020-07-04 14:05:06	2020-07-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	24284	delivery	5	28
90142	2020-07-04 14:06:01	2020-07-04	14	[{"id_menu":2,"count":1}]	3780	pick-up	0	14
90143	2020-07-04 14:07:50	2020-07-04	8	[{"id_menu":5,"count":1}]	35084	delivery	5	13
90144	2020-07-04 14:08:59	2020-07-04	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2447	delivery	5	25
90145	2020-07-04 14:11:14	2020-07-04	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	23299	delivery	5	35
90146	2020-07-04 14:11:50	2020-07-04	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	35129	delivery	5	36
90147	2020-07-04 14:15:03	2020-07-04	12	[{"id_menu":3,"count":1}]	33452	pick-up	0	12
90148	2020-07-04 14:15:33	2020-07-04	12	[{"id_menu":1,"count":1}]	11752	pick-up	0	12
90149	2020-07-04 14:17:13	2020-07-04	9	[{"id_menu":6,"count":1}]	25998	delivery	5	14
90150	2020-07-04 14:26:24	2020-07-04	17	[{"id_menu":4,"count":1}]	9191	pick-up	0	17
90151	2020-07-04 14:27:51	2020-07-04	9	[{"id_menu":6,"count":1}]	23747	delivery	5	14
90152	2020-07-04 14:28:01	2020-07-04	14	[{"id_menu":2,"count":1}]	9722	delivery	5	19
90153	2020-07-04 14:32:49	2020-07-04	9	[{"id_menu":6,"count":3}]	35195	delivery	5	14
90154	2020-07-04 14:36:07	2020-07-04	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	8487	delivery	5	40
90155	2020-07-04 14:36:49	2020-07-04	17	[{"id_menu":4,"count":1}]	35181	delivery	5	22
90156	2020-07-04 14:37:22	2020-07-04	8	[{"id_menu":5,"count":1}]	7122	delivery	5	13
90157	2020-07-04 14:42:40	2020-07-04	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	19233	pick-up	0	40
90158	2020-07-04 14:47:02	2020-07-04	9	[{"id_menu":7,"count":1}]	35097	delivery	5	14
90159	2020-07-04 14:53:26	2020-07-04	9	[{"id_menu":6,"count":1}]	5201	pick-up	0	9
90160	2020-07-04 14:57:10	2020-07-04	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	16549	pick-up	0	20
90161	2020-07-04 15:00:24	2020-07-04	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	27515	delivery	5	22
90162	2020-07-04 15:01:45	2020-07-04	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8764	delivery	5	37
90163	2020-07-04 15:02:08	2020-07-04	17	[{"id_menu":4,"count":1}]	9816	pick-up	0	17
90164	2020-07-04 15:04:02	2020-07-04	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	28344	delivery	5	39
90165	2020-07-04 15:04:49	2020-07-04	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	35007	delivery	5	30
90166	2020-07-04 15:06:18	2020-07-04	9	[{"id_menu":6,"count":1}]	13419	delivery	5	14
90167	2020-07-04 15:08:07	2020-07-04	9	[{"id_menu":7,"count":1}]	25115	delivery	5	14
90168	2020-07-04 15:09:11	2020-07-04	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	35042	delivery	5	27
90169	2020-07-04 15:09:37	2020-07-04	12	[{"id_menu":3,"count":1}]	35082	delivery	5	17
90170	2020-07-04 15:11:07	2020-07-04	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	414	delivery	5	27
90171	2020-07-04 15:11:18	2020-07-04	8	[{"id_menu":5,"count":1}]	21591	delivery	5	13
90172	2020-07-04 15:17:39	2020-07-04	8	[{"id_menu":5,"count":1}]	35094	delivery	5	13
90173	2020-07-04 15:19:35	2020-07-04	17	[{"id_menu":4,"count":1}]	875	pick-up	0	17
90174	2020-07-04 15:27:22	2020-07-04	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	35023	delivery	5	22
90175	2020-07-04 15:28:08	2020-07-04	17	[{"id_menu":4,"count":1}]	2891	pick-up	0	17
90176	2020-07-04 15:31:22	2020-07-04	12	[{"id_menu":1,"count":1}]	35091	delivery	5	17
90177	2020-07-04 15:33:52	2020-07-04	12	[{"id_menu":3,"count":1}]	14841	delivery	5	17
90178	2020-07-04 15:33:53	2020-07-04	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	35054	delivery	5	39
90179	2020-07-04 15:35:59	2020-07-04	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	35009	delivery	5	25
90180	2020-07-04 15:38:10	2020-07-04	17	[{"id_menu":4,"count":1}]	6753	delivery	5	22
90181	2020-07-04 15:38:26	2020-07-04	14	[{"id_menu":2,"count":1}]	31699	delivery	5	19
90182	2020-07-04 15:41:49	2020-07-04	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	35121	delivery	5	30
90183	2020-07-04 15:46:14	2020-07-04	9	[{"id_menu":7,"count":1}]	35043	delivery	5	14
90184	2020-07-04 15:49:08	2020-07-04	49	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2897	delivery	5	54
90185	2020-07-04 16:00:04	2020-07-04	8	[{"id_menu":5,"count":1}]	18533	pick-up	0	8
90186	2020-07-04 16:00:25	2020-07-04	17	[{"id_menu":4,"count":1}]	18253	pick-up	0	17
90187	2020-07-04 16:01:29	2020-07-04	12	[{"id_menu":3,"count":1}]	35063	delivery	5	17
90188	2020-07-04 16:05:11	2020-07-04	9	[{"id_menu":7,"count":1}]	3512	pick-up	0	9
90189	2020-07-04 16:11:35	2020-07-04	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	35145	delivery	5	48
90190	2020-07-04 16:12:13	2020-07-04	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	32267	delivery	5	36
90191	2020-07-04 16:12:50	2020-07-04	17	[{"id_menu":4,"count":1}]	226	delivery	5	22
90192	2020-07-04 16:15:31	2020-07-04	17	[{"id_menu":4,"count":1}]	4072	delivery	5	22
90193	2020-07-04 16:22:43	2020-07-04	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	971	pick-up	0	48
90194	2020-07-04 16:24:27	2020-07-04	12	[{"id_menu":3,"count":1}]	35130	delivery	5	17
90195	2020-07-04 16:25:41	2020-07-04	9	[{"id_menu":7,"count":1}]	14707	delivery	5	14
90196	2020-07-04 16:25:57	2020-07-04	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35034	delivery	5	31
90197	2020-07-04 16:30:37	2020-07-04	14	[{"id_menu":2,"count":1}]	12800	pick-up	0	14
90198	2020-07-04 16:34:01	2020-07-04	9	[{"id_menu":7,"count":1}]	8748	delivery	5	14
90199	2020-07-04 16:35:58	2020-07-04	14	[{"id_menu":2,"count":1}]	1155	pick-up	0	14
90200	2020-07-04 16:36:30	2020-07-04	9	[{"id_menu":7,"count":1}]	35200	delivery	5	14
90201	2020-07-04 16:36:39	2020-07-04	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12760	delivery	5	37
90202	2020-07-04 16:40:48	2020-07-04	8	[{"id_menu":5,"count":1}]	35049	delivery	5	13
90203	2020-07-04 16:41:51	2020-07-04	9	[{"id_menu":6,"count":1}]	35077	delivery	5	14
90204	2020-07-04 16:44:38	2020-07-04	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	12572	delivery	5	29
90205	2020-07-04 16:46:13	2020-07-04	9	[{"id_menu":6,"count":1}]	821	delivery	5	14
90206	2020-07-04 16:47:39	2020-07-04	14	[{"id_menu":2,"count":2}]	35060	delivery	5	19
90207	2020-07-04 16:48:26	2020-07-04	9	[{"id_menu":7,"count":1}]	35190	delivery	5	14
90208	2020-07-04 16:49:50	2020-07-04	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	30660	pick-up	0	26
90209	2020-07-04 16:55:25	2020-07-04	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35150	pick-up	0	32
90210	2020-07-04 16:56:26	2020-07-04	17	[{"id_menu":4,"count":1}]	17807	delivery	5	22
90211	2020-07-04 16:58:06	2020-07-04	17	[{"id_menu":4,"count":1}]	4644	pick-up	0	17
90212	2020-07-04 16:59:21	2020-07-04	9	[{"id_menu":7,"count":1}]	35171	delivery	5	14
90213	2020-07-04 17:00:19	2020-07-04	8	[{"id_menu":5,"count":1}]	11960	pick-up	0	8
90214	2020-07-04 17:00:42	2020-07-04	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	28949	delivery	5	31
90215	2020-07-04 17:04:53	2020-07-04	17	[{"id_menu":4,"count":1}]	5099	pick-up	0	17
90216	2020-07-04 17:06:04	2020-07-04	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	30455	pick-up	0	26
90217	2020-07-04 17:09:49	2020-07-04	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	7444	delivery	5	31
90218	2020-07-04 17:12:03	2020-07-04	12	[{"id_menu":1,"count":1}]	35141	delivery	5	17
90219	2020-07-04 17:19:52	2020-07-04	8	[{"id_menu":5,"count":1}]	14256	delivery	5	13
90220	2020-07-04 17:28:38	2020-07-04	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	35144	delivery	5	26
90221	2020-07-04 17:29:35	2020-07-04	8	[{"id_menu":5,"count":1}]	25620	delivery	5	13
90222	2020-07-04 17:30:32	2020-07-04	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2113	pick-up	0	26
90223	2020-07-04 17:31:33	2020-07-04	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	29490	delivery	5	40
90224	2020-07-04 17:32:07	2020-07-04	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30585	delivery	5	49
90225	2020-07-04 17:36:32	2020-07-04	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	35109	delivery	5	34
90226	2020-07-04 17:38:38	2020-07-04	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	35148	delivery	5	27
90227	2020-07-04 17:39:08	2020-07-04	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35154	delivery	5	35
90228	2020-07-04 17:39:56	2020-07-04	14	[{"id_menu":2,"count":1}]	21551	pick-up	0	14
90229	2020-07-04 17:40:19	2020-07-04	12	[{"id_menu":1,"count":1}]	40	pick-up	0	12
90230	2020-07-04 17:41:24	2020-07-04	12	[{"id_menu":1,"count":1}]	19480	delivery	5	17
90231	2020-07-04 17:46:23	2020-07-04	9	[{"id_menu":7,"count":1}]	2899	delivery	5	14
90232	2020-07-04 17:50:42	2020-07-04	9	[{"id_menu":7,"count":1}]	35055	delivery	5	14
90233	2020-07-04 17:51:00	2020-07-04	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	35031	delivery	5	31
90234	2020-07-04 17:51:39	2020-07-04	14	[{"id_menu":2,"count":1}]	31883	delivery	5	19
90235	2020-07-04 17:52:05	2020-07-04	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	35126	delivery	5	51
90236	2020-07-04 17:55:09	2020-07-04	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	35178	delivery	5	38
90237	2020-07-04 17:56:29	2020-07-04	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	24659	delivery	5	28
90238	2020-07-04 17:58:38	2020-07-04	12	[{"id_menu":1,"count":1}]	35037	pick-up	0	12
90239	2020-07-04 17:59:53	2020-07-04	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	157	pick-up	0	35
90240	2020-07-04 18:01:09	2020-07-04	14	[{"id_menu":2,"count":1}]	270	delivery	5	19
90241	2020-07-04 18:02:54	2020-07-04	9	[{"id_menu":6,"count":1}]	35113	delivery	5	14
90242	2020-07-04 18:05:05	2020-07-04	9	[{"id_menu":7,"count":2}]	35149	delivery	5	14
90243	2020-07-04 18:06:48	2020-07-04	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	12699	pick-up	0	29
90244	2020-07-04 18:10:07	2020-07-04	9	[{"id_menu":7,"count":1}]	35083	delivery	5	14
90245	2020-07-04 18:12:25	2020-07-04	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	35029	delivery	5	28
90246	2020-07-04 18:12:47	2020-07-04	17	[{"id_menu":4,"count":3}]	22358	delivery	5	22
90247	2020-07-04 18:16:25	2020-07-04	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	15964	delivery	5	25
90248	2020-07-04 18:21:12	2020-07-04	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35163	delivery	5	31
90249	2020-07-04 18:28:55	2020-07-04	8	[{"id_menu":5,"count":1}]	18565	delivery	5	13
90250	2020-07-04 18:29:17	2020-07-04	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	5582	delivery	5	31
90251	2020-07-04 18:36:33	2020-07-04	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13827	delivery	5	45
90252	2020-07-04 18:37:07	2020-07-04	9	[{"id_menu":6,"count":1}]	33607	delivery	5	14
90253	2020-07-04 18:38:24	2020-07-04	17	[{"id_menu":4,"count":1}]	33560	delivery	5	22
90254	2020-07-04 18:40:28	2020-07-04	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	33909	delivery	5	40
90255	2020-07-04 18:43:52	2020-07-04	12	[{"id_menu":1,"count":1}]	4138	pick-up	0	12
90256	2020-07-04 18:43:57	2020-07-04	12	[{"id_menu":3,"count":1}]	17794	delivery	5	17
90257	2020-07-04 18:49:28	2020-07-04	9	[{"id_menu":6,"count":1}]	13010	delivery	5	14
90258	2020-07-04 18:51:45	2020-07-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	13042	delivery	5	28
90259	2020-07-04 18:56:45	2020-07-04	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35204	delivery	5	23
90260	2020-07-04 18:57:15	2020-07-04	8	[{"id_menu":5,"count":1}]	27881	delivery	5	13
90261	2020-07-04 18:59:32	2020-07-04	12	[{"id_menu":3,"count":1}]	575	delivery	5	17
90262	2020-07-04 19:00:03	2020-07-04	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4436	pick-up	0	29
90263	2020-07-04 19:03:08	2020-07-04	17	[{"id_menu":4,"count":2}]	29613	delivery	5	22
90264	2020-07-04 19:07:25	2020-07-04	9	[{"id_menu":6,"count":1}]	27777	pick-up	0	9
90265	2020-07-04 19:08:07	2020-07-04	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	16770	delivery	5	23
90266	2020-07-04 19:08:21	2020-07-04	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	34631	delivery	5	48
90267	2020-07-04 19:08:22	2020-07-04	9	[{"id_menu":7,"count":1}]	10155	pick-up	0	9
90268	2020-07-04 19:10:07	2020-07-04	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	35056	delivery	5	53
90269	2020-07-04 19:11:05	2020-07-04	17	[{"id_menu":4,"count":1}]	35030	delivery	5	22
90270	2020-07-04 19:13:51	2020-07-04	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	7017	delivery	5	40
90271	2020-07-04 19:16:18	2020-07-04	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1531	pick-up	0	21
90272	2020-07-04 19:21:08	2020-07-04	12	[{"id_menu":1,"count":1}]	31876	pick-up	0	12
90273	2020-07-04 19:22:04	2020-07-04	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	16255	delivery	5	22
90274	2020-07-04 19:23:27	2020-07-04	14	[{"id_menu":2,"count":1}]	35087	delivery	5	19
90275	2020-07-04 19:26:06	2020-07-04	14	[{"id_menu":2,"count":1}]	35103	delivery	5	19
90276	2020-07-04 19:26:47	2020-07-04	14	[{"id_menu":2,"count":2}]	570	pick-up	0	14
90277	2020-07-04 19:28:58	2020-07-04	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	28377	pick-up	0	26
90278	2020-07-04 19:29:55	2020-07-04	14	[{"id_menu":2,"count":1}]	7204	delivery	5	19
90279	2020-07-04 19:30:58	2020-07-04	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	784	delivery	5	34
90280	2020-07-04 19:33:04	2020-07-04	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	25297	delivery	5	30
90281	2020-07-04 19:35:56	2020-07-04	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	29917	delivery	5	27
90282	2020-07-04 19:40:16	2020-07-04	9	[{"id_menu":7,"count":1}]	24392	delivery	5	14
90283	2020-07-04 19:43:03	2020-07-04	12	[{"id_menu":1,"count":1}]	19258	delivery	5	17
90284	2020-07-04 19:43:05	2020-07-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	5893	delivery	5	28
90285	2020-07-04 19:47:30	2020-07-04	12	[{"id_menu":3,"count":1}]	21803	pick-up	0	12
90286	2020-07-04 19:47:50	2020-07-04	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	35059	delivery	5	36
90287	2020-07-04 19:49:07	2020-07-04	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	29896	delivery	5	45
90288	2020-07-04 19:50:26	2020-07-04	17	[{"id_menu":4,"count":1}]	3006	delivery	5	22
90289	2020-07-04 19:51:42	2020-07-04	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	26270	delivery	5	22
90290	2020-07-04 19:52:12	2020-07-04	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	33659	delivery	5	34
90291	2020-07-04 19:58:11	2020-07-04	17	[{"id_menu":4,"count":1}]	35019	delivery	5	22
90292	2020-07-04 19:59:34	2020-07-04	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	30313	delivery	5	43
90293	2020-07-04 19:59:58	2020-07-04	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	22960	delivery	5	31
90294	2020-07-04 20:12:42	2020-07-04	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	33843	delivery	5	36
90295	2020-07-04 20:15:09	2020-07-04	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	23798	delivery	5	31
90296	2020-07-04 20:19:00	2020-07-04	9	[{"id_menu":7,"count":1}]	154	delivery	5	14
90297	2020-07-04 20:21:14	2020-07-04	12	[{"id_menu":1,"count":1}]	24519	delivery	5	17
90298	2020-07-04 20:21:15	2020-07-04	9	[{"id_menu":6,"count":1}]	382	pick-up	0	9
90299	2020-07-04 20:30:22	2020-07-04	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	4794	delivery	5	34
90300	2020-07-04 20:31:21	2020-07-04	9	[{"id_menu":6,"count":1}]	18300	delivery	5	14
90301	2020-07-04 20:38:25	2020-07-04	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17225	pick-up	0	32
90302	2020-07-04 20:38:33	2020-07-04	9	[{"id_menu":6,"count":1}]	23457	delivery	5	14
90303	2020-07-04 20:40:58	2020-07-04	8	[{"id_menu":5,"count":1}]	35104	delivery	5	13
90304	2020-07-04 20:42:25	2020-07-04	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8506	delivery	5	22
90305	2020-07-04 20:42:30	2020-07-04	14	[{"id_menu":2,"count":1}]	17691	pick-up	0	14
90306	2020-07-04 20:43:30	2020-07-04	14	[{"id_menu":2,"count":1}]	1442	delivery	5	19
90307	2020-07-04 20:45:13	2020-07-04	9	[{"id_menu":7,"count":1}]	35032	delivery	5	14
90308	2020-07-04 20:49:48	2020-07-04	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	30337	delivery	5	31
90309	2020-07-04 20:54:03	2020-07-04	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	9104	delivery	5	23
90310	2020-07-04 20:55:17	2020-07-04	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	35081	delivery	5	31
90311	2020-07-04 20:58:19	2020-07-04	12	[{"id_menu":3,"count":1}]	24603	delivery	5	17
90312	2020-07-04 21:00:08	2020-07-04	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	35072	pick-up	0	23
90313	2020-07-04 21:02:17	2020-07-04	9	[{"id_menu":6,"count":1}]	18283	delivery	5	14
90314	2020-07-04 21:02:32	2020-07-04	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	4079	delivery	5	27
90315	2020-07-04 21:03:34	2020-07-04	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	8032	delivery	5	22
90316	2020-07-04 21:03:38	2020-07-04	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11990	delivery	5	40
90317	2020-07-04 21:05:01	2020-07-04	12	[{"id_menu":1,"count":1}]	11681	pick-up	0	12
90318	2020-07-04 21:05:40	2020-07-04	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35164	delivery	5	35
90319	2020-07-04 21:08:09	2020-07-04	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":3}]	29706	delivery	5	26
90320	2020-07-04 21:16:04	2020-07-04	9	[{"id_menu":6,"count":1}]	351	pick-up	0	9
90321	2020-07-04 21:16:11	2020-07-04	17	[{"id_menu":4,"count":1}]	32706	delivery	5	22
90322	2020-07-04 21:16:54	2020-07-04	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33797	delivery	5	40
90323	2020-07-04 21:19:12	2020-07-04	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15577	delivery	5	22
90324	2020-07-04 21:25:03	2020-07-04	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	25856	delivery	5	43
90325	2020-07-04 21:25:39	2020-07-04	9	[{"id_menu":6,"count":1}]	16018	pick-up	0	9
90326	2020-07-04 21:26:33	2020-07-04	12	[{"id_menu":1,"count":3}]	5758	pick-up	0	12
90327	2020-07-04 21:26:40	2020-07-04	14	[{"id_menu":2,"count":1}]	22576	delivery	5	19
90328	2020-07-04 21:27:52	2020-07-04	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15786	delivery	5	39
90329	2020-07-04 21:29:00	2020-07-04	17	[{"id_menu":4,"count":1}]	76	pick-up	0	17
90330	2020-07-04 21:31:41	2020-07-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	35139	delivery	5	28
90331	2020-07-04 21:33:16	2020-07-04	8	[{"id_menu":5,"count":2}]	22457	delivery	5	13
90332	2020-07-04 21:34:36	2020-07-04	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":2}]	7384	delivery	5	31
90333	2020-07-04 21:45:12	2020-07-04	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	35024	delivery	5	44
90334	2020-07-04 21:46:30	2020-07-04	9	[{"id_menu":7,"count":1}]	19868	delivery	5	14
90335	2020-07-04 21:46:31	2020-07-04	9	[{"id_menu":7,"count":1}]	2959	pick-up	0	9
90336	2020-07-04 21:46:55	2020-07-04	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	26516	delivery	5	22
90337	2020-07-04 21:52:14	2020-07-04	17	[{"id_menu":4,"count":1}]	16858	delivery	5	22
90338	2020-07-04 21:54:50	2020-07-04	9	[{"id_menu":6,"count":1}]	35033	delivery	5	14
90339	2020-07-04 21:56:39	2020-07-04	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	33523	delivery	5	22
90340	2020-07-04 22:11:34	2020-07-04	17	[{"id_menu":4,"count":1}]	31834	delivery	5	22
90341	2020-07-04 22:12:13	2020-07-04	12	[{"id_menu":1,"count":1}]	35177	delivery	5	17
90342	2020-07-04 22:13:37	2020-07-04	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	31242	delivery	5	22
90343	2020-07-04 22:14:29	2020-07-04	12	[{"id_menu":1,"count":1}]	35006	pick-up	0	12
90344	2020-07-04 22:15:18	2020-07-04	12	[{"id_menu":1,"count":1}]	35143	delivery	5	17
90345	2020-07-04 22:17:28	2020-07-04	8	[{"id_menu":5,"count":1}]	14411	delivery	5	13
90346	2020-07-04 22:22:11	2020-07-04	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	31409	delivery	5	22
90347	2020-07-04 22:25:53	2020-07-04	12	[{"id_menu":1,"count":1}]	35174	delivery	5	17
90348	2020-07-04 22:27:32	2020-07-04	17	[{"id_menu":4,"count":2}]	35179	delivery	5	22
90349	2020-07-04 22:27:47	2020-07-04	12	[{"id_menu":3,"count":1}]	17958	delivery	5	17
90350	2020-07-04 22:30:50	2020-07-04	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	35117	delivery	5	40
90351	2020-07-04 22:31:43	2020-07-04	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	9014	delivery	5	26
90352	2020-07-04 22:32:17	2020-07-04	9	[{"id_menu":6,"count":1}]	26222	delivery	5	14
90353	2020-07-04 22:34:24	2020-07-04	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	35068	delivery	5	43
90354	2020-07-04 22:36:56	2020-07-04	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	22952	delivery	5	36
90355	2020-07-04 22:40:56	2020-07-04	9	[{"id_menu":6,"count":1}]	24716	delivery	5	14
90356	2020-07-04 22:45:19	2020-07-04	14	[{"id_menu":2,"count":1}]	35140	delivery	5	19
90357	2020-07-04 22:46:37	2020-07-04	9	[{"id_menu":7,"count":1}]	3135	pick-up	0	9
90358	2020-07-04 22:47:38	2020-07-04	8	[{"id_menu":5,"count":1}]	2225	delivery	5	13
90359	2020-07-04 22:47:41	2020-07-04	9	[{"id_menu":7,"count":2}]	9562	pick-up	0	9
90360	2020-07-04 22:47:53	2020-07-04	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4983	delivery	5	37
90361	2020-07-04 22:49:11	2020-07-04	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31254	delivery	5	45
90362	2020-07-04 22:49:32	2020-07-04	14	[{"id_menu":2,"count":1}]	29429	delivery	5	19
90363	2020-07-04 22:49:43	2020-07-04	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	35158	delivery	5	31
90364	2020-07-04 22:50:25	2020-07-04	17	[{"id_menu":4,"count":1}]	16825	delivery	5	22
90365	2020-07-04 22:52:53	2020-07-04	8	[{"id_menu":5,"count":1}]	35183	delivery	5	13
90366	2020-07-04 22:53:13	2020-07-04	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8521	pick-up	0	18
90367	2020-07-04 23:02:18	2020-07-04	8	[{"id_menu":5,"count":1}]	28749	delivery	5	13
90368	2020-07-04 23:02:43	2020-07-04	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	35090	delivery	5	28
90369	2020-07-04 23:03:02	2020-07-04	12	[{"id_menu":3,"count":2}]	4315	pick-up	0	12
90370	2020-07-04 23:03:49	2020-07-04	12	[{"id_menu":3,"count":1}]	1568	delivery	5	17
90371	2020-07-04 23:05:04	2020-07-04	9	[{"id_menu":7,"count":1}]	25885	pick-up	0	9
90372	2020-07-04 23:06:09	2020-07-04	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8753	delivery	5	45
90373	2020-07-04 23:07:16	2020-07-04	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	31680	delivery	5	40
90374	2020-07-04 23:11:33	2020-07-04	14	[{"id_menu":2,"count":1}]	31053	delivery	5	19
90375	2020-07-04 23:14:30	2020-07-04	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	34161	delivery	5	25
90376	2020-07-04 23:20:41	2020-07-04	8	[{"id_menu":5,"count":1}]	35159	delivery	5	13
90377	2020-07-04 23:25:19	2020-07-04	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	23729	pick-up	0	22
90378	2020-07-04 23:26:21	2020-07-04	8	[{"id_menu":5,"count":1}]	35114	delivery	5	13
90379	2020-07-04 23:26:34	2020-07-04	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	35012	delivery	5	39
90380	2020-07-04 23:26:46	2020-07-04	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2951	delivery	5	22
90381	2020-07-04 23:26:51	2020-07-04	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11429	delivery	5	36
90382	2020-07-04 23:30:37	2020-07-04	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	17502	pick-up	0	26
90383	2020-07-04 23:31:44	2020-07-04	9	[{"id_menu":7,"count":1}]	22165	delivery	5	14
90384	2020-07-04 23:40:49	2020-07-04	9	[{"id_menu":6,"count":2}]	9869	delivery	5	14
90385	2020-07-04 23:41:58	2020-07-04	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7835	delivery	5	23
90386	2020-07-04 23:43:34	2020-07-04	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22049	delivery	5	51
90387	2020-07-04 23:44:17	2020-07-04	17	[{"id_menu":4,"count":1}]	15043	delivery	5	22
90388	2020-07-04 23:47:47	2020-07-04	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	35155	delivery	5	45
90389	2020-07-04 23:52:07	2020-07-04	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	35089	delivery	5	28
90390	2020-07-04 23:53:05	2020-07-04	12	[{"id_menu":1,"count":1}]	26600	pick-up	0	12
90391	2020-07-04 23:55:27	2020-07-04	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13495	delivery	5	31
90392	2020-07-04 23:55:36	2020-07-04	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	35197	delivery	5	42
90393	2020-07-04 23:56:04	2020-07-04	14	[{"id_menu":2,"count":1}]	1955	delivery	5	19
90394	2020-07-04 23:59:28	2020-07-04	14	[{"id_menu":2,"count":1}]	26951	delivery	5	19
90395	2020-07-05 00:00:39	2020-07-05	14	[{"id_menu":2,"count":1}]	27260	delivery	5	19
90396	2020-07-05 00:01:38	2020-07-05	12	[{"id_menu":1,"count":1}]	35250	delivery	5	17
90397	2020-07-05 00:06:28	2020-07-05	8	[{"id_menu":5,"count":1}]	35399	delivery	5	13
90398	2020-07-05 00:09:55	2020-07-05	8	[{"id_menu":5,"count":1}]	32979	delivery	5	13
90399	2020-07-05 00:11:05	2020-07-05	12	[{"id_menu":1,"count":1}]	35309	delivery	5	17
90400	2020-07-05 00:16:11	2020-07-05	14	[{"id_menu":2,"count":1}]	12254	pick-up	0	14
90401	2020-07-05 00:16:36	2020-07-05	9	[{"id_menu":6,"count":1}]	35391	pick-up	0	9
90402	2020-07-05 00:19:34	2020-07-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	35372	delivery	5	31
90403	2020-07-05 00:22:50	2020-07-05	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	33920	delivery	5	31
90404	2020-07-05 00:24:43	2020-07-05	14	[{"id_menu":2,"count":1}]	80	pick-up	0	14
90405	2020-07-05 00:24:50	2020-07-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23105	delivery	5	23
90406	2020-07-05 00:27:06	2020-07-05	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	14196	delivery	5	28
90407	2020-07-05 00:27:14	2020-07-05	9	[{"id_menu":7,"count":1}]	10356	delivery	5	14
90408	2020-07-05 00:32:39	2020-07-05	12	[{"id_menu":3,"count":1}]	35392	delivery	5	17
90476	2020-07-05 02:29:16	2020-07-05	9	[{"id_menu":7,"count":1}]	27907	delivery	5	14
90409	2020-07-05 00:32:58	2020-07-05	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9565	delivery	5	36
90410	2020-07-05 00:34:15	2020-07-05	12	[{"id_menu":3,"count":1}]	16308	pick-up	0	12
90411	2020-07-05 00:36:33	2020-07-05	12	[{"id_menu":3,"count":1}]	727	pick-up	0	12
90412	2020-07-05 00:37:31	2020-07-05	8	[{"id_menu":5,"count":1}]	19369	delivery	5	13
90413	2020-07-05 00:39:11	2020-07-05	14	[{"id_menu":2,"count":1}]	1044	pick-up	0	14
90414	2020-07-05 00:40:28	2020-07-05	12	[{"id_menu":3,"count":1}]	21535	delivery	5	17
90415	2020-07-05 00:41:27	2020-07-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	21617	delivery	5	22
90416	2020-07-05 00:41:47	2020-07-05	9	[{"id_menu":6,"count":1}]	9204	delivery	5	14
90417	2020-07-05 00:42:40	2020-07-05	9	[{"id_menu":7,"count":2}]	1533	pick-up	0	9
90418	2020-07-05 00:42:41	2020-07-05	14	[{"id_menu":2,"count":2}]	68	pick-up	0	14
90419	2020-07-05 00:45:11	2020-07-05	14	[{"id_menu":2,"count":2}]	11189	delivery	5	19
90420	2020-07-05 00:47:06	2020-07-05	9	[{"id_menu":6,"count":1}]	10365	delivery	5	14
90421	2020-07-05 00:49:23	2020-07-05	9	[{"id_menu":6,"count":1}]	21517	delivery	5	14
90422	2020-07-05 00:50:23	2020-07-05	12	[{"id_menu":1,"count":1}]	20077	delivery	5	17
90423	2020-07-05 00:50:36	2020-07-05	14	[{"id_menu":2,"count":1}]	1889	pick-up	0	14
90424	2020-07-05 00:51:41	2020-07-05	17	[{"id_menu":4,"count":1}]	17189	delivery	5	22
90425	2020-07-05 00:52:50	2020-07-05	9	[{"id_menu":7,"count":1}]	4176	delivery	5	14
90426	2020-07-05 00:53:51	2020-07-05	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34034	delivery	5	35
90427	2020-07-05 00:58:38	2020-07-05	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35390	delivery	5	31
90428	2020-07-05 01:01:50	2020-07-05	8	[{"id_menu":5,"count":1}]	22174	delivery	5	13
90429	2020-07-05 01:06:10	2020-07-05	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	26735	delivery	5	31
90430	2020-07-05 01:06:11	2020-07-05	12	[{"id_menu":3,"count":1}]	28991	delivery	5	17
90431	2020-07-05 01:06:22	2020-07-05	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35207	delivery	5	35
90432	2020-07-05 01:12:33	2020-07-05	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5448	delivery	5	35
90433	2020-07-05 01:14:52	2020-07-05	14	[{"id_menu":2,"count":1}]	35297	delivery	5	19
90434	2020-07-05 01:17:03	2020-07-05	14	[{"id_menu":2,"count":1}]	16271	delivery	5	19
90435	2020-07-05 01:19:01	2020-07-05	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	35329	delivery	5	40
90436	2020-07-05 01:19:32	2020-07-05	9	[{"id_menu":7,"count":1}]	35244	delivery	5	14
90437	2020-07-05 01:19:53	2020-07-05	14	[{"id_menu":2,"count":1}]	11878	delivery	5	19
90438	2020-07-05 01:19:55	2020-07-05	14	[{"id_menu":2,"count":2}]	4161	pick-up	0	14
90439	2020-07-05 01:20:07	2020-07-05	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	21776	delivery	5	31
90440	2020-07-05 01:21:02	2020-07-05	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	890	delivery	5	53
90441	2020-07-05 01:22:21	2020-07-05	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20931	delivery	5	31
90442	2020-07-05 01:26:46	2020-07-05	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31429	delivery	5	34
90443	2020-07-05 01:27:04	2020-07-05	14	[{"id_menu":2,"count":1}]	18557	pick-up	0	14
90444	2020-07-05 01:28:38	2020-07-05	14	[{"id_menu":2,"count":1}]	17347	delivery	5	19
90445	2020-07-05 01:29:00	2020-07-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11647	delivery	5	23
90446	2020-07-05 01:34:29	2020-07-05	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	22528	delivery	5	38
90447	2020-07-05 01:34:36	2020-07-05	14	[{"id_menu":2,"count":1}]	10144	delivery	5	19
90448	2020-07-05 01:35:01	2020-07-05	8	[{"id_menu":5,"count":2}]	26362	delivery	5	13
90449	2020-07-05 01:36:23	2020-07-05	17	[{"id_menu":4,"count":1}]	5803	delivery	5	22
90450	2020-07-05 01:37:50	2020-07-05	14	[{"id_menu":2,"count":1}]	6516	delivery	5	19
90451	2020-07-05 01:47:06	2020-07-05	12	[{"id_menu":1,"count":1}]	35026	delivery	5	17
90452	2020-07-05 01:48:22	2020-07-05	9	[{"id_menu":6,"count":1}]	20890	delivery	5	14
90453	2020-07-05 01:50:33	2020-07-05	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13531	delivery	5	39
90454	2020-07-05 01:52:51	2020-07-05	14	[{"id_menu":2,"count":1}]	35216	delivery	5	19
90455	2020-07-05 01:53:42	2020-07-05	12	[{"id_menu":1,"count":1}]	27070	pick-up	0	12
90456	2020-07-05 01:55:31	2020-07-05	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21836	delivery	5	34
90457	2020-07-05 01:56:09	2020-07-05	17	[{"id_menu":4,"count":1}]	7847	delivery	5	22
90458	2020-07-05 01:56:59	2020-07-05	9	[{"id_menu":7,"count":1}]	10033	delivery	5	14
90459	2020-07-05 01:57:30	2020-07-05	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2130	pick-up	0	26
90460	2020-07-05 01:58:31	2020-07-05	9	[{"id_menu":6,"count":2}]	30455	pick-up	0	9
90461	2020-07-05 01:59:09	2020-07-05	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	21233	delivery	5	40
90462	2020-07-05 01:59:53	2020-07-05	17	[{"id_menu":4,"count":1}]	926	pick-up	0	17
90463	2020-07-05 02:01:07	2020-07-05	17	[{"id_menu":4,"count":1}]	35213	pick-up	0	17
90464	2020-07-05 02:01:10	2020-07-05	9	[{"id_menu":6,"count":1}]	5782	delivery	5	14
90465	2020-07-05 02:01:55	2020-07-05	8	[{"id_menu":5,"count":2}]	10867	pick-up	0	8
90466	2020-07-05 02:03:51	2020-07-05	8	[{"id_menu":5,"count":1}]	25120	delivery	5	13
90467	2020-07-05 02:04:05	2020-07-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	35386	delivery	5	31
90468	2020-07-05 02:06:22	2020-07-05	9	[{"id_menu":6,"count":1}]	23542	delivery	5	14
90469	2020-07-05 02:09:57	2020-07-05	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24392	delivery	5	37
90470	2020-07-05 02:15:19	2020-07-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	25295	pick-up	0	23
90471	2020-07-05 02:16:01	2020-07-05	9	[{"id_menu":6,"count":1}]	21739	delivery	5	14
90472	2020-07-05 02:20:43	2020-07-05	8	[{"id_menu":5,"count":1}]	20377	delivery	5	13
90473	2020-07-05 02:24:56	2020-07-05	12	[{"id_menu":1,"count":1}]	3544	pick-up	0	12
90474	2020-07-05 02:27:19	2020-07-05	12	[{"id_menu":1,"count":1}]	35290	delivery	5	17
90475	2020-07-05 02:28:38	2020-07-05	9	[{"id_menu":6,"count":1}]	12377	delivery	5	14
90477	2020-07-05 02:30:11	2020-07-05	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3111	pick-up	0	21
90478	2020-07-05 02:32:39	2020-07-05	12	[{"id_menu":3,"count":1}]	3909	delivery	5	17
90479	2020-07-05 02:33:19	2020-07-05	12	[{"id_menu":1,"count":1}]	35231	delivery	5	17
90480	2020-07-05 02:36:56	2020-07-05	8	[{"id_menu":5,"count":1}]	12367	pick-up	0	8
90481	2020-07-05 02:37:27	2020-07-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14491	delivery	5	22
90482	2020-07-05 02:40:59	2020-07-05	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	35327	delivery	5	26
90483	2020-07-05 02:41:08	2020-07-05	12	[{"id_menu":1,"count":1}]	32552	delivery	5	17
90484	2020-07-05 02:44:57	2020-07-05	14	[{"id_menu":2,"count":1}]	18413	delivery	5	19
90485	2020-07-05 02:46:31	2020-07-05	17	[{"id_menu":4,"count":1}]	25735	pick-up	0	17
90486	2020-07-05 02:46:40	2020-07-05	12	[{"id_menu":1,"count":1}]	35255	delivery	5	17
90487	2020-07-05 02:49:50	2020-07-05	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	4578	delivery	5	25
90488	2020-07-05 02:53:38	2020-07-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18335	delivery	5	22
90489	2020-07-05 02:54:54	2020-07-05	12	[{"id_menu":1,"count":1}]	25750	pick-up	0	12
90490	2020-07-05 02:55:00	2020-07-05	14	[{"id_menu":2,"count":1}]	32343	pick-up	0	14
90491	2020-07-05 02:56:40	2020-07-05	12	[{"id_menu":3,"count":1}]	35224	delivery	5	17
90492	2020-07-05 02:57:12	2020-07-05	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	30839	pick-up	0	26
90493	2020-07-05 02:57:47	2020-07-05	9	[{"id_menu":7,"count":1}]	31076	pick-up	0	9
90494	2020-07-05 02:59:00	2020-07-05	17	[{"id_menu":4,"count":1}]	35225	delivery	5	22
90495	2020-07-05 02:59:32	2020-07-05	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11943	delivery	5	45
90496	2020-07-05 03:01:06	2020-07-05	17	[{"id_menu":4,"count":1}]	5615	delivery	5	22
90497	2020-07-05 03:01:20	2020-07-05	8	[{"id_menu":5,"count":1}]	6511	pick-up	0	8
90498	2020-07-05 03:05:55	2020-07-05	9	[{"id_menu":6,"count":1}]	14086	pick-up	0	9
90499	2020-07-05 03:06:27	2020-07-05	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	35378	delivery	5	28
90500	2020-07-05 03:06:50	2020-07-05	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	35336	delivery	5	43
90501	2020-07-05 03:10:05	2020-07-05	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	11921	delivery	5	31
90502	2020-07-05 03:12:45	2020-07-05	17	[{"id_menu":4,"count":1}]	1650	pick-up	0	17
90503	2020-07-05 03:13:12	2020-07-05	12	[{"id_menu":1,"count":1}]	33623	delivery	5	17
90504	2020-07-05 03:15:53	2020-07-05	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	35346	delivery	5	28
90505	2020-07-05 03:16:05	2020-07-05	12	[{"id_menu":3,"count":1}]	11393	delivery	5	17
90506	2020-07-05 03:16:28	2020-07-05	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	30700	delivery	5	36
90507	2020-07-05 03:18:05	2020-07-05	9	[{"id_menu":7,"count":1}]	17596	delivery	5	14
90508	2020-07-05 03:18:12	2020-07-05	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	31697	delivery	5	30
90509	2020-07-05 03:18:21	2020-07-05	9	[{"id_menu":7,"count":1}]	17078	delivery	5	14
90510	2020-07-05 03:19:55	2020-07-05	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	32899	delivery	5	46
90511	2020-07-05 03:21:31	2020-07-05	9	[{"id_menu":7,"count":2}]	20946	delivery	5	14
90512	2020-07-05 03:23:29	2020-07-05	12	[{"id_menu":1,"count":1}]	19707	delivery	5	17
90513	2020-07-05 03:24:00	2020-07-05	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	21028	delivery	5	26
90514	2020-07-05 03:25:55	2020-07-05	8	[{"id_menu":5,"count":1}]	35226	delivery	5	13
90515	2020-07-05 03:31:15	2020-07-05	9	[{"id_menu":7,"count":1}]	11380	delivery	5	14
90516	2020-07-05 03:32:53	2020-07-05	9	[{"id_menu":6,"count":1}]	15453	delivery	5	14
90517	2020-07-05 03:34:35	2020-07-05	8	[{"id_menu":5,"count":1}]	15653	pick-up	0	8
90518	2020-07-05 03:36:08	2020-07-05	12	[{"id_menu":3,"count":1}]	2031	pick-up	0	12
90519	2020-07-05 03:37:03	2020-07-05	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	26420	delivery	5	31
90520	2020-07-05 03:38:43	2020-07-05	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	22482	delivery	5	25
90521	2020-07-05 03:39:38	2020-07-05	9	[{"id_menu":7,"count":1}]	34145	delivery	5	14
90522	2020-07-05 03:39:48	2020-07-05	9	[{"id_menu":7,"count":1}]	35252	delivery	5	14
90523	2020-07-05 03:42:08	2020-07-05	9	[{"id_menu":7,"count":1}]	2470	delivery	5	14
90524	2020-07-05 03:46:20	2020-07-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	35229	delivery	5	28
90525	2020-07-05 03:46:36	2020-07-05	12	[{"id_menu":1,"count":1}]	35265	pick-up	0	12
90526	2020-07-05 03:46:38	2020-07-05	17	[{"id_menu":4,"count":2}]	35403	delivery	5	22
90527	2020-07-05 03:47:57	2020-07-05	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	17790	delivery	5	26
90528	2020-07-05 03:48:43	2020-07-05	17	[{"id_menu":4,"count":1}]	17209	pick-up	0	17
90529	2020-07-05 03:49:54	2020-07-05	9	[{"id_menu":6,"count":1}]	35312	delivery	5	14
90530	2020-07-05 03:49:59	2020-07-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	35332	delivery	5	31
90531	2020-07-05 03:50:32	2020-07-05	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	28605	delivery	5	30
90532	2020-07-05 03:52:20	2020-07-05	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	8123	pick-up	0	23
90533	2020-07-05 03:56:53	2020-07-05	9	[{"id_menu":7,"count":2}]	35232	delivery	5	14
90534	2020-07-05 03:57:28	2020-07-05	8	[{"id_menu":5,"count":1}]	6941	pick-up	0	8
90535	2020-07-05 03:58:02	2020-07-05	9	[{"id_menu":7,"count":1}]	25932	delivery	5	14
90536	2020-07-05 03:58:42	2020-07-05	9	[{"id_menu":7,"count":1}]	35353	delivery	5	14
90537	2020-07-05 03:59:05	2020-07-05	9	[{"id_menu":7,"count":1}]	11576	delivery	5	14
90538	2020-07-05 04:00:56	2020-07-05	14	[{"id_menu":2,"count":1}]	30391	pick-up	0	14
90539	2020-07-05 04:05:49	2020-07-05	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	9716	delivery	5	35
90540	2020-07-05 04:09:48	2020-07-05	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	10598	delivery	5	26
90541	2020-07-05 04:09:52	2020-07-05	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	14427	pick-up	0	24
90542	2020-07-05 04:16:32	2020-07-05	12	[{"id_menu":3,"count":1}]	11187	delivery	5	17
90543	2020-07-05 04:17:14	2020-07-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23879	delivery	5	22
90544	2020-07-05 04:17:42	2020-07-05	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	543	pick-up	0	40
90545	2020-07-05 04:18:14	2020-07-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35268	delivery	5	23
90546	2020-07-05 04:19:14	2020-07-05	9	[{"id_menu":6,"count":1}]	27849	delivery	5	14
90547	2020-07-05 04:19:49	2020-07-05	17	[{"id_menu":4,"count":1}]	35335	delivery	5	22
90548	2020-07-05 04:20:30	2020-07-05	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	11754	delivery	5	27
90549	2020-07-05 04:22:02	2020-07-05	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	10379	delivery	5	28
90550	2020-07-05 04:22:22	2020-07-05	9	[{"id_menu":7,"count":1}]	14789	delivery	5	14
90551	2020-07-05 04:22:39	2020-07-05	8	[{"id_menu":5,"count":1}]	27532	delivery	5	13
90552	2020-07-05 04:24:35	2020-07-05	8	[{"id_menu":5,"count":1}]	12954	delivery	5	13
90553	2020-07-05 04:25:22	2020-07-05	17	[{"id_menu":4,"count":1}]	35274	delivery	5	22
90554	2020-07-05 04:26:02	2020-07-05	9	[{"id_menu":7,"count":2}]	35294	pick-up	0	9
90555	2020-07-05 04:28:32	2020-07-05	9	[{"id_menu":6,"count":1}]	35245	pick-up	0	9
90556	2020-07-05 04:33:06	2020-07-05	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	35361	delivery	5	57
90557	2020-07-05 04:35:29	2020-07-05	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	35206	delivery	5	36
90558	2020-07-05 04:37:31	2020-07-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17691	pick-up	0	17
90559	2020-07-05 04:37:33	2020-07-05	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1107	pick-up	0	50
90560	2020-07-05 04:39:00	2020-07-05	12	[{"id_menu":3,"count":1}]	1289	pick-up	0	12
90561	2020-07-05 04:39:34	2020-07-05	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	19102	delivery	5	36
90562	2020-07-05 04:39:51	2020-07-05	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	20196	delivery	5	22
90563	2020-07-05 04:40:02	2020-07-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	12303	delivery	5	31
90564	2020-07-05 04:42:30	2020-07-05	14	[{"id_menu":2,"count":1}]	11709	delivery	5	19
90565	2020-07-05 04:45:49	2020-07-05	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	35319	pick-up	0	39
90566	2020-07-05 04:46:54	2020-07-05	14	[{"id_menu":2,"count":1}]	15731	pick-up	0	14
90567	2020-07-05 04:47:01	2020-07-05	9	[{"id_menu":7,"count":1}]	21657	delivery	5	14
90568	2020-07-05 04:47:12	2020-07-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	6670	delivery	5	22
90569	2020-07-05 04:48:32	2020-07-05	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	22160	delivery	5	23
90570	2020-07-05 04:52:01	2020-07-05	9	[{"id_menu":7,"count":1}]	13737	delivery	5	14
90571	2020-07-05 04:54:42	2020-07-05	14	[{"id_menu":2,"count":1}]	27090	delivery	5	19
90572	2020-07-05 04:57:08	2020-07-05	12	[{"id_menu":1,"count":1}]	35251	delivery	5	17
90573	2020-07-05 05:15:18	2020-07-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2332	delivery	5	23
90574	2020-07-05 05:15:26	2020-07-05	12	[{"id_menu":1,"count":1}]	20161	delivery	5	17
90575	2020-07-05 05:15:40	2020-07-05	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	35355	delivery	5	37
90576	2020-07-05 05:19:40	2020-07-05	14	[{"id_menu":2,"count":1}]	26311	pick-up	0	14
90577	2020-07-05 05:21:40	2020-07-05	17	[{"id_menu":4,"count":1}]	19332	delivery	5	22
90578	2020-07-05 05:22:22	2020-07-05	12	[{"id_menu":3,"count":1}]	35267	delivery	5	17
90579	2020-07-05 05:22:55	2020-07-05	17	[{"id_menu":4,"count":1}]	33246	delivery	5	22
90580	2020-07-05 05:23:52	2020-07-05	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	7424	delivery	5	40
90581	2020-07-05 05:24:00	2020-07-05	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1167	delivery	5	27
90582	2020-07-05 05:24:19	2020-07-05	9	[{"id_menu":7,"count":1}]	4428	pick-up	0	9
90583	2020-07-05 05:25:28	2020-07-05	9	[{"id_menu":6,"count":1}]	19923	delivery	5	14
90584	2020-07-05 05:26:23	2020-07-05	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	35208	delivery	5	31
90585	2020-07-05 05:27:55	2020-07-05	9	[{"id_menu":7,"count":1}]	24407	delivery	5	14
90586	2020-07-05 05:28:10	2020-07-05	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	35359	delivery	5	42
90587	2020-07-05 05:32:23	2020-07-05	9	[{"id_menu":6,"count":1}]	22402	delivery	5	14
90588	2020-07-05 05:33:07	2020-07-05	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	25761	delivery	5	26
90589	2020-07-05 05:34:05	2020-07-05	9	[{"id_menu":6,"count":1}]	5158	delivery	5	14
90590	2020-07-05 05:34:19	2020-07-05	8	[{"id_menu":5,"count":1}]	12272	delivery	5	13
90591	2020-07-05 05:38:28	2020-07-05	9	[{"id_menu":6,"count":1}]	1425	pick-up	0	9
90592	2020-07-05 05:39:33	2020-07-05	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	18332	delivery	5	34
90593	2020-07-05 05:42:30	2020-07-05	9	[{"id_menu":6,"count":1}]	2511	pick-up	0	9
90594	2020-07-05 05:43:03	2020-07-05	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	35302	delivery	5	28
90595	2020-07-05 05:44:58	2020-07-05	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	19845	delivery	5	34
90596	2020-07-05 05:46:28	2020-07-05	9	[{"id_menu":7,"count":1}]	2244	pick-up	0	9
90597	2020-07-05 05:52:16	2020-07-05	14	[{"id_menu":2,"count":1}]	5355	pick-up	0	14
90598	2020-07-05 05:53:51	2020-07-05	9	[{"id_menu":6,"count":1}]	20663	delivery	5	14
90599	2020-07-05 05:54:25	2020-07-05	12	[{"id_menu":3,"count":1}]	14768	delivery	5	17
90600	2020-07-05 05:54:51	2020-07-05	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	18365	delivery	5	27
90601	2020-07-05 05:55:05	2020-07-05	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4720	pick-up	0	17
90602	2020-07-05 05:57:09	2020-07-05	9	[{"id_menu":6,"count":1}]	35271	delivery	5	14
90603	2020-07-05 05:57:57	2020-07-05	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	35217	delivery	5	48
90604	2020-07-05 05:58:02	2020-07-05	12	[{"id_menu":1,"count":1}]	27212	delivery	5	17
90605	2020-07-05 05:58:04	2020-07-05	14	[{"id_menu":2,"count":1}]	17685	pick-up	0	14
90606	2020-07-05 05:58:08	2020-07-05	9	[{"id_menu":7,"count":1}]	229	pick-up	0	9
90607	2020-07-05 06:03:31	2020-07-05	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	35393	delivery	5	44
90608	2020-07-05 06:06:35	2020-07-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	35248	delivery	5	22
90609	2020-07-05 06:06:58	2020-07-05	9	[{"id_menu":6,"count":1}]	11025	delivery	5	14
90610	2020-07-05 06:08:18	2020-07-05	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	34930	pick-up	0	31
90611	2020-07-05 06:08:48	2020-07-05	12	[{"id_menu":1,"count":1}]	35305	delivery	5	17
90612	2020-07-05 06:10:05	2020-07-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	26408	delivery	5	28
90613	2020-07-05 06:10:13	2020-07-05	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	31869	delivery	5	36
90614	2020-07-05 06:10:54	2020-07-05	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	4393	delivery	5	25
90615	2020-07-05 06:11:31	2020-07-05	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19681	delivery	5	52
90616	2020-07-05 06:11:41	2020-07-05	12	[{"id_menu":1,"count":1}]	35278	pick-up	0	12
90617	2020-07-05 06:13:10	2020-07-05	9	[{"id_menu":6,"count":1}]	35314	delivery	5	14
90618	2020-07-05 06:13:11	2020-07-05	12	[{"id_menu":1,"count":1}]	29806	delivery	5	17
90619	2020-07-05 06:14:37	2020-07-05	9	[{"id_menu":7,"count":1}]	35291	delivery	5	14
90620	2020-07-05 06:16:11	2020-07-05	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	28268	delivery	5	30
90621	2020-07-05 06:20:16	2020-07-05	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4090	pick-up	0	39
90622	2020-07-05 06:22:09	2020-07-05	9	[{"id_menu":7,"count":1}]	5194	pick-up	0	9
90623	2020-07-05 06:23:08	2020-07-05	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	35276	delivery	5	22
90624	2020-07-05 06:25:00	2020-07-05	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	34551	delivery	5	34
90625	2020-07-05 06:25:09	2020-07-05	9	[{"id_menu":7,"count":1}]	35230	delivery	5	14
90626	2020-07-05 06:25:14	2020-07-05	12	[{"id_menu":3,"count":1}]	998	delivery	5	17
90627	2020-07-05 06:25:56	2020-07-05	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	34788	delivery	5	26
90628	2020-07-05 06:28:52	2020-07-05	17	[{"id_menu":4,"count":1}]	33631	delivery	5	22
90629	2020-07-05 06:29:53	2020-07-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30099	pick-up	0	18
90630	2020-07-05 06:31:46	2020-07-05	9	[{"id_menu":7,"count":1}]	13025	pick-up	0	9
90631	2020-07-05 06:33:38	2020-07-05	9	[{"id_menu":6,"count":2}]	9466	pick-up	0	9
90632	2020-07-05 06:34:10	2020-07-05	9	[{"id_menu":7,"count":3}]	35228	delivery	5	14
90633	2020-07-05 06:34:18	2020-07-05	9	[{"id_menu":7,"count":1}]	35115	delivery	5	14
90634	2020-07-05 06:41:55	2020-07-05	9	[{"id_menu":7,"count":1}]	32112	delivery	5	14
90635	2020-07-05 06:44:33	2020-07-05	12	[{"id_menu":3,"count":1}]	35295	delivery	5	17
90636	2020-07-05 06:44:40	2020-07-05	14	[{"id_menu":2,"count":1}]	18294	pick-up	0	14
90637	2020-07-05 06:45:06	2020-07-05	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	8866	delivery	5	26
90638	2020-07-05 06:47:25	2020-07-05	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	17922	delivery	5	40
90639	2020-07-05 06:48:36	2020-07-05	9	[{"id_menu":6,"count":1}]	35334	delivery	5	14
90640	2020-07-05 06:51:25	2020-07-05	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12546	delivery	5	40
90641	2020-07-05 06:51:28	2020-07-05	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	31881	delivery	5	42
90642	2020-07-05 06:53:35	2020-07-05	9	[{"id_menu":6,"count":1}]	35341	delivery	5	14
90643	2020-07-05 06:53:39	2020-07-05	9	[{"id_menu":6,"count":1}]	1211	delivery	5	14
90644	2020-07-05 06:58:14	2020-07-05	9	[{"id_menu":6,"count":2}]	35210	pick-up	0	9
90645	2020-07-05 06:58:35	2020-07-05	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1780	pick-up	0	26
90646	2020-07-05 07:01:27	2020-07-05	8	[{"id_menu":5,"count":1}]	26437	delivery	5	13
90647	2020-07-05 07:02:09	2020-07-05	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	34091	pick-up	0	34
90648	2020-07-05 07:05:18	2020-07-05	12	[{"id_menu":1,"count":1}]	35235	delivery	5	17
90649	2020-07-05 07:05:20	2020-07-05	12	[{"id_menu":3,"count":1}]	35270	delivery	5	17
90650	2020-07-05 07:05:29	2020-07-05	9	[{"id_menu":7,"count":1}]	5840	delivery	5	14
90651	2020-07-05 07:09:25	2020-07-05	9	[{"id_menu":7,"count":1}]	24765	delivery	5	14
90652	2020-07-05 07:11:29	2020-07-05	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	4116	delivery	5	25
90653	2020-07-05 07:11:52	2020-07-05	9	[{"id_menu":7,"count":1}]	35310	delivery	5	14
90654	2020-07-05 07:15:00	2020-07-05	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	18309	pick-up	0	23
90655	2020-07-05 07:15:36	2020-07-05	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23665	delivery	5	22
90656	2020-07-05 07:16:36	2020-07-05	8	[{"id_menu":5,"count":1}]	35233	delivery	5	13
90657	2020-07-05 07:17:11	2020-07-05	17	[{"id_menu":4,"count":1}]	32065	delivery	5	22
90658	2020-07-05 07:19:26	2020-07-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	20140	delivery	5	28
90659	2020-07-05 07:24:55	2020-07-05	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7002	delivery	5	36
90660	2020-07-05 07:25:11	2020-07-05	14	[{"id_menu":2,"count":1}]	16727	delivery	5	19
90661	2020-07-05 07:26:08	2020-07-05	8	[{"id_menu":5,"count":1}]	25969	delivery	5	13
90662	2020-07-05 07:26:16	2020-07-05	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	13157	delivery	5	29
90663	2020-07-05 07:26:30	2020-07-05	14	[{"id_menu":2,"count":1}]	35383	delivery	5	19
90664	2020-07-05 07:29:15	2020-07-05	14	[{"id_menu":2,"count":1}]	6965	delivery	5	19
90665	2020-07-05 07:30:35	2020-07-05	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	21102	delivery	5	30
90666	2020-07-05 07:30:46	2020-07-05	8	[{"id_menu":5,"count":1}]	27214	delivery	5	13
90667	2020-07-05 07:30:49	2020-07-05	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	14668	delivery	5	34
90668	2020-07-05 07:31:40	2020-07-05	12	[{"id_menu":1,"count":1}]	16766	delivery	5	17
90669	2020-07-05 07:32:26	2020-07-05	9	[{"id_menu":7,"count":1}]	13621	delivery	5	14
90670	2020-07-05 07:32:34	2020-07-05	12	[{"id_menu":3,"count":1}]	19776	pick-up	0	12
90671	2020-07-05 07:32:40	2020-07-05	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	26240	delivery	5	28
90672	2020-07-05 07:33:14	2020-07-05	12	[{"id_menu":3,"count":1}]	35234	delivery	5	17
90673	2020-07-05 07:35:02	2020-07-05	8	[{"id_menu":5,"count":1}]	35350	pick-up	0	8
90674	2020-07-05 07:39:10	2020-07-05	12	[{"id_menu":3,"count":1}]	31791	pick-up	0	12
90675	2020-07-05 07:41:39	2020-07-05	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	19563	delivery	5	28
90676	2020-07-05 07:42:04	2020-07-05	17	[{"id_menu":4,"count":1}]	35380	delivery	5	22
90677	2020-07-05 07:43:04	2020-07-05	12	[{"id_menu":1,"count":1}]	18664	pick-up	0	12
90678	2020-07-05 07:49:40	2020-07-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	32085	delivery	5	31
90679	2020-07-05 07:55:39	2020-07-05	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	16239	delivery	5	28
90680	2020-07-05 07:57:48	2020-07-05	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":2}]	35246	delivery	5	27
90681	2020-07-05 08:05:41	2020-07-05	9	[{"id_menu":6,"count":1}]	9769	delivery	5	14
90682	2020-07-05 08:12:00	2020-07-05	9	[{"id_menu":6,"count":1}]	19922	delivery	5	14
90683	2020-07-05 08:13:03	2020-07-05	9	[{"id_menu":6,"count":1}]	4685	pick-up	0	9
90684	2020-07-05 08:13:17	2020-07-05	12	[{"id_menu":3,"count":1}]	10498	delivery	5	17
90685	2020-07-05 08:13:21	2020-07-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	12185	delivery	5	28
90686	2020-07-05 08:18:37	2020-07-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14638	delivery	5	22
90687	2020-07-05 08:18:59	2020-07-05	9	[{"id_menu":6,"count":1}]	35227	delivery	5	14
90688	2020-07-05 08:21:51	2020-07-05	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	22537	delivery	5	28
90689	2020-07-05 08:22:49	2020-07-05	14	[{"id_menu":2,"count":1}]	25438	delivery	5	19
90690	2020-07-05 08:23:24	2020-07-05	9	[{"id_menu":7,"count":1}]	34599	delivery	5	14
90691	2020-07-05 08:24:22	2020-07-05	12	[{"id_menu":1,"count":1}]	35282	delivery	5	17
90692	2020-07-05 08:27:25	2020-07-05	9	[{"id_menu":6,"count":2}]	18352	delivery	5	14
90693	2020-07-05 08:28:40	2020-07-05	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35279	delivery	5	35
90694	2020-07-05 08:32:47	2020-07-05	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	22759	delivery	5	34
90695	2020-07-05 08:37:51	2020-07-05	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	29796	delivery	5	43
90696	2020-07-05 08:37:57	2020-07-05	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	477	delivery	5	31
90697	2020-07-05 08:40:50	2020-07-05	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	35220	delivery	5	28
90698	2020-07-05 08:47:30	2020-07-05	12	[{"id_menu":3,"count":2}]	2691	pick-up	0	12
90699	2020-07-05 08:47:36	2020-07-05	17	[{"id_menu":4,"count":1}]	30625	delivery	5	22
90700	2020-07-05 08:47:52	2020-07-05	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10703	delivery	5	45
90701	2020-07-05 08:49:59	2020-07-05	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	23464	delivery	5	34
90702	2020-07-05 08:50:27	2020-07-05	14	[{"id_menu":2,"count":1}]	35221	delivery	5	19
90703	2020-07-05 08:50:52	2020-07-05	9	[{"id_menu":7,"count":2}]	26300	delivery	5	14
90704	2020-07-05 08:51:15	2020-07-05	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15627	delivery	5	43
90705	2020-07-05 08:51:17	2020-07-05	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	34794	delivery	5	27
90706	2020-07-05 08:52:16	2020-07-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":3}]	35340	delivery	5	28
90707	2020-07-05 08:52:38	2020-07-05	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	35321	delivery	5	25
90708	2020-07-05 08:52:50	2020-07-05	12	[{"id_menu":3,"count":1}]	18810	pick-up	0	12
90709	2020-07-05 08:53:33	2020-07-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13435	delivery	5	23
90710	2020-07-05 08:54:03	2020-07-05	9	[{"id_menu":6,"count":1}]	2621	delivery	5	14
90711	2020-07-05 08:54:22	2020-07-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	18752	delivery	5	28
90712	2020-07-05 08:54:36	2020-07-05	14	[{"id_menu":2,"count":2}]	28161	delivery	5	19
90713	2020-07-05 08:57:19	2020-07-05	9	[{"id_menu":7,"count":1}]	7652	pick-up	0	9
90714	2020-07-05 08:59:07	2020-07-05	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	35288	delivery	5	43
90715	2020-07-05 09:00:43	2020-07-05	14	[{"id_menu":2,"count":1}]	7772	delivery	5	19
90716	2020-07-05 09:00:44	2020-07-05	17	[{"id_menu":4,"count":1}]	35300	pick-up	0	17
90717	2020-07-05 09:01:30	2020-07-05	9	[{"id_menu":7,"count":1}]	35339	delivery	5	14
90718	2020-07-05 09:03:11	2020-07-05	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35349	delivery	5	31
90719	2020-07-05 09:09:07	2020-07-05	9	[{"id_menu":6,"count":1}]	18144	pick-up	0	9
90720	2020-07-05 09:09:23	2020-07-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22361	delivery	5	23
90721	2020-07-05 09:09:39	2020-07-05	9	[{"id_menu":6,"count":1}]	35311	delivery	5	14
90722	2020-07-05 09:10:29	2020-07-05	14	[{"id_menu":2,"count":1}]	2867	pick-up	0	14
90723	2020-07-05 09:10:37	2020-07-05	12	[{"id_menu":3,"count":1}]	32111	delivery	5	17
90724	2020-07-05 09:11:26	2020-07-05	12	[{"id_menu":1,"count":1}]	35306	delivery	5	17
90725	2020-07-05 09:11:31	2020-07-05	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	31496	delivery	5	31
90726	2020-07-05 09:11:45	2020-07-05	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	28174	delivery	5	26
90727	2020-07-05 09:12:34	2020-07-05	9	[{"id_menu":7,"count":1}]	3736	pick-up	0	9
90728	2020-07-05 09:15:09	2020-07-05	9	[{"id_menu":6,"count":1}]	35394	delivery	5	14
90729	2020-07-05 09:15:44	2020-07-05	12	[{"id_menu":1,"count":1}]	14692	delivery	5	17
90730	2020-07-05 09:16:54	2020-07-05	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":2}]	3335	delivery	5	31
90731	2020-07-05 09:19:10	2020-07-05	14	[{"id_menu":2,"count":1}]	22283	delivery	5	19
90732	2020-07-05 09:21:17	2020-07-05	9	[{"id_menu":7,"count":2}]	15679	delivery	5	14
90733	2020-07-05 09:30:06	2020-07-05	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8007	delivery	5	28
90734	2020-07-05 09:30:24	2020-07-05	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	19854	delivery	5	28
90735	2020-07-05 09:31:12	2020-07-05	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	30629	delivery	5	34
90736	2020-07-05 09:42:24	2020-07-05	8	[{"id_menu":5,"count":1}]	30647	delivery	5	13
90737	2020-07-05 09:42:38	2020-07-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25020	delivery	5	23
90738	2020-07-05 09:44:10	2020-07-05	12	[{"id_menu":3,"count":1}]	6489	pick-up	0	12
90739	2020-07-05 09:46:07	2020-07-05	14	[{"id_menu":2,"count":1}]	2520	delivery	5	19
90740	2020-07-05 09:48:34	2020-07-05	9	[{"id_menu":6,"count":1}]	12881	delivery	5	14
90741	2020-07-05 09:52:37	2020-07-05	9	[{"id_menu":7,"count":1}]	9695	delivery	5	14
90742	2020-07-05 09:52:40	2020-07-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	35387	delivery	5	31
90743	2020-07-05 09:54:07	2020-07-05	14	[{"id_menu":2,"count":1}]	19635	pick-up	0	14
90744	2020-07-05 09:56:16	2020-07-05	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6098	delivery	5	49
90745	2020-07-05 09:58:52	2020-07-05	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	3645	delivery	5	26
90746	2020-07-05 10:01:11	2020-07-05	12	[{"id_menu":1,"count":1}]	35256	delivery	5	17
90747	2020-07-05 10:03:45	2020-07-05	9	[{"id_menu":6,"count":1}]	19720	delivery	5	14
90748	2020-07-05 10:06:26	2020-07-05	14	[{"id_menu":2,"count":1}]	4599	delivery	5	19
90749	2020-07-05 10:07:34	2020-07-05	8	[{"id_menu":5,"count":1}]	35362	delivery	5	13
90750	2020-07-05 10:07:57	2020-07-05	9	[{"id_menu":7,"count":1}]	35322	delivery	5	14
90751	2020-07-05 10:08:41	2020-07-05	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	22062	delivery	5	56
90752	2020-07-05 10:09:16	2020-07-05	17	[{"id_menu":4,"count":1}]	35266	delivery	5	22
90753	2020-07-05 10:09:45	2020-07-05	14	[{"id_menu":2,"count":1}]	9420	pick-up	0	14
90754	2020-07-05 10:17:59	2020-07-05	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	35218	delivery	5	42
90755	2020-07-05 10:18:54	2020-07-05	9	[{"id_menu":7,"count":2}]	9424	delivery	5	14
90756	2020-07-05 10:21:53	2020-07-05	17	[{"id_menu":4,"count":1}]	4615	pick-up	0	17
90757	2020-07-05 10:23:26	2020-07-05	17	[{"id_menu":4,"count":1}]	35375	delivery	5	22
90758	2020-07-05 10:28:21	2020-07-05	14	[{"id_menu":2,"count":3}]	35263	delivery	5	19
90759	2020-07-05 10:28:42	2020-07-05	8	[{"id_menu":5,"count":1}]	24093	pick-up	0	8
90760	2020-07-05 10:30:24	2020-07-05	9	[{"id_menu":6,"count":1}]	24571	pick-up	0	9
90761	2020-07-05 10:30:27	2020-07-05	12	[{"id_menu":1,"count":1}]	35262	delivery	5	17
90762	2020-07-05 10:32:34	2020-07-05	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2646	delivery	5	31
90763	2020-07-05 10:37:06	2020-07-05	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	20700	delivery	5	22
90764	2020-07-05 10:42:55	2020-07-05	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	7072	pick-up	0	29
90765	2020-07-05 10:44:45	2020-07-05	17	[{"id_menu":4,"count":1}]	8873	pick-up	0	17
90766	2020-07-05 10:46:58	2020-07-05	9	[{"id_menu":6,"count":1}]	5589	delivery	5	14
90767	2020-07-05 10:47:31	2020-07-05	17	[{"id_menu":4,"count":1}]	28357	delivery	5	22
90768	2020-07-05 10:48:16	2020-07-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	22973	delivery	5	28
90769	2020-07-05 10:48:27	2020-07-05	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	22243	delivery	5	40
90770	2020-07-05 10:49:27	2020-07-05	8	[{"id_menu":5,"count":1}]	13940	delivery	5	13
90771	2020-07-05 10:54:37	2020-07-05	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":2}]	29346	delivery	5	22
90772	2020-07-05 10:54:51	2020-07-05	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4020	delivery	5	40
90773	2020-07-05 10:54:52	2020-07-05	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	2641	pick-up	0	24
90774	2020-07-05 10:56:43	2020-07-05	12	[{"id_menu":1,"count":1}]	6782	delivery	5	17
90775	2020-07-05 10:58:50	2020-07-05	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	29024	pick-up	0	21
90776	2020-07-05 11:00:34	2020-07-05	17	[{"id_menu":4,"count":1}]	35243	delivery	5	22
90777	2020-07-05 11:02:02	2020-07-05	8	[{"id_menu":5,"count":1}]	35308	delivery	5	13
90778	2020-07-05 11:04:33	2020-07-05	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35371	delivery	5	31
90779	2020-07-05 11:06:28	2020-07-05	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	26445	delivery	5	26
90780	2020-07-05 11:09:46	2020-07-05	12	[{"id_menu":1,"count":1}]	1664	delivery	5	17
90781	2020-07-05 11:10:12	2020-07-05	14	[{"id_menu":2,"count":1}]	35320	delivery	5	19
90782	2020-07-05 11:10:24	2020-07-05	14	[{"id_menu":2,"count":1}]	35260	delivery	5	19
90783	2020-07-05 11:10:38	2020-07-05	14	[{"id_menu":2,"count":1}]	20749	delivery	5	19
90784	2020-07-05 11:12:36	2020-07-05	12	[{"id_menu":1,"count":1}]	2228	pick-up	0	12
90785	2020-07-05 11:15:20	2020-07-05	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	14759	delivery	5	36
90786	2020-07-05 11:16:15	2020-07-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	12169	delivery	5	22
90787	2020-07-05 11:16:43	2020-07-05	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9708	delivery	5	37
90788	2020-07-05 11:19:09	2020-07-05	8	[{"id_menu":5,"count":1}]	20656	delivery	5	13
90789	2020-07-05 11:19:39	2020-07-05	9	[{"id_menu":7,"count":1}]	35367	delivery	5	14
90790	2020-07-05 11:20:32	2020-07-05	9	[{"id_menu":7,"count":1}]	17594	pick-up	0	9
90791	2020-07-05 11:20:44	2020-07-05	9	[{"id_menu":6,"count":1}]	14040	delivery	5	14
90792	2020-07-05 11:24:13	2020-07-05	9	[{"id_menu":7,"count":1}]	4635	pick-up	0	9
90793	2020-07-05 11:24:25	2020-07-05	9	[{"id_menu":7,"count":1}]	16240	delivery	5	14
90794	2020-07-05 11:25:10	2020-07-05	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	35277	delivery	5	39
90795	2020-07-05 11:25:55	2020-07-05	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	486	pick-up	0	26
90796	2020-07-05 11:28:04	2020-07-05	9	[{"id_menu":6,"count":1}]	4794	delivery	5	14
90797	2020-07-05 11:31:33	2020-07-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10886	delivery	5	22
90798	2020-07-05 11:32:20	2020-07-05	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	35254	delivery	5	30
90799	2020-07-05 11:36:10	2020-07-05	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20865	delivery	5	34
90800	2020-07-05 11:36:15	2020-07-05	12	[{"id_menu":1,"count":1}]	27087	delivery	5	17
90801	2020-07-05 11:40:25	2020-07-05	8	[{"id_menu":5,"count":1}]	1956	pick-up	0	8
90802	2020-07-05 11:40:33	2020-07-05	12	[{"id_menu":3,"count":1}]	10479	pick-up	0	12
90803	2020-07-05 11:41:51	2020-07-05	9	[{"id_menu":6,"count":1}]	35389	delivery	5	14
90804	2020-07-05 11:42:36	2020-07-05	8	[{"id_menu":5,"count":1}]	35287	pick-up	0	8
90805	2020-07-05 11:44:53	2020-07-05	12	[{"id_menu":3,"count":1}]	10951	pick-up	0	12
90806	2020-07-05 11:45:00	2020-07-05	9	[{"id_menu":7,"count":2}]	20954	delivery	5	14
90807	2020-07-05 11:45:22	2020-07-05	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	35257	delivery	5	26
90808	2020-07-05 11:47:38	2020-07-05	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25171	delivery	5	39
90809	2020-07-05 11:52:14	2020-07-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32379	delivery	5	22
90810	2020-07-05 11:52:35	2020-07-05	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	4987	pick-up	0	26
90811	2020-07-05 11:53:14	2020-07-05	12	[{"id_menu":1,"count":1}]	29851	delivery	5	17
90812	2020-07-05 11:53:15	2020-07-05	8	[{"id_menu":5,"count":1}]	35328	delivery	5	13
90813	2020-07-05 11:55:46	2020-07-05	14	[{"id_menu":2,"count":1}]	22414	delivery	5	19
90814	2020-07-05 11:59:04	2020-07-05	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":3}]	8467	delivery	5	26
90815	2020-07-05 12:00:45	2020-07-05	9	[{"id_menu":7,"count":1}]	32942	delivery	5	14
90816	2020-07-05 12:00:46	2020-07-05	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	35369	delivery	5	39
90817	2020-07-05 12:01:10	2020-07-05	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	26232	pick-up	0	26
90818	2020-07-05 12:03:17	2020-07-05	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	23539	delivery	5	26
90819	2020-07-05 12:05:46	2020-07-05	8	[{"id_menu":5,"count":1}]	5338	pick-up	0	8
90820	2020-07-05 12:06:39	2020-07-05	8	[{"id_menu":5,"count":1}]	35384	delivery	5	13
90821	2020-07-05 12:14:15	2020-07-05	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	34153	delivery	5	42
90822	2020-07-05 12:15:59	2020-07-05	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2311	pick-up	0	20
90823	2020-07-05 12:18:36	2020-07-05	9	[{"id_menu":7,"count":1}]	35237	delivery	5	14
90824	2020-07-05 12:20:49	2020-07-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26526	pick-up	0	18
90825	2020-07-05 12:22:39	2020-07-05	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	7741	pick-up	0	26
90826	2020-07-05 12:24:47	2020-07-05	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	6413	delivery	5	40
90827	2020-07-05 12:25:59	2020-07-05	9	[{"id_menu":7,"count":1}]	16283	delivery	5	14
90828	2020-07-05 12:26:41	2020-07-05	8	[{"id_menu":5,"count":1}]	35366	delivery	5	13
90829	2020-07-05 12:28:16	2020-07-05	9	[{"id_menu":6,"count":1}]	35313	delivery	5	14
90830	2020-07-05 12:31:23	2020-07-05	9	[{"id_menu":6,"count":1}]	35344	delivery	5	14
90831	2020-07-05 12:35:05	2020-07-05	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20169	delivery	5	51
90832	2020-07-05 12:35:46	2020-07-05	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	35358	delivery	5	40
90833	2020-07-05 12:35:55	2020-07-05	9	[{"id_menu":7,"count":1}]	35275	pick-up	0	9
90834	2020-07-05 12:37:47	2020-07-05	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	31840	delivery	5	40
90835	2020-07-05 12:39:19	2020-07-05	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	35401	delivery	5	39
90836	2020-07-05 12:39:42	2020-07-05	9	[{"id_menu":7,"count":1}]	9193	delivery	5	14
90837	2020-07-05 12:40:14	2020-07-05	14	[{"id_menu":2,"count":1}]	5811	pick-up	0	14
90838	2020-07-05 12:41:38	2020-07-05	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	22706	delivery	5	40
90839	2020-07-05 12:42:51	2020-07-05	9	[{"id_menu":6,"count":1}]	19423	delivery	5	14
90840	2020-07-05 12:43:05	2020-07-05	8	[{"id_menu":5,"count":1}]	7635	delivery	5	13
90841	2020-07-05 12:47:26	2020-07-05	12	[{"id_menu":3,"count":1}]	17814	pick-up	0	12
90842	2020-07-05 12:47:29	2020-07-05	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	30955	pick-up	0	29
90843	2020-07-05 12:48:21	2020-07-05	17	[{"id_menu":4,"count":1}]	381	pick-up	0	17
90844	2020-07-05 12:48:30	2020-07-05	9	[{"id_menu":7,"count":1}]	16127	pick-up	0	9
90845	2020-07-05 12:50:10	2020-07-05	17	[{"id_menu":4,"count":1}]	9337	pick-up	0	17
90846	2020-07-05 12:50:41	2020-07-05	14	[{"id_menu":2,"count":1}]	35249	delivery	5	19
90847	2020-07-05 12:51:05	2020-07-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17726	delivery	5	22
90848	2020-07-05 12:52:02	2020-07-05	9	[{"id_menu":6,"count":1}]	35402	delivery	5	14
90849	2020-07-05 12:52:20	2020-07-05	9	[{"id_menu":7,"count":1}]	35323	pick-up	0	9
90850	2020-07-05 12:53:43	2020-07-05	8	[{"id_menu":5,"count":1}]	13429	pick-up	0	8
90851	2020-07-05 12:57:07	2020-07-05	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	33077	delivery	5	38
90852	2020-07-05 12:59:03	2020-07-05	14	[{"id_menu":2,"count":1}]	1464	pick-up	0	14
90853	2020-07-05 12:59:09	2020-07-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13272	delivery	5	31
90854	2020-07-05 12:59:12	2020-07-05	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	35398	delivery	5	43
90855	2020-07-05 12:59:27	2020-07-05	12	[{"id_menu":3,"count":1}]	14756	delivery	5	17
90856	2020-07-05 13:00:07	2020-07-05	9	[{"id_menu":7,"count":1}]	16592	delivery	5	14
90857	2020-07-05 13:03:59	2020-07-05	14	[{"id_menu":2,"count":1}]	18996	delivery	5	19
90858	2020-07-05 13:04:22	2020-07-05	12	[{"id_menu":1,"count":1}]	35240	delivery	5	17
90859	2020-07-05 13:05:23	2020-07-05	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	29682	delivery	5	31
90860	2020-07-05 13:06:38	2020-07-05	9	[{"id_menu":6,"count":1}]	16423	delivery	5	14
90861	2020-07-05 13:08:51	2020-07-05	17	[{"id_menu":4,"count":1}]	35253	delivery	5	22
90862	2020-07-05 13:11:47	2020-07-05	12	[{"id_menu":1,"count":1}]	35299	delivery	5	17
90863	2020-07-05 13:13:07	2020-07-05	14	[{"id_menu":2,"count":1}]	7046	pick-up	0	14
90864	2020-07-05 13:15:16	2020-07-05	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11144	delivery	5	45
90865	2020-07-05 13:16:35	2020-07-05	8	[{"id_menu":5,"count":2}]	35330	delivery	5	13
90866	2020-07-05 13:18:26	2020-07-05	9	[{"id_menu":7,"count":1}]	23857	delivery	5	14
90867	2020-07-05 13:18:32	2020-07-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	35304	delivery	5	31
90868	2020-07-05 13:19:12	2020-07-05	9	[{"id_menu":6,"count":1}]	2425	pick-up	0	9
90869	2020-07-05 13:22:37	2020-07-05	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	18102	delivery	5	56
90870	2020-07-05 13:22:37	2020-07-05	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	17126	delivery	5	28
90871	2020-07-05 13:24:01	2020-07-05	8	[{"id_menu":5,"count":2}]	16508	delivery	5	13
90872	2020-07-05 13:24:32	2020-07-05	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	34651	delivery	5	28
90873	2020-07-05 13:25:09	2020-07-05	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	9727	delivery	5	31
90874	2020-07-05 13:29:42	2020-07-05	8	[{"id_menu":5,"count":1}]	19924	delivery	5	13
90875	2020-07-05 13:33:47	2020-07-05	9	[{"id_menu":6,"count":1}]	12087	delivery	5	14
90876	2020-07-05 13:34:04	2020-07-05	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	16858	pick-up	0	31
90877	2020-07-05 13:34:31	2020-07-05	17	[{"id_menu":4,"count":1}]	1742	pick-up	0	17
90878	2020-07-05 13:37:52	2020-07-05	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	16069	pick-up	0	33
90879	2020-07-05 13:39:11	2020-07-05	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	286	pick-up	0	50
90880	2020-07-05 13:41:36	2020-07-05	9	[{"id_menu":7,"count":1}]	35338	delivery	5	14
90881	2020-07-05 13:42:04	2020-07-05	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	35360	delivery	5	22
90882	2020-07-05 13:42:43	2020-07-05	9	[{"id_menu":7,"count":1}]	13439	delivery	5	14
90883	2020-07-05 13:42:49	2020-07-05	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7451	delivery	5	40
90884	2020-07-05 13:42:52	2020-07-05	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	35259	delivery	5	26
90885	2020-07-05 13:42:56	2020-07-05	9	[{"id_menu":6,"count":1}]	18736	delivery	5	14
90886	2020-07-05 13:43:11	2020-07-05	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	31467	delivery	5	25
90887	2020-07-05 13:46:51	2020-07-05	8	[{"id_menu":5,"count":1}]	15645	pick-up	0	8
90888	2020-07-05 13:54:13	2020-07-05	12	[{"id_menu":3,"count":1}]	35211	delivery	5	17
90889	2020-07-05 13:54:54	2020-07-05	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4834	delivery	5	45
90890	2020-07-05 14:00:02	2020-07-05	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33570	delivery	5	35
90891	2020-07-05 14:02:28	2020-07-05	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14812	delivery	5	43
90892	2020-07-05 14:02:51	2020-07-05	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23424	pick-up	0	41
90893	2020-07-05 14:04:54	2020-07-05	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	35247	delivery	5	36
90894	2020-07-05 14:08:42	2020-07-05	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16719	delivery	5	43
90895	2020-07-05 14:08:52	2020-07-05	9	[{"id_menu":6,"count":1}]	35325	pick-up	0	9
90896	2020-07-05 14:10:11	2020-07-05	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":2}]	3364	delivery	5	27
90897	2020-07-05 14:12:56	2020-07-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35272	delivery	5	23
90898	2020-07-05 14:14:14	2020-07-05	8	[{"id_menu":5,"count":1}]	20476	delivery	5	13
90899	2020-07-05 14:15:02	2020-07-05	9	[{"id_menu":6,"count":1}]	9796	pick-up	0	9
90900	2020-07-05 14:16:53	2020-07-05	9	[{"id_menu":7,"count":1}]	35293	delivery	5	14
90901	2020-07-05 14:17:11	2020-07-05	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	31716	delivery	5	31
90902	2020-07-05 14:18:53	2020-07-05	9	[{"id_menu":6,"count":2}]	4367	pick-up	0	9
90903	2020-07-05 14:19:14	2020-07-05	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	34388	delivery	5	40
90904	2020-07-05 14:20:14	2020-07-05	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	10628	delivery	5	23
90905	2020-07-05 14:24:23	2020-07-05	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	35239	delivery	5	34
90906	2020-07-05 14:24:40	2020-07-05	12	[{"id_menu":3,"count":1}]	35215	delivery	5	17
90907	2020-07-05 14:26:21	2020-07-05	17	[{"id_menu":4,"count":2}]	37	pick-up	0	17
90908	2020-07-05 14:26:24	2020-07-05	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	29042	delivery	5	34
90909	2020-07-05 14:27:33	2020-07-05	9	[{"id_menu":7,"count":1}]	14441	delivery	5	14
90910	2020-07-05 14:29:29	2020-07-05	8	[{"id_menu":5,"count":1}]	8109	pick-up	0	8
90911	2020-07-05 14:31:19	2020-07-05	14	[{"id_menu":2,"count":1}]	355	delivery	5	19
90912	2020-07-05 14:31:30	2020-07-05	14	[{"id_menu":2,"count":1}]	35397	pick-up	0	14
90913	2020-07-05 14:35:14	2020-07-05	9	[{"id_menu":6,"count":1}]	11961	delivery	5	14
90914	2020-07-05 14:37:59	2020-07-05	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	21665	delivery	5	37
90915	2020-07-05 14:38:03	2020-07-05	8	[{"id_menu":5,"count":1}]	35044	delivery	5	13
90916	2020-07-05 14:38:21	2020-07-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15574	delivery	5	22
90917	2020-07-05 14:38:44	2020-07-05	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	27106	delivery	5	31
90918	2020-07-05 14:39:07	2020-07-05	9	[{"id_menu":7,"count":1}]	35280	delivery	5	14
90919	2020-07-05 14:44:08	2020-07-05	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	35376	delivery	5	23
90920	2020-07-05 14:44:43	2020-07-05	12	[{"id_menu":1,"count":1}]	6030	delivery	5	17
90921	2020-07-05 14:45:57	2020-07-05	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	28933	delivery	5	36
90922	2020-07-05 14:48:13	2020-07-05	14	[{"id_menu":2,"count":1}]	24511	delivery	5	19
90923	2020-07-05 14:48:28	2020-07-05	12	[{"id_menu":1,"count":1}]	16632	pick-up	0	12
90924	2020-07-05 14:48:46	2020-07-05	9	[{"id_menu":6,"count":1}]	35269	pick-up	0	9
90925	2020-07-05 14:49:18	2020-07-05	9	[{"id_menu":7,"count":1}]	30699	delivery	5	14
90926	2020-07-05 14:52:01	2020-07-05	14	[{"id_menu":2,"count":1}]	35209	delivery	5	19
90927	2020-07-05 14:52:59	2020-07-05	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	35345	delivery	5	36
90928	2020-07-05 14:53:28	2020-07-05	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	5917	pick-up	0	20
90929	2020-07-05 14:54:01	2020-07-05	9	[{"id_menu":7,"count":1}]	17353	pick-up	0	9
90930	2020-07-05 14:54:10	2020-07-05	9	[{"id_menu":6,"count":1}]	4949	delivery	5	14
90931	2020-07-05 14:58:19	2020-07-05	9	[{"id_menu":7,"count":1}]	16165	pick-up	0	9
90932	2020-07-05 14:58:36	2020-07-05	9	[{"id_menu":7,"count":1}]	16680	delivery	5	14
90933	2020-07-05 14:59:18	2020-07-05	8	[{"id_menu":5,"count":1}]	35364	delivery	5	13
90934	2020-07-05 15:00:49	2020-07-05	17	[{"id_menu":4,"count":1}]	18870	delivery	5	22
90935	2020-07-05 15:01:11	2020-07-05	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	18924	delivery	5	45
90936	2020-07-05 15:07:19	2020-07-05	12	[{"id_menu":3,"count":1}]	35316	delivery	5	17
90937	2020-07-05 15:07:37	2020-07-05	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	35356	delivery	5	22
90938	2020-07-05 15:08:32	2020-07-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7301	delivery	5	23
90939	2020-07-05 15:12:46	2020-07-05	9	[{"id_menu":6,"count":1}]	23334	delivery	5	14
90940	2020-07-05 15:19:26	2020-07-05	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":2}]	31966	delivery	5	28
90941	2020-07-05 15:20:28	2020-07-05	8	[{"id_menu":5,"count":1}]	1110	delivery	5	13
90942	2020-07-05 15:21:21	2020-07-05	9	[{"id_menu":6,"count":1}]	26038	delivery	5	14
90943	2020-07-05 15:27:11	2020-07-05	9	[{"id_menu":7,"count":1}]	31656	delivery	5	14
90944	2020-07-05 15:30:36	2020-07-05	9	[{"id_menu":6,"count":1}]	1205	pick-up	0	9
90945	2020-07-05 15:32:18	2020-07-05	9	[{"id_menu":6,"count":1}]	14905	delivery	5	14
90946	2020-07-05 15:32:41	2020-07-05	12	[{"id_menu":3,"count":1}]	31571	delivery	5	17
90947	2020-07-05 15:36:06	2020-07-05	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	33484	delivery	5	26
90948	2020-07-05 15:38:24	2020-07-05	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":2}]	385	delivery	5	22
90949	2020-07-05 15:43:31	2020-07-05	14	[{"id_menu":2,"count":1}]	34252	pick-up	0	14
90950	2020-07-05 15:45:51	2020-07-05	14	[{"id_menu":2,"count":1}]	14679	pick-up	0	14
90951	2020-07-05 15:47:50	2020-07-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28515	delivery	5	23
90952	2020-07-05 15:48:25	2020-07-05	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	24767	pick-up	0	22
90953	2020-07-05 15:49:17	2020-07-05	17	[{"id_menu":4,"count":1}]	9891	delivery	5	22
90954	2020-07-05 15:50:33	2020-07-05	12	[{"id_menu":3,"count":1}]	799	pick-up	0	12
90955	2020-07-05 15:50:45	2020-07-05	8	[{"id_menu":5,"count":1}]	8640	pick-up	0	8
90956	2020-07-05 15:52:14	2020-07-05	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7825	delivery	5	36
90957	2020-07-05 15:54:53	2020-07-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9977	pick-up	0	26
90958	2020-07-05 15:55:22	2020-07-05	8	[{"id_menu":5,"count":1}]	1379	delivery	5	13
90959	2020-07-05 15:56:52	2020-07-05	14	[{"id_menu":2,"count":1}]	23546	delivery	5	19
90960	2020-07-05 15:57:15	2020-07-05	9	[{"id_menu":6,"count":1}]	13172	delivery	5	14
90961	2020-07-05 15:59:35	2020-07-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	35373	delivery	5	31
90962	2020-07-05 16:03:22	2020-07-05	9	[{"id_menu":6,"count":1}]	32553	delivery	5	14
90963	2020-07-05 16:05:27	2020-07-05	8	[{"id_menu":5,"count":1}]	16042	delivery	5	13
90964	2020-07-05 16:08:30	2020-07-05	17	[{"id_menu":4,"count":1}]	6865	delivery	5	22
90965	2020-07-05 16:09:42	2020-07-05	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	17268	delivery	5	34
90966	2020-07-05 16:09:57	2020-07-05	9	[{"id_menu":6,"count":1}]	35385	delivery	5	14
90967	2020-07-05 16:11:33	2020-07-05	17	[{"id_menu":4,"count":1}]	30096	delivery	5	22
90968	2020-07-05 16:11:48	2020-07-05	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	17270	delivery	5	26
90969	2020-07-05 16:13:05	2020-07-05	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	35317	delivery	5	34
90970	2020-07-05 16:15:55	2020-07-05	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35289	delivery	5	45
90971	2020-07-05 16:19:38	2020-07-05	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31953	delivery	5	40
90972	2020-07-05 16:20:03	2020-07-05	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	35324	delivery	5	38
90973	2020-07-05 16:20:10	2020-07-05	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	35354	delivery	5	36
90974	2020-07-05 16:22:14	2020-07-05	9	[{"id_menu":6,"count":1}]	35273	delivery	5	14
90975	2020-07-05 16:22:36	2020-07-05	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1245	pick-up	0	26
90976	2020-07-05 16:23:07	2020-07-05	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1030	delivery	5	30
90977	2020-07-05 16:23:11	2020-07-05	9	[{"id_menu":7,"count":1}]	3293	delivery	5	14
90978	2020-07-05 16:24:44	2020-07-05	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14859	delivery	5	22
90979	2020-07-05 16:26:31	2020-07-05	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	35381	delivery	5	36
90980	2020-07-05 16:26:40	2020-07-05	12	[{"id_menu":1,"count":1}]	7430	pick-up	0	12
90981	2020-07-05 16:26:54	2020-07-05	12	[{"id_menu":1,"count":1}]	1332	pick-up	0	12
90982	2020-07-05 16:28:35	2020-07-05	9	[{"id_menu":7,"count":1}]	11862	delivery	5	14
90983	2020-07-05 16:29:03	2020-07-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	143	pick-up	0	23
90984	2020-07-05 16:31:26	2020-07-05	12	[{"id_menu":1,"count":1}]	10389	pick-up	0	12
90985	2020-07-05 16:32:32	2020-07-05	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	13425	delivery	5	26
90986	2020-07-05 16:34:57	2020-07-05	9	[{"id_menu":7,"count":1}]	13762	delivery	5	14
90987	2020-07-05 16:36:06	2020-07-05	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	27078	delivery	5	31
90988	2020-07-05 16:38:56	2020-07-05	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	23036	delivery	5	26
90989	2020-07-05 16:39:52	2020-07-05	9	[{"id_menu":6,"count":1}]	35303	delivery	5	14
90990	2020-07-05 16:42:23	2020-07-05	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	14473	delivery	5	31
90991	2020-07-05 16:42:39	2020-07-05	9	[{"id_menu":6,"count":1}]	22524	delivery	5	14
90992	2020-07-05 16:45:06	2020-07-05	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35377	delivery	5	37
90993	2020-07-05 16:45:18	2020-07-05	12	[{"id_menu":1,"count":1}]	17056	pick-up	0	12
90994	2020-07-05 16:45:54	2020-07-05	8	[{"id_menu":5,"count":1}]	2561	delivery	5	13
90995	2020-07-05 16:47:32	2020-07-05	9	[{"id_menu":7,"count":2}]	20136	pick-up	0	9
90996	2020-07-05 16:50:03	2020-07-05	8	[{"id_menu":5,"count":1}]	18348	delivery	5	13
90997	2020-07-05 16:54:00	2020-07-05	9	[{"id_menu":7,"count":1}]	22383	pick-up	0	9
90998	2020-07-05 16:57:14	2020-07-05	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	29247	delivery	5	26
90999	2020-07-05 17:04:13	2020-07-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	22900	delivery	5	28
91000	2020-07-05 17:05:00	2020-07-05	8	[{"id_menu":5,"count":1}]	21160	delivery	5	13
91001	2020-07-05 17:08:04	2020-07-05	12	[{"id_menu":3,"count":1}]	16587	delivery	5	17
91002	2020-07-05 17:12:04	2020-07-05	12	[{"id_menu":1,"count":1}]	15629	delivery	5	17
91003	2020-07-05 17:12:07	2020-07-05	17	[{"id_menu":4,"count":1}]	8952	delivery	5	22
91004	2020-07-05 17:12:55	2020-07-05	9	[{"id_menu":6,"count":1}]	16578	delivery	5	14
91005	2020-07-05 17:14:13	2020-07-05	9	[{"id_menu":7,"count":1}]	4745	delivery	5	14
91006	2020-07-05 17:15:46	2020-07-05	9	[{"id_menu":6,"count":1}]	35368	delivery	5	14
91007	2020-07-05 17:17:53	2020-07-05	8	[{"id_menu":5,"count":1}]	35285	delivery	5	13
91008	2020-07-05 17:19:54	2020-07-05	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	35236	pick-up	0	26
91009	2020-07-05 17:21:32	2020-07-05	9	[{"id_menu":6,"count":1}]	35307	delivery	5	14
91010	2020-07-05 17:27:21	2020-07-05	9	[{"id_menu":6,"count":1}]	17034	delivery	5	14
91011	2020-07-05 17:30:55	2020-07-05	9	[{"id_menu":6,"count":3}]	11956	delivery	5	14
91012	2020-07-05 17:34:28	2020-07-05	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	35283	pick-up	0	29
91013	2020-07-05 17:35:50	2020-07-05	17	[{"id_menu":4,"count":1}]	35296	pick-up	0	17
91014	2020-07-05 17:36:23	2020-07-05	9	[{"id_menu":6,"count":1}]	35337	delivery	5	14
91015	2020-07-05 17:38:12	2020-07-05	9	[{"id_menu":6,"count":1}]	3289	pick-up	0	9
91016	2020-07-05 17:39:33	2020-07-05	17	[{"id_menu":4,"count":1}]	27257	pick-up	0	17
91017	2020-07-05 17:39:48	2020-07-05	9	[{"id_menu":6,"count":1}]	18237	delivery	5	14
91018	2020-07-05 17:40:13	2020-07-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	26656	delivery	5	22
91019	2020-07-05 17:41:11	2020-07-05	14	[{"id_menu":2,"count":1}]	35212	pick-up	0	14
91020	2020-07-05 17:42:03	2020-07-05	9	[{"id_menu":6,"count":1}]	7476	delivery	5	14
91021	2020-07-05 17:44:48	2020-07-05	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	408	delivery	5	26
91022	2020-07-05 17:45:05	2020-07-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4988	pick-up	0	26
91023	2020-07-05 17:49:47	2020-07-05	12	[{"id_menu":3,"count":1}]	35352	delivery	5	17
91024	2020-07-05 17:49:52	2020-07-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2134	delivery	5	23
91025	2020-07-05 17:50:44	2020-07-05	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	28712	pick-up	0	38
91026	2020-07-05 17:50:54	2020-07-05	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	14037	delivery	5	40
91027	2020-07-05 17:51:48	2020-07-05	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	16729	delivery	5	27
91028	2020-07-05 17:58:04	2020-07-05	29	[{"id_menu":3,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16679	delivery	5	34
91029	2020-07-05 18:02:30	2020-07-05	9	[{"id_menu":7,"count":1}]	1079	delivery	5	14
91030	2020-07-05 18:04:30	2020-07-05	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	35388	delivery	5	31
91031	2020-07-05 18:04:36	2020-07-05	12	[{"id_menu":3,"count":1}]	35301	delivery	5	17
91032	2020-07-05 18:04:59	2020-07-05	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	28734	delivery	5	39
91033	2020-07-05 18:05:56	2020-07-05	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14249	delivery	5	51
91034	2020-07-05 18:06:58	2020-07-05	17	[{"id_menu":4,"count":1}]	34208	pick-up	0	17
91035	2020-07-05 18:08:41	2020-07-05	14	[{"id_menu":2,"count":1}]	3205	delivery	5	19
91036	2020-07-05 18:11:12	2020-07-05	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	31893	delivery	5	43
91037	2020-07-05 18:13:40	2020-07-05	9	[{"id_menu":7,"count":1}]	23450	delivery	5	14
91038	2020-07-05 18:14:01	2020-07-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31736	delivery	5	22
91039	2020-07-05 18:16:04	2020-07-05	14	[{"id_menu":2,"count":1}]	10662	delivery	5	19
91040	2020-07-05 18:16:44	2020-07-05	9	[{"id_menu":6,"count":1}]	35298	delivery	5	14
91041	2020-07-05 18:19:16	2020-07-05	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	23758	delivery	5	31
91042	2020-07-05 18:21:29	2020-07-05	9	[{"id_menu":7,"count":1}]	31900	delivery	5	14
91043	2020-07-05 18:22:36	2020-07-05	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	7278	delivery	5	29
91044	2020-07-05 18:23:55	2020-07-05	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	9378	delivery	5	44
91045	2020-07-05 18:24:24	2020-07-05	9	[{"id_menu":7,"count":1}]	20664	delivery	5	14
91046	2020-07-05 18:24:55	2020-07-05	8	[{"id_menu":5,"count":1}]	31859	delivery	5	13
91047	2020-07-05 18:25:52	2020-07-05	9	[{"id_menu":6,"count":1}]	11383	pick-up	0	9
91048	2020-07-05 18:25:53	2020-07-05	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1075	pick-up	0	23
91049	2020-07-05 18:31:26	2020-07-05	12	[{"id_menu":1,"count":1}]	21003	delivery	5	17
91050	2020-07-05 18:32:19	2020-07-05	17	[{"id_menu":4,"count":1}]	30632	delivery	5	22
91051	2020-07-05 18:33:20	2020-07-05	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	18793	pick-up	0	29
91052	2020-07-05 18:34:37	2020-07-05	14	[{"id_menu":2,"count":1}]	9737	delivery	5	19
91053	2020-07-05 18:34:53	2020-07-05	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18263	delivery	5	39
91054	2020-07-05 18:35:28	2020-07-05	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5101	delivery	5	34
91055	2020-07-05 18:35:30	2020-07-05	9	[{"id_menu":6,"count":1}]	2943	pick-up	0	9
91056	2020-07-05 18:41:51	2020-07-05	8	[{"id_menu":5,"count":1}]	35343	delivery	5	13
91057	2020-07-05 18:45:15	2020-07-05	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	26292	delivery	5	31
91058	2020-07-05 18:47:03	2020-07-05	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	14010	pick-up	0	26
91059	2020-07-05 18:47:20	2020-07-05	17	[{"id_menu":4,"count":1}]	35038	pick-up	0	17
91060	2020-07-05 18:51:11	2020-07-05	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	14947	pick-up	0	24
91061	2020-07-05 18:51:26	2020-07-05	8	[{"id_menu":5,"count":1}]	27199	delivery	5	13
91062	2020-07-05 18:53:37	2020-07-05	12	[{"id_menu":1,"count":1}]	2564	delivery	5	17
91063	2020-07-05 18:57:23	2020-07-05	9	[{"id_menu":6,"count":1}]	11363	delivery	5	14
91064	2020-07-05 18:58:39	2020-07-05	17	[{"id_menu":4,"count":1}]	35223	pick-up	0	17
91065	2020-07-05 19:01:53	2020-07-05	14	[{"id_menu":2,"count":1}]	26223	delivery	5	19
91066	2020-07-05 19:02:26	2020-07-05	9	[{"id_menu":7,"count":1}]	12774	delivery	5	14
91067	2020-07-05 19:04:02	2020-07-05	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8828	delivery	5	31
91068	2020-07-05 19:09:52	2020-07-05	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3069	pick-up	0	26
91069	2020-07-05 19:13:26	2020-07-05	8	[{"id_menu":5,"count":1}]	35396	delivery	5	13
91070	2020-07-05 19:18:27	2020-07-05	12	[{"id_menu":1,"count":2}]	1198	pick-up	0	12
91071	2020-07-05 19:22:54	2020-07-05	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5678	delivery	5	22
91072	2020-07-05 19:23:19	2020-07-05	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1929	pick-up	0	21
91073	2020-07-05 19:31:33	2020-07-05	9	[{"id_menu":6,"count":1}]	21072	delivery	5	14
91074	2020-07-05 19:35:49	2020-07-05	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28208	delivery	5	35
91075	2020-07-05 19:38:12	2020-07-05	9	[{"id_menu":6,"count":1}]	26927	delivery	5	14
91076	2020-07-05 19:41:35	2020-07-05	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	34121	delivery	5	25
91077	2020-07-05 19:41:56	2020-07-05	14	[{"id_menu":2,"count":1}]	15415	delivery	5	19
91078	2020-07-05 19:43:21	2020-07-05	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	19488	delivery	5	48
91079	2020-07-05 19:46:02	2020-07-05	9	[{"id_menu":6,"count":1}]	10638	delivery	5	14
91080	2020-07-05 19:52:10	2020-07-05	14	[{"id_menu":2,"count":1}]	2618	delivery	5	19
91081	2020-07-05 19:52:12	2020-07-05	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	29139	delivery	5	22
91082	2020-07-05 20:00:08	2020-07-05	9	[{"id_menu":7,"count":1}]	33452	pick-up	0	9
91083	2020-07-05 20:07:10	2020-07-05	9	[{"id_menu":6,"count":1}]	8771	delivery	5	14
91084	2020-07-05 20:07:34	2020-07-05	8	[{"id_menu":5,"count":1}]	35214	delivery	5	13
91085	2020-07-05 20:08:21	2020-07-05	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	35292	delivery	5	34
91086	2020-07-05 20:09:12	2020-07-05	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	33022	delivery	5	26
91087	2020-07-05 20:11:43	2020-07-05	9	[{"id_menu":6,"count":1}]	3227	pick-up	0	9
91088	2020-07-05 20:17:17	2020-07-05	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	21092	delivery	5	43
91089	2020-07-05 20:26:11	2020-07-05	14	[{"id_menu":2,"count":2}]	28230	pick-up	0	14
91090	2020-07-05 20:26:26	2020-07-05	9	[{"id_menu":6,"count":1}]	19860	delivery	5	14
91091	2020-07-05 20:27:40	2020-07-05	9	[{"id_menu":7,"count":2}]	4458	pick-up	0	9
91092	2020-07-05 20:29:27	2020-07-05	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	35241	delivery	5	34
91093	2020-07-05 20:32:20	2020-07-05	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	32870	delivery	5	26
91094	2020-07-05 20:32:34	2020-07-05	17	[{"id_menu":4,"count":1}]	8275	delivery	5	22
91095	2020-07-05 20:35:59	2020-07-05	12	[{"id_menu":1,"count":1}]	2519	delivery	5	17
91096	2020-07-05 20:39:18	2020-07-05	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	18567	delivery	5	26
91097	2020-07-05 20:43:29	2020-07-05	9	[{"id_menu":7,"count":1}]	13488	delivery	5	14
91098	2020-07-05 20:50:39	2020-07-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	35365	delivery	5	22
91099	2020-07-05 20:52:41	2020-07-05	8	[{"id_menu":5,"count":1}]	15596	delivery	5	13
91100	2020-07-05 20:53:48	2020-07-05	8	[{"id_menu":5,"count":1}]	213	pick-up	0	8
91101	2020-07-05 20:53:51	2020-07-05	12	[{"id_menu":1,"count":1}]	35284	delivery	5	17
91102	2020-07-05 20:55:00	2020-07-05	12	[{"id_menu":1,"count":1}]	23073	delivery	5	17
91103	2020-07-05 20:55:19	2020-07-05	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27660	delivery	5	52
91104	2020-07-05 20:57:40	2020-07-05	9	[{"id_menu":6,"count":1}]	13943	delivery	5	14
91105	2020-07-05 21:01:22	2020-07-05	9	[{"id_menu":7,"count":1}]	2531	delivery	5	14
91106	2020-07-05 21:01:26	2020-07-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	35261	delivery	5	22
91107	2020-07-05 21:05:28	2020-07-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	11802	delivery	5	23
91108	2020-07-05 21:06:00	2020-07-05	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	28987	delivery	5	43
91109	2020-07-05 21:06:12	2020-07-05	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	1922	delivery	5	31
91110	2020-07-05 21:06:34	2020-07-05	8	[{"id_menu":5,"count":1}]	35242	delivery	5	13
91111	2020-07-05 21:07:40	2020-07-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9731	delivery	5	23
91112	2020-07-05 21:08:05	2020-07-05	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	932	pick-up	0	25
91113	2020-07-05 21:09:59	2020-07-05	9	[{"id_menu":6,"count":1}]	28885	delivery	5	14
91114	2020-07-05 21:10:39	2020-07-05	14	[{"id_menu":2,"count":1}]	34370	delivery	5	19
91115	2020-07-05 21:13:52	2020-07-05	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	26721	delivery	5	26
91116	2020-07-05 21:14:09	2020-07-05	9	[{"id_menu":6,"count":1}]	35281	delivery	5	14
91117	2020-07-05 21:15:24	2020-07-05	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	35357	delivery	5	25
91118	2020-07-05 21:16:02	2020-07-05	12	[{"id_menu":3,"count":1}]	18199	delivery	5	17
91119	2020-07-05 21:16:21	2020-07-05	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8700	pick-up	0	25
91120	2020-07-05 21:17:14	2020-07-05	12	[{"id_menu":1,"count":1}]	4494	delivery	5	17
91121	2020-07-05 21:17:27	2020-07-05	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	32158	delivery	5	28
91122	2020-07-05 21:17:51	2020-07-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":3}]	35222	delivery	5	22
91123	2020-07-05 21:19:41	2020-07-05	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2187	delivery	5	26
91124	2020-07-05 21:20:44	2020-07-05	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	35264	pick-up	0	17
91125	2020-07-05 21:21:37	2020-07-05	9	[{"id_menu":6,"count":1}]	35152	delivery	5	14
91126	2020-07-05 21:22:23	2020-07-05	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8100	delivery	5	35
91127	2020-07-05 21:24:14	2020-07-05	12	[{"id_menu":1,"count":1}]	13126	delivery	5	17
91128	2020-07-05 21:28:30	2020-07-05	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	35258	pick-up	0	17
91129	2020-07-05 21:29:54	2020-07-05	14	[{"id_menu":2,"count":1}]	13624	delivery	5	19
91130	2020-07-05 21:33:16	2020-07-05	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	5903	delivery	5	40
91131	2020-07-05 21:33:38	2020-07-05	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35382	delivery	5	35
91132	2020-07-05 21:33:53	2020-07-05	20	[{"id_menu":1,"count":3},{"id_menu":5,"count":1}]	35238	delivery	5	25
91133	2020-07-05 21:36:55	2020-07-05	17	[{"id_menu":4,"count":2}]	28019	delivery	5	22
91134	2020-07-05 21:39:36	2020-07-05	8	[{"id_menu":5,"count":1}]	35219	delivery	5	13
91135	2020-07-05 21:43:48	2020-07-05	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	5099	pick-up	0	29
91136	2020-07-05 21:45:08	2020-07-05	17	[{"id_menu":4,"count":1}]	5215	pick-up	0	17
91137	2020-07-05 21:45:21	2020-07-05	17	[{"id_menu":4,"count":1}]	35326	delivery	5	22
91138	2020-07-05 21:45:42	2020-07-05	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	31444	delivery	5	25
91139	2020-07-05 21:48:11	2020-07-05	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	35315	delivery	5	38
91140	2020-07-05 21:53:29	2020-07-05	12	[{"id_menu":3,"count":1}]	27202	delivery	5	17
91141	2020-07-05 21:54:32	2020-07-05	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1838	delivery	5	37
91142	2020-07-05 21:55:52	2020-07-05	12	[{"id_menu":1,"count":1}]	31089	delivery	5	17
91143	2020-07-05 21:59:22	2020-07-05	9	[{"id_menu":7,"count":1}]	2731	pick-up	0	9
91144	2020-07-05 22:02:00	2020-07-05	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	27511	delivery	5	26
91145	2020-07-05 22:02:11	2020-07-05	14	[{"id_menu":2,"count":1}]	12577	pick-up	0	14
91146	2020-07-05 22:03:51	2020-07-05	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	19059	delivery	5	40
91147	2020-07-05 22:07:44	2020-07-05	12	[{"id_menu":3,"count":1}]	15720	pick-up	0	12
91148	2020-07-05 22:09:52	2020-07-05	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	14083	delivery	5	25
91149	2020-07-05 22:10:56	2020-07-05	14	[{"id_menu":2,"count":1}]	7899	delivery	5	19
91150	2020-07-05 22:12:10	2020-07-05	9	[{"id_menu":7,"count":1}]	7303	delivery	5	14
91151	2020-07-05 22:12:11	2020-07-05	12	[{"id_menu":1,"count":1}]	28695	delivery	5	17
91152	2020-07-05 22:17:20	2020-07-05	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12778	delivery	5	37
91153	2020-07-05 22:18:48	2020-07-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	35374	delivery	5	22
91154	2020-07-05 22:20:36	2020-07-05	9	[{"id_menu":7,"count":1}]	26814	pick-up	0	9
91155	2020-07-05 22:23:18	2020-07-05	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	30	pick-up	0	17
91156	2020-07-05 22:26:36	2020-07-05	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2082	delivery	5	45
91157	2020-07-05 22:29:43	2020-07-05	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	35347	delivery	5	27
91158	2020-07-05 22:29:57	2020-07-05	8	[{"id_menu":5,"count":2}]	16960	delivery	5	13
91159	2020-07-05 22:31:24	2020-07-05	8	[{"id_menu":5,"count":1}]	4195	pick-up	0	8
91160	2020-07-05 22:33:33	2020-07-05	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	17606	delivery	5	26
91161	2020-07-05 22:37:25	2020-07-05	9	[{"id_menu":7,"count":1}]	35395	delivery	5	14
91162	2020-07-05 22:44:31	2020-07-05	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	13416	delivery	5	31
91163	2020-07-05 22:45:55	2020-07-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	35400	delivery	5	31
91164	2020-07-05 22:48:16	2020-07-05	14	[{"id_menu":2,"count":1}]	12349	delivery	5	19
91165	2020-07-05 22:49:48	2020-07-05	14	[{"id_menu":2,"count":1}]	6101	pick-up	0	14
91166	2020-07-05 22:50:25	2020-07-05	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	8276	delivery	5	34
91167	2020-07-05 22:50:47	2020-07-05	12	[{"id_menu":1,"count":1}]	3641	delivery	5	17
91168	2020-07-05 22:58:55	2020-07-05	9	[{"id_menu":6,"count":1}]	18170	pick-up	0	9
91169	2020-07-05 23:01:43	2020-07-05	9	[{"id_menu":6,"count":1}]	35379	delivery	5	14
91170	2020-07-05 23:05:54	2020-07-05	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	35370	delivery	5	45
91171	2020-07-05 23:06:10	2020-07-05	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	25789	delivery	5	28
91172	2020-07-05 23:07:16	2020-07-05	9	[{"id_menu":7,"count":1}]	14101	delivery	5	14
91173	2020-07-05 23:07:51	2020-07-05	12	[{"id_menu":3,"count":1}]	11104	delivery	5	17
91174	2020-07-05 23:08:10	2020-07-05	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	5280	delivery	5	31
91175	2020-07-05 23:09:21	2020-07-05	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	35318	delivery	5	25
91176	2020-07-05 23:12:25	2020-07-05	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	12075	pick-up	0	21
91177	2020-07-05 23:12:26	2020-07-05	14	[{"id_menu":2,"count":1}]	35342	delivery	5	19
91178	2020-07-05 23:13:16	2020-07-05	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	16359	delivery	5	27
91179	2020-07-05 23:18:03	2020-07-05	9	[{"id_menu":6,"count":1}]	35351	delivery	5	14
91180	2020-07-05 23:19:46	2020-07-05	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	17650	delivery	5	28
91181	2020-07-05 23:20:27	2020-07-05	14	[{"id_menu":2,"count":1}]	14616	pick-up	0	14
91182	2020-07-05 23:21:30	2020-07-05	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	6815	delivery	5	34
91183	2020-07-05 23:23:34	2020-07-05	14	[{"id_menu":2,"count":1}]	4242	pick-up	0	14
91184	2020-07-05 23:23:50	2020-07-05	12	[{"id_menu":3,"count":1}]	35331	delivery	5	17
91185	2020-07-05 23:24:38	2020-07-05	9	[{"id_menu":6,"count":1}]	1494	delivery	5	14
91186	2020-07-05 23:25:51	2020-07-05	12	[{"id_menu":3,"count":1}]	6328	pick-up	0	12
91187	2020-07-05 23:26:57	2020-07-05	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	20432	delivery	5	23
91188	2020-07-05 23:27:01	2020-07-05	17	[{"id_menu":4,"count":1}]	30855	delivery	5	22
91189	2020-07-05 23:28:21	2020-07-05	9	[{"id_menu":7,"count":1}]	35286	delivery	5	14
91190	2020-07-05 23:36:10	2020-07-05	9	[{"id_menu":7,"count":1}]	4960	pick-up	0	9
91191	2020-07-05 23:39:27	2020-07-05	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33243	delivery	5	35
91192	2020-07-05 23:40:31	2020-07-05	17	[{"id_menu":4,"count":1}]	9766	pick-up	0	17
91193	2020-07-05 23:44:16	2020-07-05	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	35348	delivery	5	27
91194	2020-07-05 23:45:34	2020-07-05	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10740	delivery	5	44
91195	2020-07-05 23:51:47	2020-07-05	12	[{"id_menu":1,"count":1}]	32693	delivery	5	17
91196	2020-07-05 23:54:25	2020-07-05	9	[{"id_menu":6,"count":1}]	12709	pick-up	0	9
91197	2020-07-05 23:55:57	2020-07-05	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	34627	pick-up	0	21
91198	2020-07-06 00:01:43	2020-07-06	14	[{"id_menu":2,"count":1}]	35484	pick-up	0	14
91199	2020-07-06 00:04:46	2020-07-06	12	[{"id_menu":1,"count":1}]	9095	delivery	5	17
91200	2020-07-06 00:08:09	2020-07-06	9	[{"id_menu":6,"count":2}]	2798	pick-up	0	9
91201	2020-07-06 00:11:42	2020-07-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9140	delivery	5	28
91202	2020-07-06 00:12:42	2020-07-06	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13414	delivery	5	39
91203	2020-07-06 00:12:48	2020-07-06	12	[{"id_menu":1,"count":1}]	28177	delivery	5	17
91204	2020-07-06 00:15:58	2020-07-06	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8806	pick-up	0	26
91205	2020-07-06 00:16:05	2020-07-06	9	[{"id_menu":6,"count":1}]	448	delivery	5	14
91206	2020-07-06 00:17:21	2020-07-06	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	26840	delivery	5	42
91207	2020-07-06 00:17:26	2020-07-06	9	[{"id_menu":7,"count":1}]	6245	delivery	5	14
91208	2020-07-06 00:21:55	2020-07-06	17	[{"id_menu":4,"count":1}]	9005	delivery	5	22
91209	2020-07-06 00:21:58	2020-07-06	8	[{"id_menu":5,"count":1}]	22457	delivery	5	13
91210	2020-07-06 00:28:04	2020-07-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	35510	delivery	5	28
91211	2020-07-06 00:28:43	2020-07-06	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	35475	delivery	5	29
91212	2020-07-06 00:31:03	2020-07-06	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	34261	delivery	5	31
91213	2020-07-06 00:40:32	2020-07-06	14	[{"id_menu":2,"count":1}]	35480	delivery	5	19
91214	2020-07-06 00:40:51	2020-07-06	12	[{"id_menu":1,"count":1}]	25608	delivery	5	17
91215	2020-07-06 00:45:41	2020-07-06	9	[{"id_menu":7,"count":1}]	27674	delivery	5	14
91216	2020-07-06 00:50:43	2020-07-06	8	[{"id_menu":5,"count":1}]	10136	delivery	5	13
91217	2020-07-06 00:52:46	2020-07-06	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	35461	delivery	5	40
91218	2020-07-06 00:54:20	2020-07-06	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	33019	delivery	5	43
91219	2020-07-06 00:59:22	2020-07-06	9	[{"id_menu":6,"count":1}]	12181	delivery	5	14
91220	2020-07-06 01:03:37	2020-07-06	9	[{"id_menu":6,"count":1}]	35465	delivery	5	14
91221	2020-07-06 01:05:08	2020-07-06	17	[{"id_menu":4,"count":1}]	861	delivery	5	22
91222	2020-07-06 01:08:02	2020-07-06	14	[{"id_menu":2,"count":1}]	30297	delivery	5	19
91223	2020-07-06 01:08:47	2020-07-06	12	[{"id_menu":3,"count":1}]	35431	delivery	5	17
91224	2020-07-06 01:20:02	2020-07-06	14	[{"id_menu":2,"count":1}]	30812	pick-up	0	14
91225	2020-07-06 01:23:28	2020-07-06	9	[{"id_menu":7,"count":1}]	33215	delivery	5	14
91226	2020-07-06 01:23:36	2020-07-06	14	[{"id_menu":2,"count":1}]	21509	pick-up	0	14
91227	2020-07-06 01:25:54	2020-07-06	9	[{"id_menu":7,"count":1}]	7041	delivery	5	14
91228	2020-07-06 01:31:46	2020-07-06	12	[{"id_menu":3,"count":1}]	7491	delivery	5	17
91229	2020-07-06 01:38:02	2020-07-06	9	[{"id_menu":6,"count":1}]	35462	delivery	5	14
91230	2020-07-06 01:40:11	2020-07-06	12	[{"id_menu":3,"count":1}]	81	delivery	5	17
91231	2020-07-06 01:56:17	2020-07-06	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23287	pick-up	0	17
91232	2020-07-06 01:57:54	2020-07-06	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":3}]	31280	delivery	5	23
91233	2020-07-06 02:02:03	2020-07-06	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12805	delivery	5	49
91234	2020-07-06 02:03:33	2020-07-06	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12882	delivery	5	39
91235	2020-07-06 02:06:02	2020-07-06	9	[{"id_menu":6,"count":1}]	23194	delivery	5	14
91236	2020-07-06 02:10:06	2020-07-06	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18539	delivery	5	34
91237	2020-07-06 02:13:32	2020-07-06	9	[{"id_menu":6,"count":1}]	20515	pick-up	0	9
91238	2020-07-06 02:14:31	2020-07-06	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26708	delivery	5	31
91239	2020-07-06 02:14:32	2020-07-06	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	35489	delivery	5	40
91240	2020-07-06 02:19:49	2020-07-06	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	20447	delivery	5	31
91241	2020-07-06 02:24:10	2020-07-06	12	[{"id_menu":1,"count":1}]	2413	delivery	5	17
91242	2020-07-06 02:27:29	2020-07-06	14	[{"id_menu":2,"count":1}]	21975	pick-up	0	14
91243	2020-07-06 02:28:22	2020-07-06	12	[{"id_menu":1,"count":1}]	16891	pick-up	0	12
91244	2020-07-06 02:31:00	2020-07-06	9	[{"id_menu":7,"count":1}]	197	delivery	5	14
91245	2020-07-06 02:35:07	2020-07-06	12	[{"id_menu":1,"count":1}]	9767	delivery	5	17
91246	2020-07-06 02:35:41	2020-07-06	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6228	delivery	5	31
91247	2020-07-06 02:43:01	2020-07-06	12	[{"id_menu":1,"count":1}]	25984	delivery	5	17
91248	2020-07-06 02:43:49	2020-07-06	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	35556	delivery	5	31
91249	2020-07-06 02:44:52	2020-07-06	8	[{"id_menu":5,"count":1}]	35537	delivery	5	13
91250	2020-07-06 02:45:23	2020-07-06	12	[{"id_menu":1,"count":1}]	19523	pick-up	0	12
91251	2020-07-06 02:47:26	2020-07-06	14	[{"id_menu":2,"count":1}]	35541	delivery	5	19
91252	2020-07-06 02:52:33	2020-07-06	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	3052	delivery	5	26
91253	2020-07-06 02:55:36	2020-07-06	17	[{"id_menu":4,"count":1}]	22287	delivery	5	22
91254	2020-07-06 03:01:51	2020-07-06	8	[{"id_menu":5,"count":1}]	2237	pick-up	0	8
91255	2020-07-06 03:01:59	2020-07-06	9	[{"id_menu":7,"count":1}]	25203	delivery	5	14
91256	2020-07-06 03:04:38	2020-07-06	9	[{"id_menu":6,"count":1}]	29203	delivery	5	14
91257	2020-07-06 03:04:38	2020-07-06	9	[{"id_menu":6,"count":1}]	4102	pick-up	0	9
91258	2020-07-06 03:19:46	2020-07-06	9	[{"id_menu":6,"count":1}]	35113	delivery	5	14
91259	2020-07-06 03:19:54	2020-07-06	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	35502	delivery	5	27
91260	2020-07-06 03:22:49	2020-07-06	14	[{"id_menu":2,"count":1}]	35466	delivery	5	19
91261	2020-07-06 03:25:40	2020-07-06	14	[{"id_menu":2,"count":1}]	35490	delivery	5	19
91262	2020-07-06 03:29:09	2020-07-06	8	[{"id_menu":5,"count":1}]	2286	pick-up	0	8
91263	2020-07-06 03:31:39	2020-07-06	8	[{"id_menu":5,"count":1}]	33656	delivery	5	13
91264	2020-07-06 03:34:56	2020-07-06	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	35544	delivery	5	40
91265	2020-07-06 03:38:33	2020-07-06	9	[{"id_menu":6,"count":1}]	35505	delivery	5	14
91266	2020-07-06 03:42:20	2020-07-06	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	15433	delivery	5	27
91267	2020-07-06 03:51:42	2020-07-06	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17564	delivery	5	39
91268	2020-07-06 04:03:14	2020-07-06	17	[{"id_menu":4,"count":1}]	25128	delivery	5	22
91269	2020-07-06 04:08:11	2020-07-06	9	[{"id_menu":7,"count":1}]	13233	pick-up	0	9
91270	2020-07-06 04:08:58	2020-07-06	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21153	delivery	5	35
91271	2020-07-06 04:09:14	2020-07-06	12	[{"id_menu":1,"count":1}]	9737	delivery	5	17
91272	2020-07-06 04:09:21	2020-07-06	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	22064	delivery	5	23
91273	2020-07-06 04:26:26	2020-07-06	9	[{"id_menu":7,"count":1}]	27327	delivery	5	14
91274	2020-07-06 04:30:00	2020-07-06	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	10190	delivery	5	23
91275	2020-07-06 04:30:29	2020-07-06	12	[{"id_menu":3,"count":1}]	22012	delivery	5	17
91276	2020-07-06 04:30:48	2020-07-06	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	35571	delivery	5	37
91277	2020-07-06 04:30:59	2020-07-06	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	35419	delivery	5	37
91278	2020-07-06 04:32:50	2020-07-06	9	[{"id_menu":6,"count":2}]	15535	pick-up	0	9
91279	2020-07-06 04:33:41	2020-07-06	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	24883	delivery	5	28
91280	2020-07-06 04:36:04	2020-07-06	8	[{"id_menu":5,"count":1}]	35492	pick-up	0	8
91281	2020-07-06 04:36:52	2020-07-06	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	35549	delivery	5	40
91282	2020-07-06 04:37:08	2020-07-06	17	[{"id_menu":4,"count":1}]	13572	pick-up	0	17
91283	2020-07-06 04:38:06	2020-07-06	17	[{"id_menu":4,"count":1}]	2585	pick-up	0	17
91284	2020-07-06 04:39:49	2020-07-06	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1645	pick-up	0	24
91285	2020-07-06 04:44:33	2020-07-06	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	35446	delivery	5	34
91286	2020-07-06 04:47:52	2020-07-06	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	16409	pick-up	0	21
91287	2020-07-06 04:52:30	2020-07-06	14	[{"id_menu":2,"count":1}]	1721	pick-up	0	14
91288	2020-07-06 04:57:11	2020-07-06	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10432	delivery	5	45
91289	2020-07-06 05:00:45	2020-07-06	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26015	delivery	5	37
91290	2020-07-06 05:02:46	2020-07-06	9	[{"id_menu":7,"count":1}]	4783	pick-up	0	9
91291	2020-07-06 05:06:00	2020-07-06	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	6455	delivery	5	40
91292	2020-07-06 05:08:19	2020-07-06	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23298	delivery	5	31
91293	2020-07-06 05:09:55	2020-07-06	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	35463	delivery	5	26
91294	2020-07-06 05:10:52	2020-07-06	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	17941	delivery	5	22
91295	2020-07-06 05:11:56	2020-07-06	9	[{"id_menu":7,"count":2}]	1685	pick-up	0	9
91296	2020-07-06 05:13:21	2020-07-06	8	[{"id_menu":5,"count":1}]	11061	delivery	5	13
91297	2020-07-06 05:18:25	2020-07-06	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	25080	delivery	5	28
91298	2020-07-06 05:19:53	2020-07-06	12	[{"id_menu":1,"count":1}]	31798	delivery	5	17
91299	2020-07-06 05:25:27	2020-07-06	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	23405	delivery	5	34
91300	2020-07-06 05:27:23	2020-07-06	12	[{"id_menu":3,"count":1}]	7200	delivery	5	17
91301	2020-07-06 05:33:12	2020-07-06	12	[{"id_menu":3,"count":1}]	9303	delivery	5	17
91302	2020-07-06 05:47:03	2020-07-06	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	34918	delivery	5	40
91303	2020-07-06 06:07:14	2020-07-06	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	33520	delivery	5	39
91304	2020-07-06 06:07:21	2020-07-06	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	35468	pick-up	0	21
91305	2020-07-06 06:09:24	2020-07-06	17	[{"id_menu":4,"count":1}]	28808	delivery	5	22
91306	2020-07-06 06:11:39	2020-07-06	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	13707	pick-up	0	26
91307	2020-07-06 06:12:47	2020-07-06	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	35560	delivery	5	26
91308	2020-07-06 06:17:31	2020-07-06	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	34565	delivery	5	22
91309	2020-07-06 06:22:45	2020-07-06	17	[{"id_menu":4,"count":1}]	2676	delivery	5	22
91310	2020-07-06 06:34:46	2020-07-06	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	35404	delivery	5	31
91311	2020-07-06 06:37:17	2020-07-06	14	[{"id_menu":2,"count":1}]	35513	delivery	5	19
91312	2020-07-06 06:40:00	2020-07-06	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15976	delivery	5	43
91313	2020-07-06 06:53:50	2020-07-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1308	delivery	5	28
91314	2020-07-06 06:54:17	2020-07-06	12	[{"id_menu":3,"count":1}]	1075	pick-up	0	12
91315	2020-07-06 06:54:22	2020-07-06	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18810	pick-up	0	17
91316	2020-07-06 06:56:50	2020-07-06	14	[{"id_menu":2,"count":1}]	35503	pick-up	0	14
91317	2020-07-06 06:58:55	2020-07-06	12	[{"id_menu":1,"count":1}]	11094	delivery	5	17
91318	2020-07-06 07:00:24	2020-07-06	17	[{"id_menu":4,"count":1}]	35528	delivery	5	22
91319	2020-07-06 07:04:39	2020-07-06	14	[{"id_menu":2,"count":1}]	35453	delivery	5	19
91320	2020-07-06 07:04:58	2020-07-06	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18634	delivery	5	31
91321	2020-07-06 07:10:37	2020-07-06	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	18398	delivery	5	27
91322	2020-07-06 07:10:50	2020-07-06	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	35427	pick-up	0	22
91323	2020-07-06 07:14:21	2020-07-06	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10009	delivery	5	31
91324	2020-07-06 07:14:54	2020-07-06	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	6859	delivery	5	25
91325	2020-07-06 07:16:30	2020-07-06	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	22822	pick-up	0	26
91326	2020-07-06 07:33:19	2020-07-06	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10724	delivery	5	22
91327	2020-07-06 07:33:20	2020-07-06	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	16000	delivery	5	39
91328	2020-07-06 07:36:22	2020-07-06	8	[{"id_menu":5,"count":1}]	28252	pick-up	0	8
91329	2020-07-06 07:40:41	2020-07-06	9	[{"id_menu":6,"count":1}]	35447	delivery	5	14
91330	2020-07-06 07:42:24	2020-07-06	12	[{"id_menu":1,"count":1}]	34227	delivery	5	17
91331	2020-07-06 07:44:58	2020-07-06	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	2560	delivery	5	22
91332	2020-07-06 07:49:12	2020-07-06	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22062	delivery	5	39
91333	2020-07-06 07:51:27	2020-07-06	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":3}]	24117	delivery	5	30
91334	2020-07-06 07:52:32	2020-07-06	12	[{"id_menu":1,"count":1}]	23846	delivery	5	17
91335	2020-07-06 07:55:07	2020-07-06	12	[{"id_menu":1,"count":1}]	33440	delivery	5	17
91336	2020-07-06 07:59:10	2020-07-06	14	[{"id_menu":2,"count":1}]	34962	delivery	5	19
91337	2020-07-06 08:00:43	2020-07-06	9	[{"id_menu":7,"count":1}]	31313	pick-up	0	9
91338	2020-07-06 08:03:55	2020-07-06	14	[{"id_menu":2,"count":1}]	4137	pick-up	0	14
91339	2020-07-06 08:07:57	2020-07-06	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	11988	delivery	5	25
91340	2020-07-06 08:07:58	2020-07-06	14	[{"id_menu":2,"count":1}]	14662	pick-up	0	14
91341	2020-07-06 08:12:52	2020-07-06	14	[{"id_menu":2,"count":1}]	11583	delivery	5	19
91342	2020-07-06 08:14:52	2020-07-06	12	[{"id_menu":3,"count":1}]	193	pick-up	0	12
91343	2020-07-06 08:23:30	2020-07-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	735	pick-up	0	23
91344	2020-07-06 08:27:16	2020-07-06	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13434	delivery	5	22
91345	2020-07-06 08:29:47	2020-07-06	12	[{"id_menu":3,"count":1}]	32313	delivery	5	17
91346	2020-07-06 08:33:22	2020-07-06	9	[{"id_menu":7,"count":1}]	8300	delivery	5	14
91347	2020-07-06 08:35:19	2020-07-06	9	[{"id_menu":6,"count":1}]	18340	delivery	5	14
91348	2020-07-06 08:43:35	2020-07-06	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	13068	pick-up	0	26
91349	2020-07-06 08:49:58	2020-07-06	14	[{"id_menu":2,"count":2}]	15919	delivery	5	19
91350	2020-07-06 08:52:23	2020-07-06	12	[{"id_menu":1,"count":1}]	23924	delivery	5	17
91351	2020-07-06 08:57:20	2020-07-06	12	[{"id_menu":1,"count":1}]	7549	delivery	5	17
91352	2020-07-06 08:58:33	2020-07-06	17	[{"id_menu":4,"count":1}]	14052	delivery	5	22
91353	2020-07-06 09:01:46	2020-07-06	12	[{"id_menu":1,"count":1}]	23074	delivery	5	17
91354	2020-07-06 09:03:46	2020-07-06	17	[{"id_menu":4,"count":1}]	35530	delivery	5	22
91355	2020-07-06 09:04:22	2020-07-06	8	[{"id_menu":5,"count":1}]	26336	delivery	5	13
91356	2020-07-06 09:20:21	2020-07-06	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2630	pick-up	0	25
91357	2020-07-06 09:21:40	2020-07-06	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	17527	delivery	5	31
91358	2020-07-06 09:23:13	2020-07-06	9	[{"id_menu":6,"count":1}]	8666	delivery	5	14
91359	2020-07-06 09:26:37	2020-07-06	12	[{"id_menu":3,"count":1}]	4823	delivery	5	17
91360	2020-07-06 09:33:09	2020-07-06	8	[{"id_menu":5,"count":1}]	28585	delivery	5	13
91361	2020-07-06 09:35:35	2020-07-06	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	13835	pick-up	0	31
91362	2020-07-06 09:53:51	2020-07-06	12	[{"id_menu":3,"count":1}]	4130	pick-up	0	12
91363	2020-07-06 09:54:34	2020-07-06	9	[{"id_menu":7,"count":1}]	14093	delivery	5	14
91364	2020-07-06 09:55:27	2020-07-06	14	[{"id_menu":2,"count":1}]	3399	pick-up	0	14
91365	2020-07-06 09:59:37	2020-07-06	8	[{"id_menu":5,"count":1}]	21702	delivery	5	13
91366	2020-07-06 10:00:13	2020-07-06	9	[{"id_menu":7,"count":1}]	33462	delivery	5	14
91367	2020-07-06 10:05:03	2020-07-06	12	[{"id_menu":1,"count":1}]	12043	pick-up	0	12
91368	2020-07-06 10:06:56	2020-07-06	14	[{"id_menu":2,"count":2}]	11289	delivery	5	19
91369	2020-07-06 10:07:16	2020-07-06	14	[{"id_menu":2,"count":1}]	34930	delivery	5	19
91370	2020-07-06 10:09:00	2020-07-06	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	24926	delivery	5	28
91371	2020-07-06 10:11:00	2020-07-06	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	35540	delivery	5	34
91372	2020-07-06 10:11:30	2020-07-06	9	[{"id_menu":7,"count":2}]	35507	delivery	5	14
91373	2020-07-06 10:12:19	2020-07-06	14	[{"id_menu":2,"count":2}]	28191	delivery	5	19
91374	2020-07-06 10:21:08	2020-07-06	17	[{"id_menu":4,"count":1}]	6251	delivery	5	22
91375	2020-07-06 10:22:00	2020-07-06	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35407	delivery	5	43
91376	2020-07-06 10:22:28	2020-07-06	17	[{"id_menu":4,"count":1}]	9779	delivery	5	22
91377	2020-07-06 10:22:45	2020-07-06	12	[{"id_menu":1,"count":1}]	35534	delivery	5	17
91378	2020-07-06 10:24:22	2020-07-06	9	[{"id_menu":7,"count":2}]	22113	delivery	5	14
91379	2020-07-06 10:25:02	2020-07-06	9	[{"id_menu":7,"count":1}]	35517	delivery	5	14
91380	2020-07-06 10:29:05	2020-07-06	12	[{"id_menu":3,"count":1}]	874	pick-up	0	12
91381	2020-07-06 10:33:01	2020-07-06	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	35491	delivery	5	22
91382	2020-07-06 10:33:50	2020-07-06	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	25151	delivery	5	22
91383	2020-07-06 10:38:22	2020-07-06	9	[{"id_menu":6,"count":1}]	11477	delivery	5	14
91384	2020-07-06 10:39:18	2020-07-06	8	[{"id_menu":5,"count":1}]	8656	pick-up	0	8
91385	2020-07-06 10:48:19	2020-07-06	8	[{"id_menu":5,"count":1}]	19511	delivery	5	13
91386	2020-07-06 10:52:19	2020-07-06	17	[{"id_menu":4,"count":1}]	35485	delivery	5	22
91387	2020-07-06 10:52:31	2020-07-06	12	[{"id_menu":1,"count":1}]	33293	delivery	5	17
91388	2020-07-06 10:56:05	2020-07-06	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	35522	delivery	5	31
91389	2020-07-06 10:59:23	2020-07-06	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20819	delivery	5	23
91390	2020-07-06 11:01:02	2020-07-06	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	35553	delivery	5	34
91391	2020-07-06 11:14:16	2020-07-06	9	[{"id_menu":6,"count":1}]	3155	pick-up	0	9
91392	2020-07-06 11:14:38	2020-07-06	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	35425	delivery	5	39
91393	2020-07-06 11:15:48	2020-07-06	14	[{"id_menu":2,"count":1}]	2536	pick-up	0	14
91394	2020-07-06 11:20:12	2020-07-06	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	18283	delivery	5	43
91395	2020-07-06 11:20:13	2020-07-06	17	[{"id_menu":4,"count":1}]	8748	pick-up	0	17
91396	2020-07-06 11:24:57	2020-07-06	8	[{"id_menu":5,"count":1}]	12541	delivery	5	13
91397	2020-07-06 11:30:56	2020-07-06	9	[{"id_menu":6,"count":1}]	35151	pick-up	0	9
91398	2020-07-06 11:34:42	2020-07-06	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	31857	delivery	5	43
91399	2020-07-06 11:41:37	2020-07-06	14	[{"id_menu":2,"count":1}]	4643	delivery	5	19
91400	2020-07-06 11:44:03	2020-07-06	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	34208	pick-up	0	20
91401	2020-07-06 11:45:23	2020-07-06	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	20494	delivery	5	22
91402	2020-07-06 11:51:19	2020-07-06	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	35474	delivery	5	43
91403	2020-07-06 11:52:36	2020-07-06	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	31763	delivery	5	40
91404	2020-07-06 11:55:20	2020-07-06	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15159	delivery	5	51
91405	2020-07-06 11:55:30	2020-07-06	9	[{"id_menu":7,"count":1}]	34170	delivery	5	14
91406	2020-07-06 11:56:30	2020-07-06	9	[{"id_menu":6,"count":1}]	16496	pick-up	0	9
91407	2020-07-06 12:00:35	2020-07-06	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14016	delivery	5	40
91408	2020-07-06 12:03:40	2020-07-06	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12240	pick-up	0	40
91409	2020-07-06 12:10:35	2020-07-06	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35543	delivery	5	37
91410	2020-07-06 12:11:00	2020-07-06	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	35555	delivery	5	25
91411	2020-07-06 12:13:18	2020-07-06	8	[{"id_menu":5,"count":1}]	35471	pick-up	0	8
91412	2020-07-06 12:14:17	2020-07-06	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17579	delivery	5	22
91413	2020-07-06 12:18:48	2020-07-06	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	19971	delivery	5	34
91414	2020-07-06 12:21:36	2020-07-06	8	[{"id_menu":5,"count":1}]	35487	delivery	5	13
91415	2020-07-06 12:22:56	2020-07-06	8	[{"id_menu":5,"count":1}]	30712	delivery	5	13
91416	2020-07-06 12:25:04	2020-07-06	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	3148	pick-up	0	23
91417	2020-07-06 12:25:27	2020-07-06	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	22973	delivery	5	22
91418	2020-07-06 12:35:50	2020-07-06	9	[{"id_menu":7,"count":1}]	33015	delivery	5	14
91419	2020-07-06 12:37:08	2020-07-06	12	[{"id_menu":3,"count":1}]	1924	delivery	5	17
91420	2020-07-06 12:51:11	2020-07-06	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	7770	delivery	5	34
91421	2020-07-06 12:59:37	2020-07-06	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8914	delivery	5	22
91422	2020-07-06 13:10:08	2020-07-06	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	23665	delivery	5	36
91423	2020-07-06 13:10:56	2020-07-06	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	13185	delivery	5	27
91424	2020-07-06 13:15:26	2020-07-06	17	[{"id_menu":5,"count":3},{"id_menu":6,"count":1}]	528	delivery	5	22
91425	2020-07-06 13:16:10	2020-07-06	9	[{"id_menu":7,"count":1}]	16914	delivery	5	14
91426	2020-07-06 13:18:37	2020-07-06	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	35497	delivery	5	34
91427	2020-07-06 13:19:34	2020-07-06	8	[{"id_menu":5,"count":1}]	35011	delivery	5	13
91428	2020-07-06 13:24:49	2020-07-06	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	17545	delivery	5	26
91429	2020-07-06 13:28:09	2020-07-06	8	[{"id_menu":5,"count":1}]	35470	delivery	5	13
91430	2020-07-06 13:28:26	2020-07-06	14	[{"id_menu":2,"count":1}]	21178	delivery	5	19
91431	2020-07-06 13:28:41	2020-07-06	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7125	delivery	5	23
91432	2020-07-06 13:34:48	2020-07-06	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16322	delivery	5	22
91433	2020-07-06 13:43:28	2020-07-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	20521	delivery	5	28
91434	2020-07-06 13:46:28	2020-07-06	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	13656	delivery	5	31
91435	2020-07-06 13:53:46	2020-07-06	9	[{"id_menu":6,"count":1}]	21448	pick-up	0	9
91436	2020-07-06 13:55:53	2020-07-06	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	35499	delivery	5	26
91437	2020-07-06 13:57:04	2020-07-06	8	[{"id_menu":5,"count":1}]	35412	delivery	5	13
91438	2020-07-06 14:03:31	2020-07-06	8	[{"id_menu":5,"count":1}]	29604	delivery	5	13
91439	2020-07-06 14:08:51	2020-07-06	9	[{"id_menu":6,"count":1}]	35408	delivery	5	14
91440	2020-07-06 14:23:59	2020-07-06	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	35410	delivery	5	26
91441	2020-07-06 14:24:39	2020-07-06	17	[{"id_menu":4,"count":1}]	372	delivery	5	22
91442	2020-07-06 14:25:18	2020-07-06	9	[{"id_menu":7,"count":1}]	28712	pick-up	0	9
91443	2020-07-06 14:30:03	2020-07-06	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1062	delivery	5	31
91444	2020-07-06 14:33:38	2020-07-06	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	35554	delivery	5	31
91445	2020-07-06 14:33:53	2020-07-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	35533	delivery	5	28
91446	2020-07-06 14:42:46	2020-07-06	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	34425	delivery	5	26
91447	2020-07-06 14:48:16	2020-07-06	14	[{"id_menu":2,"count":1}]	28907	delivery	5	19
91448	2020-07-06 14:55:49	2020-07-06	12	[{"id_menu":3,"count":1}]	30105	pick-up	0	12
91449	2020-07-06 14:55:50	2020-07-06	9	[{"id_menu":7,"count":1}]	35482	delivery	5	14
91450	2020-07-06 14:56:05	2020-07-06	14	[{"id_menu":2,"count":1}]	35535	pick-up	0	14
91451	2020-07-06 14:56:58	2020-07-06	14	[{"id_menu":2,"count":1}]	32899	delivery	5	19
91452	2020-07-06 15:05:59	2020-07-06	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":3}]	35521	delivery	5	26
91453	2020-07-06 15:06:47	2020-07-06	14	[{"id_menu":2,"count":1}]	28391	delivery	5	19
91454	2020-07-06 15:11:01	2020-07-06	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	8054	pick-up	0	29
91455	2020-07-06 15:19:56	2020-07-06	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	15866	pick-up	0	29
91456	2020-07-06 15:20:56	2020-07-06	12	[{"id_menu":1,"count":1}]	31061	delivery	5	17
91457	2020-07-06 15:42:32	2020-07-06	9	[{"id_menu":6,"count":1}]	7436	delivery	5	14
91458	2020-07-06 15:52:09	2020-07-06	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	3446	delivery	5	26
91459	2020-07-06 15:53:48	2020-07-06	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	35464	delivery	5	31
91460	2020-07-06 15:56:32	2020-07-06	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	20000	delivery	5	39
91461	2020-07-06 15:59:20	2020-07-06	9	[{"id_menu":6,"count":1}]	4530	delivery	5	14
91462	2020-07-06 15:59:28	2020-07-06	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	7444	delivery	5	39
91463	2020-07-06 16:11:27	2020-07-06	12	[{"id_menu":1,"count":1}]	27686	delivery	5	17
91464	2020-07-06 16:11:42	2020-07-06	12	[{"id_menu":1,"count":1}]	5963	delivery	5	17
91465	2020-07-06 16:12:22	2020-07-06	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	33789	delivery	5	43
91466	2020-07-06 16:14:36	2020-07-06	12	[{"id_menu":1,"count":1}]	35416	delivery	5	17
91467	2020-07-06 16:14:38	2020-07-06	8	[{"id_menu":5,"count":2}]	2430	delivery	5	13
91468	2020-07-06 16:17:19	2020-07-06	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6807	pick-up	0	40
91469	2020-07-06 16:19:29	2020-07-06	14	[{"id_menu":2,"count":1}]	35531	pick-up	0	14
91470	2020-07-06 16:32:28	2020-07-06	8	[{"id_menu":5,"count":2}]	24870	pick-up	0	8
91471	2020-07-06 16:40:18	2020-07-06	14	[{"id_menu":2,"count":2}]	35500	delivery	5	19
91472	2020-07-06 16:45:53	2020-07-06	12	[{"id_menu":1,"count":1}]	7843	delivery	5	17
91473	2020-07-06 16:46:46	2020-07-06	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	35406	delivery	5	34
91474	2020-07-06 16:51:43	2020-07-06	8	[{"id_menu":5,"count":2}]	35411	delivery	5	13
91475	2020-07-06 17:02:54	2020-07-06	14	[{"id_menu":2,"count":1}]	15961	pick-up	0	14
91476	2020-07-06 17:04:24	2020-07-06	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	3147	delivery	5	31
91477	2020-07-06 17:21:36	2020-07-06	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	7096	delivery	5	29
91478	2020-07-06 17:22:15	2020-07-06	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35456	pick-up	0	18
91479	2020-07-06 17:29:22	2020-07-06	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14585	pick-up	0	26
91480	2020-07-06 17:29:32	2020-07-06	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	4015	delivery	5	43
91481	2020-07-06 17:31:33	2020-07-06	14	[{"id_menu":2,"count":1}]	17641	delivery	5	19
91482	2020-07-06 17:31:54	2020-07-06	9	[{"id_menu":7,"count":1}]	23350	pick-up	0	9
91483	2020-07-06 17:42:40	2020-07-06	14	[{"id_menu":2,"count":1}]	8224	pick-up	0	14
91484	2020-07-06 17:48:18	2020-07-06	9	[{"id_menu":7,"count":1}]	35473	delivery	5	14
91485	2020-07-06 17:50:36	2020-07-06	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	31614	delivery	5	28
91486	2020-07-06 17:53:10	2020-07-06	17	[{"id_menu":4,"count":2}]	35539	delivery	5	22
91487	2020-07-06 17:53:47	2020-07-06	8	[{"id_menu":5,"count":1}]	15926	delivery	5	13
91488	2020-07-06 17:54:52	2020-07-06	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	28023	delivery	5	30
91489	2020-07-06 17:57:27	2020-07-06	14	[{"id_menu":2,"count":1}]	18602	delivery	5	19
91490	2020-07-06 17:57:35	2020-07-06	14	[{"id_menu":2,"count":1}]	14419	delivery	5	19
91491	2020-07-06 18:04:49	2020-07-06	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	35359	delivery	5	22
91492	2020-07-06 18:07:15	2020-07-06	12	[{"id_menu":3,"count":1}]	30253	delivery	5	17
91493	2020-07-06 18:09:21	2020-07-06	12	[{"id_menu":1,"count":1}]	5064	pick-up	0	12
91494	2020-07-06 18:12:13	2020-07-06	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	14155	delivery	5	31
91495	2020-07-06 18:14:45	2020-07-06	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6619	delivery	5	35
91496	2020-07-06 18:15:38	2020-07-06	17	[{"id_menu":4,"count":1}]	13905	delivery	5	22
91497	2020-07-06 18:19:29	2020-07-06	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	12298	delivery	5	23
91498	2020-07-06 18:26:53	2020-07-06	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15199	delivery	5	31
91499	2020-07-06 18:27:09	2020-07-06	9	[{"id_menu":7,"count":1}]	799	delivery	5	14
91500	2020-07-06 18:33:56	2020-07-06	12	[{"id_menu":1,"count":1}]	35478	pick-up	0	12
91501	2020-07-06 18:36:19	2020-07-06	9	[{"id_menu":7,"count":1}]	15788	delivery	5	14
91502	2020-07-06 18:37:11	2020-07-06	9	[{"id_menu":7,"count":1}]	30533	delivery	5	14
91503	2020-07-06 18:38:55	2020-07-06	9	[{"id_menu":6,"count":1}]	34060	delivery	5	14
91504	2020-07-06 18:39:20	2020-07-06	14	[{"id_menu":2,"count":1}]	2504	pick-up	0	14
91505	2020-07-06 18:41:12	2020-07-06	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1282	pick-up	0	40
91506	2020-07-06 18:41:26	2020-07-06	9	[{"id_menu":7,"count":1}]	32316	delivery	5	14
91507	2020-07-06 18:43:40	2020-07-06	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	22917	delivery	5	25
91508	2020-07-06 18:46:57	2020-07-06	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12302	delivery	5	53
91509	2020-07-06 18:47:19	2020-07-06	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	35444	delivery	5	29
91510	2020-07-06 18:47:43	2020-07-06	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	35569	delivery	5	30
91511	2020-07-06 18:51:30	2020-07-06	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	30877	delivery	5	26
91512	2020-07-06 18:53:15	2020-07-06	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	14862	delivery	5	36
91513	2020-07-06 18:55:43	2020-07-06	9	[{"id_menu":7,"count":1}]	19911	delivery	5	14
91514	2020-07-06 18:56:16	2020-07-06	9	[{"id_menu":7,"count":3}]	11760	delivery	5	14
91515	2020-07-06 18:56:52	2020-07-06	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2071	delivery	5	45
91516	2020-07-06 18:58:55	2020-07-06	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	15336	delivery	5	25
91517	2020-07-06 19:01:04	2020-07-06	38	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4635	pick-up	0	38
91518	2020-07-06 19:03:54	2020-07-06	8	[{"id_menu":5,"count":1}]	2123	pick-up	0	8
91519	2020-07-06 19:04:06	2020-07-06	9	[{"id_menu":7,"count":1}]	32546	delivery	5	14
91520	2020-07-06 19:06:47	2020-07-06	17	[{"id_menu":4,"count":1}]	32058	delivery	5	22
91521	2020-07-06 19:09:30	2020-07-06	9	[{"id_menu":6,"count":1}]	3832	delivery	5	14
91522	2020-07-06 19:13:00	2020-07-06	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	22443	delivery	5	26
91523	2020-07-06 19:15:05	2020-07-06	8	[{"id_menu":5,"count":1}]	13978	delivery	5	13
91524	2020-07-06 19:15:28	2020-07-06	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":3}]	16552	delivery	5	22
91525	2020-07-06 19:16:56	2020-07-06	17	[{"id_menu":4,"count":1}]	3355	pick-up	0	17
91526	2020-07-06 19:26:08	2020-07-06	14	[{"id_menu":2,"count":1}]	32152	delivery	5	19
91527	2020-07-06 19:30:51	2020-07-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	35563	delivery	5	28
91528	2020-07-06 19:32:43	2020-07-06	8	[{"id_menu":5,"count":1}]	35508	delivery	5	13
91529	2020-07-06 19:35:12	2020-07-06	9	[{"id_menu":6,"count":1}]	17995	pick-up	0	9
91530	2020-07-06 19:39:07	2020-07-06	9	[{"id_menu":6,"count":1}]	29853	delivery	5	14
91531	2020-07-06 19:41:09	2020-07-06	14	[{"id_menu":2,"count":1}]	3262	delivery	5	19
91532	2020-07-06 19:41:22	2020-07-06	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	5743	delivery	5	31
91533	2020-07-06 19:47:00	2020-07-06	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35523	delivery	5	37
91534	2020-07-06 19:51:59	2020-07-06	14	[{"id_menu":2,"count":1}]	3636	delivery	5	19
91535	2020-07-06 19:59:23	2020-07-06	9	[{"id_menu":6,"count":1}]	35483	delivery	5	14
91536	2020-07-06 20:07:07	2020-07-06	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7181	delivery	5	36
91537	2020-07-06 20:08:00	2020-07-06	12	[{"id_menu":3,"count":1}]	6909	delivery	5	17
91538	2020-07-06 20:13:33	2020-07-06	9	[{"id_menu":7,"count":1}]	35547	delivery	5	14
91539	2020-07-06 20:23:04	2020-07-06	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	35424	delivery	5	26
91540	2020-07-06 20:23:41	2020-07-06	12	[{"id_menu":3,"count":1}]	35430	delivery	5	17
91541	2020-07-06 20:29:33	2020-07-06	12	[{"id_menu":3,"count":1}]	35566	pick-up	0	12
91542	2020-07-06 20:33:14	2020-07-06	9	[{"id_menu":6,"count":1}]	1244	pick-up	0	9
91543	2020-07-06 20:37:01	2020-07-06	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	34270	delivery	5	25
91544	2020-07-06 20:38:51	2020-07-06	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7291	delivery	5	23
91545	2020-07-06 20:55:09	2020-07-06	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27306	delivery	5	31
91546	2020-07-06 20:55:37	2020-07-06	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	34002	delivery	5	45
91547	2020-07-06 20:56:09	2020-07-06	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13968	delivery	5	35
91548	2020-07-06 21:10:30	2020-07-06	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1316	pick-up	0	21
91549	2020-07-06 21:10:49	2020-07-06	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1227	pick-up	0	21
91550	2020-07-06 21:15:04	2020-07-06	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	35460	delivery	5	45
91551	2020-07-06 21:15:57	2020-07-06	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	17413	delivery	5	36
91552	2020-07-06 21:19:23	2020-07-06	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	35520	delivery	5	46
91553	2020-07-06 21:22:26	2020-07-06	14	[{"id_menu":2,"count":1}]	33827	pick-up	0	14
91554	2020-07-06 21:26:43	2020-07-06	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	35526	delivery	5	31
91555	2020-07-06 21:30:27	2020-07-06	9	[{"id_menu":7,"count":1}]	12159	delivery	5	14
91556	2020-07-06 21:30:49	2020-07-06	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7451	delivery	5	28
91557	2020-07-06 21:31:59	2020-07-06	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3175	pick-up	0	21
91558	2020-07-06 21:39:07	2020-07-06	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4653	delivery	5	26
91559	2020-07-06 21:40:01	2020-07-06	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	26874	delivery	5	23
91560	2020-07-06 21:48:29	2020-07-06	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11163	delivery	5	37
91561	2020-07-06 21:54:59	2020-07-06	17	[{"id_menu":5,"count":3},{"id_menu":7,"count":1}]	35132	delivery	5	22
91562	2020-07-06 21:58:06	2020-07-06	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	35422	delivery	5	27
91563	2020-07-06 22:00:37	2020-07-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	29742	pick-up	0	23
91564	2020-07-06 22:24:28	2020-07-06	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	35546	delivery	5	34
91565	2020-07-06 22:24:58	2020-07-06	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	19537	pick-up	0	31
91566	2020-07-06 22:28:02	2020-07-06	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	17359	delivery	5	27
91567	2020-07-06 22:29:49	2020-07-06	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35488	delivery	5	37
91568	2020-07-06 22:31:34	2020-07-06	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	12524	delivery	5	30
91569	2020-07-06 22:32:45	2020-07-06	12	[{"id_menu":1,"count":1}]	14617	delivery	5	17
91570	2020-07-06 22:33:07	2020-07-06	8	[{"id_menu":5,"count":1}]	1527	pick-up	0	8
91571	2020-07-06 22:33:25	2020-07-06	12	[{"id_menu":1,"count":1}]	12367	pick-up	0	12
91572	2020-07-06 22:35:41	2020-07-06	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	996	delivery	5	43
91573	2020-07-06 22:36:39	2020-07-06	17	[{"id_menu":4,"count":2}]	11983	delivery	5	22
91574	2020-07-06 22:39:20	2020-07-06	9	[{"id_menu":6,"count":1}]	35509	delivery	5	14
91575	2020-07-06 22:41:31	2020-07-06	9	[{"id_menu":7,"count":2}]	24429	delivery	5	14
91576	2020-07-06 22:42:13	2020-07-06	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	25475	delivery	5	40
91577	2020-07-06 22:46:14	2020-07-06	14	[{"id_menu":2,"count":1}]	17805	pick-up	0	14
91578	2020-07-06 22:49:49	2020-07-06	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	21386	pick-up	0	29
91579	2020-07-06 22:50:36	2020-07-06	9	[{"id_menu":6,"count":1}]	21617	pick-up	0	9
91580	2020-07-06 22:51:53	2020-07-06	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	980	pick-up	0	26
91581	2020-07-06 22:57:50	2020-07-06	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2812	delivery	5	44
91582	2020-07-06 23:02:26	2020-07-06	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	10787	delivery	5	40
91583	2020-07-06 23:06:44	2020-07-06	9	[{"id_menu":7,"count":1}]	24548	delivery	5	14
91584	2020-07-06 23:10:28	2020-07-06	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	35440	delivery	5	38
91585	2020-07-06 23:16:07	2020-07-06	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	35426	pick-up	0	20
91586	2020-07-06 23:17:28	2020-07-06	12	[{"id_menu":1,"count":1}]	35452	delivery	5	17
91587	2020-07-06 23:25:32	2020-07-06	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	11225	pick-up	0	21
91588	2020-07-06 23:27:36	2020-07-06	9	[{"id_menu":7,"count":2}]	10740	delivery	5	14
91589	2020-07-06 23:30:16	2020-07-06	14	[{"id_menu":2,"count":1}]	1890	pick-up	0	14
91590	2020-07-06 23:32:05	2020-07-06	9	[{"id_menu":7,"count":1}]	9560	delivery	5	14
91591	2020-07-06 23:35:45	2020-07-06	17	[{"id_menu":4,"count":1}]	35524	pick-up	0	17
91592	2020-07-06 23:35:49	2020-07-06	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	33625	delivery	5	45
91593	2020-07-06 23:36:13	2020-07-06	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5144	delivery	5	57
91594	2020-07-06 23:36:14	2020-07-06	14	[{"id_menu":2,"count":1}]	33698	delivery	5	19
91595	2020-07-06 23:48:13	2020-07-06	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	9754	delivery	5	23
91596	2020-07-06 23:50:54	2020-07-06	9	[{"id_menu":7,"count":1}]	32120	delivery	5	14
91597	2020-07-06 23:50:55	2020-07-06	9	[{"id_menu":6,"count":1}]	5430	pick-up	0	9
91598	2020-07-06 23:52:31	2020-07-06	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	35445	pick-up	0	26
91599	2020-07-07 00:00:44	2020-07-07	12	[{"id_menu":3,"count":1}]	26412	delivery	5	17
91600	2020-07-07 00:01:52	2020-07-07	9	[{"id_menu":7,"count":1}]	1293	delivery	5	14
91601	2020-07-07 00:11:01	2020-07-07	9	[{"id_menu":7,"count":2}]	35688	delivery	5	14
91602	2020-07-07 00:24:11	2020-07-07	14	[{"id_menu":2,"count":1}]	35608	delivery	5	19
91603	2020-07-07 00:28:18	2020-07-07	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	35618	delivery	5	22
91604	2020-07-07 00:38:41	2020-07-07	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15054	delivery	5	22
91605	2020-07-07 00:40:35	2020-07-07	9	[{"id_menu":7,"count":1}]	10601	delivery	5	14
91606	2020-07-07 00:47:38	2020-07-07	17	[{"id_menu":4,"count":1}]	7241	delivery	5	22
91607	2020-07-07 00:48:20	2020-07-07	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	6470	pick-up	0	20
91608	2020-07-07 00:49:38	2020-07-07	9	[{"id_menu":6,"count":1}]	14088	delivery	5	14
91609	2020-07-07 00:50:47	2020-07-07	14	[{"id_menu":2,"count":1}]	35712	delivery	5	19
91610	2020-07-07 00:50:53	2020-07-07	9	[{"id_menu":7,"count":1}]	35705	delivery	5	14
91611	2020-07-07 00:51:03	2020-07-07	9	[{"id_menu":7,"count":1}]	19769	delivery	5	14
91612	2020-07-07 00:54:00	2020-07-07	9	[{"id_menu":6,"count":1}]	13798	delivery	5	14
91613	2020-07-07 00:55:45	2020-07-07	14	[{"id_menu":2,"count":1}]	2798	pick-up	0	14
91614	2020-07-07 00:56:37	2020-07-07	14	[{"id_menu":2,"count":1}]	677	pick-up	0	14
91615	2020-07-07 00:58:29	2020-07-07	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1183	delivery	5	25
91616	2020-07-07 00:58:33	2020-07-07	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	10810	delivery	5	25
91617	2020-07-07 01:00:41	2020-07-07	12	[{"id_menu":3,"count":1}]	4062	pick-up	0	12
91618	2020-07-07 01:14:38	2020-07-07	9	[{"id_menu":6,"count":1}]	13822	pick-up	0	9
91619	2020-07-07 01:19:02	2020-07-07	9	[{"id_menu":6,"count":1}]	35684	delivery	5	14
91620	2020-07-07 01:21:20	2020-07-07	9	[{"id_menu":6,"count":1}]	35772	delivery	5	14
91621	2020-07-07 01:21:57	2020-07-07	9	[{"id_menu":7,"count":1}]	18539	delivery	5	14
91622	2020-07-07 01:23:24	2020-07-07	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	2217	delivery	5	29
91623	2020-07-07 01:24:35	2020-07-07	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":3}]	18360	delivery	5	36
91624	2020-07-07 01:25:22	2020-07-07	12	[{"id_menu":1,"count":1}]	177	delivery	5	17
91625	2020-07-07 01:32:03	2020-07-07	8	[{"id_menu":5,"count":1}]	35797	delivery	5	13
91626	2020-07-07 01:32:27	2020-07-07	17	[{"id_menu":4,"count":1}]	2630	pick-up	0	17
91627	2020-07-07 01:47:28	2020-07-07	17	[{"id_menu":4,"count":1}]	35628	delivery	5	22
91628	2020-07-07 01:52:59	2020-07-07	8	[{"id_menu":5,"count":1}]	31605	delivery	5	13
91629	2020-07-07 01:53:04	2020-07-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	7066	delivery	5	23
91630	2020-07-07 01:53:29	2020-07-07	9	[{"id_menu":7,"count":1}]	9733	delivery	5	14
91631	2020-07-07 01:54:38	2020-07-07	12	[{"id_menu":1,"count":1}]	33092	delivery	5	17
91632	2020-07-07 01:54:59	2020-07-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	17041	delivery	5	28
91633	2020-07-07 01:59:20	2020-07-07	8	[{"id_menu":5,"count":1}]	15980	delivery	5	13
91634	2020-07-07 02:10:09	2020-07-07	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16571	pick-up	0	26
91635	2020-07-07 02:12:01	2020-07-07	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32620	delivery	5	34
91636	2020-07-07 02:12:52	2020-07-07	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	13799	delivery	5	29
91637	2020-07-07 02:21:36	2020-07-07	12	[{"id_menu":1,"count":1}]	10008	delivery	5	17
91638	2020-07-07 02:22:47	2020-07-07	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11624	delivery	5	53
91639	2020-07-07 02:25:28	2020-07-07	9	[{"id_menu":6,"count":1}]	35746	delivery	5	14
91640	2020-07-07 02:34:54	2020-07-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30872	delivery	5	23
91641	2020-07-07 02:35:09	2020-07-07	9	[{"id_menu":6,"count":2}]	837	pick-up	0	9
91642	2020-07-07 02:35:50	2020-07-07	14	[{"id_menu":2,"count":1}]	11534	pick-up	0	14
91643	2020-07-07 02:36:00	2020-07-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	35673	delivery	5	22
91644	2020-07-07 02:41:03	2020-07-07	8	[{"id_menu":5,"count":1}]	35648	delivery	5	13
91645	2020-07-07 02:45:07	2020-07-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	35763	pick-up	0	23
91646	2020-07-07 02:47:52	2020-07-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	22168	delivery	5	28
91647	2020-07-07 02:49:51	2020-07-07	17	[{"id_menu":4,"count":1}]	32178	pick-up	0	17
91648	2020-07-07 02:54:25	2020-07-07	9	[{"id_menu":7,"count":1}]	1939	delivery	5	14
91649	2020-07-07 02:55:55	2020-07-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	35796	delivery	5	28
91650	2020-07-07 03:02:03	2020-07-07	12	[{"id_menu":3,"count":1}]	35287	pick-up	0	12
91651	2020-07-07 03:05:27	2020-07-07	12	[{"id_menu":1,"count":1}]	11146	delivery	5	17
91652	2020-07-07 03:05:36	2020-07-07	17	[{"id_menu":4,"count":1}]	8862	delivery	5	22
91653	2020-07-07 03:06:01	2020-07-07	17	[{"id_menu":4,"count":1}]	92	delivery	5	22
91654	2020-07-07 03:06:34	2020-07-07	8	[{"id_menu":5,"count":1}]	213	pick-up	0	8
91655	2020-07-07 03:22:13	2020-07-07	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	35578	delivery	5	31
91656	2020-07-07 03:23:25	2020-07-07	14	[{"id_menu":2,"count":1}]	245	pick-up	0	14
91657	2020-07-07 03:23:27	2020-07-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	26923	delivery	5	28
91658	2020-07-07 03:23:35	2020-07-07	17	[{"id_menu":4,"count":1}]	1505	pick-up	0	17
91659	2020-07-07 03:26:54	2020-07-07	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	35701	delivery	5	31
91660	2020-07-07 03:30:55	2020-07-07	9	[{"id_menu":7,"count":1}]	35686	pick-up	0	9
91661	2020-07-07 03:41:12	2020-07-07	9	[{"id_menu":6,"count":1}]	35771	delivery	5	14
91662	2020-07-07 03:41:30	2020-07-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33473	delivery	5	23
91663	2020-07-07 03:48:39	2020-07-07	9	[{"id_menu":7,"count":1}]	11387	delivery	5	14
91664	2020-07-07 03:50:40	2020-07-07	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	35597	delivery	5	55
91665	2020-07-07 03:51:05	2020-07-07	12	[{"id_menu":3,"count":1}]	12407	pick-up	0	12
91666	2020-07-07 03:51:36	2020-07-07	17	[{"id_menu":4,"count":1}]	35638	delivery	5	22
91667	2020-07-07 03:57:56	2020-07-07	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	11979	delivery	5	22
91668	2020-07-07 03:58:21	2020-07-07	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7796	delivery	5	43
91669	2020-07-07 04:04:31	2020-07-07	8	[{"id_menu":5,"count":1}]	1280	pick-up	0	8
91670	2020-07-07 04:04:48	2020-07-07	9	[{"id_menu":7,"count":2}]	18190	delivery	5	14
91671	2020-07-07 04:07:43	2020-07-07	9	[{"id_menu":6,"count":1}]	1282	pick-up	0	9
91672	2020-07-07 04:10:45	2020-07-07	8	[{"id_menu":5,"count":1}]	5693	delivery	5	13
91673	2020-07-07 04:14:21	2020-07-07	17	[{"id_menu":4,"count":1}]	35617	delivery	5	22
91674	2020-07-07 04:17:04	2020-07-07	9	[{"id_menu":6,"count":1}]	35735	pick-up	0	9
91675	2020-07-07 04:17:18	2020-07-07	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	21757	delivery	5	31
91676	2020-07-07 04:17:33	2020-07-07	33	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	22320	pick-up	0	33
91677	2020-07-07 04:18:59	2020-07-07	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	35609	delivery	5	42
91678	2020-07-07 04:19:42	2020-07-07	8	[{"id_menu":5,"count":1}]	17036	pick-up	0	8
91679	2020-07-07 04:21:48	2020-07-07	9	[{"id_menu":7,"count":2}]	14845	pick-up	0	9
91680	2020-07-07 04:23:44	2020-07-07	14	[{"id_menu":2,"count":1}]	24221	delivery	5	19
91681	2020-07-07 04:25:26	2020-07-07	9	[{"id_menu":7,"count":1}]	27332	delivery	5	14
91682	2020-07-07 04:28:51	2020-07-07	9	[{"id_menu":6,"count":1}]	19368	delivery	5	14
91683	2020-07-07 04:31:12	2020-07-07	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1393	delivery	5	39
91684	2020-07-07 04:34:58	2020-07-07	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":2}]	35716	delivery	5	28
91685	2020-07-07 04:37:13	2020-07-07	8	[{"id_menu":5,"count":1}]	26083	delivery	5	13
91686	2020-07-07 04:39:28	2020-07-07	9	[{"id_menu":6,"count":1}]	18844	delivery	5	14
91687	2020-07-07 04:44:02	2020-07-07	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28288	delivery	5	35
91688	2020-07-07 04:50:09	2020-07-07	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	26456	delivery	5	34
91689	2020-07-07 04:50:47	2020-07-07	14	[{"id_menu":2,"count":1}]	29188	delivery	5	19
91690	2020-07-07 04:56:43	2020-07-07	12	[{"id_menu":1,"count":1}]	26740	delivery	5	17
91691	2020-07-07 04:59:47	2020-07-07	9	[{"id_menu":6,"count":1}]	5427	pick-up	0	9
91692	2020-07-07 05:02:37	2020-07-07	9	[{"id_menu":6,"count":3}]	34925	delivery	5	14
91693	2020-07-07 05:07:15	2020-07-07	14	[{"id_menu":2,"count":1}]	35656	delivery	5	19
91694	2020-07-07 05:15:18	2020-07-07	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	16264	pick-up	0	26
91695	2020-07-07 05:15:51	2020-07-07	12	[{"id_menu":3,"count":1}]	35674	pick-up	0	12
91696	2020-07-07 05:27:23	2020-07-07	9	[{"id_menu":7,"count":1}]	35765	delivery	5	14
91697	2020-07-07 05:31:39	2020-07-07	17	[{"id_menu":4,"count":1}]	5470	delivery	5	22
91698	2020-07-07 05:35:35	2020-07-07	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35726	delivery	5	49
91699	2020-07-07 05:42:32	2020-07-07	12	[{"id_menu":1,"count":1}]	6593	delivery	5	17
91700	2020-07-07 05:45:39	2020-07-07	12	[{"id_menu":1,"count":1}]	10828	pick-up	0	12
91701	2020-07-07 05:50:18	2020-07-07	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	35662	delivery	5	30
91702	2020-07-07 05:53:57	2020-07-07	20	[{"id_menu":1,"count":3},{"id_menu":5,"count":1}]	34491	delivery	5	25
91703	2020-07-07 06:03:52	2020-07-07	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	35774	delivery	5	31
91704	2020-07-07 06:08:32	2020-07-07	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	33585	delivery	5	26
91705	2020-07-07 06:12:37	2020-07-07	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	25386	delivery	5	25
91706	2020-07-07 06:15:37	2020-07-07	17	[{"id_menu":4,"count":1}]	35775	delivery	5	22
91707	2020-07-07 06:23:10	2020-07-07	9	[{"id_menu":6,"count":2}]	14956	delivery	5	14
91708	2020-07-07 06:24:20	2020-07-07	8	[{"id_menu":5,"count":1}]	15962	delivery	5	13
91709	2020-07-07 06:25:21	2020-07-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20379	pick-up	0	17
91710	2020-07-07 06:31:19	2020-07-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	28030	pick-up	0	23
91711	2020-07-07 06:32:35	2020-07-07	9	[{"id_menu":6,"count":1}]	35793	delivery	5	14
91712	2020-07-07 06:33:53	2020-07-07	17	[{"id_menu":4,"count":1}]	35703	delivery	5	22
91713	2020-07-07 06:34:31	2020-07-07	8	[{"id_menu":5,"count":1}]	35753	delivery	5	13
91714	2020-07-07 06:39:01	2020-07-07	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12942	delivery	5	40
91715	2020-07-07 06:40:58	2020-07-07	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5963	pick-up	0	26
91716	2020-07-07 06:43:41	2020-07-07	12	[{"id_menu":3,"count":1}]	35734	delivery	5	17
91717	2020-07-07 06:45:25	2020-07-07	12	[{"id_menu":1,"count":1}]	35652	delivery	5	17
91718	2020-07-07 06:48:42	2020-07-07	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	35595	delivery	5	37
91719	2020-07-07 06:54:05	2020-07-07	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	18900	delivery	5	29
91720	2020-07-07 06:57:39	2020-07-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23422	delivery	5	22
91721	2020-07-07 07:00:30	2020-07-07	17	[{"id_menu":4,"count":1}]	25997	pick-up	0	17
91722	2020-07-07 07:03:53	2020-07-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27813	delivery	5	23
91723	2020-07-07 07:04:25	2020-07-07	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6748	delivery	5	34
91724	2020-07-07 07:06:22	2020-07-07	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7731	delivery	5	43
91725	2020-07-07 07:06:40	2020-07-07	12	[{"id_menu":1,"count":1}]	28626	delivery	5	17
91726	2020-07-07 07:15:25	2020-07-07	17	[{"id_menu":4,"count":1}]	24675	delivery	5	22
91727	2020-07-07 07:17:57	2020-07-07	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	35680	pick-up	0	35
91728	2020-07-07 07:20:12	2020-07-07	9	[{"id_menu":7,"count":3}]	5344	delivery	5	14
91729	2020-07-07 07:24:59	2020-07-07	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	22032	delivery	5	22
91730	2020-07-07 07:32:34	2020-07-07	9	[{"id_menu":6,"count":2}]	35723	delivery	5	14
91731	2020-07-07 07:33:00	2020-07-07	9	[{"id_menu":6,"count":1}]	30731	delivery	5	14
91732	2020-07-07 07:35:37	2020-07-07	14	[{"id_menu":2,"count":1}]	897	pick-up	0	14
91733	2020-07-07 07:35:38	2020-07-07	14	[{"id_menu":2,"count":1}]	15873	pick-up	0	14
91734	2020-07-07 07:40:19	2020-07-07	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35585	delivery	5	52
91735	2020-07-07 07:44:31	2020-07-07	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	28151	pick-up	0	29
91736	2020-07-07 07:44:55	2020-07-07	9	[{"id_menu":7,"count":1}]	25312	delivery	5	14
91737	2020-07-07 07:45:23	2020-07-07	17	[{"id_menu":4,"count":1}]	26835	delivery	5	22
91738	2020-07-07 07:49:16	2020-07-07	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	35436	delivery	5	31
91739	2020-07-07 07:50:40	2020-07-07	12	[{"id_menu":3,"count":1}]	35795	delivery	5	17
91740	2020-07-07 07:53:11	2020-07-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	18222	pick-up	0	23
91741	2020-07-07 07:59:07	2020-07-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	19166	delivery	5	28
91742	2020-07-07 08:01:34	2020-07-07	9	[{"id_menu":7,"count":1}]	22226	delivery	5	14
91743	2020-07-07 08:01:34	2020-07-07	9	[{"id_menu":6,"count":1}]	35629	delivery	5	14
91744	2020-07-07 08:05:21	2020-07-07	14	[{"id_menu":2,"count":1}]	19741	delivery	5	19
91745	2020-07-07 08:08:25	2020-07-07	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	3010	pick-up	0	24
91746	2020-07-07 08:09:28	2020-07-07	9	[{"id_menu":7,"count":1}]	28709	delivery	5	14
91747	2020-07-07 08:16:57	2020-07-07	9	[{"id_menu":7,"count":1}]	35669	delivery	5	14
91748	2020-07-07 08:18:40	2020-07-07	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3568	delivery	5	45
91749	2020-07-07 08:19:09	2020-07-07	8	[{"id_menu":5,"count":1}]	1125	pick-up	0	8
91750	2020-07-07 08:20:15	2020-07-07	14	[{"id_menu":2,"count":1}]	35634	delivery	5	19
91751	2020-07-07 08:21:47	2020-07-07	14	[{"id_menu":2,"count":1}]	24948	delivery	5	19
91752	2020-07-07 08:24:59	2020-07-07	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	35785	delivery	5	31
91753	2020-07-07 08:27:36	2020-07-07	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":3}]	35654	delivery	5	22
91754	2020-07-07 08:28:27	2020-07-07	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12236	delivery	5	31
91755	2020-07-07 08:28:40	2020-07-07	14	[{"id_menu":2,"count":1}]	2001	pick-up	0	14
91756	2020-07-07 08:29:44	2020-07-07	9	[{"id_menu":7,"count":1}]	23037	delivery	5	14
91757	2020-07-07 08:31:16	2020-07-07	14	[{"id_menu":2,"count":1}]	2264	delivery	5	19
91758	2020-07-07 08:31:45	2020-07-07	9	[{"id_menu":6,"count":1}]	23080	delivery	5	14
91759	2020-07-07 08:32:22	2020-07-07	17	[{"id_menu":4,"count":1}]	25276	delivery	5	22
91760	2020-07-07 08:37:52	2020-07-07	9	[{"id_menu":6,"count":1}]	19229	delivery	5	14
91761	2020-07-07 08:39:40	2020-07-07	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	35711	delivery	5	43
91762	2020-07-07 08:45:49	2020-07-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7623	delivery	5	22
91763	2020-07-07 08:48:14	2020-07-07	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	35612	delivery	5	26
91764	2020-07-07 08:49:21	2020-07-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	31904	delivery	5	28
91765	2020-07-07 08:51:23	2020-07-07	17	[{"id_menu":4,"count":1}]	35696	pick-up	0	17
91766	2020-07-07 08:52:05	2020-07-07	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	35663	delivery	5	43
91767	2020-07-07 08:53:06	2020-07-07	14	[{"id_menu":2,"count":1}]	32813	delivery	5	19
91768	2020-07-07 09:04:21	2020-07-07	9	[{"id_menu":6,"count":2}]	35740	pick-up	0	9
91769	2020-07-07 09:04:50	2020-07-07	12	[{"id_menu":3,"count":1}]	7348	pick-up	0	12
91770	2020-07-07 09:05:46	2020-07-07	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	24616	delivery	5	27
91771	2020-07-07 09:06:04	2020-07-07	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35650	delivery	5	35
91772	2020-07-07 09:07:19	2020-07-07	17	[{"id_menu":4,"count":1}]	35624	delivery	5	22
91773	2020-07-07 09:11:18	2020-07-07	9	[{"id_menu":6,"count":1}]	34450	pick-up	0	9
91774	2020-07-07 09:11:28	2020-07-07	17	[{"id_menu":4,"count":1}]	7062	delivery	5	22
91775	2020-07-07 09:20:49	2020-07-07	12	[{"id_menu":1,"count":1}]	35588	delivery	5	17
91776	2020-07-07 09:21:02	2020-07-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	35791	delivery	5	22
91777	2020-07-07 09:22:25	2020-07-07	12	[{"id_menu":1,"count":1}]	3949	pick-up	0	12
91778	2020-07-07 09:23:43	2020-07-07	8	[{"id_menu":5,"count":1}]	14461	delivery	5	13
91779	2020-07-07 09:29:59	2020-07-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	35593	delivery	5	26
91780	2020-07-07 09:32:12	2020-07-07	14	[{"id_menu":2,"count":1}]	6122	pick-up	0	14
91781	2020-07-07 09:40:11	2020-07-07	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35630	delivery	5	31
91782	2020-07-07 09:43:56	2020-07-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	35697	delivery	5	26
91783	2020-07-07 09:47:21	2020-07-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3054	pick-up	0	18
91784	2020-07-07 09:47:52	2020-07-07	14	[{"id_menu":2,"count":1}]	35627	delivery	5	19
91785	2020-07-07 09:50:29	2020-07-07	17	[{"id_menu":4,"count":1}]	14449	pick-up	0	17
91786	2020-07-07 09:50:55	2020-07-07	14	[{"id_menu":2,"count":1}]	19468	delivery	5	19
91787	2020-07-07 09:51:57	2020-07-07	9	[{"id_menu":6,"count":1}]	26927	delivery	5	14
91788	2020-07-07 09:54:36	2020-07-07	9	[{"id_menu":7,"count":2}]	7277	delivery	5	14
91789	2020-07-07 09:56:15	2020-07-07	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	281	pick-up	0	29
91790	2020-07-07 09:57:56	2020-07-07	12	[{"id_menu":3,"count":1}]	27716	delivery	5	17
91791	2020-07-07 09:58:37	2020-07-07	9	[{"id_menu":6,"count":1}]	30319	delivery	5	14
91792	2020-07-07 09:58:58	2020-07-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	33693	delivery	5	22
91793	2020-07-07 10:00:01	2020-07-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	30417	pick-up	0	21
91794	2020-07-07 10:00:03	2020-07-07	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	5358	delivery	5	34
91795	2020-07-07 10:02:21	2020-07-07	9	[{"id_menu":7,"count":1}]	538	delivery	5	14
91796	2020-07-07 10:17:14	2020-07-07	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	35645	delivery	5	31
91797	2020-07-07 10:17:52	2020-07-07	12	[{"id_menu":1,"count":1}]	3824	delivery	5	17
91798	2020-07-07 10:20:24	2020-07-07	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	35603	delivery	5	30
91799	2020-07-07 10:21:52	2020-07-07	8	[{"id_menu":5,"count":1}]	265	pick-up	0	8
91800	2020-07-07 10:22:54	2020-07-07	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	17471	delivery	5	44
91801	2020-07-07 10:32:45	2020-07-07	12	[{"id_menu":3,"count":1}]	1499	delivery	5	17
91802	2020-07-07 10:37:58	2020-07-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	32323	delivery	5	26
91803	2020-07-07 10:38:56	2020-07-07	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	18745	delivery	5	36
91804	2020-07-07 10:40:00	2020-07-07	9	[{"id_menu":7,"count":1}]	6859	pick-up	0	9
91805	2020-07-07 10:46:43	2020-07-07	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9700	delivery	5	37
91806	2020-07-07 10:51:07	2020-07-07	17	[{"id_menu":5,"count":3},{"id_menu":6,"count":1}]	29345	delivery	5	22
91807	2020-07-07 10:51:36	2020-07-07	9	[{"id_menu":6,"count":1}]	28308	delivery	5	14
91808	2020-07-07 10:57:19	2020-07-07	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	3771	delivery	5	22
91809	2020-07-07 10:57:54	2020-07-07	14	[{"id_menu":2,"count":1}]	35641	delivery	5	19
91810	2020-07-07 10:58:32	2020-07-07	12	[{"id_menu":1,"count":1}]	35574	pick-up	0	12
91811	2020-07-07 11:00:17	2020-07-07	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	24442	delivery	5	34
91812	2020-07-07 11:03:07	2020-07-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	15216	pick-up	0	23
91813	2020-07-07 11:03:50	2020-07-07	12	[{"id_menu":3,"count":1}]	7724	delivery	5	17
91814	2020-07-07 11:04:46	2020-07-07	9	[{"id_menu":6,"count":1}]	16316	delivery	5	14
91815	2020-07-07 11:06:36	2020-07-07	14	[{"id_menu":2,"count":1}]	35607	delivery	5	19
91816	2020-07-07 11:06:49	2020-07-07	12	[{"id_menu":3,"count":1}]	18550	delivery	5	17
91817	2020-07-07 11:12:46	2020-07-07	17	[{"id_menu":4,"count":1}]	23087	pick-up	0	17
91818	2020-07-07 11:13:29	2020-07-07	14	[{"id_menu":2,"count":1}]	5343	delivery	5	19
91819	2020-07-07 11:14:59	2020-07-07	9	[{"id_menu":7,"count":1}]	19350	delivery	5	14
91820	2020-07-07 11:18:04	2020-07-07	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2651	pick-up	0	35
91821	2020-07-07 11:29:16	2020-07-07	9	[{"id_menu":6,"count":1}]	31065	delivery	5	14
91822	2020-07-07 11:32:23	2020-07-07	12	[{"id_menu":1,"count":1}]	24129	delivery	5	17
91823	2020-07-07 11:34:39	2020-07-07	17	[{"id_menu":4,"count":1}]	23298	delivery	5	22
91824	2020-07-07 11:35:19	2020-07-07	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	21272	delivery	5	25
91825	2020-07-07 11:38:58	2020-07-07	8	[{"id_menu":5,"count":1}]	2605	delivery	5	13
91826	2020-07-07 11:46:47	2020-07-07	12	[{"id_menu":3,"count":1}]	439	delivery	5	17
91827	2020-07-07 11:47:44	2020-07-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":3}]	35636	delivery	5	28
91828	2020-07-07 11:48:09	2020-07-07	12	[{"id_menu":1,"count":1}]	27757	delivery	5	17
91829	2020-07-07 11:57:19	2020-07-07	14	[{"id_menu":2,"count":1}]	549	delivery	5	19
91830	2020-07-07 12:01:54	2020-07-07	9	[{"id_menu":6,"count":1}]	28634	pick-up	0	9
91831	2020-07-07 12:02:43	2020-07-07	12	[{"id_menu":1,"count":1}]	35768	delivery	5	17
91832	2020-07-07 12:07:25	2020-07-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	35730	delivery	5	23
91833	2020-07-07 12:08:58	2020-07-07	17	[{"id_menu":4,"count":1}]	3770	delivery	5	22
91834	2020-07-07 12:10:19	2020-07-07	14	[{"id_menu":2,"count":1}]	638	pick-up	0	14
91835	2020-07-07 12:11:36	2020-07-07	12	[{"id_menu":1,"count":1}]	14098	delivery	5	17
91836	2020-07-07 12:21:37	2020-07-07	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	35707	delivery	5	45
91837	2020-07-07 12:21:46	2020-07-07	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	11227	pick-up	0	24
91838	2020-07-07 12:26:51	2020-07-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	11237	delivery	5	26
91839	2020-07-07 12:29:59	2020-07-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	24005	delivery	5	26
91840	2020-07-07 12:30:45	2020-07-07	17	[{"id_menu":4,"count":1}]	24987	delivery	5	22
91841	2020-07-07 12:33:30	2020-07-07	17	[{"id_menu":4,"count":1}]	2761	delivery	5	22
91842	2020-07-07 12:33:30	2020-07-07	9	[{"id_menu":7,"count":1}]	28632	delivery	5	14
91843	2020-07-07 12:34:57	2020-07-07	12	[{"id_menu":1,"count":1}]	35606	delivery	5	17
91844	2020-07-07 12:35:17	2020-07-07	8	[{"id_menu":5,"count":1}]	35580	delivery	5	13
91845	2020-07-07 12:36:19	2020-07-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	24918	delivery	5	28
91846	2020-07-07 12:36:21	2020-07-07	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	35427	pick-up	0	26
91847	2020-07-07 12:37:45	2020-07-07	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	35783	delivery	5	29
91848	2020-07-07 12:39:24	2020-07-07	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35644	delivery	5	54
91849	2020-07-07 12:48:03	2020-07-07	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	19473	delivery	5	25
91850	2020-07-07 12:50:25	2020-07-07	9	[{"id_menu":6,"count":1}]	19474	delivery	5	14
91851	2020-07-07 12:59:05	2020-07-07	9	[{"id_menu":7,"count":1}]	35752	delivery	5	14
91852	2020-07-07 12:59:47	2020-07-07	14	[{"id_menu":2,"count":1}]	360	delivery	5	19
91853	2020-07-07 13:01:07	2020-07-07	14	[{"id_menu":2,"count":1}]	32294	pick-up	0	14
91854	2020-07-07 13:04:38	2020-07-07	12	[{"id_menu":3,"count":1}]	35665	delivery	5	17
91855	2020-07-07 13:10:32	2020-07-07	14	[{"id_menu":2,"count":1}]	4590	delivery	5	19
91856	2020-07-07 13:12:51	2020-07-07	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	35596	delivery	5	34
91857	2020-07-07 13:13:57	2020-07-07	17	[{"id_menu":4,"count":2}]	35633	delivery	5	22
91858	2020-07-07 13:24:46	2020-07-07	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	25149	delivery	5	44
91859	2020-07-07 13:30:11	2020-07-07	9	[{"id_menu":6,"count":1}]	35668	delivery	5	14
91860	2020-07-07 13:35:04	2020-07-07	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	10616	delivery	5	28
91861	2020-07-07 13:40:41	2020-07-07	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	35769	delivery	5	34
91862	2020-07-07 13:41:14	2020-07-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35706	delivery	5	23
91863	2020-07-07 13:42:33	2020-07-07	12	[{"id_menu":3,"count":1}]	35778	delivery	5	17
91864	2020-07-07 13:43:05	2020-07-07	12	[{"id_menu":3,"count":1}]	396	pick-up	0	12
91865	2020-07-07 13:46:23	2020-07-07	9	[{"id_menu":6,"count":1}]	26445	pick-up	0	9
91866	2020-07-07 13:49:17	2020-07-07	14	[{"id_menu":2,"count":1}]	35748	delivery	5	19
91867	2020-07-07 13:52:36	2020-07-07	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	33462	delivery	5	30
91868	2020-07-07 13:53:32	2020-07-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35749	delivery	5	23
91869	2020-07-07 13:55:26	2020-07-07	9	[{"id_menu":7,"count":1}]	18940	delivery	5	14
91870	2020-07-07 14:06:28	2020-07-07	12	[{"id_menu":3,"count":1}]	14353	delivery	5	17
91871	2020-07-07 14:16:47	2020-07-07	17	[{"id_menu":4,"count":1}]	35589	delivery	5	22
91872	2020-07-07 14:19:28	2020-07-07	9	[{"id_menu":6,"count":1}]	35592	delivery	5	14
91873	2020-07-07 14:20:37	2020-07-07	9	[{"id_menu":6,"count":1}]	35621	delivery	5	14
91874	2020-07-07 14:22:13	2020-07-07	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	28213	delivery	5	30
91875	2020-07-07 14:31:48	2020-07-07	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	16143	delivery	5	25
91876	2020-07-07 14:34:54	2020-07-07	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	27726	delivery	5	45
91877	2020-07-07 14:38:06	2020-07-07	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	35784	delivery	5	31
91878	2020-07-07 14:41:36	2020-07-07	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	16548	delivery	5	39
91879	2020-07-07 14:44:55	2020-07-07	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	35610	delivery	5	40
91880	2020-07-07 14:45:18	2020-07-07	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	35750	delivery	5	26
91881	2020-07-07 14:46:30	2020-07-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	519	pick-up	0	23
91882	2020-07-07 14:52:20	2020-07-07	14	[{"id_menu":2,"count":1}]	35789	delivery	5	19
91883	2020-07-07 14:58:34	2020-07-07	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19050	delivery	5	39
91884	2020-07-07 15:04:45	2020-07-07	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1677	delivery	5	36
91885	2020-07-07 15:09:28	2020-07-07	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	8474	pick-up	0	31
91886	2020-07-07 15:12:35	2020-07-07	14	[{"id_menu":2,"count":1}]	14189	pick-up	0	14
91887	2020-07-07 15:21:59	2020-07-07	12	[{"id_menu":1,"count":1}]	7832	pick-up	0	12
91888	2020-07-07 15:24:49	2020-07-07	12	[{"id_menu":3,"count":1}]	173	pick-up	0	12
91889	2020-07-07 15:25:45	2020-07-07	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	21671	delivery	5	45
91890	2020-07-07 15:26:03	2020-07-07	12	[{"id_menu":3,"count":1}]	26404	delivery	5	17
91891	2020-07-07 15:26:25	2020-07-07	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	35727	delivery	5	31
91892	2020-07-07 15:27:27	2020-07-07	9	[{"id_menu":7,"count":1}]	24040	delivery	5	14
91893	2020-07-07 15:28:06	2020-07-07	9	[{"id_menu":7,"count":1}]	19776	delivery	5	14
91894	2020-07-07 15:28:12	2020-07-07	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	27777	pick-up	0	30
91895	2020-07-07 15:33:06	2020-07-07	12	[{"id_menu":3,"count":1}]	18556	delivery	5	17
91896	2020-07-07 15:34:08	2020-07-07	9	[{"id_menu":6,"count":2}]	33143	delivery	5	14
91897	2020-07-07 15:37:58	2020-07-07	8	[{"id_menu":5,"count":1}]	35794	delivery	5	13
91898	2020-07-07 15:41:31	2020-07-07	12	[{"id_menu":3,"count":1}]	34979	delivery	5	17
91899	2020-07-07 15:49:09	2020-07-07	8	[{"id_menu":5,"count":1}]	20670	pick-up	0	8
91900	2020-07-07 15:50:40	2020-07-07	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3855	delivery	5	52
91901	2020-07-07 15:51:57	2020-07-07	17	[{"id_menu":4,"count":1}]	35773	delivery	5	22
91902	2020-07-07 15:53:33	2020-07-07	17	[{"id_menu":4,"count":1}]	1453	pick-up	0	17
91903	2020-07-07 15:55:25	2020-07-07	9	[{"id_menu":6,"count":1}]	35777	delivery	5	14
91904	2020-07-07 15:57:28	2020-07-07	9	[{"id_menu":7,"count":1}]	35722	pick-up	0	9
91905	2020-07-07 15:58:41	2020-07-07	12	[{"id_menu":3,"count":1}]	35745	delivery	5	17
91906	2020-07-07 15:59:54	2020-07-07	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	35731	pick-up	0	26
91907	2020-07-07 16:01:13	2020-07-07	9	[{"id_menu":7,"count":1}]	13859	pick-up	0	9
91908	2020-07-07 16:01:22	2020-07-07	8	[{"id_menu":5,"count":1}]	7159	delivery	5	13
91909	2020-07-07 16:01:24	2020-07-07	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	35622	delivery	5	46
91910	2020-07-07 16:14:09	2020-07-07	8	[{"id_menu":5,"count":1}]	35614	delivery	5	13
91911	2020-07-07 16:16:13	2020-07-07	9	[{"id_menu":6,"count":3}]	31301	delivery	5	14
91912	2020-07-07 16:17:36	2020-07-07	12	[{"id_menu":3,"count":1}]	5798	pick-up	0	12
91913	2020-07-07 16:20:52	2020-07-07	14	[{"id_menu":2,"count":1}]	22207	pick-up	0	14
91914	2020-07-07 16:22:48	2020-07-07	9	[{"id_menu":6,"count":1}]	851	delivery	5	14
91915	2020-07-07 16:23:56	2020-07-07	9	[{"id_menu":6,"count":2}]	11566	delivery	5	14
91916	2020-07-07 16:26:48	2020-07-07	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3989	delivery	5	35
91917	2020-07-07 16:30:29	2020-07-07	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	35786	delivery	5	38
91918	2020-07-07 16:33:10	2020-07-07	9	[{"id_menu":7,"count":2}]	17502	pick-up	0	9
91919	2020-07-07 16:35:28	2020-07-07	9	[{"id_menu":6,"count":1}]	35601	delivery	5	14
91920	2020-07-07 16:45:32	2020-07-07	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	21076	pick-up	0	31
91921	2020-07-07 16:46:11	2020-07-07	12	[{"id_menu":1,"count":1}]	35702	delivery	5	17
91922	2020-07-07 16:50:31	2020-07-07	17	[{"id_menu":4,"count":1}]	23289	delivery	5	22
91923	2020-07-07 16:56:36	2020-07-07	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	35788	delivery	5	26
91924	2020-07-07 17:05:48	2020-07-07	9	[{"id_menu":6,"count":1}]	30755	delivery	5	14
91925	2020-07-07 17:12:30	2020-07-07	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	33471	delivery	5	34
91926	2020-07-07 17:19:29	2020-07-07	9	[{"id_menu":7,"count":1}]	12675	pick-up	0	9
91927	2020-07-07 17:21:12	2020-07-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	15028	delivery	5	28
91928	2020-07-07 17:29:38	2020-07-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	8353	delivery	5	28
91929	2020-07-07 17:29:53	2020-07-07	8	[{"id_menu":5,"count":1}]	4018	delivery	5	13
91930	2020-07-07 17:30:30	2020-07-07	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	4841	delivery	5	34
91931	2020-07-07 17:30:59	2020-07-07	12	[{"id_menu":1,"count":1}]	35584	delivery	5	17
91932	2020-07-07 17:37:47	2020-07-07	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1376	pick-up	0	21
91933	2020-07-07 17:41:30	2020-07-07	9	[{"id_menu":7,"count":1}]	22885	delivery	5	14
91934	2020-07-07 17:44:51	2020-07-07	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20772	delivery	5	37
91935	2020-07-07 17:45:39	2020-07-07	9	[{"id_menu":7,"count":1}]	35738	delivery	5	14
91936	2020-07-07 17:59:08	2020-07-07	17	[{"id_menu":4,"count":1}]	4986	pick-up	0	17
91937	2020-07-07 18:00:30	2020-07-07	14	[{"id_menu":2,"count":2}]	14559	delivery	5	19
91938	2020-07-07 18:02:13	2020-07-07	9	[{"id_menu":7,"count":1}]	13111	delivery	5	14
91939	2020-07-07 18:04:45	2020-07-07	9	[{"id_menu":6,"count":1}]	25924	delivery	5	14
91940	2020-07-07 18:09:24	2020-07-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	35776	delivery	5	22
91941	2020-07-07 18:10:11	2020-07-07	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	24394	delivery	5	28
91942	2020-07-07 18:13:39	2020-07-07	17	[{"id_menu":4,"count":1}]	31887	pick-up	0	17
91943	2020-07-07 18:18:30	2020-07-07	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	6060	delivery	5	27
91944	2020-07-07 18:20:28	2020-07-07	9	[{"id_menu":7,"count":1}]	7662	pick-up	0	9
91945	2020-07-07 18:21:19	2020-07-07	9	[{"id_menu":6,"count":1}]	18120	delivery	5	14
91946	2020-07-07 18:33:19	2020-07-07	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	35767	delivery	5	34
91947	2020-07-07 18:33:42	2020-07-07	17	[{"id_menu":4,"count":1}]	35739	delivery	5	22
91948	2020-07-07 18:41:34	2020-07-07	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15777	delivery	5	34
91949	2020-07-07 18:45:46	2020-07-07	17	[{"id_menu":4,"count":1}]	26623	delivery	5	22
91950	2020-07-07 18:47:22	2020-07-07	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	35754	delivery	5	30
91951	2020-07-07 18:50:16	2020-07-07	12	[{"id_menu":3,"count":1}]	3028	delivery	5	17
91952	2020-07-07 18:50:49	2020-07-07	9	[{"id_menu":6,"count":1}]	35613	delivery	5	14
91953	2020-07-07 18:55:12	2020-07-07	8	[{"id_menu":5,"count":1}]	30699	delivery	5	13
91954	2020-07-07 18:55:16	2020-07-07	12	[{"id_menu":1,"count":1}]	35764	pick-up	0	12
91955	2020-07-07 18:55:29	2020-07-07	14	[{"id_menu":2,"count":1}]	35611	delivery	5	19
91956	2020-07-07 19:00:21	2020-07-07	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	15110	delivery	5	43
91957	2020-07-07 19:00:36	2020-07-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2339	pick-up	0	23
91958	2020-07-07 19:02:19	2020-07-07	14	[{"id_menu":2,"count":1}]	35691	delivery	5	19
91959	2020-07-07 19:02:21	2020-07-07	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	30394	delivery	5	22
91960	2020-07-07 19:03:02	2020-07-07	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	27257	pick-up	0	25
91961	2020-07-07 19:04:45	2020-07-07	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	4732	delivery	5	45
91962	2020-07-07 19:06:02	2020-07-07	9	[{"id_menu":6,"count":1}]	33667	delivery	5	14
91963	2020-07-07 19:10:24	2020-07-07	9	[{"id_menu":6,"count":1}]	1765	pick-up	0	9
91964	2020-07-07 19:11:41	2020-07-07	9	[{"id_menu":6,"count":1}]	35725	delivery	5	14
91965	2020-07-07 19:23:19	2020-07-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5183	delivery	5	28
91966	2020-07-07 19:24:20	2020-07-07	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	5668	pick-up	0	29
91967	2020-07-07 19:24:24	2020-07-07	12	[{"id_menu":3,"count":1}]	5869	pick-up	0	12
91968	2020-07-07 19:24:55	2020-07-07	12	[{"id_menu":3,"count":1}]	35743	delivery	5	17
91969	2020-07-07 19:27:47	2020-07-07	17	[{"id_menu":4,"count":2}]	24770	delivery	5	22
91970	2020-07-07 19:30:17	2020-07-07	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	30022	delivery	5	36
91971	2020-07-07 19:34:29	2020-07-07	8	[{"id_menu":5,"count":1}]	16017	delivery	5	13
91972	2020-07-07 19:34:52	2020-07-07	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	31571	pick-up	0	26
91973	2020-07-07 19:37:36	2020-07-07	12	[{"id_menu":1,"count":1}]	35672	delivery	5	17
91974	2020-07-07 19:42:14	2020-07-07	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	630	delivery	5	38
91975	2020-07-07 19:44:40	2020-07-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35605	delivery	5	23
91976	2020-07-07 19:45:16	2020-07-07	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	18320	pick-up	0	31
91977	2020-07-07 19:47:21	2020-07-07	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17056	delivery	5	31
91978	2020-07-07 19:48:24	2020-07-07	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	35079	delivery	5	44
91979	2020-07-07 19:56:11	2020-07-07	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	35799	delivery	5	23
91980	2020-07-07 19:56:14	2020-07-07	12	[{"id_menu":3,"count":1}]	35715	delivery	5	17
91981	2020-07-07 19:58:48	2020-07-07	9	[{"id_menu":6,"count":1}]	23665	delivery	5	14
91982	2020-07-07 20:04:26	2020-07-07	14	[{"id_menu":2,"count":1}]	35719	delivery	5	19
91983	2020-07-07 20:04:55	2020-07-07	8	[{"id_menu":5,"count":1}]	34551	pick-up	0	8
91984	2020-07-07 20:07:28	2020-07-07	9	[{"id_menu":7,"count":1}]	27140	delivery	5	14
91985	2020-07-07 20:09:59	2020-07-07	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	20876	delivery	5	30
91986	2020-07-07 20:15:27	2020-07-07	17	[{"id_menu":4,"count":1}]	35787	delivery	5	22
91987	2020-07-07 20:18:23	2020-07-07	8	[{"id_menu":5,"count":1}]	25754	delivery	5	13
91988	2020-07-07 20:19:34	2020-07-07	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1066	delivery	5	40
91989	2020-07-07 20:23:50	2020-07-07	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	35685	delivery	5	22
91990	2020-07-07 20:23:53	2020-07-07	9	[{"id_menu":7,"count":1}]	28952	delivery	5	14
91991	2020-07-07 20:24:26	2020-07-07	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	35737	delivery	5	56
91992	2020-07-07 20:26:13	2020-07-07	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	13254	delivery	5	26
91993	2020-07-07 20:27:46	2020-07-07	9	[{"id_menu":7,"count":1}]	5286	pick-up	0	9
91994	2020-07-07 20:29:05	2020-07-07	9	[{"id_menu":6,"count":1}]	6660	delivery	5	14
91995	2020-07-07 20:33:17	2020-07-07	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	35758	delivery	5	25
91996	2020-07-07 20:37:04	2020-07-07	12	[{"id_menu":3,"count":1}]	13343	delivery	5	17
91997	2020-07-07 20:37:18	2020-07-07	9	[{"id_menu":7,"count":1}]	17685	pick-up	0	9
91998	2020-07-07 20:38:41	2020-07-07	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9445	delivery	5	35
91999	2020-07-07 20:41:35	2020-07-07	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	14128	delivery	5	36
92000	2020-07-07 20:46:07	2020-07-07	12	[{"id_menu":3,"count":1}]	35714	delivery	5	17
92001	2020-07-07 20:48:51	2020-07-07	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	14301	delivery	5	27
92002	2020-07-07 20:56:09	2020-07-07	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	35713	delivery	5	40
92003	2020-07-07 21:01:21	2020-07-07	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11348	delivery	5	43
92004	2020-07-07 21:06:13	2020-07-07	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35779	delivery	5	40
92005	2020-07-07 21:07:05	2020-07-07	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31700	delivery	5	22
92006	2020-07-07 21:08:59	2020-07-07	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	35620	delivery	5	40
92007	2020-07-07 21:09:25	2020-07-07	17	[{"id_menu":4,"count":1}]	35678	delivery	5	22
92008	2020-07-07 21:12:38	2020-07-07	9	[{"id_menu":6,"count":1}]	35594	delivery	5	14
92009	2020-07-07 21:18:33	2020-07-07	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	467	pick-up	0	31
92010	2020-07-07 21:19:28	2020-07-07	14	[{"id_menu":2,"count":1}]	35602	delivery	5	19
92011	2020-07-07 21:20:39	2020-07-07	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	12808	pick-up	0	26
92012	2020-07-07 21:22:25	2020-07-07	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	12291	delivery	5	34
92013	2020-07-07 21:24:14	2020-07-07	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10576	delivery	5	31
92014	2020-07-07 21:28:08	2020-07-07	9	[{"id_menu":7,"count":1}]	35760	delivery	5	14
92015	2020-07-07 21:30:38	2020-07-07	9	[{"id_menu":7,"count":1}]	35631	delivery	5	14
92016	2020-07-07 21:30:48	2020-07-07	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28647	delivery	5	39
92017	2020-07-07 21:32:44	2020-07-07	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	32025	pick-up	0	38
92018	2020-07-07 21:33:59	2020-07-07	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	32596	delivery	5	25
92019	2020-07-07 21:34:48	2020-07-07	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	34037	delivery	5	26
92020	2020-07-07 21:36:22	2020-07-07	14	[{"id_menu":2,"count":1}]	2124	pick-up	0	14
92021	2020-07-07 21:36:38	2020-07-07	12	[{"id_menu":3,"count":1}]	29699	delivery	5	17
92022	2020-07-07 21:36:55	2020-07-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5076	delivery	5	22
92023	2020-07-07 21:37:17	2020-07-07	12	[{"id_menu":1,"count":1}]	35704	delivery	5	17
92024	2020-07-07 21:42:49	2020-07-07	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	35591	delivery	5	31
92025	2020-07-07 21:44:09	2020-07-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	8394	pick-up	0	21
92026	2020-07-07 21:46:44	2020-07-07	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23928	delivery	5	53
92027	2020-07-07 21:51:16	2020-07-07	9	[{"id_menu":6,"count":1}]	35742	delivery	5	14
92028	2020-07-07 21:53:27	2020-07-07	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	34125	delivery	5	39
92029	2020-07-07 21:53:33	2020-07-07	17	[{"id_menu":5,"count":3},{"id_menu":7,"count":1}]	20478	delivery	5	22
92030	2020-07-07 22:03:23	2020-07-07	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28174	delivery	5	34
92031	2020-07-07 22:10:41	2020-07-07	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4385	delivery	5	31
92032	2020-07-07 22:12:23	2020-07-07	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5437	delivery	5	31
92033	2020-07-07 22:17:56	2020-07-07	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	35717	delivery	5	45
92034	2020-07-07 22:18:50	2020-07-07	9	[{"id_menu":6,"count":1}]	41	pick-up	0	9
92035	2020-07-07 22:21:38	2020-07-07	9	[{"id_menu":6,"count":1}]	25665	delivery	5	14
92036	2020-07-07 22:23:47	2020-07-07	8	[{"id_menu":5,"count":1}]	13990	delivery	5	13
92037	2020-07-07 22:24:17	2020-07-07	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	35619	delivery	5	36
92038	2020-07-07 22:25:26	2020-07-07	17	[{"id_menu":4,"count":1}]	35690	delivery	5	22
92039	2020-07-07 22:28:36	2020-07-07	14	[{"id_menu":2,"count":1}]	3817	pick-up	0	14
92040	2020-07-07 22:31:05	2020-07-07	17	[{"id_menu":4,"count":1}]	28141	delivery	5	22
92041	2020-07-07 22:31:20	2020-07-07	12	[{"id_menu":3,"count":1}]	11129	delivery	5	17
92042	2020-07-07 22:32:57	2020-07-07	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	29851	delivery	5	26
92043	2020-07-07 22:34:35	2020-07-07	9	[{"id_menu":6,"count":1}]	35568	delivery	5	14
92044	2020-07-07 22:37:16	2020-07-07	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	14968	delivery	5	31
92045	2020-07-07 22:39:03	2020-07-07	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	28413	delivery	5	48
92046	2020-07-07 22:40:32	2020-07-07	12	[{"id_menu":1,"count":1}]	35710	delivery	5	17
92047	2020-07-07 22:43:21	2020-07-07	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	35659	delivery	5	29
92048	2020-07-07 22:45:41	2020-07-07	12	[{"id_menu":1,"count":1}]	31267	pick-up	0	12
92049	2020-07-07 22:46:35	2020-07-07	9	[{"id_menu":7,"count":1}]	13676	delivery	5	14
92050	2020-07-07 22:47:27	2020-07-07	17	[{"id_menu":4,"count":1}]	6232	delivery	5	22
92051	2020-07-07 23:05:34	2020-07-07	14	[{"id_menu":2,"count":1}]	26383	delivery	5	19
92052	2020-07-07 23:08:10	2020-07-07	8	[{"id_menu":5,"count":1}]	11446	pick-up	0	8
92053	2020-07-07 23:10:12	2020-07-07	12	[{"id_menu":3,"count":1}]	7710	pick-up	0	12
92054	2020-07-07 23:10:53	2020-07-07	9	[{"id_menu":6,"count":1}]	32500	pick-up	0	9
92055	2020-07-07 23:14:57	2020-07-07	9	[{"id_menu":6,"count":1}]	28959	pick-up	0	9
92056	2020-07-07 23:17:56	2020-07-07	8	[{"id_menu":5,"count":1}]	35741	pick-up	0	8
92057	2020-07-07 23:19:54	2020-07-07	8	[{"id_menu":5,"count":1}]	14528	pick-up	0	8
92058	2020-07-07 23:20:24	2020-07-07	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	35666	delivery	5	34
92059	2020-07-07 23:23:25	2020-07-07	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	6187	delivery	5	31
92060	2020-07-07 23:27:27	2020-07-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	35653	delivery	5	28
92061	2020-07-07 23:30:21	2020-07-07	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30826	delivery	5	37
92062	2020-07-07 23:32:16	2020-07-07	9	[{"id_menu":7,"count":1}]	35724	delivery	5	14
92063	2020-07-07 23:35:46	2020-07-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21213	delivery	5	23
92064	2020-07-07 23:43:45	2020-07-07	9	[{"id_menu":6,"count":2}]	31006	pick-up	0	9
92065	2020-07-07 23:50:14	2020-07-07	9	[{"id_menu":6,"count":1}]	28138	delivery	5	14
92066	2020-07-07 23:58:31	2020-07-07	8	[{"id_menu":5,"count":1}]	35649	pick-up	0	8
92067	2020-07-07 23:59:11	2020-07-07	9	[{"id_menu":7,"count":1}]	5558	delivery	5	14
92068	2020-07-08 00:00:01	2020-07-08	9	[{"id_menu":6,"count":1}]	35856	delivery	5	14
92069	2020-07-08 00:01:08	2020-07-08	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	35919	delivery	5	34
92070	2020-07-08 00:02:34	2020-07-08	9	[{"id_menu":7,"count":1}]	11102	delivery	5	14
92071	2020-07-08 00:05:36	2020-07-08	9	[{"id_menu":6,"count":1}]	35994	delivery	5	14
92072	2020-07-08 00:05:58	2020-07-08	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21426	delivery	5	22
92073	2020-07-08 00:06:25	2020-07-08	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	9533	pick-up	0	24
92074	2020-07-08 00:08:13	2020-07-08	9	[{"id_menu":6,"count":1}]	35877	delivery	5	14
92075	2020-07-08 00:09:35	2020-07-08	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":3}]	35819	delivery	5	31
92076	2020-07-08 00:09:51	2020-07-08	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	15151	delivery	5	25
92077	2020-07-08 00:14:22	2020-07-08	17	[{"id_menu":4,"count":1}]	9331	pick-up	0	17
92078	2020-07-08 00:15:15	2020-07-08	12	[{"id_menu":3,"count":1}]	35720	delivery	5	17
92079	2020-07-08 00:16:55	2020-07-08	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	35896	delivery	5	26
92080	2020-07-08 00:17:35	2020-07-08	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	35918	delivery	5	35
92081	2020-07-08 00:19:07	2020-07-08	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	35905	delivery	5	31
92082	2020-07-08 00:20:39	2020-07-08	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31266	delivery	5	39
92083	2020-07-08 00:21:10	2020-07-08	14	[{"id_menu":2,"count":1}]	2894	delivery	5	19
92084	2020-07-08 00:22:39	2020-07-08	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22450	delivery	5	36
92085	2020-07-08 00:25:08	2020-07-08	9	[{"id_menu":7,"count":1}]	376	pick-up	0	9
92086	2020-07-08 00:27:23	2020-07-08	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35898	delivery	5	35
92087	2020-07-08 00:28:40	2020-07-08	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	35870	pick-up	0	31
92088	2020-07-08 00:30:03	2020-07-08	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":2}]	22865	delivery	5	26
92089	2020-07-08 00:35:56	2020-07-08	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	23614	delivery	5	40
92090	2020-07-08 00:39:23	2020-07-08	12	[{"id_menu":1,"count":1}]	9295	pick-up	0	12
92091	2020-07-08 00:39:27	2020-07-08	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	35814	delivery	5	39
92092	2020-07-08 00:45:05	2020-07-08	17	[{"id_menu":4,"count":1}]	8009	delivery	5	22
92093	2020-07-08 00:45:47	2020-07-08	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	4320	delivery	5	40
92094	2020-07-08 00:46:59	2020-07-08	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	21649	delivery	5	27
92095	2020-07-08 00:47:53	2020-07-08	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	35944	delivery	5	36
92096	2020-07-08 00:51:51	2020-07-08	14	[{"id_menu":2,"count":1}]	27585	delivery	5	19
92097	2020-07-08 00:53:12	2020-07-08	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	16334	delivery	5	36
92098	2020-07-08 01:06:06	2020-07-08	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	35818	delivery	5	39
92099	2020-07-08 01:06:17	2020-07-08	9	[{"id_menu":7,"count":1}]	16927	delivery	5	14
92100	2020-07-08 01:10:00	2020-07-08	17	[{"id_menu":4,"count":1}]	35863	delivery	5	22
92101	2020-07-08 01:10:37	2020-07-08	14	[{"id_menu":2,"count":1}]	35888	delivery	5	19
92102	2020-07-08 01:13:25	2020-07-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	36010	delivery	5	28
92103	2020-07-08 01:14:01	2020-07-08	14	[{"id_menu":2,"count":1}]	36001	delivery	5	19
92104	2020-07-08 01:25:03	2020-07-08	12	[{"id_menu":3,"count":1}]	35565	pick-up	0	12
92105	2020-07-08 01:25:37	2020-07-08	8	[{"id_menu":5,"count":1}]	27763	delivery	5	13
92106	2020-07-08 01:26:25	2020-07-08	12	[{"id_menu":1,"count":1}]	10828	pick-up	0	12
92107	2020-07-08 01:27:18	2020-07-08	14	[{"id_menu":2,"count":1}]	35823	pick-up	0	14
92108	2020-07-08 01:27:44	2020-07-08	9	[{"id_menu":7,"count":1}]	5391	delivery	5	14
92109	2020-07-08 01:33:11	2020-07-08	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	34147	delivery	5	35
92110	2020-07-08 01:35:07	2020-07-08	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	35883	delivery	5	34
92111	2020-07-08 01:36:50	2020-07-08	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35960	delivery	5	31
92112	2020-07-08 01:38:26	2020-07-08	9	[{"id_menu":7,"count":2}]	33738	delivery	5	14
92113	2020-07-08 01:44:49	2020-07-08	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35813	delivery	5	31
92114	2020-07-08 01:46:08	2020-07-08	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	18603	delivery	5	40
92115	2020-07-08 01:46:46	2020-07-08	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	6988	delivery	5	34
92116	2020-07-08 01:48:36	2020-07-08	17	[{"id_menu":4,"count":1}]	2470	pick-up	0	17
92117	2020-07-08 01:48:57	2020-07-08	9	[{"id_menu":6,"count":1}]	4791	delivery	5	14
92118	2020-07-08 01:49:16	2020-07-08	9	[{"id_menu":7,"count":1}]	35889	delivery	5	14
92119	2020-07-08 01:49:37	2020-07-08	8	[{"id_menu":5,"count":1}]	1923	delivery	5	13
92120	2020-07-08 01:51:49	2020-07-08	9	[{"id_menu":6,"count":1}]	609	pick-up	0	9
92121	2020-07-08 01:54:33	2020-07-08	14	[{"id_menu":2,"count":1}]	7302	delivery	5	19
92122	2020-07-08 01:55:42	2020-07-08	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35836	delivery	5	45
92123	2020-07-08 01:56:41	2020-07-08	17	[{"id_menu":4,"count":1}]	30469	delivery	5	22
92124	2020-07-08 01:57:09	2020-07-08	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	35991	delivery	5	30
92125	2020-07-08 01:59:08	2020-07-08	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	35997	delivery	5	34
92126	2020-07-08 01:59:12	2020-07-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	35887	delivery	5	28
92127	2020-07-08 02:00:50	2020-07-08	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	8397	delivery	5	45
92128	2020-07-08 02:03:05	2020-07-08	9	[{"id_menu":6,"count":1}]	33633	delivery	5	14
92129	2020-07-08 02:06:31	2020-07-08	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2568	pick-up	0	17
92130	2020-07-08 02:10:32	2020-07-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30601	delivery	5	23
92131	2020-07-08 02:10:53	2020-07-08	17	[{"id_menu":4,"count":1}]	23984	delivery	5	22
92132	2020-07-08 02:13:07	2020-07-08	17	[{"id_menu":4,"count":1}]	876	delivery	5	22
92133	2020-07-08 02:15:56	2020-07-08	9	[{"id_menu":6,"count":1}]	35807	delivery	5	14
92134	2020-07-08 02:15:59	2020-07-08	8	[{"id_menu":5,"count":1}]	35920	delivery	5	13
92135	2020-07-08 02:16:40	2020-07-08	9	[{"id_menu":7,"count":1}]	20910	pick-up	0	9
92136	2020-07-08 02:17:56	2020-07-08	9	[{"id_menu":7,"count":1}]	21387	pick-up	0	9
92137	2020-07-08 02:23:20	2020-07-08	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	13951	delivery	5	34
92138	2020-07-08 02:24:09	2020-07-08	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	35809	delivery	5	22
92139	2020-07-08 02:27:38	2020-07-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3881	delivery	5	23
92140	2020-07-08 02:33:36	2020-07-08	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2857	pick-up	0	25
92141	2020-07-08 02:36:51	2020-07-08	34	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2153	pick-up	0	34
92142	2020-07-08 02:37:40	2020-07-08	8	[{"id_menu":5,"count":1}]	30841	delivery	5	13
92143	2020-07-08 02:38:26	2020-07-08	9	[{"id_menu":6,"count":1}]	35892	delivery	5	14
92144	2020-07-08 02:41:35	2020-07-08	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	970	pick-up	0	31
92145	2020-07-08 02:47:20	2020-07-08	9	[{"id_menu":6,"count":1}]	31061	delivery	5	14
92146	2020-07-08 02:48:51	2020-07-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27556	delivery	5	22
92147	2020-07-08 02:49:15	2020-07-08	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	25793	pick-up	0	21
92148	2020-07-08 02:49:47	2020-07-08	17	[{"id_menu":4,"count":1}]	22987	pick-up	0	17
92149	2020-07-08 02:59:38	2020-07-08	9	[{"id_menu":6,"count":1}]	35822	delivery	5	14
92150	2020-07-08 03:06:44	2020-07-08	17	[{"id_menu":4,"count":1}]	31066	pick-up	0	17
92151	2020-07-08 03:08:42	2020-07-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	35893	delivery	5	28
92152	2020-07-08 03:09:32	2020-07-08	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18098	delivery	5	40
92153	2020-07-08 03:22:26	2020-07-08	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	17951	delivery	5	31
92154	2020-07-08 03:24:28	2020-07-08	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	20356	delivery	5	57
92155	2020-07-08 03:30:34	2020-07-08	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	35947	delivery	5	27
92156	2020-07-08 03:30:40	2020-07-08	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35914	delivery	5	49
92157	2020-07-08 03:31:02	2020-07-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35928	delivery	5	23
92158	2020-07-08 03:35:00	2020-07-08	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	16365	delivery	5	25
92159	2020-07-08 03:35:49	2020-07-08	12	[{"id_menu":1,"count":1}]	35951	delivery	5	17
92160	2020-07-08 03:42:08	2020-07-08	17	[{"id_menu":4,"count":1}]	1321	delivery	5	22
92161	2020-07-08 03:44:15	2020-07-08	9	[{"id_menu":6,"count":2}]	14626	delivery	5	14
92162	2020-07-08 03:47:16	2020-07-08	8	[{"id_menu":5,"count":1}]	5615	delivery	5	13
92163	2020-07-08 03:48:12	2020-07-08	14	[{"id_menu":2,"count":1}]	35808	pick-up	0	14
92164	2020-07-08 03:54:20	2020-07-08	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15945	delivery	5	31
92165	2020-07-08 03:59:59	2020-07-08	12	[{"id_menu":1,"count":1}]	6173	pick-up	0	12
92166	2020-07-08 04:03:34	2020-07-08	12	[{"id_menu":1,"count":1}]	3648	delivery	5	17
92167	2020-07-08 04:03:38	2020-07-08	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11448	delivery	5	22
92168	2020-07-08 04:04:20	2020-07-08	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	24630	delivery	5	28
92169	2020-07-08 04:07:14	2020-07-08	17	[{"id_menu":4,"count":1}]	28948	delivery	5	22
92170	2020-07-08 04:07:26	2020-07-08	9	[{"id_menu":6,"count":1}]	35941	delivery	5	14
92171	2020-07-08 04:10:41	2020-07-08	8	[{"id_menu":5,"count":1}]	35921	pick-up	0	8
92172	2020-07-08 04:11:55	2020-07-08	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2498	pick-up	0	20
92173	2020-07-08 04:14:56	2020-07-08	9	[{"id_menu":6,"count":1}]	35854	delivery	5	14
92174	2020-07-08 04:17:03	2020-07-08	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	25781	delivery	5	26
92175	2020-07-08 04:21:43	2020-07-08	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	34392	delivery	5	26
92176	2020-07-08 04:24:46	2020-07-08	9	[{"id_menu":6,"count":1}]	35964	delivery	5	14
92177	2020-07-08 04:25:57	2020-07-08	9	[{"id_menu":6,"count":2}]	25003	delivery	5	14
92178	2020-07-08 04:34:08	2020-07-08	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	35364	delivery	5	30
92179	2020-07-08 04:38:46	2020-07-08	14	[{"id_menu":2,"count":1}]	35852	delivery	5	19
92180	2020-07-08 04:40:42	2020-07-08	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	35940	delivery	5	36
92181	2020-07-08 04:45:53	2020-07-08	9	[{"id_menu":6,"count":1}]	35913	delivery	5	14
92182	2020-07-08 04:48:27	2020-07-08	8	[{"id_menu":5,"count":1}]	16367	delivery	5	13
92183	2020-07-08 04:48:43	2020-07-08	9	[{"id_menu":6,"count":1}]	35909	delivery	5	14
92184	2020-07-08 04:53:26	2020-07-08	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11214	delivery	5	34
92185	2020-07-08 04:58:53	2020-07-08	17	[{"id_menu":4,"count":1}]	19507	delivery	5	22
92186	2020-07-08 04:59:18	2020-07-08	14	[{"id_menu":2,"count":1}]	35894	delivery	5	19
92187	2020-07-08 05:00:08	2020-07-08	14	[{"id_menu":2,"count":1}]	35829	delivery	5	19
92188	2020-07-08 05:00:27	2020-07-08	9	[{"id_menu":7,"count":1}]	16839	delivery	5	14
92189	2020-07-08 05:03:34	2020-07-08	12	[{"id_menu":1,"count":1}]	972	delivery	5	17
92190	2020-07-08 05:03:43	2020-07-08	9	[{"id_menu":6,"count":2}]	32260	delivery	5	14
92191	2020-07-08 05:03:52	2020-07-08	12	[{"id_menu":1,"count":1}]	33164	delivery	5	17
92192	2020-07-08 05:04:02	2020-07-08	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	19434	delivery	5	34
92193	2020-07-08 05:04:06	2020-07-08	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	13570	pick-up	0	21
92194	2020-07-08 05:12:01	2020-07-08	12	[{"id_menu":1,"count":1}]	35975	delivery	5	17
92195	2020-07-08 05:13:35	2020-07-08	12	[{"id_menu":3,"count":1}]	30233	pick-up	0	12
92196	2020-07-08 05:17:14	2020-07-08	9	[{"id_menu":7,"count":1}]	22388	delivery	5	14
92197	2020-07-08 05:17:31	2020-07-08	17	[{"id_menu":4,"count":1}]	23735	delivery	5	22
92198	2020-07-08 05:17:57	2020-07-08	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15575	delivery	5	35
92199	2020-07-08 05:18:01	2020-07-08	14	[{"id_menu":2,"count":1}]	35966	pick-up	0	14
92200	2020-07-08 05:21:28	2020-07-08	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11829	delivery	5	43
92201	2020-07-08 05:27:07	2020-07-08	14	[{"id_menu":2,"count":1}]	35961	delivery	5	19
92202	2020-07-08 05:29:02	2020-07-08	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	32999	delivery	5	22
92203	2020-07-08 05:29:45	2020-07-08	8	[{"id_menu":5,"count":1}]	28709	delivery	5	13
92204	2020-07-08 05:34:27	2020-07-08	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	32899	delivery	5	31
92205	2020-07-08 05:36:19	2020-07-08	12	[{"id_menu":3,"count":1}]	15720	pick-up	0	12
92206	2020-07-08 05:39:17	2020-07-08	14	[{"id_menu":2,"count":2}]	35904	delivery	5	19
92207	2020-07-08 05:40:44	2020-07-08	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7204	delivery	5	36
92208	2020-07-08 05:42:29	2020-07-08	12	[{"id_menu":3,"count":1}]	24763	pick-up	0	12
92209	2020-07-08 05:46:16	2020-07-08	9	[{"id_menu":6,"count":1}]	35969	delivery	5	14
92210	2020-07-08 05:47:59	2020-07-08	9	[{"id_menu":6,"count":1}]	25313	delivery	5	14
92211	2020-07-08 05:50:37	2020-07-08	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	35834	delivery	5	36
92212	2020-07-08 05:53:35	2020-07-08	9	[{"id_menu":6,"count":1}]	19965	delivery	5	14
92213	2020-07-08 05:54:06	2020-07-08	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	26366	delivery	5	22
92214	2020-07-08 05:56:00	2020-07-08	9	[{"id_menu":6,"count":1}]	35979	delivery	5	14
92215	2020-07-08 05:57:20	2020-07-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	19270	delivery	5	28
92216	2020-07-08 05:57:25	2020-07-08	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":3}]	21261	delivery	5	25
92217	2020-07-08 05:59:25	2020-07-08	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	24538	delivery	5	36
92218	2020-07-08 06:02:47	2020-07-08	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	35855	pick-up	0	20
92219	2020-07-08 06:03:45	2020-07-08	14	[{"id_menu":2,"count":1}]	5963	pick-up	0	14
92220	2020-07-08 06:09:33	2020-07-08	8	[{"id_menu":5,"count":1}]	17150	pick-up	0	8
92221	2020-07-08 06:09:50	2020-07-08	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	35953	pick-up	0	21
92222	2020-07-08 06:12:57	2020-07-08	14	[{"id_menu":2,"count":1}]	12858	pick-up	0	14
92223	2020-07-08 06:14:23	2020-07-08	12	[{"id_menu":1,"count":1}]	20106	delivery	5	17
92224	2020-07-08 06:17:05	2020-07-08	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4255	delivery	5	35
92225	2020-07-08 06:18:53	2020-07-08	17	[{"id_menu":4,"count":1}]	23537	delivery	5	22
92226	2020-07-08 06:21:44	2020-07-08	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15605	delivery	5	39
92227	2020-07-08 06:22:23	2020-07-08	17	[{"id_menu":4,"count":1}]	22729	delivery	5	22
92228	2020-07-08 06:23:59	2020-07-08	17	[{"id_menu":4,"count":1}]	2570	delivery	5	22
92229	2020-07-08 06:24:18	2020-07-08	8	[{"id_menu":5,"count":1}]	7292	delivery	5	13
92230	2020-07-08 06:25:30	2020-07-08	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	29688	delivery	5	26
92231	2020-07-08 06:28:48	2020-07-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	27893	delivery	5	22
92232	2020-07-08 06:28:54	2020-07-08	12	[{"id_menu":3,"count":1}]	9103	delivery	5	17
92233	2020-07-08 06:34:23	2020-07-08	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	6104	delivery	5	25
92234	2020-07-08 06:35:12	2020-07-08	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	35998	delivery	5	45
92235	2020-07-08 06:36:47	2020-07-08	9	[{"id_menu":7,"count":2}]	16360	delivery	5	14
92236	2020-07-08 06:37:53	2020-07-08	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20494	delivery	5	37
92237	2020-07-08 06:39:11	2020-07-08	14	[{"id_menu":2,"count":1}]	29601	delivery	5	19
92238	2020-07-08 06:43:04	2020-07-08	14	[{"id_menu":2,"count":1}]	21492	delivery	5	19
92239	2020-07-08 06:44:40	2020-07-08	14	[{"id_menu":2,"count":1}]	1442	pick-up	0	14
92240	2020-07-08 06:46:38	2020-07-08	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	11244	pick-up	0	31
92241	2020-07-08 06:49:06	2020-07-08	14	[{"id_menu":2,"count":1}]	11709	delivery	5	19
92242	2020-07-08 06:49:32	2020-07-08	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	31939	delivery	5	27
92243	2020-07-08 06:49:38	2020-07-08	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	24367	pick-up	0	21
92244	2020-07-08 06:57:42	2020-07-08	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	2452	delivery	5	28
92245	2020-07-08 06:58:01	2020-07-08	12	[{"id_menu":3,"count":1}]	13709	delivery	5	17
92246	2020-07-08 07:05:15	2020-07-08	17	[{"id_menu":4,"count":1}]	35837	delivery	5	22
92247	2020-07-08 07:08:10	2020-07-08	12	[{"id_menu":1,"count":1}]	35962	delivery	5	17
92248	2020-07-08 07:09:53	2020-07-08	12	[{"id_menu":1,"count":1}]	17530	delivery	5	17
92249	2020-07-08 07:10:45	2020-07-08	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4872	pick-up	0	31
92250	2020-07-08 07:13:31	2020-07-08	12	[{"id_menu":1,"count":1}]	35881	delivery	5	17
92251	2020-07-08 07:15:12	2020-07-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14831	delivery	5	23
92252	2020-07-08 07:15:52	2020-07-08	14	[{"id_menu":2,"count":1}]	20745	pick-up	0	14
92253	2020-07-08 07:24:55	2020-07-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	11570	delivery	5	28
92254	2020-07-08 07:26:45	2020-07-08	9	[{"id_menu":6,"count":1}]	10424	delivery	5	14
92255	2020-07-08 07:29:52	2020-07-08	9	[{"id_menu":6,"count":2}]	35958	delivery	5	14
92256	2020-07-08 07:32:58	2020-07-08	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	35811	delivery	5	31
92257	2020-07-08 07:34:38	2020-07-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	29031	delivery	5	22
92258	2020-07-08 07:36:34	2020-07-08	14	[{"id_menu":2,"count":1}]	2731	delivery	5	19
92259	2020-07-08 07:47:15	2020-07-08	14	[{"id_menu":2,"count":1}]	16924	delivery	5	19
92260	2020-07-08 07:51:22	2020-07-08	9	[{"id_menu":6,"count":1}]	35957	delivery	5	14
92261	2020-07-08 07:52:22	2020-07-08	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2799	pick-up	0	38
92262	2020-07-08 07:54:17	2020-07-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1317	delivery	5	28
92263	2020-07-08 07:55:19	2020-07-08	14	[{"id_menu":2,"count":1}]	34905	pick-up	0	14
92264	2020-07-08 08:02:02	2020-07-08	8	[{"id_menu":5,"count":1}]	35935	delivery	5	13
92265	2020-07-08 08:02:07	2020-07-08	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1308	delivery	5	34
92266	2020-07-08 08:04:50	2020-07-08	12	[{"id_menu":1,"count":1}]	35827	pick-up	0	12
92267	2020-07-08 08:06:44	2020-07-08	12	[{"id_menu":1,"count":1}]	35824	pick-up	0	12
92268	2020-07-08 08:08:15	2020-07-08	12	[{"id_menu":3,"count":1}]	35815	pick-up	0	12
92269	2020-07-08 08:11:09	2020-07-08	14	[{"id_menu":2,"count":1}]	13960	delivery	5	19
92270	2020-07-08 08:11:44	2020-07-08	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	35974	delivery	5	26
92271	2020-07-08 08:14:18	2020-07-08	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	35907	delivery	5	39
92272	2020-07-08 08:14:47	2020-07-08	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4654	delivery	5	22
92273	2020-07-08 08:15:25	2020-07-08	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	33530	delivery	5	27
92274	2020-07-08 08:16:08	2020-07-08	9	[{"id_menu":7,"count":1}]	27775	pick-up	0	9
92275	2020-07-08 08:17:31	2020-07-08	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	35831	delivery	5	30
92276	2020-07-08 08:18:14	2020-07-08	9	[{"id_menu":6,"count":1}]	2780	pick-up	0	9
92277	2020-07-08 08:25:16	2020-07-08	12	[{"id_menu":1,"count":1}]	35830	delivery	5	17
92278	2020-07-08 08:27:22	2020-07-08	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23200	delivery	5	36
92279	2020-07-08 08:31:28	2020-07-08	12	[{"id_menu":1,"count":1}]	19691	delivery	5	17
92280	2020-07-08 08:35:05	2020-07-08	9	[{"id_menu":6,"count":1}]	5292	pick-up	0	9
92281	2020-07-08 08:36:30	2020-07-08	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	35849	delivery	5	45
92282	2020-07-08 08:37:58	2020-07-08	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	36011	delivery	5	44
92283	2020-07-08 08:38:17	2020-07-08	12	[{"id_menu":3,"count":1}]	7051	pick-up	0	12
92284	2020-07-08 08:43:51	2020-07-08	9	[{"id_menu":7,"count":1}]	35976	pick-up	0	9
92285	2020-07-08 08:50:08	2020-07-08	17	[{"id_menu":4,"count":1}]	35871	delivery	5	22
92286	2020-07-08 08:57:26	2020-07-08	12	[{"id_menu":3,"count":1}]	33520	delivery	5	17
92287	2020-07-08 08:59:41	2020-07-08	14	[{"id_menu":2,"count":1}]	5426	pick-up	0	14
92288	2020-07-08 08:59:56	2020-07-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25075	delivery	5	22
92289	2020-07-08 09:00:23	2020-07-08	9	[{"id_menu":6,"count":1}]	35899	delivery	5	14
92290	2020-07-08 09:03:05	2020-07-08	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	12460	delivery	5	39
92291	2020-07-08 09:06:30	2020-07-08	9	[{"id_menu":6,"count":2}]	35927	delivery	5	14
92292	2020-07-08 09:07:00	2020-07-08	9	[{"id_menu":7,"count":2}]	30431	delivery	5	14
92293	2020-07-08 09:07:00	2020-07-08	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	29145	delivery	5	26
92294	2020-07-08 09:07:25	2020-07-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3823	delivery	5	28
92295	2020-07-08 09:08:45	2020-07-08	12	[{"id_menu":3,"count":1}]	15138	delivery	5	17
92296	2020-07-08 09:09:31	2020-07-08	12	[{"id_menu":3,"count":1}]	3091	delivery	5	17
92297	2020-07-08 09:10:20	2020-07-08	8	[{"id_menu":5,"count":2}]	5041	delivery	5	13
92298	2020-07-08 09:14:40	2020-07-08	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	35825	delivery	5	30
92299	2020-07-08 09:15:50	2020-07-08	12	[{"id_menu":1,"count":1}]	21806	pick-up	0	12
92300	2020-07-08 09:19:53	2020-07-08	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	35992	delivery	5	42
92301	2020-07-08 09:20:27	2020-07-08	9	[{"id_menu":6,"count":1}]	35978	delivery	5	14
92302	2020-07-08 09:21:33	2020-07-08	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13158	delivery	5	22
92303	2020-07-08 09:25:51	2020-07-08	14	[{"id_menu":2,"count":1}]	7378	delivery	5	19
92304	2020-07-08 09:27:37	2020-07-08	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	35934	delivery	5	22
92305	2020-07-08 09:32:44	2020-07-08	9	[{"id_menu":7,"count":1}]	2855	pick-up	0	9
92306	2020-07-08 09:32:52	2020-07-08	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	26739	pick-up	0	29
92307	2020-07-08 09:33:59	2020-07-08	17	[{"id_menu":4,"count":2}]	5621	delivery	5	22
92308	2020-07-08 09:34:02	2020-07-08	9	[{"id_menu":6,"count":1}]	19625	delivery	5	14
92309	2020-07-08 09:38:21	2020-07-08	9	[{"id_menu":7,"count":1}]	24070	pick-up	0	9
92310	2020-07-08 09:43:50	2020-07-08	9	[{"id_menu":6,"count":1}]	4644	pick-up	0	9
92311	2020-07-08 09:43:56	2020-07-08	14	[{"id_menu":2,"count":1}]	29960	delivery	5	19
92312	2020-07-08 09:46:56	2020-07-08	9	[{"id_menu":7,"count":1}]	18758	pick-up	0	9
92313	2020-07-08 09:47:28	2020-07-08	9	[{"id_menu":7,"count":1}]	35995	delivery	5	14
92314	2020-07-08 09:50:02	2020-07-08	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	35833	delivery	5	34
92315	2020-07-08 09:50:52	2020-07-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	33015	pick-up	0	23
92316	2020-07-08 09:54:33	2020-07-08	17	[{"id_menu":4,"count":1}]	35903	delivery	5	22
92317	2020-07-08 09:55:04	2020-07-08	9	[{"id_menu":6,"count":1}]	35929	delivery	5	14
92318	2020-07-08 09:56:26	2020-07-08	9	[{"id_menu":6,"count":1}]	11054	delivery	5	14
92319	2020-07-08 09:58:21	2020-07-08	9	[{"id_menu":6,"count":1}]	8512	delivery	5	14
92320	2020-07-08 10:00:00	2020-07-08	8	[{"id_menu":5,"count":3}]	27748	delivery	5	13
92321	2020-07-08 10:00:07	2020-07-08	14	[{"id_menu":2,"count":1}]	29196	pick-up	0	14
92322	2020-07-08 10:00:30	2020-07-08	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	7971	delivery	5	34
92323	2020-07-08 10:03:50	2020-07-08	9	[{"id_menu":6,"count":1}]	338	pick-up	0	9
92324	2020-07-08 10:04:39	2020-07-08	9	[{"id_menu":6,"count":1}]	3365	pick-up	0	9
92325	2020-07-08 10:07:27	2020-07-08	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	32649	pick-up	0	26
92326	2020-07-08 10:21:46	2020-07-08	14	[{"id_menu":2,"count":1}]	24573	delivery	5	19
92327	2020-07-08 10:22:11	2020-07-08	17	[{"id_menu":4,"count":1}]	20196	delivery	5	22
92328	2020-07-08 10:24:19	2020-07-08	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	30704	pick-up	0	35
92329	2020-07-08 10:26:09	2020-07-08	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35982	delivery	5	37
92330	2020-07-08 10:26:37	2020-07-08	17	[{"id_menu":4,"count":1}]	9436	delivery	5	22
92331	2020-07-08 10:26:43	2020-07-08	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	21562	delivery	5	26
92332	2020-07-08 10:32:22	2020-07-08	14	[{"id_menu":2,"count":1}]	31963	delivery	5	19
92333	2020-07-08 10:32:54	2020-07-08	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12367	pick-up	0	31
92334	2020-07-08 10:32:58	2020-07-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	30045	pick-up	0	23
92335	2020-07-08 10:37:45	2020-07-08	22	[{"id_menu":2,"count":3},{"id_menu":5,"count":1}]	35858	delivery	5	27
92336	2020-07-08 10:40:58	2020-07-08	14	[{"id_menu":2,"count":1}]	27919	delivery	5	19
92337	2020-07-08 10:42:31	2020-07-08	17	[{"id_menu":5,"count":3},{"id_menu":6,"count":1}]	35990	delivery	5	22
92338	2020-07-08 10:44:08	2020-07-08	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	34877	delivery	5	40
92339	2020-07-08 10:44:28	2020-07-08	14	[{"id_menu":2,"count":1}]	35821	delivery	5	19
92340	2020-07-08 10:48:47	2020-07-08	9	[{"id_menu":7,"count":1}]	16585	delivery	5	14
92341	2020-07-08 10:54:26	2020-07-08	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	35879	delivery	5	26
92342	2020-07-08 10:55:24	2020-07-08	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	35971	delivery	5	34
92343	2020-07-08 11:00:33	2020-07-08	12	[{"id_menu":3,"count":1}]	35806	pick-up	0	12
92344	2020-07-08 11:00:46	2020-07-08	9	[{"id_menu":7,"count":2}]	33642	delivery	5	14
92345	2020-07-08 11:02:23	2020-07-08	8	[{"id_menu":5,"count":1}]	35873	delivery	5	13
92346	2020-07-08 11:06:54	2020-07-08	12	[{"id_menu":3,"count":1}]	36013	delivery	5	17
92347	2020-07-08 11:10:36	2020-07-08	9	[{"id_menu":7,"count":1}]	18244	delivery	5	14
92348	2020-07-08 11:10:50	2020-07-08	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	11078	delivery	5	26
92349	2020-07-08 11:13:20	2020-07-08	8	[{"id_menu":5,"count":1}]	23509	pick-up	0	8
92350	2020-07-08 11:14:04	2020-07-08	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	35866	delivery	5	31
92351	2020-07-08 11:15:38	2020-07-08	14	[{"id_menu":2,"count":1}]	23500	pick-up	0	14
92352	2020-07-08 11:16:37	2020-07-08	8	[{"id_menu":5,"count":1}]	34640	delivery	5	13
92353	2020-07-08 11:16:41	2020-07-08	9	[{"id_menu":6,"count":1}]	31735	pick-up	0	9
92354	2020-07-08 11:16:59	2020-07-08	14	[{"id_menu":2,"count":1}]	33673	delivery	5	19
92355	2020-07-08 11:20:44	2020-07-08	9	[{"id_menu":6,"count":1}]	35851	delivery	5	14
92356	2020-07-08 11:24:39	2020-07-08	17	[{"id_menu":4,"count":1}]	21553	pick-up	0	17
92357	2020-07-08 11:25:36	2020-07-08	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23433	delivery	5	37
92358	2020-07-08 11:29:27	2020-07-08	9	[{"id_menu":6,"count":1}]	36003	delivery	5	14
92359	2020-07-08 11:32:25	2020-07-08	12	[{"id_menu":3,"count":1}]	18384	pick-up	0	12
92360	2020-07-08 11:33:34	2020-07-08	12	[{"id_menu":1,"count":1}]	3600	delivery	5	17
92361	2020-07-08 11:34:14	2020-07-08	12	[{"id_menu":1,"count":1}]	4116	delivery	5	17
92362	2020-07-08 11:35:49	2020-07-08	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	35498	delivery	5	31
92363	2020-07-08 11:39:11	2020-07-08	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	35930	delivery	5	22
92364	2020-07-08 11:43:47	2020-07-08	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	6578	delivery	5	26
92365	2020-07-08 11:48:44	2020-07-08	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3934	delivery	5	34
92366	2020-07-08 11:48:58	2020-07-08	9	[{"id_menu":7,"count":1}]	31596	pick-up	0	9
92367	2020-07-08 11:54:26	2020-07-08	14	[{"id_menu":2,"count":1}]	7603	pick-up	0	14
92368	2020-07-08 12:00:20	2020-07-08	12	[{"id_menu":3,"count":1}]	10909	delivery	5	17
92369	2020-07-08 12:02:51	2020-07-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	24284	pick-up	0	23
92370	2020-07-08 12:03:56	2020-07-08	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35939	delivery	5	37
92371	2020-07-08 12:08:54	2020-07-08	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	26821	pick-up	0	32
92372	2020-07-08 12:08:55	2020-07-08	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12482	delivery	5	22
92373	2020-07-08 12:09:23	2020-07-08	8	[{"id_menu":5,"count":1}]	27846	delivery	5	13
92374	2020-07-08 12:15:13	2020-07-08	17	[{"id_menu":4,"count":1}]	35915	delivery	5	22
92375	2020-07-08 12:17:10	2020-07-08	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35925	delivery	5	35
92376	2020-07-08 12:18:54	2020-07-08	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6729	delivery	5	31
92377	2020-07-08 12:24:07	2020-07-08	9	[{"id_menu":6,"count":1}]	36008	delivery	5	14
92378	2020-07-08 12:24:26	2020-07-08	12	[{"id_menu":3,"count":1}]	14573	pick-up	0	12
92379	2020-07-08 12:28:36	2020-07-08	9	[{"id_menu":6,"count":1}]	24471	pick-up	0	9
92380	2020-07-08 12:29:06	2020-07-08	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	10513	delivery	5	27
92381	2020-07-08 12:32:03	2020-07-08	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	7220	delivery	5	26
92382	2020-07-08 12:33:00	2020-07-08	9	[{"id_menu":6,"count":1}]	31926	delivery	5	14
92383	2020-07-08 12:34:20	2020-07-08	9	[{"id_menu":6,"count":1}]	35835	delivery	5	14
92384	2020-07-08 12:35:10	2020-07-08	12	[{"id_menu":3,"count":1}]	34594	delivery	5	17
92385	2020-07-08 12:36:15	2020-07-08	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	18567	delivery	5	31
92386	2020-07-08 12:42:23	2020-07-08	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	18740	delivery	5	43
92387	2020-07-08 12:47:15	2020-07-08	14	[{"id_menu":2,"count":1}]	730	delivery	5	19
92388	2020-07-08 12:52:50	2020-07-08	8	[{"id_menu":5,"count":1}]	29728	delivery	5	13
92389	2020-07-08 12:53:15	2020-07-08	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1498	delivery	5	45
92390	2020-07-08 12:57:28	2020-07-08	17	[{"id_menu":4,"count":1}]	35510	delivery	5	22
92391	2020-07-08 12:58:47	2020-07-08	12	[{"id_menu":3,"count":1}]	23763	delivery	5	17
92392	2020-07-08 12:58:57	2020-07-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	11423	delivery	5	28
92393	2020-07-08 12:59:28	2020-07-08	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7422	delivery	5	43
92394	2020-07-08 13:00:03	2020-07-08	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2277	pick-up	0	25
92395	2020-07-08 13:02:32	2020-07-08	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20853	delivery	5	51
92396	2020-07-08 13:03:06	2020-07-08	9	[{"id_menu":7,"count":1}]	7572	pick-up	0	9
92397	2020-07-08 13:03:25	2020-07-08	9	[{"id_menu":6,"count":1}]	35868	delivery	5	14
92398	2020-07-08 13:04:32	2020-07-08	17	[{"id_menu":4,"count":1}]	16110	pick-up	0	17
92399	2020-07-08 13:06:53	2020-07-08	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	35842	delivery	5	23
92400	2020-07-08 13:07:20	2020-07-08	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	35884	pick-up	0	26
92401	2020-07-08 13:11:56	2020-07-08	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	14635	delivery	5	26
92402	2020-07-08 13:12:01	2020-07-08	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	22705	delivery	5	25
92403	2020-07-08 13:12:39	2020-07-08	8	[{"id_menu":5,"count":1}]	22048	delivery	5	13
92404	2020-07-08 13:13:15	2020-07-08	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22403	delivery	5	35
92405	2020-07-08 13:13:18	2020-07-08	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	35967	delivery	5	26
92406	2020-07-08 13:13:26	2020-07-08	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	35844	delivery	5	26
92407	2020-07-08 13:13:50	2020-07-08	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26797	delivery	5	43
92408	2020-07-08 13:14:03	2020-07-08	12	[{"id_menu":3,"count":1}]	35912	delivery	5	17
92409	2020-07-08 13:18:56	2020-07-08	9	[{"id_menu":6,"count":1}]	36005	delivery	5	14
92410	2020-07-08 13:18:57	2020-07-08	14	[{"id_menu":2,"count":1}]	25089	delivery	5	19
92411	2020-07-08 13:19:36	2020-07-08	9	[{"id_menu":6,"count":1}]	4060	delivery	5	14
92412	2020-07-08 13:20:20	2020-07-08	12	[{"id_menu":3,"count":1}]	7264	delivery	5	17
92413	2020-07-08 13:22:44	2020-07-08	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	26239	pick-up	0	22
92414	2020-07-08 13:23:41	2020-07-08	17	[{"id_menu":4,"count":1}]	35838	delivery	5	22
92415	2020-07-08 13:23:42	2020-07-08	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	32425	delivery	5	26
92416	2020-07-08 13:26:47	2020-07-08	9	[{"id_menu":6,"count":1}]	24452	pick-up	0	9
92417	2020-07-08 13:28:12	2020-07-08	12	[{"id_menu":3,"count":1}]	36007	delivery	5	17
92418	2020-07-08 13:29:23	2020-07-08	8	[{"id_menu":5,"count":1}]	9559	delivery	5	13
92419	2020-07-08 13:31:57	2020-07-08	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	4343	delivery	5	26
92420	2020-07-08 13:34:01	2020-07-08	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	6894	delivery	5	37
92421	2020-07-08 13:34:02	2020-07-08	14	[{"id_menu":2,"count":1}]	20689	delivery	5	19
92422	2020-07-08 13:39:07	2020-07-08	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	35803	delivery	5	26
92423	2020-07-08 13:41:07	2020-07-08	17	[{"id_menu":4,"count":1}]	12541	delivery	5	22
92424	2020-07-08 13:43:13	2020-07-08	12	[{"id_menu":3,"count":1}]	1526	delivery	5	17
92425	2020-07-08 13:43:52	2020-07-08	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	12959	delivery	5	31
92426	2020-07-08 13:44:02	2020-07-08	14	[{"id_menu":2,"count":1}]	8058	pick-up	0	14
92427	2020-07-08 13:44:06	2020-07-08	9	[{"id_menu":6,"count":1}]	2432	pick-up	0	9
92428	2020-07-08 13:46:52	2020-07-08	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25738	delivery	5	34
92429	2020-07-08 13:50:10	2020-07-08	14	[{"id_menu":2,"count":1}]	14652	pick-up	0	14
92430	2020-07-08 13:50:14	2020-07-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	34561	delivery	5	28
92431	2020-07-08 13:52:05	2020-07-08	8	[{"id_menu":5,"count":3}]	34805	delivery	5	13
92432	2020-07-08 13:52:39	2020-07-08	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	35828	delivery	5	40
92433	2020-07-08 13:53:13	2020-07-08	9	[{"id_menu":6,"count":2}]	15784	delivery	5	14
92434	2020-07-08 13:54:37	2020-07-08	8	[{"id_menu":5,"count":1}]	35945	delivery	5	13
92435	2020-07-08 13:57:29	2020-07-08	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	24154	delivery	5	45
92436	2020-07-08 13:59:48	2020-07-08	9	[{"id_menu":6,"count":1}]	33143	delivery	5	14
92437	2020-07-08 14:02:44	2020-07-08	8	[{"id_menu":5,"count":1}]	16304	delivery	5	13
92438	2020-07-08 14:03:17	2020-07-08	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11868	delivery	5	31
92439	2020-07-08 14:05:38	2020-07-08	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21431	delivery	5	39
92440	2020-07-08 14:10:13	2020-07-08	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	30247	delivery	5	26
92441	2020-07-08 14:13:46	2020-07-08	17	[{"id_menu":4,"count":1}]	35861	delivery	5	22
92442	2020-07-08 14:19:10	2020-07-08	8	[{"id_menu":5,"count":1}]	1938	pick-up	0	8
92443	2020-07-08 14:20:19	2020-07-08	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26431	delivery	5	43
92444	2020-07-08 14:21:07	2020-07-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	35826	delivery	5	23
92445	2020-07-08 14:22:50	2020-07-08	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7019	pick-up	0	26
92446	2020-07-08 14:23:06	2020-07-08	8	[{"id_menu":5,"count":2}]	17615	pick-up	0	8
92447	2020-07-08 14:29:18	2020-07-08	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	35943	delivery	5	48
92448	2020-07-08 14:30:44	2020-07-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6373	delivery	5	22
92449	2020-07-08 14:38:44	2020-07-08	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	35959	delivery	5	57
92450	2020-07-08 14:41:03	2020-07-08	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24246	delivery	5	39
92451	2020-07-08 14:45:14	2020-07-08	9	[{"id_menu":6,"count":1}]	17460	pick-up	0	9
92452	2020-07-08 14:49:00	2020-07-08	9	[{"id_menu":7,"count":1}]	35933	pick-up	0	9
92453	2020-07-08 14:51:52	2020-07-08	12	[{"id_menu":1,"count":1}]	4192	delivery	5	17
92454	2020-07-08 14:52:59	2020-07-08	17	[{"id_menu":4,"count":1}]	4261	delivery	5	22
92455	2020-07-08 14:54:57	2020-07-08	17	[{"id_menu":4,"count":2}]	28158	pick-up	0	17
92456	2020-07-08 14:55:28	2020-07-08	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20749	delivery	5	52
92457	2020-07-08 14:56:07	2020-07-08	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	28116	delivery	5	31
92458	2020-07-08 14:57:23	2020-07-08	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	35817	delivery	5	36
92459	2020-07-08 14:58:56	2020-07-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1174	pick-up	0	23
92460	2020-07-08 14:59:14	2020-07-08	9	[{"id_menu":7,"count":1}]	8137	pick-up	0	9
92461	2020-07-08 15:07:20	2020-07-08	8	[{"id_menu":5,"count":1}]	15220	delivery	5	13
92462	2020-07-08 15:08:37	2020-07-08	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	30627	delivery	5	53
92463	2020-07-08 15:10:49	2020-07-08	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	27973	delivery	5	29
92464	2020-07-08 15:13:37	2020-07-08	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":2}]	35926	delivery	5	36
92465	2020-07-08 15:14:06	2020-07-08	8	[{"id_menu":5,"count":1}]	14190	pick-up	0	8
92466	2020-07-08 15:14:39	2020-07-08	8	[{"id_menu":5,"count":1}]	16792	pick-up	0	8
92467	2020-07-08 15:17:59	2020-07-08	14	[{"id_menu":2,"count":1}]	20931	delivery	5	19
92468	2020-07-08 15:19:41	2020-07-08	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	25420	delivery	5	34
92469	2020-07-08 15:25:19	2020-07-08	12	[{"id_menu":3,"count":1}]	7854	pick-up	0	12
92470	2020-07-08 15:29:10	2020-07-08	12	[{"id_menu":3,"count":1}]	35816	delivery	5	17
92471	2020-07-08 15:29:12	2020-07-08	9	[{"id_menu":7,"count":1}]	8072	delivery	5	14
92472	2020-07-08 15:30:01	2020-07-08	17	[{"id_menu":4,"count":1}]	32325	pick-up	0	17
92473	2020-07-08 15:32:40	2020-07-08	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	35840	delivery	5	38
92474	2020-07-08 15:34:08	2020-07-08	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	35980	delivery	5	27
92475	2020-07-08 15:37:12	2020-07-08	12	[{"id_menu":3,"count":1}]	14679	pick-up	0	12
92476	2020-07-08 15:37:18	2020-07-08	8	[{"id_menu":5,"count":1}]	35171	delivery	5	13
92477	2020-07-08 15:41:55	2020-07-08	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	23268	delivery	5	38
92478	2020-07-08 15:43:19	2020-07-08	8	[{"id_menu":5,"count":1}]	35805	delivery	5	13
92479	2020-07-08 15:43:59	2020-07-08	17	[{"id_menu":4,"count":1}]	35841	delivery	5	22
92480	2020-07-08 15:44:01	2020-07-08	8	[{"id_menu":5,"count":1}]	3113	delivery	5	13
92481	2020-07-08 15:44:31	2020-07-08	14	[{"id_menu":2,"count":1}]	14623	delivery	5	19
92482	2020-07-08 15:45:06	2020-07-08	9	[{"id_menu":7,"count":1}]	36014	delivery	5	14
92483	2020-07-08 15:52:03	2020-07-08	9	[{"id_menu":7,"count":1}]	28057	delivery	5	14
92484	2020-07-08 15:52:21	2020-07-08	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31447	pick-up	0	34
92485	2020-07-08 15:56:20	2020-07-08	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	35891	delivery	5	36
92486	2020-07-08 16:02:11	2020-07-08	9	[{"id_menu":7,"count":1}]	21587	delivery	5	14
92487	2020-07-08 16:03:30	2020-07-08	8	[{"id_menu":5,"count":1}]	35938	delivery	5	13
92488	2020-07-08 16:06:27	2020-07-08	8	[{"id_menu":5,"count":1}]	1808	delivery	5	13
92489	2020-07-08 16:09:17	2020-07-08	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	35983	delivery	5	30
92490	2020-07-08 16:12:52	2020-07-08	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35932	delivery	5	49
92491	2020-07-08 16:13:31	2020-07-08	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	35956	pick-up	0	29
92492	2020-07-08 16:15:30	2020-07-08	12	[{"id_menu":1,"count":1}]	18650	delivery	5	17
92493	2020-07-08 16:19:25	2020-07-08	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	35882	delivery	5	25
92494	2020-07-08 16:20:15	2020-07-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	28112	delivery	5	28
92495	2020-07-08 16:20:38	2020-07-08	9	[{"id_menu":6,"count":1}]	12378	delivery	5	14
92496	2020-07-08 16:21:10	2020-07-08	14	[{"id_menu":2,"count":1}]	27422	delivery	5	19
92497	2020-07-08 16:36:51	2020-07-08	14	[{"id_menu":2,"count":1}]	17050	pick-up	0	14
92498	2020-07-08 16:37:34	2020-07-08	9	[{"id_menu":7,"count":1}]	388	pick-up	0	9
92499	2020-07-08 16:38:54	2020-07-08	8	[{"id_menu":5,"count":1}]	12709	pick-up	0	8
92500	2020-07-08 16:42:18	2020-07-08	9	[{"id_menu":7,"count":2}]	6044	delivery	5	14
92501	2020-07-08 16:42:50	2020-07-08	9	[{"id_menu":7,"count":1}]	424	pick-up	0	9
92502	2020-07-08 16:48:29	2020-07-08	12	[{"id_menu":1,"count":1}]	35839	delivery	5	17
92503	2020-07-08 16:49:18	2020-07-08	14	[{"id_menu":2,"count":1}]	35942	delivery	5	19
92504	2020-07-08 16:54:30	2020-07-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	25299	delivery	5	23
92505	2020-07-08 16:59:15	2020-07-08	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	32101	delivery	5	31
92506	2020-07-08 17:01:05	2020-07-08	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	31379	delivery	5	48
92507	2020-07-08 17:02:59	2020-07-08	14	[{"id_menu":2,"count":1}]	18954	delivery	5	19
92508	2020-07-08 17:05:20	2020-07-08	8	[{"id_menu":5,"count":1}]	36006	delivery	5	13
92509	2020-07-08 17:05:32	2020-07-08	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24411	delivery	5	36
92510	2020-07-08 17:08:24	2020-07-08	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	851	delivery	5	39
92511	2020-07-08 17:09:22	2020-07-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	35850	delivery	5	22
92512	2020-07-08 17:09:23	2020-07-08	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	22283	pick-up	0	29
92513	2020-07-08 17:11:27	2020-07-08	14	[{"id_menu":2,"count":1}]	36004	delivery	5	19
92514	2020-07-08 17:13:20	2020-07-08	9	[{"id_menu":6,"count":1}]	13441	delivery	5	14
92515	2020-07-08 17:18:52	2020-07-08	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2519	pick-up	0	25
92516	2020-07-08 17:18:56	2020-07-08	9	[{"id_menu":7,"count":1}]	35878	delivery	5	14
92517	2020-07-08 17:23:57	2020-07-08	9	[{"id_menu":7,"count":1}]	35864	delivery	5	14
92518	2020-07-08 17:24:32	2020-07-08	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	486	pick-up	0	33
92519	2020-07-08 17:26:03	2020-07-08	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	28196	delivery	5	39
92520	2020-07-08 17:26:52	2020-07-08	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35857	delivery	5	35
92521	2020-07-08 17:31:31	2020-07-08	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15907	pick-up	0	38
92522	2020-07-08 17:39:40	2020-07-08	14	[{"id_menu":2,"count":1}]	35922	delivery	5	19
92523	2020-07-08 17:42:09	2020-07-08	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	31811	delivery	5	25
92524	2020-07-08 17:48:23	2020-07-08	9	[{"id_menu":7,"count":1}]	30751	pick-up	0	9
92525	2020-07-08 17:49:08	2020-07-08	9	[{"id_menu":6,"count":1}]	36009	delivery	5	14
92526	2020-07-08 17:51:14	2020-07-08	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	35986	pick-up	0	20
92527	2020-07-08 17:52:59	2020-07-08	9	[{"id_menu":7,"count":1}]	35820	delivery	5	14
92528	2020-07-08 17:53:15	2020-07-08	17	[{"id_menu":4,"count":3}]	3451	pick-up	0	17
92529	2020-07-08 17:56:48	2020-07-08	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	22643	delivery	5	29
92530	2020-07-08 18:00:55	2020-07-08	14	[{"id_menu":2,"count":1}]	4973	pick-up	0	14
92531	2020-07-08 18:09:31	2020-07-08	8	[{"id_menu":5,"count":1}]	24716	delivery	5	13
92532	2020-07-08 18:11:42	2020-07-08	9	[{"id_menu":6,"count":2}]	2516	pick-up	0	9
92533	2020-07-08 18:11:53	2020-07-08	17	[{"id_menu":4,"count":1}]	1303	pick-up	0	17
92534	2020-07-08 18:12:32	2020-07-08	8	[{"id_menu":5,"count":1}]	2264	pick-up	0	8
92535	2020-07-08 18:15:25	2020-07-08	17	[{"id_menu":4,"count":1}]	25073	delivery	5	22
92536	2020-07-08 18:16:18	2020-07-08	8	[{"id_menu":5,"count":2}]	1756	pick-up	0	8
92537	2020-07-08 18:16:41	2020-07-08	8	[{"id_menu":5,"count":1}]	20020	delivery	5	13
92538	2020-07-08 18:24:40	2020-07-08	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19221	delivery	5	47
92539	2020-07-08 18:28:06	2020-07-08	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	35970	delivery	5	36
92540	2020-07-08 18:28:52	2020-07-08	8	[{"id_menu":5,"count":1}]	28441	delivery	5	13
92541	2020-07-08 18:30:57	2020-07-08	14	[{"id_menu":2,"count":1}]	11982	delivery	5	19
92542	2020-07-08 18:33:37	2020-07-08	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	35867	delivery	5	27
92543	2020-07-08 18:38:52	2020-07-08	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7202	delivery	5	55
92544	2020-07-08 18:39:59	2020-07-08	14	[{"id_menu":2,"count":1}]	203	delivery	5	19
92545	2020-07-08 18:40:30	2020-07-08	9	[{"id_menu":6,"count":1}]	4206	pick-up	0	9
92546	2020-07-08 18:45:18	2020-07-08	9	[{"id_menu":6,"count":1}]	36000	delivery	5	14
92547	2020-07-08 18:49:07	2020-07-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1394	pick-up	0	23
92548	2020-07-08 18:53:03	2020-07-08	9	[{"id_menu":6,"count":1}]	16858	pick-up	0	9
92549	2020-07-08 18:53:32	2020-07-08	14	[{"id_menu":2,"count":1}]	25556	delivery	5	19
92550	2020-07-08 18:54:47	2020-07-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26031	delivery	5	23
92551	2020-07-08 18:59:27	2020-07-08	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	28041	delivery	5	40
92552	2020-07-08 19:04:29	2020-07-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7300	delivery	5	28
92553	2020-07-08 19:06:50	2020-07-08	14	[{"id_menu":2,"count":1}]	23337	delivery	5	19
92554	2020-07-08 19:08:23	2020-07-08	8	[{"id_menu":5,"count":1}]	35910	delivery	5	13
92555	2020-07-08 19:13:11	2020-07-08	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	35906	pick-up	0	21
92556	2020-07-08 19:14:32	2020-07-08	17	[{"id_menu":4,"count":1}]	3329	pick-up	0	17
92557	2020-07-08 19:16:17	2020-07-08	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	25346	delivery	5	26
92558	2020-07-08 19:19:26	2020-07-08	9	[{"id_menu":7,"count":1}]	35911	delivery	5	14
92559	2020-07-08 19:20:46	2020-07-08	12	[{"id_menu":3,"count":1}]	13740	pick-up	0	12
92560	2020-07-08 19:21:42	2020-07-08	34	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	15829	pick-up	0	34
92561	2020-07-08 19:22:33	2020-07-08	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	35880	delivery	5	31
92562	2020-07-08 19:36:26	2020-07-08	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	9429	delivery	5	46
92563	2020-07-08 19:38:22	2020-07-08	12	[{"id_menu":3,"count":1}]	36012	delivery	5	17
92564	2020-07-08 19:44:26	2020-07-08	9	[{"id_menu":7,"count":1}]	27335	delivery	5	14
92565	2020-07-08 19:45:13	2020-07-08	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	25552	delivery	5	26
92566	2020-07-08 19:47:37	2020-07-08	12	[{"id_menu":3,"count":1}]	11038	delivery	5	17
92567	2020-07-08 19:50:42	2020-07-08	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2244	delivery	5	57
92568	2020-07-08 19:50:55	2020-07-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	30408	delivery	5	28
92569	2020-07-08 19:52:01	2020-07-08	9	[{"id_menu":7,"count":1}]	27538	delivery	5	14
92570	2020-07-08 19:52:13	2020-07-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	35875	delivery	5	28
92571	2020-07-08 19:52:15	2020-07-08	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	15350	delivery	5	25
92572	2020-07-08 19:52:50	2020-07-08	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	35977	delivery	5	38
92573	2020-07-08 19:55:05	2020-07-08	14	[{"id_menu":2,"count":1}]	26989	delivery	5	19
92574	2020-07-08 19:56:00	2020-07-08	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	30878	delivery	5	31
92575	2020-07-08 19:57:57	2020-07-08	9	[{"id_menu":6,"count":2}]	17566	delivery	5	14
92576	2020-07-08 20:00:11	2020-07-08	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	19432	delivery	5	28
92577	2020-07-08 20:01:16	2020-07-08	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	10106	delivery	5	26
92578	2020-07-08 20:04:40	2020-07-08	8	[{"id_menu":5,"count":1}]	35981	delivery	5	13
92579	2020-07-08 20:07:02	2020-07-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	35984	delivery	5	28
92580	2020-07-08 20:07:29	2020-07-08	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	31647	delivery	5	25
92581	2020-07-08 20:08:17	2020-07-08	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	28880	delivery	5	34
92582	2020-07-08 20:10:38	2020-07-08	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	6787	delivery	5	26
92583	2020-07-08 20:10:41	2020-07-08	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1263	delivery	5	34
92584	2020-07-08 20:12:04	2020-07-08	17	[{"id_menu":4,"count":1}]	35847	delivery	5	22
92585	2020-07-08 20:16:29	2020-07-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7279	delivery	5	28
92586	2020-07-08 20:21:26	2020-07-08	9	[{"id_menu":7,"count":1}]	35954	delivery	5	14
92587	2020-07-08 20:21:31	2020-07-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	26788	delivery	5	28
92588	2020-07-08 20:22:07	2020-07-08	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	35845	delivery	5	29
92589	2020-07-08 20:31:52	2020-07-08	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	2965	delivery	5	31
92590	2020-07-08 20:31:53	2020-07-08	9	[{"id_menu":6,"count":1}]	11854	delivery	5	14
92591	2020-07-08 20:33:03	2020-07-08	8	[{"id_menu":5,"count":1}]	22706	delivery	5	13
92592	2020-07-08 20:34:09	2020-07-08	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2891	pick-up	0	39
92593	2020-07-08 20:34:50	2020-07-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	35916	delivery	5	28
92594	2020-07-08 20:41:14	2020-07-08	12	[{"id_menu":1,"count":1}]	35886	delivery	5	17
92595	2020-07-08 20:41:34	2020-07-08	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	35897	delivery	5	45
92596	2020-07-08 20:43:29	2020-07-08	9	[{"id_menu":6,"count":1}]	35972	pick-up	0	9
92597	2020-07-08 20:45:19	2020-07-08	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	7114	delivery	5	26
92598	2020-07-08 20:52:11	2020-07-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35946	delivery	5	23
92599	2020-07-08 20:54:23	2020-07-08	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	35335	pick-up	0	26
92600	2020-07-08 20:55:43	2020-07-08	12	[{"id_menu":3,"count":1}]	22941	delivery	5	17
92601	2020-07-08 21:07:26	2020-07-08	9	[{"id_menu":6,"count":1}]	2868	delivery	5	14
92602	2020-07-08 21:07:45	2020-07-08	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14406	pick-up	0	17
92603	2020-07-08 21:12:50	2020-07-08	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	8916	pick-up	0	21
92604	2020-07-08 21:19:03	2020-07-08	9	[{"id_menu":6,"count":1}]	22273	delivery	5	14
92605	2020-07-08 21:19:51	2020-07-08	9	[{"id_menu":6,"count":1}]	35895	delivery	5	14
92606	2020-07-08 21:23:12	2020-07-08	9	[{"id_menu":6,"count":1}]	17412	delivery	5	14
92607	2020-07-08 21:23:53	2020-07-08	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	35872	pick-up	0	26
92608	2020-07-08 21:24:00	2020-07-08	14	[{"id_menu":2,"count":1}]	35538	delivery	5	19
92609	2020-07-08 21:29:09	2020-07-08	9	[{"id_menu":6,"count":2}]	27432	delivery	5	14
92610	2020-07-08 21:29:40	2020-07-08	9	[{"id_menu":6,"count":1}]	10203	pick-up	0	9
92611	2020-07-08 21:31:35	2020-07-08	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	13699	delivery	5	48
92612	2020-07-08 21:32:48	2020-07-08	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	19602	pick-up	0	21
92613	2020-07-08 21:34:21	2020-07-08	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	23373	delivery	5	34
92614	2020-07-08 21:35:37	2020-07-08	12	[{"id_menu":3,"count":1}]	7534	delivery	5	17
92615	2020-07-08 21:51:15	2020-07-08	17	[{"id_menu":4,"count":1}]	14350	delivery	5	22
92616	2020-07-08 21:53:51	2020-07-08	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	33846	delivery	5	36
92617	2020-07-08 21:54:29	2020-07-08	8	[{"id_menu":5,"count":2}]	8661	delivery	5	13
92618	2020-07-08 21:54:49	2020-07-08	12	[{"id_menu":1,"count":1}]	35931	delivery	5	17
92619	2020-07-08 21:57:50	2020-07-08	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19649	delivery	5	39
92620	2020-07-08 22:00:07	2020-07-08	12	[{"id_menu":3,"count":1}]	8755	delivery	5	17
92621	2020-07-08 22:08:04	2020-07-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	35902	delivery	5	22
92622	2020-07-08 22:09:27	2020-07-08	14	[{"id_menu":2,"count":1}]	35965	delivery	5	19
92623	2020-07-08 22:13:49	2020-07-08	9	[{"id_menu":6,"count":1}]	35804	delivery	5	14
92624	2020-07-08 22:20:27	2020-07-08	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7899	delivery	5	31
92625	2020-07-08 22:22:07	2020-07-08	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	35890	delivery	5	34
92626	2020-07-08 22:22:44	2020-07-08	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16753	pick-up	0	30
92627	2020-07-08 22:24:07	2020-07-08	8	[{"id_menu":5,"count":1}]	34660	delivery	5	13
92628	2020-07-08 22:31:01	2020-07-08	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	26359	delivery	5	31
92629	2020-07-08 22:32:02	2020-07-08	9	[{"id_menu":6,"count":1}]	18287	delivery	5	14
92630	2020-07-08 22:35:01	2020-07-08	17	[{"id_menu":4,"count":1}]	35812	pick-up	0	17
92631	2020-07-08 22:35:26	2020-07-08	9	[{"id_menu":6,"count":1}]	35843	delivery	5	14
92632	2020-07-08 22:40:11	2020-07-08	9	[{"id_menu":6,"count":1}]	35876	delivery	5	14
92633	2020-07-08 22:42:05	2020-07-08	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	27870	pick-up	0	26
92634	2020-07-08 22:43:40	2020-07-08	8	[{"id_menu":5,"count":1}]	29851	delivery	5	13
92635	2020-07-08 22:52:52	2020-07-08	12	[{"id_menu":3,"count":1}]	20511	delivery	5	17
92636	2020-07-08 22:53:04	2020-07-08	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	377	pick-up	0	17
92637	2020-07-08 22:55:00	2020-07-08	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	30931	delivery	5	26
92638	2020-07-08 22:56:35	2020-07-08	9	[{"id_menu":6,"count":1}]	6893	delivery	5	14
92639	2020-07-08 22:57:22	2020-07-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4902	delivery	5	28
92640	2020-07-08 23:00:05	2020-07-08	8	[{"id_menu":5,"count":1}]	15308	delivery	5	13
92641	2020-07-08 23:00:54	2020-07-08	8	[{"id_menu":5,"count":1}]	35860	delivery	5	13
92642	2020-07-08 23:01:20	2020-07-08	17	[{"id_menu":4,"count":1}]	10340	delivery	5	22
92643	2020-07-08 23:12:04	2020-07-08	9	[{"id_menu":6,"count":1}]	7297	delivery	5	14
92644	2020-07-08 23:12:36	2020-07-08	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	35924	delivery	5	43
92645	2020-07-08 23:13:28	2020-07-08	17	[{"id_menu":4,"count":1}]	33915	delivery	5	22
92646	2020-07-08 23:15:14	2020-07-08	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5129	delivery	5	34
92647	2020-07-08 23:17:17	2020-07-08	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1154	pick-up	0	37
92648	2020-07-08 23:23:13	2020-07-08	9	[{"id_menu":7,"count":2}]	16281	delivery	5	14
92649	2020-07-08 23:23:25	2020-07-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	9658	delivery	5	28
92650	2020-07-08 23:24:38	2020-07-08	12	[{"id_menu":1,"count":1}]	33444	delivery	5	17
92651	2020-07-08 23:26:04	2020-07-08	17	[{"id_menu":4,"count":1}]	21679	pick-up	0	17
92652	2020-07-08 23:27:40	2020-07-08	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	12809	delivery	5	31
92653	2020-07-08 23:28:27	2020-07-08	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	35936	delivery	5	39
92654	2020-07-08 23:28:43	2020-07-08	17	[{"id_menu":4,"count":1}]	35802	delivery	5	22
92655	2020-07-08 23:31:49	2020-07-08	9	[{"id_menu":7,"count":1}]	25925	delivery	5	14
92656	2020-07-08 23:36:04	2020-07-08	8	[{"id_menu":5,"count":1}]	35901	delivery	5	13
92657	2020-07-08 23:40:27	2020-07-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	34888	delivery	5	22
92658	2020-07-08 23:40:51	2020-07-08	17	[{"id_menu":4,"count":1}]	33730	pick-up	0	17
92659	2020-07-08 23:43:07	2020-07-08	9	[{"id_menu":7,"count":1}]	23521	pick-up	0	9
92660	2020-07-08 23:52:21	2020-07-08	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	35677	delivery	5	26
92661	2020-07-08 23:55:25	2020-07-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3612	delivery	5	22
92662	2020-07-09 00:00:03	2020-07-09	9	[{"id_menu":6,"count":1}]	10591	delivery	5	14
92663	2020-07-09 00:05:00	2020-07-09	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	31470	delivery	5	36
92664	2020-07-09 00:08:31	2020-07-09	9	[{"id_menu":7,"count":1}]	36188	pick-up	0	9
92665	2020-07-09 00:12:19	2020-07-09	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	24329	delivery	5	28
92666	2020-07-09 00:13:11	2020-07-09	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	12564	pick-up	0	26
92667	2020-07-09 00:13:31	2020-07-09	9	[{"id_menu":6,"count":2}]	6296	delivery	5	14
92668	2020-07-09 00:15:20	2020-07-09	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	13185	delivery	5	25
92669	2020-07-09 00:19:28	2020-07-09	9	[{"id_menu":6,"count":1}]	5461	pick-up	0	9
92670	2020-07-09 00:19:54	2020-07-09	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9582	delivery	5	37
92671	2020-07-09 00:20:02	2020-07-09	17	[{"id_menu":4,"count":1}]	36207	pick-up	0	17
92672	2020-07-09 00:22:28	2020-07-09	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	381	pick-up	0	20
92673	2020-07-09 00:24:33	2020-07-09	17	[{"id_menu":4,"count":1}]	30486	delivery	5	22
92674	2020-07-09 00:26:46	2020-07-09	12	[{"id_menu":3,"count":1}]	19017	pick-up	0	12
92675	2020-07-09 00:29:57	2020-07-09	12	[{"id_menu":1,"count":1}]	36129	delivery	5	17
92676	2020-07-09 00:34:53	2020-07-09	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	36081	delivery	5	34
92677	2020-07-09 00:36:50	2020-07-09	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	16426	delivery	5	29
92678	2020-07-09 00:39:32	2020-07-09	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19556	delivery	5	36
92679	2020-07-09 00:44:38	2020-07-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	28056	pick-up	0	23
92680	2020-07-09 00:49:37	2020-07-09	14	[{"id_menu":2,"count":1}]	36187	delivery	5	19
92681	2020-07-09 00:51:59	2020-07-09	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	36141	delivery	5	29
92682	2020-07-09 00:59:21	2020-07-09	14	[{"id_menu":2,"count":1}]	36052	delivery	5	19
92683	2020-07-09 01:05:28	2020-07-09	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	32133	pick-up	0	17
92684	2020-07-09 01:07:51	2020-07-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	36216	delivery	5	28
92685	2020-07-09 01:13:32	2020-07-09	17	[{"id_menu":4,"count":1}]	13690	pick-up	0	17
92686	2020-07-09 01:14:12	2020-07-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	35302	delivery	5	22
92687	2020-07-09 01:19:21	2020-07-09	8	[{"id_menu":5,"count":1}]	33330	delivery	5	13
92688	2020-07-09 01:21:30	2020-07-09	12	[{"id_menu":1,"count":1}]	36021	delivery	5	17
92689	2020-07-09 01:25:50	2020-07-09	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	8050	delivery	5	40
92690	2020-07-09 01:28:50	2020-07-09	9	[{"id_menu":7,"count":1}]	9394	delivery	5	14
92691	2020-07-09 01:36:40	2020-07-09	8	[{"id_menu":5,"count":2}]	35343	delivery	5	13
92692	2020-07-09 01:36:53	2020-07-09	8	[{"id_menu":5,"count":1}]	6341	delivery	5	13
92693	2020-07-09 01:37:29	2020-07-09	8	[{"id_menu":5,"count":1}]	36224	delivery	5	13
92694	2020-07-09 01:43:10	2020-07-09	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	22228	pick-up	0	26
92695	2020-07-09 01:44:33	2020-07-09	9	[{"id_menu":6,"count":1}]	13930	pick-up	0	9
92696	2020-07-09 01:45:57	2020-07-09	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8785	delivery	5	31
92697	2020-07-09 01:48:31	2020-07-09	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	24449	delivery	5	30
92698	2020-07-09 01:54:16	2020-07-09	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	36136	delivery	5	31
92699	2020-07-09 01:56:40	2020-07-09	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	7046	pick-up	0	21
92700	2020-07-09 01:58:52	2020-07-09	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	36117	delivery	5	34
92701	2020-07-09 02:03:26	2020-07-09	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	13681	delivery	5	34
92702	2020-07-09 02:04:08	2020-07-09	9	[{"id_menu":7,"count":1}]	5004	delivery	5	14
92703	2020-07-09 02:10:15	2020-07-09	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	36049	delivery	5	34
92704	2020-07-09 02:10:16	2020-07-09	12	[{"id_menu":3,"count":1}]	24023	pick-up	0	12
92705	2020-07-09 02:12:40	2020-07-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":3}]	36041	delivery	5	28
92706	2020-07-09 02:25:54	2020-07-09	8	[{"id_menu":5,"count":1}]	14003	delivery	5	13
92707	2020-07-09 02:26:26	2020-07-09	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	6901	pick-up	0	38
92708	2020-07-09 02:26:39	2020-07-09	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	22042	delivery	5	31
92709	2020-07-09 02:30:42	2020-07-09	14	[{"id_menu":2,"count":1}]	16870	delivery	5	19
92710	2020-07-09 02:33:21	2020-07-09	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	4760	delivery	5	37
92711	2020-07-09 02:34:05	2020-07-09	17	[{"id_menu":4,"count":1}]	33706	pick-up	0	17
92712	2020-07-09 02:34:59	2020-07-09	9	[{"id_menu":7,"count":2}]	1273	pick-up	0	9
92713	2020-07-09 02:37:12	2020-07-09	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	14545	delivery	5	31
92714	2020-07-09 02:45:31	2020-07-09	14	[{"id_menu":2,"count":1}]	20000	delivery	5	19
92715	2020-07-09 02:47:14	2020-07-09	9	[{"id_menu":7,"count":1}]	22197	delivery	5	14
92716	2020-07-09 02:51:41	2020-07-09	17	[{"id_menu":4,"count":1}]	24534	pick-up	0	17
92717	2020-07-09 02:55:56	2020-07-09	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	23688	delivery	5	31
92718	2020-07-09 02:58:49	2020-07-09	8	[{"id_menu":5,"count":1}]	1966	delivery	5	13
92719	2020-07-09 03:00:02	2020-07-09	8	[{"id_menu":5,"count":2}]	24468	delivery	5	13
92720	2020-07-09 03:00:35	2020-07-09	14	[{"id_menu":2,"count":1}]	36098	delivery	5	19
92721	2020-07-09 03:03:09	2020-07-09	9	[{"id_menu":7,"count":1}]	6235	pick-up	0	9
92722	2020-07-09 03:03:13	2020-07-09	12	[{"id_menu":3,"count":1}]	4873	delivery	5	17
92723	2020-07-09 03:05:34	2020-07-09	8	[{"id_menu":5,"count":2}]	11341	delivery	5	13
92724	2020-07-09 03:05:42	2020-07-09	17	[{"id_menu":4,"count":1}]	3052	pick-up	0	17
92725	2020-07-09 03:12:11	2020-07-09	12	[{"id_menu":3,"count":2}]	36130	pick-up	0	12
92726	2020-07-09 03:14:37	2020-07-09	14	[{"id_menu":2,"count":1}]	13120	delivery	5	19
92727	2020-07-09 03:14:40	2020-07-09	9	[{"id_menu":7,"count":1}]	8927	delivery	5	14
92728	2020-07-09 03:17:15	2020-07-09	9	[{"id_menu":6,"count":1}]	14190	pick-up	0	9
92729	2020-07-09 03:18:28	2020-07-09	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	36227	delivery	5	30
92730	2020-07-09 03:19:48	2020-07-09	9	[{"id_menu":6,"count":2}]	17784	pick-up	0	9
92731	2020-07-09 03:20:28	2020-07-09	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	36225	delivery	5	51
92732	2020-07-09 03:21:09	2020-07-09	17	[{"id_menu":4,"count":1}]	527	pick-up	0	17
92733	2020-07-09 03:23:44	2020-07-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8669	delivery	5	23
92734	2020-07-09 03:25:01	2020-07-09	17	[{"id_menu":4,"count":1}]	36128	delivery	5	22
92735	2020-07-09 03:25:53	2020-07-09	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	36240	delivery	5	23
92736	2020-07-09 03:27:44	2020-07-09	9	[{"id_menu":6,"count":1}]	4054	delivery	5	14
92737	2020-07-09 03:28:43	2020-07-09	9	[{"id_menu":7,"count":1}]	8394	delivery	5	14
92738	2020-07-09 03:28:52	2020-07-09	12	[{"id_menu":1,"count":1}]	13144	pick-up	0	12
92739	2020-07-09 03:29:01	2020-07-09	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3946	pick-up	0	21
92740	2020-07-09 03:31:27	2020-07-09	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30620	delivery	5	48
92741	2020-07-09 03:34:49	2020-07-09	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	28211	delivery	5	31
92742	2020-07-09 03:37:09	2020-07-09	14	[{"id_menu":2,"count":1}]	1949	pick-up	0	14
92743	2020-07-09 03:38:09	2020-07-09	12	[{"id_menu":1,"count":1}]	16084	pick-up	0	12
92744	2020-07-09 03:39:53	2020-07-09	12	[{"id_menu":3,"count":1}]	32810	pick-up	0	12
92745	2020-07-09 03:44:27	2020-07-09	9	[{"id_menu":7,"count":1}]	20339	delivery	5	14
92746	2020-07-09 03:45:57	2020-07-09	9	[{"id_menu":7,"count":1}]	5786	delivery	5	14
92747	2020-07-09 03:48:16	2020-07-09	12	[{"id_menu":3,"count":1}]	74	pick-up	0	12
92748	2020-07-09 03:48:34	2020-07-09	14	[{"id_menu":2,"count":1}]	32581	delivery	5	19
92749	2020-07-09 03:51:19	2020-07-09	12	[{"id_menu":1,"count":1}]	2052	pick-up	0	12
92750	2020-07-09 03:52:11	2020-07-09	9	[{"id_menu":6,"count":1}]	5368	delivery	5	14
92751	2020-07-09 03:54:17	2020-07-09	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	8756	delivery	5	25
92752	2020-07-09 03:56:02	2020-07-09	17	[{"id_menu":4,"count":1}]	27656	delivery	5	22
92753	2020-07-09 04:00:02	2020-07-09	14	[{"id_menu":2,"count":1}]	29544	delivery	5	19
92754	2020-07-09 04:00:10	2020-07-09	17	[{"id_menu":4,"count":1}]	32491	pick-up	0	17
92755	2020-07-09 04:01:31	2020-07-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1494	delivery	5	22
92756	2020-07-09 04:01:44	2020-07-09	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10349	delivery	5	52
92757	2020-07-09 04:03:21	2020-07-09	12	[{"id_menu":1,"count":1}]	36213	delivery	5	17
92758	2020-07-09 04:05:49	2020-07-09	9	[{"id_menu":6,"count":1}]	23756	delivery	5	14
92759	2020-07-09 04:08:28	2020-07-09	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28961	delivery	5	40
92760	2020-07-09 04:08:42	2020-07-09	12	[{"id_menu":1,"count":1}]	36062	delivery	5	17
92761	2020-07-09 04:10:01	2020-07-09	14	[{"id_menu":2,"count":1}]	543	pick-up	0	14
92762	2020-07-09 04:11:13	2020-07-09	9	[{"id_menu":6,"count":1}]	7891	pick-up	0	9
92763	2020-07-09 04:13:05	2020-07-09	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	26427	delivery	5	57
92764	2020-07-09 04:15:06	2020-07-09	9	[{"id_menu":6,"count":1}]	34015	delivery	5	14
92765	2020-07-09 04:17:43	2020-07-09	9	[{"id_menu":6,"count":1}]	36214	delivery	5	14
92766	2020-07-09 04:19:00	2020-07-09	9	[{"id_menu":7,"count":1}]	36077	delivery	5	14
92767	2020-07-09 04:21:10	2020-07-09	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	29394	pick-up	0	21
92768	2020-07-09 04:22:41	2020-07-09	9	[{"id_menu":6,"count":1}]	20122	delivery	5	14
92769	2020-07-09 04:22:51	2020-07-09	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	6046	pick-up	0	35
92770	2020-07-09 04:24:08	2020-07-09	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	36125	delivery	5	42
92771	2020-07-09 04:28:21	2020-07-09	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	21173	delivery	5	40
92772	2020-07-09 04:28:25	2020-07-09	9	[{"id_menu":7,"count":1}]	5871	delivery	5	14
92773	2020-07-09 04:29:00	2020-07-09	9	[{"id_menu":7,"count":1}]	36157	delivery	5	14
92774	2020-07-09 04:29:23	2020-07-09	14	[{"id_menu":2,"count":1}]	7201	pick-up	0	14
92775	2020-07-09 04:29:59	2020-07-09	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	34796	delivery	5	37
92776	2020-07-09 04:30:13	2020-07-09	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16320	delivery	5	43
92777	2020-07-09 04:33:12	2020-07-09	8	[{"id_menu":5,"count":1}]	29632	delivery	5	13
92778	2020-07-09 04:35:36	2020-07-09	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	36114	delivery	5	31
92779	2020-07-09 04:38:25	2020-07-09	17	[{"id_menu":4,"count":1}]	36040	delivery	5	22
92780	2020-07-09 04:39:13	2020-07-09	12	[{"id_menu":1,"count":1}]	36090	delivery	5	17
92781	2020-07-09 04:51:26	2020-07-09	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	19445	delivery	5	31
92782	2020-07-09 04:51:27	2020-07-09	14	[{"id_menu":2,"count":1}]	36024	pick-up	0	14
92783	2020-07-09 04:52:08	2020-07-09	9	[{"id_menu":6,"count":1}]	9943	delivery	5	14
92784	2020-07-09 04:53:44	2020-07-09	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	20579	delivery	5	34
92785	2020-07-09 04:58:11	2020-07-09	17	[{"id_menu":4,"count":1}]	27178	delivery	5	22
92786	2020-07-09 04:59:14	2020-07-09	14	[{"id_menu":2,"count":1}]	31666	pick-up	0	14
92787	2020-07-09 04:59:28	2020-07-09	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	36237	delivery	5	40
92788	2020-07-09 05:03:35	2020-07-09	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9273	delivery	5	31
92789	2020-07-09 05:05:30	2020-07-09	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2783	pick-up	0	26
92790	2020-07-09 05:08:00	2020-07-09	12	[{"id_menu":1,"count":1}]	547	delivery	5	17
92791	2020-07-09 05:09:34	2020-07-09	9	[{"id_menu":7,"count":1}]	36063	delivery	5	14
92792	2020-07-09 05:13:51	2020-07-09	46	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	25259	delivery	5	51
92793	2020-07-09 05:15:43	2020-07-09	9	[{"id_menu":6,"count":1}]	36080	pick-up	0	9
92794	2020-07-09 05:17:03	2020-07-09	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	36075	delivery	5	27
92795	2020-07-09 05:19:28	2020-07-09	9	[{"id_menu":7,"count":1}]	36031	delivery	5	14
92796	2020-07-09 05:21:40	2020-07-09	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	36132	delivery	5	31
92797	2020-07-09 05:23:31	2020-07-09	9	[{"id_menu":7,"count":2}]	6116	delivery	5	14
92798	2020-07-09 05:24:23	2020-07-09	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	36191	delivery	5	31
92799	2020-07-09 05:24:52	2020-07-09	12	[{"id_menu":1,"count":1}]	36165	delivery	5	17
92800	2020-07-09 05:26:39	2020-07-09	14	[{"id_menu":2,"count":1}]	36043	delivery	5	19
92801	2020-07-09 05:27:36	2020-07-09	9	[{"id_menu":7,"count":1}]	8072	delivery	5	14
92802	2020-07-09 05:28:23	2020-07-09	8	[{"id_menu":5,"count":1}]	36223	delivery	5	13
92803	2020-07-09 05:29:06	2020-07-09	9	[{"id_menu":6,"count":1}]	459	delivery	5	14
92804	2020-07-09 05:29:14	2020-07-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7527	delivery	5	23
92805	2020-07-09 05:36:04	2020-07-09	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	36045	pick-up	0	37
92806	2020-07-09 05:36:59	2020-07-09	14	[{"id_menu":2,"count":1}]	36058	delivery	5	19
92807	2020-07-09 05:38:29	2020-07-09	17	[{"id_menu":4,"count":1}]	25034	delivery	5	22
92808	2020-07-09 05:43:09	2020-07-09	9	[{"id_menu":6,"count":1}]	13707	pick-up	0	9
92809	2020-07-09 05:45:25	2020-07-09	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	36032	delivery	5	27
92810	2020-07-09 05:49:37	2020-07-09	9	[{"id_menu":7,"count":1}]	23118	delivery	5	14
92811	2020-07-09 05:49:57	2020-07-09	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	36089	delivery	5	36
92812	2020-07-09 05:52:34	2020-07-09	14	[{"id_menu":2,"count":1}]	6941	pick-up	0	14
92813	2020-07-09 05:57:42	2020-07-09	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	5310	pick-up	0	29
92814	2020-07-09 05:58:07	2020-07-09	14	[{"id_menu":2,"count":1}]	12144	delivery	5	19
92815	2020-07-09 05:58:52	2020-07-09	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	23665	delivery	5	31
92816	2020-07-09 05:59:43	2020-07-09	17	[{"id_menu":4,"count":2}]	23676	delivery	5	22
92817	2020-07-09 06:00:05	2020-07-09	14	[{"id_menu":2,"count":1}]	14984	delivery	5	19
92818	2020-07-09 06:02:08	2020-07-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36196	delivery	5	23
92819	2020-07-09 06:05:36	2020-07-09	17	[{"id_menu":4,"count":1}]	34209	delivery	5	22
92820	2020-07-09 06:14:59	2020-07-09	9	[{"id_menu":6,"count":1}]	20002	delivery	5	14
92821	2020-07-09 06:16:12	2020-07-09	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	5648	pick-up	0	34
92822	2020-07-09 06:18:17	2020-07-09	17	[{"id_menu":4,"count":1}]	25580	pick-up	0	17
92823	2020-07-09 06:19:11	2020-07-09	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	30409	pick-up	0	21
92824	2020-07-09 06:19:52	2020-07-09	9	[{"id_menu":6,"count":1}]	26272	delivery	5	14
92825	2020-07-09 06:21:58	2020-07-09	17	[{"id_menu":4,"count":1}]	36097	pick-up	0	17
92826	2020-07-09 06:24:57	2020-07-09	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	36138	delivery	5	22
92827	2020-07-09 06:26:53	2020-07-09	9	[{"id_menu":6,"count":1}]	7623	delivery	5	14
92828	2020-07-09 06:27:51	2020-07-09	17	[{"id_menu":4,"count":1}]	36215	delivery	5	22
92829	2020-07-09 06:27:54	2020-07-09	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	16914	pick-up	0	20
92830	2020-07-09 06:28:45	2020-07-09	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	32044	delivery	5	42
92831	2020-07-09 06:35:53	2020-07-09	12	[{"id_menu":1,"count":1}]	31601	delivery	5	17
92832	2020-07-09 06:38:05	2020-07-09	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	30921	pick-up	0	33
92833	2020-07-09 06:40:04	2020-07-09	17	[{"id_menu":4,"count":1}]	23831	pick-up	0	17
92834	2020-07-09 06:41:05	2020-07-09	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23870	delivery	5	36
92835	2020-07-09 06:41:26	2020-07-09	12	[{"id_menu":3,"count":1}]	36055	delivery	5	17
92836	2020-07-09 06:41:51	2020-07-09	9	[{"id_menu":7,"count":1}]	36139	delivery	5	14
92837	2020-07-09 06:41:57	2020-07-09	9	[{"id_menu":6,"count":1}]	3545	delivery	5	14
92838	2020-07-09 06:47:27	2020-07-09	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24171	delivery	5	51
92839	2020-07-09 06:56:27	2020-07-09	9	[{"id_menu":7,"count":1}]	36047	delivery	5	14
92840	2020-07-09 06:56:55	2020-07-09	12	[{"id_menu":3,"count":1}]	35546	delivery	5	17
92841	2020-07-09 06:56:57	2020-07-09	8	[{"id_menu":5,"count":2}]	7877	delivery	5	13
92842	2020-07-09 06:59:38	2020-07-09	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":3}]	36028	delivery	5	26
92843	2020-07-09 07:00:26	2020-07-09	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":2}]	36145	delivery	5	28
92844	2020-07-09 07:01:38	2020-07-09	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	35691	delivery	5	27
92845	2020-07-09 07:03:31	2020-07-09	9	[{"id_menu":6,"count":1}]	24018	pick-up	0	9
92846	2020-07-09 07:03:56	2020-07-09	9	[{"id_menu":7,"count":1}]	16514	delivery	5	14
92847	2020-07-09 07:06:23	2020-07-09	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23982	delivery	5	39
92848	2020-07-09 07:09:14	2020-07-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23494	delivery	5	23
92849	2020-07-09 07:17:17	2020-07-09	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	24889	delivery	5	31
92850	2020-07-09 07:29:21	2020-07-09	9	[{"id_menu":7,"count":1}]	353	delivery	5	14
92851	2020-07-09 07:29:53	2020-07-09	12	[{"id_menu":3,"count":1}]	4976	delivery	5	17
92852	2020-07-09 07:35:27	2020-07-09	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	17154	delivery	5	31
92853	2020-07-09 07:36:24	2020-07-09	8	[{"id_menu":5,"count":1}]	36241	delivery	5	13
92854	2020-07-09 07:38:35	2020-07-09	9	[{"id_menu":7,"count":1}]	36085	delivery	5	14
92855	2020-07-09 07:40:18	2020-07-09	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30156	delivery	5	45
92856	2020-07-09 07:47:50	2020-07-09	9	[{"id_menu":7,"count":1}]	4594	delivery	5	14
92857	2020-07-09 07:49:49	2020-07-09	9	[{"id_menu":7,"count":1}]	32119	delivery	5	14
92858	2020-07-09 07:50:05	2020-07-09	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8521	pick-up	0	38
92859	2020-07-09 07:52:59	2020-07-09	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	32344	delivery	5	26
92860	2020-07-09 07:55:48	2020-07-09	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2608	delivery	5	26
92861	2020-07-09 07:59:03	2020-07-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	36069	delivery	5	22
92862	2020-07-09 07:59:50	2020-07-09	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	13615	delivery	5	34
92863	2020-07-09 08:03:35	2020-07-09	9	[{"id_menu":6,"count":1}]	12297	delivery	5	14
92864	2020-07-09 08:04:03	2020-07-09	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14781	delivery	5	34
92865	2020-07-09 08:08:14	2020-07-09	17	[{"id_menu":4,"count":1}]	36022	delivery	5	22
92866	2020-07-09 08:09:04	2020-07-09	9	[{"id_menu":7,"count":1}]	29550	delivery	5	14
92867	2020-07-09 08:09:58	2020-07-09	9	[{"id_menu":7,"count":1}]	36071	delivery	5	14
92868	2020-07-09 08:12:31	2020-07-09	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9384	delivery	5	22
92869	2020-07-09 08:13:42	2020-07-09	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	36074	delivery	5	36
92870	2020-07-09 08:20:07	2020-07-09	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	22983	pick-up	0	21
92871	2020-07-09 08:21:37	2020-07-09	9	[{"id_menu":7,"count":1}]	287	pick-up	0	9
92872	2020-07-09 08:22:47	2020-07-09	9	[{"id_menu":6,"count":1}]	6969	delivery	5	14
92873	2020-07-09 08:23:53	2020-07-09	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11225	pick-up	0	26
92874	2020-07-09 08:31:05	2020-07-09	14	[{"id_menu":2,"count":1}]	27110	delivery	5	19
92875	2020-07-09 08:31:10	2020-07-09	38	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	26304	delivery	5	43
92876	2020-07-09 08:32:05	2020-07-09	14	[{"id_menu":2,"count":1}]	36126	pick-up	0	14
92877	2020-07-09 08:39:02	2020-07-09	14	[{"id_menu":2,"count":1}]	294	pick-up	0	14
92878	2020-07-09 08:42:04	2020-07-09	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1301	delivery	5	36
92879	2020-07-09 08:43:23	2020-07-09	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	36048	delivery	5	44
92880	2020-07-09 08:43:42	2020-07-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6426	delivery	5	23
92881	2020-07-09 08:44:04	2020-07-09	14	[{"id_menu":2,"count":1}]	21483	delivery	5	19
92882	2020-07-09 08:46:00	2020-07-09	8	[{"id_menu":5,"count":1}]	33523	delivery	5	13
92883	2020-07-09 08:48:51	2020-07-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	36218	delivery	5	22
92884	2020-07-09 08:50:08	2020-07-09	8	[{"id_menu":5,"count":1}]	17310	delivery	5	13
92885	2020-07-09 08:53:13	2020-07-09	14	[{"id_menu":2,"count":1}]	4846	pick-up	0	14
92886	2020-07-09 08:55:07	2020-07-09	9	[{"id_menu":6,"count":1}]	16484	pick-up	0	9
92887	2020-07-09 08:59:01	2020-07-09	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	36156	delivery	5	34
92888	2020-07-09 09:05:21	2020-07-09	9	[{"id_menu":6,"count":1}]	9107	delivery	5	14
92889	2020-07-09 09:05:57	2020-07-09	8	[{"id_menu":5,"count":2}]	10242	delivery	5	13
92890	2020-07-09 09:13:11	2020-07-09	12	[{"id_menu":1,"count":1}]	7109	delivery	5	17
92891	2020-07-09 09:13:27	2020-07-09	8	[{"id_menu":5,"count":1}]	21785	pick-up	0	8
92892	2020-07-09 09:17:15	2020-07-09	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36197	delivery	5	48
92893	2020-07-09 09:19:45	2020-07-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	24126	delivery	5	22
92894	2020-07-09 09:22:03	2020-07-09	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15148	delivery	5	36
92895	2020-07-09 09:22:08	2020-07-09	12	[{"id_menu":3,"count":1}]	36160	delivery	5	17
92896	2020-07-09 09:26:51	2020-07-09	12	[{"id_menu":3,"count":1}]	3487	pick-up	0	12
92897	2020-07-09 09:28:29	2020-07-09	9	[{"id_menu":6,"count":1}]	2599	delivery	5	14
92898	2020-07-09 09:31:53	2020-07-09	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	19628	delivery	5	25
92899	2020-07-09 09:37:16	2020-07-09	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	34812	delivery	5	26
92900	2020-07-09 09:43:12	2020-07-09	14	[{"id_menu":2,"count":3}]	3976	pick-up	0	14
92901	2020-07-09 09:45:49	2020-07-09	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	36061	delivery	5	34
92902	2020-07-09 09:45:54	2020-07-09	12	[{"id_menu":1,"count":1}]	36106	pick-up	0	12
92903	2020-07-09 09:47:40	2020-07-09	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	36044	delivery	5	57
92904	2020-07-09 09:50:51	2020-07-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	5506	delivery	5	28
92905	2020-07-09 09:51:03	2020-07-09	14	[{"id_menu":2,"count":1}]	5048	pick-up	0	14
92906	2020-07-09 09:51:24	2020-07-09	12	[{"id_menu":3,"count":1}]	3123	delivery	5	17
92907	2020-07-09 09:57:58	2020-07-09	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36169	delivery	5	35
92908	2020-07-09 09:58:00	2020-07-09	9	[{"id_menu":7,"count":1}]	36108	delivery	5	14
92909	2020-07-09 09:58:17	2020-07-09	12	[{"id_menu":3,"count":1}]	36185	delivery	5	17
92910	2020-07-09 10:01:15	2020-07-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	36029	pick-up	0	23
92911	2020-07-09 10:03:18	2020-07-09	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	32872	delivery	5	39
92912	2020-07-09 10:03:38	2020-07-09	9	[{"id_menu":6,"count":1}]	12688	pick-up	0	9
92913	2020-07-09 10:07:56	2020-07-09	9	[{"id_menu":7,"count":1}]	36182	pick-up	0	9
92914	2020-07-09 10:14:34	2020-07-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9915	delivery	5	23
92915	2020-07-09 10:15:16	2020-07-09	17	[{"id_menu":4,"count":1}]	10842	pick-up	0	17
92916	2020-07-09 10:15:39	2020-07-09	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	15636	delivery	5	23
92917	2020-07-09 10:17:57	2020-07-09	14	[{"id_menu":2,"count":1}]	13622	delivery	5	19
92918	2020-07-09 10:18:38	2020-07-09	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	34606	delivery	5	45
92919	2020-07-09 10:20:35	2020-07-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20261	delivery	5	23
92920	2020-07-09 10:23:31	2020-07-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	36143	delivery	5	28
92921	2020-07-09 10:27:35	2020-07-09	17	[{"id_menu":4,"count":1}]	11171	delivery	5	22
92922	2020-07-09 10:28:59	2020-07-09	9	[{"id_menu":7,"count":1}]	33428	delivery	5	14
92923	2020-07-09 10:33:07	2020-07-09	14	[{"id_menu":2,"count":1}]	32739	delivery	5	19
92924	2020-07-09 10:35:17	2020-07-09	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	36171	delivery	5	34
92925	2020-07-09 10:37:23	2020-07-09	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	24666	delivery	5	25
92926	2020-07-09 10:37:23	2020-07-09	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	36078	delivery	5	34
92927	2020-07-09 10:37:53	2020-07-09	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	33844	delivery	5	34
92928	2020-07-09 10:43:00	2020-07-09	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	36019	delivery	5	26
92929	2020-07-09 10:43:47	2020-07-09	14	[{"id_menu":2,"count":1}]	36239	delivery	5	19
92930	2020-07-09 10:45:37	2020-07-09	12	[{"id_menu":3,"count":1}]	17500	delivery	5	17
92931	2020-07-09 10:46:23	2020-07-09	17	[{"id_menu":4,"count":1}]	36170	delivery	5	22
92932	2020-07-09 10:46:42	2020-07-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	29374	delivery	5	28
92933	2020-07-09 10:49:06	2020-07-09	9	[{"id_menu":7,"count":1}]	5622	delivery	5	14
92934	2020-07-09 10:50:01	2020-07-09	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	36042	delivery	5	44
92935	2020-07-09 10:53:47	2020-07-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	36082	delivery	5	23
92936	2020-07-09 10:58:38	2020-07-09	9	[{"id_menu":6,"count":1}]	36033	delivery	5	14
92937	2020-07-09 11:02:38	2020-07-09	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	26235	delivery	5	30
92938	2020-07-09 11:09:20	2020-07-09	9	[{"id_menu":7,"count":1}]	19237	delivery	5	14
92939	2020-07-09 11:10:09	2020-07-09	12	[{"id_menu":3,"count":2}]	36238	delivery	5	17
92940	2020-07-09 11:11:34	2020-07-09	9	[{"id_menu":6,"count":1}]	33418	delivery	5	14
92941	2020-07-09 11:13:39	2020-07-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25386	delivery	5	23
92942	2020-07-09 11:18:07	2020-07-09	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	17227	delivery	5	40
92943	2020-07-09 11:18:45	2020-07-09	8	[{"id_menu":5,"count":1}]	35511	delivery	5	13
92944	2020-07-09 11:29:06	2020-07-09	9	[{"id_menu":6,"count":1}]	24200	pick-up	0	9
92945	2020-07-09 11:34:43	2020-07-09	14	[{"id_menu":2,"count":1}]	19011	pick-up	0	14
92946	2020-07-09 11:43:22	2020-07-09	9	[{"id_menu":7,"count":1}]	7835	pick-up	0	9
92947	2020-07-09 11:43:40	2020-07-09	14	[{"id_menu":2,"count":1}]	36051	delivery	5	19
92948	2020-07-09 11:43:44	2020-07-09	9	[{"id_menu":7,"count":1}]	26407	delivery	5	14
92949	2020-07-09 11:44:31	2020-07-09	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":3}]	22272	delivery	5	26
92950	2020-07-09 11:46:20	2020-07-09	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	14775	delivery	5	42
92951	2020-07-09 11:46:38	2020-07-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	36181	delivery	5	28
92952	2020-07-09 11:47:38	2020-07-09	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	19663	delivery	5	40
92953	2020-07-09 11:51:15	2020-07-09	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1386	pick-up	0	31
92954	2020-07-09 11:52:19	2020-07-09	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	3767	delivery	5	22
92955	2020-07-09 11:53:04	2020-07-09	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	36234	delivery	5	29
92956	2020-07-09 11:58:39	2020-07-09	9	[{"id_menu":7,"count":1}]	21039	delivery	5	14
92957	2020-07-09 11:59:19	2020-07-09	12	[{"id_menu":1,"count":1}]	3000	delivery	5	17
92958	2020-07-09 12:02:20	2020-07-09	9	[{"id_menu":6,"count":1}]	13	pick-up	0	9
92959	2020-07-09 12:03:34	2020-07-09	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15855	delivery	5	31
92960	2020-07-09 12:05:04	2020-07-09	37	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	27538	pick-up	0	37
92961	2020-07-09 12:09:43	2020-07-09	9	[{"id_menu":7,"count":1}]	5743	delivery	5	14
92962	2020-07-09 12:13:22	2020-07-09	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	12089	delivery	5	43
92963	2020-07-09 12:16:31	2020-07-09	9	[{"id_menu":6,"count":1}]	9040	pick-up	0	9
92964	2020-07-09 12:21:56	2020-07-09	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	26018	delivery	5	45
92965	2020-07-09 12:22:44	2020-07-09	9	[{"id_menu":7,"count":1}]	26170	delivery	5	14
92966	2020-07-09 12:23:20	2020-07-09	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	10121	delivery	5	26
92967	2020-07-09 12:25:43	2020-07-09	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	17555	delivery	5	31
92968	2020-07-09 12:28:35	2020-07-09	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	7530	delivery	5	27
92969	2020-07-09 12:30:03	2020-07-09	17	[{"id_menu":4,"count":1}]	2855	pick-up	0	17
92970	2020-07-09 12:31:06	2020-07-09	9	[{"id_menu":6,"count":1}]	14246	delivery	5	14
92971	2020-07-09 12:32:22	2020-07-09	17	[{"id_menu":4,"count":1}]	27044	pick-up	0	17
92972	2020-07-09 12:35:53	2020-07-09	14	[{"id_menu":2,"count":1}]	14670	delivery	5	19
92973	2020-07-09 12:36:07	2020-07-09	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36173	delivery	5	35
92974	2020-07-09 12:39:30	2020-07-09	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	36144	delivery	5	23
92975	2020-07-09 12:40:09	2020-07-09	9	[{"id_menu":7,"count":2}]	8865	delivery	5	14
92976	2020-07-09 12:40:37	2020-07-09	17	[{"id_menu":4,"count":1}]	2119	delivery	5	22
92977	2020-07-09 12:45:16	2020-07-09	9	[{"id_menu":7,"count":1}]	399	pick-up	0	9
92978	2020-07-09 12:46:20	2020-07-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	35980	delivery	5	28
92979	2020-07-09 12:51:58	2020-07-09	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	13767	pick-up	0	29
92980	2020-07-09 12:52:14	2020-07-09	9	[{"id_menu":6,"count":1}]	3235	delivery	5	14
92981	2020-07-09 12:53:40	2020-07-09	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	36086	delivery	5	26
92982	2020-07-09 13:00:31	2020-07-09	8	[{"id_menu":5,"count":1}]	27153	delivery	5	13
92983	2020-07-09 13:01:27	2020-07-09	12	[{"id_menu":3,"count":1}]	796	delivery	5	17
92984	2020-07-09 13:01:59	2020-07-09	12	[{"id_menu":1,"count":1}]	9249	delivery	5	17
92985	2020-07-09 13:03:38	2020-07-09	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	36046	delivery	5	31
92986	2020-07-09 13:05:02	2020-07-09	8	[{"id_menu":5,"count":1}]	2615	pick-up	0	8
92987	2020-07-09 13:07:02	2020-07-09	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	12686	delivery	5	46
92988	2020-07-09 13:07:21	2020-07-09	14	[{"id_menu":2,"count":1}]	19523	delivery	5	19
92989	2020-07-09 13:07:36	2020-07-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	22540	delivery	5	22
92990	2020-07-09 13:08:07	2020-07-09	9	[{"id_menu":7,"count":1}]	36133	pick-up	0	9
92991	2020-07-09 13:08:12	2020-07-09	9	[{"id_menu":7,"count":1}]	36228	delivery	5	14
92992	2020-07-09 13:09:13	2020-07-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5329	delivery	5	22
92993	2020-07-09 13:16:03	2020-07-09	14	[{"id_menu":2,"count":1}]	26201	pick-up	0	14
92994	2020-07-09 13:19:33	2020-07-09	8	[{"id_menu":5,"count":1}]	29575	delivery	5	13
92995	2020-07-09 13:20:15	2020-07-09	12	[{"id_menu":3,"count":1}]	15024	pick-up	0	12
92996	2020-07-09 13:27:36	2020-07-09	17	[{"id_menu":4,"count":1}]	29284	delivery	5	22
92997	2020-07-09 13:32:35	2020-07-09	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	36110	pick-up	0	39
92998	2020-07-09 13:34:41	2020-07-09	14	[{"id_menu":2,"count":1}]	7186	pick-up	0	14
92999	2020-07-09 13:36:21	2020-07-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28779	delivery	5	22
93000	2020-07-09 13:41:24	2020-07-09	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	17278	delivery	5	26
93001	2020-07-09 13:41:53	2020-07-09	9	[{"id_menu":6,"count":1}]	10677	delivery	5	14
93002	2020-07-09 13:44:03	2020-07-09	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	36068	delivery	5	31
93003	2020-07-09 13:45:59	2020-07-09	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	36202	delivery	5	26
93004	2020-07-09 13:58:01	2020-07-09	17	[{"id_menu":4,"count":1}]	2662	pick-up	0	17
93005	2020-07-09 14:01:27	2020-07-09	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	5527	delivery	5	38
93006	2020-07-09 14:03:06	2020-07-09	12	[{"id_menu":1,"count":1}]	29869	delivery	5	17
93007	2020-07-09 14:03:19	2020-07-09	12	[{"id_menu":3,"count":1}]	7040	pick-up	0	12
93008	2020-07-09 14:03:44	2020-07-09	14	[{"id_menu":2,"count":1}]	24650	pick-up	0	14
93009	2020-07-09 14:03:53	2020-07-09	17	[{"id_menu":4,"count":1}]	36118	delivery	5	22
93010	2020-07-09 14:04:22	2020-07-09	12	[{"id_menu":1,"count":1}]	2413	pick-up	0	12
93011	2020-07-09 14:04:27	2020-07-09	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	26596	delivery	5	35
93012	2020-07-09 14:06:00	2020-07-09	9	[{"id_menu":6,"count":1}]	31007	delivery	5	14
93013	2020-07-09 14:11:08	2020-07-09	9	[{"id_menu":7,"count":1}]	36186	delivery	5	14
93014	2020-07-09 14:13:22	2020-07-09	8	[{"id_menu":5,"count":1}]	36159	delivery	5	13
93015	2020-07-09 14:17:39	2020-07-09	9	[{"id_menu":6,"count":1}]	10651	delivery	5	14
93016	2020-07-09 14:19:03	2020-07-09	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	36091	delivery	5	39
93017	2020-07-09 14:20:36	2020-07-09	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	36036	delivery	5	31
93018	2020-07-09 14:24:32	2020-07-09	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	36123	delivery	5	26
93019	2020-07-09 14:26:21	2020-07-09	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	36221	delivery	5	48
93020	2020-07-09 14:27:57	2020-07-09	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21915	delivery	5	37
93021	2020-07-09 14:31:18	2020-07-09	9	[{"id_menu":6,"count":1}]	36164	delivery	5	14
93022	2020-07-09 14:31:39	2020-07-09	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	17654	delivery	5	31
93023	2020-07-09 14:33:42	2020-07-09	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	23432	pick-up	0	26
93024	2020-07-09 14:37:15	2020-07-09	9	[{"id_menu":6,"count":1}]	31969	delivery	5	14
93025	2020-07-09 14:38:16	2020-07-09	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	23718	delivery	5	31
93026	2020-07-09 14:38:34	2020-07-09	9	[{"id_menu":6,"count":1}]	12870	delivery	5	14
93027	2020-07-09 14:41:54	2020-07-09	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	19187	delivery	5	23
93028	2020-07-09 14:45:31	2020-07-09	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	23900	delivery	5	26
93029	2020-07-09 14:49:22	2020-07-09	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	36233	delivery	5	48
93030	2020-07-09 14:52:13	2020-07-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	36105	pick-up	0	23
93031	2020-07-09 15:00:11	2020-07-09	12	[{"id_menu":3,"count":1}]	36054	delivery	5	17
93032	2020-07-09 15:03:17	2020-07-09	17	[{"id_menu":4,"count":1}]	24301	delivery	5	22
93033	2020-07-09 15:09:24	2020-07-09	9	[{"id_menu":6,"count":1}]	12361	delivery	5	14
93034	2020-07-09 15:11:55	2020-07-09	9	[{"id_menu":7,"count":1}]	33492	delivery	5	14
93035	2020-07-09 15:12:12	2020-07-09	9	[{"id_menu":6,"count":1}]	36230	delivery	5	14
93036	2020-07-09 15:15:18	2020-07-09	12	[{"id_menu":3,"count":1}]	23827	delivery	5	17
93037	2020-07-09 15:16:09	2020-07-09	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	36109	delivery	5	22
93038	2020-07-09 15:16:31	2020-07-09	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1168	delivery	5	45
93039	2020-07-09 15:17:58	2020-07-09	12	[{"id_menu":3,"count":1}]	22445	pick-up	0	12
93040	2020-07-09 15:21:50	2020-07-09	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4282	delivery	5	31
93041	2020-07-09 15:22:11	2020-07-09	9	[{"id_menu":7,"count":1}]	13432	delivery	5	14
93042	2020-07-09 15:24:13	2020-07-09	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	36219	delivery	5	45
93043	2020-07-09 15:24:43	2020-07-09	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	36134	delivery	5	26
93044	2020-07-09 15:32:13	2020-07-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2616	pick-up	0	23
93045	2020-07-09 15:36:00	2020-07-09	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	15690	delivery	5	35
93046	2020-07-09 15:36:17	2020-07-09	12	[{"id_menu":1,"count":1}]	28755	delivery	5	17
93047	2020-07-09 15:36:58	2020-07-09	9	[{"id_menu":7,"count":1}]	22871	delivery	5	14
93048	2020-07-09 15:38:26	2020-07-09	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	10746	delivery	5	34
93049	2020-07-09 15:39:11	2020-07-09	8	[{"id_menu":5,"count":1}]	12601	delivery	5	13
93050	2020-07-09 15:44:00	2020-07-09	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16091	delivery	5	37
93051	2020-07-09 15:44:22	2020-07-09	8	[{"id_menu":5,"count":1}]	7074	delivery	5	13
93052	2020-07-09 15:50:33	2020-07-09	55	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4209	pick-up	0	55
93053	2020-07-09 15:53:11	2020-07-09	14	[{"id_menu":2,"count":1}]	9588	pick-up	0	14
93054	2020-07-09 15:55:22	2020-07-09	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36209	delivery	5	43
93055	2020-07-09 15:57:52	2020-07-09	14	[{"id_menu":2,"count":1}]	26798	delivery	5	19
93056	2020-07-09 16:00:50	2020-07-09	9	[{"id_menu":6,"count":1}]	35087	delivery	5	14
93057	2020-07-09 16:01:51	2020-07-09	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	35993	pick-up	0	21
93058	2020-07-09 16:04:41	2020-07-09	17	[{"id_menu":4,"count":1}]	15323	delivery	5	22
93059	2020-07-09 16:06:00	2020-07-09	14	[{"id_menu":2,"count":1}]	17275	delivery	5	19
93060	2020-07-09 16:11:02	2020-07-09	9	[{"id_menu":7,"count":1}]	30070	delivery	5	14
93061	2020-07-09 16:11:58	2020-07-09	9	[{"id_menu":7,"count":1}]	21100	delivery	5	14
93062	2020-07-09 16:12:49	2020-07-09	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	15656	delivery	5	44
93063	2020-07-09 16:20:29	2020-07-09	12	[{"id_menu":1,"count":2}]	17534	delivery	5	17
93064	2020-07-09 16:21:43	2020-07-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	36057	delivery	5	28
93065	2020-07-09 16:22:37	2020-07-09	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4234	delivery	5	27
93066	2020-07-09 16:25:50	2020-07-09	9	[{"id_menu":6,"count":1}]	27625	delivery	5	14
93067	2020-07-09 16:26:23	2020-07-09	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	36152	delivery	5	30
93068	2020-07-09 16:30:02	2020-07-09	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2173	pick-up	0	21
93069	2020-07-09 16:31:01	2020-07-09	12	[{"id_menu":1,"count":1}]	1379	pick-up	0	12
93070	2020-07-09 16:39:38	2020-07-09	14	[{"id_menu":2,"count":1}]	36177	delivery	5	19
93071	2020-07-09 16:40:20	2020-07-09	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	36180	delivery	5	26
93072	2020-07-09 16:40:21	2020-07-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28602	delivery	5	22
93073	2020-07-09 16:44:05	2020-07-09	34	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	2153	pick-up	0	34
93074	2020-07-09 16:47:52	2020-07-09	8	[{"id_menu":5,"count":1}]	36113	delivery	5	13
93075	2020-07-09 16:49:35	2020-07-09	14	[{"id_menu":2,"count":1}]	3464	pick-up	0	14
93076	2020-07-09 16:50:26	2020-07-09	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2081	delivery	5	26
93077	2020-07-09 16:51:47	2020-07-09	9	[{"id_menu":6,"count":1}]	21765	delivery	5	14
93078	2020-07-09 16:56:45	2020-07-09	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	25597	delivery	5	40
93079	2020-07-09 16:57:21	2020-07-09	14	[{"id_menu":2,"count":1}]	29608	delivery	5	19
93080	2020-07-09 16:57:36	2020-07-09	9	[{"id_menu":7,"count":1}]	270	pick-up	0	9
93081	2020-07-09 17:04:57	2020-07-09	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	36030	delivery	5	40
93082	2020-07-09 17:06:44	2020-07-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":3}]	28247	delivery	5	22
93083	2020-07-09 17:07:44	2020-07-09	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32298	delivery	5	35
93084	2020-07-09 17:08:48	2020-07-09	17	[{"id_menu":4,"count":1}]	36217	delivery	5	22
93085	2020-07-09 17:13:11	2020-07-09	9	[{"id_menu":7,"count":1}]	18728	delivery	5	14
93086	2020-07-09 17:13:16	2020-07-09	9	[{"id_menu":7,"count":1}]	26909	delivery	5	14
93087	2020-07-09 17:18:03	2020-07-09	12	[{"id_menu":3,"count":1}]	1559	delivery	5	17
93088	2020-07-09 17:23:15	2020-07-09	9	[{"id_menu":7,"count":1}]	36163	delivery	5	14
93089	2020-07-09 17:29:31	2020-07-09	9	[{"id_menu":6,"count":1}]	36103	delivery	5	14
93090	2020-07-09 17:30:40	2020-07-09	14	[{"id_menu":2,"count":1}]	36193	pick-up	0	14
93091	2020-07-09 17:31:21	2020-07-09	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":3}]	145	delivery	5	34
93092	2020-07-09 17:31:34	2020-07-09	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	21287	delivery	5	31
93093	2020-07-09 17:33:39	2020-07-09	12	[{"id_menu":1,"count":1}]	229	delivery	5	17
93094	2020-07-09 17:33:47	2020-07-09	12	[{"id_menu":1,"count":1}]	5730	delivery	5	17
93095	2020-07-09 17:36:57	2020-07-09	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	36017	delivery	5	30
93096	2020-07-09 17:38:15	2020-07-09	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36179	delivery	5	37
93097	2020-07-09 17:40:55	2020-07-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7051	pick-up	0	17
93098	2020-07-09 17:42:08	2020-07-09	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	21629	delivery	5	22
93099	2020-07-09 17:42:12	2020-07-09	12	[{"id_menu":3,"count":1}]	36121	pick-up	0	12
93100	2020-07-09 17:46:58	2020-07-09	9	[{"id_menu":6,"count":1}]	35870	pick-up	0	9
93101	2020-07-09 17:48:05	2020-07-09	8	[{"id_menu":5,"count":1}]	25276	pick-up	0	8
93102	2020-07-09 17:49:28	2020-07-09	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	36211	delivery	5	34
93103	2020-07-09 17:54:07	2020-07-09	14	[{"id_menu":2,"count":1}]	6916	pick-up	0	14
93104	2020-07-09 17:55:42	2020-07-09	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	23559	delivery	5	26
93105	2020-07-09 17:55:47	2020-07-09	9	[{"id_menu":7,"count":1}]	34034	delivery	5	14
93106	2020-07-09 17:58:21	2020-07-09	12	[{"id_menu":1,"count":1}]	9191	pick-up	0	12
93107	2020-07-09 18:01:09	2020-07-09	14	[{"id_menu":2,"count":1}]	5292	delivery	5	19
93108	2020-07-09 18:04:47	2020-07-09	9	[{"id_menu":7,"count":1}]	36100	delivery	5	14
93109	2020-07-09 18:11:04	2020-07-09	17	[{"id_menu":4,"count":1}]	3634	pick-up	0	17
93110	2020-07-09 18:13:12	2020-07-09	17	[{"id_menu":4,"count":1}]	34066	delivery	5	22
93111	2020-07-09 18:14:21	2020-07-09	12	[{"id_menu":3,"count":1}]	30632	pick-up	0	12
93112	2020-07-09 18:14:36	2020-07-09	12	[{"id_menu":1,"count":1}]	36025	delivery	5	17
93113	2020-07-09 18:17:22	2020-07-09	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	6437	delivery	5	39
93114	2020-07-09 18:20:48	2020-07-09	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1380	delivery	5	31
93115	2020-07-09 18:21:27	2020-07-09	9	[{"id_menu":6,"count":1}]	21501	delivery	5	14
93116	2020-07-09 18:22:09	2020-07-09	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	36176	delivery	5	30
93117	2020-07-09 18:23:03	2020-07-09	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12355	delivery	5	57
93118	2020-07-09 18:23:52	2020-07-09	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	16765	delivery	5	31
93119	2020-07-09 18:25:43	2020-07-09	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	15013	delivery	5	26
93120	2020-07-09 18:27:45	2020-07-09	17	[{"id_menu":4,"count":1}]	36166	delivery	5	22
93121	2020-07-09 18:27:58	2020-07-09	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	36084	delivery	5	36
93122	2020-07-09 18:29:16	2020-07-09	9	[{"id_menu":6,"count":1}]	24779	delivery	5	14
93123	2020-07-09 18:29:58	2020-07-09	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	12918	pick-up	0	22
93124	2020-07-09 18:34:29	2020-07-09	8	[{"id_menu":5,"count":1}]	34685	delivery	5	13
93125	2020-07-09 18:38:28	2020-07-09	9	[{"id_menu":7,"count":1}]	36020	pick-up	0	9
93126	2020-07-09 18:39:39	2020-07-09	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	4578	delivery	5	26
93127	2020-07-09 18:39:58	2020-07-09	9	[{"id_menu":7,"count":1}]	36200	delivery	5	14
93128	2020-07-09 18:42:24	2020-07-09	9	[{"id_menu":7,"count":1}]	36158	delivery	5	14
93129	2020-07-09 18:43:27	2020-07-09	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	14868	delivery	5	25
93130	2020-07-09 18:43:57	2020-07-09	14	[{"id_menu":2,"count":1}]	21365	delivery	5	19
93131	2020-07-09 18:46:48	2020-07-09	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	36107	delivery	5	43
93132	2020-07-09 18:49:54	2020-07-09	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	36016	delivery	5	26
93133	2020-07-09 18:52:36	2020-07-09	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	36092	delivery	5	48
93134	2020-07-09 18:53:24	2020-07-09	12	[{"id_menu":3,"count":1}]	11969	delivery	5	17
93135	2020-07-09 18:53:32	2020-07-09	17	[{"id_menu":4,"count":1}]	16441	delivery	5	22
93136	2020-07-09 18:54:28	2020-07-09	14	[{"id_menu":2,"count":2}]	3435	delivery	5	19
93137	2020-07-09 18:55:11	2020-07-09	17	[{"id_menu":4,"count":1}]	19386	delivery	5	22
93138	2020-07-09 18:58:12	2020-07-09	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	33321	delivery	5	34
93139	2020-07-09 18:59:00	2020-07-09	14	[{"id_menu":2,"count":1}]	36064	delivery	5	19
93140	2020-07-09 19:00:35	2020-07-09	8	[{"id_menu":5,"count":1}]	36222	delivery	5	13
93141	2020-07-09 19:02:19	2020-07-09	8	[{"id_menu":5,"count":1}]	13219	delivery	5	13
93142	2020-07-09 19:06:01	2020-07-09	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1421	delivery	5	29
93143	2020-07-09 19:06:31	2020-07-09	17	[{"id_menu":4,"count":1}]	36161	delivery	5	22
93144	2020-07-09 19:08:43	2020-07-09	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	36079	delivery	5	30
93145	2020-07-09 19:15:26	2020-07-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	12566	delivery	5	28
93146	2020-07-09 19:17:31	2020-07-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16457	delivery	5	23
93147	2020-07-09 19:21:15	2020-07-09	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	30471	delivery	5	36
93148	2020-07-09 19:24:41	2020-07-09	17	[{"id_menu":4,"count":1}]	2359	pick-up	0	17
93149	2020-07-09 19:26:50	2020-07-09	9	[{"id_menu":7,"count":1}]	16019	delivery	5	14
93150	2020-07-09 19:28:30	2020-07-09	12	[{"id_menu":1,"count":1}]	8245	delivery	5	17
93151	2020-07-09 19:29:49	2020-07-09	9	[{"id_menu":7,"count":1}]	36154	delivery	5	14
93152	2020-07-09 19:30:15	2020-07-09	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	36116	delivery	5	26
93153	2020-07-09 19:33:28	2020-07-09	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	36124	delivery	5	39
93154	2020-07-09 19:34:15	2020-07-09	12	[{"id_menu":3,"count":1}]	31955	delivery	5	17
93155	2020-07-09 19:35:27	2020-07-09	9	[{"id_menu":6,"count":1}]	11298	delivery	5	14
93156	2020-07-09 19:38:32	2020-07-09	9	[{"id_menu":6,"count":1}]	36072	delivery	5	14
93157	2020-07-09 19:42:50	2020-07-09	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	17701	delivery	5	26
93158	2020-07-09 19:45:48	2020-07-09	9	[{"id_menu":7,"count":1}]	27660	delivery	5	14
93159	2020-07-09 19:48:31	2020-07-09	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9011	delivery	5	44
93160	2020-07-09 19:49:19	2020-07-09	9	[{"id_menu":7,"count":1}]	14086	pick-up	0	9
93161	2020-07-09 19:55:41	2020-07-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	36195	delivery	5	23
93162	2020-07-09 19:56:19	2020-07-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15679	delivery	5	23
93163	2020-07-09 19:58:12	2020-07-09	17	[{"id_menu":4,"count":1}]	15873	pick-up	0	17
93164	2020-07-09 20:00:20	2020-07-09	9	[{"id_menu":6,"count":1}]	10325	delivery	5	14
93165	2020-07-09 20:01:23	2020-07-09	8	[{"id_menu":5,"count":1}]	36192	delivery	5	13
93166	2020-07-09 20:04:32	2020-07-09	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	34588	delivery	5	44
93167	2020-07-09 20:05:13	2020-07-09	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	36035	delivery	5	39
93168	2020-07-09 20:06:07	2020-07-09	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27202	delivery	5	40
93169	2020-07-09 20:06:35	2020-07-09	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	36201	delivery	5	30
93170	2020-07-09 20:08:02	2020-07-09	14	[{"id_menu":2,"count":1}]	17975	delivery	5	19
93171	2020-07-09 20:11:23	2020-07-09	17	[{"id_menu":4,"count":1}]	10193	delivery	5	22
93172	2020-07-09 20:11:40	2020-07-09	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	20212	delivery	5	26
93173	2020-07-09 20:13:04	2020-07-09	9	[{"id_menu":6,"count":1}]	36232	delivery	5	14
93174	2020-07-09 20:14:24	2020-07-09	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15166	delivery	5	39
93175	2020-07-09 20:15:10	2020-07-09	17	[{"id_menu":4,"count":1}]	36070	pick-up	0	17
93176	2020-07-09 20:15:40	2020-07-09	17	[{"id_menu":4,"count":1}]	33560	delivery	5	22
93177	2020-07-09 20:17:08	2020-07-09	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1416	delivery	5	31
93178	2020-07-09 20:19:48	2020-07-09	17	[{"id_menu":4,"count":1}]	6278	pick-up	0	17
93179	2020-07-09 20:20:08	2020-07-09	9	[{"id_menu":7,"count":1}]	29407	delivery	5	14
93180	2020-07-09 20:31:38	2020-07-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2107	pick-up	0	23
93181	2020-07-09 20:32:32	2020-07-09	17	[{"id_menu":4,"count":1}]	25894	delivery	5	22
93182	2020-07-09 20:39:03	2020-07-09	9	[{"id_menu":6,"count":1}]	36168	delivery	5	14
93183	2020-07-09 20:39:46	2020-07-09	14	[{"id_menu":2,"count":1}]	36235	pick-up	0	14
93184	2020-07-09 20:40:56	2020-07-09	14	[{"id_menu":2,"count":1}]	36226	delivery	5	19
93185	2020-07-09 20:42:36	2020-07-09	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14725	delivery	5	22
93186	2020-07-09 20:43:08	2020-07-09	8	[{"id_menu":5,"count":2}]	10553	delivery	5	13
93187	2020-07-09 20:46:37	2020-07-09	9	[{"id_menu":7,"count":1}]	9470	delivery	5	14
93188	2020-07-09 20:49:51	2020-07-09	8	[{"id_menu":5,"count":1}]	36203	delivery	5	13
93189	2020-07-09 20:51:53	2020-07-09	12	[{"id_menu":1,"count":1}]	36190	delivery	5	17
93190	2020-07-09 20:53:54	2020-07-09	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	36050	delivery	5	57
93191	2020-07-09 20:55:07	2020-07-09	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	10616	delivery	5	25
93192	2020-07-09 20:55:42	2020-07-09	8	[{"id_menu":5,"count":1}]	6533	pick-up	0	8
93193	2020-07-09 20:55:46	2020-07-09	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	10365	delivery	5	26
93194	2020-07-09 20:57:49	2020-07-09	8	[{"id_menu":5,"count":1}]	15383	delivery	5	13
93195	2020-07-09 20:58:43	2020-07-09	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	27792	delivery	5	45
93196	2020-07-09 20:58:55	2020-07-09	17	[{"id_menu":4,"count":1}]	36204	delivery	5	22
93197	2020-07-09 21:01:20	2020-07-09	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	13172	delivery	5	25
93198	2020-07-09 21:12:53	2020-07-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":3}]	2846	delivery	5	28
93199	2020-07-09 21:13:29	2020-07-09	14	[{"id_menu":2,"count":1}]	1992	pick-up	0	14
93200	2020-07-09 21:15:15	2020-07-09	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	36167	delivery	5	43
93201	2020-07-09 21:16:31	2020-07-09	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	23575	delivery	5	25
93202	2020-07-09 21:16:54	2020-07-09	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	36066	delivery	5	22
93203	2020-07-09 21:19:26	2020-07-09	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	36137	delivery	5	36
93204	2020-07-09 21:19:59	2020-07-09	17	[{"id_menu":4,"count":1}]	36065	delivery	5	22
93205	2020-07-09 21:20:07	2020-07-09	17	[{"id_menu":4,"count":2}]	24272	delivery	5	22
93206	2020-07-09 21:20:17	2020-07-09	9	[{"id_menu":7,"count":2}]	36026	delivery	5	14
93207	2020-07-09 21:21:17	2020-07-09	17	[{"id_menu":4,"count":1}]	33798	pick-up	0	17
93208	2020-07-09 21:21:55	2020-07-09	8	[{"id_menu":5,"count":1}]	9392	delivery	5	13
93209	2020-07-09 21:22:00	2020-07-09	12	[{"id_menu":1,"count":1}]	526	delivery	5	17
93210	2020-07-09 21:23:25	2020-07-09	17	[{"id_menu":4,"count":1}]	36076	delivery	5	22
93211	2020-07-09 21:23:56	2020-07-09	12	[{"id_menu":1,"count":1}]	24040	delivery	5	17
93212	2020-07-09 21:28:17	2020-07-09	9	[{"id_menu":7,"count":1}]	16165	pick-up	0	9
93213	2020-07-09 21:28:55	2020-07-09	12	[{"id_menu":3,"count":1}]	6589	pick-up	0	12
93214	2020-07-09 21:29:12	2020-07-09	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	33298	delivery	5	25
93215	2020-07-09 21:30:32	2020-07-09	9	[{"id_menu":7,"count":1}]	36212	delivery	5	14
93216	2020-07-09 21:32:02	2020-07-09	9	[{"id_menu":7,"count":1}]	33025	delivery	5	14
93217	2020-07-09 21:34:39	2020-07-09	14	[{"id_menu":2,"count":1}]	6487	pick-up	0	14
93218	2020-07-09 21:35:55	2020-07-09	12	[{"id_menu":1,"count":1}]	36149	delivery	5	17
93219	2020-07-09 21:38:35	2020-07-09	8	[{"id_menu":5,"count":1}]	9417	delivery	5	13
93220	2020-07-09 21:45:42	2020-07-09	9	[{"id_menu":7,"count":1}]	27806	delivery	5	14
93221	2020-07-09 21:47:29	2020-07-09	9	[{"id_menu":6,"count":1}]	33487	delivery	5	14
93222	2020-07-09 21:51:21	2020-07-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	24767	delivery	5	28
93223	2020-07-09 21:52:03	2020-07-09	9	[{"id_menu":6,"count":1}]	9508	pick-up	0	9
93224	2020-07-09 21:52:18	2020-07-09	17	[{"id_menu":4,"count":1}]	1953	delivery	5	22
93225	2020-07-09 21:58:17	2020-07-09	8	[{"id_menu":5,"count":1}]	21849	pick-up	0	8
93226	2020-07-09 21:58:53	2020-07-09	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	32881	delivery	5	31
93227	2020-07-09 21:59:10	2020-07-09	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	36140	delivery	5	45
93228	2020-07-09 22:00:38	2020-07-09	9	[{"id_menu":7,"count":1}]	36151	delivery	5	14
93229	2020-07-09 22:01:59	2020-07-09	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	26827	delivery	5	26
93230	2020-07-09 22:04:12	2020-07-09	17	[{"id_menu":4,"count":1}]	299	pick-up	0	17
93231	2020-07-09 22:07:16	2020-07-09	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":2}]	36127	delivery	5	36
93232	2020-07-09 22:09:40	2020-07-09	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	36236	delivery	5	31
93233	2020-07-09 22:11:50	2020-07-09	14	[{"id_menu":2,"count":1}]	31471	delivery	5	19
93234	2020-07-09 22:15:18	2020-07-09	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	36210	delivery	5	34
93235	2020-07-09 22:18:59	2020-07-09	12	[{"id_menu":1,"count":1}]	3636	delivery	5	17
93236	2020-07-09 22:20:27	2020-07-09	8	[{"id_menu":5,"count":1}]	36199	delivery	5	13
93237	2020-07-09 22:24:33	2020-07-09	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	30913	delivery	5	43
93238	2020-07-09 22:27:00	2020-07-09	12	[{"id_menu":3,"count":1}]	10732	delivery	5	17
93239	2020-07-09 22:29:16	2020-07-09	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	36162	delivery	5	22
93240	2020-07-09 22:30:18	2020-07-09	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	30463	delivery	5	22
93241	2020-07-09 22:31:22	2020-07-09	8	[{"id_menu":5,"count":1}]	27126	delivery	5	13
93242	2020-07-09 22:34:14	2020-07-09	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	36131	delivery	5	36
93243	2020-07-09 22:35:28	2020-07-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6008	delivery	5	28
93244	2020-07-09 22:36:16	2020-07-09	9	[{"id_menu":6,"count":1}]	36119	delivery	5	14
93245	2020-07-09 22:37:51	2020-07-09	12	[{"id_menu":3,"count":1}]	32540	pick-up	0	12
93246	2020-07-09 22:41:28	2020-07-09	9	[{"id_menu":6,"count":1}]	36206	delivery	5	14
93247	2020-07-09 22:41:50	2020-07-09	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2062	pick-up	0	26
93248	2020-07-09 22:41:51	2020-07-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3001	pick-up	0	23
93249	2020-07-09 22:45:13	2020-07-09	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7553	delivery	5	43
93250	2020-07-09 22:47:42	2020-07-09	9	[{"id_menu":7,"count":1}]	15151	delivery	5	14
93251	2020-07-09 22:51:01	2020-07-09	17	[{"id_menu":4,"count":1}]	36198	delivery	5	22
93252	2020-07-09 22:51:34	2020-07-09	17	[{"id_menu":4,"count":1}]	6369	pick-up	0	17
93253	2020-07-09 22:53:10	2020-07-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36023	delivery	5	23
93254	2020-07-09 22:55:19	2020-07-09	14	[{"id_menu":2,"count":1}]	2654	pick-up	0	14
93255	2020-07-09 22:57:54	2020-07-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	31751	delivery	5	28
93256	2020-07-09 23:00:32	2020-07-09	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	12378	delivery	5	39
93257	2020-07-09 23:00:46	2020-07-09	17	[{"id_menu":4,"count":1}]	4012	pick-up	0	17
93258	2020-07-09 23:00:49	2020-07-09	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	36205	delivery	5	22
93259	2020-07-09 23:03:35	2020-07-09	14	[{"id_menu":2,"count":1}]	36220	delivery	5	19
93260	2020-07-09 23:04:03	2020-07-09	9	[{"id_menu":6,"count":2}]	36059	delivery	5	14
93261	2020-07-09 23:04:12	2020-07-09	8	[{"id_menu":5,"count":1}]	18256	delivery	5	13
93262	2020-07-09 23:05:05	2020-07-09	14	[{"id_menu":2,"count":1}]	36056	delivery	5	19
93263	2020-07-09 23:05:54	2020-07-09	12	[{"id_menu":1,"count":1}]	36095	delivery	5	17
93264	2020-07-09 23:05:54	2020-07-09	12	[{"id_menu":3,"count":1}]	21257	delivery	5	17
93265	2020-07-09 23:08:49	2020-07-09	8	[{"id_menu":5,"count":1}]	31243	delivery	5	13
93266	2020-07-09 23:10:24	2020-07-09	9	[{"id_menu":7,"count":1}]	19287	delivery	5	14
93267	2020-07-09 23:11:30	2020-07-09	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36073	delivery	5	37
93268	2020-07-09 23:20:42	2020-07-09	38	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	33568	delivery	5	43
93269	2020-07-09 23:23:24	2020-07-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	33131	delivery	5	28
93270	2020-07-09 23:30:31	2020-07-09	17	[{"id_menu":4,"count":1}]	36027	delivery	5	22
93271	2020-07-09 23:32:43	2020-07-09	8	[{"id_menu":5,"count":1}]	36147	delivery	5	13
93272	2020-07-09 23:33:19	2020-07-09	8	[{"id_menu":5,"count":1}]	1713	pick-up	0	8
93273	2020-07-09 23:36:52	2020-07-09	9	[{"id_menu":6,"count":1}]	172	delivery	5	14
93274	2020-07-09 23:39:51	2020-07-09	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	36083	delivery	5	44
93275	2020-07-09 23:40:48	2020-07-09	55	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1541	delivery	5	60
93276	2020-07-09 23:41:42	2020-07-09	9	[{"id_menu":7,"count":1}]	30025	delivery	5	14
93277	2020-07-09 23:46:59	2020-07-09	9	[{"id_menu":6,"count":1}]	23799	delivery	5	14
93278	2020-07-09 23:47:13	2020-07-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	25548	pick-up	0	17
93279	2020-07-09 23:52:03	2020-07-09	8	[{"id_menu":5,"count":1}]	36148	delivery	5	13
93280	2020-07-09 23:56:01	2020-07-09	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3788	delivery	5	45
93281	2020-07-10 00:00:22	2020-07-10	9	[{"id_menu":6,"count":2}]	32119	delivery	5	14
93282	2020-07-10 00:03:40	2020-07-10	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	36319	delivery	5	31
93283	2020-07-10 00:08:50	2020-07-10	12	[{"id_menu":3,"count":1}]	16484	pick-up	0	12
93284	2020-07-10 00:16:49	2020-07-10	9	[{"id_menu":6,"count":1}]	10672	delivery	5	14
93285	2020-07-10 00:17:41	2020-07-10	12	[{"id_menu":1,"count":1}]	18271	delivery	5	17
93286	2020-07-10 00:19:59	2020-07-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25576	delivery	5	22
93287	2020-07-10 00:23:00	2020-07-10	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	19596	delivery	5	37
93288	2020-07-10 00:23:09	2020-07-10	9	[{"id_menu":6,"count":1}]	36334	delivery	5	14
93289	2020-07-10 00:24:52	2020-07-10	8	[{"id_menu":5,"count":1}]	36242	delivery	5	13
93290	2020-07-10 00:27:19	2020-07-10	14	[{"id_menu":2,"count":1}]	36329	pick-up	0	14
93291	2020-07-10 00:28:56	2020-07-10	8	[{"id_menu":5,"count":1}]	21020	pick-up	0	8
93292	2020-07-10 00:30:04	2020-07-10	12	[{"id_menu":1,"count":1}]	36265	pick-up	0	12
93293	2020-07-10 00:30:11	2020-07-10	8	[{"id_menu":5,"count":1}]	36350	delivery	5	13
93294	2020-07-10 00:37:30	2020-07-10	9	[{"id_menu":6,"count":1}]	8684	delivery	5	14
93295	2020-07-10 00:42:21	2020-07-10	8	[{"id_menu":5,"count":1}]	30991	delivery	5	13
93296	2020-07-10 00:52:02	2020-07-10	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	36347	pick-up	0	26
93297	2020-07-10 00:52:29	2020-07-10	8	[{"id_menu":5,"count":1}]	33044	delivery	5	13
93298	2020-07-10 00:52:58	2020-07-10	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	32667	delivery	5	34
93299	2020-07-10 00:59:47	2020-07-10	9	[{"id_menu":6,"count":1}]	36387	delivery	5	14
93300	2020-07-10 01:00:17	2020-07-10	12	[{"id_menu":3,"count":1}]	29421	delivery	5	17
93301	2020-07-10 01:00:49	2020-07-10	9	[{"id_menu":7,"count":1}]	36288	delivery	5	14
93302	2020-07-10 01:04:37	2020-07-10	12	[{"id_menu":1,"count":1}]	36363	delivery	5	17
93303	2020-07-10 01:06:12	2020-07-10	9	[{"id_menu":7,"count":1}]	12246	delivery	5	14
93304	2020-07-10 01:06:53	2020-07-10	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	36273	delivery	5	34
93305	2020-07-10 01:07:10	2020-07-10	12	[{"id_menu":1,"count":1}]	15752	pick-up	0	12
93306	2020-07-10 01:09:13	2020-07-10	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	36450	delivery	5	34
93307	2020-07-10 01:10:00	2020-07-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	27390	delivery	5	28
93308	2020-07-10 01:14:17	2020-07-10	17	[{"id_menu":4,"count":1}]	16641	delivery	5	22
93309	2020-07-10 01:15:47	2020-07-10	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	28161	delivery	5	23
93310	2020-07-10 01:15:52	2020-07-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36248	delivery	5	23
93311	2020-07-10 01:16:05	2020-07-10	8	[{"id_menu":5,"count":2}]	29218	delivery	5	13
93312	2020-07-10 01:16:27	2020-07-10	8	[{"id_menu":5,"count":1}]	36475	delivery	5	13
93313	2020-07-10 01:16:49	2020-07-10	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	34114	delivery	5	27
93314	2020-07-10 01:17:02	2020-07-10	17	[{"id_menu":4,"count":1}]	11586	delivery	5	22
93315	2020-07-10 01:17:22	2020-07-10	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	32280	delivery	5	39
93316	2020-07-10 01:19:24	2020-07-10	12	[{"id_menu":1,"count":1}]	36266	pick-up	0	12
93317	2020-07-10 01:20:20	2020-07-10	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2064	pick-up	0	29
93318	2020-07-10 01:20:58	2020-07-10	9	[{"id_menu":7,"count":1}]	28261	delivery	5	14
93319	2020-07-10 01:21:13	2020-07-10	9	[{"id_menu":6,"count":1}]	36243	delivery	5	14
93320	2020-07-10 01:32:06	2020-07-10	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	36464	delivery	5	31
93321	2020-07-10 01:32:33	2020-07-10	17	[{"id_menu":4,"count":1}]	36478	delivery	5	22
93322	2020-07-10 01:34:42	2020-07-10	38	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	36482	delivery	5	43
93323	2020-07-10 01:35:20	2020-07-10	9	[{"id_menu":6,"count":1}]	21698	delivery	5	14
93324	2020-07-10 01:37:49	2020-07-10	9	[{"id_menu":7,"count":1}]	23989	delivery	5	14
93325	2020-07-10 01:38:17	2020-07-10	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	36364	delivery	5	43
93326	2020-07-10 01:38:37	2020-07-10	9	[{"id_menu":7,"count":1}]	22952	pick-up	0	9
93327	2020-07-10 01:47:57	2020-07-10	17	[{"id_menu":4,"count":1}]	36503	delivery	5	22
93328	2020-07-10 01:49:19	2020-07-10	9	[{"id_menu":6,"count":1}]	20262	delivery	5	14
93329	2020-07-10 01:57:43	2020-07-10	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24594	delivery	5	49
93330	2020-07-10 01:59:12	2020-07-10	12	[{"id_menu":3,"count":1}]	36277	delivery	5	17
93331	2020-07-10 02:01:54	2020-07-10	12	[{"id_menu":3,"count":1}]	25749	delivery	5	17
93332	2020-07-10 02:03:03	2020-07-10	9	[{"id_menu":7,"count":1}]	36254	delivery	5	14
93333	2020-07-10 02:03:17	2020-07-10	8	[{"id_menu":5,"count":1}]	97	pick-up	0	8
93334	2020-07-10 02:05:16	2020-07-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9319	delivery	5	28
93335	2020-07-10 02:15:02	2020-07-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	30816	delivery	5	28
93336	2020-07-10 02:17:25	2020-07-10	8	[{"id_menu":5,"count":2}]	36280	delivery	5	13
93337	2020-07-10 02:20:17	2020-07-10	14	[{"id_menu":2,"count":1}]	3931	pick-up	0	14
93338	2020-07-10 02:22:11	2020-07-10	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	1866	delivery	5	40
93339	2020-07-10 02:25:04	2020-07-10	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	21551	delivery	5	34
93340	2020-07-10 02:29:06	2020-07-10	8	[{"id_menu":5,"count":1}]	30939	delivery	5	13
93341	2020-07-10 02:31:31	2020-07-10	12	[{"id_menu":1,"count":1}]	15604	delivery	5	17
93342	2020-07-10 02:32:44	2020-07-10	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	36315	delivery	5	26
93343	2020-07-10 02:33:51	2020-07-10	17	[{"id_menu":4,"count":1}]	36492	pick-up	0	17
93344	2020-07-10 02:37:48	2020-07-10	12	[{"id_menu":1,"count":1}]	36417	delivery	5	17
93345	2020-07-10 02:38:03	2020-07-10	8	[{"id_menu":5,"count":1}]	36454	delivery	5	13
93346	2020-07-10 02:38:29	2020-07-10	17	[{"id_menu":4,"count":1}]	36366	delivery	5	22
93347	2020-07-10 02:39:54	2020-07-10	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	35130	delivery	5	25
93348	2020-07-10 02:40:02	2020-07-10	9	[{"id_menu":7,"count":1}]	2529	pick-up	0	9
93349	2020-07-10 02:42:25	2020-07-10	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9323	delivery	5	37
93350	2020-07-10 02:42:58	2020-07-10	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	36458	pick-up	0	22
93351	2020-07-10 02:43:17	2020-07-10	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	36340	delivery	5	57
93352	2020-07-10 02:43:27	2020-07-10	9	[{"id_menu":7,"count":1}]	36437	delivery	5	14
93353	2020-07-10 02:43:39	2020-07-10	9	[{"id_menu":6,"count":1}]	467	pick-up	0	9
93354	2020-07-10 02:46:25	2020-07-10	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18940	delivery	5	52
93355	2020-07-10 02:47:53	2020-07-10	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	19817	delivery	5	34
93356	2020-07-10 02:49:42	2020-07-10	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	26373	pick-up	0	21
93357	2020-07-10 02:51:40	2020-07-10	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	29225	delivery	5	36
93358	2020-07-10 02:52:25	2020-07-10	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	7501	pick-up	0	26
93359	2020-07-10 02:56:02	2020-07-10	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	28824	pick-up	0	26
93360	2020-07-10 02:56:36	2020-07-10	12	[{"id_menu":3,"count":1}]	29123	delivery	5	17
93361	2020-07-10 03:03:14	2020-07-10	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	7426	delivery	5	40
93362	2020-07-10 03:03:35	2020-07-10	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25075	delivery	5	39
93363	2020-07-10 03:03:38	2020-07-10	17	[{"id_menu":4,"count":1}]	370	delivery	5	22
93364	2020-07-10 03:04:37	2020-07-10	9	[{"id_menu":6,"count":1}]	32747	delivery	5	14
93365	2020-07-10 03:06:42	2020-07-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	36502	delivery	5	22
93366	2020-07-10 03:06:49	2020-07-10	17	[{"id_menu":4,"count":1}]	36500	pick-up	0	17
93367	2020-07-10 03:11:57	2020-07-10	14	[{"id_menu":2,"count":1}]	36284	delivery	5	19
93368	2020-07-10 03:13:19	2020-07-10	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	36342	delivery	5	28
93369	2020-07-10 03:18:28	2020-07-10	9	[{"id_menu":7,"count":1}]	36390	delivery	5	14
93370	2020-07-10 03:24:42	2020-07-10	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	19328	delivery	5	30
93371	2020-07-10 03:25:31	2020-07-10	9	[{"id_menu":6,"count":1}]	7129	delivery	5	14
93372	2020-07-10 03:26:00	2020-07-10	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14984	delivery	5	35
93373	2020-07-10 03:27:54	2020-07-10	9	[{"id_menu":6,"count":1}]	22732	pick-up	0	9
93374	2020-07-10 03:28:28	2020-07-10	9	[{"id_menu":6,"count":1}]	3705	delivery	5	14
93375	2020-07-10 03:36:12	2020-07-10	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8987	delivery	5	57
93376	2020-07-10 03:44:30	2020-07-10	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	2605	delivery	5	40
93377	2020-07-10 03:46:15	2020-07-10	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33203	delivery	5	37
93378	2020-07-10 03:50:01	2020-07-10	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	25123	delivery	5	26
93379	2020-07-10 03:50:16	2020-07-10	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	36379	delivery	5	22
93380	2020-07-10 03:53:02	2020-07-10	12	[{"id_menu":3,"count":1}]	5473	pick-up	0	12
93381	2020-07-10 03:58:33	2020-07-10	17	[{"id_menu":4,"count":1}]	36405	delivery	5	22
93382	2020-07-10 04:01:08	2020-07-10	17	[{"id_menu":4,"count":1}]	30391	delivery	5	22
93383	2020-07-10 04:01:42	2020-07-10	14	[{"id_menu":2,"count":1}]	30489	delivery	5	19
93384	2020-07-10 04:02:36	2020-07-10	9	[{"id_menu":7,"count":1}]	8242	delivery	5	14
93385	2020-07-10 04:02:40	2020-07-10	12	[{"id_menu":3,"count":1}]	36278	delivery	5	17
93386	2020-07-10 04:05:03	2020-07-10	17	[{"id_menu":4,"count":1}]	35892	delivery	5	22
93387	2020-07-10 04:05:55	2020-07-10	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	36305	delivery	5	39
93388	2020-07-10 04:08:30	2020-07-10	9	[{"id_menu":6,"count":2}]	36487	delivery	5	14
93389	2020-07-10 04:08:51	2020-07-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	36418	delivery	5	28
93390	2020-07-10 04:11:34	2020-07-10	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27718	delivery	5	34
93391	2020-07-10 04:13:43	2020-07-10	8	[{"id_menu":5,"count":1}]	36419	delivery	5	13
93392	2020-07-10 04:17:23	2020-07-10	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	31353	delivery	5	30
93393	2020-07-10 04:18:08	2020-07-10	12	[{"id_menu":1,"count":1}]	14972	delivery	5	17
93394	2020-07-10 04:20:47	2020-07-10	12	[{"id_menu":1,"count":1}]	4617	pick-up	0	12
93395	2020-07-10 04:20:47	2020-07-10	8	[{"id_menu":5,"count":1}]	36389	delivery	5	13
93396	2020-07-10 04:23:22	2020-07-10	8	[{"id_menu":5,"count":1}]	29782	delivery	5	13
93397	2020-07-10 04:25:05	2020-07-10	9	[{"id_menu":7,"count":1}]	36321	delivery	5	14
93398	2020-07-10 04:27:09	2020-07-10	9	[{"id_menu":6,"count":1}]	24094	delivery	5	14
93399	2020-07-10 04:30:35	2020-07-10	9	[{"id_menu":7,"count":1}]	34196	delivery	5	14
93400	2020-07-10 04:32:29	2020-07-10	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	24332	delivery	5	40
93401	2020-07-10 04:33:51	2020-07-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	29743	delivery	5	22
93402	2020-07-10 04:36:15	2020-07-10	14	[{"id_menu":2,"count":1}]	28158	pick-up	0	14
93403	2020-07-10 04:36:26	2020-07-10	12	[{"id_menu":3,"count":1}]	36306	delivery	5	17
93404	2020-07-10 04:43:06	2020-07-10	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32686	delivery	5	40
93405	2020-07-10 04:43:18	2020-07-10	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	10461	delivery	5	34
93406	2020-07-10 04:56:33	2020-07-10	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3707	delivery	5	22
93407	2020-07-10 04:58:55	2020-07-10	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10692	delivery	5	46
93408	2020-07-10 04:59:34	2020-07-10	12	[{"id_menu":1,"count":1}]	27677	delivery	5	17
93409	2020-07-10 04:59:53	2020-07-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14027	pick-up	0	18
93410	2020-07-10 05:00:20	2020-07-10	8	[{"id_menu":5,"count":1}]	36375	delivery	5	13
93411	2020-07-10 05:01:45	2020-07-10	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	36261	pick-up	0	21
93412	2020-07-10 05:02:16	2020-07-10	8	[{"id_menu":5,"count":1}]	18929	delivery	5	13
93413	2020-07-10 05:03:22	2020-07-10	29	[{"id_menu":3,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	36461	delivery	5	34
93414	2020-07-10 05:07:31	2020-07-10	17	[{"id_menu":4,"count":1}]	36260	delivery	5	22
93415	2020-07-10 05:09:16	2020-07-10	12	[{"id_menu":1,"count":1}]	22784	delivery	5	17
93416	2020-07-10 05:12:08	2020-07-10	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	36296	delivery	5	26
93417	2020-07-10 05:13:14	2020-07-10	8	[{"id_menu":5,"count":2}]	36377	delivery	5	13
93418	2020-07-10 05:17:20	2020-07-10	14	[{"id_menu":2,"count":1}]	24430	delivery	5	19
93419	2020-07-10 05:17:38	2020-07-10	12	[{"id_menu":3,"count":1}]	13076	delivery	5	17
93420	2020-07-10 05:17:52	2020-07-10	12	[{"id_menu":1,"count":1}]	36256	delivery	5	17
93421	2020-07-10 05:18:40	2020-07-10	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":2}]	36499	delivery	5	22
93422	2020-07-10 05:19:49	2020-07-10	9	[{"id_menu":6,"count":1}]	35795	delivery	5	14
93423	2020-07-10 05:20:43	2020-07-10	8	[{"id_menu":5,"count":1}]	36443	delivery	5	13
93424	2020-07-10 05:26:27	2020-07-10	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	36493	delivery	5	37
93425	2020-07-10 05:30:29	2020-07-10	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	702	delivery	5	25
93426	2020-07-10 05:30:40	2020-07-10	8	[{"id_menu":5,"count":1}]	26338	delivery	5	13
93427	2020-07-10 05:31:45	2020-07-10	12	[{"id_menu":1,"count":1}]	2134	pick-up	0	12
93428	2020-07-10 05:44:14	2020-07-10	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	36442	delivery	5	51
93429	2020-07-10 05:46:17	2020-07-10	8	[{"id_menu":5,"count":1}]	32809	delivery	5	13
93430	2020-07-10 05:50:04	2020-07-10	14	[{"id_menu":2,"count":1}]	36440	delivery	5	19
93431	2020-07-10 05:50:59	2020-07-10	9	[{"id_menu":7,"count":1}]	21298	delivery	5	14
93432	2020-07-10 05:53:17	2020-07-10	9	[{"id_menu":7,"count":1}]	36293	delivery	5	14
93433	2020-07-10 05:58:00	2020-07-10	8	[{"id_menu":5,"count":1}]	32764	delivery	5	13
93434	2020-07-10 05:58:15	2020-07-10	12	[{"id_menu":1,"count":1}]	33251	pick-up	0	12
93435	2020-07-10 06:01:32	2020-07-10	14	[{"id_menu":2,"count":1}]	19529	delivery	5	19
93436	2020-07-10 06:01:43	2020-07-10	8	[{"id_menu":5,"count":1}]	35772	delivery	5	13
93437	2020-07-10 06:06:48	2020-07-10	9	[{"id_menu":6,"count":1}]	2599	delivery	5	14
93438	2020-07-10 06:14:52	2020-07-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	19622	delivery	5	28
93439	2020-07-10 06:15:16	2020-07-10	12	[{"id_menu":3,"count":1}]	4021	pick-up	0	12
93440	2020-07-10 06:15:37	2020-07-10	14	[{"id_menu":2,"count":1}]	1756	delivery	5	19
93441	2020-07-10 06:16:36	2020-07-10	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6399	delivery	5	22
93442	2020-07-10 06:18:27	2020-07-10	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6202	pick-up	0	35
93443	2020-07-10 06:21:37	2020-07-10	14	[{"id_menu":2,"count":1}]	12413	delivery	5	19
93444	2020-07-10 06:31:52	2020-07-10	8	[{"id_menu":5,"count":1}]	36318	delivery	5	13
93445	2020-07-10 06:36:28	2020-07-10	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5527	delivery	5	45
93446	2020-07-10 06:37:30	2020-07-10	9	[{"id_menu":7,"count":1}]	13607	delivery	5	14
93447	2020-07-10 06:37:44	2020-07-10	9	[{"id_menu":6,"count":1}]	36396	delivery	5	14
93448	2020-07-10 06:41:56	2020-07-10	12	[{"id_menu":1,"count":1}]	32861	delivery	5	17
93449	2020-07-10 06:42:56	2020-07-10	8	[{"id_menu":5,"count":1}]	34490	delivery	5	13
93450	2020-07-10 06:44:18	2020-07-10	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36483	delivery	5	45
93451	2020-07-10 06:45:50	2020-07-10	8	[{"id_menu":5,"count":1}]	36449	delivery	5	13
93452	2020-07-10 06:48:23	2020-07-10	14	[{"id_menu":2,"count":1}]	36263	delivery	5	19
93453	2020-07-10 06:49:38	2020-07-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	20188	delivery	5	28
93454	2020-07-10 06:49:40	2020-07-10	9	[{"id_menu":6,"count":1}]	18251	delivery	5	14
93455	2020-07-10 06:51:06	2020-07-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7802	delivery	5	23
93456	2020-07-10 06:52:04	2020-07-10	9	[{"id_menu":7,"count":1}]	36272	delivery	5	14
93457	2020-07-10 06:52:05	2020-07-10	14	[{"id_menu":2,"count":1}]	32386	delivery	5	19
93458	2020-07-10 06:52:25	2020-07-10	9	[{"id_menu":7,"count":1}]	1094	delivery	5	14
93459	2020-07-10 06:54:34	2020-07-10	9	[{"id_menu":6,"count":1}]	9920	pick-up	0	9
93460	2020-07-10 06:56:21	2020-07-10	9	[{"id_menu":6,"count":2}]	36498	delivery	5	14
93461	2020-07-10 06:56:43	2020-07-10	9	[{"id_menu":7,"count":1}]	36341	delivery	5	14
93462	2020-07-10 06:56:53	2020-07-10	9	[{"id_menu":7,"count":1}]	12145	delivery	5	14
93463	2020-07-10 06:59:53	2020-07-10	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	184	pick-up	0	35
93464	2020-07-10 07:01:45	2020-07-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	14891	delivery	5	28
93465	2020-07-10 07:07:28	2020-07-10	9	[{"id_menu":7,"count":1}]	36432	delivery	5	14
93466	2020-07-10 07:10:23	2020-07-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	17605	delivery	5	22
93467	2020-07-10 07:13:32	2020-07-10	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36289	delivery	5	35
93468	2020-07-10 07:14:15	2020-07-10	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	19822	delivery	5	26
93469	2020-07-10 07:14:49	2020-07-10	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1761	pick-up	0	21
93470	2020-07-10 07:18:01	2020-07-10	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	36429	delivery	5	31
93471	2020-07-10 07:20:34	2020-07-10	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21278	delivery	5	35
93472	2020-07-10 07:22:09	2020-07-10	14	[{"id_menu":2,"count":1}]	36462	delivery	5	19
93473	2020-07-10 07:23:18	2020-07-10	12	[{"id_menu":3,"count":1}]	1273	pick-up	0	12
93474	2020-07-10 07:24:43	2020-07-10	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	36353	delivery	5	22
93475	2020-07-10 07:25:57	2020-07-10	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	36410	delivery	5	38
93476	2020-07-10 07:33:18	2020-07-10	17	[{"id_menu":4,"count":1}]	27820	delivery	5	22
93477	2020-07-10 07:38:37	2020-07-10	9	[{"id_menu":6,"count":1}]	25804	delivery	5	14
93478	2020-07-10 07:39:16	2020-07-10	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	36457	delivery	5	28
93479	2020-07-10 07:41:14	2020-07-10	9	[{"id_menu":6,"count":1}]	35947	delivery	5	14
93480	2020-07-10 07:42:14	2020-07-10	9	[{"id_menu":7,"count":1}]	13634	delivery	5	14
93481	2020-07-10 07:49:36	2020-07-10	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25816	pick-up	0	30
93482	2020-07-10 07:49:51	2020-07-10	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	33149	delivery	5	36
93483	2020-07-10 07:56:01	2020-07-10	55	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	14568	pick-up	0	55
93484	2020-07-10 07:56:08	2020-07-10	14	[{"id_menu":2,"count":1}]	28777	pick-up	0	14
93485	2020-07-10 07:57:10	2020-07-10	14	[{"id_menu":2,"count":1}]	17520	delivery	5	19
93486	2020-07-10 08:05:26	2020-07-10	12	[{"id_menu":1,"count":1}]	23763	delivery	5	17
93487	2020-07-10 08:11:27	2020-07-10	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":2}]	15769	pick-up	0	21
93488	2020-07-10 08:13:18	2020-07-10	12	[{"id_menu":1,"count":1}]	9193	delivery	5	17
93489	2020-07-10 08:16:44	2020-07-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	36376	delivery	5	22
93490	2020-07-10 08:25:10	2020-07-10	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	14650	delivery	5	26
93491	2020-07-10 08:25:11	2020-07-10	17	[{"id_menu":4,"count":1}]	25945	delivery	5	22
93492	2020-07-10 08:25:53	2020-07-10	9	[{"id_menu":7,"count":1}]	36332	delivery	5	14
93493	2020-07-10 08:28:15	2020-07-10	8	[{"id_menu":5,"count":1}]	36245	delivery	5	13
93494	2020-07-10 08:29:22	2020-07-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	15677	delivery	5	28
93495	2020-07-10 08:30:07	2020-07-10	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	31078	delivery	5	29
93496	2020-07-10 08:36:15	2020-07-10	9	[{"id_menu":6,"count":1}]	36346	delivery	5	14
93497	2020-07-10 08:36:44	2020-07-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4036	delivery	5	22
93498	2020-07-10 08:37:14	2020-07-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	27775	delivery	5	28
93499	2020-07-10 08:39:33	2020-07-10	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	24129	pick-up	0	22
93500	2020-07-10 08:39:40	2020-07-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	36330	delivery	5	23
93501	2020-07-10 08:39:42	2020-07-10	9	[{"id_menu":7,"count":1}]	14257	delivery	5	14
93502	2020-07-10 08:48:21	2020-07-10	8	[{"id_menu":5,"count":1}]	7772	pick-up	0	8
93503	2020-07-10 08:49:30	2020-07-10	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	36298	pick-up	0	17
93504	2020-07-10 09:00:11	2020-07-10	8	[{"id_menu":5,"count":1}]	15000	delivery	5	13
93505	2020-07-10 09:00:41	2020-07-10	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	4695	delivery	5	26
93506	2020-07-10 09:02:45	2020-07-10	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	36352	delivery	5	37
93507	2020-07-10 09:02:48	2020-07-10	12	[{"id_menu":3,"count":1}]	14696	delivery	5	17
93508	2020-07-10 09:08:49	2020-07-10	8	[{"id_menu":5,"count":1}]	31631	delivery	5	13
93509	2020-07-10 09:09:57	2020-07-10	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	36354	delivery	5	46
93510	2020-07-10 09:10:15	2020-07-10	9	[{"id_menu":7,"count":1}]	1330	pick-up	0	9
93511	2020-07-10 09:19:20	2020-07-10	14	[{"id_menu":2,"count":1}]	7500	delivery	5	19
93512	2020-07-10 09:21:46	2020-07-10	17	[{"id_menu":4,"count":2}]	29524	delivery	5	22
93513	2020-07-10 09:23:21	2020-07-10	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	36401	delivery	5	26
93514	2020-07-10 09:31:46	2020-07-10	12	[{"id_menu":3,"count":1}]	1731	delivery	5	17
93515	2020-07-10 09:33:38	2020-07-10	12	[{"id_menu":1,"count":1}]	36269	delivery	5	17
93516	2020-07-10 09:34:47	2020-07-10	17	[{"id_menu":4,"count":1}]	36268	delivery	5	22
93517	2020-07-10 09:36:53	2020-07-10	8	[{"id_menu":5,"count":1}]	36407	pick-up	0	8
93518	2020-07-10 09:36:53	2020-07-10	17	[{"id_menu":4,"count":1}]	36416	delivery	5	22
93519	2020-07-10 09:39:35	2020-07-10	8	[{"id_menu":5,"count":1}]	34969	delivery	5	13
93520	2020-07-10 09:41:28	2020-07-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	30922	delivery	5	28
93521	2020-07-10 09:57:31	2020-07-10	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	6843	pick-up	0	21
93522	2020-07-10 09:58:26	2020-07-10	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	36384	delivery	5	31
93523	2020-07-10 09:59:26	2020-07-10	8	[{"id_menu":5,"count":1}]	33081	delivery	5	13
93524	2020-07-10 10:03:32	2020-07-10	12	[{"id_menu":3,"count":3}]	36395	delivery	5	17
93525	2020-07-10 10:05:14	2020-07-10	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	36391	delivery	5	34
93526	2020-07-10 10:09:11	2020-07-10	12	[{"id_menu":1,"count":1}]	17241	delivery	5	17
93527	2020-07-10 10:09:31	2020-07-10	9	[{"id_menu":6,"count":1}]	3521	delivery	5	14
93528	2020-07-10 10:10:33	2020-07-10	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	6440	pick-up	0	24
93529	2020-07-10 10:14:01	2020-07-10	9	[{"id_menu":7,"count":1}]	8629	delivery	5	14
93530	2020-07-10 10:16:01	2020-07-10	9	[{"id_menu":7,"count":1}]	5975	delivery	5	14
93531	2020-07-10 10:20:35	2020-07-10	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	14354	delivery	5	52
93532	2020-07-10 10:30:21	2020-07-10	17	[{"id_menu":4,"count":1}]	30437	delivery	5	22
93533	2020-07-10 10:31:38	2020-07-10	9	[{"id_menu":6,"count":1}]	36365	delivery	5	14
93534	2020-07-10 10:32:11	2020-07-10	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36300	delivery	5	35
93535	2020-07-10 10:33:38	2020-07-10	9	[{"id_menu":6,"count":1}]	3780	pick-up	0	9
93536	2020-07-10 10:33:40	2020-07-10	9	[{"id_menu":6,"count":1}]	5253	delivery	5	14
93537	2020-07-10 10:34:58	2020-07-10	9	[{"id_menu":7,"count":1}]	36400	delivery	5	14
93538	2020-07-10 10:36:26	2020-07-10	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	36486	delivery	5	39
93539	2020-07-10 10:36:57	2020-07-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	35230	delivery	5	28
93540	2020-07-10 10:38:12	2020-07-10	17	[{"id_menu":4,"count":1}]	136	pick-up	0	17
93541	2020-07-10 10:39:37	2020-07-10	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	19987	delivery	5	57
93542	2020-07-10 10:46:09	2020-07-10	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	21606	pick-up	0	24
93543	2020-07-10 10:53:02	2020-07-10	12	[{"id_menu":3,"count":1}]	22175	delivery	5	17
93544	2020-07-10 10:54:07	2020-07-10	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	36324	delivery	5	44
93545	2020-07-10 10:54:47	2020-07-10	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	36451	delivery	5	29
93546	2020-07-10 10:56:40	2020-07-10	12	[{"id_menu":1,"count":1}]	4872	pick-up	0	12
93547	2020-07-10 10:59:42	2020-07-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36455	delivery	5	23
93548	2020-07-10 11:05:14	2020-07-10	17	[{"id_menu":4,"count":1}]	36132	delivery	5	22
93549	2020-07-10 11:06:49	2020-07-10	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	21849	pick-up	0	29
93550	2020-07-10 11:07:27	2020-07-10	8	[{"id_menu":5,"count":1}]	812	delivery	5	13
93551	2020-07-10 11:11:55	2020-07-10	12	[{"id_menu":3,"count":1}]	22004	delivery	5	17
93552	2020-07-10 11:17:13	2020-07-10	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17014	delivery	5	55
93553	2020-07-10 11:17:48	2020-07-10	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2309	pick-up	0	26
93554	2020-07-10 11:19:54	2020-07-10	17	[{"id_menu":4,"count":1}]	655	delivery	5	22
93555	2020-07-10 11:20:17	2020-07-10	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	15563	delivery	5	31
93556	2020-07-10 11:21:22	2020-07-10	17	[{"id_menu":4,"count":1}]	36297	pick-up	0	17
93557	2020-07-10 11:21:43	2020-07-10	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12532	pick-up	0	26
93558	2020-07-10 11:23:18	2020-07-10	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36247	delivery	5	37
93559	2020-07-10 11:23:30	2020-07-10	14	[{"id_menu":2,"count":1}]	31959	delivery	5	19
93560	2020-07-10 11:28:33	2020-07-10	9	[{"id_menu":6,"count":1}]	36378	delivery	5	14
93561	2020-07-10 11:29:55	2020-07-10	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	3984	delivery	5	29
93562	2020-07-10 11:30:41	2020-07-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	15603	delivery	5	23
93563	2020-07-10 11:32:43	2020-07-10	14	[{"id_menu":2,"count":1}]	27655	pick-up	0	14
93564	2020-07-10 11:39:10	2020-07-10	14	[{"id_menu":2,"count":1}]	2450	pick-up	0	14
93565	2020-07-10 11:39:27	2020-07-10	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	36367	pick-up	0	25
93566	2020-07-10 11:39:41	2020-07-10	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	23178	delivery	5	22
93567	2020-07-10 11:41:25	2020-07-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	27156	delivery	5	28
93568	2020-07-10 11:46:17	2020-07-10	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9312	delivery	5	42
93569	2020-07-10 11:51:00	2020-07-10	8	[{"id_menu":5,"count":1}]	11833	pick-up	0	8
93570	2020-07-10 11:54:49	2020-07-10	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	36360	delivery	5	40
93571	2020-07-10 11:55:04	2020-07-10	17	[{"id_menu":4,"count":1}]	28971	pick-up	0	17
93572	2020-07-10 11:55:58	2020-07-10	14	[{"id_menu":2,"count":1}]	36327	delivery	5	19
93573	2020-07-10 11:57:30	2020-07-10	17	[{"id_menu":4,"count":1}]	8149	delivery	5	22
93574	2020-07-10 12:00:48	2020-07-10	8	[{"id_menu":5,"count":1}]	36328	delivery	5	13
93575	2020-07-10 12:05:28	2020-07-10	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1296	pick-up	0	31
93576	2020-07-10 12:08:33	2020-07-10	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3597	delivery	5	35
93577	2020-07-10 12:10:53	2020-07-10	12	[{"id_menu":3,"count":1}]	35740	pick-up	0	12
93578	2020-07-10 12:14:35	2020-07-10	9	[{"id_menu":6,"count":1}]	33180	pick-up	0	9
93579	2020-07-10 12:16:42	2020-07-10	14	[{"id_menu":2,"count":1}]	17540	pick-up	0	14
93580	2020-07-10 12:24:05	2020-07-10	12	[{"id_menu":1,"count":1}]	3577	pick-up	0	12
93581	2020-07-10 12:24:34	2020-07-10	9	[{"id_menu":7,"count":1}]	29945	delivery	5	14
93582	2020-07-10 12:25:05	2020-07-10	12	[{"id_menu":3,"count":1}]	17351	pick-up	0	12
93583	2020-07-10 12:26:42	2020-07-10	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	10310	delivery	5	45
93584	2020-07-10 12:28:22	2020-07-10	30	[{"id_menu":3,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36480	delivery	5	35
93585	2020-07-10 12:28:45	2020-07-10	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	36497	pick-up	0	29
93586	2020-07-10 12:29:22	2020-07-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	32455	delivery	5	28
93587	2020-07-10 12:30:27	2020-07-10	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	36430	delivery	5	38
93588	2020-07-10 12:31:00	2020-07-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24787	delivery	5	22
93589	2020-07-10 12:31:20	2020-07-10	14	[{"id_menu":2,"count":1}]	17460	pick-up	0	14
93590	2020-07-10 12:37:17	2020-07-10	8	[{"id_menu":5,"count":1}]	36447	delivery	5	13
93591	2020-07-10 12:39:56	2020-07-10	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21107	delivery	5	35
93592	2020-07-10 12:40:59	2020-07-10	12	[{"id_menu":1,"count":1}]	698	delivery	5	17
93593	2020-07-10 12:41:46	2020-07-10	8	[{"id_menu":5,"count":1}]	13254	delivery	5	13
93594	2020-07-10 12:48:57	2020-07-10	12	[{"id_menu":1,"count":1}]	22313	pick-up	0	12
93595	2020-07-10 12:50:50	2020-07-10	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24473	delivery	5	48
93596	2020-07-10 12:53:56	2020-07-10	9	[{"id_menu":6,"count":1}]	7756	delivery	5	14
93597	2020-07-10 12:56:56	2020-07-10	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	11691	delivery	5	26
93598	2020-07-10 12:58:19	2020-07-10	12	[{"id_menu":1,"count":1}]	12019	pick-up	0	12
93599	2020-07-10 12:59:26	2020-07-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	20457	delivery	5	28
93600	2020-07-10 13:01:47	2020-07-10	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	30291	delivery	5	51
93601	2020-07-10 13:04:45	2020-07-10	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	36445	delivery	5	42
93602	2020-07-10 13:05:00	2020-07-10	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6883	delivery	5	35
93603	2020-07-10 13:07:33	2020-07-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	26066	delivery	5	28
93604	2020-07-10 13:09:40	2020-07-10	9	[{"id_menu":6,"count":1}]	4199	delivery	5	14
93605	2020-07-10 13:10:27	2020-07-10	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	31684	delivery	5	27
93606	2020-07-10 13:12:26	2020-07-10	12	[{"id_menu":1,"count":1}]	18155	delivery	5	17
93607	2020-07-10 13:12:51	2020-07-10	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	24254	delivery	5	34
93608	2020-07-10 13:18:42	2020-07-10	12	[{"id_menu":3,"count":1}]	32162	delivery	5	17
93609	2020-07-10 13:19:33	2020-07-10	17	[{"id_menu":4,"count":1}]	27019	pick-up	0	17
93610	2020-07-10 13:20:19	2020-07-10	12	[{"id_menu":1,"count":1}]	25788	delivery	5	17
93611	2020-07-10 13:25:08	2020-07-10	9	[{"id_menu":6,"count":1}]	8230	delivery	5	14
93612	2020-07-10 13:30:35	2020-07-10	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	5131	pick-up	0	26
93613	2020-07-10 13:31:43	2020-07-10	17	[{"id_menu":4,"count":1}]	36479	delivery	5	22
93614	2020-07-10 13:32:59	2020-07-10	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2874	pick-up	0	25
93615	2020-07-10 13:33:07	2020-07-10	14	[{"id_menu":2,"count":1}]	21934	delivery	5	19
93616	2020-07-10 13:38:41	2020-07-10	8	[{"id_menu":5,"count":1}]	36339	delivery	5	13
93617	2020-07-10 13:40:05	2020-07-10	12	[{"id_menu":3,"count":1}]	25367	pick-up	0	12
93618	2020-07-10 13:46:00	2020-07-10	14	[{"id_menu":2,"count":1}]	1929	delivery	5	19
93619	2020-07-10 13:46:47	2020-07-10	17	[{"id_menu":4,"count":1}]	17421	delivery	5	22
93620	2020-07-10 13:47:27	2020-07-10	9	[{"id_menu":6,"count":1}]	36311	pick-up	0	9
93621	2020-07-10 13:50:24	2020-07-10	17	[{"id_menu":4,"count":1}]	14918	pick-up	0	17
93622	2020-07-10 13:50:25	2020-07-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3332	pick-up	0	23
93623	2020-07-10 13:53:14	2020-07-10	17	[{"id_menu":4,"count":1}]	23424	pick-up	0	17
93624	2020-07-10 13:55:15	2020-07-10	9	[{"id_menu":6,"count":1}]	3948	pick-up	0	9
93625	2020-07-10 14:01:26	2020-07-10	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36505	delivery	5	31
93626	2020-07-10 14:02:08	2020-07-10	14	[{"id_menu":2,"count":1}]	28099	pick-up	0	14
93627	2020-07-10 14:05:06	2020-07-10	9	[{"id_menu":6,"count":1}]	36463	delivery	5	14
93628	2020-07-10 14:07:58	2020-07-10	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	36267	delivery	5	22
93629	2020-07-10 14:14:09	2020-07-10	14	[{"id_menu":2,"count":1}]	19652	delivery	5	19
93630	2020-07-10 14:19:37	2020-07-10	14	[{"id_menu":2,"count":1}]	4655	delivery	5	19
93631	2020-07-10 14:20:12	2020-07-10	8	[{"id_menu":5,"count":2}]	36281	delivery	5	13
93632	2020-07-10 14:24:13	2020-07-10	12	[{"id_menu":1,"count":1}]	2162	pick-up	0	12
93633	2020-07-10 14:30:26	2020-07-10	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	33776	delivery	5	40
93634	2020-07-10 14:32:54	2020-07-10	14	[{"id_menu":2,"count":1}]	36472	pick-up	0	14
93635	2020-07-10 14:33:09	2020-07-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	26968	delivery	5	22
93636	2020-07-10 14:34:29	2020-07-10	8	[{"id_menu":5,"count":1}]	36368	delivery	5	13
93637	2020-07-10 14:34:34	2020-07-10	12	[{"id_menu":3,"count":2}]	36481	delivery	5	17
93638	2020-07-10 14:38:43	2020-07-10	9	[{"id_menu":7,"count":1}]	36276	delivery	5	14
93639	2020-07-10 14:41:10	2020-07-10	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	14360	delivery	5	39
93640	2020-07-10 14:42:13	2020-07-10	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	34779	delivery	5	51
93641	2020-07-10 14:45:35	2020-07-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1239	pick-up	0	23
93642	2020-07-10 14:50:40	2020-07-10	8	[{"id_menu":5,"count":1}]	36253	delivery	5	13
93643	2020-07-10 14:52:25	2020-07-10	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	18234	delivery	5	26
93644	2020-07-10 14:58:32	2020-07-10	9	[{"id_menu":7,"count":1}]	26392	delivery	5	14
93645	2020-07-10 14:59:14	2020-07-10	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	9215	delivery	5	27
93646	2020-07-10 15:02:00	2020-07-10	8	[{"id_menu":5,"count":1}]	30658	delivery	5	13
93647	2020-07-10 15:06:53	2020-07-10	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	36490	delivery	5	36
93648	2020-07-10 15:11:04	2020-07-10	9	[{"id_menu":6,"count":1}]	24223	delivery	5	14
93649	2020-07-10 15:11:59	2020-07-10	17	[{"id_menu":4,"count":1}]	14081	delivery	5	22
93650	2020-07-10 15:12:32	2020-07-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	36372	delivery	5	28
93651	2020-07-10 15:12:54	2020-07-10	8	[{"id_menu":5,"count":1}]	292	delivery	5	13
93652	2020-07-10 15:13:47	2020-07-10	9	[{"id_menu":7,"count":1}]	16543	delivery	5	14
93653	2020-07-10 15:22:01	2020-07-10	14	[{"id_menu":2,"count":1}]	15902	delivery	5	19
93654	2020-07-10 15:24:37	2020-07-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15782	delivery	5	22
93655	2020-07-10 15:28:40	2020-07-10	14	[{"id_menu":2,"count":1}]	108	pick-up	0	14
93656	2020-07-10 15:30:04	2020-07-10	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6421	delivery	5	31
93657	2020-07-10 15:30:34	2020-07-10	12	[{"id_menu":3,"count":1}]	18067	delivery	5	17
93658	2020-07-10 15:32:24	2020-07-10	8	[{"id_menu":5,"count":1}]	12942	delivery	5	13
93659	2020-07-10 15:32:29	2020-07-10	17	[{"id_menu":4,"count":1}]	14463	pick-up	0	17
93660	2020-07-10 15:32:59	2020-07-10	14	[{"id_menu":2,"count":1}]	3909	pick-up	0	14
93661	2020-07-10 15:34:08	2020-07-10	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	36303	delivery	5	39
93662	2020-07-10 15:34:08	2020-07-10	14	[{"id_menu":2,"count":1}]	6250	delivery	5	19
93663	2020-07-10 15:36:54	2020-07-10	14	[{"id_menu":2,"count":1}]	36413	delivery	5	19
93664	2020-07-10 15:38:51	2020-07-10	17	[{"id_menu":4,"count":1}]	22126	delivery	5	22
93665	2020-07-10 15:44:46	2020-07-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5041	pick-up	0	18
93666	2020-07-10 15:47:05	2020-07-10	8	[{"id_menu":5,"count":1}]	2331	delivery	5	13
93667	2020-07-10 15:48:27	2020-07-10	17	[{"id_menu":4,"count":1}]	31129	delivery	5	22
93668	2020-07-10 15:50:55	2020-07-10	9	[{"id_menu":7,"count":1}]	9739	pick-up	0	9
93669	2020-07-10 15:52:58	2020-07-10	9	[{"id_menu":6,"count":1}]	14237	delivery	5	14
93670	2020-07-10 15:59:42	2020-07-10	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	36299	pick-up	0	38
93671	2020-07-10 16:02:33	2020-07-10	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	36358	pick-up	0	31
93672	2020-07-10 16:07:56	2020-07-10	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	36325	delivery	5	31
93673	2020-07-10 16:09:13	2020-07-10	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23642	delivery	5	22
93674	2020-07-10 16:10:01	2020-07-10	8	[{"id_menu":5,"count":1}]	36295	delivery	5	13
93675	2020-07-10 16:11:12	2020-07-10	12	[{"id_menu":3,"count":1}]	8320	delivery	5	17
93676	2020-07-10 16:12:15	2020-07-10	17	[{"id_menu":4,"count":1}]	18423	delivery	5	22
93677	2020-07-10 16:20:49	2020-07-10	17	[{"id_menu":4,"count":1}]	12174	delivery	5	22
93678	2020-07-10 16:22:00	2020-07-10	14	[{"id_menu":2,"count":1}]	4622	delivery	5	19
93679	2020-07-10 16:24:48	2020-07-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36302	delivery	5	23
93680	2020-07-10 16:25:00	2020-07-10	9	[{"id_menu":7,"count":1}]	3087	delivery	5	14
93681	2020-07-10 16:27:04	2020-07-10	8	[{"id_menu":5,"count":1}]	28122	delivery	5	13
93682	2020-07-10 16:43:38	2020-07-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	36246	delivery	5	22
93683	2020-07-10 16:49:36	2020-07-10	12	[{"id_menu":1,"count":1}]	32592	delivery	5	17
93684	2020-07-10 16:55:29	2020-07-10	12	[{"id_menu":3,"count":1}]	14797	delivery	5	17
93685	2020-07-10 16:56:32	2020-07-10	9	[{"id_menu":6,"count":1}]	21867	pick-up	0	9
93686	2020-07-10 16:59:38	2020-07-10	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	34485	delivery	5	27
93687	2020-07-10 17:04:18	2020-07-10	9	[{"id_menu":7,"count":1}]	12783	delivery	5	14
93688	2020-07-10 17:04:22	2020-07-10	8	[{"id_menu":5,"count":1}]	2232	pick-up	0	8
93689	2020-07-10 17:04:51	2020-07-10	14	[{"id_menu":2,"count":1}]	31957	pick-up	0	14
93690	2020-07-10 17:08:08	2020-07-10	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":2}]	13606	delivery	5	29
93691	2020-07-10 17:08:09	2020-07-10	12	[{"id_menu":3,"count":1}]	2526	pick-up	0	12
93692	2020-07-10 17:08:54	2020-07-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	32640	delivery	5	28
93693	2020-07-10 17:09:56	2020-07-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36271	delivery	5	23
93694	2020-07-10 17:11:34	2020-07-10	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22863	delivery	5	35
93695	2020-07-10 17:16:00	2020-07-10	9	[{"id_menu":6,"count":1}]	3534	delivery	5	14
93696	2020-07-10 17:20:44	2020-07-10	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	36491	delivery	5	34
93697	2020-07-10 17:20:45	2020-07-10	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	36404	delivery	5	40
93698	2020-07-10 17:29:53	2020-07-10	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7896	delivery	5	45
93699	2020-07-10 17:35:02	2020-07-10	17	[{"id_menu":4,"count":1}]	5110	delivery	5	22
93700	2020-07-10 17:35:54	2020-07-10	8	[{"id_menu":5,"count":1}]	3168	pick-up	0	8
93701	2020-07-10 17:38:24	2020-07-10	8	[{"id_menu":5,"count":1}]	7953	delivery	5	13
93702	2020-07-10 17:39:18	2020-07-10	8	[{"id_menu":5,"count":1}]	6910	pick-up	0	8
93703	2020-07-10 17:42:16	2020-07-10	14	[{"id_menu":2,"count":1}]	36448	delivery	5	19
93704	2020-07-10 17:42:43	2020-07-10	8	[{"id_menu":5,"count":1}]	1293	delivery	5	13
93705	2020-07-10 17:45:30	2020-07-10	9	[{"id_menu":6,"count":1}]	7525	delivery	5	14
93706	2020-07-10 17:46:45	2020-07-10	14	[{"id_menu":2,"count":1}]	16404	delivery	5	19
93707	2020-07-10 17:49:58	2020-07-10	12	[{"id_menu":3,"count":1}]	5768	delivery	5	17
93708	2020-07-10 17:54:04	2020-07-10	12	[{"id_menu":1,"count":1}]	36476	delivery	5	17
93709	2020-07-10 17:55:41	2020-07-10	14	[{"id_menu":2,"count":1}]	36433	delivery	5	19
93710	2020-07-10 17:56:39	2020-07-10	14	[{"id_menu":2,"count":1}]	36244	pick-up	0	14
93711	2020-07-10 17:58:53	2020-07-10	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":2}]	23696	pick-up	0	17
93712	2020-07-10 18:05:53	2020-07-10	9	[{"id_menu":7,"count":1}]	9500	delivery	5	14
93713	2020-07-10 18:11:28	2020-07-10	14	[{"id_menu":2,"count":1}]	27894	delivery	5	19
93714	2020-07-10 18:15:24	2020-07-10	9	[{"id_menu":6,"count":1}]	9603	pick-up	0	9
93715	2020-07-10 18:18:56	2020-07-10	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	36489	delivery	5	26
93716	2020-07-10 18:23:39	2020-07-10	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	36411	delivery	5	34
93717	2020-07-10 18:25:30	2020-07-10	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	36326	delivery	5	25
93718	2020-07-10 18:27:57	2020-07-10	8	[{"id_menu":5,"count":1}]	36323	delivery	5	13
93719	2020-07-10 18:28:33	2020-07-10	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	21894	delivery	5	31
93720	2020-07-10 18:32:30	2020-07-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9053	delivery	5	28
93721	2020-07-10 18:35:59	2020-07-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	31827	delivery	5	28
93722	2020-07-10 18:37:07	2020-07-10	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	13045	delivery	5	26
93723	2020-07-10 18:38:23	2020-07-10	12	[{"id_menu":3,"count":1}]	36283	delivery	5	17
93724	2020-07-10 18:40:54	2020-07-10	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	36452	delivery	5	34
93725	2020-07-10 18:42:57	2020-07-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2447	pick-up	0	18
93726	2020-07-10 18:43:06	2020-07-10	14	[{"id_menu":2,"count":1}]	26121	pick-up	0	14
93727	2020-07-10 18:44:32	2020-07-10	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	30687	pick-up	0	26
93728	2020-07-10 18:45:20	2020-07-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7858	delivery	5	22
93729	2020-07-10 18:47:03	2020-07-10	17	[{"id_menu":4,"count":1}]	10023	delivery	5	22
93730	2020-07-10 18:47:44	2020-07-10	8	[{"id_menu":5,"count":2}]	18450	delivery	5	13
93731	2020-07-10 18:51:31	2020-07-10	9	[{"id_menu":6,"count":1}]	389	delivery	5	14
93732	2020-07-10 18:59:06	2020-07-10	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	36477	delivery	5	43
93733	2020-07-10 18:59:45	2020-07-10	9	[{"id_menu":7,"count":1}]	36496	delivery	5	14
93734	2020-07-10 19:00:57	2020-07-10	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10827	delivery	5	22
93735	2020-07-10 19:01:13	2020-07-10	12	[{"id_menu":3,"count":1}]	36501	delivery	5	17
93736	2020-07-10 19:03:24	2020-07-10	12	[{"id_menu":1,"count":1}]	9716	pick-up	0	12
93737	2020-07-10 19:08:28	2020-07-10	12	[{"id_menu":1,"count":2}]	36351	delivery	5	17
93738	2020-07-10 19:08:59	2020-07-10	14	[{"id_menu":2,"count":1}]	9404	delivery	5	19
93739	2020-07-10 19:09:36	2020-07-10	12	[{"id_menu":1,"count":1}]	4630	delivery	5	17
93740	2020-07-10 19:10:23	2020-07-10	9	[{"id_menu":6,"count":1}]	765	pick-up	0	9
93741	2020-07-10 19:12:08	2020-07-10	8	[{"id_menu":5,"count":1}]	33793	delivery	5	13
93742	2020-07-10 19:16:43	2020-07-10	12	[{"id_menu":3,"count":1}]	2016	delivery	5	17
93743	2020-07-10 19:19:42	2020-07-10	9	[{"id_menu":7,"count":1}]	330	pick-up	0	9
93744	2020-07-10 19:19:49	2020-07-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10438	delivery	5	23
93745	2020-07-10 19:25:03	2020-07-10	8	[{"id_menu":5,"count":1}]	2287	delivery	5	13
93746	2020-07-10 19:25:24	2020-07-10	12	[{"id_menu":3,"count":1}]	6182	pick-up	0	12
93747	2020-07-10 19:26:01	2020-07-10	9	[{"id_menu":6,"count":1}]	31778	delivery	5	14
93748	2020-07-10 19:27:19	2020-07-10	9	[{"id_menu":7,"count":1}]	10263	delivery	5	14
93749	2020-07-10 19:31:53	2020-07-10	9	[{"id_menu":6,"count":1}]	36336	delivery	5	14
93750	2020-07-10 19:33:24	2020-07-10	9	[{"id_menu":6,"count":1}]	2956	pick-up	0	9
93751	2020-07-10 19:35:04	2020-07-10	12	[{"id_menu":3,"count":1}]	7125	delivery	5	17
93752	2020-07-10 19:37:51	2020-07-10	12	[{"id_menu":1,"count":1}]	1453	pick-up	0	12
93753	2020-07-10 19:40:43	2020-07-10	14	[{"id_menu":2,"count":1}]	12919	delivery	5	19
93754	2020-07-10 19:44:44	2020-07-10	14	[{"id_menu":2,"count":1}]	25533	delivery	5	19
93755	2020-07-10 19:45:04	2020-07-10	9	[{"id_menu":6,"count":1}]	739	delivery	5	14
93756	2020-07-10 19:46:27	2020-07-10	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	36428	delivery	5	26
93757	2020-07-10 19:47:32	2020-07-10	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	13667	delivery	5	40
93758	2020-07-10 19:48:42	2020-07-10	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	36275	delivery	5	31
93759	2020-07-10 19:53:05	2020-07-10	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	36456	delivery	5	34
93760	2020-07-10 19:54:02	2020-07-10	9	[{"id_menu":6,"count":1}]	9728	delivery	5	14
93761	2020-07-10 19:55:37	2020-07-10	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	36310	pick-up	0	43
93762	2020-07-10 19:56:45	2020-07-10	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	36441	delivery	5	43
93763	2020-07-10 19:58:38	2020-07-10	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2050	delivery	5	31
93764	2020-07-10 19:58:57	2020-07-10	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18400	delivery	5	35
93765	2020-07-10 20:04:56	2020-07-10	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4170	delivery	5	31
93766	2020-07-10 20:05:23	2020-07-10	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10993	delivery	5	35
93767	2020-07-10 20:05:56	2020-07-10	9	[{"id_menu":6,"count":1}]	22564	delivery	5	14
93768	2020-07-10 20:07:50	2020-07-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17209	pick-up	0	17
93769	2020-07-10 20:09:56	2020-07-10	9	[{"id_menu":6,"count":1}]	18367	delivery	5	14
93770	2020-07-10 20:10:47	2020-07-10	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	36356	delivery	5	22
93771	2020-07-10 20:18:03	2020-07-10	9	[{"id_menu":6,"count":1}]	36504	delivery	5	14
93772	2020-07-10 20:19:47	2020-07-10	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	36333	delivery	5	22
93773	2020-07-10 20:24:07	2020-07-10	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	4818	delivery	5	35
93774	2020-07-10 20:28:56	2020-07-10	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	22721	delivery	5	31
93775	2020-07-10 20:29:38	2020-07-10	12	[{"id_menu":1,"count":1}]	10068	delivery	5	17
93776	2020-07-10 20:33:15	2020-07-10	12	[{"id_menu":1,"count":1}]	35325	pick-up	0	12
93777	2020-07-10 20:35:18	2020-07-10	8	[{"id_menu":5,"count":1}]	36435	delivery	5	13
93778	2020-07-10 20:35:39	2020-07-10	8	[{"id_menu":5,"count":1}]	4297	delivery	5	13
93779	2020-07-10 20:36:18	2020-07-10	9	[{"id_menu":6,"count":1}]	36412	delivery	5	14
93780	2020-07-10 20:44:11	2020-07-10	12	[{"id_menu":1,"count":1}]	36399	delivery	5	17
93845	2020-07-10 22:50:23	2020-07-10	12	[{"id_menu":3,"count":1}]	28556	delivery	5	17
93781	2020-07-10 20:47:05	2020-07-10	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36309	delivery	5	37
93782	2020-07-10 20:50:17	2020-07-10	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	17038	delivery	5	31
93783	2020-07-10 20:51:03	2020-07-10	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25607	delivery	5	52
93784	2020-07-10 20:51:20	2020-07-10	9	[{"id_menu":7,"count":1}]	35983	delivery	5	14
93785	2020-07-10 20:51:38	2020-07-10	8	[{"id_menu":5,"count":1}]	30469	pick-up	0	8
93786	2020-07-10 20:52:18	2020-07-10	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13779	delivery	5	39
93787	2020-07-10 20:57:59	2020-07-10	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	15530	delivery	5	31
93788	2020-07-10 20:58:01	2020-07-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	35198	delivery	5	22
93789	2020-07-10 20:58:18	2020-07-10	8	[{"id_menu":5,"count":1}]	36406	delivery	5	13
93790	2020-07-10 20:58:29	2020-07-10	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8076	delivery	5	31
93791	2020-07-10 21:00:09	2020-07-10	17	[{"id_menu":4,"count":1}]	21715	delivery	5	22
93792	2020-07-10 21:00:20	2020-07-10	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":2}]	20553	delivery	5	31
93793	2020-07-10 21:03:09	2020-07-10	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	32294	pick-up	0	31
93794	2020-07-10 21:03:21	2020-07-10	9	[{"id_menu":7,"count":1}]	36402	delivery	5	14
93795	2020-07-10 21:04:52	2020-07-10	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	36307	delivery	5	26
93796	2020-07-10 21:06:38	2020-07-10	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	36383	delivery	5	31
93797	2020-07-10 21:07:04	2020-07-10	9	[{"id_menu":6,"count":1}]	8580	delivery	5	14
93798	2020-07-10 21:08:23	2020-07-10	12	[{"id_menu":3,"count":1}]	15439	pick-up	0	12
93799	2020-07-10 21:08:45	2020-07-10	14	[{"id_menu":2,"count":1}]	10782	delivery	5	19
93800	2020-07-10 21:09:51	2020-07-10	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7766	pick-up	0	25
93801	2020-07-10 21:10:55	2020-07-10	12	[{"id_menu":3,"count":1}]	16783	delivery	5	17
93802	2020-07-10 21:16:31	2020-07-10	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	22373	delivery	5	42
93803	2020-07-10 21:17:19	2020-07-10	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	15394	pick-up	0	31
93804	2020-07-10 21:17:45	2020-07-10	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	15252	pick-up	0	29
93805	2020-07-10 21:18:21	2020-07-10	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36338	delivery	5	37
93806	2020-07-10 21:18:26	2020-07-10	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14958	delivery	5	36
93807	2020-07-10 21:21:44	2020-07-10	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4527	delivery	5	31
93808	2020-07-10 21:21:45	2020-07-10	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	36424	pick-up	0	29
93809	2020-07-10 21:21:46	2020-07-10	8	[{"id_menu":5,"count":1}]	36264	delivery	5	13
93810	2020-07-10 21:23:20	2020-07-10	14	[{"id_menu":2,"count":1}]	20768	delivery	5	19
93811	2020-07-10 21:31:07	2020-07-10	8	[{"id_menu":5,"count":1}]	12361	delivery	5	13
93812	2020-07-10 21:32:39	2020-07-10	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12047	delivery	5	31
93813	2020-07-10 21:34:04	2020-07-10	9	[{"id_menu":7,"count":1}]	14071	delivery	5	14
93814	2020-07-10 21:35:11	2020-07-10	14	[{"id_menu":2,"count":1}]	6825	pick-up	0	14
93815	2020-07-10 21:38:51	2020-07-10	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	36485	delivery	5	27
93816	2020-07-10 21:40:19	2020-07-10	9	[{"id_menu":6,"count":1}]	36317	delivery	5	14
93817	2020-07-10 21:41:31	2020-07-10	9	[{"id_menu":6,"count":1}]	12282	delivery	5	14
93818	2020-07-10 21:41:53	2020-07-10	38	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	36381	delivery	5	43
93819	2020-07-10 21:42:48	2020-07-10	9	[{"id_menu":7,"count":1}]	5149	pick-up	0	9
93820	2020-07-10 21:47:08	2020-07-10	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	36465	delivery	5	30
93821	2020-07-10 21:48:16	2020-07-10	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2995	delivery	5	43
93822	2020-07-10 21:48:49	2020-07-10	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	36484	delivery	5	26
93823	2020-07-10 21:50:54	2020-07-10	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16153	delivery	5	34
93824	2020-07-10 21:51:25	2020-07-10	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	12098	delivery	5	25
93825	2020-07-10 21:57:03	2020-07-10	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	5822	delivery	5	31
93826	2020-07-10 22:02:20	2020-07-10	9	[{"id_menu":6,"count":1}]	18202	pick-up	0	9
93827	2020-07-10 22:13:07	2020-07-10	12	[{"id_menu":3,"count":1}]	36466	delivery	5	17
93828	2020-07-10 22:14:51	2020-07-10	17	[{"id_menu":4,"count":1}]	24309	delivery	5	22
93829	2020-07-10 22:22:32	2020-07-10	12	[{"id_menu":1,"count":1}]	2519	pick-up	0	12
93830	2020-07-10 22:26:21	2020-07-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	36398	delivery	5	23
93831	2020-07-10 22:27:22	2020-07-10	14	[{"id_menu":2,"count":1}]	31963	delivery	5	19
93832	2020-07-10 22:27:34	2020-07-10	8	[{"id_menu":5,"count":1}]	13623	delivery	5	13
93833	2020-07-10 22:29:20	2020-07-10	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	18082	pick-up	0	26
93834	2020-07-10 22:30:59	2020-07-10	9	[{"id_menu":7,"count":1}]	11093	delivery	5	14
93835	2020-07-10 22:32:12	2020-07-10	17	[{"id_menu":4,"count":1}]	36249	delivery	5	22
93836	2020-07-10 22:32:38	2020-07-10	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13109	delivery	5	40
93837	2020-07-10 22:36:26	2020-07-10	9	[{"id_menu":7,"count":1}]	15787	delivery	5	14
93838	2020-07-10 22:38:44	2020-07-10	17	[{"id_menu":4,"count":1}]	8065	delivery	5	22
93839	2020-07-10 22:39:27	2020-07-10	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	35669	delivery	5	29
93840	2020-07-10 22:39:47	2020-07-10	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	35966	pick-up	0	20
93841	2020-07-10 22:40:29	2020-07-10	9	[{"id_menu":6,"count":1}]	11733	delivery	5	14
93842	2020-07-10 22:41:24	2020-07-10	12	[{"id_menu":1,"count":1}]	18341	delivery	5	17
93843	2020-07-10 22:42:35	2020-07-10	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36460	delivery	5	31
93844	2020-07-10 22:48:38	2020-07-10	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	36431	delivery	5	31
93846	2020-07-10 22:56:26	2020-07-10	17	[{"id_menu":4,"count":1}]	10354	delivery	5	22
93847	2020-07-10 22:59:41	2020-07-10	8	[{"id_menu":5,"count":1}]	36320	pick-up	0	8
93848	2020-07-10 23:02:55	2020-07-10	14	[{"id_menu":2,"count":1}]	15456	pick-up	0	14
93849	2020-07-10 23:11:13	2020-07-10	25	[{"id_menu":4,"count":3},{"id_menu":5,"count":1}]	36397	delivery	5	30
93850	2020-07-10 23:11:20	2020-07-10	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36361	delivery	5	45
93851	2020-07-10 23:16:52	2020-07-10	17	[{"id_menu":4,"count":1}]	2633	pick-up	0	17
93852	2020-07-10 23:17:18	2020-07-10	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	35019	pick-up	0	34
93853	2020-07-10 23:18:14	2020-07-10	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14989	delivery	5	36
93854	2020-07-10 23:24:03	2020-07-10	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	36348	delivery	5	34
93855	2020-07-10 23:24:15	2020-07-10	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	36343	delivery	5	31
93856	2020-07-10 23:25:16	2020-07-10	14	[{"id_menu":2,"count":1}]	36282	delivery	5	19
93857	2020-07-10 23:27:38	2020-07-10	12	[{"id_menu":1,"count":1}]	13950	delivery	5	17
93858	2020-07-10 23:29:43	2020-07-10	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	36488	delivery	5	40
93859	2020-07-10 23:30:52	2020-07-10	8	[{"id_menu":5,"count":1}]	5000	delivery	5	13
93860	2020-07-10 23:31:49	2020-07-10	17	[{"id_menu":4,"count":1}]	3173	delivery	5	22
93861	2020-07-10 23:34:21	2020-07-10	9	[{"id_menu":7,"count":1}]	14159	delivery	5	14
93862	2020-07-10 23:35:39	2020-07-10	9	[{"id_menu":7,"count":1}]	36255	delivery	5	14
93863	2020-07-10 23:36:55	2020-07-10	8	[{"id_menu":5,"count":1}]	9618	delivery	5	13
93864	2020-07-10 23:38:00	2020-07-10	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12660	delivery	5	39
93865	2020-07-10 23:39:26	2020-07-10	8	[{"id_menu":5,"count":1}]	36495	delivery	5	13
93866	2020-07-10 23:39:35	2020-07-10	12	[{"id_menu":1,"count":1}]	16007	pick-up	0	12
93867	2020-07-10 23:44:10	2020-07-10	9	[{"id_menu":6,"count":1}]	36468	pick-up	0	9
93868	2020-07-10 23:46:58	2020-07-10	14	[{"id_menu":2,"count":1}]	20982	pick-up	0	14
93869	2020-07-10 23:50:45	2020-07-10	8	[{"id_menu":5,"count":1}]	36292	delivery	5	13
93870	2020-07-10 23:51:27	2020-07-10	12	[{"id_menu":1,"count":1}]	27082	pick-up	0	12
93871	2020-07-11 00:00:47	2020-07-11	9	[{"id_menu":7,"count":1}]	36581	pick-up	0	9
93872	2020-07-11 00:02:21	2020-07-11	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	16829	pick-up	0	21
93873	2020-07-11 00:06:23	2020-07-11	9	[{"id_menu":7,"count":2}]	24392	delivery	5	14
93874	2020-07-11 00:07:12	2020-07-11	17	[{"id_menu":4,"count":1}]	36552	pick-up	0	17
93875	2020-07-11 00:12:08	2020-07-11	12	[{"id_menu":3,"count":1}]	19052	delivery	5	17
93876	2020-07-11 00:13:11	2020-07-11	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	36563	delivery	5	28
93877	2020-07-11 00:13:25	2020-07-11	9	[{"id_menu":7,"count":1}]	36652	pick-up	0	9
93878	2020-07-11 00:15:14	2020-07-11	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	36722	delivery	5	43
93879	2020-07-11 00:18:30	2020-07-11	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36734	delivery	5	48
93880	2020-07-11 00:19:55	2020-07-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":3}]	11411	delivery	5	23
93881	2020-07-11 00:20:04	2020-07-11	14	[{"id_menu":2,"count":2}]	36746	delivery	5	19
93882	2020-07-11 00:23:00	2020-07-11	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	36679	delivery	5	48
93883	2020-07-11 00:24:20	2020-07-11	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	34670	delivery	5	39
93884	2020-07-11 00:26:11	2020-07-11	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	19273	delivery	5	31
93885	2020-07-11 00:38:03	2020-07-11	9	[{"id_menu":6,"count":1}]	30303	delivery	5	14
93886	2020-07-11 00:39:27	2020-07-11	12	[{"id_menu":3,"count":1}]	13101	delivery	5	17
93887	2020-07-11 00:41:36	2020-07-11	17	[{"id_menu":4,"count":1}]	36752	delivery	5	22
93888	2020-07-11 00:42:13	2020-07-11	9	[{"id_menu":7,"count":1}]	36614	delivery	5	14
93889	2020-07-11 00:47:23	2020-07-11	9	[{"id_menu":6,"count":1}]	36596	delivery	5	14
93890	2020-07-11 00:50:56	2020-07-11	17	[{"id_menu":4,"count":1}]	31176	delivery	5	22
93891	2020-07-11 00:51:33	2020-07-11	12	[{"id_menu":1,"count":1}]	1693	pick-up	0	12
93892	2020-07-11 00:52:34	2020-07-11	14	[{"id_menu":2,"count":1}]	9682	pick-up	0	14
93893	2020-07-11 00:55:53	2020-07-11	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	35440	delivery	5	34
93894	2020-07-11 01:03:01	2020-07-11	9	[{"id_menu":7,"count":3}]	1192	delivery	5	14
93895	2020-07-11 01:08:09	2020-07-11	8	[{"id_menu":5,"count":1}]	36669	delivery	5	13
93896	2020-07-11 01:08:19	2020-07-11	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7595	pick-up	0	23
93897	2020-07-11 01:09:06	2020-07-11	17	[{"id_menu":4,"count":1}]	6277	pick-up	0	17
93898	2020-07-11 01:11:49	2020-07-11	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	36671	delivery	5	26
93899	2020-07-11 01:13:23	2020-07-11	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	14202	delivery	5	31
93900	2020-07-11 01:15:03	2020-07-11	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5882	delivery	5	42
93901	2020-07-11 01:17:56	2020-07-11	17	[{"id_menu":4,"count":1}]	9208	delivery	5	22
93902	2020-07-11 01:20:48	2020-07-11	9	[{"id_menu":6,"count":1}]	7550	delivery	5	14
93903	2020-07-11 01:24:35	2020-07-11	9	[{"id_menu":7,"count":1}]	36739	delivery	5	14
93904	2020-07-11 01:24:48	2020-07-11	8	[{"id_menu":5,"count":1}]	36677	delivery	5	13
93905	2020-07-11 01:26:57	2020-07-11	17	[{"id_menu":4,"count":1}]	36555	delivery	5	22
93906	2020-07-11 01:27:54	2020-07-11	12	[{"id_menu":1,"count":1}]	5667	delivery	5	17
93907	2020-07-11 01:29:45	2020-07-11	14	[{"id_menu":2,"count":1}]	14042	delivery	5	19
93908	2020-07-11 01:30:31	2020-07-11	9	[{"id_menu":7,"count":1}]	931	pick-up	0	9
93909	2020-07-11 01:30:53	2020-07-11	43	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	14608	delivery	5	48
93910	2020-07-11 01:32:43	2020-07-11	14	[{"id_menu":2,"count":1}]	5146	delivery	5	19
93911	2020-07-11 01:33:55	2020-07-11	9	[{"id_menu":6,"count":1}]	23770	pick-up	0	9
93912	2020-07-11 01:34:00	2020-07-11	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	9925	delivery	5	29
93913	2020-07-11 01:34:28	2020-07-11	17	[{"id_menu":4,"count":1}]	4874	delivery	5	22
93914	2020-07-11 01:35:21	2020-07-11	17	[{"id_menu":4,"count":1}]	23947	pick-up	0	17
93915	2020-07-11 01:37:36	2020-07-11	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	35285	delivery	5	31
93916	2020-07-11 01:41:11	2020-07-11	9	[{"id_menu":6,"count":1}]	36757	delivery	5	14
93917	2020-07-11 01:43:01	2020-07-11	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16664	delivery	5	37
93918	2020-07-11 01:45:43	2020-07-11	12	[{"id_menu":1,"count":1}]	5760	delivery	5	17
93919	2020-07-11 01:46:21	2020-07-11	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	18980	pick-up	0	31
93920	2020-07-11 01:47:29	2020-07-11	14	[{"id_menu":2,"count":1}]	36676	delivery	5	19
93921	2020-07-11 01:50:43	2020-07-11	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	8390	delivery	5	26
93922	2020-07-11 01:52:56	2020-07-11	9	[{"id_menu":6,"count":1}]	3350	delivery	5	14
93923	2020-07-11 01:55:16	2020-07-11	14	[{"id_menu":2,"count":1}]	36507	delivery	5	19
93924	2020-07-11 01:56:03	2020-07-11	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	36539	delivery	5	39
93925	2020-07-11 01:58:58	2020-07-11	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9749	delivery	5	57
93926	2020-07-11 02:00:36	2020-07-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26504	delivery	5	23
93927	2020-07-11 02:02:31	2020-07-11	14	[{"id_menu":2,"count":1}]	21588	delivery	5	19
93928	2020-07-11 02:02:59	2020-07-11	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21571	delivery	5	39
93929	2020-07-11 02:08:14	2020-07-11	9	[{"id_menu":7,"count":1}]	2961	pick-up	0	9
93930	2020-07-11 02:09:29	2020-07-11	9	[{"id_menu":7,"count":1}]	36615	delivery	5	14
93931	2020-07-11 02:11:18	2020-07-11	17	[{"id_menu":4,"count":1}]	29065	delivery	5	22
93932	2020-07-11 02:12:35	2020-07-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	22965	pick-up	0	23
93933	2020-07-11 02:17:28	2020-07-11	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	36506	delivery	5	34
93934	2020-07-11 02:20:54	2020-07-11	8	[{"id_menu":5,"count":1}]	5211	delivery	5	13
93935	2020-07-11 02:21:53	2020-07-11	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	35568	delivery	5	34
93936	2020-07-11 02:23:34	2020-07-11	8	[{"id_menu":5,"count":1}]	36518	delivery	5	13
93937	2020-07-11 02:24:20	2020-07-11	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4463	pick-up	0	31
93938	2020-07-11 02:25:11	2020-07-11	9	[{"id_menu":7,"count":1}]	36641	delivery	5	14
93939	2020-07-11 02:29:31	2020-07-11	12	[{"id_menu":3,"count":1}]	20216	pick-up	0	12
93940	2020-07-11 02:29:38	2020-07-11	17	[{"id_menu":4,"count":1}]	26257	delivery	5	22
93941	2020-07-11 02:30:23	2020-07-11	9	[{"id_menu":7,"count":1}]	31313	pick-up	0	9
93942	2020-07-11 02:32:40	2020-07-11	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	23551	delivery	5	42
93943	2020-07-11 02:32:44	2020-07-11	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	36542	delivery	5	23
93944	2020-07-11 02:32:56	2020-07-11	14	[{"id_menu":2,"count":2}]	688	delivery	5	19
93945	2020-07-11 02:36:07	2020-07-11	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	13400	pick-up	0	21
93946	2020-07-11 02:36:30	2020-07-11	8	[{"id_menu":5,"count":1}]	36756	delivery	5	13
93947	2020-07-11 02:39:37	2020-07-11	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	36729	pick-up	0	29
93948	2020-07-11 02:41:34	2020-07-11	12	[{"id_menu":1,"count":1}]	21357	delivery	5	17
93949	2020-07-11 02:43:26	2020-07-11	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	11716	delivery	5	25
93950	2020-07-11 02:43:50	2020-07-11	17	[{"id_menu":4,"count":1}]	5439	pick-up	0	17
93951	2020-07-11 02:49:10	2020-07-11	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5654	delivery	5	40
93952	2020-07-11 02:49:21	2020-07-11	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	9560	delivery	5	31
93953	2020-07-11 02:50:42	2020-07-11	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	28425	delivery	5	40
93954	2020-07-11 02:50:44	2020-07-11	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10247	delivery	5	36
93955	2020-07-11 02:51:29	2020-07-11	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27897	delivery	5	35
93956	2020-07-11 02:52:30	2020-07-11	12	[{"id_menu":1,"count":1}]	36532	pick-up	0	12
93957	2020-07-11 02:54:29	2020-07-11	14	[{"id_menu":2,"count":1}]	32610	delivery	5	19
93958	2020-07-11 03:04:49	2020-07-11	17	[{"id_menu":4,"count":1}]	22870	pick-up	0	17
93959	2020-07-11 03:06:27	2020-07-11	14	[{"id_menu":2,"count":1}]	12666	delivery	5	19
93960	2020-07-11 03:07:48	2020-07-11	9	[{"id_menu":7,"count":1}]	28465	delivery	5	14
93961	2020-07-11 03:09:55	2020-07-11	17	[{"id_menu":4,"count":1}]	22784	pick-up	0	17
93962	2020-07-11 03:10:41	2020-07-11	9	[{"id_menu":6,"count":1}]	17086	delivery	5	14
93963	2020-07-11 03:11:51	2020-07-11	9	[{"id_menu":7,"count":1}]	920	pick-up	0	9
93964	2020-07-11 03:12:57	2020-07-11	12	[{"id_menu":1,"count":1}]	36694	delivery	5	17
93965	2020-07-11 03:18:54	2020-07-11	9	[{"id_menu":7,"count":1}]	28767	delivery	5	14
93966	2020-07-11 03:25:34	2020-07-11	9	[{"id_menu":7,"count":1}]	28655	delivery	5	14
93967	2020-07-11 03:25:56	2020-07-11	12	[{"id_menu":3,"count":1}]	36528	delivery	5	17
93968	2020-07-11 03:29:08	2020-07-11	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	36593	delivery	5	36
93969	2020-07-11 03:30:51	2020-07-11	14	[{"id_menu":2,"count":1}]	13340	delivery	5	19
93970	2020-07-11 03:31:03	2020-07-11	17	[{"id_menu":4,"count":1}]	19303	delivery	5	22
93971	2020-07-11 03:33:42	2020-07-11	9	[{"id_menu":6,"count":1}]	36749	delivery	5	14
93972	2020-07-11 03:34:15	2020-07-11	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	30450	delivery	5	22
93973	2020-07-11 03:36:42	2020-07-11	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	26193	delivery	5	38
93974	2020-07-11 03:43:19	2020-07-11	9	[{"id_menu":7,"count":1}]	245	pick-up	0	9
93975	2020-07-11 03:44:21	2020-07-11	17	[{"id_menu":4,"count":1}]	14327	pick-up	0	17
93976	2020-07-11 03:44:43	2020-07-11	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	18312	delivery	5	31
93977	2020-07-11 03:46:17	2020-07-11	9	[{"id_menu":7,"count":1}]	24197	delivery	5	14
93978	2020-07-11 03:47:50	2020-07-11	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	36604	delivery	5	31
93979	2020-07-11 03:49:29	2020-07-11	14	[{"id_menu":2,"count":1}]	18192	delivery	5	19
93980	2020-07-11 03:51:53	2020-07-11	9	[{"id_menu":7,"count":1}]	14950	delivery	5	14
93981	2020-07-11 03:52:20	2020-07-11	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	36600	delivery	5	28
93982	2020-07-11 03:53:42	2020-07-11	12	[{"id_menu":1,"count":1}]	36533	delivery	5	17
93983	2020-07-11 03:53:49	2020-07-11	14	[{"id_menu":2,"count":2}]	25599	delivery	5	19
93984	2020-07-11 03:53:54	2020-07-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	36738	delivery	5	22
93985	2020-07-11 03:57:32	2020-07-11	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	7983	pick-up	0	26
93986	2020-07-11 03:57:48	2020-07-11	9	[{"id_menu":7,"count":1}]	8065	pick-up	0	9
93987	2020-07-11 03:58:44	2020-07-11	12	[{"id_menu":1,"count":1}]	17392	pick-up	0	12
93988	2020-07-11 03:58:47	2020-07-11	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	36545	delivery	5	26
93989	2020-07-11 04:00:04	2020-07-11	9	[{"id_menu":7,"count":1}]	7189	pick-up	0	9
93990	2020-07-11 04:03:19	2020-07-11	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	27145	delivery	5	42
93991	2020-07-11 04:06:55	2020-07-11	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	15319	pick-up	0	26
93992	2020-07-11 04:11:49	2020-07-11	12	[{"id_menu":1,"count":1}]	15770	delivery	5	17
93993	2020-07-11 04:13:47	2020-07-11	14	[{"id_menu":2,"count":1}]	13939	delivery	5	19
93994	2020-07-11 04:16:00	2020-07-11	17	[{"id_menu":4,"count":1}]	36630	delivery	5	22
93995	2020-07-11 04:18:08	2020-07-11	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	36705	delivery	5	25
93996	2020-07-11 04:18:24	2020-07-11	8	[{"id_menu":5,"count":1}]	4486	pick-up	0	8
93997	2020-07-11 04:21:15	2020-07-11	14	[{"id_menu":2,"count":1}]	29856	delivery	5	19
93998	2020-07-11 04:22:20	2020-07-11	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	30001	pick-up	0	21
93999	2020-07-11 04:28:00	2020-07-11	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	24807	delivery	5	40
94000	2020-07-11 04:28:17	2020-07-11	9	[{"id_menu":6,"count":1}]	2699	pick-up	0	9
94001	2020-07-11 04:33:02	2020-07-11	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	9440	delivery	5	28
94002	2020-07-11 04:34:07	2020-07-11	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	33105	delivery	5	26
94003	2020-07-11 04:35:42	2020-07-11	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	21907	delivery	5	23
94004	2020-07-11 04:36:03	2020-07-11	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11529	delivery	5	34
94005	2020-07-11 04:36:43	2020-07-11	17	[{"id_menu":4,"count":1}]	1183	pick-up	0	17
94006	2020-07-11 04:37:21	2020-07-11	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	645	pick-up	0	25
94007	2020-07-11 04:39:52	2020-07-11	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1754	pick-up	0	31
94008	2020-07-11 04:44:17	2020-07-11	9	[{"id_menu":6,"count":1}]	787	pick-up	0	9
94009	2020-07-11 04:50:13	2020-07-11	14	[{"id_menu":2,"count":1}]	36531	delivery	5	19
94010	2020-07-11 04:50:29	2020-07-11	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	36619	delivery	5	40
94011	2020-07-11 04:51:55	2020-07-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	36647	delivery	5	22
94012	2020-07-11 04:52:23	2020-07-11	12	[{"id_menu":3,"count":1}]	2513	delivery	5	17
94013	2020-07-11 04:53:15	2020-07-11	17	[{"id_menu":4,"count":1}]	23561	pick-up	0	17
94014	2020-07-11 04:53:47	2020-07-11	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	36640	delivery	5	34
94015	2020-07-11 04:53:50	2020-07-11	9	[{"id_menu":7,"count":1}]	25337	pick-up	0	9
94016	2020-07-11 04:57:13	2020-07-11	8	[{"id_menu":5,"count":1}]	34973	pick-up	0	8
94017	2020-07-11 04:58:50	2020-07-11	12	[{"id_menu":3,"count":1}]	26866	delivery	5	17
94018	2020-07-11 05:02:29	2020-07-11	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	26162	delivery	5	31
94019	2020-07-11 05:04:30	2020-07-11	9	[{"id_menu":6,"count":1}]	20636	delivery	5	14
94020	2020-07-11 05:05:18	2020-07-11	12	[{"id_menu":3,"count":1}]	28835	delivery	5	17
94021	2020-07-11 05:05:31	2020-07-11	9	[{"id_menu":7,"count":1}]	23588	pick-up	0	9
94022	2020-07-11 05:06:49	2020-07-11	12	[{"id_menu":3,"count":1}]	36517	delivery	5	17
94023	2020-07-11 05:07:31	2020-07-11	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	36755	delivery	5	23
94024	2020-07-11 05:08:07	2020-07-11	14	[{"id_menu":2,"count":1}]	1208	pick-up	0	14
94025	2020-07-11 05:09:16	2020-07-11	12	[{"id_menu":3,"count":1}]	31887	pick-up	0	12
94026	2020-07-11 05:12:17	2020-07-11	9	[{"id_menu":7,"count":1}]	25695	delivery	5	14
94027	2020-07-11 05:13:30	2020-07-11	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	655	delivery	5	25
94028	2020-07-11 05:15:50	2020-07-11	9	[{"id_menu":6,"count":1}]	1781	delivery	5	14
94029	2020-07-11 05:18:06	2020-07-11	17	[{"id_menu":4,"count":1}]	36736	delivery	5	22
94030	2020-07-11 05:18:57	2020-07-11	14	[{"id_menu":2,"count":1}]	28288	delivery	5	19
94031	2020-07-11 05:20:00	2020-07-11	12	[{"id_menu":3,"count":1}]	27639	delivery	5	17
94032	2020-07-11 05:20:25	2020-07-11	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4242	delivery	5	39
94033	2020-07-11 05:20:33	2020-07-11	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	36562	delivery	5	38
94034	2020-07-11 05:21:09	2020-07-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":3}]	17417	delivery	5	22
94035	2020-07-11 05:24:04	2020-07-11	9	[{"id_menu":6,"count":1}]	626	delivery	5	14
94036	2020-07-11 05:24:05	2020-07-11	9	[{"id_menu":6,"count":1}]	3332	pick-up	0	9
94037	2020-07-11 05:26:16	2020-07-11	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2933	pick-up	0	23
94038	2020-07-11 05:26:45	2020-07-11	9	[{"id_menu":7,"count":1}]	29283	delivery	5	14
94039	2020-07-11 05:26:52	2020-07-11	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	14002	pick-up	0	21
94040	2020-07-11 05:27:23	2020-07-11	17	[{"id_menu":4,"count":1}]	35278	pick-up	0	17
94041	2020-07-11 05:31:00	2020-07-11	17	[{"id_menu":4,"count":1}]	36670	delivery	5	22
94042	2020-07-11 05:35:05	2020-07-11	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	36661	pick-up	0	21
94043	2020-07-11 05:37:57	2020-07-11	17	[{"id_menu":4,"count":1}]	8224	pick-up	0	17
94044	2020-07-11 05:39:55	2020-07-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	36214	delivery	5	28
94045	2020-07-11 05:41:20	2020-07-11	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	26386	delivery	5	31
94046	2020-07-11 05:45:02	2020-07-11	17	[{"id_menu":4,"count":1}]	8454	delivery	5	22
94047	2020-07-11 05:46:38	2020-07-11	9	[{"id_menu":7,"count":1}]	25911	delivery	5	14
94048	2020-07-11 05:49:46	2020-07-11	26	[{"id_menu":4,"count":3},{"id_menu":6,"count":1}]	36537	delivery	5	31
94049	2020-07-11 05:50:13	2020-07-11	17	[{"id_menu":4,"count":1}]	36547	delivery	5	22
94050	2020-07-11 05:50:57	2020-07-11	17	[{"id_menu":4,"count":1}]	36130	pick-up	0	17
94051	2020-07-11 05:53:52	2020-07-11	9	[{"id_menu":6,"count":1}]	4978	delivery	5	14
94052	2020-07-11 05:56:55	2020-07-11	17	[{"id_menu":4,"count":1}]	36515	delivery	5	22
94053	2020-07-11 05:57:17	2020-07-11	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	22610	pick-up	0	38
94054	2020-07-11 05:58:41	2020-07-11	17	[{"id_menu":4,"count":1}]	36688	delivery	5	22
94055	2020-07-11 05:59:10	2020-07-11	9	[{"id_menu":6,"count":1}]	23791	delivery	5	14
94056	2020-07-11 06:00:18	2020-07-11	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	36599	delivery	5	31
94057	2020-07-11 06:00:59	2020-07-11	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	36620	delivery	5	26
94058	2020-07-11 06:02:26	2020-07-11	9	[{"id_menu":6,"count":1}]	36674	pick-up	0	9
94059	2020-07-11 06:02:36	2020-07-11	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3629	delivery	5	28
94060	2020-07-11 06:03:14	2020-07-11	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	25324	delivery	5	39
94061	2020-07-11 06:03:42	2020-07-11	12	[{"id_menu":1,"count":1}]	30381	delivery	5	17
94062	2020-07-11 06:04:16	2020-07-11	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	36511	pick-up	0	21
94063	2020-07-11 06:05:10	2020-07-11	9	[{"id_menu":7,"count":1}]	19786	delivery	5	14
94064	2020-07-11 06:06:05	2020-07-11	12	[{"id_menu":1,"count":1}]	36605	delivery	5	17
94065	2020-07-11 06:12:57	2020-07-11	12	[{"id_menu":3,"count":1}]	2619	pick-up	0	12
94066	2020-07-11 06:13:07	2020-07-11	12	[{"id_menu":3,"count":1}]	1654	pick-up	0	12
94067	2020-07-11 06:14:39	2020-07-11	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	36621	delivery	5	45
94068	2020-07-11 06:15:42	2020-07-11	9	[{"id_menu":6,"count":1}]	20392	delivery	5	14
94069	2020-07-11 06:17:56	2020-07-11	14	[{"id_menu":2,"count":1}]	36591	pick-up	0	14
94070	2020-07-11 06:20:43	2020-07-11	9	[{"id_menu":6,"count":1}]	36579	delivery	5	14
94071	2020-07-11 06:25:59	2020-07-11	17	[{"id_menu":4,"count":2}]	3451	delivery	5	22
94072	2020-07-11 06:26:22	2020-07-11	9	[{"id_menu":7,"count":1}]	19750	delivery	5	14
94073	2020-07-11 06:27:39	2020-07-11	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36612	delivery	5	35
94074	2020-07-11 06:31:18	2020-07-11	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	1258	pick-up	0	26
94075	2020-07-11 06:31:22	2020-07-11	9	[{"id_menu":7,"count":1}]	36525	delivery	5	14
94076	2020-07-11 06:33:04	2020-07-11	9	[{"id_menu":6,"count":1}]	31172	delivery	5	14
94077	2020-07-11 06:33:40	2020-07-11	14	[{"id_menu":2,"count":1}]	14970	pick-up	0	14
94078	2020-07-11 06:41:59	2020-07-11	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36629	delivery	5	35
94079	2020-07-11 06:43:48	2020-07-11	8	[{"id_menu":5,"count":1}]	36718	delivery	5	13
94080	2020-07-11 06:47:12	2020-07-11	17	[{"id_menu":4,"count":1}]	10281	delivery	5	22
94081	2020-07-11 06:47:50	2020-07-11	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	31311	delivery	5	31
94082	2020-07-11 06:47:51	2020-07-11	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	36521	delivery	5	22
94083	2020-07-11 06:47:56	2020-07-11	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	36616	delivery	5	31
94084	2020-07-11 06:51:59	2020-07-11	9	[{"id_menu":7,"count":1}]	36638	delivery	5	14
94085	2020-07-11 06:54:11	2020-07-11	12	[{"id_menu":1,"count":1}]	7756	delivery	5	17
94086	2020-07-11 06:57:31	2020-07-11	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	36607	delivery	5	31
94087	2020-07-11 06:58:00	2020-07-11	9	[{"id_menu":6,"count":1}]	30917	delivery	5	14
94088	2020-07-11 06:59:47	2020-07-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36572	delivery	5	23
94089	2020-07-11 07:01:38	2020-07-11	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	22664	pick-up	0	23
94090	2020-07-11 07:07:50	2020-07-11	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36675	delivery	5	40
94091	2020-07-11 07:09:09	2020-07-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	29270	delivery	5	22
94092	2020-07-11 07:10:26	2020-07-11	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	28936	delivery	5	30
94093	2020-07-11 07:15:56	2020-07-11	17	[{"id_menu":4,"count":1}]	36687	delivery	5	22
94094	2020-07-11 07:18:15	2020-07-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	22630	delivery	5	28
94095	2020-07-11 07:22:11	2020-07-11	9	[{"id_menu":6,"count":1}]	6072	delivery	5	14
94096	2020-07-11 07:22:28	2020-07-11	12	[{"id_menu":1,"count":1}]	19005	delivery	5	17
94097	2020-07-11 07:24:24	2020-07-11	9	[{"id_menu":6,"count":1}]	29836	delivery	5	14
94098	2020-07-11 07:25:52	2020-07-11	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	36666	delivery	5	26
94099	2020-07-11 07:30:37	2020-07-11	17	[{"id_menu":4,"count":1}]	36624	delivery	5	22
94100	2020-07-11 07:32:19	2020-07-11	9	[{"id_menu":6,"count":1}]	12628	delivery	5	14
94101	2020-07-11 07:38:29	2020-07-11	14	[{"id_menu":2,"count":1}]	14867	delivery	5	19
94102	2020-07-11 07:44:21	2020-07-11	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	15372	delivery	5	36
94103	2020-07-11 07:46:30	2020-07-11	8	[{"id_menu":5,"count":1}]	10612	delivery	5	13
94104	2020-07-11 07:47:04	2020-07-11	9	[{"id_menu":6,"count":1}]	23405	delivery	5	14
94105	2020-07-11 07:47:12	2020-07-11	8	[{"id_menu":5,"count":1}]	12512	delivery	5	13
94106	2020-07-11 07:50:07	2020-07-11	9	[{"id_menu":6,"count":1}]	29505	delivery	5	14
94107	2020-07-11 07:51:09	2020-07-11	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11110	delivery	5	31
94108	2020-07-11 07:54:23	2020-07-11	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8038	delivery	5	34
94109	2020-07-11 07:54:31	2020-07-11	9	[{"id_menu":7,"count":1}]	20850	pick-up	0	9
94110	2020-07-11 07:59:18	2020-07-11	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	17854	delivery	5	40
94111	2020-07-11 08:12:19	2020-07-11	12	[{"id_menu":1,"count":1}]	23343	delivery	5	17
94112	2020-07-11 08:14:04	2020-07-11	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	29745	delivery	5	28
94113	2020-07-11 08:15:07	2020-07-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23027	delivery	5	23
94114	2020-07-11 08:16:24	2020-07-11	8	[{"id_menu":5,"count":1}]	6034	delivery	5	13
94115	2020-07-11 08:16:26	2020-07-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36703	delivery	5	23
94116	2020-07-11 08:17:03	2020-07-11	12	[{"id_menu":1,"count":1}]	36639	delivery	5	17
94117	2020-07-11 08:19:21	2020-07-11	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	36651	pick-up	0	23
94118	2020-07-11 08:22:38	2020-07-11	14	[{"id_menu":2,"count":1}]	12240	pick-up	0	14
94119	2020-07-11 08:34:19	2020-07-11	12	[{"id_menu":3,"count":1}]	15292	pick-up	0	12
94120	2020-07-11 08:39:27	2020-07-11	9	[{"id_menu":6,"count":1}]	12807	delivery	5	14
94121	2020-07-11 08:40:46	2020-07-11	14	[{"id_menu":2,"count":1}]	36656	pick-up	0	14
94122	2020-07-11 08:41:23	2020-07-11	8	[{"id_menu":5,"count":1}]	23532	delivery	5	13
94123	2020-07-11 08:45:56	2020-07-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36609	delivery	5	23
94124	2020-07-11 08:47:16	2020-07-11	12	[{"id_menu":1,"count":1}]	4007	pick-up	0	12
94125	2020-07-11 08:48:07	2020-07-11	14	[{"id_menu":2,"count":1}]	36021	pick-up	0	14
94126	2020-07-11 08:52:12	2020-07-11	12	[{"id_menu":1,"count":1}]	36571	delivery	5	17
94127	2020-07-11 08:53:07	2020-07-11	17	[{"id_menu":4,"count":1}]	36608	delivery	5	22
94128	2020-07-11 08:53:32	2020-07-11	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	19883	delivery	5	57
94129	2020-07-11 08:53:34	2020-07-11	12	[{"id_menu":1,"count":1}]	3530	delivery	5	17
94130	2020-07-11 08:53:50	2020-07-11	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2995	delivery	5	39
94131	2020-07-11 08:54:25	2020-07-11	12	[{"id_menu":3,"count":1}]	36659	delivery	5	17
94132	2020-07-11 08:54:36	2020-07-11	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	36636	delivery	5	34
94133	2020-07-11 08:55:48	2020-07-11	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3238	delivery	5	40
94134	2020-07-11 08:55:49	2020-07-11	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17979	delivery	5	35
94135	2020-07-11 08:56:24	2020-07-11	9	[{"id_menu":6,"count":1}]	36660	delivery	5	14
94136	2020-07-11 09:00:40	2020-07-11	8	[{"id_menu":5,"count":1}]	56	delivery	5	13
94137	2020-07-11 09:02:33	2020-07-11	9	[{"id_menu":7,"count":1}]	36650	delivery	5	14
94138	2020-07-11 09:05:00	2020-07-11	14	[{"id_menu":2,"count":1}]	36663	delivery	5	19
94139	2020-07-11 09:12:43	2020-07-11	9	[{"id_menu":7,"count":1}]	20643	delivery	5	14
94140	2020-07-11 09:14:24	2020-07-11	12	[{"id_menu":1,"count":1}]	35408	delivery	5	17
94141	2020-07-11 09:15:10	2020-07-11	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3561	delivery	5	36
94142	2020-07-11 09:15:31	2020-07-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	36690	delivery	5	22
94143	2020-07-11 09:17:17	2020-07-11	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	15092	delivery	5	26
94144	2020-07-11 09:20:38	2020-07-11	17	[{"id_menu":4,"count":1}]	9093	delivery	5	22
94145	2020-07-11 09:22:19	2020-07-11	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	64	pick-up	0	41
94146	2020-07-11 09:24:48	2020-07-11	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36711	delivery	5	47
94147	2020-07-11 09:26:18	2020-07-11	9	[{"id_menu":7,"count":1}]	36512	delivery	5	14
94148	2020-07-11 09:27:57	2020-07-11	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2807	delivery	5	56
94149	2020-07-11 09:28:18	2020-07-11	9	[{"id_menu":7,"count":1}]	31650	delivery	5	14
94150	2020-07-11 09:28:30	2020-07-11	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36623	delivery	5	40
94151	2020-07-11 09:30:12	2020-07-11	8	[{"id_menu":5,"count":1}]	36508	delivery	5	13
94152	2020-07-11 09:30:13	2020-07-11	8	[{"id_menu":5,"count":1}]	36731	delivery	5	13
94153	2020-07-11 09:31:43	2020-07-11	9	[{"id_menu":6,"count":1}]	36655	delivery	5	14
94154	2020-07-11 09:34:53	2020-07-11	9	[{"id_menu":7,"count":1}]	25776	delivery	5	14
94155	2020-07-11 09:37:41	2020-07-11	9	[{"id_menu":7,"count":1}]	31763	delivery	5	14
94156	2020-07-11 09:38:13	2020-07-11	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	36726	delivery	5	39
94157	2020-07-11 09:40:20	2020-07-11	8	[{"id_menu":5,"count":1}]	15498	delivery	5	13
94158	2020-07-11 09:41:20	2020-07-11	14	[{"id_menu":2,"count":1}]	36540	delivery	5	19
94159	2020-07-11 09:42:49	2020-07-11	17	[{"id_menu":4,"count":1}]	12107	delivery	5	22
94160	2020-07-11 09:43:51	2020-07-11	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	23203	delivery	5	34
94161	2020-07-11 09:45:24	2020-07-11	17	[{"id_menu":4,"count":2}]	3083	delivery	5	22
94162	2020-07-11 09:45:35	2020-07-11	9	[{"id_menu":7,"count":1}]	36583	delivery	5	14
94163	2020-07-11 09:52:07	2020-07-11	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28839	delivery	5	34
94164	2020-07-11 09:54:16	2020-07-11	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10668	delivery	5	31
94165	2020-07-11 09:56:49	2020-07-11	12	[{"id_menu":1,"count":1}]	28308	delivery	5	17
94166	2020-07-11 09:57:47	2020-07-11	9	[{"id_menu":7,"count":1}]	36573	delivery	5	14
94167	2020-07-11 10:00:41	2020-07-11	17	[{"id_menu":4,"count":1}]	13061	delivery	5	22
94168	2020-07-11 10:01:04	2020-07-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	36665	delivery	5	28
94169	2020-07-11 10:03:27	2020-07-11	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	36727	delivery	5	25
94170	2020-07-11 10:03:46	2020-07-11	8	[{"id_menu":5,"count":1}]	10507	delivery	5	13
94171	2020-07-11 10:03:58	2020-07-11	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	17711	delivery	5	31
94172	2020-07-11 10:07:54	2020-07-11	12	[{"id_menu":3,"count":1}]	36707	delivery	5	17
94173	2020-07-11 10:11:25	2020-07-11	9	[{"id_menu":7,"count":1}]	36580	delivery	5	14
94174	2020-07-11 10:11:31	2020-07-11	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	36633	delivery	5	27
94175	2020-07-11 10:11:31	2020-07-11	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	36520	delivery	5	34
94176	2020-07-11 10:13:19	2020-07-11	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	36667	delivery	5	22
94177	2020-07-11 10:18:38	2020-07-11	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36686	delivery	5	37
94178	2020-07-11 10:21:59	2020-07-11	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3115	pick-up	0	23
94179	2020-07-11 10:26:25	2020-07-11	8	[{"id_menu":5,"count":1}]	36578	delivery	5	13
94180	2020-07-11 10:28:42	2020-07-11	9	[{"id_menu":6,"count":1}]	36701	delivery	5	14
94181	2020-07-11 10:28:53	2020-07-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	19794	delivery	5	28
94182	2020-07-11 10:32:46	2020-07-11	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	33071	delivery	5	45
94183	2020-07-11 10:33:53	2020-07-11	9	[{"id_menu":7,"count":1}]	11871	delivery	5	14
94184	2020-07-11 10:34:30	2020-07-11	17	[{"id_menu":4,"count":1}]	13852	pick-up	0	17
94185	2020-07-11 10:34:33	2020-07-11	9	[{"id_menu":7,"count":1}]	14727	delivery	5	14
94186	2020-07-11 10:36:33	2020-07-11	17	[{"id_menu":4,"count":1}]	36509	delivery	5	22
94187	2020-07-11 10:38:16	2020-07-11	17	[{"id_menu":4,"count":1}]	16539	delivery	5	22
94188	2020-07-11 10:39:52	2020-07-11	9	[{"id_menu":6,"count":1}]	6677	delivery	5	14
94189	2020-07-11 10:45:26	2020-07-11	12	[{"id_menu":1,"count":1}]	23285	delivery	5	17
94190	2020-07-11 10:45:43	2020-07-11	14	[{"id_menu":2,"count":1}]	35330	delivery	5	19
94191	2020-07-11 10:47:23	2020-07-11	9	[{"id_menu":6,"count":1}]	36741	delivery	5	14
94192	2020-07-11 10:48:09	2020-07-11	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	11666	delivery	5	39
94193	2020-07-11 10:48:53	2020-07-11	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	20329	delivery	5	31
94194	2020-07-11 10:49:57	2020-07-11	12	[{"id_menu":1,"count":1}]	1765	delivery	5	17
94195	2020-07-11 10:51:38	2020-07-11	12	[{"id_menu":3,"count":1}]	8904	delivery	5	17
94196	2020-07-11 10:56:04	2020-07-11	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13708	delivery	5	43
94197	2020-07-11 10:57:26	2020-07-11	12	[{"id_menu":1,"count":1}]	36510	delivery	5	17
94198	2020-07-11 10:58:40	2020-07-11	14	[{"id_menu":2,"count":3}]	36548	delivery	5	19
94199	2020-07-11 11:01:15	2020-07-11	12	[{"id_menu":1,"count":1}]	36544	delivery	5	17
94200	2020-07-11 11:01:37	2020-07-11	14	[{"id_menu":2,"count":1}]	13500	delivery	5	19
94201	2020-07-11 11:04:35	2020-07-11	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	36586	delivery	5	31
94202	2020-07-11 11:04:49	2020-07-11	8	[{"id_menu":5,"count":1}]	29342	delivery	5	13
94203	2020-07-11 11:06:25	2020-07-11	12	[{"id_menu":1,"count":1}]	1072	pick-up	0	12
94204	2020-07-11 11:08:19	2020-07-11	9	[{"id_menu":6,"count":1}]	9695	delivery	5	14
94205	2020-07-11 11:09:17	2020-07-11	8	[{"id_menu":5,"count":1}]	19892	delivery	5	13
94206	2020-07-11 11:11:05	2020-07-11	9	[{"id_menu":7,"count":2}]	36695	delivery	5	14
94207	2020-07-11 11:12:25	2020-07-11	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14138	delivery	5	36
94208	2020-07-11 11:13:17	2020-07-11	9	[{"id_menu":6,"count":1}]	12527	pick-up	0	9
94209	2020-07-11 11:15:21	2020-07-11	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	27958	delivery	5	42
94210	2020-07-11 11:17:43	2020-07-11	14	[{"id_menu":2,"count":1}]	36700	delivery	5	19
94211	2020-07-11 11:19:43	2020-07-11	9	[{"id_menu":6,"count":2}]	19971	delivery	5	14
94212	2020-07-11 11:19:52	2020-07-11	12	[{"id_menu":1,"count":1}]	32700	delivery	5	17
94213	2020-07-11 11:20:36	2020-07-11	9	[{"id_menu":7,"count":1}]	36735	delivery	5	14
94214	2020-07-11 11:21:23	2020-07-11	17	[{"id_menu":4,"count":1}]	28323	delivery	5	22
94215	2020-07-11 11:21:53	2020-07-11	17	[{"id_menu":4,"count":1}]	12477	delivery	5	22
94216	2020-07-11 11:23:16	2020-07-11	9	[{"id_menu":7,"count":1}]	2119	delivery	5	14
94217	2020-07-11 11:24:53	2020-07-11	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	36577	pick-up	0	22
94218	2020-07-11 11:28:40	2020-07-11	8	[{"id_menu":5,"count":1}]	36631	delivery	5	13
94219	2020-07-11 11:30:46	2020-07-11	9	[{"id_menu":6,"count":1}]	30964	delivery	5	14
94220	2020-07-11 11:31:13	2020-07-11	12	[{"id_menu":3,"count":1}]	22373	delivery	5	17
94221	2020-07-11 11:34:20	2020-07-11	9	[{"id_menu":6,"count":1}]	13849	delivery	5	14
94222	2020-07-11 11:38:54	2020-07-11	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	36751	delivery	5	34
94223	2020-07-11 11:42:51	2020-07-11	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	28893	delivery	5	31
94224	2020-07-11 11:45:51	2020-07-11	8	[{"id_menu":5,"count":1}]	36699	delivery	5	13
94225	2020-07-11 11:46:10	2020-07-11	12	[{"id_menu":3,"count":1}]	10019	pick-up	0	12
94226	2020-07-11 11:48:14	2020-07-11	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	19935	delivery	5	37
94227	2020-07-11 11:52:59	2020-07-11	9	[{"id_menu":7,"count":1}]	6368	pick-up	0	9
94228	2020-07-11 11:53:49	2020-07-11	14	[{"id_menu":2,"count":1}]	2590	pick-up	0	14
94229	2020-07-11 11:54:16	2020-07-11	26	[{"id_menu":2,"count":3},{"id_menu":3,"count":1}]	7069	pick-up	0	26
94230	2020-07-11 11:58:23	2020-07-11	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	20303	delivery	5	44
94231	2020-07-11 12:00:21	2020-07-11	17	[{"id_menu":4,"count":1}]	5082	pick-up	0	17
94232	2020-07-11 12:03:32	2020-07-11	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	20652	delivery	5	36
94233	2020-07-11 12:04:38	2020-07-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13379	delivery	5	23
94234	2020-07-11 12:07:15	2020-07-11	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	36627	delivery	5	40
94235	2020-07-11 12:07:16	2020-07-11	9	[{"id_menu":7,"count":1}]	10039	pick-up	0	9
94236	2020-07-11 12:07:22	2020-07-11	17	[{"id_menu":4,"count":1}]	4716	delivery	5	22
94237	2020-07-11 12:09:51	2020-07-11	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	21002	pick-up	0	29
94238	2020-07-11 12:10:43	2020-07-11	9	[{"id_menu":6,"count":1}]	8680	delivery	5	14
94239	2020-07-11 12:11:00	2020-07-11	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	36704	delivery	5	40
94240	2020-07-11 12:14:21	2020-07-11	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	10590	pick-up	0	21
94241	2020-07-11 12:18:13	2020-07-11	9	[{"id_menu":6,"count":1}]	36683	delivery	5	14
94242	2020-07-11 12:20:30	2020-07-11	14	[{"id_menu":2,"count":1}]	9941	pick-up	0	14
94243	2020-07-11 12:20:51	2020-07-11	12	[{"id_menu":1,"count":1}]	4562	delivery	5	17
94244	2020-07-11 12:21:28	2020-07-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4937	pick-up	0	23
94245	2020-07-11 12:28:08	2020-07-11	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1945	delivery	5	34
94246	2020-07-11 12:30:39	2020-07-11	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	36543	delivery	5	42
94247	2020-07-11 12:34:56	2020-07-11	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	21198	delivery	5	27
94248	2020-07-11 12:35:11	2020-07-11	12	[{"id_menu":3,"count":1}]	36684	delivery	5	17
94249	2020-07-11 12:35:19	2020-07-11	9	[{"id_menu":6,"count":1}]	36653	delivery	5	14
94250	2020-07-11 12:35:34	2020-07-11	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	7246	delivery	5	26
94251	2020-07-11 12:36:04	2020-07-11	17	[{"id_menu":4,"count":1}]	18658	delivery	5	22
94252	2020-07-11 12:36:08	2020-07-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	15880	delivery	5	28
94253	2020-07-11 12:36:31	2020-07-11	9	[{"id_menu":7,"count":1}]	12338	pick-up	0	9
94254	2020-07-11 12:37:13	2020-07-11	9	[{"id_menu":6,"count":1}]	11741	delivery	5	14
94255	2020-07-11 12:37:26	2020-07-11	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36709	delivery	5	31
94256	2020-07-11 12:37:34	2020-07-11	17	[{"id_menu":4,"count":1}]	2937	delivery	5	22
94257	2020-07-11 12:39:13	2020-07-11	9	[{"id_menu":7,"count":1}]	26826	delivery	5	14
94258	2020-07-11 12:39:42	2020-07-11	9	[{"id_menu":7,"count":1}]	23849	delivery	5	14
94259	2020-07-11 12:42:08	2020-07-11	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	36747	delivery	5	26
94260	2020-07-11 12:45:25	2020-07-11	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4047	delivery	5	28
94261	2020-07-11 12:45:36	2020-07-11	9	[{"id_menu":7,"count":1}]	12424	delivery	5	14
94262	2020-07-11 12:46:14	2020-07-11	34	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	36527	delivery	5	39
94263	2020-07-11 12:48:04	2020-07-11	12	[{"id_menu":3,"count":1}]	19506	pick-up	0	12
94264	2020-07-11 12:51:59	2020-07-11	9	[{"id_menu":7,"count":1}]	41	pick-up	0	9
94265	2020-07-11 12:53:37	2020-07-11	8	[{"id_menu":5,"count":1}]	3825	pick-up	0	8
94266	2020-07-11 12:54:27	2020-07-11	12	[{"id_menu":1,"count":1}]	3809	pick-up	0	12
94267	2020-07-11 12:54:53	2020-07-11	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36556	delivery	5	31
94268	2020-07-11 12:55:59	2020-07-11	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	36589	delivery	5	48
94269	2020-07-11 12:58:04	2020-07-11	17	[{"id_menu":4,"count":1}]	606	delivery	5	22
94270	2020-07-11 13:04:36	2020-07-11	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	36602	delivery	5	31
94271	2020-07-11 13:08:35	2020-07-11	14	[{"id_menu":2,"count":1}]	36534	delivery	5	19
94272	2020-07-11 13:08:41	2020-07-11	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	36569	delivery	5	45
94273	2020-07-11 13:09:32	2020-07-11	17	[{"id_menu":4,"count":1}]	4228	delivery	5	22
94274	2020-07-11 13:10:54	2020-07-11	12	[{"id_menu":3,"count":1}]	36558	delivery	5	17
94275	2020-07-11 13:12:10	2020-07-11	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	8750	delivery	5	36
94276	2020-07-11 13:13:29	2020-07-11	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	31307	delivery	5	31
94277	2020-07-11 13:14:01	2020-07-11	9	[{"id_menu":6,"count":1}]	14734	delivery	5	14
94278	2020-07-11 13:14:06	2020-07-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36595	delivery	5	23
94279	2020-07-11 13:14:39	2020-07-11	12	[{"id_menu":3,"count":1}]	12053	pick-up	0	12
94280	2020-07-11 13:16:01	2020-07-11	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6134	delivery	5	28
94281	2020-07-11 13:16:28	2020-07-11	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	36582	delivery	5	26
94282	2020-07-11 13:19:05	2020-07-11	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	31013	delivery	5	23
94283	2020-07-11 13:19:23	2020-07-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	34581	delivery	5	28
94284	2020-07-11 13:19:27	2020-07-11	9	[{"id_menu":7,"count":1}]	20454	delivery	5	14
94285	2020-07-11 13:20:14	2020-07-11	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	11041	delivery	5	44
94286	2020-07-11 13:22:57	2020-07-11	12	[{"id_menu":1,"count":1}]	17691	pick-up	0	12
94287	2020-07-11 13:26:17	2020-07-11	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	24200	delivery	5	34
94288	2020-07-11 13:27:20	2020-07-11	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	32119	delivery	5	31
94289	2020-07-11 13:29:23	2020-07-11	12	[{"id_menu":1,"count":1}]	15052	delivery	5	17
94290	2020-07-11 13:29:47	2020-07-11	9	[{"id_menu":6,"count":1}]	18148	delivery	5	14
94291	2020-07-11 13:29:54	2020-07-11	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	19102	delivery	5	27
94292	2020-07-11 13:30:39	2020-07-11	9	[{"id_menu":7,"count":2}]	36618	delivery	5	14
94293	2020-07-11 13:32:36	2020-07-11	14	[{"id_menu":2,"count":1}]	22367	delivery	5	19
94294	2020-07-11 13:33:09	2020-07-11	8	[{"id_menu":5,"count":2}]	36668	delivery	5	13
94295	2020-07-11 13:33:46	2020-07-11	12	[{"id_menu":3,"count":1}]	36743	delivery	5	17
94296	2020-07-11 13:35:44	2020-07-11	12	[{"id_menu":1,"count":1}]	27685	pick-up	0	12
94297	2020-07-11 13:38:00	2020-07-11	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8811	pick-up	0	26
94298	2020-07-11 13:39:41	2020-07-11	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	36742	delivery	5	36
94299	2020-07-11 13:41:50	2020-07-11	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	441	delivery	5	45
94300	2020-07-11 13:42:19	2020-07-11	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	36664	delivery	5	34
94301	2020-07-11 13:43:19	2020-07-11	12	[{"id_menu":1,"count":1}]	14480	delivery	5	17
94302	2020-07-11 13:43:46	2020-07-11	9	[{"id_menu":6,"count":1}]	36637	delivery	5	14
94303	2020-07-11 13:44:10	2020-07-11	17	[{"id_menu":4,"count":2}]	1381	pick-up	0	17
94304	2020-07-11 13:44:34	2020-07-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36716	delivery	5	23
94305	2020-07-11 13:48:41	2020-07-11	9	[{"id_menu":7,"count":1}]	36576	delivery	5	14
94306	2020-07-11 13:57:11	2020-07-11	8	[{"id_menu":5,"count":1}]	8671	delivery	5	13
94307	2020-07-11 14:05:30	2020-07-11	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	28276	delivery	5	34
94308	2020-07-11 14:07:33	2020-07-11	8	[{"id_menu":5,"count":1}]	11899	delivery	5	13
94309	2020-07-11 14:08:05	2020-07-11	14	[{"id_menu":2,"count":2}]	36728	delivery	5	19
94310	2020-07-11 14:08:11	2020-07-11	12	[{"id_menu":1,"count":1}]	33942	delivery	5	17
94311	2020-07-11 14:08:22	2020-07-11	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	313	delivery	5	27
94312	2020-07-11 14:08:55	2020-07-11	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5701	pick-up	0	25
94313	2020-07-11 14:09:20	2020-07-11	17	[{"id_menu":4,"count":1}]	21821	delivery	5	22
94314	2020-07-11 14:09:30	2020-07-11	17	[{"id_menu":4,"count":1}]	36611	pick-up	0	17
94315	2020-07-11 14:11:19	2020-07-11	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6344	delivery	5	45
94316	2020-07-11 14:11:43	2020-07-11	12	[{"id_menu":1,"count":1}]	27936	delivery	5	17
94317	2020-07-11 14:13:08	2020-07-11	9	[{"id_menu":6,"count":1}]	36606	delivery	5	14
94318	2020-07-11 14:15:58	2020-07-11	9	[{"id_menu":7,"count":1}]	2360	delivery	5	14
94319	2020-07-11 14:17:15	2020-07-11	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	34700	delivery	5	36
94320	2020-07-11 14:18:28	2020-07-11	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	36634	delivery	5	30
94321	2020-07-11 14:22:37	2020-07-11	8	[{"id_menu":5,"count":3}]	30085	delivery	5	13
94322	2020-07-11 14:22:50	2020-07-11	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2082	delivery	5	36
94323	2020-07-11 14:24:08	2020-07-11	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	36750	delivery	5	28
94324	2020-07-11 14:24:13	2020-07-11	9	[{"id_menu":7,"count":1}]	27621	delivery	5	14
94325	2020-07-11 14:24:38	2020-07-11	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	36546	delivery	5	43
94326	2020-07-11 14:24:54	2020-07-11	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21533	delivery	5	40
94327	2020-07-11 14:25:08	2020-07-11	17	[{"id_menu":4,"count":1}]	18758	pick-up	0	17
94328	2020-07-11 14:26:31	2020-07-11	9	[{"id_menu":6,"count":1}]	34413	delivery	5	14
94329	2020-07-11 14:27:01	2020-07-11	9	[{"id_menu":6,"count":1}]	36733	delivery	5	14
94330	2020-07-11 14:27:30	2020-07-11	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9943	pick-up	0	38
94331	2020-07-11 14:27:56	2020-07-11	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	17503	delivery	5	39
94332	2020-07-11 14:28:33	2020-07-11	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	6372	pick-up	0	22
94333	2020-07-11 14:30:58	2020-07-11	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1184	pick-up	0	21
94334	2020-07-11 14:31:26	2020-07-11	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	36692	delivery	5	26
94335	2020-07-11 14:32:27	2020-07-11	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	36696	delivery	5	26
94336	2020-07-11 14:34:00	2020-07-11	9	[{"id_menu":7,"count":1}]	36519	delivery	5	14
94337	2020-07-11 14:35:42	2020-07-11	8	[{"id_menu":5,"count":1}]	2541	delivery	5	13
94338	2020-07-11 14:37:25	2020-07-11	9	[{"id_menu":7,"count":1}]	20167	delivery	5	14
94339	2020-07-11 14:38:43	2020-07-11	14	[{"id_menu":2,"count":2}]	36554	delivery	5	19
94340	2020-07-11 14:43:07	2020-07-11	9	[{"id_menu":6,"count":1}]	29225	delivery	5	14
94341	2020-07-11 14:43:54	2020-07-11	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	13639	pick-up	0	26
94342	2020-07-11 14:46:07	2020-07-11	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	36697	delivery	5	23
94343	2020-07-11 14:47:55	2020-07-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7775	delivery	5	22
94344	2020-07-11 14:49:37	2020-07-11	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11562	delivery	5	37
94345	2020-07-11 14:54:10	2020-07-11	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	8877	delivery	5	31
94346	2020-07-11 14:58:03	2020-07-11	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	22011	pick-up	0	35
94347	2020-07-11 15:02:23	2020-07-11	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	14540	delivery	5	28
94348	2020-07-11 15:05:51	2020-07-11	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	36717	delivery	5	40
94349	2020-07-11 15:06:23	2020-07-11	12	[{"id_menu":3,"count":1}]	36673	delivery	5	17
94350	2020-07-11 15:06:56	2020-07-11	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	35242	delivery	5	27
94351	2020-07-11 15:08:36	2020-07-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27736	delivery	5	22
94352	2020-07-11 15:08:54	2020-07-11	17	[{"id_menu":4,"count":1}]	36574	delivery	5	22
94353	2020-07-11 15:08:58	2020-07-11	9	[{"id_menu":6,"count":1}]	32264	delivery	5	14
94354	2020-07-11 15:09:14	2020-07-11	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4644	pick-up	0	31
94355	2020-07-11 15:09:48	2020-07-11	12	[{"id_menu":1,"count":2}]	20158	delivery	5	17
94356	2020-07-11 15:11:22	2020-07-11	9	[{"id_menu":6,"count":1}]	36672	delivery	5	14
94357	2020-07-11 15:11:42	2020-07-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22643	pick-up	0	18
94358	2020-07-11 15:11:49	2020-07-11	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	36744	delivery	5	55
94359	2020-07-11 15:13:20	2020-07-11	14	[{"id_menu":2,"count":1}]	20021	pick-up	0	14
94360	2020-07-11 15:15:33	2020-07-11	17	[{"id_menu":4,"count":1}]	24042	delivery	5	22
94361	2020-07-11 15:21:44	2020-07-11	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6439	pick-up	0	31
94362	2020-07-11 15:21:49	2020-07-11	9	[{"id_menu":7,"count":1}]	36617	delivery	5	14
94363	2020-07-11 15:23:12	2020-07-11	9	[{"id_menu":6,"count":1}]	8930	pick-up	0	9
94364	2020-07-11 15:24:06	2020-07-11	12	[{"id_menu":3,"count":1}]	14894	delivery	5	17
94365	2020-07-11 15:24:44	2020-07-11	9	[{"id_menu":7,"count":1}]	17198	delivery	5	14
94366	2020-07-11 15:25:39	2020-07-11	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	36706	pick-up	0	31
94367	2020-07-11 15:26:40	2020-07-11	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9634	pick-up	0	25
94368	2020-07-11 15:27:19	2020-07-11	17	[{"id_menu":4,"count":1}]	2122	pick-up	0	17
94369	2020-07-11 15:28:49	2020-07-11	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3883	delivery	5	28
94370	2020-07-11 15:29:05	2020-07-11	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	26461	delivery	5	42
94371	2020-07-11 15:29:40	2020-07-11	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	12686	pick-up	0	29
94372	2020-07-11 15:32:06	2020-07-11	14	[{"id_menu":2,"count":1}]	8298	delivery	5	19
94373	2020-07-11 15:33:04	2020-07-11	17	[{"id_menu":4,"count":1}]	1485	pick-up	0	17
94374	2020-07-11 15:33:33	2020-07-11	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	36719	delivery	5	30
94375	2020-07-11 15:34:46	2020-07-11	17	[{"id_menu":4,"count":1}]	36721	delivery	5	22
94376	2020-07-11 15:39:32	2020-07-11	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	36526	delivery	5	26
94377	2020-07-11 15:42:38	2020-07-11	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	24899	delivery	5	48
94378	2020-07-11 15:45:02	2020-07-11	14	[{"id_menu":2,"count":1}]	28872	delivery	5	19
94379	2020-07-11 15:47:16	2020-07-11	12	[{"id_menu":3,"count":1}]	36550	delivery	5	17
94380	2020-07-11 15:47:26	2020-07-11	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	25808	pick-up	0	29
94381	2020-07-11 15:49:23	2020-07-11	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	21292	delivery	5	34
94382	2020-07-11 15:50:20	2020-07-11	9	[{"id_menu":7,"count":1}]	36715	delivery	5	14
94383	2020-07-11 15:50:56	2020-07-11	8	[{"id_menu":5,"count":1}]	19817	delivery	5	13
94384	2020-07-11 15:52:20	2020-07-11	17	[{"id_menu":4,"count":1}]	7924	delivery	5	22
94385	2020-07-11 15:52:34	2020-07-11	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	36758	delivery	5	45
94386	2020-07-11 15:55:50	2020-07-11	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	28532	pick-up	0	43
94387	2020-07-11 15:56:49	2020-07-11	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	27515	delivery	5	36
94388	2020-07-11 15:58:15	2020-07-11	9	[{"id_menu":7,"count":1}]	36561	delivery	5	14
94389	2020-07-11 15:58:31	2020-07-11	9	[{"id_menu":7,"count":1}]	31005	delivery	5	14
94390	2020-07-11 16:06:35	2020-07-11	9	[{"id_menu":7,"count":1}]	304	pick-up	0	9
94391	2020-07-11 16:07:56	2020-07-11	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	30967	delivery	5	25
94392	2020-07-11 16:08:30	2020-07-11	12	[{"id_menu":3,"count":1}]	13410	delivery	5	17
94393	2020-07-11 16:08:30	2020-07-11	17	[{"id_menu":4,"count":1}]	3153	delivery	5	22
94394	2020-07-11 16:09:09	2020-07-11	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	36754	delivery	5	40
94395	2020-07-11 16:12:07	2020-07-11	17	[{"id_menu":4,"count":1}]	9664	delivery	5	22
94396	2020-07-11 16:14:57	2020-07-11	17	[{"id_menu":4,"count":1}]	3146	delivery	5	22
94397	2020-07-11 16:16:21	2020-07-11	9	[{"id_menu":6,"count":1}]	18578	delivery	5	14
94398	2020-07-11 16:20:16	2020-07-11	9	[{"id_menu":7,"count":1}]	2711	delivery	5	14
94399	2020-07-11 16:20:45	2020-07-11	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	36588	delivery	5	31
94400	2020-07-11 16:22:37	2020-07-11	14	[{"id_menu":2,"count":1}]	36748	delivery	5	19
94401	2020-07-11 16:24:32	2020-07-11	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	36708	delivery	5	43
94402	2020-07-11 16:29:43	2020-07-11	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	36712	delivery	5	43
94403	2020-07-11 16:31:47	2020-07-11	9	[{"id_menu":7,"count":1}]	32944	delivery	5	14
94404	2020-07-11 16:32:03	2020-07-11	12	[{"id_menu":3,"count":1}]	26775	delivery	5	17
94405	2020-07-11 16:35:03	2020-07-11	9	[{"id_menu":7,"count":1}]	36720	delivery	5	14
94406	2020-07-11 16:37:00	2020-07-11	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36603	delivery	5	31
94407	2020-07-11 16:39:26	2020-07-11	12	[{"id_menu":1,"count":1}]	22603	pick-up	0	12
94408	2020-07-11 16:44:46	2020-07-11	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	29010	pick-up	0	26
94409	2020-07-11 16:45:56	2020-07-11	12	[{"id_menu":3,"count":1}]	13335	pick-up	0	12
94410	2020-07-11 16:48:46	2020-07-11	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23450	delivery	5	51
94411	2020-07-11 16:50:40	2020-07-11	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	33568	delivery	5	26
94412	2020-07-11 16:53:23	2020-07-11	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	34578	delivery	5	42
94413	2020-07-11 16:54:40	2020-07-11	9	[{"id_menu":7,"count":1}]	5328	delivery	5	14
94414	2020-07-11 16:59:39	2020-07-11	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9516	delivery	5	39
94415	2020-07-11 17:00:16	2020-07-11	14	[{"id_menu":2,"count":1}]	1723	pick-up	0	14
94416	2020-07-11 17:02:47	2020-07-11	9	[{"id_menu":7,"count":2}]	36645	delivery	5	14
94417	2020-07-11 17:05:46	2020-07-11	9	[{"id_menu":6,"count":1}]	36702	delivery	5	14
94418	2020-07-11 17:08:00	2020-07-11	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	11812	delivery	5	37
94419	2020-07-11 17:08:17	2020-07-11	12	[{"id_menu":3,"count":1}]	17253	delivery	5	17
94420	2020-07-11 17:09:01	2020-07-11	14	[{"id_menu":2,"count":1}]	36565	pick-up	0	14
94421	2020-07-11 17:12:14	2020-07-11	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	11917	pick-up	0	22
94422	2020-07-11 17:16:45	2020-07-11	17	[{"id_menu":4,"count":1}]	13767	delivery	5	22
94423	2020-07-11 17:19:33	2020-07-11	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	36529	delivery	5	36
94424	2020-07-11 17:20:57	2020-07-11	12	[{"id_menu":3,"count":1}]	11709	delivery	5	17
94425	2020-07-11 17:23:30	2020-07-11	9	[{"id_menu":7,"count":1}]	36732	delivery	5	14
94426	2020-07-11 17:24:02	2020-07-11	8	[{"id_menu":5,"count":1}]	36564	delivery	5	13
94427	2020-07-11 17:25:19	2020-07-11	12	[{"id_menu":1,"count":1}]	12612	delivery	5	17
94428	2020-07-11 17:26:10	2020-07-11	14	[{"id_menu":2,"count":1}]	4654	pick-up	0	14
94429	2020-07-11 17:26:44	2020-07-11	9	[{"id_menu":7,"count":1}]	294	pick-up	0	9
94430	2020-07-11 17:29:06	2020-07-11	17	[{"id_menu":4,"count":1}]	19287	delivery	5	22
94431	2020-07-11 17:35:51	2020-07-11	9	[{"id_menu":6,"count":1}]	6820	delivery	5	14
94432	2020-07-11 17:38:43	2020-07-11	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11721	delivery	5	39
94433	2020-07-11 17:41:03	2020-07-11	12	[{"id_menu":1,"count":1}]	6780	delivery	5	17
94434	2020-07-11 17:41:22	2020-07-11	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	21866	delivery	5	25
94435	2020-07-11 17:43:53	2020-07-11	9	[{"id_menu":7,"count":1}]	36691	pick-up	0	9
94436	2020-07-11 17:45:12	2020-07-11	14	[{"id_menu":2,"count":1}]	22933	pick-up	0	14
94437	2020-07-11 17:47:47	2020-07-11	12	[{"id_menu":3,"count":1}]	36635	delivery	5	17
94438	2020-07-11 17:47:52	2020-07-11	12	[{"id_menu":1,"count":1}]	10021	delivery	5	17
94439	2020-07-11 17:51:55	2020-07-11	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	7428	delivery	5	31
94440	2020-07-11 17:53:57	2020-07-11	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	31501	delivery	5	26
94441	2020-07-11 18:01:20	2020-07-11	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3579	delivery	5	40
94442	2020-07-11 18:01:31	2020-07-11	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20438	delivery	5	39
94443	2020-07-11 18:04:48	2020-07-11	9	[{"id_menu":6,"count":1}]	20739	delivery	5	14
94444	2020-07-11 18:07:27	2020-07-11	9	[{"id_menu":6,"count":1}]	18344	delivery	5	14
94445	2020-07-11 18:10:03	2020-07-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":3}]	10872	delivery	5	23
94446	2020-07-11 18:10:55	2020-07-11	14	[{"id_menu":2,"count":1}]	5169	pick-up	0	14
94447	2020-07-11 18:17:35	2020-07-11	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	5033	pick-up	0	21
94448	2020-07-11 18:21:42	2020-07-11	14	[{"id_menu":2,"count":1}]	13673	delivery	5	19
94449	2020-07-11 18:21:56	2020-07-11	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	36523	delivery	5	26
94450	2020-07-11 18:24:00	2020-07-11	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	22606	delivery	5	26
94451	2020-07-11 18:24:57	2020-07-11	14	[{"id_menu":2,"count":1}]	4190	delivery	5	19
94452	2020-07-11 18:25:47	2020-07-11	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	28564	delivery	5	44
94453	2020-07-11 18:27:17	2020-07-11	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36654	delivery	5	37
94454	2020-07-11 18:28:32	2020-07-11	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	5022	delivery	5	40
94455	2020-07-11 18:29:14	2020-07-11	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	36584	delivery	5	26
94456	2020-07-11 18:29:23	2020-07-11	17	[{"id_menu":4,"count":1}]	5603	delivery	5	22
94457	2020-07-11 18:30:09	2020-07-11	14	[{"id_menu":2,"count":1}]	7510	delivery	5	19
94458	2020-07-11 18:31:59	2020-07-11	14	[{"id_menu":2,"count":1}]	3105	delivery	5	19
94459	2020-07-11 18:32:07	2020-07-11	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	34546	delivery	5	26
94460	2020-07-11 18:32:50	2020-07-11	9	[{"id_menu":7,"count":1}]	36557	delivery	5	14
94461	2020-07-11 18:36:11	2020-07-11	14	[{"id_menu":2,"count":1}]	18054	delivery	5	19
94462	2020-07-11 18:39:03	2020-07-11	8	[{"id_menu":5,"count":1}]	5635	delivery	5	13
94463	2020-07-11 18:43:24	2020-07-11	12	[{"id_menu":3,"count":1}]	8146	pick-up	0	12
94464	2020-07-11 18:43:56	2020-07-11	9	[{"id_menu":6,"count":1}]	27141	delivery	5	14
94465	2020-07-11 18:51:47	2020-07-11	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	21601	pick-up	0	20
94466	2020-07-11 18:53:27	2020-07-11	9	[{"id_menu":6,"count":2}]	7653	delivery	5	14
94467	2020-07-11 18:56:38	2020-07-11	14	[{"id_menu":2,"count":2}]	36524	pick-up	0	14
94468	2020-07-11 18:57:03	2020-07-11	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	26536	delivery	5	39
94469	2020-07-11 18:58:16	2020-07-11	9	[{"id_menu":6,"count":1}]	1093	pick-up	0	9
94470	2020-07-11 19:00:45	2020-07-11	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6265	pick-up	0	23
94471	2020-07-11 19:02:22	2020-07-11	12	[{"id_menu":3,"count":1}]	26902	delivery	5	17
94472	2020-07-11 19:05:03	2020-07-11	9	[{"id_menu":7,"count":1}]	32697	delivery	5	14
94473	2020-07-11 19:05:58	2020-07-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16290	delivery	5	22
94474	2020-07-11 19:06:03	2020-07-11	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	10851	delivery	5	28
94475	2020-07-11 19:09:48	2020-07-11	12	[{"id_menu":3,"count":1}]	12027	delivery	5	17
94476	2020-07-11 19:10:20	2020-07-11	8	[{"id_menu":5,"count":1}]	9575	pick-up	0	8
94477	2020-07-11 19:13:12	2020-07-11	9	[{"id_menu":7,"count":1}]	4094	pick-up	0	9
94478	2020-07-11 19:17:28	2020-07-11	9	[{"id_menu":7,"count":1}]	36567	delivery	5	14
94479	2020-07-11 19:19:03	2020-07-11	9	[{"id_menu":7,"count":1}]	27486	delivery	5	14
94480	2020-07-11 19:21:02	2020-07-11	17	[{"id_menu":4,"count":1}]	36745	delivery	5	22
94481	2020-07-11 19:23:03	2020-07-11	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25575	delivery	5	37
94482	2020-07-11 19:23:37	2020-07-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	36560	delivery	5	23
94483	2020-07-11 19:26:30	2020-07-11	12	[{"id_menu":3,"count":1}]	36516	delivery	5	17
94484	2020-07-11 19:27:57	2020-07-11	17	[{"id_menu":4,"count":1}]	36681	delivery	5	22
94485	2020-07-11 19:28:21	2020-07-11	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	36710	delivery	5	39
94486	2020-07-11 19:28:25	2020-07-11	17	[{"id_menu":4,"count":1}]	599	pick-up	0	17
94487	2020-07-11 19:32:27	2020-07-11	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	31823	delivery	5	30
94488	2020-07-11 19:35:34	2020-07-11	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	11046	delivery	5	30
94489	2020-07-11 19:35:41	2020-07-11	9	[{"id_menu":6,"count":1}]	36535	delivery	5	14
94490	2020-07-11 19:38:21	2020-07-11	8	[{"id_menu":5,"count":1}]	25214	pick-up	0	8
94491	2020-07-11 19:39:25	2020-07-11	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2653	pick-up	0	51
94492	2020-07-11 19:41:22	2020-07-11	9	[{"id_menu":6,"count":1}]	18392	pick-up	0	9
94493	2020-07-11 19:42:55	2020-07-11	8	[{"id_menu":5,"count":1}]	36541	delivery	5	13
94494	2020-07-11 19:44:27	2020-07-11	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	33357	delivery	5	22
94495	2020-07-11 19:45:36	2020-07-11	8	[{"id_menu":5,"count":1}]	36643	delivery	5	13
94496	2020-07-11 19:46:04	2020-07-11	9	[{"id_menu":6,"count":1}]	18274	delivery	5	14
94497	2020-07-11 19:54:25	2020-07-11	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	531	pick-up	0	29
94498	2020-07-11 19:54:46	2020-07-11	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	15491	delivery	5	39
94499	2020-07-11 19:58:15	2020-07-11	12	[{"id_menu":3,"count":1}]	36625	delivery	5	17
94500	2020-07-11 20:02:24	2020-07-11	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	16858	delivery	5	26
94501	2020-07-11 20:05:58	2020-07-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11435	delivery	5	22
94502	2020-07-11 20:06:03	2020-07-11	8	[{"id_menu":5,"count":1}]	36590	delivery	5	13
94503	2020-07-11 20:06:56	2020-07-11	17	[{"id_menu":4,"count":2}]	36594	delivery	5	22
94504	2020-07-11 20:07:25	2020-07-11	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	36723	delivery	5	39
94505	2020-07-11 20:08:10	2020-07-11	17	[{"id_menu":4,"count":1}]	13054	pick-up	0	17
94506	2020-07-11 20:11:20	2020-07-11	12	[{"id_menu":3,"count":1}]	35326	delivery	5	17
94507	2020-07-11 20:11:36	2020-07-11	9	[{"id_menu":6,"count":1}]	19957	pick-up	0	9
94508	2020-07-11 20:11:46	2020-07-11	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27895	delivery	5	48
94509	2020-07-11 20:15:26	2020-07-11	12	[{"id_menu":1,"count":1}]	6015	delivery	5	17
94510	2020-07-11 20:20:36	2020-07-11	17	[{"id_menu":4,"count":1}]	14115	pick-up	0	17
94511	2020-07-11 20:21:36	2020-07-11	9	[{"id_menu":6,"count":1}]	33452	pick-up	0	9
94512	2020-07-11 20:23:38	2020-07-11	9	[{"id_menu":6,"count":1}]	11465	pick-up	0	9
94513	2020-07-11 20:25:35	2020-07-11	9	[{"id_menu":7,"count":1}]	26610	delivery	5	14
94514	2020-07-11 20:28:50	2020-07-11	17	[{"id_menu":4,"count":1}]	8546	delivery	5	22
94515	2020-07-11 20:30:40	2020-07-11	17	[{"id_menu":4,"count":1}]	22767	delivery	5	22
94516	2020-07-11 20:31:33	2020-07-11	9	[{"id_menu":7,"count":1}]	36598	delivery	5	14
94517	2020-07-11 20:31:50	2020-07-11	14	[{"id_menu":2,"count":1}]	1303	pick-up	0	14
94518	2020-07-11 20:36:06	2020-07-11	12	[{"id_menu":1,"count":1}]	31701	pick-up	0	12
94519	2020-07-11 20:36:18	2020-07-11	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	36642	delivery	5	37
94520	2020-07-11 20:40:02	2020-07-11	9	[{"id_menu":7,"count":1}]	36559	delivery	5	14
94521	2020-07-11 20:40:45	2020-07-11	9	[{"id_menu":6,"count":1}]	11592	delivery	5	14
94522	2020-07-11 20:41:13	2020-07-11	12	[{"id_menu":1,"count":1}]	3554	delivery	5	17
94523	2020-07-11 20:41:59	2020-07-11	9	[{"id_menu":7,"count":1}]	15025	delivery	5	14
94524	2020-07-11 20:42:09	2020-07-11	9	[{"id_menu":6,"count":3}]	8570	delivery	5	14
94525	2020-07-11 20:42:16	2020-07-11	9	[{"id_menu":6,"count":1}]	34196	delivery	5	14
94526	2020-07-11 20:43:27	2020-07-11	12	[{"id_menu":1,"count":1}]	19541	pick-up	0	12
94527	2020-07-11 20:44:22	2020-07-11	9	[{"id_menu":6,"count":1}]	9193	delivery	5	14
94528	2020-07-11 20:45:12	2020-07-11	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	36553	delivery	5	23
94529	2020-07-11 20:45:36	2020-07-11	17	[{"id_menu":4,"count":1}]	36435	delivery	5	22
94530	2020-07-11 20:47:31	2020-07-11	12	[{"id_menu":3,"count":1}]	55	pick-up	0	12
94531	2020-07-11 20:51:48	2020-07-11	17	[{"id_menu":4,"count":1}]	13482	delivery	5	22
94532	2020-07-11 21:01:27	2020-07-11	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	36622	delivery	5	31
94533	2020-07-11 21:06:35	2020-07-11	9	[{"id_menu":6,"count":1}]	36626	delivery	5	14
94534	2020-07-11 21:07:50	2020-07-11	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	10498	delivery	5	23
94535	2020-07-11 21:08:22	2020-07-11	17	[{"id_menu":4,"count":1}]	36513	delivery	5	22
94536	2020-07-11 21:12:20	2020-07-11	12	[{"id_menu":1,"count":2}]	36740	delivery	5	17
94537	2020-07-11 21:15:00	2020-07-11	17	[{"id_menu":4,"count":1}]	36648	delivery	5	22
94538	2020-07-11 21:16:30	2020-07-11	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	9524	delivery	5	31
94539	2020-07-11 21:20:43	2020-07-11	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	36632	delivery	5	40
94540	2020-07-11 21:21:29	2020-07-11	8	[{"id_menu":5,"count":1}]	21048	delivery	5	13
94541	2020-07-11 21:23:10	2020-07-11	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	34975	delivery	5	36
94542	2020-07-11 21:25:33	2020-07-11	9	[{"id_menu":6,"count":1}]	30295	delivery	5	14
94543	2020-07-11 21:27:35	2020-07-11	12	[{"id_menu":3,"count":1}]	17067	delivery	5	17
94544	2020-07-11 21:28:28	2020-07-11	9	[{"id_menu":6,"count":2}]	36737	delivery	5	14
94545	2020-07-11 21:34:44	2020-07-11	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9194	delivery	5	22
94546	2020-07-11 21:34:52	2020-07-11	14	[{"id_menu":2,"count":1}]	36682	delivery	5	19
94547	2020-07-11 21:35:10	2020-07-11	8	[{"id_menu":5,"count":1}]	12855	delivery	5	13
94548	2020-07-11 21:36:09	2020-07-11	9	[{"id_menu":7,"count":1}]	36601	delivery	5	14
94549	2020-07-11 21:38:39	2020-07-11	9	[{"id_menu":6,"count":1}]	36568	delivery	5	14
94550	2020-07-11 21:39:48	2020-07-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	36597	delivery	5	28
94551	2020-07-11 21:43:03	2020-07-11	9	[{"id_menu":7,"count":1}]	24789	delivery	5	14
94552	2020-07-11 21:48:40	2020-07-11	9	[{"id_menu":6,"count":1}]	26743	delivery	5	14
94553	2020-07-11 21:49:37	2020-07-11	9	[{"id_menu":7,"count":1}]	23334	delivery	5	14
94554	2020-07-11 21:49:39	2020-07-11	12	[{"id_menu":3,"count":1}]	3651	delivery	5	17
94555	2020-07-11 21:50:37	2020-07-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	36575	delivery	5	22
94556	2020-07-11 21:50:52	2020-07-11	9	[{"id_menu":6,"count":1}]	2173	pick-up	0	9
94557	2020-07-11 21:56:55	2020-07-11	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	35449	delivery	5	31
94558	2020-07-11 21:57:26	2020-07-11	9	[{"id_menu":7,"count":1}]	18777	delivery	5	14
94559	2020-07-11 21:58:27	2020-07-11	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	36689	delivery	5	23
94560	2020-07-11 22:01:20	2020-07-11	8	[{"id_menu":5,"count":1}]	31284	delivery	5	13
94561	2020-07-11 22:02:01	2020-07-11	9	[{"id_menu":7,"count":1}]	36628	delivery	5	14
94562	2020-07-11 22:05:23	2020-07-11	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12853	delivery	5	37
94563	2020-07-11 22:06:31	2020-07-11	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36566	delivery	5	52
94564	2020-07-11 22:07:29	2020-07-11	9	[{"id_menu":6,"count":2}]	36680	delivery	5	14
94565	2020-07-11 22:08:30	2020-07-11	9	[{"id_menu":6,"count":2}]	25969	delivery	5	14
94566	2020-07-11 22:15:16	2020-07-11	17	[{"id_menu":4,"count":1}]	3634	delivery	5	22
94567	2020-07-11 22:15:25	2020-07-11	9	[{"id_menu":6,"count":1}]	36698	delivery	5	14
94568	2020-07-11 22:15:26	2020-07-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	36713	delivery	5	22
94569	2020-07-11 22:16:06	2020-07-11	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	34400	delivery	5	45
94570	2020-07-11 22:16:22	2020-07-11	9	[{"id_menu":7,"count":1}]	23835	delivery	5	14
94571	2020-07-11 22:18:15	2020-07-11	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	35102	delivery	5	26
94572	2020-07-11 22:22:34	2020-07-11	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	36657	delivery	5	45
94573	2020-07-11 22:23:11	2020-07-11	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	18755	pick-up	0	21
94574	2020-07-11 22:24:10	2020-07-11	12	[{"id_menu":3,"count":1}]	3361	pick-up	0	12
94575	2020-07-11 22:30:00	2020-07-11	12	[{"id_menu":3,"count":1}]	36514	delivery	5	17
94576	2020-07-11 22:32:06	2020-07-11	9	[{"id_menu":6,"count":1}]	36724	pick-up	0	9
94577	2020-07-11 22:34:41	2020-07-11	9	[{"id_menu":7,"count":1}]	36610	delivery	5	14
94578	2020-07-11 22:37:44	2020-07-11	14	[{"id_menu":2,"count":1}]	36658	pick-up	0	14
94579	2020-07-11 22:41:35	2020-07-11	12	[{"id_menu":3,"count":1}]	25631	delivery	5	17
94580	2020-07-11 22:43:35	2020-07-11	9	[{"id_menu":6,"count":1}]	4100	delivery	5	14
94581	2020-07-11 22:43:51	2020-07-11	9	[{"id_menu":6,"count":1}]	5970	pick-up	0	9
94582	2020-07-11 22:48:38	2020-07-11	12	[{"id_menu":3,"count":1}]	36685	delivery	5	17
94583	2020-07-11 22:49:53	2020-07-11	8	[{"id_menu":5,"count":1}]	36587	delivery	5	13
94584	2020-07-11 22:50:50	2020-07-11	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	36570	delivery	5	45
94585	2020-07-11 22:53:35	2020-07-11	14	[{"id_menu":2,"count":1}]	33415	delivery	5	19
94586	2020-07-11 22:54:01	2020-07-11	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19307	delivery	5	31
94587	2020-07-11 22:57:31	2020-07-11	17	[{"id_menu":4,"count":1}]	36472	pick-up	0	17
94588	2020-07-11 22:58:06	2020-07-11	12	[{"id_menu":1,"count":1}]	18839	pick-up	0	12
94589	2020-07-11 22:59:35	2020-07-11	9	[{"id_menu":6,"count":1}]	19583	delivery	5	14
94590	2020-07-11 22:59:46	2020-07-11	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15628	delivery	5	43
94591	2020-07-11 23:00:04	2020-07-11	12	[{"id_menu":3,"count":1}]	2053	delivery	5	17
94592	2020-07-11 23:00:38	2020-07-11	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	36644	delivery	5	34
94593	2020-07-11 23:01:36	2020-07-11	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":2}]	36693	delivery	5	28
94594	2020-07-11 23:02:00	2020-07-11	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	279	pick-up	0	29
94595	2020-07-11 23:05:16	2020-07-11	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	35812	delivery	5	43
94596	2020-07-11 23:06:53	2020-07-11	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	7849	delivery	5	40
94597	2020-07-11 23:08:38	2020-07-11	8	[{"id_menu":5,"count":1}]	32603	delivery	5	13
94598	2020-07-11 23:09:10	2020-07-11	9	[{"id_menu":6,"count":1}]	12132	delivery	5	14
94599	2020-07-11 23:10:22	2020-07-11	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	15827	delivery	5	26
94600	2020-07-11 23:12:19	2020-07-11	12	[{"id_menu":3,"count":1}]	31279	delivery	5	17
94601	2020-07-11 23:13:39	2020-07-11	14	[{"id_menu":2,"count":1}]	7875	delivery	5	19
94602	2020-07-11 23:13:53	2020-07-11	17	[{"id_menu":4,"count":1}]	7639	pick-up	0	17
94603	2020-07-11 23:16:29	2020-07-11	14	[{"id_menu":2,"count":2}]	4193	pick-up	0	14
94604	2020-07-11 23:16:33	2020-07-11	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	8739	pick-up	0	29
94605	2020-07-11 23:17:09	2020-07-11	9	[{"id_menu":6,"count":1}]	19566	delivery	5	14
94606	2020-07-11 23:17:13	2020-07-11	8	[{"id_menu":5,"count":1}]	14133	pick-up	0	8
94607	2020-07-11 23:17:29	2020-07-11	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4642	pick-up	0	35
94608	2020-07-11 23:20:51	2020-07-11	9	[{"id_menu":6,"count":1}]	17472	pick-up	0	9
94609	2020-07-11 23:22:00	2020-07-11	8	[{"id_menu":5,"count":1}]	34221	delivery	5	13
94610	2020-07-11 23:24:00	2020-07-11	17	[{"id_menu":4,"count":1}]	36725	pick-up	0	17
94611	2020-07-11 23:26:37	2020-07-11	9	[{"id_menu":6,"count":1}]	36530	delivery	5	14
94612	2020-07-11 23:27:12	2020-07-11	12	[{"id_menu":1,"count":1}]	12615	delivery	5	17
94613	2020-07-11 23:27:57	2020-07-11	34	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	8136	delivery	5	39
94614	2020-07-11 23:33:02	2020-07-11	8	[{"id_menu":5,"count":1}]	36536	pick-up	0	8
94615	2020-07-11 23:36:31	2020-07-11	12	[{"id_menu":3,"count":2}]	36649	delivery	5	17
94616	2020-07-11 23:37:44	2020-07-11	9	[{"id_menu":6,"count":1}]	2231	delivery	5	14
94617	2020-07-11 23:40:51	2020-07-11	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	36585	delivery	5	44
94618	2020-07-11 23:42:47	2020-07-11	12	[{"id_menu":3,"count":1}]	4528	delivery	5	17
94619	2020-07-11 23:44:12	2020-07-11	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	36592	delivery	5	39
94620	2020-07-11 23:47:52	2020-07-11	9	[{"id_menu":7,"count":1}]	20835	pick-up	0	9
94621	2020-07-11 23:48:12	2020-07-11	12	[{"id_menu":3,"count":2}]	36549	delivery	5	17
94622	2020-07-11 23:48:42	2020-07-11	9	[{"id_menu":6,"count":1}]	9242	delivery	5	14
94623	2020-07-11 23:50:44	2020-07-11	12	[{"id_menu":3,"count":1}]	2637	pick-up	0	12
94624	2020-07-11 23:53:18	2020-07-11	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	18947	delivery	5	43
94625	2020-07-11 23:55:52	2020-07-11	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	36730	delivery	5	30
94626	2020-07-11 23:57:37	2020-07-11	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	26373	pick-up	0	21
94627	2020-07-11 23:58:38	2020-07-11	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	35940	delivery	5	43
94628	2020-07-11 23:59:23	2020-07-11	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":3}]	36538	delivery	5	36
94629	2020-07-11 23:59:41	2020-07-11	8	[{"id_menu":5,"count":1}]	22127	delivery	5	13
94630	2020-07-12 00:00:40	2020-07-12	12	[{"id_menu":1,"count":1}]	28155	delivery	5	17
94631	2020-07-12 00:00:51	2020-07-12	14	[{"id_menu":2,"count":1}]	36784	delivery	5	19
94632	2020-07-12 00:01:12	2020-07-12	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	8866	delivery	5	39
94633	2020-07-12 00:04:23	2020-07-12	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	26789	delivery	5	22
94634	2020-07-12 00:06:50	2020-07-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	36899	delivery	5	31
94635	2020-07-12 00:07:09	2020-07-12	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36937	delivery	5	45
94636	2020-07-12 00:10:04	2020-07-12	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6641	pick-up	0	26
94637	2020-07-12 00:13:18	2020-07-12	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3648	delivery	5	30
94638	2020-07-12 00:15:46	2020-07-12	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	26242	delivery	5	27
94639	2020-07-12 00:15:52	2020-07-12	12	[{"id_menu":3,"count":1}]	34917	delivery	5	17
94640	2020-07-12 00:17:56	2020-07-12	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6034	delivery	5	31
94641	2020-07-12 00:18:16	2020-07-12	17	[{"id_menu":4,"count":1}]	19181	delivery	5	22
94642	2020-07-12 00:20:09	2020-07-12	14	[{"id_menu":2,"count":1}]	12326	pick-up	0	14
94643	2020-07-12 00:21:42	2020-07-12	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	36780	delivery	5	35
94644	2020-07-12 00:22:31	2020-07-12	9	[{"id_menu":7,"count":1}]	36919	delivery	5	14
94645	2020-07-12 00:24:32	2020-07-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	36857	delivery	5	31
94646	2020-07-12 00:25:54	2020-07-12	14	[{"id_menu":2,"count":1}]	33452	delivery	5	19
94647	2020-07-12 00:26:06	2020-07-12	9	[{"id_menu":6,"count":2}]	36861	delivery	5	14
94648	2020-07-12 00:27:53	2020-07-12	9	[{"id_menu":6,"count":1}]	35285	delivery	5	14
94649	2020-07-12 00:28:00	2020-07-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	36968	delivery	5	31
94650	2020-07-12 00:31:02	2020-07-12	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14224	delivery	5	43
94651	2020-07-12 00:31:24	2020-07-12	14	[{"id_menu":2,"count":1}]	16082	delivery	5	19
94652	2020-07-12 00:32:04	2020-07-12	8	[{"id_menu":5,"count":1}]	13220	delivery	5	13
94653	2020-07-12 00:35:52	2020-07-12	9	[{"id_menu":6,"count":2}]	9734	pick-up	0	9
94654	2020-07-12 00:36:15	2020-07-12	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	33399	delivery	5	31
94655	2020-07-12 00:36:25	2020-07-12	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	36903	delivery	5	39
94656	2020-07-12 00:38:10	2020-07-12	17	[{"id_menu":4,"count":1}]	36839	pick-up	0	17
94657	2020-07-12 00:38:59	2020-07-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36932	delivery	5	23
94658	2020-07-12 00:40:46	2020-07-12	17	[{"id_menu":4,"count":1}]	26675	delivery	5	22
94659	2020-07-12 00:42:39	2020-07-12	9	[{"id_menu":6,"count":3}]	30906	delivery	5	14
94660	2020-07-12 00:43:02	2020-07-12	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3540	delivery	5	31
94661	2020-07-12 00:44:09	2020-07-12	8	[{"id_menu":5,"count":1}]	16352	delivery	5	13
94662	2020-07-12 00:44:29	2020-07-12	17	[{"id_menu":4,"count":1}]	1071	delivery	5	22
94663	2020-07-12 00:45:41	2020-07-12	9	[{"id_menu":6,"count":1}]	30350	delivery	5	14
94664	2020-07-12 00:46:01	2020-07-12	9	[{"id_menu":7,"count":1}]	17652	delivery	5	14
94665	2020-07-12 00:48:56	2020-07-12	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5192	delivery	5	31
94666	2020-07-12 00:50:13	2020-07-12	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5945	pick-up	0	26
94667	2020-07-12 00:54:16	2020-07-12	8	[{"id_menu":5,"count":1}]	1860	pick-up	0	8
94668	2020-07-12 00:54:36	2020-07-12	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	705	delivery	5	34
94669	2020-07-12 00:55:42	2020-07-12	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	36959	delivery	5	27
94670	2020-07-12 00:56:24	2020-07-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19812	delivery	5	23
94671	2020-07-12 00:56:41	2020-07-12	14	[{"id_menu":2,"count":2}]	16235	delivery	5	19
94672	2020-07-12 00:58:32	2020-07-12	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	31526	delivery	5	26
94673	2020-07-12 01:00:25	2020-07-12	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1079	delivery	5	31
94674	2020-07-12 01:01:29	2020-07-12	14	[{"id_menu":2,"count":1}]	389	pick-up	0	14
94675	2020-07-12 01:02:17	2020-07-12	9	[{"id_menu":6,"count":1}]	7819	delivery	5	14
94676	2020-07-12 01:02:33	2020-07-12	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	490	delivery	5	45
94677	2020-07-12 01:02:44	2020-07-12	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	14985	delivery	5	26
94678	2020-07-12 01:03:31	2020-07-12	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	36824	delivery	5	31
94679	2020-07-12 01:04:17	2020-07-12	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	35886	pick-up	0	17
94680	2020-07-12 01:06:40	2020-07-12	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	36770	delivery	5	45
94681	2020-07-12 01:08:31	2020-07-12	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	15189	delivery	5	26
94682	2020-07-12 01:09:45	2020-07-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1183	pick-up	0	26
94683	2020-07-12 01:13:22	2020-07-12	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	33084	delivery	5	26
94684	2020-07-12 01:17:53	2020-07-12	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	36834	delivery	5	43
94685	2020-07-12 01:20:26	2020-07-12	12	[{"id_menu":3,"count":1}]	14862	delivery	5	17
94686	2020-07-12 01:22:21	2020-07-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	32222	pick-up	0	23
94687	2020-07-12 01:23:49	2020-07-12	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	30327	delivery	5	45
94688	2020-07-12 01:24:03	2020-07-12	17	[{"id_menu":4,"count":1}]	36963	delivery	5	22
94689	2020-07-12 01:24:06	2020-07-12	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	36934	delivery	5	26
94690	2020-07-12 01:25:39	2020-07-12	14	[{"id_menu":2,"count":1}]	36975	delivery	5	19
94691	2020-07-12 01:25:56	2020-07-12	8	[{"id_menu":5,"count":1}]	34775	delivery	5	13
94692	2020-07-12 01:25:59	2020-07-12	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	36828	delivery	5	44
94693	2020-07-12 01:26:21	2020-07-12	9	[{"id_menu":7,"count":1}]	27970	delivery	5	14
94694	2020-07-12 01:28:50	2020-07-12	9	[{"id_menu":6,"count":1}]	3835	delivery	5	14
94695	2020-07-12 01:31:14	2020-07-12	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	36859	delivery	5	36
94696	2020-07-12 01:32:27	2020-07-12	9	[{"id_menu":6,"count":1}]	20787	delivery	5	14
94697	2020-07-12 01:34:45	2020-07-12	14	[{"id_menu":2,"count":1}]	32641	delivery	5	19
94698	2020-07-12 01:34:53	2020-07-12	8	[{"id_menu":5,"count":1}]	30747	delivery	5	13
94699	2020-07-12 01:38:25	2020-07-12	14	[{"id_menu":2,"count":1}]	26412	delivery	5	19
94700	2020-07-12 01:40:56	2020-07-12	12	[{"id_menu":3,"count":1}]	7188	delivery	5	17
94701	2020-07-12 01:41:14	2020-07-12	9	[{"id_menu":6,"count":2}]	36936	delivery	5	14
94702	2020-07-12 01:44:08	2020-07-12	12	[{"id_menu":3,"count":1}]	5485	delivery	5	17
94703	2020-07-12 01:44:23	2020-07-12	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	4629	delivery	5	26
94704	2020-07-12 01:47:45	2020-07-12	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36862	delivery	5	49
94705	2020-07-12 01:48:15	2020-07-12	8	[{"id_menu":5,"count":1}]	36939	delivery	5	13
94706	2020-07-12 01:48:49	2020-07-12	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	14915	delivery	5	38
94707	2020-07-12 01:48:55	2020-07-12	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	36789	delivery	5	35
94708	2020-07-12 01:48:57	2020-07-12	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	26187	delivery	5	30
94709	2020-07-12 01:50:12	2020-07-12	9	[{"id_menu":7,"count":1}]	6664	delivery	5	14
94710	2020-07-12 01:51:27	2020-07-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1481	pick-up	0	18
94711	2020-07-12 01:54:18	2020-07-12	9	[{"id_menu":6,"count":1}]	4650	pick-up	0	9
94712	2020-07-12 01:55:12	2020-07-12	17	[{"id_menu":4,"count":1}]	36844	delivery	5	22
94713	2020-07-12 01:59:08	2020-07-12	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	31706	delivery	5	28
94714	2020-07-12 02:01:48	2020-07-12	9	[{"id_menu":6,"count":1}]	36819	delivery	5	14
94715	2020-07-12 02:01:58	2020-07-12	9	[{"id_menu":7,"count":1}]	24620	pick-up	0	9
94716	2020-07-12 02:11:18	2020-07-12	14	[{"id_menu":2,"count":1}]	36879	delivery	5	19
94717	2020-07-12 02:13:07	2020-07-12	17	[{"id_menu":4,"count":1}]	36810	delivery	5	22
94718	2020-07-12 02:13:15	2020-07-12	9	[{"id_menu":7,"count":1}]	10656	delivery	5	14
94719	2020-07-12 02:15:14	2020-07-12	12	[{"id_menu":1,"count":1}]	36917	delivery	5	17
94720	2020-07-12 02:17:44	2020-07-12	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7245	delivery	5	34
94721	2020-07-12 02:19:37	2020-07-12	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	15132	delivery	5	26
94722	2020-07-12 02:20:17	2020-07-12	14	[{"id_menu":2,"count":1}]	36823	delivery	5	19
94723	2020-07-12 02:21:30	2020-07-12	9	[{"id_menu":6,"count":1}]	8303	pick-up	0	9
94724	2020-07-12 02:21:58	2020-07-12	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	2820	delivery	5	29
94725	2020-07-12 02:24:00	2020-07-12	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	5972	pick-up	0	20
94726	2020-07-12 02:26:53	2020-07-12	8	[{"id_menu":5,"count":1}]	31712	delivery	5	13
94727	2020-07-12 02:28:27	2020-07-12	8	[{"id_menu":5,"count":1}]	24255	delivery	5	13
94728	2020-07-12 02:31:00	2020-07-12	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	36943	delivery	5	48
94729	2020-07-12 02:34:28	2020-07-12	12	[{"id_menu":3,"count":1}]	23391	delivery	5	17
94730	2020-07-12 02:34:30	2020-07-12	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	26804	pick-up	0	26
94731	2020-07-12 02:39:09	2020-07-12	17	[{"id_menu":4,"count":1}]	36929	delivery	5	22
94732	2020-07-12 02:44:44	2020-07-12	9	[{"id_menu":6,"count":1}]	27645	delivery	5	14
94733	2020-07-12 02:44:48	2020-07-12	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	36803	delivery	5	28
94734	2020-07-12 02:47:05	2020-07-12	14	[{"id_menu":2,"count":1}]	19682	delivery	5	19
94735	2020-07-12 02:53:02	2020-07-12	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	36809	delivery	5	36
94736	2020-07-12 02:55:44	2020-07-12	9	[{"id_menu":7,"count":1}]	36908	delivery	5	14
94737	2020-07-12 02:56:32	2020-07-12	9	[{"id_menu":7,"count":1}]	27817	delivery	5	14
94738	2020-07-12 02:58:37	2020-07-12	9	[{"id_menu":7,"count":1}]	13136	pick-up	0	9
94739	2020-07-12 03:00:08	2020-07-12	9	[{"id_menu":6,"count":1}]	31486	delivery	5	14
94740	2020-07-12 03:00:25	2020-07-12	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20400	delivery	5	39
94741	2020-07-12 03:03:17	2020-07-12	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	31596	pick-up	0	31
94742	2020-07-12 03:03:38	2020-07-12	14	[{"id_menu":2,"count":1}]	36791	delivery	5	19
94743	2020-07-12 03:05:04	2020-07-12	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	20993	delivery	5	30
94744	2020-07-12 03:09:06	2020-07-12	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4635	pick-up	0	29
94745	2020-07-12 03:11:40	2020-07-12	12	[{"id_menu":3,"count":1}]	36878	delivery	5	17
94746	2020-07-12 03:12:38	2020-07-12	9	[{"id_menu":7,"count":1}]	36895	delivery	5	14
94747	2020-07-12 03:13:00	2020-07-12	9	[{"id_menu":7,"count":1}]	35576	delivery	5	14
94748	2020-07-12 03:17:06	2020-07-12	8	[{"id_menu":5,"count":1}]	36775	delivery	5	13
94749	2020-07-12 03:17:21	2020-07-12	8	[{"id_menu":5,"count":1}]	4363	pick-up	0	8
94750	2020-07-12 03:19:15	2020-07-12	12	[{"id_menu":3,"count":1}]	36960	delivery	5	17
94751	2020-07-12 03:19:46	2020-07-12	9	[{"id_menu":6,"count":1}]	21162	delivery	5	14
94752	2020-07-12 03:19:54	2020-07-12	12	[{"id_menu":3,"count":1}]	36799	delivery	5	17
94753	2020-07-12 03:20:41	2020-07-12	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	20033	delivery	5	23
94754	2020-07-12 03:21:12	2020-07-12	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	19986	delivery	5	25
94755	2020-07-12 03:23:34	2020-07-12	9	[{"id_menu":7,"count":1}]	36544	delivery	5	14
94756	2020-07-12 03:24:55	2020-07-12	9	[{"id_menu":7,"count":1}]	33338	delivery	5	14
94757	2020-07-12 03:26:04	2020-07-12	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20710	delivery	5	39
94758	2020-07-12 03:27:57	2020-07-12	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	36918	delivery	5	34
94759	2020-07-12 03:30:33	2020-07-12	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9350	delivery	5	40
94760	2020-07-12 03:35:57	2020-07-12	8	[{"id_menu":5,"count":2}]	30062	delivery	5	13
94761	2020-07-12 03:37:43	2020-07-12	8	[{"id_menu":5,"count":1}]	1269	delivery	5	13
94762	2020-07-12 03:38:07	2020-07-12	12	[{"id_menu":3,"count":1}]	24505	delivery	5	17
94763	2020-07-12 03:39:38	2020-07-12	8	[{"id_menu":5,"count":1}]	36774	delivery	5	13
94764	2020-07-12 03:41:17	2020-07-12	9	[{"id_menu":7,"count":1}]	34475	delivery	5	14
94765	2020-07-12 03:41:42	2020-07-12	9	[{"id_menu":7,"count":1}]	36865	delivery	5	14
94766	2020-07-12 03:41:48	2020-07-12	14	[{"id_menu":2,"count":1}]	30230	delivery	5	19
94767	2020-07-12 03:42:45	2020-07-12	43	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	14522	delivery	5	48
94768	2020-07-12 03:43:32	2020-07-12	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	6811	delivery	5	34
94769	2020-07-12 03:43:33	2020-07-12	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	36868	delivery	5	31
94770	2020-07-12 03:44:03	2020-07-12	12	[{"id_menu":1,"count":1}]	30316	pick-up	0	12
94771	2020-07-12 03:46:27	2020-07-12	9	[{"id_menu":6,"count":1}]	36785	delivery	5	14
94772	2020-07-12 03:47:14	2020-07-12	9	[{"id_menu":6,"count":1}]	36866	delivery	5	14
94773	2020-07-12 03:48:31	2020-07-12	12	[{"id_menu":3,"count":1}]	28693	delivery	5	17
94774	2020-07-12 03:50:16	2020-07-12	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":2}]	6883	delivery	5	28
94775	2020-07-12 03:50:20	2020-07-12	14	[{"id_menu":2,"count":1}]	23421	pick-up	0	14
94776	2020-07-12 03:50:48	2020-07-12	9	[{"id_menu":6,"count":1}]	20657	delivery	5	14
94777	2020-07-12 03:51:10	2020-07-12	17	[{"id_menu":4,"count":1}]	21551	pick-up	0	17
94778	2020-07-12 03:53:44	2020-07-12	14	[{"id_menu":2,"count":1}]	9056	delivery	5	19
94779	2020-07-12 03:57:08	2020-07-12	8	[{"id_menu":5,"count":1}]	17086	delivery	5	13
94780	2020-07-12 04:01:10	2020-07-12	17	[{"id_menu":4,"count":1}]	33631	pick-up	0	17
94781	2020-07-12 04:01:25	2020-07-12	9	[{"id_menu":7,"count":1}]	14775	delivery	5	14
94782	2020-07-12 04:02:19	2020-07-12	9	[{"id_menu":7,"count":1}]	19931	delivery	5	14
94783	2020-07-12 04:04:12	2020-07-12	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	36907	delivery	5	31
94784	2020-07-12 04:06:18	2020-07-12	9	[{"id_menu":6,"count":1}]	31754	delivery	5	14
94785	2020-07-12 04:07:36	2020-07-12	9	[{"id_menu":6,"count":1}]	692	delivery	5	14
94786	2020-07-12 04:12:39	2020-07-12	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36854	delivery	5	40
94787	2020-07-12 04:13:00	2020-07-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	5117	delivery	5	28
94788	2020-07-12 04:14:16	2020-07-12	12	[{"id_menu":3,"count":1}]	36841	pick-up	0	12
94789	2020-07-12 04:14:18	2020-07-12	8	[{"id_menu":5,"count":1}]	23151	delivery	5	13
94790	2020-07-12 04:14:33	2020-07-12	9	[{"id_menu":7,"count":1}]	36948	pick-up	0	9
94791	2020-07-12 04:15:19	2020-07-12	8	[{"id_menu":5,"count":1}]	24538	delivery	5	13
94792	2020-07-12 04:18:00	2020-07-12	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	23486	delivery	5	45
94793	2020-07-12 04:18:37	2020-07-12	9	[{"id_menu":6,"count":2}]	15748	delivery	5	14
94794	2020-07-12 04:21:21	2020-07-12	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	5933	pick-up	0	21
94795	2020-07-12 04:21:53	2020-07-12	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	30049	delivery	5	44
94796	2020-07-12 04:22:50	2020-07-12	8	[{"id_menu":5,"count":1}]	36882	delivery	5	13
94797	2020-07-12 04:30:46	2020-07-12	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1366	pick-up	0	41
94798	2020-07-12 04:31:00	2020-07-12	14	[{"id_menu":2,"count":1}]	30812	pick-up	0	14
94799	2020-07-12 04:31:25	2020-07-12	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	14664	delivery	5	40
94800	2020-07-12 04:34:10	2020-07-12	12	[{"id_menu":1,"count":1}]	7955	delivery	5	17
94801	2020-07-12 04:34:26	2020-07-12	9	[{"id_menu":6,"count":1}]	27675	delivery	5	14
94802	2020-07-12 04:38:05	2020-07-12	17	[{"id_menu":4,"count":1}]	12557	delivery	5	22
94803	2020-07-12 04:38:39	2020-07-12	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14413	delivery	5	40
94804	2020-07-12 04:40:07	2020-07-12	12	[{"id_menu":3,"count":1}]	16745	pick-up	0	12
94805	2020-07-12 04:40:19	2020-07-12	8	[{"id_menu":5,"count":1}]	25884	delivery	5	13
94806	2020-07-12 04:41:29	2020-07-12	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	34870	delivery	5	28
94807	2020-07-12 04:42:00	2020-07-12	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	25313	delivery	5	40
94808	2020-07-12 04:45:21	2020-07-12	9	[{"id_menu":6,"count":1}]	26299	delivery	5	14
94809	2020-07-12 04:52:19	2020-07-12	8	[{"id_menu":5,"count":1}]	36837	delivery	5	13
94810	2020-07-12 04:53:44	2020-07-12	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	9348	delivery	5	27
94811	2020-07-12 04:53:48	2020-07-12	12	[{"id_menu":1,"count":2}]	32144	pick-up	0	12
94812	2020-07-12 04:56:08	2020-07-12	12	[{"id_menu":1,"count":1}]	2770	delivery	5	17
94813	2020-07-12 04:59:40	2020-07-12	12	[{"id_menu":1,"count":1}]	36935	delivery	5	17
94814	2020-07-12 05:00:45	2020-07-12	9	[{"id_menu":7,"count":1}]	36884	delivery	5	14
94815	2020-07-12 05:01:47	2020-07-12	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	36871	delivery	5	26
94816	2020-07-12 05:02:49	2020-07-12	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36921	delivery	5	31
94817	2020-07-12 05:03:47	2020-07-12	14	[{"id_menu":2,"count":1}]	30704	pick-up	0	14
94818	2020-07-12 05:05:26	2020-07-12	12	[{"id_menu":1,"count":1}]	36806	delivery	5	17
94819	2020-07-12 05:06:24	2020-07-12	9	[{"id_menu":6,"count":1}]	3837	delivery	5	14
94820	2020-07-12 05:12:09	2020-07-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14758	delivery	5	23
94821	2020-07-12 05:12:26	2020-07-12	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	31720	delivery	5	43
94822	2020-07-12 05:13:26	2020-07-12	14	[{"id_menu":2,"count":1}]	8054	pick-up	0	14
94823	2020-07-12 05:16:44	2020-07-12	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3570	pick-up	0	21
94824	2020-07-12 05:17:31	2020-07-12	12	[{"id_menu":1,"count":1}]	28208	delivery	5	17
94825	2020-07-12 05:18:43	2020-07-12	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	31578	pick-up	0	26
94826	2020-07-12 05:21:24	2020-07-12	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	36777	delivery	5	36
94827	2020-07-12 05:25:44	2020-07-12	9	[{"id_menu":6,"count":2}]	9737	delivery	5	14
94828	2020-07-12 05:26:02	2020-07-12	9	[{"id_menu":7,"count":1}]	16434	pick-up	0	9
94829	2020-07-12 05:26:06	2020-07-12	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	36843	delivery	5	56
94830	2020-07-12 05:29:35	2020-07-12	9	[{"id_menu":6,"count":1}]	36941	delivery	5	14
94831	2020-07-12 05:29:40	2020-07-12	9	[{"id_menu":7,"count":1}]	22283	pick-up	0	9
94832	2020-07-12 05:39:58	2020-07-12	8	[{"id_menu":5,"count":1}]	22614	pick-up	0	8
94833	2020-07-12 05:40:00	2020-07-12	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	29787	delivery	5	27
94834	2020-07-12 05:42:04	2020-07-12	14	[{"id_menu":2,"count":1}]	21360	delivery	5	19
94835	2020-07-12 05:43:09	2020-07-12	12	[{"id_menu":3,"count":1}]	26891	pick-up	0	12
94836	2020-07-12 05:43:16	2020-07-12	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	14447	delivery	5	36
94837	2020-07-12 05:44:04	2020-07-12	14	[{"id_menu":2,"count":1}]	18755	pick-up	0	14
94838	2020-07-12 05:45:33	2020-07-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35669	delivery	5	23
94839	2020-07-12 05:45:52	2020-07-12	12	[{"id_menu":1,"count":1}]	8355	pick-up	0	12
94840	2020-07-12 05:46:05	2020-07-12	12	[{"id_menu":1,"count":1}]	22626	delivery	5	17
94841	2020-07-12 05:48:01	2020-07-12	12	[{"id_menu":3,"count":2}]	2573	pick-up	0	12
94842	2020-07-12 05:48:02	2020-07-12	9	[{"id_menu":7,"count":1}]	36969	delivery	5	14
94843	2020-07-12 05:50:13	2020-07-12	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2605	delivery	5	34
94844	2020-07-12 05:52:22	2020-07-12	9	[{"id_menu":6,"count":1}]	36945	delivery	5	14
94845	2020-07-12 05:55:27	2020-07-12	12	[{"id_menu":3,"count":1}]	8402	delivery	5	17
94846	2020-07-12 05:56:05	2020-07-12	9	[{"id_menu":6,"count":1}]	14922	delivery	5	14
94847	2020-07-12 06:02:29	2020-07-12	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	25022	delivery	5	57
94848	2020-07-12 06:02:40	2020-07-12	9	[{"id_menu":7,"count":1}]	3868	delivery	5	14
94849	2020-07-12 06:04:22	2020-07-12	9	[{"id_menu":7,"count":1}]	22363	delivery	5	14
94850	2020-07-12 06:05:34	2020-07-12	12	[{"id_menu":3,"count":1}]	5780	pick-up	0	12
94851	2020-07-12 06:08:58	2020-07-12	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	13969	delivery	5	31
94852	2020-07-12 06:10:22	2020-07-12	9	[{"id_menu":7,"count":1}]	10826	delivery	5	14
94853	2020-07-12 06:15:40	2020-07-12	14	[{"id_menu":2,"count":1}]	19052	pick-up	0	14
94854	2020-07-12 06:17:48	2020-07-12	17	[{"id_menu":4,"count":1}]	36815	delivery	5	22
94855	2020-07-12 06:17:51	2020-07-12	9	[{"id_menu":7,"count":1}]	25063	delivery	5	14
94856	2020-07-12 06:18:23	2020-07-12	9	[{"id_menu":6,"count":1}]	36832	delivery	5	14
94857	2020-07-12 06:19:53	2020-07-12	9	[{"id_menu":6,"count":1}]	8363	delivery	5	14
94858	2020-07-12 06:21:46	2020-07-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	36888	delivery	5	22
94859	2020-07-12 06:24:25	2020-07-12	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	11600	delivery	5	26
94860	2020-07-12 06:24:30	2020-07-12	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36772	delivery	5	49
94861	2020-07-12 06:25:58	2020-07-12	14	[{"id_menu":2,"count":1}]	36914	pick-up	0	14
94862	2020-07-12 06:26:52	2020-07-12	12	[{"id_menu":3,"count":1}]	36944	pick-up	0	12
94863	2020-07-12 06:27:48	2020-07-12	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	18069	delivery	5	26
94864	2020-07-12 06:29:11	2020-07-12	8	[{"id_menu":5,"count":1}]	36833	pick-up	0	8
94865	2020-07-12 06:29:56	2020-07-12	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13497	delivery	5	34
94866	2020-07-12 06:30:46	2020-07-12	12	[{"id_menu":1,"count":1}]	15643	delivery	5	17
94867	2020-07-12 06:32:41	2020-07-12	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	17558	delivery	5	28
94868	2020-07-12 06:33:59	2020-07-12	14	[{"id_menu":2,"count":1}]	14451	delivery	5	19
94869	2020-07-12 06:38:41	2020-07-12	17	[{"id_menu":4,"count":1}]	36790	delivery	5	22
94870	2020-07-12 06:40:38	2020-07-12	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	13841	pick-up	0	31
94871	2020-07-12 06:43:08	2020-07-12	14	[{"id_menu":2,"count":1}]	420	pick-up	0	14
94872	2020-07-12 06:44:15	2020-07-12	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	36804	delivery	5	26
94873	2020-07-12 06:44:24	2020-07-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	1117	delivery	5	31
94874	2020-07-12 06:45:07	2020-07-12	9	[{"id_menu":6,"count":1}]	28288	delivery	5	14
94875	2020-07-12 06:46:18	2020-07-12	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	36924	pick-up	0	24
94876	2020-07-12 06:53:28	2020-07-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	10886	delivery	5	28
94877	2020-07-12 06:55:14	2020-07-12	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	20553	delivery	5	28
94878	2020-07-12 06:55:54	2020-07-12	9	[{"id_menu":7,"count":1}]	45	delivery	5	14
94879	2020-07-12 06:56:34	2020-07-12	9	[{"id_menu":6,"count":1}]	3126	delivery	5	14
94880	2020-07-12 07:00:27	2020-07-12	12	[{"id_menu":1,"count":1}]	36831	pick-up	0	12
94881	2020-07-12 07:04:54	2020-07-12	12	[{"id_menu":3,"count":1}]	23624	delivery	5	17
94882	2020-07-12 07:07:05	2020-07-12	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	27519	delivery	5	28
94883	2020-07-12 07:09:30	2020-07-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	26961	delivery	5	22
94884	2020-07-12 07:11:40	2020-07-12	14	[{"id_menu":2,"count":1}]	25956	delivery	5	19
94885	2020-07-12 07:12:38	2020-07-12	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	22546	delivery	5	29
94886	2020-07-12 07:12:44	2020-07-12	9	[{"id_menu":7,"count":1}]	11716	delivery	5	14
94887	2020-07-12 07:13:19	2020-07-12	12	[{"id_menu":3,"count":1}]	26889	delivery	5	17
94888	2020-07-12 07:13:25	2020-07-12	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	32274	delivery	5	26
94889	2020-07-12 07:13:50	2020-07-12	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	33126	delivery	5	26
94890	2020-07-12 07:15:24	2020-07-12	9	[{"id_menu":7,"count":1}]	10194	pick-up	0	9
94891	2020-07-12 07:15:34	2020-07-12	12	[{"id_menu":1,"count":1}]	1847	delivery	5	17
94892	2020-07-12 07:18:29	2020-07-12	9	[{"id_menu":7,"count":1}]	36766	delivery	5	14
94893	2020-07-12 07:19:06	2020-07-12	14	[{"id_menu":2,"count":1}]	12830	delivery	5	19
94894	2020-07-12 07:20:22	2020-07-12	9	[{"id_menu":6,"count":1}]	35141	delivery	5	14
94895	2020-07-12 07:22:01	2020-07-12	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14873	delivery	5	39
94896	2020-07-12 07:23:38	2020-07-12	8	[{"id_menu":5,"count":1}]	2015	pick-up	0	8
94897	2020-07-12 07:28:20	2020-07-12	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	25291	delivery	5	40
94898	2020-07-12 07:28:45	2020-07-12	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	21872	delivery	5	43
94899	2020-07-12 07:37:03	2020-07-12	9	[{"id_menu":7,"count":1}]	28827	delivery	5	14
94900	2020-07-12 07:37:40	2020-07-12	12	[{"id_menu":3,"count":1}]	20909	delivery	5	17
94901	2020-07-12 07:40:55	2020-07-12	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	36976	delivery	5	22
94902	2020-07-12 07:41:47	2020-07-12	14	[{"id_menu":2,"count":1}]	31963	pick-up	0	14
94903	2020-07-12 07:44:54	2020-07-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2301	pick-up	0	23
94904	2020-07-12 07:49:37	2020-07-12	17	[{"id_menu":4,"count":1}]	16679	delivery	5	22
94905	2020-07-12 07:49:58	2020-07-12	12	[{"id_menu":1,"count":1}]	36889	delivery	5	17
94906	2020-07-12 07:50:35	2020-07-12	12	[{"id_menu":1,"count":1}]	32264	delivery	5	17
94907	2020-07-12 07:52:11	2020-07-12	12	[{"id_menu":1,"count":1}]	2217	pick-up	0	12
94908	2020-07-12 07:53:34	2020-07-12	12	[{"id_menu":3,"count":1}]	9040	pick-up	0	12
94909	2020-07-12 07:54:00	2020-07-12	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	18778	delivery	5	34
94910	2020-07-12 07:54:37	2020-07-12	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	5758	delivery	5	28
94911	2020-07-12 08:04:02	2020-07-12	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8943	delivery	5	39
94912	2020-07-12 08:09:48	2020-07-12	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	36966	pick-up	0	22
94913	2020-07-12 08:10:17	2020-07-12	9	[{"id_menu":7,"count":1}]	8035	delivery	5	14
94914	2020-07-12 08:14:52	2020-07-12	12	[{"id_menu":1,"count":1}]	13275	pick-up	0	12
94915	2020-07-12 08:15:26	2020-07-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	22985	pick-up	0	17
94916	2020-07-12 08:15:36	2020-07-12	9	[{"id_menu":7,"count":2}]	36858	delivery	5	14
94917	2020-07-12 08:17:28	2020-07-12	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9902	delivery	5	36
94918	2020-07-12 08:19:16	2020-07-12	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	8509	delivery	5	27
94919	2020-07-12 08:22:08	2020-07-12	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8742	delivery	5	28
94920	2020-07-12 08:22:39	2020-07-12	17	[{"id_menu":4,"count":1}]	36776	delivery	5	22
94921	2020-07-12 08:28:17	2020-07-12	9	[{"id_menu":6,"count":1}]	19629	delivery	5	14
94922	2020-07-12 08:31:09	2020-07-12	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36940	delivery	5	47
94923	2020-07-12 08:31:55	2020-07-12	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	36870	delivery	5	28
94924	2020-07-12 08:35:18	2020-07-12	9	[{"id_menu":7,"count":1}]	29603	delivery	5	14
94925	2020-07-12 08:48:54	2020-07-12	12	[{"id_menu":3,"count":1}]	36896	delivery	5	17
94926	2020-07-12 08:50:42	2020-07-12	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10608	delivery	5	57
94927	2020-07-12 08:56:30	2020-07-12	14	[{"id_menu":2,"count":1}]	204	pick-up	0	14
94928	2020-07-12 08:56:40	2020-07-12	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	19190	delivery	5	34
94929	2020-07-12 09:03:25	2020-07-12	17	[{"id_menu":4,"count":1}]	6406	delivery	5	22
94930	2020-07-12 09:04:38	2020-07-12	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	32050	delivery	5	22
94931	2020-07-12 09:08:46	2020-07-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	29542	delivery	5	22
94932	2020-07-12 09:08:48	2020-07-12	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	27618	delivery	5	38
94933	2020-07-12 09:09:32	2020-07-12	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	16960	delivery	5	27
94934	2020-07-12 09:09:48	2020-07-12	8	[{"id_menu":5,"count":1}]	3548	delivery	5	13
94935	2020-07-12 09:12:25	2020-07-12	12	[{"id_menu":3,"count":1}]	4089	pick-up	0	12
94936	2020-07-12 09:12:54	2020-07-12	12	[{"id_menu":1,"count":1}]	546	delivery	5	17
94937	2020-07-12 09:17:07	2020-07-12	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	36805	delivery	5	40
94938	2020-07-12 09:17:22	2020-07-12	12	[{"id_menu":3,"count":2}]	27305	delivery	5	17
94939	2020-07-12 09:18:09	2020-07-12	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	12769	delivery	5	38
94940	2020-07-12 09:19:40	2020-07-12	14	[{"id_menu":2,"count":1}]	66	pick-up	0	14
94941	2020-07-12 09:21:04	2020-07-12	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	10260	delivery	5	39
94942	2020-07-12 09:22:58	2020-07-12	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	36274	delivery	5	26
94943	2020-07-12 09:23:20	2020-07-12	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":2}]	15291	delivery	5	30
94944	2020-07-12 09:24:26	2020-07-12	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	36811	delivery	5	28
94945	2020-07-12 09:25:53	2020-07-12	8	[{"id_menu":5,"count":1}]	35343	delivery	5	13
94946	2020-07-12 09:28:08	2020-07-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	36830	delivery	5	22
94947	2020-07-12 09:30:10	2020-07-12	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	19698	delivery	5	40
94948	2020-07-12 09:32:09	2020-07-12	9	[{"id_menu":6,"count":1}]	22641	delivery	5	14
94949	2020-07-12 09:33:47	2020-07-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	36788	delivery	5	28
94950	2020-07-12 09:38:34	2020-07-12	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	17245	delivery	5	27
94951	2020-07-12 09:40:33	2020-07-12	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26086	delivery	5	35
94952	2020-07-12 09:41:47	2020-07-12	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	36793	delivery	5	28
94953	2020-07-12 09:43:29	2020-07-12	12	[{"id_menu":1,"count":2}]	23427	delivery	5	17
94954	2020-07-12 09:43:39	2020-07-12	9	[{"id_menu":6,"count":1}]	36942	delivery	5	14
94955	2020-07-12 09:44:56	2020-07-12	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	8578	delivery	5	38
94956	2020-07-12 09:52:19	2020-07-12	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	22017	delivery	5	34
94957	2020-07-12 09:53:25	2020-07-12	9	[{"id_menu":7,"count":1}]	16774	delivery	5	14
94958	2020-07-12 09:54:19	2020-07-12	14	[{"id_menu":2,"count":1}]	36965	delivery	5	19
94959	2020-07-12 09:54:24	2020-07-12	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36912	delivery	5	45
94960	2020-07-12 09:55:21	2020-07-12	17	[{"id_menu":4,"count":1}]	32343	pick-up	0	17
94961	2020-07-12 09:56:14	2020-07-12	14	[{"id_menu":2,"count":1}]	4935	delivery	5	19
94962	2020-07-12 09:56:55	2020-07-12	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4268	pick-up	0	52
94963	2020-07-12 09:57:38	2020-07-12	9	[{"id_menu":7,"count":1}]	36787	pick-up	0	9
94964	2020-07-12 09:58:38	2020-07-12	9	[{"id_menu":7,"count":2}]	5055	delivery	5	14
94965	2020-07-12 10:01:23	2020-07-12	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10066	delivery	5	45
94966	2020-07-12 10:01:48	2020-07-12	12	[{"id_menu":3,"count":1}]	36850	pick-up	0	12
94967	2020-07-12 10:03:02	2020-07-12	8	[{"id_menu":5,"count":1}]	10389	pick-up	0	8
94968	2020-07-12 10:03:49	2020-07-12	12	[{"id_menu":1,"count":1}]	26930	pick-up	0	12
94969	2020-07-12 10:03:57	2020-07-12	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	10093	delivery	5	26
94970	2020-07-12 10:05:24	2020-07-12	9	[{"id_menu":6,"count":1}]	36797	delivery	5	14
94971	2020-07-12 10:05:48	2020-07-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19830	delivery	5	23
94972	2020-07-12 10:06:34	2020-07-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	14403	delivery	5	28
94973	2020-07-12 10:06:43	2020-07-12	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	7807	delivery	5	26
94974	2020-07-12 10:06:56	2020-07-12	14	[{"id_menu":2,"count":1}]	36938	pick-up	0	14
94975	2020-07-12 10:08:16	2020-07-12	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	14423	delivery	5	42
94976	2020-07-12 10:09:07	2020-07-12	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	5440	pick-up	0	21
94977	2020-07-12 10:10:38	2020-07-12	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	21382	delivery	5	22
94978	2020-07-12 10:16:02	2020-07-12	17	[{"id_menu":4,"count":1}]	23109	delivery	5	22
94979	2020-07-12 10:18:15	2020-07-12	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	29202	delivery	5	30
94980	2020-07-12 10:18:44	2020-07-12	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	30674	delivery	5	22
94981	2020-07-12 10:19:16	2020-07-12	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	11268	delivery	5	40
94982	2020-07-12 10:19:24	2020-07-12	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31343	delivery	5	34
94983	2020-07-12 10:20:05	2020-07-12	17	[{"id_menu":4,"count":1}]	33989	delivery	5	22
94984	2020-07-12 10:20:48	2020-07-12	9	[{"id_menu":6,"count":1}]	36767	delivery	5	14
94985	2020-07-12 10:21:23	2020-07-12	9	[{"id_menu":7,"count":1}]	4943	pick-up	0	9
94986	2020-07-12 10:22:50	2020-07-12	12	[{"id_menu":3,"count":1}]	9704	delivery	5	17
94987	2020-07-12 10:24:00	2020-07-12	9	[{"id_menu":6,"count":1}]	16779	delivery	5	14
94988	2020-07-12 10:24:53	2020-07-12	17	[{"id_menu":4,"count":3}]	9012	delivery	5	22
94989	2020-07-12 10:25:49	2020-07-12	12	[{"id_menu":1,"count":1}]	29359	pick-up	0	12
94990	2020-07-12 10:26:08	2020-07-12	12	[{"id_menu":1,"count":1}]	36883	delivery	5	17
94991	2020-07-12 10:27:37	2020-07-12	9	[{"id_menu":7,"count":1}]	29554	delivery	5	14
94992	2020-07-12 10:28:15	2020-07-12	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	11252	delivery	5	31
94993	2020-07-12 10:32:40	2020-07-12	14	[{"id_menu":2,"count":1}]	36794	pick-up	0	14
94994	2020-07-12 10:35:18	2020-07-12	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	26613	delivery	5	26
94995	2020-07-12 10:35:35	2020-07-12	21	[{"id_menu":3,"count":3},{"id_menu":7,"count":1}]	2424	delivery	5	26
94996	2020-07-12 10:36:20	2020-07-12	17	[{"id_menu":4,"count":1}]	36829	delivery	5	22
94997	2020-07-12 10:38:55	2020-07-12	14	[{"id_menu":2,"count":1}]	4493	delivery	5	19
94998	2020-07-12 10:40:26	2020-07-12	9	[{"id_menu":6,"count":1}]	12378	delivery	5	14
94999	2020-07-12 10:47:36	2020-07-12	17	[{"id_menu":4,"count":1}]	27846	delivery	5	22
95000	2020-07-12 10:50:10	2020-07-12	12	[{"id_menu":1,"count":1}]	15594	delivery	5	17
95001	2020-07-12 10:51:02	2020-07-12	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	23704	delivery	5	30
95002	2020-07-12 10:51:28	2020-07-12	9	[{"id_menu":6,"count":1}]	30987	pick-up	0	9
95003	2020-07-12 10:58:27	2020-07-12	12	[{"id_menu":1,"count":1}]	36902	delivery	5	17
95004	2020-07-12 10:58:49	2020-07-12	12	[{"id_menu":3,"count":1}]	36749	delivery	5	17
95005	2020-07-12 10:58:58	2020-07-12	8	[{"id_menu":5,"count":1}]	36812	delivery	5	13
95006	2020-07-12 11:05:19	2020-07-12	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36350	delivery	5	54
95007	2020-07-12 11:05:49	2020-07-12	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8695	delivery	5	45
95008	2020-07-12 11:06:29	2020-07-12	9	[{"id_menu":7,"count":1}]	6068	delivery	5	14
95009	2020-07-12 11:07:00	2020-07-12	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	10655	delivery	5	39
95010	2020-07-12 11:07:44	2020-07-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	6905	delivery	5	23
95011	2020-07-12 11:11:00	2020-07-12	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14238	delivery	5	22
95012	2020-07-12 11:13:32	2020-07-12	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24651	delivery	5	22
95013	2020-07-12 11:18:03	2020-07-12	9	[{"id_menu":7,"count":1}]	18945	delivery	5	14
95014	2020-07-12 11:18:20	2020-07-12	14	[{"id_menu":2,"count":1}]	396	pick-up	0	14
95015	2020-07-12 11:19:28	2020-07-12	9	[{"id_menu":6,"count":1}]	17324	delivery	5	14
95016	2020-07-12 11:20:37	2020-07-12	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3334	delivery	5	28
95017	2020-07-12 11:23:32	2020-07-12	9	[{"id_menu":7,"count":1}]	27522	delivery	5	14
95018	2020-07-12 11:30:20	2020-07-12	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	20593	delivery	5	26
95019	2020-07-12 11:30:28	2020-07-12	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29075	delivery	5	34
95020	2020-07-12 11:31:03	2020-07-12	9	[{"id_menu":7,"count":1}]	36840	delivery	5	14
95021	2020-07-12 11:31:21	2020-07-12	8	[{"id_menu":5,"count":1}]	36846	delivery	5	13
95022	2020-07-12 11:40:26	2020-07-12	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	36950	delivery	5	34
95023	2020-07-12 11:41:08	2020-07-12	9	[{"id_menu":6,"count":1}]	15326	pick-up	0	9
95024	2020-07-12 11:43:10	2020-07-12	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	34482	delivery	5	31
95025	2020-07-12 11:43:53	2020-07-12	12	[{"id_menu":1,"count":1}]	36892	pick-up	0	12
95026	2020-07-12 11:44:55	2020-07-12	14	[{"id_menu":2,"count":1}]	5110	delivery	5	19
95027	2020-07-12 11:45:57	2020-07-12	9	[{"id_menu":7,"count":1}]	32799	delivery	5	14
95028	2020-07-12 11:46:12	2020-07-12	9	[{"id_menu":6,"count":1}]	34488	pick-up	0	9
95029	2020-07-12 11:46:13	2020-07-12	17	[{"id_menu":4,"count":1}]	36864	delivery	5	22
95030	2020-07-12 11:46:34	2020-07-12	14	[{"id_menu":2,"count":1}]	36913	delivery	5	19
95031	2020-07-12 11:46:45	2020-07-12	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	16967	pick-up	0	25
95032	2020-07-12 11:47:06	2020-07-12	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36951	delivery	5	35
95033	2020-07-12 11:47:30	2020-07-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	29990	delivery	5	22
95034	2020-07-12 11:48:19	2020-07-12	9	[{"id_menu":6,"count":2}]	36887	delivery	5	14
95035	2020-07-12 11:50:34	2020-07-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10235	delivery	5	31
95036	2020-07-12 11:50:38	2020-07-12	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	8208	pick-up	0	26
95037	2020-07-12 11:52:55	2020-07-12	9	[{"id_menu":7,"count":2}]	16193	delivery	5	14
95038	2020-07-12 11:58:47	2020-07-12	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	35064	pick-up	0	26
95039	2020-07-12 11:59:21	2020-07-12	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24308	delivery	5	31
95040	2020-07-12 12:01:22	2020-07-12	9	[{"id_menu":7,"count":1}]	18897	delivery	5	14
95041	2020-07-12 12:02:15	2020-07-12	14	[{"id_menu":2,"count":1}]	32792	delivery	5	19
95042	2020-07-12 12:03:13	2020-07-12	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13584	delivery	5	43
95043	2020-07-12 12:11:31	2020-07-12	9	[{"id_menu":6,"count":1}]	36762	pick-up	0	9
95044	2020-07-12 12:12:42	2020-07-12	12	[{"id_menu":1,"count":1}]	21145	delivery	5	17
95045	2020-07-12 12:13:27	2020-07-12	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15641	delivery	5	40
95046	2020-07-12 12:22:44	2020-07-12	9	[{"id_menu":6,"count":1}]	12452	delivery	5	14
95047	2020-07-12 12:23:33	2020-07-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16870	delivery	5	23
95048	2020-07-12 12:23:50	2020-07-12	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	35812	pick-up	0	20
95049	2020-07-12 12:24:37	2020-07-12	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	3602	delivery	5	31
95050	2020-07-12 12:25:26	2020-07-12	9	[{"id_menu":7,"count":1}]	5112	delivery	5	14
95051	2020-07-12 12:26:47	2020-07-12	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	15249	delivery	5	27
95052	2020-07-12 12:27:53	2020-07-12	12	[{"id_menu":1,"count":1}]	6785	delivery	5	17
95053	2020-07-12 12:31:18	2020-07-12	9	[{"id_menu":6,"count":1}]	32947	delivery	5	14
95054	2020-07-12 12:31:58	2020-07-12	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17764	pick-up	0	38
95055	2020-07-12 12:32:56	2020-07-12	17	[{"id_menu":4,"count":1}]	31243	delivery	5	22
95056	2020-07-12 12:35:17	2020-07-12	12	[{"id_menu":1,"count":1}]	13851	pick-up	0	12
95057	2020-07-12 12:36:05	2020-07-12	9	[{"id_menu":6,"count":1}]	36860	delivery	5	14
95058	2020-07-12 12:37:43	2020-07-12	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	36904	delivery	5	51
95059	2020-07-12 12:41:01	2020-07-12	12	[{"id_menu":3,"count":1}]	6876	delivery	5	17
95060	2020-07-12 12:44:47	2020-07-12	8	[{"id_menu":5,"count":1}]	14795	delivery	5	13
95061	2020-07-12 12:45:04	2020-07-12	8	[{"id_menu":5,"count":1}]	4546	pick-up	0	8
95062	2020-07-12 12:47:24	2020-07-12	12	[{"id_menu":3,"count":1}]	21536	delivery	5	17
95063	2020-07-12 12:49:05	2020-07-12	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	18348	delivery	5	25
95064	2020-07-12 12:54:56	2020-07-12	17	[{"id_menu":4,"count":1}]	36874	pick-up	0	17
95065	2020-07-12 12:55:52	2020-07-12	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	25938	delivery	5	26
95066	2020-07-12 12:56:26	2020-07-12	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3852	pick-up	0	21
95067	2020-07-12 12:57:08	2020-07-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7084	delivery	5	22
95068	2020-07-12 12:57:29	2020-07-12	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	36769	delivery	5	31
95069	2020-07-12 12:59:46	2020-07-12	8	[{"id_menu":5,"count":1}]	14326	delivery	5	13
95070	2020-07-12 13:02:24	2020-07-12	8	[{"id_menu":5,"count":1}]	122	pick-up	0	8
95071	2020-07-12 13:05:21	2020-07-12	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	24744	delivery	5	25
95072	2020-07-12 13:08:55	2020-07-12	9	[{"id_menu":6,"count":1}]	27841	delivery	5	14
95073	2020-07-12 13:10:20	2020-07-12	17	[{"id_menu":4,"count":1}]	8966	pick-up	0	17
95074	2020-07-12 13:12:57	2020-07-12	9	[{"id_menu":6,"count":1}]	36910	pick-up	0	9
95075	2020-07-12 13:15:03	2020-07-12	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	4351	delivery	5	29
95076	2020-07-12 13:15:36	2020-07-12	17	[{"id_menu":4,"count":1}]	2190	pick-up	0	17
95077	2020-07-12 13:15:41	2020-07-12	12	[{"id_menu":3,"count":1}]	36816	delivery	5	17
95078	2020-07-12 13:17:49	2020-07-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	36923	delivery	5	23
95079	2020-07-12 13:17:52	2020-07-12	12	[{"id_menu":1,"count":1}]	11724	pick-up	0	12
95080	2020-07-12 13:18:23	2020-07-12	17	[{"id_menu":4,"count":1}]	4075	pick-up	0	17
95081	2020-07-12 13:18:43	2020-07-12	17	[{"id_menu":4,"count":1}]	36931	delivery	5	22
95082	2020-07-12 13:19:39	2020-07-12	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	20215	pick-up	0	21
95083	2020-07-12 13:21:01	2020-07-12	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	26909	delivery	5	28
95084	2020-07-12 13:21:31	2020-07-12	9	[{"id_menu":7,"count":1}]	14395	delivery	5	14
95085	2020-07-12 13:21:58	2020-07-12	9	[{"id_menu":6,"count":1}]	8870	delivery	5	14
95086	2020-07-12 13:24:14	2020-07-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2124	pick-up	0	18
95087	2020-07-12 13:24:16	2020-07-12	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22270	delivery	5	22
95088	2020-07-12 13:26:32	2020-07-12	12	[{"id_menu":3,"count":1}]	19634	delivery	5	17
95089	2020-07-12 13:29:39	2020-07-12	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	36971	delivery	5	26
95090	2020-07-12 13:30:10	2020-07-12	9	[{"id_menu":7,"count":1}]	20659	delivery	5	14
95091	2020-07-12 13:30:53	2020-07-12	12	[{"id_menu":1,"count":1}]	32167	pick-up	0	12
95092	2020-07-12 13:32:05	2020-07-12	12	[{"id_menu":1,"count":1}]	788	pick-up	0	12
95093	2020-07-12 13:34:12	2020-07-12	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	14903	delivery	5	30
95094	2020-07-12 13:34:15	2020-07-12	12	[{"id_menu":1,"count":2}]	20327	pick-up	0	12
95095	2020-07-12 13:36:03	2020-07-12	9	[{"id_menu":7,"count":1}]	36863	delivery	5	14
95096	2020-07-12 13:40:52	2020-07-12	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	12530	delivery	5	22
95097	2020-07-12 13:44:31	2020-07-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21257	delivery	5	22
95098	2020-07-12 13:47:07	2020-07-12	9	[{"id_menu":6,"count":2}]	6286	delivery	5	14
95099	2020-07-12 13:49:31	2020-07-12	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	13989	delivery	5	26
95100	2020-07-12 13:51:12	2020-07-12	17	[{"id_menu":4,"count":1}]	36801	delivery	5	22
95101	2020-07-12 13:51:20	2020-07-12	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	20762	delivery	5	31
95102	2020-07-12 13:58:13	2020-07-12	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	36926	pick-up	0	24
95103	2020-07-12 13:58:20	2020-07-12	9	[{"id_menu":7,"count":1}]	32277	delivery	5	14
95104	2020-07-12 13:59:44	2020-07-12	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	10337	delivery	5	42
95105	2020-07-12 14:00:30	2020-07-12	9	[{"id_menu":6,"count":1}]	36893	pick-up	0	9
95106	2020-07-12 14:01:22	2020-07-12	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	3480	pick-up	0	24
95107	2020-07-12 14:06:03	2020-07-12	12	[{"id_menu":1,"count":1}]	10399	delivery	5	17
95108	2020-07-12 14:06:21	2020-07-12	17	[{"id_menu":4,"count":1}]	11260	pick-up	0	17
95109	2020-07-12 14:07:38	2020-07-12	12	[{"id_menu":3,"count":1}]	30769	delivery	5	17
95110	2020-07-12 14:07:46	2020-07-12	9	[{"id_menu":6,"count":1}]	34491	delivery	5	14
95111	2020-07-12 14:10:14	2020-07-12	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	25736	delivery	5	39
95112	2020-07-12 14:11:38	2020-07-12	12	[{"id_menu":1,"count":1}]	36920	delivery	5	17
95113	2020-07-12 14:11:47	2020-07-12	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2150	pick-up	0	29
95114	2020-07-12 14:11:59	2020-07-12	8	[{"id_menu":5,"count":1}]	7050	delivery	5	13
95115	2020-07-12 14:16:28	2020-07-12	9	[{"id_menu":6,"count":2}]	11507	delivery	5	14
95116	2020-07-12 14:19:19	2020-07-12	9	[{"id_menu":7,"count":1}]	36891	delivery	5	14
95117	2020-07-12 14:21:40	2020-07-12	9	[{"id_menu":7,"count":1}]	23426	delivery	5	14
95118	2020-07-12 14:21:50	2020-07-12	9	[{"id_menu":7,"count":1}]	35272	delivery	5	14
95119	2020-07-12 14:21:55	2020-07-12	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	17804	delivery	5	26
95120	2020-07-12 14:22:08	2020-07-12	14	[{"id_menu":2,"count":1}]	15598	delivery	5	19
95121	2020-07-12 14:25:40	2020-07-12	12	[{"id_menu":1,"count":1}]	4480	delivery	5	17
95122	2020-07-12 14:28:22	2020-07-12	9	[{"id_menu":6,"count":1}]	581	delivery	5	14
95123	2020-07-12 14:29:32	2020-07-12	12	[{"id_menu":3,"count":1}]	36835	delivery	5	17
95124	2020-07-12 14:30:16	2020-07-12	9	[{"id_menu":7,"count":1}]	36851	delivery	5	14
95125	2020-07-12 14:35:45	2020-07-12	8	[{"id_menu":5,"count":1}]	11634	pick-up	0	8
95126	2020-07-12 14:37:41	2020-07-12	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	26935	delivery	5	48
95127	2020-07-12 14:37:50	2020-07-12	12	[{"id_menu":1,"count":1}]	17837	delivery	5	17
95128	2020-07-12 14:38:29	2020-07-12	12	[{"id_menu":3,"count":1}]	10828	pick-up	0	12
95129	2020-07-12 14:39:37	2020-07-12	17	[{"id_menu":4,"count":1}]	18770	delivery	5	22
95130	2020-07-12 14:40:39	2020-07-12	14	[{"id_menu":2,"count":2}]	36779	delivery	5	19
95131	2020-07-12 14:43:06	2020-07-12	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	6491	delivery	5	26
95132	2020-07-12 14:43:08	2020-07-12	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	16330	pick-up	0	20
95133	2020-07-12 14:45:36	2020-07-12	9	[{"id_menu":7,"count":1}]	12132	delivery	5	14
95134	2020-07-12 14:48:45	2020-07-12	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	36869	delivery	5	26
95135	2020-07-12 14:51:25	2020-07-12	8	[{"id_menu":5,"count":1}]	36900	delivery	5	13
95136	2020-07-12 14:52:15	2020-07-12	12	[{"id_menu":1,"count":1}]	7571	pick-up	0	12
95137	2020-07-12 14:53:28	2020-07-12	9	[{"id_menu":6,"count":2}]	8305	delivery	5	14
95138	2020-07-12 14:55:43	2020-07-12	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	20800	delivery	5	57
95139	2020-07-12 14:59:06	2020-07-12	8	[{"id_menu":5,"count":1}]	23668	delivery	5	13
95140	2020-07-12 14:59:18	2020-07-12	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	21256	delivery	5	43
95141	2020-07-12 15:00:59	2020-07-12	9	[{"id_menu":7,"count":1}]	64	pick-up	0	9
95142	2020-07-12 15:03:14	2020-07-12	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":3}]	36782	delivery	5	34
95143	2020-07-12 15:04:03	2020-07-12	9	[{"id_menu":6,"count":2}]	26962	delivery	5	14
95144	2020-07-12 15:06:38	2020-07-12	12	[{"id_menu":1,"count":1}]	10875	pick-up	0	12
95145	2020-07-12 15:07:00	2020-07-12	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1322	delivery	5	36
95146	2020-07-12 15:08:34	2020-07-12	9	[{"id_menu":6,"count":1}]	11957	delivery	5	14
95147	2020-07-12 15:10:46	2020-07-12	8	[{"id_menu":5,"count":1}]	10870	pick-up	0	8
95148	2020-07-12 15:11:32	2020-07-12	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4301	delivery	5	37
95149	2020-07-12 15:13:57	2020-07-12	12	[{"id_menu":1,"count":1}]	30852	delivery	5	17
95150	2020-07-12 15:14:35	2020-07-12	8	[{"id_menu":5,"count":1}]	36885	pick-up	0	8
95151	2020-07-12 15:18:45	2020-07-12	14	[{"id_menu":2,"count":1}]	36898	delivery	5	19
95152	2020-07-12 15:19:30	2020-07-12	14	[{"id_menu":2,"count":1}]	949	delivery	5	19
95153	2020-07-12 15:19:52	2020-07-12	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	36949	delivery	5	22
95154	2020-07-12 15:22:23	2020-07-12	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29713	delivery	5	48
95155	2020-07-12 15:24:49	2020-07-12	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33794	pick-up	0	49
95156	2020-07-12 15:24:58	2020-07-12	9	[{"id_menu":6,"count":1}]	8082	delivery	5	14
95157	2020-07-12 15:27:03	2020-07-12	17	[{"id_menu":4,"count":1}]	11497	delivery	5	22
95158	2020-07-12 15:27:55	2020-07-12	9	[{"id_menu":7,"count":1}]	2051	delivery	5	14
95159	2020-07-12 15:28:08	2020-07-12	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	30629	delivery	5	25
95160	2020-07-12 15:29:54	2020-07-12	14	[{"id_menu":2,"count":1}]	34845	delivery	5	19
95161	2020-07-12 15:30:12	2020-07-12	12	[{"id_menu":1,"count":1}]	1021	pick-up	0	12
95162	2020-07-12 15:31:31	2020-07-12	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2837	delivery	5	27
95163	2020-07-12 15:32:32	2020-07-12	9	[{"id_menu":6,"count":1}]	36927	delivery	5	14
95164	2020-07-12 15:35:29	2020-07-12	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	36952	delivery	5	26
95165	2020-07-12 15:35:41	2020-07-12	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4673	pick-up	0	21
95166	2020-07-12 15:38:50	2020-07-12	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	8842	delivery	5	26
95167	2020-07-12 15:40:47	2020-07-12	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	36881	pick-up	0	22
95168	2020-07-12 15:43:11	2020-07-12	9	[{"id_menu":7,"count":1}]	27765	delivery	5	14
95169	2020-07-12 15:43:58	2020-07-12	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36876	delivery	5	35
95170	2020-07-12 15:45:31	2020-07-12	17	[{"id_menu":4,"count":1}]	26110	delivery	5	22
95171	2020-07-12 15:47:11	2020-07-12	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15377	delivery	5	36
95172	2020-07-12 15:53:13	2020-07-12	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	28601	delivery	5	45
95173	2020-07-12 15:55:18	2020-07-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	36901	delivery	5	22
95174	2020-07-12 15:56:44	2020-07-12	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	8530	pick-up	0	21
95175	2020-07-12 15:57:04	2020-07-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":3}]	36954	delivery	5	28
95176	2020-07-12 15:59:13	2020-07-12	9	[{"id_menu":7,"count":1}]	26823	delivery	5	14
95177	2020-07-12 16:01:22	2020-07-12	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	36886	delivery	5	38
95178	2020-07-12 16:01:50	2020-07-12	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	36773	delivery	5	36
95179	2020-07-12 16:02:30	2020-07-12	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	10796	delivery	5	26
95180	2020-07-12 16:02:44	2020-07-12	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29017	delivery	5	40
95181	2020-07-12 16:03:06	2020-07-12	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	20740	delivery	5	34
95182	2020-07-12 16:04:55	2020-07-12	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	36946	delivery	5	26
95183	2020-07-12 16:07:19	2020-07-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	36911	delivery	5	31
95184	2020-07-12 16:16:33	2020-07-12	12	[{"id_menu":1,"count":1}]	36970	delivery	5	17
95185	2020-07-12 16:18:07	2020-07-12	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	36761	delivery	5	34
95186	2020-07-12 16:18:54	2020-07-12	9	[{"id_menu":7,"count":1}]	213	delivery	5	14
95187	2020-07-12 16:19:29	2020-07-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	36800	delivery	5	28
95188	2020-07-12 16:20:16	2020-07-12	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	13769	delivery	5	23
95189	2020-07-12 16:22:45	2020-07-12	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	36956	delivery	5	40
95190	2020-07-12 16:25:19	2020-07-12	9	[{"id_menu":7,"count":1}]	18873	delivery	5	14
95191	2020-07-12 16:25:39	2020-07-12	14	[{"id_menu":2,"count":1}]	2758	delivery	5	19
95192	2020-07-12 16:26:11	2020-07-12	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	7946	delivery	5	26
95193	2020-07-12 16:30:17	2020-07-12	17	[{"id_menu":4,"count":1}]	2453	delivery	5	22
95194	2020-07-12 16:30:32	2020-07-12	17	[{"id_menu":4,"count":2}]	22180	pick-up	0	17
95195	2020-07-12 16:32:37	2020-07-12	17	[{"id_menu":4,"count":1}]	18940	delivery	5	22
95196	2020-07-12 16:32:47	2020-07-12	12	[{"id_menu":1,"count":1}]	36967	delivery	5	17
95197	2020-07-12 16:34:33	2020-07-12	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	13669	pick-up	0	35
95198	2020-07-12 16:35:19	2020-07-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	36825	delivery	5	23
95199	2020-07-12 16:37:01	2020-07-12	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5565	delivery	5	40
95200	2020-07-12 16:37:47	2020-07-12	12	[{"id_menu":3,"count":1}]	36906	delivery	5	17
95201	2020-07-12 16:41:45	2020-07-12	9	[{"id_menu":7,"count":1}]	25003	delivery	5	14
95202	2020-07-12 16:43:21	2020-07-12	14	[{"id_menu":2,"count":1}]	36933	delivery	5	19
95203	2020-07-12 16:45:50	2020-07-12	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	5640	delivery	5	43
95204	2020-07-12 16:46:18	2020-07-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	11399	delivery	5	28
95205	2020-07-12 16:46:20	2020-07-12	12	[{"id_menu":1,"count":2}]	18602	pick-up	0	12
95206	2020-07-12 16:46:51	2020-07-12	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	30665	delivery	5	31
95207	2020-07-12 16:47:15	2020-07-12	12	[{"id_menu":1,"count":1}]	36922	delivery	5	17
95208	2020-07-12 16:48:20	2020-07-12	14	[{"id_menu":2,"count":1}]	33538	delivery	5	19
95209	2020-07-12 16:49:47	2020-07-12	12	[{"id_menu":1,"count":1}]	23782	pick-up	0	12
95210	2020-07-12 16:50:19	2020-07-12	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	20905	delivery	5	29
95211	2020-07-12 16:51:56	2020-07-12	9	[{"id_menu":6,"count":1}]	36807	delivery	5	14
95212	2020-07-12 16:54:29	2020-07-12	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5506	pick-up	0	37
95213	2020-07-12 16:57:46	2020-07-12	9	[{"id_menu":6,"count":1}]	36925	delivery	5	14
95214	2020-07-12 16:59:36	2020-07-12	38	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3996	delivery	5	43
95215	2020-07-12 17:03:42	2020-07-12	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4606	delivery	5	34
95216	2020-07-12 17:06:26	2020-07-12	17	[{"id_menu":4,"count":1}]	36205	delivery	5	22
95217	2020-07-12 17:11:04	2020-07-12	17	[{"id_menu":4,"count":1}]	32583	pick-up	0	17
95218	2020-07-12 17:12:26	2020-07-12	12	[{"id_menu":1,"count":1}]	36905	delivery	5	17
95219	2020-07-12 17:15:34	2020-07-12	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	30508	delivery	5	34
95220	2020-07-12 17:16:24	2020-07-12	12	[{"id_menu":3,"count":1}]	36877	delivery	5	17
95221	2020-07-12 17:17:56	2020-07-12	12	[{"id_menu":1,"count":1}]	34907	pick-up	0	12
95222	2020-07-12 17:20:10	2020-07-12	12	[{"id_menu":1,"count":1}]	4139	pick-up	0	12
95223	2020-07-12 17:21:52	2020-07-12	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	22268	delivery	5	25
95224	2020-07-12 17:22:00	2020-07-12	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	32328	delivery	5	28
95225	2020-07-12 17:27:07	2020-07-12	9	[{"id_menu":6,"count":1}]	9995	pick-up	0	9
95226	2020-07-12 17:29:28	2020-07-12	8	[{"id_menu":5,"count":1}]	12827	delivery	5	13
95227	2020-07-12 17:30:12	2020-07-12	9	[{"id_menu":7,"count":1}]	27924	delivery	5	14
95228	2020-07-12 17:33:02	2020-07-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	36765	delivery	5	31
95229	2020-07-12 17:38:15	2020-07-12	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	11309	delivery	5	36
95230	2020-07-12 17:42:34	2020-07-12	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	36852	pick-up	0	31
95231	2020-07-12 17:42:57	2020-07-12	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	36955	delivery	5	26
95232	2020-07-12 17:43:40	2020-07-12	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	36848	delivery	5	26
95233	2020-07-12 17:46:04	2020-07-12	9	[{"id_menu":6,"count":1}]	30233	pick-up	0	9
95234	2020-07-12 17:46:06	2020-07-12	9	[{"id_menu":7,"count":1}]	36961	delivery	5	14
95235	2020-07-12 17:48:38	2020-07-12	8	[{"id_menu":5,"count":1}]	24513	delivery	5	13
95236	2020-07-12 17:49:58	2020-07-12	14	[{"id_menu":2,"count":1}]	36796	delivery	5	19
95237	2020-07-12 17:51:01	2020-07-12	9	[{"id_menu":6,"count":1}]	36111	delivery	5	14
95238	2020-07-12 17:53:34	2020-07-12	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	27473	delivery	5	43
95239	2020-07-12 17:53:53	2020-07-12	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	26392	delivery	5	22
95240	2020-07-12 17:55:33	2020-07-12	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24847	delivery	5	39
95241	2020-07-12 17:56:37	2020-07-12	17	[{"id_menu":4,"count":1}]	5019	pick-up	0	17
95242	2020-07-12 17:57:11	2020-07-12	12	[{"id_menu":1,"count":1}]	22214	delivery	5	17
95243	2020-07-12 17:57:42	2020-07-12	9	[{"id_menu":6,"count":1}]	35249	delivery	5	14
95244	2020-07-12 18:00:05	2020-07-12	9	[{"id_menu":7,"count":1}]	888	delivery	5	14
95245	2020-07-12 18:01:58	2020-07-12	12	[{"id_menu":3,"count":1}]	24690	delivery	5	17
95246	2020-07-12 18:03:03	2020-07-12	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	36808	delivery	5	45
95247	2020-07-12 18:05:16	2020-07-12	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36813	delivery	5	31
95248	2020-07-12 18:05:17	2020-07-12	14	[{"id_menu":2,"count":1}]	23561	pick-up	0	14
95249	2020-07-12 18:06:12	2020-07-12	14	[{"id_menu":2,"count":1}]	36928	delivery	5	19
95250	2020-07-12 18:08:28	2020-07-12	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29470	delivery	5	40
95251	2020-07-12 18:11:43	2020-07-12	12	[{"id_menu":1,"count":1}]	12254	pick-up	0	12
95252	2020-07-12 18:14:48	2020-07-12	17	[{"id_menu":4,"count":1}]	29157	delivery	5	22
95253	2020-07-12 18:15:11	2020-07-12	12	[{"id_menu":1,"count":1}]	612	pick-up	0	12
95254	2020-07-12 18:17:28	2020-07-12	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7227	delivery	5	35
95255	2020-07-12 18:17:57	2020-07-12	12	[{"id_menu":1,"count":1}]	10441	pick-up	0	12
95256	2020-07-12 18:20:18	2020-07-12	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	5297	delivery	5	39
95257	2020-07-12 18:20:43	2020-07-12	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21520	delivery	5	37
95258	2020-07-12 18:21:42	2020-07-12	14	[{"id_menu":2,"count":1}]	2082	delivery	5	19
95259	2020-07-12 18:22:36	2020-07-12	9	[{"id_menu":7,"count":3}]	36781	delivery	5	14
95260	2020-07-12 18:24:07	2020-07-12	12	[{"id_menu":3,"count":1}]	1223	pick-up	0	12
95261	2020-07-12 18:25:47	2020-07-12	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	36897	delivery	5	31
95262	2020-07-12 18:29:49	2020-07-12	8	[{"id_menu":5,"count":1}]	36930	delivery	5	13
95263	2020-07-12 18:29:53	2020-07-12	9	[{"id_menu":6,"count":1}]	623	pick-up	0	9
95264	2020-07-12 18:35:11	2020-07-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17372	delivery	5	31
95265	2020-07-12 18:40:01	2020-07-12	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36853	delivery	5	31
95266	2020-07-12 18:40:23	2020-07-12	8	[{"id_menu":5,"count":1}]	15752	pick-up	0	8
95267	2020-07-12 18:41:54	2020-07-12	8	[{"id_menu":5,"count":1}]	34873	delivery	5	13
95268	2020-07-12 18:42:10	2020-07-12	14	[{"id_menu":2,"count":1}]	30093	pick-up	0	14
95269	2020-07-12 18:42:23	2020-07-12	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	36849	delivery	5	45
95270	2020-07-12 18:43:12	2020-07-12	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	36909	delivery	5	25
95271	2020-07-12 18:44:06	2020-07-12	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	21215	delivery	5	34
95272	2020-07-12 18:44:07	2020-07-12	9	[{"id_menu":7,"count":1}]	36856	delivery	5	14
95273	2020-07-12 18:46:22	2020-07-12	12	[{"id_menu":3,"count":1}]	23230	delivery	5	17
95274	2020-07-12 18:46:59	2020-07-12	17	[{"id_menu":4,"count":1}]	47	pick-up	0	17
95275	2020-07-12 18:47:49	2020-07-12	9	[{"id_menu":7,"count":2}]	27332	pick-up	0	9
95276	2020-07-12 18:51:09	2020-07-12	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	17118	delivery	5	27
95277	2020-07-12 18:52:31	2020-07-12	9	[{"id_menu":6,"count":3}]	31069	delivery	5	14
95278	2020-07-12 18:55:40	2020-07-12	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	36817	delivery	5	56
95279	2020-07-12 19:02:22	2020-07-12	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	30808	delivery	5	26
95280	2020-07-12 19:03:09	2020-07-12	8	[{"id_menu":5,"count":1}]	36875	delivery	5	13
95281	2020-07-12 19:04:59	2020-07-12	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	12453	delivery	5	40
95282	2020-07-12 19:05:06	2020-07-12	12	[{"id_menu":1,"count":1}]	3848	delivery	5	17
95283	2020-07-12 19:05:25	2020-07-12	9	[{"id_menu":7,"count":1}]	2590	delivery	5	14
95284	2020-07-12 19:05:44	2020-07-12	8	[{"id_menu":5,"count":2}]	76	delivery	5	13
95285	2020-07-12 19:05:46	2020-07-12	9	[{"id_menu":7,"count":1}]	2780	delivery	5	14
95286	2020-07-12 19:06:23	2020-07-12	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29613	delivery	5	36
95287	2020-07-12 19:06:52	2020-07-12	12	[{"id_menu":1,"count":1}]	36973	delivery	5	17
95288	2020-07-12 19:08:18	2020-07-12	14	[{"id_menu":2,"count":1}]	28212	delivery	5	19
95289	2020-07-12 19:08:46	2020-07-12	9	[{"id_menu":6,"count":1}]	36783	delivery	5	14
95290	2020-07-12 19:09:48	2020-07-12	8	[{"id_menu":5,"count":1}]	36798	pick-up	0	8
95291	2020-07-12 19:10:05	2020-07-12	9	[{"id_menu":6,"count":1}]	14495	delivery	5	14
95292	2020-07-12 19:10:27	2020-07-12	9	[{"id_menu":6,"count":1}]	6164	delivery	5	14
95293	2020-07-12 19:11:22	2020-07-12	8	[{"id_menu":5,"count":1}]	33427	delivery	5	13
95294	2020-07-12 19:16:39	2020-07-12	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	36847	delivery	5	36
95295	2020-07-12 19:18:50	2020-07-12	9	[{"id_menu":7,"count":1}]	3085	pick-up	0	9
95296	2020-07-12 19:18:52	2020-07-12	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	36972	delivery	5	25
95297	2020-07-12 19:26:31	2020-07-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	22197	delivery	5	28
95298	2020-07-12 19:26:50	2020-07-12	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	32244	delivery	5	28
95299	2020-07-12 19:29:53	2020-07-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15585	delivery	5	22
95300	2020-07-12 19:32:37	2020-07-12	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	33775	delivery	5	31
95301	2020-07-12 19:33:26	2020-07-12	9	[{"id_menu":6,"count":1}]	14696	delivery	5	14
95302	2020-07-12 19:42:10	2020-07-12	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	4007	delivery	5	26
95303	2020-07-12 19:42:20	2020-07-12	9	[{"id_menu":7,"count":1}]	2641	pick-up	0	9
95304	2020-07-12 19:42:54	2020-07-12	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	11270	delivery	5	22
95305	2020-07-12 19:43:18	2020-07-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	26272	delivery	5	28
95306	2020-07-12 19:46:35	2020-07-12	9	[{"id_menu":6,"count":1}]	36814	delivery	5	14
95307	2020-07-12 19:52:18	2020-07-12	17	[{"id_menu":4,"count":1}]	7814	delivery	5	22
95308	2020-07-12 19:54:08	2020-07-12	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	8655	delivery	5	34
95309	2020-07-12 19:56:05	2020-07-12	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	12724	delivery	5	28
95310	2020-07-12 19:56:22	2020-07-12	9	[{"id_menu":6,"count":1}]	36867	delivery	5	14
95311	2020-07-12 19:56:42	2020-07-12	14	[{"id_menu":2,"count":1}]	18927	delivery	5	19
95312	2020-07-12 19:58:03	2020-07-12	9	[{"id_menu":6,"count":1}]	9733	delivery	5	14
95313	2020-07-12 19:59:59	2020-07-12	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	36818	delivery	5	45
95314	2020-07-12 20:00:33	2020-07-12	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14909	delivery	5	34
95315	2020-07-12 20:00:45	2020-07-12	12	[{"id_menu":1,"count":1}]	33719	pick-up	0	12
95316	2020-07-12 20:00:47	2020-07-12	9	[{"id_menu":6,"count":1}]	22456	delivery	5	14
95317	2020-07-12 20:01:17	2020-07-12	14	[{"id_menu":2,"count":1}]	16461	delivery	5	19
95318	2020-07-12 20:01:39	2020-07-12	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	856	delivery	5	28
95319	2020-07-12 20:05:39	2020-07-12	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	22346	delivery	5	34
95320	2020-07-12 20:06:59	2020-07-12	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	36890	delivery	5	39
95321	2020-07-12 20:07:17	2020-07-12	12	[{"id_menu":1,"count":1}]	36764	delivery	5	17
95322	2020-07-12 20:07:44	2020-07-12	14	[{"id_menu":2,"count":1}]	36786	delivery	5	19
95323	2020-07-12 20:08:59	2020-07-12	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36759	delivery	5	48
95324	2020-07-12 20:12:12	2020-07-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	18747	delivery	5	28
95325	2020-07-12 20:13:35	2020-07-12	9	[{"id_menu":6,"count":1}]	2654	pick-up	0	9
95326	2020-07-12 20:14:01	2020-07-12	9	[{"id_menu":7,"count":1}]	3227	pick-up	0	9
95327	2020-07-12 20:20:51	2020-07-12	9	[{"id_menu":7,"count":1}]	7070	delivery	5	14
95328	2020-07-12 20:21:28	2020-07-12	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	8626	delivery	5	26
95329	2020-07-12 20:21:50	2020-07-12	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	24383	delivery	5	36
95330	2020-07-12 20:22:16	2020-07-12	9	[{"id_menu":7,"count":1}]	28357	pick-up	0	9
95331	2020-07-12 20:22:43	2020-07-12	14	[{"id_menu":2,"count":1}]	399	delivery	5	19
95332	2020-07-12 20:25:05	2020-07-12	17	[{"id_menu":4,"count":1}]	10264	pick-up	0	17
95333	2020-07-12 20:25:59	2020-07-12	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	36821	delivery	5	40
95334	2020-07-12 20:28:08	2020-07-12	17	[{"id_menu":4,"count":1}]	2106	delivery	5	22
95335	2020-07-12 20:28:33	2020-07-12	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	20805	pick-up	0	21
95336	2020-07-12 20:29:03	2020-07-12	14	[{"id_menu":2,"count":1}]	36827	delivery	5	19
95337	2020-07-12 20:32:43	2020-07-12	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	36842	delivery	5	35
95338	2020-07-12 20:33:51	2020-07-12	14	[{"id_menu":2,"count":1}]	36974	delivery	5	19
95339	2020-07-12 20:34:04	2020-07-12	9	[{"id_menu":7,"count":1}]	22086	delivery	5	14
95340	2020-07-12 20:36:10	2020-07-12	12	[{"id_menu":1,"count":1}]	172	delivery	5	17
95341	2020-07-12 20:37:06	2020-07-12	17	[{"id_menu":4,"count":1}]	24943	pick-up	0	17
95342	2020-07-12 20:38:46	2020-07-12	9	[{"id_menu":6,"count":1}]	7399	delivery	5	14
95343	2020-07-12 20:39:17	2020-07-12	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	36726	delivery	5	30
95344	2020-07-12 20:47:57	2020-07-12	17	[{"id_menu":4,"count":1}]	19771	delivery	5	22
95345	2020-07-12 20:48:04	2020-07-12	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	36962	delivery	5	27
95346	2020-07-12 20:48:40	2020-07-12	14	[{"id_menu":2,"count":1}]	36768	delivery	5	19
95347	2020-07-12 20:48:44	2020-07-12	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16785	delivery	5	35
95348	2020-07-12 20:51:27	2020-07-12	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	5701	delivery	5	31
95349	2020-07-12 20:54:09	2020-07-12	9	[{"id_menu":7,"count":2}]	29769	delivery	5	14
95350	2020-07-12 20:54:10	2020-07-12	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	21923	delivery	5	45
95351	2020-07-12 20:55:03	2020-07-12	9	[{"id_menu":6,"count":1}]	5445	delivery	5	14
95352	2020-07-12 20:55:17	2020-07-12	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	3631	delivery	5	34
95353	2020-07-12 20:58:32	2020-07-12	17	[{"id_menu":4,"count":1}]	17555	delivery	5	22
95354	2020-07-12 20:58:53	2020-07-12	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4592	delivery	5	46
95355	2020-07-12 20:59:28	2020-07-12	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	30534	delivery	5	31
95356	2020-07-12 20:59:36	2020-07-12	14	[{"id_menu":2,"count":1}]	8232	pick-up	0	14
95357	2020-07-12 21:01:58	2020-07-12	12	[{"id_menu":1,"count":1}]	1934	pick-up	0	12
95358	2020-07-12 21:04:13	2020-07-12	12	[{"id_menu":3,"count":1}]	36855	delivery	5	17
95359	2020-07-12 21:06:40	2020-07-12	17	[{"id_menu":4,"count":1}]	26534	delivery	5	22
95360	2020-07-12 21:08:08	2020-07-12	9	[{"id_menu":7,"count":1}]	3145	delivery	5	14
95361	2020-07-12 21:17:34	2020-07-12	9	[{"id_menu":6,"count":1}]	36760	pick-up	0	9
95362	2020-07-12 21:18:27	2020-07-12	8	[{"id_menu":5,"count":1}]	36822	delivery	5	13
95363	2020-07-12 21:21:49	2020-07-12	9	[{"id_menu":6,"count":1}]	7128	pick-up	0	9
95364	2020-07-12 21:22:16	2020-07-12	9	[{"id_menu":7,"count":1}]	7065	delivery	5	14
95365	2020-07-12 21:25:38	2020-07-12	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	20841	delivery	5	34
95366	2020-07-12 21:25:42	2020-07-12	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	35023	delivery	5	44
95367	2020-07-12 21:26:02	2020-07-12	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36838	delivery	5	40
95368	2020-07-12 21:26:47	2020-07-12	12	[{"id_menu":1,"count":1}]	1379	pick-up	0	12
95369	2020-07-12 21:27:55	2020-07-12	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36778	delivery	5	31
95370	2020-07-12 21:30:01	2020-07-12	17	[{"id_menu":4,"count":1}]	12242	delivery	5	22
95371	2020-07-12 21:30:10	2020-07-12	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	8726	delivery	5	26
95372	2020-07-12 21:30:10	2020-07-12	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26292	delivery	5	35
95373	2020-07-12 21:43:20	2020-07-12	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	10422	delivery	5	30
95374	2020-07-12 21:45:25	2020-07-12	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23986	delivery	5	22
95375	2020-07-12 21:48:08	2020-07-12	8	[{"id_menu":5,"count":1}]	34199	delivery	5	13
95376	2020-07-12 21:51:08	2020-07-12	9	[{"id_menu":7,"count":2}]	4170	delivery	5	14
95377	2020-07-12 21:56:05	2020-07-12	9	[{"id_menu":7,"count":1}]	17242	delivery	5	14
95378	2020-07-12 21:57:12	2020-07-12	9	[{"id_menu":7,"count":1}]	36880	delivery	5	14
95379	2020-07-12 21:57:45	2020-07-12	9	[{"id_menu":6,"count":1}]	8094	delivery	5	14
95380	2020-07-12 21:59:04	2020-07-12	12	[{"id_menu":3,"count":1}]	25994	delivery	5	17
95381	2020-07-12 22:00:05	2020-07-12	8	[{"id_menu":5,"count":1}]	16518	delivery	5	13
95382	2020-07-12 22:01:32	2020-07-12	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17489	delivery	5	31
95383	2020-07-12 22:08:11	2020-07-12	9	[{"id_menu":7,"count":1}]	9977	delivery	5	14
95384	2020-07-12 22:08:34	2020-07-12	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	9054	delivery	5	26
95385	2020-07-12 22:08:37	2020-07-12	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	30783	delivery	5	26
95386	2020-07-12 22:11:07	2020-07-12	8	[{"id_menu":5,"count":1}]	26932	delivery	5	13
95387	2020-07-12 22:11:27	2020-07-12	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	21413	delivery	5	25
95388	2020-07-12 22:11:40	2020-07-12	12	[{"id_menu":3,"count":1}]	36873	delivery	5	17
95389	2020-07-12 22:15:13	2020-07-12	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	36820	delivery	5	34
95390	2020-07-12 22:16:36	2020-07-12	12	[{"id_menu":1,"count":1}]	3669	pick-up	0	12
95391	2020-07-12 22:19:08	2020-07-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33683	delivery	5	23
95392	2020-07-12 22:21:25	2020-07-12	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	36792	delivery	5	38
95393	2020-07-12 22:26:40	2020-07-12	8	[{"id_menu":5,"count":1}]	30442	delivery	5	13
95394	2020-07-12 22:27:56	2020-07-12	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	36836	delivery	5	36
95395	2020-07-12 22:28:53	2020-07-12	12	[{"id_menu":3,"count":1}]	8150	pick-up	0	12
95396	2020-07-12 22:29:08	2020-07-12	9	[{"id_menu":7,"count":1}]	666	pick-up	0	9
95397	2020-07-12 22:30:33	2020-07-12	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34406	delivery	5	40
95398	2020-07-12 22:32:50	2020-07-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	22564	delivery	5	28
95399	2020-07-12 22:35:36	2020-07-12	12	[{"id_menu":1,"count":1}]	18900	delivery	5	17
95400	2020-07-12 22:36:18	2020-07-12	12	[{"id_menu":1,"count":1}]	36916	delivery	5	17
95401	2020-07-12 22:38:29	2020-07-12	12	[{"id_menu":1,"count":1}]	33511	delivery	5	17
95402	2020-07-12 22:39:27	2020-07-12	17	[{"id_menu":4,"count":1}]	36763	delivery	5	22
95403	2020-07-12 22:40:34	2020-07-12	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	30256	pick-up	0	29
95404	2020-07-12 22:40:49	2020-07-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	22485	delivery	5	28
95405	2020-07-12 22:41:29	2020-07-12	9	[{"id_menu":6,"count":1}]	30790	delivery	5	14
95406	2020-07-12 22:44:27	2020-07-12	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	36872	pick-up	0	21
95407	2020-07-12 22:47:28	2020-07-12	9	[{"id_menu":7,"count":1}]	2995	delivery	5	14
95408	2020-07-12 22:48:03	2020-07-12	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	36953	pick-up	0	31
95409	2020-07-12 22:50:03	2020-07-12	9	[{"id_menu":6,"count":1}]	36795	delivery	5	14
95410	2020-07-12 22:53:39	2020-07-12	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	32885	pick-up	0	31
95411	2020-07-12 22:55:01	2020-07-12	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	19380	delivery	5	48
95412	2020-07-12 22:55:20	2020-07-12	9	[{"id_menu":7,"count":1}]	2425	pick-up	0	9
95413	2020-07-12 22:57:03	2020-07-12	9	[{"id_menu":7,"count":1}]	18058	delivery	5	14
95414	2020-07-12 22:57:53	2020-07-12	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	36957	pick-up	0	22
95415	2020-07-12 22:58:13	2020-07-12	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	26116	delivery	5	30
95416	2020-07-12 22:59:27	2020-07-12	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10145	delivery	5	31
95417	2020-07-12 23:02:23	2020-07-12	55	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	29569	delivery	5	60
95418	2020-07-12 23:02:33	2020-07-12	8	[{"id_menu":5,"count":1}]	17780	delivery	5	13
95419	2020-07-12 23:03:37	2020-07-12	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	36802	delivery	5	22
95420	2020-07-12 23:05:35	2020-07-12	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	3636	delivery	5	26
95421	2020-07-12 23:07:17	2020-07-12	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	36964	delivery	5	48
95422	2020-07-12 23:08:13	2020-07-12	12	[{"id_menu":1,"count":1}]	23260	delivery	5	17
95423	2020-07-12 23:09:17	2020-07-12	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	36826	delivery	5	28
95424	2020-07-12 23:14:41	2020-07-12	17	[{"id_menu":4,"count":1}]	36771	delivery	5	22
95425	2020-07-12 23:16:33	2020-07-12	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	9893	delivery	5	34
95426	2020-07-12 23:16:49	2020-07-12	8	[{"id_menu":5,"count":1}]	36845	delivery	5	13
95427	2020-07-12 23:17:06	2020-07-12	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	28728	delivery	5	28
95428	2020-07-12 23:19:58	2020-07-12	9	[{"id_menu":7,"count":2}]	36915	delivery	5	14
95429	2020-07-12 23:22:06	2020-07-12	8	[{"id_menu":5,"count":1}]	8126	delivery	5	13
95430	2020-07-12 23:23:02	2020-07-12	8	[{"id_menu":5,"count":1}]	10636	delivery	5	13
95431	2020-07-12 23:23:03	2020-07-12	14	[{"id_menu":2,"count":1}]	5303	pick-up	0	14
95432	2020-07-12 23:24:43	2020-07-12	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16825	pick-up	0	46
95433	2020-07-12 23:29:06	2020-07-12	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	36059	delivery	5	23
95434	2020-07-12 23:30:57	2020-07-12	12	[{"id_menu":1,"count":1}]	25015	pick-up	0	12
95435	2020-07-12 23:33:09	2020-07-12	8	[{"id_menu":5,"count":1}]	36553	delivery	5	13
95436	2020-07-12 23:35:55	2020-07-12	14	[{"id_menu":2,"count":1}]	1168	delivery	5	19
95437	2020-07-12 23:36:46	2020-07-12	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	22126	delivery	5	39
95438	2020-07-12 23:36:58	2020-07-12	17	[{"id_menu":4,"count":1}]	10544	delivery	5	22
95439	2020-07-12 23:38:13	2020-07-12	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	26974	pick-up	0	21
95440	2020-07-12 23:42:17	2020-07-12	12	[{"id_menu":1,"count":1}]	5099	pick-up	0	12
95441	2020-07-12 23:46:32	2020-07-12	8	[{"id_menu":5,"count":1}]	33251	pick-up	0	8
95442	2020-07-12 23:49:59	2020-07-12	9	[{"id_menu":6,"count":1}]	13070	delivery	5	14
95443	2020-07-12 23:53:30	2020-07-12	9	[{"id_menu":7,"count":1}]	1427	pick-up	0	9
95444	2020-07-12 23:54:44	2020-07-12	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	36894	delivery	5	23
95445	2020-07-12 23:55:32	2020-07-12	8	[{"id_menu":5,"count":1}]	10420	delivery	5	13
95446	2020-07-12 23:57:23	2020-07-12	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	28362	delivery	5	26
95447	2020-07-13 00:03:40	2020-07-13	9	[{"id_menu":7,"count":1}]	31853	delivery	5	14
95448	2020-07-13 00:04:16	2020-07-13	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	21884	delivery	5	31
95449	2020-07-13 00:08:16	2020-07-13	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	37046	delivery	5	30
95450	2020-07-13 00:08:28	2020-07-13	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	17507	delivery	5	26
95451	2020-07-13 00:14:15	2020-07-13	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	477	pick-up	0	17
95452	2020-07-13 00:14:27	2020-07-13	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16831	delivery	5	36
95453	2020-07-13 00:19:42	2020-07-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	37125	delivery	5	36
95454	2020-07-13 00:22:23	2020-07-13	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2567	pick-up	0	29
95455	2020-07-13 00:24:00	2020-07-13	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	26468	delivery	5	51
95456	2020-07-13 00:29:27	2020-07-13	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9550	delivery	5	34
95457	2020-07-13 00:30:51	2020-07-13	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	37072	delivery	5	22
95458	2020-07-13 00:35:36	2020-07-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	24041	pick-up	0	31
95459	2020-07-13 00:35:59	2020-07-13	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	37115	delivery	5	30
95460	2020-07-13 00:37:32	2020-07-13	14	[{"id_menu":2,"count":1}]	16155	pick-up	0	14
95461	2020-07-13 00:38:16	2020-07-13	17	[{"id_menu":4,"count":1}]	32994	delivery	5	22
95462	2020-07-13 00:41:06	2020-07-13	17	[{"id_menu":4,"count":1}]	24044	delivery	5	22
95463	2020-07-13 00:44:05	2020-07-13	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	6767	delivery	5	44
95464	2020-07-13 00:52:01	2020-07-13	14	[{"id_menu":2,"count":1}]	37113	delivery	5	19
95465	2020-07-13 01:00:19	2020-07-13	12	[{"id_menu":1,"count":1}]	7582	pick-up	0	12
95466	2020-07-13 01:02:35	2020-07-13	17	[{"id_menu":4,"count":1}]	7435	pick-up	0	17
95467	2020-07-13 01:15:55	2020-07-13	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24842	delivery	5	22
95468	2020-07-13 01:17:43	2020-07-13	9	[{"id_menu":6,"count":1}]	36244	pick-up	0	9
95469	2020-07-13 01:18:42	2020-07-13	9	[{"id_menu":6,"count":1}]	37163	delivery	5	14
95470	2020-07-13 01:23:13	2020-07-13	9	[{"id_menu":6,"count":1}]	5886	delivery	5	14
95471	2020-07-13 01:31:34	2020-07-13	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24033	delivery	5	40
95472	2020-07-13 01:34:13	2020-07-13	9	[{"id_menu":6,"count":1}]	9603	pick-up	0	9
95473	2020-07-13 01:35:11	2020-07-13	17	[{"id_menu":4,"count":1}]	37051	delivery	5	22
95474	2020-07-13 01:37:44	2020-07-13	17	[{"id_menu":4,"count":1}]	33658	pick-up	0	17
95475	2020-07-13 01:42:56	2020-07-13	12	[{"id_menu":1,"count":1}]	6857	delivery	5	17
95476	2020-07-13 01:46:29	2020-07-13	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	37065	delivery	5	34
95477	2020-07-13 01:47:55	2020-07-13	14	[{"id_menu":2,"count":1}]	36980	pick-up	0	14
95478	2020-07-13 01:48:57	2020-07-13	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5279	pick-up	0	43
95479	2020-07-13 01:49:28	2020-07-13	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	37087	delivery	5	26
95480	2020-07-13 01:51:10	2020-07-13	17	[{"id_menu":4,"count":2}]	2633	pick-up	0	17
95481	2020-07-13 01:52:32	2020-07-13	9	[{"id_menu":7,"count":1}]	11289	pick-up	0	9
95482	2020-07-13 01:53:22	2020-07-13	9	[{"id_menu":6,"count":2}]	37068	delivery	5	14
95483	2020-07-13 01:54:33	2020-07-13	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	37048	delivery	5	39
95484	2020-07-13 02:00:40	2020-07-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37095	delivery	5	23
95485	2020-07-13 02:00:45	2020-07-13	14	[{"id_menu":2,"count":1}]	9308	delivery	5	19
95486	2020-07-13 02:00:55	2020-07-13	9	[{"id_menu":7,"count":1}]	37018	delivery	5	14
95487	2020-07-13 02:01:41	2020-07-13	9	[{"id_menu":7,"count":1}]	30867	delivery	5	14
95488	2020-07-13 02:03:22	2020-07-13	12	[{"id_menu":3,"count":1}]	2894	pick-up	0	12
95489	2020-07-13 02:06:13	2020-07-13	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	37052	delivery	5	34
95490	2020-07-13 02:10:23	2020-07-13	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	16522	delivery	5	22
95491	2020-07-13 02:25:14	2020-07-13	8	[{"id_menu":5,"count":1}]	31328	delivery	5	13
95492	2020-07-13 02:27:47	2020-07-13	9	[{"id_menu":7,"count":1}]	3931	delivery	5	14
95493	2020-07-13 02:31:48	2020-07-13	9	[{"id_menu":6,"count":1}]	15566	pick-up	0	9
95494	2020-07-13 02:32:05	2020-07-13	9	[{"id_menu":7,"count":2}]	30998	delivery	5	14
95495	2020-07-13 02:34:29	2020-07-13	9	[{"id_menu":7,"count":1}]	37122	delivery	5	14
95496	2020-07-13 02:39:39	2020-07-13	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	37130	pick-up	0	29
95497	2020-07-13 02:45:31	2020-07-13	9	[{"id_menu":6,"count":2}]	37159	delivery	5	14
95498	2020-07-13 02:46:19	2020-07-13	12	[{"id_menu":1,"count":1}]	7639	delivery	5	17
95499	2020-07-13 02:46:58	2020-07-13	14	[{"id_menu":2,"count":1}]	15127	delivery	5	19
95500	2020-07-13 02:47:28	2020-07-13	9	[{"id_menu":7,"count":1}]	21877	pick-up	0	9
95501	2020-07-13 02:47:59	2020-07-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	8640	pick-up	0	31
95502	2020-07-13 02:48:25	2020-07-13	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	12240	pick-up	0	21
95503	2020-07-13 03:01:36	2020-07-13	9	[{"id_menu":6,"count":1}]	31161	delivery	5	14
95504	2020-07-13 03:03:34	2020-07-13	8	[{"id_menu":5,"count":1}]	19218	pick-up	0	8
95505	2020-07-13 03:10:45	2020-07-13	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	18224	delivery	5	28
95506	2020-07-13 03:16:06	2020-07-13	12	[{"id_menu":1,"count":1}]	37091	delivery	5	17
95507	2020-07-13 03:16:24	2020-07-13	14	[{"id_menu":2,"count":1}]	4300	pick-up	0	14
95508	2020-07-13 03:17:02	2020-07-13	14	[{"id_menu":2,"count":1}]	7098	pick-up	0	14
95509	2020-07-13 03:20:41	2020-07-13	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	5180	pick-up	0	41
95510	2020-07-13 03:24:38	2020-07-13	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	37059	delivery	5	31
95511	2020-07-13 03:24:44	2020-07-13	8	[{"id_menu":5,"count":1}]	3889	delivery	5	13
95512	2020-07-13 03:30:00	2020-07-13	29	[{"id_menu":3,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32901	pick-up	0	29
95513	2020-07-13 03:32:38	2020-07-13	9	[{"id_menu":6,"count":1}]	37025	delivery	5	14
95514	2020-07-13 03:48:58	2020-07-13	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8904	pick-up	0	26
95515	2020-07-13 03:51:49	2020-07-13	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	22515	pick-up	0	21
95516	2020-07-13 03:51:50	2020-07-13	9	[{"id_menu":6,"count":1}]	21885	delivery	5	14
95517	2020-07-13 03:51:56	2020-07-13	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	23138	delivery	5	48
95518	2020-07-13 03:53:26	2020-07-13	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	27365	delivery	5	27
95519	2020-07-13 04:00:38	2020-07-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6221	pick-up	0	23
95520	2020-07-13 04:05:02	2020-07-13	12	[{"id_menu":1,"count":1}]	37024	delivery	5	17
95521	2020-07-13 04:05:19	2020-07-13	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21264	delivery	5	22
95522	2020-07-13 04:07:23	2020-07-13	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	28097	pick-up	0	26
95523	2020-07-13 04:08:23	2020-07-13	9	[{"id_menu":6,"count":1}]	10159	delivery	5	14
95524	2020-07-13 04:09:43	2020-07-13	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7293	delivery	5	47
95525	2020-07-13 04:20:25	2020-07-13	9	[{"id_menu":6,"count":1}]	20405	delivery	5	14
95526	2020-07-13 04:22:34	2020-07-13	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26523	delivery	5	37
95527	2020-07-13 04:23:13	2020-07-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6709	delivery	5	36
95528	2020-07-13 04:27:21	2020-07-13	9	[{"id_menu":7,"count":1}]	15814	delivery	5	14
95529	2020-07-13 04:34:08	2020-07-13	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	37126	delivery	5	45
95530	2020-07-13 04:35:20	2020-07-13	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	33472	delivery	5	34
95531	2020-07-13 04:36:00	2020-07-13	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	37092	pick-up	0	31
95532	2020-07-13 04:42:48	2020-07-13	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	37007	delivery	5	28
95533	2020-07-13 04:48:07	2020-07-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	37004	delivery	5	28
95534	2020-07-13 05:01:11	2020-07-13	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	22598	pick-up	0	26
95535	2020-07-13 05:02:44	2020-07-13	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	9793	delivery	5	31
95536	2020-07-13 05:03:34	2020-07-13	8	[{"id_menu":5,"count":1}]	29017	delivery	5	13
95537	2020-07-13 05:09:11	2020-07-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37172	delivery	5	23
95538	2020-07-13 05:25:45	2020-07-13	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1380	delivery	5	54
95539	2020-07-13 05:27:23	2020-07-13	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	15452	delivery	5	25
95540	2020-07-13 05:28:31	2020-07-13	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3040	delivery	5	38
95541	2020-07-13 05:28:34	2020-07-13	12	[{"id_menu":1,"count":1}]	37035	delivery	5	17
95542	2020-07-13 05:29:19	2020-07-13	9	[{"id_menu":6,"count":2}]	16489	delivery	5	14
95543	2020-07-13 05:30:46	2020-07-13	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7208	delivery	5	56
95544	2020-07-13 05:37:37	2020-07-13	9	[{"id_menu":7,"count":1}]	17388	delivery	5	14
95545	2020-07-13 05:46:20	2020-07-13	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	37023	delivery	5	57
95546	2020-07-13 05:47:41	2020-07-13	17	[{"id_menu":4,"count":1}]	32851	delivery	5	22
95547	2020-07-13 06:05:08	2020-07-13	14	[{"id_menu":2,"count":1}]	37099	pick-up	0	14
95548	2020-07-13 06:13:44	2020-07-13	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	26640	delivery	5	26
95549	2020-07-13 06:13:54	2020-07-13	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	32251	delivery	5	26
95550	2020-07-13 06:14:39	2020-07-13	14	[{"id_menu":2,"count":1}]	28796	delivery	5	19
95551	2020-07-13 06:14:42	2020-07-13	9	[{"id_menu":6,"count":1}]	37094	delivery	5	14
95552	2020-07-13 06:17:24	2020-07-13	17	[{"id_menu":4,"count":1}]	21795	pick-up	0	17
95553	2020-07-13 06:19:05	2020-07-13	9	[{"id_menu":6,"count":1}]	37033	delivery	5	14
95554	2020-07-13 06:26:31	2020-07-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	31065	delivery	5	28
95555	2020-07-13 06:28:07	2020-07-13	9	[{"id_menu":6,"count":1}]	10810	pick-up	0	9
95556	2020-07-13 06:33:25	2020-07-13	14	[{"id_menu":2,"count":2}]	36612	delivery	5	19
95557	2020-07-13 06:37:12	2020-07-13	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11260	pick-up	0	32
95558	2020-07-13 06:38:51	2020-07-13	8	[{"id_menu":5,"count":1}]	21765	delivery	5	13
95559	2020-07-13 06:43:37	2020-07-13	9	[{"id_menu":7,"count":1}]	24556	pick-up	0	9
95560	2020-07-13 06:51:24	2020-07-13	8	[{"id_menu":5,"count":1}]	35759	delivery	5	13
95561	2020-07-13 06:51:50	2020-07-13	14	[{"id_menu":2,"count":1}]	28168	delivery	5	19
95562	2020-07-13 06:56:35	2020-07-13	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	37156	delivery	5	34
95563	2020-07-13 07:00:19	2020-07-13	9	[{"id_menu":6,"count":1}]	36999	delivery	5	14
95564	2020-07-13 07:05:16	2020-07-13	12	[{"id_menu":3,"count":1}]	11401	delivery	5	17
95565	2020-07-13 07:09:24	2020-07-13	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25420	delivery	5	37
95566	2020-07-13 07:12:13	2020-07-13	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	36449	delivery	5	52
95567	2020-07-13 07:17:48	2020-07-13	14	[{"id_menu":2,"count":1}]	4960	delivery	5	19
95568	2020-07-13 07:29:57	2020-07-13	12	[{"id_menu":1,"count":1}]	20803	delivery	5	17
95569	2020-07-13 07:33:39	2020-07-13	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	17157	delivery	5	28
95570	2020-07-13 07:35:19	2020-07-13	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	35804	delivery	5	38
95571	2020-07-13 07:40:45	2020-07-13	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	32249	delivery	5	48
95572	2020-07-13 07:43:32	2020-07-13	12	[{"id_menu":3,"count":1}]	15039	delivery	5	17
95573	2020-07-13 07:44:45	2020-07-13	14	[{"id_menu":2,"count":1}]	37135	delivery	5	19
95574	2020-07-13 07:47:03	2020-07-13	8	[{"id_menu":5,"count":1}]	19889	delivery	5	13
95575	2020-07-13 07:56:25	2020-07-13	9	[{"id_menu":7,"count":1}]	4497	pick-up	0	9
95576	2020-07-13 07:58:18	2020-07-13	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	33662	delivery	5	55
95577	2020-07-13 08:03:08	2020-07-13	12	[{"id_menu":1,"count":1}]	14258	pick-up	0	12
95578	2020-07-13 08:11:59	2020-07-13	14	[{"id_menu":2,"count":1}]	269	delivery	5	19
95579	2020-07-13 08:14:22	2020-07-13	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	37147	delivery	5	36
95580	2020-07-13 08:20:00	2020-07-13	9	[{"id_menu":7,"count":1}]	37145	delivery	5	14
95581	2020-07-13 08:31:42	2020-07-13	14	[{"id_menu":2,"count":1}]	37064	delivery	5	19
95582	2020-07-13 08:36:03	2020-07-13	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12309	delivery	5	43
95583	2020-07-13 08:36:13	2020-07-13	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	37183	delivery	5	22
95584	2020-07-13 08:44:19	2020-07-13	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	34166	delivery	5	39
95585	2020-07-13 08:48:25	2020-07-13	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	23266	delivery	5	31
95586	2020-07-13 08:51:27	2020-07-13	9	[{"id_menu":7,"count":2}]	18187	delivery	5	14
95587	2020-07-13 08:58:25	2020-07-13	8	[{"id_menu":5,"count":1}]	37110	delivery	5	13
95588	2020-07-13 08:58:44	2020-07-13	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	30131	delivery	5	30
95589	2020-07-13 09:03:24	2020-07-13	8	[{"id_menu":5,"count":1}]	504	pick-up	0	8
95590	2020-07-13 09:11:53	2020-07-13	17	[{"id_menu":4,"count":1}]	12552	delivery	5	22
95591	2020-07-13 09:14:37	2020-07-13	17	[{"id_menu":4,"count":1}]	3211	delivery	5	22
95592	2020-07-13 09:16:14	2020-07-13	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10785	delivery	5	31
95593	2020-07-13 09:20:15	2020-07-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36991	delivery	5	23
95594	2020-07-13 09:28:14	2020-07-13	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	37129	delivery	5	39
95595	2020-07-13 09:32:25	2020-07-13	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	17732	delivery	5	26
95596	2020-07-13 09:32:37	2020-07-13	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32233	delivery	5	34
95597	2020-07-13 09:32:56	2020-07-13	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	27313	delivery	5	45
95598	2020-07-13 09:34:21	2020-07-13	9	[{"id_menu":6,"count":2}]	6046	delivery	5	14
95599	2020-07-13 09:35:11	2020-07-13	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13424	delivery	5	36
95600	2020-07-13 09:36:40	2020-07-13	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	316	delivery	5	43
95601	2020-07-13 09:40:15	2020-07-13	17	[{"id_menu":4,"count":1}]	3065	pick-up	0	17
95602	2020-07-13 09:41:20	2020-07-13	17	[{"id_menu":4,"count":1}]	37132	delivery	5	22
95603	2020-07-13 09:50:54	2020-07-13	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	37030	delivery	5	34
95604	2020-07-13 09:51:29	2020-07-13	17	[{"id_menu":4,"count":1}]	18051	delivery	5	22
95605	2020-07-13 09:53:56	2020-07-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	31917	delivery	5	36
95606	2020-07-13 09:58:28	2020-07-13	12	[{"id_menu":3,"count":1}]	36358	pick-up	0	12
95607	2020-07-13 10:11:12	2020-07-13	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	16843	pick-up	0	26
95608	2020-07-13 10:11:33	2020-07-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	17870	delivery	5	28
95609	2020-07-13 10:12:11	2020-07-13	9	[{"id_menu":7,"count":2}]	37143	delivery	5	14
95610	2020-07-13 10:12:35	2020-07-13	8	[{"id_menu":5,"count":1}]	22871	delivery	5	13
95611	2020-07-13 10:17:04	2020-07-13	9	[{"id_menu":7,"count":1}]	37154	delivery	5	14
95612	2020-07-13 10:17:34	2020-07-13	9	[{"id_menu":6,"count":1}]	3612	delivery	5	14
95613	2020-07-13 10:18:44	2020-07-13	8	[{"id_menu":5,"count":1}]	1261	delivery	5	13
95614	2020-07-13 10:23:16	2020-07-13	14	[{"id_menu":2,"count":1}]	376	pick-up	0	14
95615	2020-07-13 10:23:28	2020-07-13	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	37053	delivery	5	27
95616	2020-07-13 10:25:22	2020-07-13	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37047	delivery	5	43
95617	2020-07-13 10:25:41	2020-07-13	9	[{"id_menu":7,"count":1}]	36992	pick-up	0	9
95618	2020-07-13 10:27:44	2020-07-13	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	37062	delivery	5	46
95619	2020-07-13 10:30:20	2020-07-13	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	26700	delivery	5	23
95620	2020-07-13 10:34:47	2020-07-13	17	[{"id_menu":4,"count":1}]	95	delivery	5	22
95621	2020-07-13 10:38:23	2020-07-13	8	[{"id_menu":5,"count":1}]	8680	delivery	5	13
95622	2020-07-13 10:46:47	2020-07-13	9	[{"id_menu":6,"count":1}]	24358	delivery	5	14
95623	2020-07-13 10:54:44	2020-07-13	12	[{"id_menu":3,"count":1}]	37075	delivery	5	17
95624	2020-07-13 10:55:59	2020-07-13	14	[{"id_menu":2,"count":1}]	37118	delivery	5	19
95625	2020-07-13 10:56:47	2020-07-13	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	24343	delivery	5	22
95626	2020-07-13 11:09:08	2020-07-13	9	[{"id_menu":7,"count":1}]	31332	pick-up	0	9
95627	2020-07-13 11:13:11	2020-07-13	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	5238	pick-up	0	21
95628	2020-07-13 11:13:41	2020-07-13	14	[{"id_menu":2,"count":1}]	16295	pick-up	0	14
95629	2020-07-13 11:14:24	2020-07-13	12	[{"id_menu":1,"count":1}]	34282	delivery	5	17
95630	2020-07-13 11:18:56	2020-07-13	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	27524	delivery	5	22
95631	2020-07-13 11:33:31	2020-07-13	8	[{"id_menu":5,"count":1}]	6692	pick-up	0	8
95632	2020-07-13 11:37:48	2020-07-13	9	[{"id_menu":6,"count":1}]	25386	delivery	5	14
95633	2020-07-13 11:46:18	2020-07-13	9	[{"id_menu":7,"count":1}]	37175	pick-up	0	9
95634	2020-07-13 11:47:10	2020-07-13	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	35493	delivery	5	40
95635	2020-07-13 11:49:03	2020-07-13	17	[{"id_menu":4,"count":1}]	1035	pick-up	0	17
95636	2020-07-13 11:49:32	2020-07-13	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	203	delivery	5	38
95637	2020-07-13 11:54:29	2020-07-13	9	[{"id_menu":7,"count":1}]	17784	pick-up	0	9
95638	2020-07-13 11:57:00	2020-07-13	9	[{"id_menu":6,"count":1}]	25507	delivery	5	14
95639	2020-07-13 11:57:56	2020-07-13	12	[{"id_menu":1,"count":1}]	5733	delivery	5	17
95640	2020-07-13 12:00:12	2020-07-13	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	5125	pick-up	0	23
95641	2020-07-13 12:04:02	2020-07-13	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	36986	delivery	5	36
95642	2020-07-13 12:11:25	2020-07-13	8	[{"id_menu":5,"count":1}]	37050	delivery	5	13
95643	2020-07-13 12:12:50	2020-07-13	8	[{"id_menu":5,"count":1}]	29449	delivery	5	13
95644	2020-07-13 12:13:48	2020-07-13	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	37056	pick-up	0	40
95645	2020-07-13 12:19:48	2020-07-13	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32440	delivery	5	35
95646	2020-07-13 12:25:18	2020-07-13	12	[{"id_menu":3,"count":1}]	10185	pick-up	0	12
95647	2020-07-13 12:25:57	2020-07-13	12	[{"id_menu":3,"count":1}]	13667	delivery	5	17
95648	2020-07-13 12:27:04	2020-07-13	14	[{"id_menu":2,"count":1}]	37090	delivery	5	19
95649	2020-07-13 12:27:49	2020-07-13	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	5822	delivery	5	23
95650	2020-07-13 12:28:45	2020-07-13	14	[{"id_menu":2,"count":1}]	13465	delivery	5	19
95651	2020-07-13 12:32:59	2020-07-13	9	[{"id_menu":6,"count":1}]	20060	pick-up	0	9
95652	2020-07-13 12:37:25	2020-07-13	9	[{"id_menu":7,"count":1}]	33369	delivery	5	14
95653	2020-07-13 12:37:28	2020-07-13	17	[{"id_menu":4,"count":1}]	19501	delivery	5	22
95654	2020-07-13 12:41:00	2020-07-13	8	[{"id_menu":5,"count":1}]	2704	delivery	5	13
95655	2020-07-13 12:41:19	2020-07-13	12	[{"id_menu":3,"count":1}]	10175	delivery	5	17
95656	2020-07-13 12:44:34	2020-07-13	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	37054	delivery	5	39
95657	2020-07-13 12:48:13	2020-07-13	12	[{"id_menu":3,"count":1}]	8746	delivery	5	17
95658	2020-07-13 12:49:08	2020-07-13	17	[{"id_menu":4,"count":1}]	1457	delivery	5	22
95659	2020-07-13 12:49:55	2020-07-13	14	[{"id_menu":2,"count":1}]	7053	pick-up	0	14
95660	2020-07-13 13:11:47	2020-07-13	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	26983	delivery	5	34
95661	2020-07-13 13:13:39	2020-07-13	14	[{"id_menu":2,"count":1}]	34601	delivery	5	19
95662	2020-07-13 13:13:56	2020-07-13	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24580	delivery	5	40
95663	2020-07-13 13:20:15	2020-07-13	9	[{"id_menu":7,"count":1}]	37070	pick-up	0	9
95664	2020-07-13 13:27:38	2020-07-13	17	[{"id_menu":4,"count":1}]	18628	delivery	5	22
95665	2020-07-13 13:32:15	2020-07-13	17	[{"id_menu":4,"count":1}]	10209	pick-up	0	17
95666	2020-07-13 13:34:48	2020-07-13	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	31869	delivery	5	43
95667	2020-07-13 13:37:34	2020-07-13	9	[{"id_menu":6,"count":2}]	36424	pick-up	0	9
95668	2020-07-13 13:38:04	2020-07-13	9	[{"id_menu":6,"count":1}]	15603	delivery	5	14
95669	2020-07-13 13:38:14	2020-07-13	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15932	delivery	5	36
95670	2020-07-13 13:43:31	2020-07-13	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	6941	pick-up	0	26
95671	2020-07-13 13:43:48	2020-07-13	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	37108	delivery	5	27
95672	2020-07-13 13:45:01	2020-07-13	9	[{"id_menu":7,"count":1}]	36989	delivery	5	14
95673	2020-07-13 13:48:12	2020-07-13	12	[{"id_menu":1,"count":2}]	24465	delivery	5	17
95674	2020-07-13 13:51:24	2020-07-13	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	37055	delivery	5	30
95675	2020-07-13 13:51:59	2020-07-13	8	[{"id_menu":5,"count":1}]	36300	delivery	5	13
95676	2020-07-13 13:52:07	2020-07-13	8	[{"id_menu":5,"count":2}]	6331	delivery	5	13
95677	2020-07-13 13:52:54	2020-07-13	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	36995	delivery	5	22
95678	2020-07-13 13:54:15	2020-07-13	9	[{"id_menu":6,"count":1}]	19750	delivery	5	14
95679	2020-07-13 13:56:40	2020-07-13	14	[{"id_menu":2,"count":1}]	37142	pick-up	0	14
95680	2020-07-13 13:57:24	2020-07-13	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	6047	delivery	5	27
95681	2020-07-13 13:58:16	2020-07-13	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4382	pick-up	0	35
95682	2020-07-13 14:00:43	2020-07-13	9	[{"id_menu":6,"count":1}]	34279	delivery	5	14
95683	2020-07-13 14:11:53	2020-07-13	9	[{"id_menu":6,"count":2}]	36990	delivery	5	14
95684	2020-07-13 14:14:25	2020-07-13	9	[{"id_menu":6,"count":1}]	35197	delivery	5	14
95685	2020-07-13 14:15:14	2020-07-13	14	[{"id_menu":2,"count":1}]	8461	delivery	5	19
95686	2020-07-13 14:21:41	2020-07-13	12	[{"id_menu":1,"count":1}]	23422	delivery	5	17
95687	2020-07-13 14:26:39	2020-07-13	12	[{"id_menu":3,"count":1}]	20823	delivery	5	17
95688	2020-07-13 14:29:22	2020-07-13	12	[{"id_menu":1,"count":1}]	20302	delivery	5	17
95689	2020-07-13 14:30:42	2020-07-13	14	[{"id_menu":2,"count":1}]	18569	pick-up	0	14
95690	2020-07-13 14:33:52	2020-07-13	8	[{"id_menu":5,"count":1}]	37112	delivery	5	13
95691	2020-07-13 14:37:02	2020-07-13	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	37136	delivery	5	36
95692	2020-07-13 14:42:48	2020-07-13	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2551	pick-up	0	35
95693	2020-07-13 14:47:06	2020-07-13	17	[{"id_menu":4,"count":1}]	36234	delivery	5	22
95694	2020-07-13 14:48:50	2020-07-13	17	[{"id_menu":4,"count":1}]	536	delivery	5	22
95695	2020-07-13 14:52:29	2020-07-13	9	[{"id_menu":6,"count":3}]	10614	delivery	5	14
95696	2020-07-13 15:01:13	2020-07-13	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	12105	delivery	5	26
95697	2020-07-13 15:03:26	2020-07-13	12	[{"id_menu":1,"count":1}]	24929	delivery	5	17
95698	2020-07-13 15:09:19	2020-07-13	9	[{"id_menu":6,"count":1}]	2217	pick-up	0	9
95699	2020-07-13 15:09:37	2020-07-13	17	[{"id_menu":5,"count":3},{"id_menu":7,"count":1}]	37012	delivery	5	22
95700	2020-07-13 15:13:16	2020-07-13	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	33371	delivery	5	31
95701	2020-07-13 15:16:08	2020-07-13	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	22379	delivery	5	26
95702	2020-07-13 15:18:28	2020-07-13	9	[{"id_menu":7,"count":1}]	37032	delivery	5	14
95703	2020-07-13 15:19:20	2020-07-13	14	[{"id_menu":2,"count":1}]	17657	delivery	5	19
95704	2020-07-13 15:28:16	2020-07-13	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	34557	delivery	5	43
95705	2020-07-13 15:29:15	2020-07-13	9	[{"id_menu":7,"count":1}]	19094	delivery	5	14
95706	2020-07-13 15:33:38	2020-07-13	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	26099	pick-up	0	17
95707	2020-07-13 15:41:28	2020-07-13	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	23174	delivery	5	26
95708	2020-07-13 15:44:41	2020-07-13	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	37038	delivery	5	48
95709	2020-07-13 15:46:48	2020-07-13	12	[{"id_menu":3,"count":1}]	2613	delivery	5	17
95710	2020-07-13 15:47:21	2020-07-13	12	[{"id_menu":3,"count":1}]	37162	delivery	5	17
95711	2020-07-13 15:49:23	2020-07-13	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	31240	delivery	5	40
95712	2020-07-13 15:55:17	2020-07-13	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	863	delivery	5	31
95713	2020-07-13 16:11:20	2020-07-13	9	[{"id_menu":7,"count":1}]	37022	delivery	5	14
95714	2020-07-13 16:14:09	2020-07-13	9	[{"id_menu":7,"count":1}]	36291	delivery	5	14
95715	2020-07-13 16:16:36	2020-07-13	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3832	delivery	5	30
95716	2020-07-13 16:18:53	2020-07-13	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26267	delivery	5	37
95717	2020-07-13 16:20:17	2020-07-13	12	[{"id_menu":3,"count":1}]	20937	delivery	5	17
95718	2020-07-13 16:24:35	2020-07-13	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	29625	pick-up	0	17
95719	2020-07-13 16:27:04	2020-07-13	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	25254	pick-up	0	26
95720	2020-07-13 16:28:02	2020-07-13	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	30265	delivery	5	30
95721	2020-07-13 16:28:22	2020-07-13	9	[{"id_menu":6,"count":1}]	14081	pick-up	0	9
95722	2020-07-13 16:28:33	2020-07-13	9	[{"id_menu":6,"count":1}]	35105	delivery	5	14
95723	2020-07-13 16:37:52	2020-07-13	9	[{"id_menu":6,"count":1}]	30697	delivery	5	14
95724	2020-07-13 16:42:39	2020-07-13	12	[{"id_menu":3,"count":1}]	20433	delivery	5	17
95725	2020-07-13 16:51:42	2020-07-13	12	[{"id_menu":1,"count":1}]	29245	delivery	5	17
95726	2020-07-13 16:53:25	2020-07-13	9	[{"id_menu":6,"count":2}]	9443	delivery	5	14
95727	2020-07-13 16:53:48	2020-07-13	17	[{"id_menu":4,"count":1}]	27208	delivery	5	22
95728	2020-07-13 16:54:20	2020-07-13	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	1207	delivery	5	26
95729	2020-07-13 16:57:37	2020-07-13	12	[{"id_menu":1,"count":1}]	13026	pick-up	0	12
95730	2020-07-13 17:02:30	2020-07-13	9	[{"id_menu":6,"count":1}]	189	pick-up	0	9
95731	2020-07-13 17:05:20	2020-07-13	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	37021	delivery	5	43
95732	2020-07-13 17:06:57	2020-07-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27146	delivery	5	23
95733	2020-07-13 17:21:00	2020-07-13	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37170	delivery	5	35
95734	2020-07-13 17:23:03	2020-07-13	12	[{"id_menu":1,"count":1}]	2885	delivery	5	17
95735	2020-07-13 17:23:07	2020-07-13	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	34525	pick-up	0	29
95736	2020-07-13 17:23:27	2020-07-13	9	[{"id_menu":6,"count":1}]	8145	delivery	5	14
95737	2020-07-13 17:24:35	2020-07-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3539	pick-up	0	31
95738	2020-07-13 17:30:19	2020-07-13	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	30010	delivery	5	25
95739	2020-07-13 17:30:57	2020-07-13	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	37005	delivery	5	25
95740	2020-07-13 17:38:37	2020-07-13	9	[{"id_menu":7,"count":1}]	252	delivery	5	14
95741	2020-07-13 17:39:07	2020-07-13	9	[{"id_menu":6,"count":1}]	37103	delivery	5	14
95742	2020-07-13 17:51:57	2020-07-13	9	[{"id_menu":7,"count":1}]	23349	pick-up	0	9
95743	2020-07-13 17:55:01	2020-07-13	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	26086	delivery	5	31
95744	2020-07-13 18:02:41	2020-07-13	17	[{"id_menu":4,"count":1}]	25865	delivery	5	22
95745	2020-07-13 18:03:25	2020-07-13	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	37166	delivery	5	40
95746	2020-07-13 18:06:50	2020-07-13	14	[{"id_menu":2,"count":1}]	37104	delivery	5	19
95747	2020-07-13 18:12:16	2020-07-13	9	[{"id_menu":7,"count":1}]	20874	delivery	5	14
95748	2020-07-13 18:17:11	2020-07-13	9	[{"id_menu":7,"count":1}]	37017	delivery	5	14
95749	2020-07-13 18:17:26	2020-07-13	17	[{"id_menu":4,"count":1}]	18709	delivery	5	22
95750	2020-07-13 18:24:17	2020-07-13	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	10870	pick-up	0	20
95751	2020-07-13 18:25:22	2020-07-13	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	14853	delivery	5	27
95752	2020-07-13 18:28:00	2020-07-13	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	35573	delivery	5	28
95753	2020-07-13 18:31:03	2020-07-13	8	[{"id_menu":5,"count":1}]	37138	pick-up	0	8
95754	2020-07-13 18:34:05	2020-07-13	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	37071	delivery	5	34
95755	2020-07-13 18:34:38	2020-07-13	9	[{"id_menu":6,"count":1}]	1044	pick-up	0	9
95756	2020-07-13 18:35:29	2020-07-13	14	[{"id_menu":2,"count":1}]	25508	pick-up	0	14
95757	2020-07-13 18:35:33	2020-07-13	9	[{"id_menu":7,"count":1}]	1445	pick-up	0	9
95758	2020-07-13 18:36:47	2020-07-13	8	[{"id_menu":5,"count":1}]	37011	delivery	5	13
95759	2020-07-13 18:40:39	2020-07-13	9	[{"id_menu":7,"count":1}]	13165	delivery	5	14
95760	2020-07-13 18:44:05	2020-07-13	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	37081	delivery	5	40
95761	2020-07-13 18:44:20	2020-07-13	12	[{"id_menu":3,"count":1}]	37061	pick-up	0	12
95762	2020-07-13 18:48:22	2020-07-13	12	[{"id_menu":1,"count":1}]	35223	pick-up	0	12
95763	2020-07-13 18:49:11	2020-07-13	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	25169	delivery	5	26
95764	2020-07-13 18:51:34	2020-07-13	8	[{"id_menu":5,"count":1}]	28964	delivery	5	13
95765	2020-07-13 19:00:31	2020-07-13	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	37044	delivery	5	31
95766	2020-07-13 19:07:44	2020-07-13	8	[{"id_menu":5,"count":1}]	37101	delivery	5	13
95767	2020-07-13 19:09:34	2020-07-13	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	37079	delivery	5	25
95768	2020-07-13 19:10:14	2020-07-13	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	36361	delivery	5	31
95769	2020-07-13 19:11:00	2020-07-13	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	6000	delivery	5	26
95770	2020-07-13 19:15:59	2020-07-13	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5649	delivery	5	36
95771	2020-07-13 19:22:01	2020-07-13	9	[{"id_menu":6,"count":1}]	1260	delivery	5	14
95772	2020-07-13 19:25:50	2020-07-13	8	[{"id_menu":5,"count":1}]	37161	delivery	5	13
95773	2020-07-13 19:32:20	2020-07-13	12	[{"id_menu":1,"count":1}]	24350	delivery	5	17
95774	2020-07-13 19:34:18	2020-07-13	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	7941	pick-up	0	26
95775	2020-07-13 19:43:24	2020-07-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	31447	pick-up	0	31
95776	2020-07-13 19:50:59	2020-07-13	17	[{"id_menu":4,"count":1}]	35016	pick-up	0	17
95777	2020-07-13 19:51:59	2020-07-13	8	[{"id_menu":5,"count":1}]	29904	delivery	5	13
95778	2020-07-13 19:54:23	2020-07-13	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	37180	delivery	5	40
95779	2020-07-13 19:54:30	2020-07-13	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	10670	delivery	5	37
95780	2020-07-13 19:56:45	2020-07-13	9	[{"id_menu":7,"count":1}]	37165	delivery	5	14
95781	2020-07-13 20:03:12	2020-07-13	9	[{"id_menu":6,"count":1}]	17629	delivery	5	14
95782	2020-07-13 20:09:46	2020-07-13	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	17005	delivery	5	28
95783	2020-07-13 20:10:21	2020-07-13	12	[{"id_menu":3,"count":1}]	15301	delivery	5	17
95784	2020-07-13 20:10:36	2020-07-13	17	[{"id_menu":4,"count":1}]	36854	delivery	5	22
95785	2020-07-13 20:14:47	2020-07-13	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	37100	delivery	5	22
95786	2020-07-13 20:17:11	2020-07-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	16469	pick-up	0	23
95787	2020-07-13 20:19:26	2020-07-13	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	16002	delivery	5	42
95788	2020-07-13 20:23:05	2020-07-13	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	6232	pick-up	0	22
95789	2020-07-13 20:24:53	2020-07-13	9	[{"id_menu":7,"count":1}]	28467	delivery	5	14
95790	2020-07-13 20:41:17	2020-07-13	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	37153	delivery	5	28
95791	2020-07-13 20:50:01	2020-07-13	17	[{"id_menu":4,"count":1}]	37045	delivery	5	22
95792	2020-07-13 20:53:22	2020-07-13	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	37089	delivery	5	39
95793	2020-07-13 20:56:49	2020-07-13	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1008	delivery	5	40
95794	2020-07-13 20:59:03	2020-07-13	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10356	delivery	5	43
95795	2020-07-13 21:01:24	2020-07-13	9	[{"id_menu":7,"count":1}]	36996	delivery	5	14
95796	2020-07-13 21:03:20	2020-07-13	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8961	delivery	5	31
95797	2020-07-13 21:04:28	2020-07-13	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	32962	delivery	5	34
95798	2020-07-13 21:07:06	2020-07-13	9	[{"id_menu":6,"count":1}]	5097	delivery	5	14
95799	2020-07-13 21:12:57	2020-07-13	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20905	pick-up	0	30
95800	2020-07-13 21:16:56	2020-07-13	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	27556	delivery	5	45
95801	2020-07-13 21:22:05	2020-07-13	9	[{"id_menu":6,"count":1}]	15653	pick-up	0	9
95802	2020-07-13 21:23:20	2020-07-13	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	37098	delivery	5	30
95803	2020-07-13 21:30:18	2020-07-13	9	[{"id_menu":6,"count":1}]	37146	delivery	5	14
95804	2020-07-13 21:30:49	2020-07-13	9	[{"id_menu":7,"count":2}]	36179	delivery	5	14
95805	2020-07-13 21:31:31	2020-07-13	17	[{"id_menu":4,"count":1}]	37085	pick-up	0	17
95806	2020-07-13 21:32:09	2020-07-13	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	37178	delivery	5	25
95807	2020-07-13 21:34:59	2020-07-13	17	[{"id_menu":4,"count":2}]	16219	delivery	5	22
95808	2020-07-13 21:42:23	2020-07-13	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	8856	delivery	5	27
95809	2020-07-13 21:42:43	2020-07-13	8	[{"id_menu":5,"count":1}]	27491	delivery	5	13
95810	2020-07-13 21:47:45	2020-07-13	8	[{"id_menu":5,"count":1}]	33988	delivery	5	13
95811	2020-07-13 21:48:39	2020-07-13	9	[{"id_menu":7,"count":1}]	9679	delivery	5	14
95812	2020-07-13 21:52:19	2020-07-13	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	32388	delivery	5	26
95813	2020-07-13 21:52:57	2020-07-13	9	[{"id_menu":7,"count":1}]	23322	delivery	5	14
95814	2020-07-13 21:53:17	2020-07-13	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10478	delivery	5	43
95815	2020-07-13 21:53:40	2020-07-13	12	[{"id_menu":1,"count":1}]	8471	pick-up	0	12
95816	2020-07-13 21:59:32	2020-07-13	17	[{"id_menu":4,"count":1}]	37043	delivery	5	22
95817	2020-07-13 22:00:43	2020-07-13	12	[{"id_menu":3,"count":1}]	19386	delivery	5	17
95818	2020-07-13 22:01:23	2020-07-13	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	2783	pick-up	0	34
95819	2020-07-13 22:01:55	2020-07-13	14	[{"id_menu":2,"count":1}]	37127	delivery	5	19
95820	2020-07-13 22:02:37	2020-07-13	9	[{"id_menu":7,"count":1}]	16015	delivery	5	14
95821	2020-07-13 22:04:32	2020-07-13	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14256	delivery	5	39
95822	2020-07-13 22:05:27	2020-07-13	9	[{"id_menu":7,"count":1}]	21679	pick-up	0	9
95823	2020-07-13 22:08:39	2020-07-13	17	[{"id_menu":4,"count":1}]	13273	delivery	5	22
95824	2020-07-13 22:11:49	2020-07-13	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9685	delivery	5	48
95825	2020-07-13 22:15:42	2020-07-13	14	[{"id_menu":2,"count":1}]	12962	pick-up	0	14
95826	2020-07-13 22:29:41	2020-07-13	14	[{"id_menu":2,"count":1}]	37134	delivery	5	19
95827	2020-07-13 22:30:00	2020-07-13	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":3}]	37152	delivery	5	22
95828	2020-07-13 22:35:13	2020-07-13	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	22989	delivery	5	43
95829	2020-07-13 22:36:11	2020-07-13	17	[{"id_menu":4,"count":1}]	33660	delivery	5	22
95830	2020-07-13 22:39:56	2020-07-13	17	[{"id_menu":4,"count":1}]	10396	delivery	5	22
95831	2020-07-13 22:46:10	2020-07-13	9	[{"id_menu":6,"count":1}]	37078	delivery	5	14
95832	2020-07-13 22:49:51	2020-07-13	9	[{"id_menu":6,"count":1}]	9704	pick-up	0	9
95833	2020-07-13 22:52:24	2020-07-13	9	[{"id_menu":7,"count":1}]	1245	pick-up	0	9
95834	2020-07-13 22:52:37	2020-07-13	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":2}]	3701	delivery	5	31
95835	2020-07-13 22:55:16	2020-07-13	8	[{"id_menu":5,"count":1}]	23190	delivery	5	13
95836	2020-07-13 22:56:16	2020-07-13	14	[{"id_menu":2,"count":1}]	33126	pick-up	0	14
95837	2020-07-13 23:00:00	2020-07-13	8	[{"id_menu":5,"count":1}]	37144	delivery	5	13
95838	2020-07-13 23:05:09	2020-07-13	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	37133	delivery	5	31
95839	2020-07-13 23:06:09	2020-07-13	9	[{"id_menu":6,"count":1}]	36515	delivery	5	14
95840	2020-07-13 23:07:19	2020-07-13	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	13851	pick-up	0	29
95841	2020-07-13 23:08:57	2020-07-13	17	[{"id_menu":4,"count":2}]	37074	delivery	5	22
95842	2020-07-13 23:09:30	2020-07-13	8	[{"id_menu":5,"count":1}]	35306	delivery	5	13
95843	2020-07-13 23:15:09	2020-07-13	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	37096	delivery	5	44
95844	2020-07-13 23:27:44	2020-07-13	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	495	delivery	5	35
95845	2020-07-13 23:29:08	2020-07-13	9	[{"id_menu":6,"count":1}]	37149	delivery	5	14
95846	2020-07-13 23:33:13	2020-07-13	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	11770	delivery	5	26
95847	2020-07-13 23:39:53	2020-07-13	9	[{"id_menu":6,"count":1}]	15236	delivery	5	14
95848	2020-07-13 23:56:21	2020-07-13	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	26630	delivery	5	34
95849	2020-07-13 23:56:59	2020-07-13	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	11946	pick-up	0	21
95850	2020-07-13 23:58:02	2020-07-13	9	[{"id_menu":7,"count":1}]	14668	delivery	5	14
95851	2020-07-13 23:58:58	2020-07-13	17	[{"id_menu":4,"count":1}]	37107	delivery	5	22
95852	2020-07-14 00:00:28	2020-07-14	14	[{"id_menu":2,"count":1}]	14112	delivery	5	19
95853	2020-07-14 00:01:03	2020-07-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9153	delivery	5	28
95854	2020-07-14 00:15:22	2020-07-14	14	[{"id_menu":2,"count":1}]	37335	delivery	5	19
95855	2020-07-14 00:15:54	2020-07-14	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31647	delivery	5	23
95856	2020-07-14 00:17:55	2020-07-14	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	37306	delivery	5	22
95857	2020-07-14 00:18:56	2020-07-14	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	7870	delivery	5	23
95858	2020-07-14 00:21:09	2020-07-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	37347	delivery	5	36
95859	2020-07-14 00:24:02	2020-07-14	12	[{"id_menu":1,"count":1}]	14059	delivery	5	17
95860	2020-07-14 00:26:26	2020-07-14	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":2}]	37230	delivery	5	28
95861	2020-07-14 00:27:02	2020-07-14	9	[{"id_menu":6,"count":1}]	15930	delivery	5	14
95862	2020-07-14 00:27:44	2020-07-14	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	34503	delivery	5	22
95863	2020-07-14 00:28:47	2020-07-14	12	[{"id_menu":1,"count":1}]	18057	pick-up	0	12
95864	2020-07-14 00:29:23	2020-07-14	14	[{"id_menu":2,"count":1}]	33199	delivery	5	19
95865	2020-07-14 00:31:07	2020-07-14	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	3508	delivery	5	26
95866	2020-07-14 00:32:50	2020-07-14	12	[{"id_menu":3,"count":1}]	37303	delivery	5	17
95867	2020-07-14 00:36:21	2020-07-14	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	4624	delivery	5	29
95868	2020-07-14 00:46:02	2020-07-14	17	[{"id_menu":4,"count":1}]	20493	pick-up	0	17
95869	2020-07-14 00:54:21	2020-07-14	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":3}]	37339	delivery	5	22
95870	2020-07-14 00:57:17	2020-07-14	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19456	delivery	5	22
95871	2020-07-14 00:58:47	2020-07-14	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	13027	delivery	5	26
95872	2020-07-14 01:00:33	2020-07-14	9	[{"id_menu":6,"count":1}]	2974	delivery	5	14
95873	2020-07-14 01:01:24	2020-07-14	9	[{"id_menu":7,"count":1}]	22771	delivery	5	14
95874	2020-07-14 01:03:09	2020-07-14	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10484	delivery	5	22
95875	2020-07-14 01:10:03	2020-07-14	17	[{"id_menu":4,"count":1}]	19275	pick-up	0	17
95876	2020-07-14 01:16:14	2020-07-14	12	[{"id_menu":1,"count":1}]	6865	pick-up	0	12
95877	2020-07-14 01:20:56	2020-07-14	17	[{"id_menu":4,"count":1}]	1882	pick-up	0	17
95878	2020-07-14 01:22:09	2020-07-14	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	12675	pick-up	0	21
95879	2020-07-14 01:24:10	2020-07-14	17	[{"id_menu":4,"count":1}]	351	delivery	5	22
95880	2020-07-14 01:24:54	2020-07-14	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	15139	delivery	5	40
95881	2020-07-14 01:29:15	2020-07-14	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37373	delivery	5	52
95882	2020-07-14 01:29:18	2020-07-14	9	[{"id_menu":6,"count":1}]	23104	delivery	5	14
95883	2020-07-14 01:29:30	2020-07-14	9	[{"id_menu":6,"count":1}]	6090	pick-up	0	9
95884	2020-07-14 01:31:57	2020-07-14	12	[{"id_menu":3,"count":1}]	26437	delivery	5	17
95885	2020-07-14 01:37:15	2020-07-14	17	[{"id_menu":4,"count":1}]	31313	pick-up	0	17
95886	2020-07-14 01:37:24	2020-07-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10106	pick-up	0	26
95887	2020-07-14 01:39:18	2020-07-14	8	[{"id_menu":5,"count":1}]	19295	delivery	5	13
95888	2020-07-14 01:41:28	2020-07-14	8	[{"id_menu":5,"count":2}]	37212	delivery	5	13
95889	2020-07-14 01:42:10	2020-07-14	8	[{"id_menu":5,"count":1}]	299	pick-up	0	8
95890	2020-07-14 01:42:38	2020-07-14	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19320	delivery	5	37
95891	2020-07-14 01:47:53	2020-07-14	14	[{"id_menu":2,"count":1}]	37337	delivery	5	19
95892	2020-07-14 01:48:05	2020-07-14	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7190	delivery	5	28
95893	2020-07-14 01:53:25	2020-07-14	9	[{"id_menu":7,"count":1}]	31134	pick-up	0	9
95894	2020-07-14 01:56:02	2020-07-14	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	37344	delivery	5	39
95895	2020-07-14 01:57:45	2020-07-14	12	[{"id_menu":1,"count":1}]	37201	pick-up	0	12
95896	2020-07-14 01:57:59	2020-07-14	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	37258	delivery	5	39
95897	2020-07-14 02:04:19	2020-07-14	8	[{"id_menu":5,"count":1}]	9156	delivery	5	13
95898	2020-07-14 02:04:51	2020-07-14	14	[{"id_menu":2,"count":1}]	2083	pick-up	0	14
95899	2020-07-14 02:05:27	2020-07-14	9	[{"id_menu":7,"count":1}]	37231	delivery	5	14
95900	2020-07-14 02:07:38	2020-07-14	14	[{"id_menu":2,"count":1}]	34488	pick-up	0	14
95901	2020-07-14 02:09:12	2020-07-14	17	[{"id_menu":4,"count":1}]	7007	delivery	5	22
95902	2020-07-14 02:10:32	2020-07-14	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	25049	delivery	5	39
95903	2020-07-14 02:11:30	2020-07-14	14	[{"id_menu":2,"count":1}]	37374	delivery	5	19
95904	2020-07-14 02:12:31	2020-07-14	9	[{"id_menu":6,"count":1}]	15585	delivery	5	14
95905	2020-07-14 02:12:42	2020-07-14	14	[{"id_menu":2,"count":1}]	18677	delivery	5	19
95906	2020-07-14 02:14:28	2020-07-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	27291	delivery	5	31
95907	2020-07-14 02:15:18	2020-07-14	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20525	delivery	5	37
95908	2020-07-14 02:16:51	2020-07-14	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	28773	delivery	5	26
95909	2020-07-14 02:17:26	2020-07-14	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23134	delivery	5	36
95910	2020-07-14 02:25:53	2020-07-14	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	37353	delivery	5	34
95911	2020-07-14 02:44:34	2020-07-14	9	[{"id_menu":6,"count":1}]	27913	delivery	5	14
95912	2020-07-14 02:45:42	2020-07-14	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	12905	delivery	5	25
95913	2020-07-14 02:50:11	2020-07-14	14	[{"id_menu":2,"count":1}]	7148	pick-up	0	14
95914	2020-07-14 02:54:05	2020-07-14	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15488	delivery	5	35
95915	2020-07-14 02:57:44	2020-07-14	17	[{"id_menu":4,"count":1}]	37198	delivery	5	22
95916	2020-07-14 02:57:51	2020-07-14	17	[{"id_menu":4,"count":1}]	11945	delivery	5	22
95917	2020-07-14 03:01:35	2020-07-14	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3328	delivery	5	44
95918	2020-07-14 03:01:41	2020-07-14	8	[{"id_menu":5,"count":2}]	11333	delivery	5	13
95919	2020-07-14 03:03:44	2020-07-14	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24873	delivery	5	31
95920	2020-07-14 03:04:32	2020-07-14	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	20533	pick-up	0	22
95921	2020-07-14 03:09:33	2020-07-14	17	[{"id_menu":4,"count":1}]	16749	delivery	5	22
95922	2020-07-14 03:11:15	2020-07-14	9	[{"id_menu":7,"count":1}]	28404	delivery	5	14
95923	2020-07-14 03:15:25	2020-07-14	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	11825	delivery	5	27
95924	2020-07-14 03:19:08	2020-07-14	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	37218	delivery	5	45
95925	2020-07-14 03:20:38	2020-07-14	17	[{"id_menu":4,"count":1}]	2575	pick-up	0	17
95926	2020-07-14 03:25:00	2020-07-14	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	25970	delivery	5	39
95927	2020-07-14 03:28:30	2020-07-14	8	[{"id_menu":5,"count":1}]	34410	delivery	5	13
95928	2020-07-14 03:32:46	2020-07-14	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	9563	delivery	5	26
95929	2020-07-14 03:35:38	2020-07-14	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	12541	delivery	5	38
95930	2020-07-14 03:42:14	2020-07-14	17	[{"id_menu":4,"count":1}]	13062	delivery	5	22
95931	2020-07-14 03:42:25	2020-07-14	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	21521	delivery	5	40
95932	2020-07-14 03:43:04	2020-07-14	9	[{"id_menu":7,"count":1}]	14726	delivery	5	14
95933	2020-07-14 03:47:17	2020-07-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	37208	delivery	5	28
95934	2020-07-14 03:47:36	2020-07-14	8	[{"id_menu":5,"count":1}]	14739	delivery	5	13
95935	2020-07-14 03:48:17	2020-07-14	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6277	pick-up	0	25
95936	2020-07-14 03:48:59	2020-07-14	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	37099	pick-up	0	17
95937	2020-07-14 03:49:34	2020-07-14	8	[{"id_menu":5,"count":1}]	15124	delivery	5	13
95938	2020-07-14 03:49:59	2020-07-14	8	[{"id_menu":5,"count":1}]	37295	delivery	5	13
95939	2020-07-14 03:50:37	2020-07-14	12	[{"id_menu":3,"count":1}]	34208	pick-up	0	12
95940	2020-07-14 03:51:25	2020-07-14	14	[{"id_menu":2,"count":1}]	2071	delivery	5	19
95941	2020-07-14 03:53:11	2020-07-14	12	[{"id_menu":1,"count":1}]	14954	delivery	5	17
95942	2020-07-14 03:57:24	2020-07-14	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	35720	delivery	5	26
95943	2020-07-14 04:00:16	2020-07-14	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":2}]	9520	delivery	5	31
95944	2020-07-14 04:04:01	2020-07-14	8	[{"id_menu":5,"count":1}]	15916	delivery	5	13
95945	2020-07-14 04:04:15	2020-07-14	8	[{"id_menu":5,"count":1}]	12378	delivery	5	13
95946	2020-07-14 04:09:48	2020-07-14	8	[{"id_menu":5,"count":1}]	1140	pick-up	0	8
95947	2020-07-14 04:12:19	2020-07-14	9	[{"id_menu":7,"count":1}]	13262	delivery	5	14
95948	2020-07-14 04:14:27	2020-07-14	12	[{"id_menu":3,"count":1}]	20544	delivery	5	17
95949	2020-07-14 04:15:13	2020-07-14	17	[{"id_menu":4,"count":1}]	1506	delivery	5	22
95950	2020-07-14 04:21:45	2020-07-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14722	delivery	5	31
95951	2020-07-14 04:23:40	2020-07-14	9	[{"id_menu":7,"count":1}]	27692	delivery	5	14
95952	2020-07-14 04:24:21	2020-07-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	27711	delivery	5	28
95953	2020-07-14 04:29:42	2020-07-14	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	4478	delivery	5	29
95954	2020-07-14 04:30:26	2020-07-14	12	[{"id_menu":1,"count":1}]	19075	pick-up	0	12
95955	2020-07-14 04:36:13	2020-07-14	9	[{"id_menu":6,"count":1}]	36148	pick-up	0	9
95956	2020-07-14 04:41:31	2020-07-14	8	[{"id_menu":5,"count":1}]	33864	delivery	5	13
95957	2020-07-14 04:42:49	2020-07-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	12502	pick-up	0	31
95958	2020-07-14 04:44:05	2020-07-14	8	[{"id_menu":5,"count":2}]	37283	delivery	5	13
95959	2020-07-14 04:46:14	2020-07-14	8	[{"id_menu":5,"count":1}]	37346	delivery	5	13
95960	2020-07-14 04:47:27	2020-07-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	22716	delivery	5	31
95961	2020-07-14 04:54:35	2020-07-14	8	[{"id_menu":5,"count":1}]	37196	delivery	5	13
95962	2020-07-14 04:56:28	2020-07-14	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	29854	delivery	5	39
95963	2020-07-14 05:02:38	2020-07-14	14	[{"id_menu":2,"count":1}]	7362	delivery	5	19
95964	2020-07-14 05:02:59	2020-07-14	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	37185	pick-up	0	26
95965	2020-07-14 05:04:19	2020-07-14	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	15437	delivery	5	26
95966	2020-07-14 05:04:22	2020-07-14	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	37294	pick-up	0	38
95967	2020-07-14 05:08:23	2020-07-14	8	[{"id_menu":5,"count":1}]	23298	delivery	5	13
95968	2020-07-14 05:13:08	2020-07-14	9	[{"id_menu":6,"count":1}]	37238	delivery	5	14
95969	2020-07-14 05:15:28	2020-07-14	9	[{"id_menu":6,"count":1}]	37359	delivery	5	14
95970	2020-07-14 05:16:42	2020-07-14	14	[{"id_menu":2,"count":1}]	15464	delivery	5	19
95971	2020-07-14 05:16:46	2020-07-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	12468	delivery	5	28
95972	2020-07-14 05:16:56	2020-07-14	8	[{"id_menu":5,"count":1}]	37237	delivery	5	13
95973	2020-07-14 05:21:48	2020-07-14	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	36798	pick-up	0	26
95974	2020-07-14 05:23:35	2020-07-14	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	730	pick-up	0	17
95975	2020-07-14 05:23:36	2020-07-14	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	37262	delivery	5	26
95976	2020-07-14 05:27:48	2020-07-14	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	16214	delivery	5	27
95977	2020-07-14 05:31:03	2020-07-14	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1418	pick-up	0	39
95978	2020-07-14 05:32:18	2020-07-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	35063	delivery	5	22
95979	2020-07-14 05:38:54	2020-07-14	14	[{"id_menu":2,"count":1}]	37204	delivery	5	19
95980	2020-07-14 05:46:51	2020-07-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	37276	delivery	5	31
95981	2020-07-14 05:48:22	2020-07-14	8	[{"id_menu":5,"count":1}]	37300	delivery	5	13
95982	2020-07-14 05:50:54	2020-07-14	9	[{"id_menu":6,"count":1}]	32316	delivery	5	14
95983	2020-07-14 05:51:38	2020-07-14	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	37206	delivery	5	26
95984	2020-07-14 05:53:47	2020-07-14	17	[{"id_menu":4,"count":1}]	37186	pick-up	0	17
95985	2020-07-14 05:53:56	2020-07-14	17	[{"id_menu":4,"count":1}]	7603	pick-up	0	17
95986	2020-07-14 05:59:38	2020-07-14	12	[{"id_menu":3,"count":1}]	22688	delivery	5	17
95987	2020-07-14 06:00:19	2020-07-14	9	[{"id_menu":6,"count":1}]	37248	delivery	5	14
95988	2020-07-14 06:01:55	2020-07-14	12	[{"id_menu":3,"count":1}]	37275	delivery	5	17
95989	2020-07-14 06:04:52	2020-07-14	12	[{"id_menu":3,"count":1}]	37225	delivery	5	17
95990	2020-07-14 06:05:27	2020-07-14	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	315	pick-up	0	29
95991	2020-07-14 06:06:09	2020-07-14	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	37236	delivery	5	30
95992	2020-07-14 06:06:14	2020-07-14	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	366	delivery	5	36
95993	2020-07-14 06:08:22	2020-07-14	9	[{"id_menu":7,"count":1}]	19380	delivery	5	14
95994	2020-07-14 06:09:07	2020-07-14	17	[{"id_menu":4,"count":1}]	2068	pick-up	0	17
95995	2020-07-14 06:10:09	2020-07-14	17	[{"id_menu":4,"count":1}]	37357	delivery	5	22
95996	2020-07-14 06:13:55	2020-07-14	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	37334	delivery	5	31
95997	2020-07-14 06:17:08	2020-07-14	9	[{"id_menu":6,"count":1}]	37284	delivery	5	14
95998	2020-07-14 06:19:58	2020-07-14	9	[{"id_menu":6,"count":1}]	2153	delivery	5	14
95999	2020-07-14 06:20:22	2020-07-14	9	[{"id_menu":7,"count":1}]	18845	delivery	5	14
96000	2020-07-14 06:24:50	2020-07-14	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	37315	delivery	5	31
96001	2020-07-14 06:28:34	2020-07-14	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	13320	delivery	5	27
96002	2020-07-14 06:28:57	2020-07-14	9	[{"id_menu":6,"count":1}]	37287	delivery	5	14
96003	2020-07-14 06:29:04	2020-07-14	8	[{"id_menu":5,"count":1}]	2310	delivery	5	13
96004	2020-07-14 06:30:32	2020-07-14	9	[{"id_menu":6,"count":1}]	30777	pick-up	0	9
96005	2020-07-14 06:31:38	2020-07-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	344	pick-up	0	26
96006	2020-07-14 06:32:12	2020-07-14	17	[{"id_menu":4,"count":1}]	23179	delivery	5	22
96007	2020-07-14 06:32:44	2020-07-14	8	[{"id_menu":5,"count":1}]	37331	delivery	5	13
96008	2020-07-14 06:39:17	2020-07-14	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	33148	delivery	5	44
96009	2020-07-14 06:47:42	2020-07-14	12	[{"id_menu":1,"count":1}]	226	pick-up	0	12
96010	2020-07-14 06:49:22	2020-07-14	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	11266	delivery	5	28
96011	2020-07-14 06:50:10	2020-07-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":3}]	30977	delivery	5	36
96012	2020-07-14 06:59:44	2020-07-14	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":2}]	11840	delivery	5	26
96013	2020-07-14 07:04:50	2020-07-14	12	[{"id_menu":3,"count":1}]	5588	pick-up	0	12
96014	2020-07-14 07:09:21	2020-07-14	9	[{"id_menu":6,"count":1}]	3509	pick-up	0	9
96015	2020-07-14 07:14:33	2020-07-14	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	3034	pick-up	0	21
96016	2020-07-14 07:17:09	2020-07-14	14	[{"id_menu":2,"count":1}]	28257	delivery	5	19
96017	2020-07-14 07:17:23	2020-07-14	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	28319	pick-up	0	29
96018	2020-07-14 07:17:35	2020-07-14	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7128	pick-up	0	43
96019	2020-07-14 07:17:48	2020-07-14	8	[{"id_menu":5,"count":1}]	14867	delivery	5	13
96020	2020-07-14 07:18:14	2020-07-14	30	[{"id_menu":3,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	172	pick-up	0	30
96021	2020-07-14 07:30:17	2020-07-14	12	[{"id_menu":1,"count":2}]	4479	delivery	5	17
96022	2020-07-14 07:33:18	2020-07-14	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	34394	delivery	5	27
96023	2020-07-14 07:42:25	2020-07-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27449	delivery	5	22
96024	2020-07-14 07:43:28	2020-07-14	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3924	pick-up	0	21
96025	2020-07-14 07:43:30	2020-07-14	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6366	delivery	5	31
96026	2020-07-14 07:45:01	2020-07-14	17	[{"id_menu":4,"count":1}]	107	pick-up	0	17
96027	2020-07-14 07:49:30	2020-07-14	9	[{"id_menu":7,"count":1}]	15696	delivery	5	14
96028	2020-07-14 07:49:55	2020-07-14	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37222	delivery	5	45
96029	2020-07-14 07:52:23	2020-07-14	8	[{"id_menu":5,"count":2}]	37279	delivery	5	13
96030	2020-07-14 07:56:03	2020-07-14	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	37366	delivery	5	26
96031	2020-07-14 07:56:18	2020-07-14	9	[{"id_menu":6,"count":1}]	37268	delivery	5	14
96032	2020-07-14 07:58:04	2020-07-14	9	[{"id_menu":7,"count":1}]	36650	delivery	5	14
96033	2020-07-14 07:58:08	2020-07-14	12	[{"id_menu":1,"count":1}]	37332	delivery	5	17
96034	2020-07-14 07:58:46	2020-07-14	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	21897	delivery	5	28
96035	2020-07-14 08:01:59	2020-07-14	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	502	delivery	5	22
96036	2020-07-14 08:04:09	2020-07-14	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	9065	pick-up	0	26
96037	2020-07-14 08:05:01	2020-07-14	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	20990	delivery	5	30
96038	2020-07-14 08:07:27	2020-07-14	39	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	37301	delivery	5	44
96039	2020-07-14 08:08:13	2020-07-14	9	[{"id_menu":6,"count":1}]	1090	delivery	5	14
96040	2020-07-14 08:09:27	2020-07-14	12	[{"id_menu":1,"count":1}]	37271	pick-up	0	12
96041	2020-07-14 08:10:02	2020-07-14	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	37311	delivery	5	39
96042	2020-07-14 08:10:36	2020-07-14	12	[{"id_menu":3,"count":1}]	408	delivery	5	17
96043	2020-07-14 08:17:09	2020-07-14	9	[{"id_menu":6,"count":1}]	36634	pick-up	0	9
96044	2020-07-14 08:21:33	2020-07-14	9	[{"id_menu":6,"count":1}]	5486	delivery	5	14
96045	2020-07-14 08:21:47	2020-07-14	9	[{"id_menu":7,"count":1}]	37326	delivery	5	14
96046	2020-07-14 08:25:22	2020-07-14	17	[{"id_menu":4,"count":1}]	1366	pick-up	0	17
96047	2020-07-14 08:27:59	2020-07-14	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	31659	delivery	5	31
96048	2020-07-14 08:29:56	2020-07-14	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10390	delivery	5	39
96049	2020-07-14 08:31:06	2020-07-14	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	37203	delivery	5	35
96050	2020-07-14 08:33:56	2020-07-14	17	[{"id_menu":4,"count":1}]	37280	delivery	5	22
96051	2020-07-14 08:35:18	2020-07-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	34400	delivery	5	28
96052	2020-07-14 08:43:16	2020-07-14	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32407	delivery	5	31
96053	2020-07-14 08:43:47	2020-07-14	8	[{"id_menu":5,"count":1}]	3077	delivery	5	13
96054	2020-07-14 08:44:21	2020-07-14	9	[{"id_menu":7,"count":1}]	33717	delivery	5	14
96055	2020-07-14 08:52:25	2020-07-14	14	[{"id_menu":2,"count":1}]	18538	delivery	5	19
96056	2020-07-14 08:58:54	2020-07-14	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	37318	delivery	5	27
96057	2020-07-14 09:02:07	2020-07-14	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3728	pick-up	0	52
96058	2020-07-14 09:07:13	2020-07-14	8	[{"id_menu":5,"count":1}]	6688	pick-up	0	8
96059	2020-07-14 09:15:40	2020-07-14	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	265	pick-up	0	26
96060	2020-07-14 09:16:19	2020-07-14	12	[{"id_menu":3,"count":1}]	5910	delivery	5	17
96061	2020-07-14 09:16:24	2020-07-14	14	[{"id_menu":2,"count":1}]	37358	delivery	5	19
96062	2020-07-14 09:21:02	2020-07-14	17	[{"id_menu":4,"count":1}]	569	delivery	5	22
96063	2020-07-14 09:21:31	2020-07-14	14	[{"id_menu":2,"count":1}]	14696	delivery	5	19
96064	2020-07-14 09:22:57	2020-07-14	12	[{"id_menu":3,"count":1}]	37297	delivery	5	17
96065	2020-07-14 09:23:01	2020-07-14	12	[{"id_menu":1,"count":1}]	7341	delivery	5	17
96066	2020-07-14 09:24:29	2020-07-14	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	14068	delivery	5	25
96067	2020-07-14 09:26:06	2020-07-14	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	37264	delivery	5	27
96068	2020-07-14 09:27:54	2020-07-14	14	[{"id_menu":2,"count":1}]	33212	delivery	5	19
96069	2020-07-14 09:29:33	2020-07-14	9	[{"id_menu":6,"count":1}]	27960	delivery	5	14
96070	2020-07-14 09:30:33	2020-07-14	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	32671	delivery	5	26
96071	2020-07-14 09:33:36	2020-07-14	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	21349	delivery	5	34
96072	2020-07-14 09:35:12	2020-07-14	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37260	delivery	5	31
96073	2020-07-14 09:37:58	2020-07-14	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	37243	delivery	5	31
96074	2020-07-14 09:41:48	2020-07-14	9	[{"id_menu":6,"count":1}]	19911	pick-up	0	9
96075	2020-07-14 09:42:49	2020-07-14	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	34311	delivery	5	40
96076	2020-07-14 09:45:06	2020-07-14	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	32817	delivery	5	26
96077	2020-07-14 09:50:05	2020-07-14	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23326	delivery	5	31
96078	2020-07-14 09:51:11	2020-07-14	8	[{"id_menu":5,"count":1}]	17257	delivery	5	13
96079	2020-07-14 09:52:38	2020-07-14	14	[{"id_menu":2,"count":1}]	37319	delivery	5	19
96080	2020-07-14 09:58:38	2020-07-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13291	delivery	5	22
96081	2020-07-14 09:59:39	2020-07-14	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12267	pick-up	0	52
96082	2020-07-14 10:05:25	2020-07-14	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	26242	delivery	5	40
96083	2020-07-14 10:05:39	2020-07-14	17	[{"id_menu":4,"count":1}]	37240	delivery	5	22
96084	2020-07-14 10:07:53	2020-07-14	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16066	delivery	5	45
96085	2020-07-14 10:09:49	2020-07-14	17	[{"id_menu":4,"count":1}]	8792	delivery	5	22
96086	2020-07-14 10:09:58	2020-07-14	9	[{"id_menu":6,"count":1}]	37292	delivery	5	14
96087	2020-07-14 10:13:29	2020-07-14	9	[{"id_menu":7,"count":1}]	1494	delivery	5	14
96088	2020-07-14 10:13:59	2020-07-14	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16045	delivery	5	48
96089	2020-07-14 10:18:08	2020-07-14	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20786	delivery	5	54
96090	2020-07-14 10:20:34	2020-07-14	12	[{"id_menu":3,"count":1}]	37223	pick-up	0	12
96091	2020-07-14 10:29:00	2020-07-14	8	[{"id_menu":5,"count":1}]	14829	delivery	5	13
96092	2020-07-14 10:30:56	2020-07-14	9	[{"id_menu":7,"count":1}]	8139	delivery	5	14
96093	2020-07-14 10:31:04	2020-07-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	31160	pick-up	0	23
96094	2020-07-14 10:31:41	2020-07-14	12	[{"id_menu":1,"count":1}]	23583	delivery	5	17
96095	2020-07-14 10:33:17	2020-07-14	17	[{"id_menu":4,"count":1}]	2932	pick-up	0	17
96096	2020-07-14 10:44:37	2020-07-14	14	[{"id_menu":2,"count":1}]	5858	delivery	5	19
96097	2020-07-14 10:48:00	2020-07-14	9	[{"id_menu":7,"count":1}]	31803	delivery	5	14
96098	2020-07-14 10:48:01	2020-07-14	9	[{"id_menu":7,"count":1}]	37342	delivery	5	14
96099	2020-07-14 10:48:21	2020-07-14	12	[{"id_menu":1,"count":1}]	11398	delivery	5	17
96100	2020-07-14 10:51:40	2020-07-14	14	[{"id_menu":2,"count":1}]	2770	delivery	5	19
96101	2020-07-14 10:55:37	2020-07-14	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	27124	delivery	5	34
96102	2020-07-14 10:55:42	2020-07-14	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	8410	delivery	5	31
96103	2020-07-14 10:59:24	2020-07-14	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":2}]	19788	delivery	5	25
96104	2020-07-14 11:00:11	2020-07-14	12	[{"id_menu":1,"count":1}]	5498	pick-up	0	12
96105	2020-07-14 11:00:43	2020-07-14	14	[{"id_menu":2,"count":1}]	11335	delivery	5	19
96106	2020-07-14 11:01:20	2020-07-14	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":3}]	24013	delivery	5	28
96107	2020-07-14 11:01:55	2020-07-14	17	[{"id_menu":4,"count":1}]	37251	delivery	5	22
96108	2020-07-14 11:04:28	2020-07-14	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	3459	pick-up	0	24
96109	2020-07-14 11:12:05	2020-07-14	8	[{"id_menu":5,"count":1}]	289	pick-up	0	8
96110	2020-07-14 11:23:41	2020-07-14	14	[{"id_menu":2,"count":1}]	36720	delivery	5	19
96111	2020-07-14 11:26:29	2020-07-14	17	[{"id_menu":4,"count":2}]	37278	delivery	5	22
96112	2020-07-14 11:31:10	2020-07-14	12	[{"id_menu":1,"count":1}]	2339	pick-up	0	12
96113	2020-07-14 11:31:19	2020-07-14	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15797	pick-up	0	48
96114	2020-07-14 11:31:38	2020-07-14	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	37192	delivery	5	40
96115	2020-07-14 11:33:22	2020-07-14	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	37184	delivery	5	39
96116	2020-07-14 11:38:34	2020-07-14	8	[{"id_menu":5,"count":1}]	37343	pick-up	0	8
96117	2020-07-14 11:39:12	2020-07-14	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	26504	delivery	5	31
96118	2020-07-14 11:42:29	2020-07-14	14	[{"id_menu":2,"count":1}]	37298	delivery	5	19
96119	2020-07-14 11:55:32	2020-07-14	9	[{"id_menu":7,"count":1}]	37273	delivery	5	14
96120	2020-07-14 11:56:11	2020-07-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	22587	delivery	5	22
96121	2020-07-14 12:04:23	2020-07-14	9	[{"id_menu":7,"count":1}]	24023	pick-up	0	9
96122	2020-07-14 12:05:36	2020-07-14	14	[{"id_menu":2,"count":1}]	7211	delivery	5	19
96123	2020-07-14 12:09:03	2020-07-14	9	[{"id_menu":6,"count":1}]	3349	pick-up	0	9
96124	2020-07-14 12:09:19	2020-07-14	9	[{"id_menu":6,"count":1}]	9069	delivery	5	14
96125	2020-07-14 12:22:55	2020-07-14	9	[{"id_menu":6,"count":1}]	35635	delivery	5	14
96126	2020-07-14 12:29:27	2020-07-14	9	[{"id_menu":6,"count":1}]	19360	delivery	5	14
96127	2020-07-14 12:33:26	2020-07-14	9	[{"id_menu":7,"count":1}]	21686	pick-up	0	9
96128	2020-07-14 12:35:44	2020-07-14	14	[{"id_menu":2,"count":1}]	14290	pick-up	0	14
96129	2020-07-14 12:38:28	2020-07-14	12	[{"id_menu":3,"count":1}]	4339	delivery	5	17
96130	2020-07-14 12:51:36	2020-07-14	14	[{"id_menu":2,"count":1}]	16084	delivery	5	19
96131	2020-07-14 12:52:01	2020-07-14	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	37340	delivery	5	36
96132	2020-07-14 12:56:28	2020-07-14	9	[{"id_menu":6,"count":2}]	11239	pick-up	0	9
96133	2020-07-14 12:56:31	2020-07-14	12	[{"id_menu":3,"count":1}]	8358	delivery	5	17
96134	2020-07-14 13:01:46	2020-07-14	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	33407	delivery	5	22
96135	2020-07-14 13:06:23	2020-07-14	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	21553	pick-up	0	41
96136	2020-07-14 13:08:40	2020-07-14	14	[{"id_menu":2,"count":1}]	13555	pick-up	0	14
96137	2020-07-14 13:09:09	2020-07-14	12	[{"id_menu":3,"count":1}]	33532	delivery	5	17
96138	2020-07-14 13:11:04	2020-07-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	15098	delivery	5	28
96139	2020-07-14 13:18:50	2020-07-14	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	37191	delivery	5	45
96140	2020-07-14 13:19:12	2020-07-14	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	37221	delivery	5	31
96141	2020-07-14 13:19:33	2020-07-14	14	[{"id_menu":2,"count":1}]	37211	delivery	5	19
96142	2020-07-14 13:20:10	2020-07-14	8	[{"id_menu":5,"count":1}]	2895	delivery	5	13
96143	2020-07-14 13:23:15	2020-07-14	9	[{"id_menu":6,"count":1}]	37253	delivery	5	14
96144	2020-07-14 13:26:35	2020-07-14	12	[{"id_menu":3,"count":1}]	3537	delivery	5	17
96145	2020-07-14 13:28:13	2020-07-14	9	[{"id_menu":7,"count":1}]	10142	pick-up	0	9
96146	2020-07-14 13:31:34	2020-07-14	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	17996	delivery	5	46
96147	2020-07-14 13:36:07	2020-07-14	8	[{"id_menu":5,"count":1}]	11215	delivery	5	13
96148	2020-07-14 13:36:25	2020-07-14	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	22602	delivery	5	26
96149	2020-07-14 13:38:33	2020-07-14	12	[{"id_menu":3,"count":1}]	31963	pick-up	0	12
96150	2020-07-14 13:47:38	2020-07-14	17	[{"id_menu":4,"count":1}]	37368	delivery	5	22
96151	2020-07-14 13:57:10	2020-07-14	9	[{"id_menu":7,"count":1}]	19466	delivery	5	14
96152	2020-07-14 14:00:14	2020-07-14	14	[{"id_menu":2,"count":1}]	16501	pick-up	0	14
96153	2020-07-14 14:00:17	2020-07-14	9	[{"id_menu":7,"count":1}]	37220	delivery	5	14
96154	2020-07-14 14:00:59	2020-07-14	8	[{"id_menu":5,"count":1}]	37227	delivery	5	13
96155	2020-07-14 14:03:26	2020-07-14	8	[{"id_menu":5,"count":1}]	13397	delivery	5	13
96156	2020-07-14 14:07:11	2020-07-14	12	[{"id_menu":3,"count":1}]	22266	delivery	5	17
96157	2020-07-14 14:12:29	2020-07-14	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	12281	delivery	5	34
96158	2020-07-14 14:14:27	2020-07-14	9	[{"id_menu":6,"count":2}]	3908	pick-up	0	9
96159	2020-07-14 14:19:45	2020-07-14	9	[{"id_menu":6,"count":1}]	9583	delivery	5	14
96160	2020-07-14 14:20:04	2020-07-14	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37259	delivery	5	35
96161	2020-07-14 14:26:10	2020-07-14	9	[{"id_menu":6,"count":1}]	37217	delivery	5	14
96162	2020-07-14 14:36:03	2020-07-14	9	[{"id_menu":7,"count":1}]	20567	delivery	5	14
96163	2020-07-14 14:36:56	2020-07-14	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	21850	delivery	5	23
96164	2020-07-14 14:37:20	2020-07-14	12	[{"id_menu":1,"count":1}]	5314	pick-up	0	12
96165	2020-07-14 14:40:47	2020-07-14	9	[{"id_menu":7,"count":1}]	10436	pick-up	0	9
96166	2020-07-14 14:45:13	2020-07-14	9	[{"id_menu":7,"count":1}]	37199	delivery	5	14
96167	2020-07-14 14:49:14	2020-07-14	9	[{"id_menu":7,"count":2}]	18803	delivery	5	14
96168	2020-07-14 14:51:00	2020-07-14	14	[{"id_menu":2,"count":1}]	3536	pick-up	0	14
96169	2020-07-14 14:51:17	2020-07-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	30651	pick-up	0	23
96170	2020-07-14 14:51:17	2020-07-14	17	[{"id_menu":4,"count":1}]	35961	delivery	5	22
96171	2020-07-14 14:51:28	2020-07-14	12	[{"id_menu":1,"count":1}]	3138	pick-up	0	12
96172	2020-07-14 14:55:57	2020-07-14	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	30073	delivery	5	28
96173	2020-07-14 14:56:28	2020-07-14	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	36072	delivery	5	43
96174	2020-07-14 15:02:38	2020-07-14	17	[{"id_menu":4,"count":1}]	37233	delivery	5	22
96175	2020-07-14 15:12:25	2020-07-14	14	[{"id_menu":2,"count":1}]	37263	delivery	5	19
96176	2020-07-14 15:15:00	2020-07-14	9	[{"id_menu":6,"count":1}]	13673	delivery	5	14
96177	2020-07-14 15:19:57	2020-07-14	12	[{"id_menu":1,"count":1}]	23432	pick-up	0	12
96178	2020-07-14 15:25:52	2020-07-14	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	37372	delivery	5	26
96179	2020-07-14 15:29:25	2020-07-14	9	[{"id_menu":7,"count":1}]	6717	delivery	5	14
96180	2020-07-14 15:30:14	2020-07-14	8	[{"id_menu":5,"count":3}]	37323	delivery	5	13
96181	2020-07-14 15:30:45	2020-07-14	14	[{"id_menu":2,"count":1}]	18332	delivery	5	19
96182	2020-07-14 15:39:47	2020-07-14	9	[{"id_menu":6,"count":1}]	37367	delivery	5	14
96183	2020-07-14 15:40:02	2020-07-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	37234	delivery	5	22
96184	2020-07-14 15:41:29	2020-07-14	17	[{"id_menu":4,"count":1}]	2113	delivery	5	22
96185	2020-07-14 15:41:36	2020-07-14	17	[{"id_menu":4,"count":1}]	29702	delivery	5	22
96186	2020-07-14 15:42:49	2020-07-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6228	delivery	5	36
96187	2020-07-14 15:45:33	2020-07-14	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	390	pick-up	0	20
96188	2020-07-14 15:45:44	2020-07-14	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	33299	delivery	5	25
96189	2020-07-14 15:47:55	2020-07-14	12	[{"id_menu":1,"count":1}]	25054	delivery	5	17
96190	2020-07-14 15:55:15	2020-07-14	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37189	delivery	5	31
96191	2020-07-14 15:56:35	2020-07-14	9	[{"id_menu":6,"count":1}]	32809	delivery	5	14
96192	2020-07-14 15:57:22	2020-07-14	14	[{"id_menu":2,"count":1}]	37307	delivery	5	19
96193	2020-07-14 15:58:22	2020-07-14	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	37207	pick-up	0	29
96194	2020-07-14 16:01:04	2020-07-14	17	[{"id_menu":4,"count":1}]	37333	delivery	5	22
96195	2020-07-14 16:01:43	2020-07-14	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	13987	delivery	5	31
96196	2020-07-14 16:06:30	2020-07-14	12	[{"id_menu":1,"count":1}]	37244	delivery	5	17
96197	2020-07-14 16:11:04	2020-07-14	9	[{"id_menu":6,"count":1}]	22613	delivery	5	14
96198	2020-07-14 16:11:07	2020-07-14	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29754	delivery	5	52
96199	2020-07-14 16:11:25	2020-07-14	12	[{"id_menu":3,"count":1}]	37314	delivery	5	17
96200	2020-07-14 16:18:59	2020-07-14	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	11187	delivery	5	34
96201	2020-07-14 16:23:09	2020-07-14	9	[{"id_menu":6,"count":2}]	35969	delivery	5	14
96202	2020-07-14 16:23:13	2020-07-14	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	35016	pick-up	0	29
96203	2020-07-14 16:24:33	2020-07-14	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	7205	pick-up	0	21
96204	2020-07-14 16:29:47	2020-07-14	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	32595	delivery	5	36
96205	2020-07-14 16:31:01	2020-07-14	9	[{"id_menu":6,"count":1}]	18153	delivery	5	14
96206	2020-07-14 16:31:53	2020-07-14	9	[{"id_menu":6,"count":1}]	6429	delivery	5	14
96207	2020-07-14 16:34:29	2020-07-14	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18833	delivery	5	40
96208	2020-07-14 16:34:40	2020-07-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	31653	delivery	5	28
96209	2020-07-14 16:42:38	2020-07-14	14	[{"id_menu":2,"count":1}]	12792	delivery	5	19
96210	2020-07-14 16:44:07	2020-07-14	12	[{"id_menu":1,"count":1}]	19670	delivery	5	17
96211	2020-07-14 16:44:52	2020-07-14	12	[{"id_menu":3,"count":1}]	37187	pick-up	0	12
96212	2020-07-14 16:51:09	2020-07-14	9	[{"id_menu":7,"count":1}]	9420	delivery	5	14
96213	2020-07-14 16:56:03	2020-07-14	17	[{"id_menu":4,"count":1}]	615	pick-up	0	17
96214	2020-07-14 16:57:40	2020-07-14	12	[{"id_menu":3,"count":1}]	8561	delivery	5	17
96215	2020-07-14 17:00:18	2020-07-14	8	[{"id_menu":5,"count":2}]	22355	delivery	5	13
96216	2020-07-14 17:06:32	2020-07-14	12	[{"id_menu":3,"count":1}]	28489	delivery	5	17
96217	2020-07-14 17:06:46	2020-07-14	14	[{"id_menu":2,"count":1}]	7182	pick-up	0	14
96218	2020-07-14 17:10:39	2020-07-14	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	11636	delivery	5	22
96219	2020-07-14 17:12:00	2020-07-14	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	37245	delivery	5	26
96220	2020-07-14 17:12:12	2020-07-14	8	[{"id_menu":5,"count":1}]	9041	delivery	5	13
96221	2020-07-14 17:12:13	2020-07-14	9	[{"id_menu":7,"count":1}]	13188	delivery	5	14
96222	2020-07-14 17:13:11	2020-07-14	14	[{"id_menu":2,"count":1}]	1819	pick-up	0	14
96223	2020-07-14 17:15:45	2020-07-14	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	14127	pick-up	0	20
96224	2020-07-14 17:15:53	2020-07-14	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6975	delivery	5	22
96225	2020-07-14 17:17:02	2020-07-14	12	[{"id_menu":1,"count":1}]	33446	pick-up	0	12
96226	2020-07-14 17:18:50	2020-07-14	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	15616	delivery	5	36
96227	2020-07-14 17:19:02	2020-07-14	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	13026	pick-up	0	22
96228	2020-07-14 17:22:56	2020-07-14	8	[{"id_menu":5,"count":1}]	30555	delivery	5	13
96229	2020-07-14 17:25:14	2020-07-14	9	[{"id_menu":7,"count":1}]	37324	delivery	5	14
96230	2020-07-14 17:31:38	2020-07-14	9	[{"id_menu":6,"count":1}]	5479	delivery	5	14
96231	2020-07-14 17:33:59	2020-07-14	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	34038	delivery	5	45
96232	2020-07-14 17:35:59	2020-07-14	12	[{"id_menu":1,"count":1}]	9830	pick-up	0	12
96233	2020-07-14 17:36:54	2020-07-14	12	[{"id_menu":3,"count":1}]	37309	delivery	5	17
96234	2020-07-14 17:38:19	2020-07-14	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":3}]	23867	delivery	5	34
96235	2020-07-14 17:39:11	2020-07-14	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17829	delivery	5	31
96236	2020-07-14 17:40:16	2020-07-14	9	[{"id_menu":6,"count":1}]	22369	delivery	5	14
96237	2020-07-14 17:48:23	2020-07-14	14	[{"id_menu":2,"count":1}]	37305	pick-up	0	14
96238	2020-07-14 17:49:14	2020-07-14	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	35561	delivery	5	37
96239	2020-07-14 17:51:34	2020-07-14	17	[{"id_menu":4,"count":1}]	20549	pick-up	0	17
96240	2020-07-14 18:07:05	2020-07-14	9	[{"id_menu":6,"count":1}]	12169	delivery	5	14
96241	2020-07-14 18:07:46	2020-07-14	9	[{"id_menu":6,"count":1}]	37257	delivery	5	14
96242	2020-07-14 18:09:40	2020-07-14	17	[{"id_menu":4,"count":1}]	14095	delivery	5	22
96243	2020-07-14 18:12:19	2020-07-14	17	[{"id_menu":4,"count":1}]	4929	pick-up	0	17
96244	2020-07-14 18:14:01	2020-07-14	14	[{"id_menu":2,"count":1}]	15720	pick-up	0	14
96245	2020-07-14 18:17:15	2020-07-14	17	[{"id_menu":4,"count":2}]	37299	pick-up	0	17
96246	2020-07-14 18:30:41	2020-07-14	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	33909	delivery	5	39
96247	2020-07-14 18:32:37	2020-07-14	14	[{"id_menu":2,"count":1}]	21698	delivery	5	19
96248	2020-07-14 18:37:28	2020-07-14	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	17014	delivery	5	26
96249	2020-07-14 18:42:36	2020-07-14	12	[{"id_menu":1,"count":1}]	18409	pick-up	0	12
96250	2020-07-14 18:47:25	2020-07-14	12	[{"id_menu":1,"count":1}]	35790	delivery	5	17
96251	2020-07-14 18:54:25	2020-07-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	13455	delivery	5	31
96252	2020-07-14 18:58:40	2020-07-14	9	[{"id_menu":7,"count":1}]	37302	delivery	5	14
96253	2020-07-14 19:00:02	2020-07-14	9	[{"id_menu":6,"count":1}]	6008	delivery	5	14
96254	2020-07-14 19:03:41	2020-07-14	17	[{"id_menu":4,"count":1}]	37362	delivery	5	22
96255	2020-07-14 19:07:02	2020-07-14	14	[{"id_menu":2,"count":1}]	36957	pick-up	0	14
96256	2020-07-14 19:14:30	2020-07-14	9	[{"id_menu":6,"count":1}]	1864	pick-up	0	9
96257	2020-07-14 19:15:47	2020-07-14	9	[{"id_menu":7,"count":1}]	21447	delivery	5	14
96258	2020-07-14 19:15:58	2020-07-14	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	20697	delivery	5	57
96259	2020-07-14 19:16:40	2020-07-14	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	22971	delivery	5	28
96260	2020-07-14 19:18:05	2020-07-14	8	[{"id_menu":5,"count":1}]	37210	delivery	5	13
96261	2020-07-14 19:21:32	2020-07-14	17	[{"id_menu":4,"count":1}]	37270	delivery	5	22
96262	2020-07-14 19:21:57	2020-07-14	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	37360	pick-up	0	29
96263	2020-07-14 19:23:24	2020-07-14	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	27530	pick-up	0	31
96264	2020-07-14 19:23:59	2020-07-14	9	[{"id_menu":7,"count":1}]	17710	delivery	5	14
96265	2020-07-14 19:33:39	2020-07-14	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	15566	pick-up	0	25
96266	2020-07-14 19:34:49	2020-07-14	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	6650	delivery	5	31
96267	2020-07-14 19:37:04	2020-07-14	12	[{"id_menu":1,"count":1}]	33096	delivery	5	17
96268	2020-07-14 19:47:37	2020-07-14	12	[{"id_menu":1,"count":1}]	27565	delivery	5	17
96269	2020-07-14 19:47:55	2020-07-14	9	[{"id_menu":7,"count":1}]	4920	pick-up	0	9
96270	2020-07-14 19:51:17	2020-07-14	14	[{"id_menu":2,"count":1}]	3066	pick-up	0	14
96271	2020-07-14 19:51:50	2020-07-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	37364	delivery	5	22
96272	2020-07-14 19:53:45	2020-07-14	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	37239	delivery	5	45
96273	2020-07-14 19:54:55	2020-07-14	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	37325	delivery	5	28
96274	2020-07-14 20:01:16	2020-07-14	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	37242	delivery	5	26
96275	2020-07-14 20:04:32	2020-07-14	12	[{"id_menu":3,"count":1}]	2876	delivery	5	17
96276	2020-07-14 20:04:59	2020-07-14	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	10662	delivery	5	39
96277	2020-07-14 20:08:14	2020-07-14	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1186	delivery	5	36
96278	2020-07-14 20:10:48	2020-07-14	14	[{"id_menu":2,"count":1}]	37202	delivery	5	19
96279	2020-07-14 20:11:20	2020-07-14	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	34758	delivery	5	39
96280	2020-07-14 20:18:41	2020-07-14	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	30668	delivery	5	40
96281	2020-07-14 20:27:47	2020-07-14	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	37363	delivery	5	26
96282	2020-07-14 20:27:53	2020-07-14	14	[{"id_menu":2,"count":1}]	37322	delivery	5	19
96283	2020-07-14 20:27:58	2020-07-14	12	[{"id_menu":3,"count":1}]	8793	delivery	5	17
96284	2020-07-14 20:32:05	2020-07-14	8	[{"id_menu":5,"count":1}]	497	pick-up	0	8
96285	2020-07-14 20:34:40	2020-07-14	8	[{"id_menu":5,"count":1}]	37341	delivery	5	13
96286	2020-07-14 20:40:29	2020-07-14	12	[{"id_menu":3,"count":1}]	10525	pick-up	0	12
96287	2020-07-14 20:41:38	2020-07-14	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	21461	delivery	5	43
96288	2020-07-14 20:42:43	2020-07-14	17	[{"id_menu":4,"count":1}]	9060	delivery	5	22
96289	2020-07-14 20:48:33	2020-07-14	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1101	delivery	5	31
96290	2020-07-14 20:48:39	2020-07-14	12	[{"id_menu":3,"count":1}]	5338	delivery	5	17
96291	2020-07-14 20:52:47	2020-07-14	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	37313	delivery	5	57
96292	2020-07-14 20:57:14	2020-07-14	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	23845	delivery	5	23
96293	2020-07-14 20:58:27	2020-07-14	9	[{"id_menu":6,"count":1}]	4072	delivery	5	14
96294	2020-07-14 21:11:10	2020-07-14	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	37269	delivery	5	36
96295	2020-07-14 21:13:16	2020-07-14	14	[{"id_menu":2,"count":1}]	13088	delivery	5	19
96296	2020-07-14 21:14:04	2020-07-14	8	[{"id_menu":5,"count":1}]	21617	pick-up	0	8
96297	2020-07-14 21:25:42	2020-07-14	9	[{"id_menu":7,"count":1}]	28119	delivery	5	14
96298	2020-07-14 21:28:08	2020-07-14	14	[{"id_menu":2,"count":1}]	3123	pick-up	0	14
96299	2020-07-14 21:28:50	2020-07-14	12	[{"id_menu":1,"count":1}]	37327	delivery	5	17
96300	2020-07-14 21:33:21	2020-07-14	8	[{"id_menu":5,"count":1}]	22928	delivery	5	13
96301	2020-07-14 21:35:32	2020-07-14	9	[{"id_menu":7,"count":1}]	15369	delivery	5	14
96302	2020-07-14 21:35:41	2020-07-14	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5300	pick-up	0	29
96303	2020-07-14 21:39:25	2020-07-14	17	[{"id_menu":4,"count":1}]	6987	delivery	5	22
96304	2020-07-14 21:42:04	2020-07-14	17	[{"id_menu":4,"count":1}]	34242	pick-up	0	17
96305	2020-07-14 21:43:55	2020-07-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7407	delivery	5	36
96306	2020-07-14 21:44:13	2020-07-14	9	[{"id_menu":7,"count":1}]	12022	delivery	5	14
96307	2020-07-14 21:47:18	2020-07-14	12	[{"id_menu":3,"count":1}]	31555	delivery	5	17
96308	2020-07-14 21:49:47	2020-07-14	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	14451	pick-up	0	21
96309	2020-07-14 21:52:23	2020-07-14	14	[{"id_menu":2,"count":1}]	26095	delivery	5	19
96310	2020-07-14 21:52:47	2020-07-14	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	34258	delivery	5	40
96311	2020-07-14 21:55:26	2020-07-14	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	25353	pick-up	0	17
96312	2020-07-14 21:56:22	2020-07-14	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	37235	delivery	5	40
96313	2020-07-14 21:58:09	2020-07-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	32787	delivery	5	31
96314	2020-07-14 22:03:03	2020-07-14	8	[{"id_menu":5,"count":1}]	24453	delivery	5	13
96315	2020-07-14 22:05:20	2020-07-14	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	7186	pick-up	0	26
96316	2020-07-14 22:16:25	2020-07-14	12	[{"id_menu":3,"count":1}]	19504	delivery	5	17
96317	2020-07-14 22:16:28	2020-07-14	8	[{"id_menu":5,"count":1}]	37288	delivery	5	13
96318	2020-07-14 22:20:19	2020-07-14	14	[{"id_menu":2,"count":1}]	37228	delivery	5	19
96319	2020-07-14 22:24:23	2020-07-14	12	[{"id_menu":1,"count":1}]	37352	delivery	5	17
96320	2020-07-14 22:28:27	2020-07-14	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12392	delivery	5	39
96321	2020-07-14 22:34:24	2020-07-14	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	37285	delivery	5	31
96322	2020-07-14 22:34:44	2020-07-14	9	[{"id_menu":6,"count":1}]	34741	delivery	5	14
96323	2020-07-14 22:37:50	2020-07-14	8	[{"id_menu":5,"count":1}]	37354	delivery	5	13
96324	2020-07-14 22:38:18	2020-07-14	17	[{"id_menu":4,"count":1}]	16166	delivery	5	22
96325	2020-07-14 22:39:26	2020-07-14	14	[{"id_menu":2,"count":1}]	37350	delivery	5	19
96326	2020-07-14 22:40:55	2020-07-14	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	29320	delivery	5	34
96327	2020-07-14 22:42:36	2020-07-14	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	8424	delivery	5	31
96328	2020-07-14 22:44:10	2020-07-14	12	[{"id_menu":1,"count":1}]	22960	pick-up	0	12
96329	2020-07-14 22:46:03	2020-07-14	9	[{"id_menu":7,"count":1}]	324	pick-up	0	9
96330	2020-07-14 22:48:20	2020-07-14	8	[{"id_menu":5,"count":1}]	37296	delivery	5	13
96331	2020-07-14 22:52:34	2020-07-14	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7234	delivery	5	28
96332	2020-07-14 22:52:44	2020-07-14	9	[{"id_menu":6,"count":1}]	21014	delivery	5	14
96333	2020-07-14 22:58:02	2020-07-14	9	[{"id_menu":7,"count":1}]	11380	pick-up	0	9
96334	2020-07-14 22:58:49	2020-07-14	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9254	delivery	5	34
96335	2020-07-14 22:59:15	2020-07-14	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	37317	delivery	5	34
96336	2020-07-14 23:01:43	2020-07-14	9	[{"id_menu":6,"count":1}]	9706	pick-up	0	9
96337	2020-07-14 23:03:12	2020-07-14	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	26292	delivery	5	35
96338	2020-07-14 23:08:11	2020-07-14	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	16567	delivery	5	30
96339	2020-07-14 23:08:49	2020-07-14	9	[{"id_menu":7,"count":1}]	1185	delivery	5	14
96340	2020-07-14 23:12:10	2020-07-14	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	15614	delivery	5	27
96341	2020-07-14 23:12:41	2020-07-14	8	[{"id_menu":5,"count":1}]	28108	delivery	5	13
96342	2020-07-14 23:17:10	2020-07-14	8	[{"id_menu":5,"count":1}]	5149	pick-up	0	8
96343	2020-07-14 23:18:53	2020-07-14	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1115	pick-up	0	35
96344	2020-07-14 23:19:12	2020-07-14	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	37356	delivery	5	26
96345	2020-07-14 23:19:31	2020-07-14	9	[{"id_menu":6,"count":2}]	37252	delivery	5	14
96346	2020-07-14 23:20:50	2020-07-14	17	[{"id_menu":4,"count":1}]	23253	pick-up	0	17
96347	2020-07-14 23:25:08	2020-07-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	37316	pick-up	0	31
96348	2020-07-14 23:25:46	2020-07-14	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	24413	delivery	5	26
96349	2020-07-14 23:30:19	2020-07-14	17	[{"id_menu":4,"count":1}]	7431	delivery	5	22
96350	2020-07-14 23:31:13	2020-07-14	9	[{"id_menu":6,"count":1}]	3949	delivery	5	14
96351	2020-07-14 23:38:45	2020-07-14	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	22965	pick-up	0	24
96352	2020-07-14 23:41:18	2020-07-14	9	[{"id_menu":6,"count":1}]	7226	delivery	5	14
96353	2020-07-14 23:43:24	2020-07-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2633	pick-up	0	31
96354	2020-07-14 23:45:30	2020-07-14	14	[{"id_menu":2,"count":1}]	22788	delivery	5	19
96355	2020-07-14 23:59:26	2020-07-14	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14025	delivery	5	48
96356	2020-07-15 00:01:00	2020-07-15	12	[{"id_menu":3,"count":1}]	845	pick-up	0	12
96357	2020-07-15 00:07:37	2020-07-15	14	[{"id_menu":2,"count":1}]	3534	delivery	5	19
96358	2020-07-15 00:08:48	2020-07-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	13920	pick-up	0	23
96359	2020-07-15 00:09:28	2020-07-15	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	24725	pick-up	0	21
96360	2020-07-15 00:12:18	2020-07-15	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	35782	delivery	5	27
96361	2020-07-15 00:13:10	2020-07-15	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	19013	delivery	5	26
96362	2020-07-15 00:14:55	2020-07-15	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	36869	delivery	5	57
96363	2020-07-15 00:14:56	2020-07-15	12	[{"id_menu":1,"count":1}]	3592	delivery	5	17
96364	2020-07-15 00:15:28	2020-07-15	17	[{"id_menu":4,"count":1}]	37500	delivery	5	22
96365	2020-07-15 00:17:07	2020-07-15	9	[{"id_menu":7,"count":1}]	37578	delivery	5	14
96366	2020-07-15 00:20:32	2020-07-15	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	17857	delivery	5	26
96367	2020-07-15 00:20:34	2020-07-15	14	[{"id_menu":2,"count":1}]	27916	delivery	5	19
96368	2020-07-15 00:25:42	2020-07-15	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17825	delivery	5	53
96369	2020-07-15 00:26:45	2020-07-15	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20097	delivery	5	36
96370	2020-07-15 00:28:58	2020-07-15	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	13994	delivery	5	26
96371	2020-07-15 00:31:39	2020-07-15	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11683	delivery	5	47
96372	2020-07-15 00:35:24	2020-07-15	14	[{"id_menu":2,"count":1}]	37518	delivery	5	19
96373	2020-07-15 00:39:36	2020-07-15	17	[{"id_menu":4,"count":1}]	37543	pick-up	0	17
96374	2020-07-15 00:42:24	2020-07-15	14	[{"id_menu":2,"count":1}]	29823	pick-up	0	14
96375	2020-07-15 00:44:35	2020-07-15	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37457	delivery	5	54
96376	2020-07-15 00:46:27	2020-07-15	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10820	delivery	5	45
96377	2020-07-15 00:49:04	2020-07-15	38	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	27130	delivery	5	43
96378	2020-07-15 00:58:59	2020-07-15	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	26045	delivery	5	28
96379	2020-07-15 00:59:17	2020-07-15	17	[{"id_menu":4,"count":1}]	37515	delivery	5	22
96380	2020-07-15 01:03:40	2020-07-15	9	[{"id_menu":6,"count":1}]	37477	delivery	5	14
96381	2020-07-15 01:03:49	2020-07-15	9	[{"id_menu":6,"count":1}]	744	pick-up	0	9
96382	2020-07-15 01:05:56	2020-07-15	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	36041	delivery	5	44
96383	2020-07-15 01:07:09	2020-07-15	14	[{"id_menu":2,"count":1}]	4043	delivery	5	19
96384	2020-07-15 01:09:22	2020-07-15	8	[{"id_menu":5,"count":2}]	5466	delivery	5	13
96385	2020-07-15 01:09:57	2020-07-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	20492	delivery	5	31
96386	2020-07-15 01:10:51	2020-07-15	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	37551	delivery	5	31
96387	2020-07-15 01:13:55	2020-07-15	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	5914	delivery	5	26
96388	2020-07-15 01:16:53	2020-07-15	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	37495	delivery	5	38
96389	2020-07-15 01:17:52	2020-07-15	8	[{"id_menu":5,"count":2}]	26228	pick-up	0	8
96390	2020-07-15 01:18:05	2020-07-15	17	[{"id_menu":4,"count":1}]	23272	pick-up	0	17
96391	2020-07-15 01:20:13	2020-07-15	8	[{"id_menu":5,"count":1}]	37196	delivery	5	13
96392	2020-07-15 01:20:19	2020-07-15	12	[{"id_menu":1,"count":1}]	37350	delivery	5	17
96393	2020-07-15 01:30:52	2020-07-15	9	[{"id_menu":7,"count":1}]	24644	delivery	5	14
96394	2020-07-15 01:31:59	2020-07-15	14	[{"id_menu":2,"count":1}]	15911	delivery	5	19
96395	2020-07-15 01:34:00	2020-07-15	9	[{"id_menu":7,"count":1}]	36813	delivery	5	14
96396	2020-07-15 01:36:52	2020-07-15	14	[{"id_menu":2,"count":1}]	547	delivery	5	19
96397	2020-07-15 01:38:01	2020-07-15	9	[{"id_menu":6,"count":1}]	31657	delivery	5	14
96398	2020-07-15 01:39:38	2020-07-15	9	[{"id_menu":6,"count":1}]	22834	delivery	5	14
96399	2020-07-15 01:43:06	2020-07-15	12	[{"id_menu":3,"count":1}]	7806	pick-up	0	12
96400	2020-07-15 01:43:23	2020-07-15	12	[{"id_menu":3,"count":1}]	20496	delivery	5	17
96401	2020-07-15 01:43:57	2020-07-15	9	[{"id_menu":6,"count":1}]	1754	pick-up	0	9
96402	2020-07-15 01:46:22	2020-07-15	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17667	delivery	5	51
96403	2020-07-15 01:49:22	2020-07-15	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	37485	delivery	5	39
96404	2020-07-15 01:50:06	2020-07-15	17	[{"id_menu":4,"count":1}]	4116	delivery	5	22
96405	2020-07-15 01:52:53	2020-07-15	12	[{"id_menu":1,"count":1}]	37491	delivery	5	17
96406	2020-07-15 01:59:15	2020-07-15	12	[{"id_menu":3,"count":1}]	21038	delivery	5	17
96407	2020-07-15 02:02:48	2020-07-15	9	[{"id_menu":6,"count":1}]	22438	delivery	5	14
96408	2020-07-15 02:03:48	2020-07-15	9	[{"id_menu":6,"count":1}]	10524	delivery	5	14
96409	2020-07-15 02:05:51	2020-07-15	9	[{"id_menu":7,"count":1}]	16507	delivery	5	14
96410	2020-07-15 02:07:57	2020-07-15	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	563	delivery	5	40
96411	2020-07-15 02:13:44	2020-07-15	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33949	delivery	5	40
96412	2020-07-15 02:15:35	2020-07-15	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	34068	delivery	5	43
96413	2020-07-15 02:21:41	2020-07-15	9	[{"id_menu":6,"count":1}]	26553	delivery	5	14
96414	2020-07-15 02:24:36	2020-07-15	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	37589	delivery	5	26
96415	2020-07-15 02:30:17	2020-07-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3450	delivery	5	31
96416	2020-07-15 02:32:12	2020-07-15	8	[{"id_menu":5,"count":1}]	2238	pick-up	0	8
96417	2020-07-15 02:34:25	2020-07-15	12	[{"id_menu":1,"count":2}]	10855	pick-up	0	12
96418	2020-07-15 02:34:49	2020-07-15	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	37537	delivery	5	25
96419	2020-07-15 02:42:58	2020-07-15	17	[{"id_menu":4,"count":2}]	37460	delivery	5	22
96420	2020-07-15 02:52:44	2020-07-15	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	37422	delivery	5	43
96421	2020-07-15 02:55:54	2020-07-15	9	[{"id_menu":6,"count":1}]	737	pick-up	0	9
96422	2020-07-15 02:57:20	2020-07-15	14	[{"id_menu":2,"count":1}]	1125	pick-up	0	14
96423	2020-07-15 03:01:53	2020-07-15	9	[{"id_menu":7,"count":1}]	37176	pick-up	0	9
96491	2020-07-15 05:28:30	2020-07-15	9	[{"id_menu":6,"count":1}]	37433	delivery	5	14
96424	2020-07-15 03:02:55	2020-07-15	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	29395	delivery	5	42
96425	2020-07-15 03:06:21	2020-07-15	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	8084	delivery	5	28
96426	2020-07-15 03:09:44	2020-07-15	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	37510	delivery	5	25
96427	2020-07-15 03:09:57	2020-07-15	8	[{"id_menu":5,"count":1}]	37465	delivery	5	13
96428	2020-07-15 03:11:04	2020-07-15	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	14487	pick-up	0	26
96429	2020-07-15 03:15:16	2020-07-15	9	[{"id_menu":7,"count":1}]	33226	delivery	5	14
96430	2020-07-15 03:16:58	2020-07-15	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19229	delivery	5	40
96431	2020-07-15 03:18:03	2020-07-15	8	[{"id_menu":5,"count":1}]	13010	delivery	5	13
96432	2020-07-15 03:19:14	2020-07-15	9	[{"id_menu":6,"count":1}]	26630	delivery	5	14
96433	2020-07-15 03:19:37	2020-07-15	12	[{"id_menu":1,"count":1}]	37514	delivery	5	17
96434	2020-07-15 03:21:16	2020-07-15	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	37467	delivery	5	36
96435	2020-07-15 03:23:42	2020-07-15	17	[{"id_menu":4,"count":1}]	29651	delivery	5	22
96436	2020-07-15 03:24:15	2020-07-15	9	[{"id_menu":6,"count":1}]	23782	delivery	5	14
96437	2020-07-15 03:25:24	2020-07-15	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	730	pick-up	0	21
96438	2020-07-15 03:25:42	2020-07-15	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	7704	delivery	5	31
96439	2020-07-15 03:26:41	2020-07-15	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	37436	delivery	5	23
96440	2020-07-15 03:26:47	2020-07-15	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	37415	delivery	5	39
96441	2020-07-15 03:27:59	2020-07-15	9	[{"id_menu":7,"count":1}]	17743	delivery	5	14
96442	2020-07-15 03:31:04	2020-07-15	12	[{"id_menu":1,"count":1}]	37499	delivery	5	17
96443	2020-07-15 03:35:42	2020-07-15	17	[{"id_menu":4,"count":1}]	4298	delivery	5	22
96444	2020-07-15 03:36:33	2020-07-15	12	[{"id_menu":1,"count":1}]	27488	pick-up	0	12
96445	2020-07-15 03:38:21	2020-07-15	12	[{"id_menu":1,"count":1}]	16322	delivery	5	17
96446	2020-07-15 03:40:35	2020-07-15	17	[{"id_menu":4,"count":1}]	37388	delivery	5	22
96447	2020-07-15 03:42:18	2020-07-15	12	[{"id_menu":3,"count":1}]	20721	delivery	5	17
96448	2020-07-15 03:44:23	2020-07-15	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	37454	delivery	5	35
96449	2020-07-15 03:45:01	2020-07-15	9	[{"id_menu":6,"count":1}]	37084	pick-up	0	9
96450	2020-07-15 03:51:33	2020-07-15	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	5782	pick-up	0	20
96451	2020-07-15 03:56:45	2020-07-15	12	[{"id_menu":3,"count":1}]	37493	delivery	5	17
96452	2020-07-15 03:57:45	2020-07-15	12	[{"id_menu":1,"count":1}]	20196	delivery	5	17
96453	2020-07-15 03:59:06	2020-07-15	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	12924	delivery	5	31
96454	2020-07-15 03:59:50	2020-07-15	14	[{"id_menu":2,"count":1}]	18074	delivery	5	19
96455	2020-07-15 04:03:00	2020-07-15	12	[{"id_menu":3,"count":1}]	4205	delivery	5	17
96456	2020-07-15 04:03:29	2020-07-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	14214	delivery	5	28
96457	2020-07-15 04:06:11	2020-07-15	14	[{"id_menu":2,"count":1}]	37378	delivery	5	19
96458	2020-07-15 04:09:19	2020-07-15	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	8410	delivery	5	28
96459	2020-07-15 04:12:11	2020-07-15	8	[{"id_menu":5,"count":1}]	11899	delivery	5	13
96460	2020-07-15 04:12:36	2020-07-15	17	[{"id_menu":4,"count":1}]	35593	delivery	5	22
96461	2020-07-15 04:12:54	2020-07-15	12	[{"id_menu":1,"count":1}]	36337	pick-up	0	12
96462	2020-07-15 04:13:15	2020-07-15	12	[{"id_menu":3,"count":1}]	37466	delivery	5	17
96463	2020-07-15 04:13:35	2020-07-15	14	[{"id_menu":2,"count":1}]	25724	pick-up	0	14
96464	2020-07-15 04:15:39	2020-07-15	9	[{"id_menu":6,"count":1}]	35660	delivery	5	14
96465	2020-07-15 04:19:02	2020-07-15	9	[{"id_menu":6,"count":1}]	37395	delivery	5	14
96466	2020-07-15 04:19:45	2020-07-15	17	[{"id_menu":4,"count":1}]	15377	delivery	5	22
96467	2020-07-15 04:20:33	2020-07-15	9	[{"id_menu":6,"count":1}]	37277	delivery	5	14
96468	2020-07-15 04:21:19	2020-07-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8846	delivery	5	31
96469	2020-07-15 04:23:24	2020-07-15	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	19766	delivery	5	34
96470	2020-07-15 04:28:54	2020-07-15	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	9732	pick-up	0	38
96471	2020-07-15 04:30:48	2020-07-15	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16692	delivery	5	48
96472	2020-07-15 04:38:57	2020-07-15	12	[{"id_menu":3,"count":1}]	13477	delivery	5	17
96473	2020-07-15 04:39:17	2020-07-15	12	[{"id_menu":1,"count":1}]	28947	delivery	5	17
96474	2020-07-15 04:39:48	2020-07-15	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	31310	delivery	5	31
96475	2020-07-15 04:40:12	2020-07-15	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	37472	delivery	5	25
96476	2020-07-15 04:43:50	2020-07-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12701	delivery	5	23
96477	2020-07-15 04:47:45	2020-07-15	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	31255	pick-up	0	31
96478	2020-07-15 04:51:05	2020-07-15	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	37218	delivery	5	22
96479	2020-07-15 04:51:29	2020-07-15	9	[{"id_menu":6,"count":1}]	37573	delivery	5	14
96480	2020-07-15 04:55:32	2020-07-15	9	[{"id_menu":6,"count":1}]	21848	delivery	5	14
96481	2020-07-15 04:59:02	2020-07-15	41	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	37385	delivery	5	46
96482	2020-07-15 05:03:53	2020-07-15	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	29439	delivery	5	22
96483	2020-07-15 05:05:12	2020-07-15	9	[{"id_menu":6,"count":1}]	37579	delivery	5	14
96484	2020-07-15 05:06:07	2020-07-15	8	[{"id_menu":5,"count":1}]	37548	delivery	5	13
96485	2020-07-15 05:10:50	2020-07-15	17	[{"id_menu":4,"count":1}]	26034	delivery	5	22
96486	2020-07-15 05:11:33	2020-07-15	12	[{"id_menu":3,"count":1}]	33015	pick-up	0	12
96487	2020-07-15 05:16:47	2020-07-15	8	[{"id_menu":5,"count":1}]	26208	pick-up	0	8
96488	2020-07-15 05:18:28	2020-07-15	12	[{"id_menu":1,"count":1}]	5487	delivery	5	17
96489	2020-07-15 05:18:38	2020-07-15	17	[{"id_menu":4,"count":1}]	18927	delivery	5	22
96490	2020-07-15 05:18:52	2020-07-15	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	23352	pick-up	0	31
96492	2020-07-15 05:29:32	2020-07-15	8	[{"id_menu":5,"count":1}]	23829	delivery	5	13
96493	2020-07-15 05:33:37	2020-07-15	12	[{"id_menu":3,"count":1}]	37434	delivery	5	17
96494	2020-07-15 05:33:46	2020-07-15	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	34195	delivery	5	48
96495	2020-07-15 05:34:56	2020-07-15	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	29038	delivery	5	40
96496	2020-07-15 05:42:53	2020-07-15	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	22369	delivery	5	40
96497	2020-07-15 05:45:22	2020-07-15	12	[{"id_menu":1,"count":1}]	21352	pick-up	0	12
96498	2020-07-15 05:45:46	2020-07-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	37451	pick-up	0	26
96499	2020-07-15 05:45:54	2020-07-15	8	[{"id_menu":5,"count":1}]	37377	delivery	5	13
96500	2020-07-15 05:48:19	2020-07-15	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3126	delivery	5	45
96501	2020-07-15 05:48:43	2020-07-15	17	[{"id_menu":4,"count":1}]	10441	pick-up	0	17
96502	2020-07-15 05:51:36	2020-07-15	14	[{"id_menu":2,"count":1}]	29127	pick-up	0	14
96503	2020-07-15 05:51:53	2020-07-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	36695	delivery	5	31
96504	2020-07-15 05:52:19	2020-07-15	17	[{"id_menu":4,"count":1}]	2715	pick-up	0	17
96505	2020-07-15 05:52:27	2020-07-15	12	[{"id_menu":3,"count":1}]	37458	delivery	5	17
96506	2020-07-15 05:56:11	2020-07-15	12	[{"id_menu":3,"count":1}]	6894	delivery	5	17
96507	2020-07-15 05:59:09	2020-07-15	8	[{"id_menu":5,"count":1}]	37544	delivery	5	13
96508	2020-07-15 06:00:23	2020-07-15	12	[{"id_menu":1,"count":1}]	1511	pick-up	0	12
96509	2020-07-15 06:01:47	2020-07-15	8	[{"id_menu":5,"count":1}]	26487	delivery	5	13
96510	2020-07-15 06:01:56	2020-07-15	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	7633	delivery	5	27
96511	2020-07-15 06:02:58	2020-07-15	9	[{"id_menu":7,"count":2}]	27625	delivery	5	14
96512	2020-07-15 06:06:01	2020-07-15	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	5329	delivery	5	31
96513	2020-07-15 06:08:27	2020-07-15	8	[{"id_menu":5,"count":1}]	21456	pick-up	0	8
96514	2020-07-15 06:09:31	2020-07-15	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18787	delivery	5	22
96515	2020-07-15 06:16:43	2020-07-15	12	[{"id_menu":3,"count":1}]	2631	delivery	5	17
96516	2020-07-15 06:17:28	2020-07-15	14	[{"id_menu":2,"count":1}]	37556	delivery	5	19
96517	2020-07-15 06:18:12	2020-07-15	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18605	delivery	5	39
96518	2020-07-15 06:19:58	2020-07-15	9	[{"id_menu":6,"count":1}]	37497	delivery	5	14
96519	2020-07-15 06:20:37	2020-07-15	9	[{"id_menu":6,"count":1}]	32774	delivery	5	14
96520	2020-07-15 06:21:26	2020-07-15	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	9052	delivery	5	26
96521	2020-07-15 06:22:11	2020-07-15	8	[{"id_menu":5,"count":1}]	37437	delivery	5	13
96522	2020-07-15 06:23:09	2020-07-15	17	[{"id_menu":4,"count":1}]	32833	delivery	5	22
96523	2020-07-15 06:27:36	2020-07-15	9	[{"id_menu":6,"count":1}]	22321	delivery	5	14
96524	2020-07-15 06:32:22	2020-07-15	12	[{"id_menu":1,"count":1}]	23989	delivery	5	17
96525	2020-07-15 06:40:36	2020-07-15	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3323	delivery	5	48
96526	2020-07-15 06:44:39	2020-07-15	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	37386	delivery	5	34
96527	2020-07-15 06:52:58	2020-07-15	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16755	delivery	5	36
96528	2020-07-15 06:55:05	2020-07-15	14	[{"id_menu":2,"count":1}]	30304	delivery	5	19
96529	2020-07-15 06:59:13	2020-07-15	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20029	delivery	5	35
96530	2020-07-15 06:59:20	2020-07-15	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	7871	delivery	5	34
96531	2020-07-15 07:02:20	2020-07-15	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	37489	delivery	5	36
96532	2020-07-15 07:03:20	2020-07-15	8	[{"id_menu":5,"count":1}]	19504	pick-up	0	8
96533	2020-07-15 07:04:20	2020-07-15	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	37522	delivery	5	40
96534	2020-07-15 07:04:41	2020-07-15	9	[{"id_menu":6,"count":2}]	10315	delivery	5	14
96535	2020-07-15 07:08:04	2020-07-15	14	[{"id_menu":2,"count":1}]	37410	delivery	5	19
96536	2020-07-15 07:08:41	2020-07-15	9	[{"id_menu":6,"count":1}]	15406	delivery	5	14
96537	2020-07-15 07:11:52	2020-07-15	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29052	pick-up	0	30
96538	2020-07-15 07:13:17	2020-07-15	8	[{"id_menu":5,"count":1}]	3996	delivery	5	13
96539	2020-07-15 07:15:12	2020-07-15	8	[{"id_menu":5,"count":1}]	37577	delivery	5	13
96540	2020-07-15 07:20:20	2020-07-15	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37483	delivery	5	37
96541	2020-07-15 07:22:10	2020-07-15	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2609	pick-up	0	21
96542	2020-07-15 07:22:38	2020-07-15	9	[{"id_menu":6,"count":1}]	3563	delivery	5	14
96543	2020-07-15 07:22:43	2020-07-15	12	[{"id_menu":3,"count":1}]	2317	delivery	5	17
96544	2020-07-15 07:24:39	2020-07-15	9	[{"id_menu":6,"count":1}]	1929	pick-up	0	9
96545	2020-07-15 07:26:55	2020-07-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5292	pick-up	0	26
96546	2020-07-15 07:28:07	2020-07-15	8	[{"id_menu":5,"count":1}]	22670	pick-up	0	8
96547	2020-07-15 07:29:12	2020-07-15	14	[{"id_menu":2,"count":1}]	5009	delivery	5	19
96548	2020-07-15 07:29:46	2020-07-15	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	29762	delivery	5	23
96549	2020-07-15 07:30:48	2020-07-15	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	32447	delivery	5	22
96550	2020-07-15 07:31:43	2020-07-15	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	29946	delivery	5	25
96551	2020-07-15 07:31:50	2020-07-15	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	37503	delivery	5	26
96552	2020-07-15 07:32:54	2020-07-15	9	[{"id_menu":7,"count":1}]	26520	delivery	5	14
96553	2020-07-15 07:33:28	2020-07-15	12	[{"id_menu":1,"count":1}]	421	delivery	5	17
96554	2020-07-15 07:34:58	2020-07-15	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	37520	delivery	5	27
96555	2020-07-15 07:36:26	2020-07-15	8	[{"id_menu":5,"count":1}]	37504	delivery	5	13
96556	2020-07-15 07:42:38	2020-07-15	9	[{"id_menu":7,"count":2}]	37583	delivery	5	14
96557	2020-07-15 07:42:52	2020-07-15	12	[{"id_menu":1,"count":1}]	37431	delivery	5	17
96558	2020-07-15 07:43:49	2020-07-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	12398	delivery	5	28
96559	2020-07-15 07:44:49	2020-07-15	9	[{"id_menu":7,"count":1}]	32718	delivery	5	14
96560	2020-07-15 07:45:01	2020-07-15	8	[{"id_menu":5,"count":1}]	37432	delivery	5	13
96561	2020-07-15 07:47:52	2020-07-15	17	[{"id_menu":4,"count":1}]	5004	delivery	5	22
96562	2020-07-15 07:48:40	2020-07-15	9	[{"id_menu":7,"count":1}]	16459	delivery	5	14
96563	2020-07-15 07:51:22	2020-07-15	14	[{"id_menu":2,"count":1}]	8394	delivery	5	19
96564	2020-07-15 07:51:25	2020-07-15	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	5267	pick-up	0	26
96565	2020-07-15 07:51:45	2020-07-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	19062	delivery	5	23
96566	2020-07-15 07:51:49	2020-07-15	12	[{"id_menu":3,"count":1}]	25406	delivery	5	17
96567	2020-07-15 07:54:51	2020-07-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	27318	pick-up	0	23
96568	2020-07-15 07:59:19	2020-07-15	9	[{"id_menu":6,"count":1}]	1373	pick-up	0	9
96569	2020-07-15 08:00:08	2020-07-15	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	26268	delivery	5	26
96570	2020-07-15 08:00:29	2020-07-15	12	[{"id_menu":1,"count":1}]	25504	delivery	5	17
96571	2020-07-15 08:01:14	2020-07-15	17	[{"id_menu":4,"count":1}]	32513	delivery	5	22
96572	2020-07-15 08:04:16	2020-07-15	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12320	delivery	5	49
96573	2020-07-15 08:04:24	2020-07-15	12	[{"id_menu":3,"count":1}]	34972	pick-up	0	12
96574	2020-07-15 08:13:12	2020-07-15	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	37475	delivery	5	38
96575	2020-07-15 08:13:37	2020-07-15	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	35622	delivery	5	22
96576	2020-07-15 08:15:18	2020-07-15	14	[{"id_menu":2,"count":1}]	10495	delivery	5	19
96577	2020-07-15 08:15:37	2020-07-15	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	14722	pick-up	0	26
96578	2020-07-15 08:19:05	2020-07-15	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	37462	delivery	5	31
96579	2020-07-15 08:21:01	2020-07-15	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	37473	delivery	5	25
96580	2020-07-15 08:21:02	2020-07-15	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	37440	delivery	5	26
96581	2020-07-15 08:21:30	2020-07-15	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	37530	delivery	5	26
96582	2020-07-15 08:21:44	2020-07-15	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	15530	delivery	5	26
96583	2020-07-15 08:23:17	2020-07-15	9	[{"id_menu":6,"count":1}]	397	delivery	5	14
96584	2020-07-15 08:23:37	2020-07-15	8	[{"id_menu":5,"count":1}]	24771	delivery	5	13
96585	2020-07-15 08:25:16	2020-07-15	9	[{"id_menu":6,"count":1}]	16972	pick-up	0	9
96586	2020-07-15 08:36:43	2020-07-15	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7595	delivery	5	22
96587	2020-07-15 08:37:19	2020-07-15	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24033	delivery	5	35
96588	2020-07-15 08:39:41	2020-07-15	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	13847	delivery	5	37
96589	2020-07-15 08:40:56	2020-07-15	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13516	delivery	5	51
96590	2020-07-15 08:43:37	2020-07-15	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	21771	delivery	5	34
96591	2020-07-15 08:43:40	2020-07-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	37509	delivery	5	31
96592	2020-07-15 08:44:17	2020-07-15	12	[{"id_menu":3,"count":1}]	37443	delivery	5	17
96593	2020-07-15 08:45:40	2020-07-15	12	[{"id_menu":3,"count":1}]	37540	delivery	5	17
96594	2020-07-15 08:46:48	2020-07-15	9	[{"id_menu":6,"count":1}]	17681	delivery	5	14
96595	2020-07-15 08:48:36	2020-07-15	8	[{"id_menu":5,"count":2}]	1672	pick-up	0	8
96596	2020-07-15 08:48:42	2020-07-15	12	[{"id_menu":1,"count":1}]	8354	pick-up	0	12
96597	2020-07-15 08:50:26	2020-07-15	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	28874	delivery	5	26
96598	2020-07-15 08:50:30	2020-07-15	8	[{"id_menu":5,"count":1}]	12514	delivery	5	13
96599	2020-07-15 08:50:41	2020-07-15	8	[{"id_menu":5,"count":1}]	3687	delivery	5	13
96600	2020-07-15 08:53:02	2020-07-15	12	[{"id_menu":1,"count":1}]	37478	pick-up	0	12
96601	2020-07-15 08:57:21	2020-07-15	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	25278	delivery	5	34
96602	2020-07-15 08:57:26	2020-07-15	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	21000	delivery	5	26
96603	2020-07-15 08:58:39	2020-07-15	12	[{"id_menu":3,"count":1}]	708	pick-up	0	12
96604	2020-07-15 09:03:37	2020-07-15	9	[{"id_menu":6,"count":2}]	7709	delivery	5	14
96605	2020-07-15 09:07:30	2020-07-15	8	[{"id_menu":5,"count":1}]	37492	delivery	5	13
96606	2020-07-15 09:09:00	2020-07-15	12	[{"id_menu":3,"count":2}]	7084	pick-up	0	12
96607	2020-07-15 09:10:39	2020-07-15	12	[{"id_menu":1,"count":1}]	7280	delivery	5	17
96608	2020-07-15 09:12:33	2020-07-15	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	32009	delivery	5	25
96609	2020-07-15 09:12:47	2020-07-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	11749	delivery	5	28
96610	2020-07-15 09:13:13	2020-07-15	12	[{"id_menu":1,"count":1}]	37471	delivery	5	17
96611	2020-07-15 09:16:03	2020-07-15	8	[{"id_menu":5,"count":1}]	37487	delivery	5	13
96612	2020-07-15 09:17:33	2020-07-15	8	[{"id_menu":5,"count":1}]	35088	delivery	5	13
96613	2020-07-15 09:20:11	2020-07-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	37439	pick-up	0	23
96614	2020-07-15 09:32:05	2020-07-15	17	[{"id_menu":4,"count":2}]	7692	delivery	5	22
96615	2020-07-15 09:32:15	2020-07-15	9	[{"id_menu":7,"count":1}]	37382	delivery	5	14
96616	2020-07-15 09:35:06	2020-07-15	9	[{"id_menu":7,"count":1}]	6183	pick-up	0	9
96617	2020-07-15 09:37:47	2020-07-15	9	[{"id_menu":6,"count":1}]	9017	pick-up	0	9
96618	2020-07-15 09:40:05	2020-07-15	9	[{"id_menu":7,"count":3}]	28713	delivery	5	14
96619	2020-07-15 09:46:26	2020-07-15	9	[{"id_menu":7,"count":1}]	16030	delivery	5	14
96620	2020-07-15 09:50:25	2020-07-15	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18630	delivery	5	52
96621	2020-07-15 09:50:58	2020-07-15	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	37408	delivery	5	36
96622	2020-07-15 09:52:02	2020-07-15	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	37387	delivery	5	43
96623	2020-07-15 09:52:04	2020-07-15	14	[{"id_menu":2,"count":1}]	37380	delivery	5	19
96624	2020-07-15 09:52:20	2020-07-15	14	[{"id_menu":2,"count":2}]	4967	pick-up	0	14
96625	2020-07-15 09:54:32	2020-07-15	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	37476	delivery	5	26
96626	2020-07-15 09:59:33	2020-07-15	14	[{"id_menu":2,"count":1}]	7053	delivery	5	19
96627	2020-07-15 09:59:37	2020-07-15	14	[{"id_menu":2,"count":1}]	2151	pick-up	0	14
96628	2020-07-15 10:00:14	2020-07-15	9	[{"id_menu":7,"count":1}]	28107	delivery	5	14
96629	2020-07-15 10:01:50	2020-07-15	14	[{"id_menu":2,"count":1}]	37409	delivery	5	19
96630	2020-07-15 10:03:49	2020-07-15	9	[{"id_menu":7,"count":1}]	13964	delivery	5	14
96631	2020-07-15 10:11:43	2020-07-15	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2819	delivery	5	35
96632	2020-07-15 10:14:01	2020-07-15	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	37566	delivery	5	40
96633	2020-07-15 10:16:19	2020-07-15	14	[{"id_menu":2,"count":1}]	36896	delivery	5	19
96634	2020-07-15 10:29:07	2020-07-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	807	pick-up	0	23
96635	2020-07-15 10:29:55	2020-07-15	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	32811	delivery	5	28
96636	2020-07-15 10:30:24	2020-07-15	8	[{"id_menu":5,"count":1}]	29288	delivery	5	13
96637	2020-07-15 10:31:46	2020-07-15	9	[{"id_menu":7,"count":1}]	37557	delivery	5	14
96638	2020-07-15 10:32:46	2020-07-15	9	[{"id_menu":6,"count":1}]	6912	delivery	5	14
96639	2020-07-15 10:33:56	2020-07-15	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34509	delivery	5	37
96640	2020-07-15 10:34:32	2020-07-15	14	[{"id_menu":2,"count":1}]	12208	delivery	5	19
96641	2020-07-15 10:34:45	2020-07-15	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	37561	delivery	5	26
96642	2020-07-15 10:34:47	2020-07-15	8	[{"id_menu":5,"count":1}]	19739	delivery	5	13
96643	2020-07-15 10:37:21	2020-07-15	9	[{"id_menu":7,"count":1}]	10429	delivery	5	14
96644	2020-07-15 10:37:58	2020-07-15	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	21749	delivery	5	29
96645	2020-07-15 10:39:23	2020-07-15	14	[{"id_menu":2,"count":1}]	37447	delivery	5	19
96646	2020-07-15 10:40:07	2020-07-15	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6296	delivery	5	39
96647	2020-07-15 10:40:45	2020-07-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	37399	delivery	5	23
96648	2020-07-15 10:44:24	2020-07-15	14	[{"id_menu":2,"count":1}]	37516	delivery	5	19
96649	2020-07-15 10:47:38	2020-07-15	9	[{"id_menu":6,"count":1}]	37567	delivery	5	14
96650	2020-07-15 10:49:59	2020-07-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":3}]	35688	delivery	5	28
96651	2020-07-15 10:50:43	2020-07-15	9	[{"id_menu":6,"count":1}]	23613	delivery	5	14
96652	2020-07-15 10:53:15	2020-07-15	9	[{"id_menu":7,"count":1}]	37402	delivery	5	14
96653	2020-07-15 11:00:19	2020-07-15	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":2}]	2488	pick-up	0	31
96654	2020-07-15 11:06:50	2020-07-15	14	[{"id_menu":2,"count":1}]	35265	pick-up	0	14
96655	2020-07-15 11:07:38	2020-07-15	8	[{"id_menu":5,"count":1}]	18567	delivery	5	13
96656	2020-07-15 11:09:59	2020-07-15	8	[{"id_menu":5,"count":1}]	2716	pick-up	0	8
96657	2020-07-15 11:15:42	2020-07-15	8	[{"id_menu":5,"count":1}]	30903	delivery	5	13
96658	2020-07-15 11:16:50	2020-07-15	14	[{"id_menu":2,"count":1}]	26341	delivery	5	19
96659	2020-07-15 11:22:58	2020-07-15	9	[{"id_menu":7,"count":1}]	37456	delivery	5	14
96660	2020-07-15 11:24:25	2020-07-15	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	7984	delivery	5	26
96661	2020-07-15 11:25:01	2020-07-15	9	[{"id_menu":6,"count":2}]	30901	delivery	5	14
96662	2020-07-15 11:25:25	2020-07-15	8	[{"id_menu":5,"count":1}]	15189	delivery	5	13
96663	2020-07-15 11:32:05	2020-07-15	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	25003	delivery	5	26
96664	2020-07-15 11:34:21	2020-07-15	9	[{"id_menu":7,"count":1}]	10717	delivery	5	14
96665	2020-07-15 11:36:01	2020-07-15	9	[{"id_menu":7,"count":1}]	8324	delivery	5	14
96666	2020-07-15 11:36:27	2020-07-15	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37486	delivery	5	52
96667	2020-07-15 11:38:25	2020-07-15	9	[{"id_menu":6,"count":1}]	31142	delivery	5	14
96668	2020-07-15 11:38:25	2020-07-15	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	15407	delivery	5	26
96669	2020-07-15 11:38:33	2020-07-15	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37529	delivery	5	40
96670	2020-07-15 11:43:24	2020-07-15	14	[{"id_menu":2,"count":1}]	13193	pick-up	0	14
96671	2020-07-15 11:44:38	2020-07-15	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	37438	delivery	5	22
96672	2020-07-15 11:45:10	2020-07-15	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	37418	delivery	5	37
96673	2020-07-15 11:46:13	2020-07-15	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	37396	delivery	5	31
96674	2020-07-15 11:46:19	2020-07-15	12	[{"id_menu":3,"count":2}]	15556	delivery	5	17
96675	2020-07-15 11:46:42	2020-07-15	12	[{"id_menu":1,"count":1}]	36405	delivery	5	17
96676	2020-07-15 11:46:51	2020-07-15	12	[{"id_menu":1,"count":1}]	25254	pick-up	0	12
96677	2020-07-15 11:49:35	2020-07-15	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	4166	delivery	5	26
96678	2020-07-15 11:51:57	2020-07-15	12	[{"id_menu":1,"count":1}]	36547	pick-up	0	12
96679	2020-07-15 11:52:43	2020-07-15	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37381	delivery	5	35
96680	2020-07-15 11:53:26	2020-07-15	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	31647	delivery	5	39
96681	2020-07-15 11:53:42	2020-07-15	9	[{"id_menu":6,"count":1}]	13054	pick-up	0	9
96682	2020-07-15 11:56:46	2020-07-15	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21170	delivery	5	22
96683	2020-07-15 11:59:00	2020-07-15	14	[{"id_menu":2,"count":1}]	5050	delivery	5	19
96684	2020-07-15 12:02:19	2020-07-15	9	[{"id_menu":6,"count":1}]	14375	delivery	5	14
96685	2020-07-15 12:03:09	2020-07-15	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	8865	delivery	5	39
96686	2020-07-15 12:05:23	2020-07-15	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	29225	pick-up	0	20
96687	2020-07-15 12:05:31	2020-07-15	9	[{"id_menu":7,"count":1}]	23947	pick-up	0	9
96688	2020-07-15 12:05:33	2020-07-15	14	[{"id_menu":2,"count":1}]	37400	delivery	5	19
96689	2020-07-15 12:10:35	2020-07-15	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	21314	delivery	5	26
96690	2020-07-15 12:12:44	2020-07-15	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	37445	delivery	5	45
96691	2020-07-15 12:15:47	2020-07-15	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	32025	pick-up	0	35
96692	2020-07-15 12:20:08	2020-07-15	17	[{"id_menu":4,"count":1}]	35743	delivery	5	22
96693	2020-07-15 12:22:22	2020-07-15	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27673	delivery	5	39
96694	2020-07-15 12:23:31	2020-07-15	9	[{"id_menu":6,"count":1}]	14888	pick-up	0	9
96695	2020-07-15 12:24:50	2020-07-15	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2333	pick-up	0	22
96696	2020-07-15 12:24:52	2020-07-15	9	[{"id_menu":6,"count":1}]	10862	pick-up	0	9
96697	2020-07-15 12:30:15	2020-07-15	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	3165	delivery	5	22
96698	2020-07-15 12:31:00	2020-07-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	10956	delivery	5	28
96699	2020-07-15 12:31:36	2020-07-15	12	[{"id_menu":1,"count":1}]	34140	pick-up	0	12
96700	2020-07-15 12:36:39	2020-07-15	8	[{"id_menu":5,"count":1}]	12388	pick-up	0	8
96701	2020-07-15 12:43:37	2020-07-15	12	[{"id_menu":1,"count":1}]	9464	delivery	5	17
96702	2020-07-15 12:48:43	2020-07-15	9	[{"id_menu":7,"count":1}]	37376	delivery	5	14
96703	2020-07-15 12:52:11	2020-07-15	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	26188	delivery	5	22
96704	2020-07-15 12:52:12	2020-07-15	8	[{"id_menu":5,"count":1}]	37498	delivery	5	13
96705	2020-07-15 12:52:20	2020-07-15	23	[{"id_menu":2,"count":3},{"id_menu":7,"count":1}]	27931	delivery	5	28
96706	2020-07-15 12:54:22	2020-07-15	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32021	delivery	5	49
96707	2020-07-15 12:54:34	2020-07-15	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	20535	delivery	5	27
96708	2020-07-15 12:55:26	2020-07-15	12	[{"id_menu":3,"count":1}]	32178	pick-up	0	12
96709	2020-07-15 12:57:49	2020-07-15	8	[{"id_menu":5,"count":1}]	37468	delivery	5	13
96710	2020-07-15 12:57:51	2020-07-15	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31950	pick-up	0	29
96711	2020-07-15 12:58:16	2020-07-15	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	37508	pick-up	0	29
96712	2020-07-15 13:02:52	2020-07-15	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37429	delivery	5	37
96713	2020-07-15 13:07:17	2020-07-15	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	10415	pick-up	0	24
96714	2020-07-15 13:10:12	2020-07-15	9	[{"id_menu":6,"count":1}]	25795	delivery	5	14
96715	2020-07-15 13:11:34	2020-07-15	8	[{"id_menu":5,"count":1}]	2774	delivery	5	13
96716	2020-07-15 13:13:42	2020-07-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	13172	delivery	5	28
96717	2020-07-15 13:13:51	2020-07-15	12	[{"id_menu":3,"count":1}]	35173	pick-up	0	12
96718	2020-07-15 13:15:08	2020-07-15	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	11007	delivery	5	31
96719	2020-07-15 13:16:02	2020-07-15	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	30385	delivery	5	22
96720	2020-07-15 13:18:27	2020-07-15	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	37524	delivery	5	31
96721	2020-07-15 13:23:29	2020-07-15	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	29387	delivery	5	26
96722	2020-07-15 13:24:25	2020-07-15	12	[{"id_menu":1,"count":1}]	37464	delivery	5	17
96723	2020-07-15 13:27:15	2020-07-15	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	29490	delivery	5	43
96724	2020-07-15 13:30:11	2020-07-15	9	[{"id_menu":7,"count":1}]	37071	delivery	5	14
96725	2020-07-15 13:30:42	2020-07-15	9	[{"id_menu":7,"count":2}]	11635	delivery	5	14
96726	2020-07-15 13:37:54	2020-07-15	17	[{"id_menu":4,"count":1}]	37469	delivery	5	22
96727	2020-07-15 13:38:10	2020-07-15	8	[{"id_menu":5,"count":1}]	13441	delivery	5	13
96728	2020-07-15 13:39:27	2020-07-15	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	18539	delivery	5	44
96729	2020-07-15 13:40:37	2020-07-15	17	[{"id_menu":4,"count":1}]	21620	delivery	5	22
96730	2020-07-15 13:42:31	2020-07-15	12	[{"id_menu":1,"count":1}]	13244	delivery	5	17
96731	2020-07-15 13:51:26	2020-07-15	17	[{"id_menu":4,"count":1}]	35303	delivery	5	22
96732	2020-07-15 13:51:32	2020-07-15	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	30120	delivery	5	38
96733	2020-07-15 13:52:31	2020-07-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4728	delivery	5	28
96734	2020-07-15 13:59:44	2020-07-15	17	[{"id_menu":4,"count":1}]	22253	pick-up	0	17
96735	2020-07-15 14:01:59	2020-07-15	9	[{"id_menu":7,"count":1}]	3827	pick-up	0	9
96736	2020-07-15 14:03:58	2020-07-15	9	[{"id_menu":6,"count":1}]	149	delivery	5	14
96737	2020-07-15 14:06:44	2020-07-15	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19397	delivery	5	22
96738	2020-07-15 14:08:27	2020-07-15	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	27821	delivery	5	35
96739	2020-07-15 14:11:53	2020-07-15	8	[{"id_menu":5,"count":1}]	7164	delivery	5	13
96740	2020-07-15 14:12:36	2020-07-15	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	37585	delivery	5	43
96741	2020-07-15 14:14:12	2020-07-15	14	[{"id_menu":2,"count":1}]	37427	delivery	5	19
96742	2020-07-15 14:17:07	2020-07-15	14	[{"id_menu":2,"count":1}]	26222	delivery	5	19
96743	2020-07-15 14:20:51	2020-07-15	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	10516	delivery	5	48
96744	2020-07-15 14:20:57	2020-07-15	8	[{"id_menu":5,"count":1}]	34415	pick-up	0	8
96745	2020-07-15 14:31:41	2020-07-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17476	delivery	5	31
96746	2020-07-15 14:31:55	2020-07-15	17	[{"id_menu":4,"count":1}]	35287	pick-up	0	17
96747	2020-07-15 14:33:24	2020-07-15	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1176	delivery	5	26
96748	2020-07-15 14:33:47	2020-07-15	8	[{"id_menu":5,"count":1}]	25496	delivery	5	13
96749	2020-07-15 14:37:37	2020-07-15	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	37541	delivery	5	39
96750	2020-07-15 14:48:56	2020-07-15	14	[{"id_menu":2,"count":1}]	11189	delivery	5	19
96751	2020-07-15 14:52:37	2020-07-15	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	34390	delivery	5	36
96752	2020-07-15 14:54:13	2020-07-15	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	37384	delivery	5	34
96753	2020-07-15 14:54:24	2020-07-15	12	[{"id_menu":1,"count":1}]	34930	delivery	5	17
96754	2020-07-15 14:54:55	2020-07-15	8	[{"id_menu":5,"count":1}]	14867	delivery	5	13
96755	2020-07-15 14:55:37	2020-07-15	17	[{"id_menu":4,"count":1}]	5699	delivery	5	22
96756	2020-07-15 14:57:02	2020-07-15	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	31251	delivery	5	26
96757	2020-07-15 14:59:35	2020-07-15	9	[{"id_menu":7,"count":1}]	13236	delivery	5	14
96758	2020-07-15 15:03:07	2020-07-15	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	37424	delivery	5	28
96759	2020-07-15 15:06:33	2020-07-15	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18809	delivery	5	48
96760	2020-07-15 15:07:34	2020-07-15	17	[{"id_menu":4,"count":1}]	7623	delivery	5	22
96761	2020-07-15 15:09:06	2020-07-15	8	[{"id_menu":5,"count":1}]	4453	delivery	5	13
96762	2020-07-15 15:10:30	2020-07-15	14	[{"id_menu":2,"count":1}]	10354	delivery	5	19
96763	2020-07-15 15:11:32	2020-07-15	8	[{"id_menu":5,"count":1}]	37526	delivery	5	13
96764	2020-07-15 15:17:57	2020-07-15	17	[{"id_menu":4,"count":1}]	13331	delivery	5	22
96765	2020-07-15 15:18:17	2020-07-15	22	[{"id_menu":2,"count":3},{"id_menu":5,"count":1}]	37568	delivery	5	27
96766	2020-07-15 15:20:25	2020-07-15	9	[{"id_menu":7,"count":1}]	4081	pick-up	0	9
96767	2020-07-15 15:21:27	2020-07-15	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	20050	delivery	5	25
96768	2020-07-15 15:22:01	2020-07-15	9	[{"id_menu":7,"count":1}]	37453	delivery	5	14
96769	2020-07-15 15:25:06	2020-07-15	17	[{"id_menu":4,"count":1}]	37494	delivery	5	22
96770	2020-07-15 15:25:46	2020-07-15	9	[{"id_menu":7,"count":1}]	37407	delivery	5	14
96771	2020-07-15 15:26:48	2020-07-15	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1393	delivery	5	26
96772	2020-07-15 15:26:57	2020-07-15	14	[{"id_menu":2,"count":1}]	37481	pick-up	0	14
96773	2020-07-15 15:29:49	2020-07-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	37490	delivery	5	28
96774	2020-07-15 15:32:36	2020-07-15	12	[{"id_menu":3,"count":1}]	11722	delivery	5	17
96775	2020-07-15 15:38:33	2020-07-15	9	[{"id_menu":7,"count":1}]	18853	delivery	5	14
96776	2020-07-15 15:40:10	2020-07-15	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	37480	delivery	5	22
96777	2020-07-15 15:45:14	2020-07-15	9	[{"id_menu":6,"count":1}]	10666	delivery	5	14
96778	2020-07-15 15:45:38	2020-07-15	17	[{"id_menu":4,"count":1}]	9878	delivery	5	22
96779	2020-07-15 15:48:51	2020-07-15	12	[{"id_menu":1,"count":1}]	18489	delivery	5	17
96780	2020-07-15 15:49:57	2020-07-15	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	37565	delivery	5	39
96781	2020-07-15 15:50:08	2020-07-15	9	[{"id_menu":7,"count":1}]	15049	delivery	5	14
96782	2020-07-15 15:51:37	2020-07-15	9	[{"id_menu":7,"count":1}]	37250	delivery	5	14
96783	2020-07-15 15:56:22	2020-07-15	14	[{"id_menu":2,"count":1}]	12841	delivery	5	19
96784	2020-07-15 15:58:22	2020-07-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	32312	delivery	5	31
96785	2020-07-15 15:58:49	2020-07-15	9	[{"id_menu":6,"count":1}]	1685	pick-up	0	9
96786	2020-07-15 15:59:08	2020-07-15	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1109	delivery	5	34
96787	2020-07-15 16:00:42	2020-07-15	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20309	delivery	5	43
96788	2020-07-15 16:01:43	2020-07-15	8	[{"id_menu":5,"count":1}]	23414	delivery	5	13
96789	2020-07-15 16:03:32	2020-07-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23851	delivery	5	23
96790	2020-07-15 16:04:05	2020-07-15	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	13230	delivery	5	42
96791	2020-07-15 16:06:13	2020-07-15	12	[{"id_menu":3,"count":1}]	30976	pick-up	0	12
96792	2020-07-15 16:09:52	2020-07-15	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37570	delivery	5	31
96793	2020-07-15 16:11:47	2020-07-15	17	[{"id_menu":4,"count":1}]	37564	pick-up	0	17
96794	2020-07-15 16:12:03	2020-07-15	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	37430	delivery	5	40
96795	2020-07-15 16:15:49	2020-07-15	9	[{"id_menu":6,"count":1}]	37569	delivery	5	14
96796	2020-07-15 16:17:12	2020-07-15	9	[{"id_menu":6,"count":1}]	23939	pick-up	0	9
96797	2020-07-15 16:19:10	2020-07-15	12	[{"id_menu":1,"count":1}]	4099	pick-up	0	12
96798	2020-07-15 16:19:22	2020-07-15	9	[{"id_menu":6,"count":1}]	16839	delivery	5	14
96799	2020-07-15 16:19:34	2020-07-15	14	[{"id_menu":2,"count":1}]	37534	pick-up	0	14
96800	2020-07-15 16:22:03	2020-07-15	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22500	delivery	5	34
96801	2020-07-15 16:22:41	2020-07-15	9	[{"id_menu":7,"count":1}]	37511	delivery	5	14
96802	2020-07-15 16:30:10	2020-07-15	14	[{"id_menu":2,"count":1}]	8090	pick-up	0	14
96803	2020-07-15 16:32:48	2020-07-15	17	[{"id_menu":4,"count":1}]	34942	delivery	5	22
96804	2020-07-15 16:36:11	2020-07-15	9	[{"id_menu":7,"count":1}]	14544	delivery	5	14
96805	2020-07-15 16:36:19	2020-07-15	14	[{"id_menu":2,"count":1}]	20357	delivery	5	19
96806	2020-07-15 16:41:43	2020-07-15	30	[{"id_menu":1,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8971	delivery	5	35
96807	2020-07-15 16:44:38	2020-07-15	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	32936	pick-up	0	26
96808	2020-07-15 16:48:16	2020-07-15	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37482	delivery	5	37
96809	2020-07-15 16:51:07	2020-07-15	12	[{"id_menu":1,"count":1}]	28362	delivery	5	17
96810	2020-07-15 16:52:58	2020-07-15	8	[{"id_menu":5,"count":1}]	36587	delivery	5	13
96811	2020-07-15 16:54:47	2020-07-15	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12068	delivery	5	43
96812	2020-07-15 16:58:42	2020-07-15	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29725	delivery	5	34
96813	2020-07-15 17:01:32	2020-07-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	15117	delivery	5	28
96814	2020-07-15 17:02:45	2020-07-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	14771	pick-up	0	23
96815	2020-07-15 17:02:59	2020-07-15	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	26311	pick-up	0	17
96816	2020-07-15 17:04:35	2020-07-15	9	[{"id_menu":6,"count":1}]	37425	delivery	5	14
96817	2020-07-15 17:15:37	2020-07-15	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	37379	delivery	5	27
96818	2020-07-15 17:20:52	2020-07-15	8	[{"id_menu":5,"count":1}]	37449	delivery	5	13
96819	2020-07-15 17:22:31	2020-07-15	8	[{"id_menu":5,"count":1}]	22928	delivery	5	13
96820	2020-07-15 17:23:09	2020-07-15	9	[{"id_menu":6,"count":1}]	8407	pick-up	0	9
96821	2020-07-15 17:27:03	2020-07-15	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	23461	delivery	5	44
96822	2020-07-15 17:27:35	2020-07-15	9	[{"id_menu":6,"count":1}]	37404	delivery	5	14
96823	2020-07-15 17:28:37	2020-07-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8081	pick-up	0	18
96824	2020-07-15 17:30:25	2020-07-15	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	11412	delivery	5	26
96825	2020-07-15 17:35:55	2020-07-15	9	[{"id_menu":7,"count":1}]	22762	delivery	5	14
96826	2020-07-15 17:37:57	2020-07-15	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37463	delivery	5	49
96827	2020-07-15 17:39:04	2020-07-15	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21074	delivery	5	34
96828	2020-07-15 17:40:30	2020-07-15	12	[{"id_menu":3,"count":1}]	17784	pick-up	0	12
96829	2020-07-15 17:42:14	2020-07-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8151	delivery	5	23
96830	2020-07-15 17:50:03	2020-07-15	9	[{"id_menu":7,"count":1}]	37419	delivery	5	14
96831	2020-07-15 17:52:10	2020-07-15	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	37572	delivery	5	22
96832	2020-07-15 17:53:33	2020-07-15	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	21559	delivery	5	22
96833	2020-07-15 17:53:44	2020-07-15	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	37411	delivery	5	26
96834	2020-07-15 17:57:01	2020-07-15	8	[{"id_menu":5,"count":1}]	3203	delivery	5	13
96835	2020-07-15 17:58:23	2020-07-15	14	[{"id_menu":2,"count":1}]	30246	delivery	5	19
96836	2020-07-15 17:59:06	2020-07-15	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37413	delivery	5	49
96837	2020-07-15 17:59:39	2020-07-15	8	[{"id_menu":5,"count":1}]	37375	delivery	5	13
96838	2020-07-15 18:01:42	2020-07-15	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	37558	delivery	5	26
96839	2020-07-15 18:03:42	2020-07-15	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	21069	delivery	5	26
96840	2020-07-15 18:09:39	2020-07-15	14	[{"id_menu":2,"count":1}]	7207	delivery	5	19
96841	2020-07-15 18:12:12	2020-07-15	14	[{"id_menu":2,"count":1}]	12282	delivery	5	19
96842	2020-07-15 18:15:01	2020-07-15	8	[{"id_menu":5,"count":1}]	37555	delivery	5	13
96843	2020-07-15 18:19:17	2020-07-15	12	[{"id_menu":1,"count":1}]	35223	pick-up	0	12
96844	2020-07-15 18:19:36	2020-07-15	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13377	delivery	5	37
96845	2020-07-15 18:21:29	2020-07-15	8	[{"id_menu":5,"count":1}]	10334	delivery	5	13
96846	2020-07-15 18:21:49	2020-07-15	9	[{"id_menu":7,"count":1}]	26669	delivery	5	14
96847	2020-07-15 18:22:32	2020-07-15	9	[{"id_menu":6,"count":1}]	1306	pick-up	0	9
96848	2020-07-15 18:28:44	2020-07-15	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	17307	delivery	5	48
96849	2020-07-15 18:30:15	2020-07-15	12	[{"id_menu":3,"count":1}]	5761	pick-up	0	12
96850	2020-07-15 18:30:45	2020-07-15	12	[{"id_menu":1,"count":1}]	2520	pick-up	0	12
96851	2020-07-15 18:33:16	2020-07-15	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29108	delivery	5	37
96852	2020-07-15 18:36:05	2020-07-15	9	[{"id_menu":6,"count":1}]	37428	delivery	5	14
96853	2020-07-15 18:36:43	2020-07-15	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":2}]	37389	delivery	5	27
96854	2020-07-15 18:37:44	2020-07-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	11298	delivery	5	28
96855	2020-07-15 18:38:02	2020-07-15	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":3}]	37521	delivery	5	26
96856	2020-07-15 18:44:42	2020-07-15	17	[{"id_menu":4,"count":1}]	623	pick-up	0	17
96857	2020-07-15 18:47:56	2020-07-15	9	[{"id_menu":6,"count":2}]	11134	delivery	5	14
96858	2020-07-15 18:49:25	2020-07-15	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	21576	delivery	5	30
96859	2020-07-15 18:49:34	2020-07-15	12	[{"id_menu":3,"count":1}]	22983	pick-up	0	12
96860	2020-07-15 18:50:38	2020-07-15	14	[{"id_menu":2,"count":1}]	3465	pick-up	0	14
96861	2020-07-15 18:55:31	2020-07-15	9	[{"id_menu":6,"count":1}]	34421	delivery	5	14
96862	2020-07-15 18:57:50	2020-07-15	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	16178	pick-up	0	21
96863	2020-07-15 19:02:12	2020-07-15	9	[{"id_menu":6,"count":1}]	17046	pick-up	0	9
96864	2020-07-15 19:03:09	2020-07-15	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11285	delivery	5	22
96865	2020-07-15 19:03:31	2020-07-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6480	delivery	5	31
96866	2020-07-15 19:05:29	2020-07-15	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	37581	delivery	5	43
96867	2020-07-15 19:11:16	2020-07-15	12	[{"id_menu":1,"count":1}]	37435	pick-up	0	12
96868	2020-07-15 19:11:31	2020-07-15	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	37455	delivery	5	51
96869	2020-07-15 19:11:34	2020-07-15	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	33124	delivery	5	22
96870	2020-07-15 19:12:35	2020-07-15	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	37559	delivery	5	22
96871	2020-07-15 19:13:16	2020-07-15	9	[{"id_menu":7,"count":1}]	37554	delivery	5	14
96872	2020-07-15 19:15:38	2020-07-15	9	[{"id_menu":7,"count":1}]	23004	delivery	5	14
96873	2020-07-15 19:15:40	2020-07-15	17	[{"id_menu":4,"count":1}]	6386	pick-up	0	17
96874	2020-07-15 19:18:09	2020-07-15	12	[{"id_menu":1,"count":1}]	37542	delivery	5	17
96875	2020-07-15 19:18:47	2020-07-15	9	[{"id_menu":6,"count":1}]	7603	pick-up	0	9
96876	2020-07-15 19:19:04	2020-07-15	9	[{"id_menu":7,"count":2}]	21640	delivery	5	14
96877	2020-07-15 19:19:34	2020-07-15	14	[{"id_menu":2,"count":1}]	19039	delivery	5	19
96878	2020-07-15 19:20:10	2020-07-15	12	[{"id_menu":1,"count":1}]	16114	pick-up	0	12
96879	2020-07-15 19:20:59	2020-07-15	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16152	delivery	5	31
96880	2020-07-15 19:22:43	2020-07-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	37393	delivery	5	31
96881	2020-07-15 19:23:28	2020-07-15	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	37452	delivery	5	39
96882	2020-07-15 19:37:52	2020-07-15	8	[{"id_menu":5,"count":1}]	12158	delivery	5	13
96883	2020-07-15 19:37:53	2020-07-15	8	[{"id_menu":5,"count":1}]	28744	delivery	5	13
96884	2020-07-15 19:38:14	2020-07-15	12	[{"id_menu":3,"count":1}]	37488	delivery	5	17
96885	2020-07-15 19:40:04	2020-07-15	17	[{"id_menu":4,"count":1}]	7261	delivery	5	22
96886	2020-07-15 19:41:24	2020-07-15	9	[{"id_menu":7,"count":1}]	20021	delivery	5	14
96887	2020-07-15 19:41:27	2020-07-15	8	[{"id_menu":5,"count":1}]	17664	delivery	5	13
96888	2020-07-15 19:41:48	2020-07-15	14	[{"id_menu":2,"count":1}]	22062	delivery	5	19
96889	2020-07-15 19:47:06	2020-07-15	8	[{"id_menu":5,"count":1}]	28335	delivery	5	13
96890	2020-07-15 19:47:55	2020-07-15	8	[{"id_menu":5,"count":1}]	8265	pick-up	0	8
96891	2020-07-15 19:48:17	2020-07-15	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25596	pick-up	0	34
96892	2020-07-15 19:51:46	2020-07-15	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	32468	pick-up	0	31
96893	2020-07-15 19:54:52	2020-07-15	9	[{"id_menu":7,"count":2}]	31177	delivery	5	14
96894	2020-07-15 20:01:19	2020-07-15	9	[{"id_menu":6,"count":1}]	31172	delivery	5	14
96895	2020-07-15 20:02:34	2020-07-15	17	[{"id_menu":4,"count":1}]	37441	pick-up	0	17
96896	2020-07-15 20:03:08	2020-07-15	9	[{"id_menu":6,"count":1}]	28056	pick-up	0	9
96897	2020-07-15 20:05:39	2020-07-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1548	pick-up	0	23
96898	2020-07-15 20:07:35	2020-07-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37050	delivery	5	23
96899	2020-07-15 20:08:09	2020-07-15	9	[{"id_menu":6,"count":1}]	37461	delivery	5	14
96900	2020-07-15 20:10:52	2020-07-15	12	[{"id_menu":3,"count":1}]	27182	delivery	5	17
96901	2020-07-15 20:12:03	2020-07-15	9	[{"id_menu":6,"count":1}]	19628	delivery	5	14
96902	2020-07-15 20:12:26	2020-07-15	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	37550	pick-up	0	22
96903	2020-07-15 20:17:38	2020-07-15	9	[{"id_menu":7,"count":1}]	1731	pick-up	0	9
96904	2020-07-15 20:23:15	2020-07-15	12	[{"id_menu":3,"count":2}]	37527	pick-up	0	12
96905	2020-07-15 20:25:11	2020-07-15	9	[{"id_menu":6,"count":1}]	8186	delivery	5	14
96906	2020-07-15 20:25:27	2020-07-15	8	[{"id_menu":5,"count":1}]	37525	pick-up	0	8
96907	2020-07-15 20:30:16	2020-07-15	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37576	delivery	5	35
96908	2020-07-15 20:35:17	2020-07-15	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	13913	delivery	5	36
96909	2020-07-15 20:36:12	2020-07-15	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14686	delivery	5	39
96910	2020-07-15 20:37:24	2020-07-15	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17657	delivery	5	35
96911	2020-07-15 20:39:03	2020-07-15	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	32339	delivery	5	34
96912	2020-07-15 20:39:31	2020-07-15	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10461	delivery	5	45
96913	2020-07-15 20:45:52	2020-07-15	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4594	delivery	5	45
96914	2020-07-15 20:49:04	2020-07-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	37532	pick-up	0	23
96915	2020-07-15 20:50:10	2020-07-15	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	16518	delivery	5	29
96916	2020-07-15 20:51:31	2020-07-15	9	[{"id_menu":7,"count":1}]	23138	delivery	5	14
96917	2020-07-15 20:52:21	2020-07-15	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	22614	pick-up	0	29
96918	2020-07-15 20:53:22	2020-07-15	9	[{"id_menu":6,"count":1}]	19889	delivery	5	14
96919	2020-07-15 20:54:14	2020-07-15	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":3}]	30937	delivery	5	22
96920	2020-07-15 20:55:09	2020-07-15	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	18770	pick-up	0	26
96921	2020-07-15 20:55:33	2020-07-15	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8006	delivery	5	31
96922	2020-07-15 20:55:47	2020-07-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1582	pick-up	0	18
96923	2020-07-15 20:57:43	2020-07-15	12	[{"id_menu":3,"count":1}]	25279	pick-up	0	12
96924	2020-07-15 20:58:02	2020-07-15	12	[{"id_menu":1,"count":1}]	24434	pick-up	0	12
96925	2020-07-15 20:59:17	2020-07-15	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	36226	delivery	5	40
96926	2020-07-15 21:01:19	2020-07-15	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	37563	delivery	5	34
96927	2020-07-15 21:02:32	2020-07-15	9	[{"id_menu":7,"count":1}]	10718	delivery	5	14
96928	2020-07-15 21:05:57	2020-07-15	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	25214	pick-up	0	29
96929	2020-07-15 21:08:11	2020-07-15	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	37517	delivery	5	25
96930	2020-07-15 21:08:56	2020-07-15	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1934	pick-up	0	41
96931	2020-07-15 21:12:21	2020-07-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	37512	delivery	5	28
96932	2020-07-15 21:14:28	2020-07-15	12	[{"id_menu":3,"count":1}]	28617	delivery	5	17
96933	2020-07-15 21:14:44	2020-07-15	12	[{"id_menu":1,"count":1}]	37416	delivery	5	17
96934	2020-07-15 21:16:58	2020-07-15	9	[{"id_menu":6,"count":1}]	37403	delivery	5	14
96935	2020-07-15 21:18:28	2020-07-15	14	[{"id_menu":2,"count":1}]	5600	pick-up	0	14
96936	2020-07-15 21:24:19	2020-07-15	8	[{"id_menu":5,"count":1}]	8517	delivery	5	13
96937	2020-07-15 21:25:17	2020-07-15	14	[{"id_menu":2,"count":1}]	37446	delivery	5	19
96938	2020-07-15 21:26:38	2020-07-15	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":3}]	32587	delivery	5	26
96939	2020-07-15 21:27:10	2020-07-15	12	[{"id_menu":3,"count":1}]	35367	delivery	5	17
96940	2020-07-15 21:27:58	2020-07-15	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1010	pick-up	0	35
96941	2020-07-15 21:29:39	2020-07-15	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	37459	delivery	5	34
96942	2020-07-15 21:29:52	2020-07-15	9	[{"id_menu":6,"count":1}]	3436	delivery	5	14
96943	2020-07-15 21:30:45	2020-07-15	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3661	delivery	5	34
96944	2020-07-15 21:32:23	2020-07-15	12	[{"id_menu":1,"count":1}]	37501	pick-up	0	12
96945	2020-07-15 21:34:09	2020-07-15	9	[{"id_menu":7,"count":1}]	8264	delivery	5	14
96946	2020-07-15 21:37:33	2020-07-15	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	5349	delivery	5	28
96947	2020-07-15 21:42:27	2020-07-15	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	13665	delivery	5	42
96948	2020-07-15 21:43:46	2020-07-15	12	[{"id_menu":3,"count":1}]	10381	pick-up	0	12
96949	2020-07-15 21:45:18	2020-07-15	14	[{"id_menu":2,"count":2}]	3478	pick-up	0	14
96950	2020-07-15 21:47:05	2020-07-15	14	[{"id_menu":2,"count":1}]	37533	pick-up	0	14
96951	2020-07-15 21:48:50	2020-07-15	9	[{"id_menu":7,"count":1}]	32083	delivery	5	14
96952	2020-07-15 21:49:04	2020-07-15	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	9558	delivery	5	22
96953	2020-07-15 21:49:21	2020-07-15	8	[{"id_menu":5,"count":1}]	35095	delivery	5	13
96954	2020-07-15 21:53:48	2020-07-15	8	[{"id_menu":5,"count":1}]	15368	delivery	5	13
96955	2020-07-15 21:54:02	2020-07-15	9	[{"id_menu":6,"count":1}]	6896	pick-up	0	9
96956	2020-07-15 21:56:00	2020-07-15	9	[{"id_menu":6,"count":2}]	37414	delivery	5	14
96957	2020-07-15 21:57:43	2020-07-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4562	pick-up	0	23
96958	2020-07-15 22:01:37	2020-07-15	8	[{"id_menu":5,"count":1}]	11475	delivery	5	13
96959	2020-07-15 22:02:05	2020-07-15	14	[{"id_menu":2,"count":1}]	37528	delivery	5	19
96960	2020-07-15 22:02:25	2020-07-15	14	[{"id_menu":2,"count":1}]	2845	delivery	5	19
96961	2020-07-15 22:03:52	2020-07-15	12	[{"id_menu":1,"count":1}]	9867	delivery	5	17
96962	2020-07-15 22:05:19	2020-07-15	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27758	delivery	5	43
96963	2020-07-15 22:10:19	2020-07-15	12	[{"id_menu":1,"count":1}]	24603	pick-up	0	12
96964	2020-07-15 22:17:35	2020-07-15	9	[{"id_menu":7,"count":1}]	17232	delivery	5	14
96965	2020-07-15 22:19:53	2020-07-15	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	35271	delivery	5	31
96966	2020-07-15 22:20:17	2020-07-15	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	27389	delivery	5	44
96967	2020-07-15 22:21:08	2020-07-15	17	[{"id_menu":4,"count":1}]	23515	delivery	5	22
96968	2020-07-15 22:21:15	2020-07-15	8	[{"id_menu":5,"count":1}]	26694	delivery	5	13
96969	2020-07-15 22:24:48	2020-07-15	8	[{"id_menu":5,"count":2}]	37484	delivery	5	13
96970	2020-07-15 22:26:10	2020-07-15	9	[{"id_menu":7,"count":1}]	698	delivery	5	14
96971	2020-07-15 22:31:21	2020-07-15	8	[{"id_menu":5,"count":3}]	7899	delivery	5	13
96972	2020-07-15 22:32:13	2020-07-15	17	[{"id_menu":4,"count":1}]	24407	pick-up	0	17
96973	2020-07-15 22:35:48	2020-07-15	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	9430	delivery	5	29
96974	2020-07-15 22:41:14	2020-07-15	12	[{"id_menu":3,"count":1}]	37394	delivery	5	17
96975	2020-07-15 22:48:21	2020-07-15	9	[{"id_menu":7,"count":1}]	17780	delivery	5	14
96976	2020-07-15 22:55:05	2020-07-15	9	[{"id_menu":6,"count":1}]	37502	delivery	5	14
96977	2020-07-15 22:55:21	2020-07-15	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37513	delivery	5	35
96978	2020-07-15 22:55:56	2020-07-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	36832	delivery	5	28
96979	2020-07-15 22:58:16	2020-07-15	12	[{"id_menu":3,"count":1}]	21331	delivery	5	17
96980	2020-07-15 22:59:25	2020-07-15	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":2}]	28305	delivery	5	30
96981	2020-07-15 23:03:23	2020-07-15	12	[{"id_menu":1,"count":1}]	37405	delivery	5	17
96982	2020-07-15 23:08:33	2020-07-15	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27556	delivery	5	49
96983	2020-07-15 23:10:21	2020-07-15	9	[{"id_menu":6,"count":1}]	25042	delivery	5	14
96984	2020-07-15 23:12:47	2020-07-15	9	[{"id_menu":6,"count":1}]	19715	delivery	5	14
96985	2020-07-15 23:16:59	2020-07-15	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	37549	delivery	5	39
96986	2020-07-15 23:19:15	2020-07-15	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	11859	pick-up	0	31
96987	2020-07-15 23:22:50	2020-07-15	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	37539	delivery	5	36
96988	2020-07-15 23:23:39	2020-07-15	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	24289	delivery	5	56
96989	2020-07-15 23:24:54	2020-07-15	12	[{"id_menu":3,"count":1}]	1536	pick-up	0	12
96990	2020-07-15 23:26:48	2020-07-15	9	[{"id_menu":6,"count":1}]	4691	delivery	5	14
96991	2020-07-15 23:31:26	2020-07-15	8	[{"id_menu":5,"count":1}]	37560	delivery	5	13
96992	2020-07-15 23:33:07	2020-07-15	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	37397	delivery	5	45
96993	2020-07-15 23:33:41	2020-07-15	17	[{"id_menu":4,"count":1}]	4800	pick-up	0	17
96994	2020-07-15 23:34:01	2020-07-15	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	37519	delivery	5	26
96995	2020-07-15 23:35:21	2020-07-15	9	[{"id_menu":7,"count":1}]	10356	delivery	5	14
96996	2020-07-15 23:39:25	2020-07-15	17	[{"id_menu":4,"count":1}]	5134	delivery	5	22
96997	2020-07-15 23:39:27	2020-07-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	24624	delivery	5	31
96998	2020-07-15 23:46:42	2020-07-15	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	32061	delivery	5	40
96999	2020-07-15 23:51:36	2020-07-15	12	[{"id_menu":3,"count":1}]	37531	delivery	5	17
97000	2020-07-15 23:51:52	2020-07-15	9	[{"id_menu":6,"count":1}]	33958	delivery	5	14
97001	2020-07-15 23:52:39	2020-07-15	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	37582	delivery	5	31
97002	2020-07-15 23:56:09	2020-07-15	9	[{"id_menu":7,"count":1}]	37507	delivery	5	14
97003	2020-07-15 23:56:33	2020-07-15	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	17533	delivery	5	25
97004	2020-07-15 23:56:59	2020-07-15	9	[{"id_menu":7,"count":1}]	13636	delivery	5	14
97005	2020-07-15 23:58:15	2020-07-15	9	[{"id_menu":6,"count":1}]	33131	delivery	5	14
97006	2020-07-16 00:00:59	2020-07-16	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	37763	pick-up	0	35
97007	2020-07-16 00:02:53	2020-07-16	14	[{"id_menu":2,"count":1}]	37760	delivery	5	19
97008	2020-07-16 00:04:53	2020-07-16	14	[{"id_menu":2,"count":1}]	20183	delivery	5	19
97009	2020-07-16 00:06:21	2020-07-16	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	37822	delivery	5	26
97010	2020-07-16 00:17:04	2020-07-16	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	21102	delivery	5	40
97011	2020-07-16 00:17:36	2020-07-16	9	[{"id_menu":7,"count":1}]	12527	pick-up	0	9
97012	2020-07-16 00:19:19	2020-07-16	14	[{"id_menu":2,"count":1}]	29040	delivery	5	19
97013	2020-07-16 00:20:43	2020-07-16	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	37820	delivery	5	38
97014	2020-07-16 00:20:54	2020-07-16	14	[{"id_menu":2,"count":1}]	1088	pick-up	0	14
97015	2020-07-16 00:21:51	2020-07-16	12	[{"id_menu":3,"count":1}]	1255	pick-up	0	12
97016	2020-07-16 00:24:51	2020-07-16	17	[{"id_menu":4,"count":1}]	26694	pick-up	0	17
97017	2020-07-16 00:24:54	2020-07-16	17	[{"id_menu":4,"count":1}]	27316	pick-up	0	17
97018	2020-07-16 00:28:59	2020-07-16	9	[{"id_menu":6,"count":1}]	5350	pick-up	0	9
97019	2020-07-16 00:29:15	2020-07-16	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	37742	delivery	5	36
97020	2020-07-16 00:29:52	2020-07-16	9	[{"id_menu":6,"count":2}]	3385	delivery	5	14
97021	2020-07-16 00:32:08	2020-07-16	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	11454	delivery	5	43
97022	2020-07-16 00:33:18	2020-07-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	37770	delivery	5	28
97023	2020-07-16 00:35:25	2020-07-16	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	23859	delivery	5	31
97024	2020-07-16 00:37:54	2020-07-16	14	[{"id_menu":2,"count":1}]	25885	pick-up	0	14
97025	2020-07-16 00:38:43	2020-07-16	17	[{"id_menu":4,"count":1}]	11351	pick-up	0	17
97026	2020-07-16 00:39:11	2020-07-16	14	[{"id_menu":2,"count":1}]	37829	delivery	5	19
97027	2020-07-16 00:40:16	2020-07-16	17	[{"id_menu":4,"count":1}]	37814	delivery	5	22
97028	2020-07-16 00:41:41	2020-07-16	8	[{"id_menu":5,"count":1}]	22217	delivery	5	13
97029	2020-07-16 00:43:34	2020-07-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	37800	delivery	5	26
97030	2020-07-16 00:45:46	2020-07-16	12	[{"id_menu":1,"count":1}]	37592	pick-up	0	12
97031	2020-07-16 00:51:43	2020-07-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	18524	delivery	5	31
97032	2020-07-16 00:58:05	2020-07-16	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30935	delivery	5	49
97033	2020-07-16 01:00:28	2020-07-16	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4881	delivery	5	34
97034	2020-07-16 01:01:32	2020-07-16	8	[{"id_menu":5,"count":1}]	37650	delivery	5	13
97035	2020-07-16 01:02:37	2020-07-16	8	[{"id_menu":5,"count":1}]	8735	delivery	5	13
97036	2020-07-16 01:05:12	2020-07-16	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	37677	delivery	5	31
97037	2020-07-16 01:08:18	2020-07-16	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	25488	pick-up	0	29
97038	2020-07-16 01:14:42	2020-07-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	26634	delivery	5	31
97039	2020-07-16 01:18:38	2020-07-16	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	37651	delivery	5	34
97040	2020-07-16 01:19:48	2020-07-16	12	[{"id_menu":3,"count":1}]	23168	delivery	5	17
97041	2020-07-16 01:22:28	2020-07-16	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	31316	delivery	5	40
97042	2020-07-16 01:24:56	2020-07-16	9	[{"id_menu":6,"count":1}]	5140	delivery	5	14
97043	2020-07-16 01:28:56	2020-07-16	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	19299	delivery	5	42
97044	2020-07-16 01:29:36	2020-07-16	8	[{"id_menu":5,"count":1}]	11183	pick-up	0	8
97045	2020-07-16 01:29:52	2020-07-16	14	[{"id_menu":2,"count":1}]	36853	delivery	5	19
97046	2020-07-16 01:32:28	2020-07-16	17	[{"id_menu":4,"count":1}]	11328	delivery	5	22
97047	2020-07-16 01:34:03	2020-07-16	9	[{"id_menu":7,"count":1}]	24267	delivery	5	14
97048	2020-07-16 01:34:48	2020-07-16	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	37697	delivery	5	26
97049	2020-07-16 01:35:50	2020-07-16	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	37600	delivery	5	45
97050	2020-07-16 01:36:44	2020-07-16	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	4252	pick-up	0	24
97051	2020-07-16 01:37:11	2020-07-16	17	[{"id_menu":4,"count":1}]	37687	delivery	5	22
97052	2020-07-16 01:40:51	2020-07-16	9	[{"id_menu":6,"count":2}]	19669	delivery	5	14
97053	2020-07-16 01:47:13	2020-07-16	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37727	delivery	5	49
97054	2020-07-16 01:47:16	2020-07-16	8	[{"id_menu":5,"count":1}]	33155	delivery	5	13
97055	2020-07-16 01:56:01	2020-07-16	12	[{"id_menu":3,"count":1}]	2381	pick-up	0	12
97056	2020-07-16 02:00:46	2020-07-16	9	[{"id_menu":6,"count":1}]	34347	delivery	5	14
97057	2020-07-16 02:01:11	2020-07-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32557	delivery	5	23
97058	2020-07-16 02:02:40	2020-07-16	17	[{"id_menu":4,"count":1}]	7874	delivery	5	22
97059	2020-07-16 02:05:00	2020-07-16	9	[{"id_menu":7,"count":1}]	29576	delivery	5	14
97060	2020-07-16 02:08:28	2020-07-16	9	[{"id_menu":6,"count":1}]	37669	delivery	5	14
97061	2020-07-16 02:14:03	2020-07-16	17	[{"id_menu":4,"count":1}]	29187	delivery	5	22
97062	2020-07-16 02:15:07	2020-07-16	9	[{"id_menu":7,"count":1}]	16333	pick-up	0	9
97063	2020-07-16 02:15:38	2020-07-16	17	[{"id_menu":4,"count":1}]	37792	delivery	5	22
97064	2020-07-16 02:17:29	2020-07-16	8	[{"id_menu":5,"count":1}]	37684	delivery	5	13
97065	2020-07-16 02:18:03	2020-07-16	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15351	pick-up	0	31
97066	2020-07-16 02:20:02	2020-07-16	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	28860	delivery	5	36
97067	2020-07-16 02:20:15	2020-07-16	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	14495	delivery	5	45
97068	2020-07-16 02:22:49	2020-07-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	30697	delivery	5	28
97069	2020-07-16 02:24:00	2020-07-16	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	25420	delivery	5	56
97070	2020-07-16 02:27:03	2020-07-16	14	[{"id_menu":2,"count":1}]	22320	pick-up	0	14
97071	2020-07-16 02:29:30	2020-07-16	17	[{"id_menu":4,"count":1}]	35161	pick-up	0	17
97072	2020-07-16 02:30:05	2020-07-16	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	6450	delivery	5	25
97073	2020-07-16 02:35:04	2020-07-16	14	[{"id_menu":2,"count":1}]	32144	pick-up	0	14
97074	2020-07-16 02:38:20	2020-07-16	14	[{"id_menu":2,"count":1}]	32903	delivery	5	19
97075	2020-07-16 02:42:26	2020-07-16	9	[{"id_menu":6,"count":1}]	20037	delivery	5	14
97076	2020-07-16 02:46:44	2020-07-16	17	[{"id_menu":4,"count":2}]	17941	delivery	5	22
97077	2020-07-16 02:48:13	2020-07-16	9	[{"id_menu":7,"count":1}]	35280	delivery	5	14
97078	2020-07-16 02:50:42	2020-07-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	18392	pick-up	0	21
97079	2020-07-16 02:51:23	2020-07-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3592	pick-up	0	23
97080	2020-07-16 02:51:34	2020-07-16	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	21962	delivery	5	26
97081	2020-07-16 02:51:45	2020-07-16	9	[{"id_menu":6,"count":1}]	37670	delivery	5	14
97082	2020-07-16 02:55:35	2020-07-16	12	[{"id_menu":1,"count":1}]	8595	delivery	5	17
97083	2020-07-16 02:56:02	2020-07-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	1579	delivery	5	31
97084	2020-07-16 03:01:44	2020-07-16	9	[{"id_menu":6,"count":1}]	37811	delivery	5	14
97085	2020-07-16 03:08:06	2020-07-16	12	[{"id_menu":1,"count":1}]	868	delivery	5	17
97086	2020-07-16 03:08:31	2020-07-16	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	37793	delivery	5	25
97087	2020-07-16 03:09:32	2020-07-16	14	[{"id_menu":2,"count":1}]	6576	delivery	5	19
97088	2020-07-16 03:09:52	2020-07-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37699	delivery	5	23
97089	2020-07-16 03:11:34	2020-07-16	12	[{"id_menu":3,"count":1}]	32982	pick-up	0	12
97090	2020-07-16 03:13:20	2020-07-16	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	30734	delivery	5	37
97091	2020-07-16 03:22:53	2020-07-16	9	[{"id_menu":7,"count":1}]	37758	delivery	5	14
97092	2020-07-16 03:23:02	2020-07-16	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37626	delivery	5	47
97093	2020-07-16 03:23:05	2020-07-16	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7517	pick-up	0	31
97094	2020-07-16 03:23:47	2020-07-16	12	[{"id_menu":1,"count":1}]	37802	delivery	5	17
97095	2020-07-16 03:29:44	2020-07-16	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2960	pick-up	0	38
97096	2020-07-16 03:31:25	2020-07-16	17	[{"id_menu":4,"count":1}]	5508	pick-up	0	17
97097	2020-07-16 03:34:38	2020-07-16	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	37611	delivery	5	26
97098	2020-07-16 03:38:02	2020-07-16	12	[{"id_menu":3,"count":1}]	14054	delivery	5	17
97099	2020-07-16 03:39:36	2020-07-16	34	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	36555	delivery	5	39
97100	2020-07-16 03:40:59	2020-07-16	9	[{"id_menu":7,"count":1}]	23307	delivery	5	14
97101	2020-07-16 03:43:53	2020-07-16	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	37743	delivery	5	30
97102	2020-07-16 03:43:56	2020-07-16	17	[{"id_menu":4,"count":1}]	2737	pick-up	0	17
97103	2020-07-16 03:51:31	2020-07-16	9	[{"id_menu":6,"count":1}]	37603	delivery	5	14
97104	2020-07-16 03:53:53	2020-07-16	14	[{"id_menu":2,"count":1}]	2050	delivery	5	19
97105	2020-07-16 03:56:36	2020-07-16	9	[{"id_menu":7,"count":1}]	37769	delivery	5	14
97106	2020-07-16 04:00:12	2020-07-16	8	[{"id_menu":5,"count":1}]	11296	delivery	5	13
97107	2020-07-16 04:02:28	2020-07-16	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	37715	delivery	5	34
97108	2020-07-16 04:03:17	2020-07-16	14	[{"id_menu":2,"count":1}]	19236	delivery	5	19
97109	2020-07-16 04:03:27	2020-07-16	9	[{"id_menu":6,"count":1}]	37738	delivery	5	14
97110	2020-07-16 04:03:44	2020-07-16	9	[{"id_menu":7,"count":1}]	6202	pick-up	0	9
97111	2020-07-16 04:06:28	2020-07-16	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	37615	delivery	5	45
97112	2020-07-16 04:06:33	2020-07-16	14	[{"id_menu":2,"count":1}]	3113	delivery	5	19
97113	2020-07-16 04:07:22	2020-07-16	8	[{"id_menu":5,"count":1}]	37718	pick-up	0	8
97114	2020-07-16 04:08:43	2020-07-16	9	[{"id_menu":7,"count":1}]	37765	delivery	5	14
97115	2020-07-16 04:09:27	2020-07-16	9	[{"id_menu":7,"count":1}]	37695	delivery	5	14
97116	2020-07-16 04:17:01	2020-07-16	12	[{"id_menu":3,"count":1}]	12043	delivery	5	17
97117	2020-07-16 04:19:10	2020-07-16	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	12676	delivery	5	26
97118	2020-07-16 04:22:35	2020-07-16	8	[{"id_menu":5,"count":1}]	37628	delivery	5	13
97119	2020-07-16 04:24:45	2020-07-16	8	[{"id_menu":5,"count":1}]	14566	delivery	5	13
97120	2020-07-16 04:25:33	2020-07-16	14	[{"id_menu":2,"count":2}]	10281	delivery	5	19
97121	2020-07-16 04:26:30	2020-07-16	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	4422	delivery	5	27
97122	2020-07-16 04:28:01	2020-07-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	37801	delivery	5	28
97123	2020-07-16 04:35:06	2020-07-16	17	[{"id_menu":4,"count":1}]	1780	delivery	5	22
97124	2020-07-16 04:39:54	2020-07-16	17	[{"id_menu":4,"count":1}]	37716	pick-up	0	17
97125	2020-07-16 04:41:26	2020-07-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31319	delivery	5	23
97126	2020-07-16 04:43:22	2020-07-16	9	[{"id_menu":6,"count":1}]	37733	delivery	5	14
97127	2020-07-16 04:43:39	2020-07-16	9	[{"id_menu":7,"count":1}]	14501	pick-up	0	9
97128	2020-07-16 04:44:06	2020-07-16	8	[{"id_menu":5,"count":1}]	37671	delivery	5	13
97129	2020-07-16 04:48:39	2020-07-16	9	[{"id_menu":7,"count":1}]	37803	delivery	5	14
97130	2020-07-16 04:49:07	2020-07-16	9	[{"id_menu":7,"count":1}]	5041	pick-up	0	9
97131	2020-07-16 04:51:59	2020-07-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	10719	delivery	5	26
97132	2020-07-16 04:52:55	2020-07-16	14	[{"id_menu":2,"count":1}]	26033	delivery	5	19
97133	2020-07-16 04:54:46	2020-07-16	8	[{"id_menu":5,"count":1}]	30246	delivery	5	13
97134	2020-07-16 04:58:33	2020-07-16	8	[{"id_menu":5,"count":1}]	23875	delivery	5	13
97135	2020-07-16 05:00:00	2020-07-16	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	37728	delivery	5	35
97136	2020-07-16 05:02:09	2020-07-16	12	[{"id_menu":3,"count":1}]	37764	pick-up	0	12
97137	2020-07-16 05:06:13	2020-07-16	17	[{"id_menu":4,"count":1}]	37638	pick-up	0	17
97138	2020-07-16 05:08:43	2020-07-16	9	[{"id_menu":6,"count":1}]	37632	delivery	5	14
97139	2020-07-16 05:09:28	2020-07-16	9	[{"id_menu":6,"count":1}]	6891	delivery	5	14
97140	2020-07-16 05:13:46	2020-07-16	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	37771	delivery	5	26
97141	2020-07-16 05:15:27	2020-07-16	14	[{"id_menu":2,"count":1}]	36765	delivery	5	19
97142	2020-07-16 05:16:57	2020-07-16	14	[{"id_menu":2,"count":1}]	24700	delivery	5	19
97143	2020-07-16 05:19:23	2020-07-16	12	[{"id_menu":1,"count":1}]	14025	pick-up	0	12
97144	2020-07-16 05:22:52	2020-07-16	9	[{"id_menu":7,"count":1}]	17350	delivery	5	14
97145	2020-07-16 05:25:03	2020-07-16	17	[{"id_menu":4,"count":1}]	11713	delivery	5	22
97146	2020-07-16 05:25:26	2020-07-16	8	[{"id_menu":5,"count":1}]	29164	delivery	5	13
97147	2020-07-16 05:26:23	2020-07-16	9	[{"id_menu":7,"count":1}]	37410	delivery	5	14
97148	2020-07-16 05:27:30	2020-07-16	17	[{"id_menu":4,"count":1}]	18823	delivery	5	22
97149	2020-07-16 05:29:38	2020-07-16	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21522	delivery	5	46
97150	2020-07-16 05:30:08	2020-07-16	14	[{"id_menu":2,"count":1}]	5435	delivery	5	19
97151	2020-07-16 05:32:34	2020-07-16	14	[{"id_menu":2,"count":1}]	37644	pick-up	0	14
97152	2020-07-16 05:33:43	2020-07-16	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	37789	delivery	5	26
97153	2020-07-16 05:37:25	2020-07-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37766	delivery	5	23
97154	2020-07-16 05:40:46	2020-07-16	17	[{"id_menu":4,"count":1}]	1913	pick-up	0	17
97155	2020-07-16 05:41:34	2020-07-16	14	[{"id_menu":2,"count":1}]	5408	delivery	5	19
97156	2020-07-16 05:45:19	2020-07-16	12	[{"id_menu":1,"count":1}]	13628	delivery	5	17
97157	2020-07-16 05:51:34	2020-07-16	8	[{"id_menu":5,"count":1}]	16483	delivery	5	13
97158	2020-07-16 05:56:00	2020-07-16	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15813	delivery	5	36
97159	2020-07-16 06:00:00	2020-07-16	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	37750	delivery	5	34
97160	2020-07-16 06:01:44	2020-07-16	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27470	delivery	5	48
97161	2020-07-16 06:03:59	2020-07-16	9	[{"id_menu":7,"count":1}]	2115	pick-up	0	9
97162	2020-07-16 06:05:00	2020-07-16	8	[{"id_menu":5,"count":1}]	841	pick-up	0	8
97163	2020-07-16 06:07:17	2020-07-16	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21617	delivery	5	34
97164	2020-07-16 06:07:55	2020-07-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24332	delivery	5	23
97165	2020-07-16 06:10:05	2020-07-16	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	22329	delivery	5	27
97166	2020-07-16 06:14:59	2020-07-16	9	[{"id_menu":7,"count":1}]	37726	delivery	5	14
97167	2020-07-16 06:21:03	2020-07-16	9	[{"id_menu":7,"count":1}]	489	pick-up	0	9
97168	2020-07-16 06:23:51	2020-07-16	12	[{"id_menu":3,"count":2}]	68	delivery	5	17
97169	2020-07-16 06:25:15	2020-07-16	9	[{"id_menu":6,"count":1}]	23324	delivery	5	14
97170	2020-07-16 06:29:24	2020-07-16	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20754	pick-up	0	17
97171	2020-07-16 06:29:36	2020-07-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27965	delivery	5	23
97172	2020-07-16 06:35:14	2020-07-16	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18388	delivery	5	22
97173	2020-07-16 06:41:09	2020-07-16	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1457	delivery	5	40
97174	2020-07-16 06:43:59	2020-07-16	14	[{"id_menu":2,"count":1}]	21003	delivery	5	19
97175	2020-07-16 06:45:35	2020-07-16	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	22597	delivery	5	45
97176	2020-07-16 06:49:14	2020-07-16	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19674	delivery	5	40
97177	2020-07-16 06:57:42	2020-07-16	9	[{"id_menu":6,"count":1}]	37620	delivery	5	14
97178	2020-07-16 07:01:05	2020-07-16	9	[{"id_menu":7,"count":1}]	34986	delivery	5	14
97179	2020-07-16 07:04:44	2020-07-16	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4478	delivery	5	40
97180	2020-07-16 07:05:12	2020-07-16	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	2791	delivery	5	35
97181	2020-07-16 07:06:20	2020-07-16	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	31881	delivery	5	30
97182	2020-07-16 07:09:47	2020-07-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	37654	delivery	5	28
97183	2020-07-16 07:10:47	2020-07-16	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	12001	pick-up	0	25
97184	2020-07-16 07:12:58	2020-07-16	9	[{"id_menu":6,"count":1}]	24765	delivery	5	14
97185	2020-07-16 07:18:31	2020-07-16	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	24175	delivery	5	29
97186	2020-07-16 07:19:38	2020-07-16	14	[{"id_menu":2,"count":1}]	19795	delivery	5	19
97187	2020-07-16 07:19:43	2020-07-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1674	pick-up	0	26
97188	2020-07-16 07:21:14	2020-07-16	12	[{"id_menu":3,"count":1}]	1640	pick-up	0	12
97189	2020-07-16 07:22:44	2020-07-16	9	[{"id_menu":7,"count":1}]	33852	delivery	5	14
97190	2020-07-16 07:24:57	2020-07-16	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	37744	delivery	5	53
97191	2020-07-16 07:28:13	2020-07-16	12	[{"id_menu":1,"count":1}]	30532	delivery	5	17
97192	2020-07-16 07:29:50	2020-07-16	9	[{"id_menu":7,"count":1}]	28025	delivery	5	14
97193	2020-07-16 07:31:19	2020-07-16	8	[{"id_menu":5,"count":1}]	28927	pick-up	0	8
97194	2020-07-16 07:32:22	2020-07-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15829	pick-up	0	26
97195	2020-07-16 07:34:08	2020-07-16	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1087	delivery	5	27
97196	2020-07-16 07:38:41	2020-07-16	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	37605	delivery	5	26
97197	2020-07-16 07:45:48	2020-07-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	37645	delivery	5	28
97198	2020-07-16 07:47:40	2020-07-16	12	[{"id_menu":1,"count":1}]	15117	pick-up	0	12
97199	2020-07-16 07:48:06	2020-07-16	12	[{"id_menu":3,"count":2}]	18933	delivery	5	17
97200	2020-07-16 07:48:47	2020-07-16	9	[{"id_menu":6,"count":1}]	6497	pick-up	0	9
97201	2020-07-16 07:52:10	2020-07-16	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	8058	pick-up	0	31
97202	2020-07-16 07:52:45	2020-07-16	9	[{"id_menu":6,"count":2}]	37712	delivery	5	14
97203	2020-07-16 07:53:14	2020-07-16	12	[{"id_menu":1,"count":2}]	12754	pick-up	0	12
97204	2020-07-16 07:53:31	2020-07-16	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8355	pick-up	0	25
97205	2020-07-16 07:55:19	2020-07-16	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8747	pick-up	0	39
97206	2020-07-16 07:59:48	2020-07-16	9	[{"id_menu":6,"count":3}]	11839	delivery	5	14
97207	2020-07-16 08:01:38	2020-07-16	12	[{"id_menu":3,"count":1}]	34594	delivery	5	17
97208	2020-07-16 08:02:21	2020-07-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2507	delivery	5	28
97209	2020-07-16 08:06:18	2020-07-16	8	[{"id_menu":5,"count":1}]	37748	delivery	5	13
97210	2020-07-16 08:06:24	2020-07-16	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	37647	delivery	5	26
97211	2020-07-16 08:10:33	2020-07-16	9	[{"id_menu":7,"count":1}]	5804	delivery	5	14
97212	2020-07-16 08:13:34	2020-07-16	9	[{"id_menu":7,"count":1}]	162	pick-up	0	9
97213	2020-07-16 08:16:28	2020-07-16	8	[{"id_menu":5,"count":1}]	22653	delivery	5	13
97214	2020-07-16 08:18:05	2020-07-16	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	24802	pick-up	0	35
97215	2020-07-16 08:20:40	2020-07-16	9	[{"id_menu":6,"count":1}]	37787	delivery	5	14
97283	2020-07-16 10:25:03	2020-07-16	14	[{"id_menu":2,"count":1}]	14272	delivery	5	19
97216	2020-07-16 08:21:44	2020-07-16	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	18943	delivery	5	57
97217	2020-07-16 08:27:21	2020-07-16	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4116	delivery	5	43
97218	2020-07-16 08:27:25	2020-07-16	17	[{"id_menu":4,"count":1}]	9907	pick-up	0	17
97219	2020-07-16 08:27:56	2020-07-16	12	[{"id_menu":1,"count":1}]	9750	delivery	5	17
97220	2020-07-16 08:30:46	2020-07-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	37686	delivery	5	22
97221	2020-07-16 08:30:48	2020-07-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	37703	delivery	5	28
97222	2020-07-16 08:33:56	2020-07-16	9	[{"id_menu":6,"count":1}]	37812	delivery	5	14
97223	2020-07-16 08:38:38	2020-07-16	9	[{"id_menu":6,"count":1}]	13289	pick-up	0	9
97224	2020-07-16 08:47:43	2020-07-16	9	[{"id_menu":6,"count":1}]	37818	delivery	5	14
97225	2020-07-16 08:47:49	2020-07-16	12	[{"id_menu":1,"count":1}]	3144	pick-up	0	12
97226	2020-07-16 08:48:00	2020-07-16	12	[{"id_menu":1,"count":1}]	35854	delivery	5	17
97227	2020-07-16 08:51:07	2020-07-16	12	[{"id_menu":1,"count":1}]	37735	delivery	5	17
97228	2020-07-16 08:51:28	2020-07-16	17	[{"id_menu":4,"count":1}]	1501	pick-up	0	17
97229	2020-07-16 08:54:57	2020-07-16	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23427	delivery	5	52
97230	2020-07-16 08:57:03	2020-07-16	9	[{"id_menu":7,"count":1}]	20996	delivery	5	14
97231	2020-07-16 08:57:29	2020-07-16	9	[{"id_menu":7,"count":1}]	37721	delivery	5	14
97232	2020-07-16 08:58:52	2020-07-16	12	[{"id_menu":3,"count":1}]	14088	pick-up	0	12
97233	2020-07-16 09:00:52	2020-07-16	12	[{"id_menu":3,"count":1}]	37826	pick-up	0	12
97234	2020-07-16 09:02:20	2020-07-16	9	[{"id_menu":7,"count":1}]	22708	pick-up	0	9
97235	2020-07-16 09:03:16	2020-07-16	17	[{"id_menu":4,"count":1}]	16476	pick-up	0	17
97236	2020-07-16 09:03:55	2020-07-16	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	37707	delivery	5	22
97237	2020-07-16 09:05:00	2020-07-16	14	[{"id_menu":2,"count":1}]	356	pick-up	0	14
97238	2020-07-16 09:06:44	2020-07-16	9	[{"id_menu":6,"count":1}]	35885	pick-up	0	9
97239	2020-07-16 09:07:59	2020-07-16	12	[{"id_menu":1,"count":1}]	37608	delivery	5	17
97240	2020-07-16 09:08:41	2020-07-16	14	[{"id_menu":2,"count":1}]	29210	delivery	5	19
97241	2020-07-16 09:08:59	2020-07-16	9	[{"id_menu":7,"count":1}]	4734	pick-up	0	9
97242	2020-07-16 09:09:42	2020-07-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18666	delivery	5	23
97243	2020-07-16 09:12:52	2020-07-16	8	[{"id_menu":5,"count":1}]	37623	delivery	5	13
97244	2020-07-16 09:15:47	2020-07-16	9	[{"id_menu":7,"count":1}]	2907	pick-up	0	9
97245	2020-07-16 09:18:43	2020-07-16	17	[{"id_menu":4,"count":1}]	15298	delivery	5	22
97246	2020-07-16 09:19:43	2020-07-16	12	[{"id_menu":1,"count":1}]	14891	delivery	5	17
97247	2020-07-16 09:20:23	2020-07-16	9	[{"id_menu":7,"count":1}]	32717	delivery	5	14
97248	2020-07-16 09:21:35	2020-07-16	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	342	delivery	5	34
97249	2020-07-16 09:22:30	2020-07-16	9	[{"id_menu":6,"count":1}]	24755	delivery	5	14
97250	2020-07-16 09:23:36	2020-07-16	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	37667	delivery	5	25
97251	2020-07-16 09:23:57	2020-07-16	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18901	delivery	5	40
97252	2020-07-16 09:29:52	2020-07-16	9	[{"id_menu":6,"count":1}]	28910	delivery	5	14
97253	2020-07-16 09:31:42	2020-07-16	12	[{"id_menu":1,"count":1}]	22605	pick-up	0	12
97254	2020-07-16 09:37:02	2020-07-16	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	9963	delivery	5	27
97255	2020-07-16 09:38:39	2020-07-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7591	pick-up	0	26
97256	2020-07-16 09:40:00	2020-07-16	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	37617	delivery	5	43
97257	2020-07-16 09:44:46	2020-07-16	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	13093	delivery	5	36
97258	2020-07-16 09:45:09	2020-07-16	14	[{"id_menu":2,"count":1}]	37780	delivery	5	19
97259	2020-07-16 09:45:11	2020-07-16	9	[{"id_menu":7,"count":2}]	18526	pick-up	0	9
97260	2020-07-16 09:47:32	2020-07-16	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	37705	pick-up	0	26
97261	2020-07-16 09:48:33	2020-07-16	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	37740	delivery	5	38
97262	2020-07-16 09:50:10	2020-07-16	14	[{"id_menu":2,"count":1}]	1407	delivery	5	19
97263	2020-07-16 09:50:32	2020-07-16	12	[{"id_menu":3,"count":1}]	8223	delivery	5	17
97264	2020-07-16 09:51:18	2020-07-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	37672	delivery	5	31
97265	2020-07-16 09:52:11	2020-07-16	14	[{"id_menu":2,"count":1}]	1970	pick-up	0	14
97266	2020-07-16 09:52:14	2020-07-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	34017	delivery	5	28
97267	2020-07-16 09:54:03	2020-07-16	12	[{"id_menu":3,"count":1}]	27191	delivery	5	17
97268	2020-07-16 09:55:33	2020-07-16	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	37660	delivery	5	22
97269	2020-07-16 09:59:00	2020-07-16	9	[{"id_menu":7,"count":1}]	8228	delivery	5	14
97270	2020-07-16 09:59:12	2020-07-16	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	37767	delivery	5	22
97271	2020-07-16 10:04:12	2020-07-16	12	[{"id_menu":3,"count":1}]	10151	pick-up	0	12
97272	2020-07-16 10:05:06	2020-07-16	17	[{"id_menu":4,"count":1}]	2651	delivery	5	22
97273	2020-07-16 10:05:13	2020-07-16	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	37799	delivery	5	45
97274	2020-07-16 10:07:54	2020-07-16	9	[{"id_menu":7,"count":1}]	25533	delivery	5	14
97275	2020-07-16 10:10:01	2020-07-16	8	[{"id_menu":5,"count":1}]	37753	pick-up	0	8
97276	2020-07-16 10:10:15	2020-07-16	17	[{"id_menu":4,"count":1}]	29394	pick-up	0	17
97277	2020-07-16 10:11:18	2020-07-16	9	[{"id_menu":6,"count":1}]	2945	delivery	5	14
97278	2020-07-16 10:15:07	2020-07-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	37665	delivery	5	26
97279	2020-07-16 10:15:36	2020-07-16	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	18977	delivery	5	28
97280	2020-07-16 10:17:57	2020-07-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	23693	delivery	5	31
97281	2020-07-16 10:18:09	2020-07-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	37664	delivery	5	26
97282	2020-07-16 10:18:55	2020-07-16	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	37643	delivery	5	26
97284	2020-07-16 10:26:51	2020-07-16	12	[{"id_menu":1,"count":1}]	113	delivery	5	17
97285	2020-07-16 10:28:17	2020-07-16	12	[{"id_menu":3,"count":1}]	37688	pick-up	0	12
97286	2020-07-16 10:28:23	2020-07-16	9	[{"id_menu":7,"count":2}]	37646	delivery	5	14
97287	2020-07-16 10:29:07	2020-07-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	8012	delivery	5	26
97288	2020-07-16 10:29:44	2020-07-16	17	[{"id_menu":4,"count":1}]	36622	delivery	5	22
97289	2020-07-16 10:32:14	2020-07-16	9	[{"id_menu":7,"count":1}]	263	delivery	5	14
97290	2020-07-16 10:34:15	2020-07-16	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2052	pick-up	0	21
97291	2020-07-16 10:34:50	2020-07-16	9	[{"id_menu":6,"count":1}]	37720	delivery	5	14
97292	2020-07-16 10:37:01	2020-07-16	9	[{"id_menu":7,"count":1}]	9022	delivery	5	14
97293	2020-07-16 10:37:57	2020-07-16	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	6853	delivery	5	38
97294	2020-07-16 10:38:44	2020-07-16	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	37690	delivery	5	28
97295	2020-07-16 10:43:12	2020-07-16	14	[{"id_menu":2,"count":2}]	8071	pick-up	0	14
97296	2020-07-16 10:43:34	2020-07-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	37741	delivery	5	26
97297	2020-07-16 10:47:57	2020-07-16	8	[{"id_menu":5,"count":1}]	37776	delivery	5	13
97298	2020-07-16 10:50:31	2020-07-16	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	4632	delivery	5	27
97299	2020-07-16 10:52:21	2020-07-16	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	23809	delivery	5	35
97300	2020-07-16 10:56:25	2020-07-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	28079	delivery	5	31
97301	2020-07-16 10:56:40	2020-07-16	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	16551	delivery	5	22
97302	2020-07-16 10:59:05	2020-07-16	30	[{"id_menu":3,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3835	delivery	5	35
97303	2020-07-16 11:01:47	2020-07-16	12	[{"id_menu":1,"count":1}]	37827	delivery	5	17
97304	2020-07-16 11:04:44	2020-07-16	17	[{"id_menu":4,"count":1}]	26924	pick-up	0	17
97305	2020-07-16 11:08:07	2020-07-16	14	[{"id_menu":2,"count":1}]	37806	delivery	5	19
97306	2020-07-16 11:08:42	2020-07-16	12	[{"id_menu":3,"count":1}]	2938	pick-up	0	12
97307	2020-07-16 11:10:15	2020-07-16	9	[{"id_menu":6,"count":1}]	30384	delivery	5	14
97308	2020-07-16 11:10:42	2020-07-16	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	20993	delivery	5	25
97309	2020-07-16 11:16:44	2020-07-16	8	[{"id_menu":5,"count":1}]	2310	delivery	5	13
97310	2020-07-16 11:20:26	2020-07-16	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	34805	delivery	5	39
97311	2020-07-16 11:21:57	2020-07-16	9	[{"id_menu":6,"count":1}]	19971	delivery	5	14
97312	2020-07-16 11:23:53	2020-07-16	12	[{"id_menu":3,"count":1}]	6076	delivery	5	17
97313	2020-07-16 11:27:20	2020-07-16	9	[{"id_menu":6,"count":1}]	12685	delivery	5	14
97314	2020-07-16 11:30:20	2020-07-16	17	[{"id_menu":4,"count":1}]	37614	delivery	5	22
97315	2020-07-16 11:37:57	2020-07-16	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	12338	pick-up	0	26
97316	2020-07-16 11:37:57	2020-07-16	17	[{"id_menu":4,"count":1}]	37762	pick-up	0	17
97317	2020-07-16 11:40:15	2020-07-16	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	593	delivery	5	34
97318	2020-07-16 11:45:34	2020-07-16	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37795	delivery	5	40
97319	2020-07-16 11:45:51	2020-07-16	12	[{"id_menu":1,"count":1}]	37590	delivery	5	17
97320	2020-07-16 11:46:21	2020-07-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	37648	pick-up	0	23
97321	2020-07-16 11:48:05	2020-07-16	14	[{"id_menu":2,"count":1}]	25387	delivery	5	19
97322	2020-07-16 11:48:55	2020-07-16	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32523	delivery	5	22
97323	2020-07-16 11:55:35	2020-07-16	12	[{"id_menu":1,"count":1}]	37627	delivery	5	17
97324	2020-07-16 11:56:41	2020-07-16	9	[{"id_menu":6,"count":1}]	15913	pick-up	0	9
97325	2020-07-16 11:59:40	2020-07-16	12	[{"id_menu":1,"count":1}]	18683	delivery	5	17
97326	2020-07-16 12:03:14	2020-07-16	12	[{"id_menu":3,"count":1}]	19064	delivery	5	17
97327	2020-07-16 12:06:46	2020-07-16	8	[{"id_menu":5,"count":1}]	30099	pick-up	0	8
97328	2020-07-16 12:08:17	2020-07-16	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37737	delivery	5	37
97329	2020-07-16 12:16:07	2020-07-16	9	[{"id_menu":6,"count":2}]	37618	delivery	5	14
97330	2020-07-16 12:16:19	2020-07-16	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	18583	delivery	5	36
97331	2020-07-16 12:16:35	2020-07-16	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	30976	pick-up	0	26
97332	2020-07-16 12:16:36	2020-07-16	9	[{"id_menu":6,"count":1}]	14407	pick-up	0	9
97333	2020-07-16 12:16:46	2020-07-16	9	[{"id_menu":7,"count":1}]	967	pick-up	0	9
97334	2020-07-16 12:17:14	2020-07-16	14	[{"id_menu":2,"count":1}]	2617	pick-up	0	14
97335	2020-07-16 12:24:45	2020-07-16	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	37719	delivery	5	25
97336	2020-07-16 12:27:55	2020-07-16	9	[{"id_menu":7,"count":1}]	792	pick-up	0	9
97337	2020-07-16 12:31:44	2020-07-16	9	[{"id_menu":7,"count":1}]	23385	delivery	5	14
97338	2020-07-16 12:32:24	2020-07-16	9	[{"id_menu":7,"count":1}]	686	delivery	5	14
97339	2020-07-16 12:33:56	2020-07-16	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	16119	delivery	5	36
97340	2020-07-16 12:41:04	2020-07-16	9	[{"id_menu":7,"count":1}]	1507	delivery	5	14
97341	2020-07-16 12:46:50	2020-07-16	9	[{"id_menu":6,"count":1}]	1191	pick-up	0	9
97342	2020-07-16 12:49:20	2020-07-16	17	[{"id_menu":4,"count":1}]	20070	delivery	5	22
97343	2020-07-16 12:50:03	2020-07-16	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	20487	delivery	5	28
97344	2020-07-16 12:51:39	2020-07-16	8	[{"id_menu":5,"count":1}]	12224	pick-up	0	8
97345	2020-07-16 12:52:44	2020-07-16	17	[{"id_menu":4,"count":1}]	35804	pick-up	0	17
97346	2020-07-16 12:54:22	2020-07-16	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	20243	delivery	5	34
97347	2020-07-16 12:55:37	2020-07-16	9	[{"id_menu":7,"count":1}]	37785	delivery	5	14
97348	2020-07-16 12:55:40	2020-07-16	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	20929	delivery	5	34
97349	2020-07-16 12:57:46	2020-07-16	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	2513	delivery	5	34
97350	2020-07-16 13:00:45	2020-07-16	17	[{"id_menu":4,"count":1}]	32584	pick-up	0	17
97351	2020-07-16 13:05:13	2020-07-16	9	[{"id_menu":7,"count":1}]	2705	delivery	5	14
97352	2020-07-16 13:05:26	2020-07-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	25076	delivery	5	28
97353	2020-07-16 13:06:34	2020-07-16	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	7543	delivery	5	40
97354	2020-07-16 13:14:00	2020-07-16	14	[{"id_menu":2,"count":1}]	26065	delivery	5	19
97355	2020-07-16 13:16:42	2020-07-16	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4774	delivery	5	39
97356	2020-07-16 13:18:50	2020-07-16	9	[{"id_menu":6,"count":1}]	37657	delivery	5	14
97357	2020-07-16 13:21:04	2020-07-16	12	[{"id_menu":1,"count":1}]	102	pick-up	0	12
97358	2020-07-16 13:22:05	2020-07-16	9	[{"id_menu":7,"count":1}]	8300	pick-up	0	9
97359	2020-07-16 13:24:25	2020-07-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1700	pick-up	0	26
97360	2020-07-16 13:24:42	2020-07-16	9	[{"id_menu":7,"count":1}]	1742	delivery	5	14
97361	2020-07-16 13:25:47	2020-07-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	28232	delivery	5	31
97362	2020-07-16 13:27:50	2020-07-16	14	[{"id_menu":2,"count":2}]	31320	delivery	5	19
97363	2020-07-16 13:28:56	2020-07-16	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	37597	delivery	5	27
97364	2020-07-16 13:31:16	2020-07-16	9	[{"id_menu":7,"count":1}]	13806	pick-up	0	9
97365	2020-07-16 13:31:33	2020-07-16	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	18228	pick-up	0	31
97366	2020-07-16 13:33:49	2020-07-16	12	[{"id_menu":1,"count":1}]	18877	delivery	5	17
97367	2020-07-16 13:35:16	2020-07-16	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	33708	pick-up	0	39
97368	2020-07-16 13:36:23	2020-07-16	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37621	delivery	5	37
97369	2020-07-16 13:38:46	2020-07-16	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	28284	delivery	5	26
97370	2020-07-16 13:40:30	2020-07-16	14	[{"id_menu":2,"count":1}]	37656	delivery	5	19
97371	2020-07-16 13:42:09	2020-07-16	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	37798	delivery	5	27
97372	2020-07-16 13:42:25	2020-07-16	8	[{"id_menu":5,"count":1}]	32043	delivery	5	13
97373	2020-07-16 13:42:45	2020-07-16	12	[{"id_menu":1,"count":1}]	12707	delivery	5	17
97374	2020-07-16 13:43:03	2020-07-16	8	[{"id_menu":5,"count":1}]	6176	delivery	5	13
97375	2020-07-16 13:43:43	2020-07-16	17	[{"id_menu":4,"count":1}]	16774	delivery	5	22
97376	2020-07-16 13:44:02	2020-07-16	9	[{"id_menu":6,"count":1}]	34849	delivery	5	14
97377	2020-07-16 13:46:42	2020-07-16	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	16226	pick-up	0	26
97378	2020-07-16 13:47:44	2020-07-16	17	[{"id_menu":4,"count":1}]	25221	delivery	5	22
97379	2020-07-16 13:48:04	2020-07-16	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	37747	delivery	5	36
97380	2020-07-16 13:51:41	2020-07-16	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	19819	delivery	5	26
97381	2020-07-16 13:52:12	2020-07-16	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	37668	delivery	5	57
97382	2020-07-16 13:56:21	2020-07-16	8	[{"id_menu":5,"count":2}]	1670	pick-up	0	8
97383	2020-07-16 13:56:27	2020-07-16	9	[{"id_menu":6,"count":1}]	32093	delivery	5	14
97384	2020-07-16 13:56:53	2020-07-16	9	[{"id_menu":7,"count":1}]	6547	delivery	5	14
97385	2020-07-16 13:58:16	2020-07-16	9	[{"id_menu":6,"count":1}]	23083	delivery	5	14
97386	2020-07-16 14:01:10	2020-07-16	12	[{"id_menu":3,"count":1}]	37807	delivery	5	17
97387	2020-07-16 14:01:56	2020-07-16	9	[{"id_menu":6,"count":1}]	37781	delivery	5	14
97388	2020-07-16 14:03:39	2020-07-16	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	4409	delivery	5	26
97389	2020-07-16 14:07:03	2020-07-16	14	[{"id_menu":2,"count":1}]	13771	delivery	5	19
97390	2020-07-16 14:08:17	2020-07-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	12942	delivery	5	26
97391	2020-07-16 14:10:53	2020-07-16	14	[{"id_menu":2,"count":1}]	37673	delivery	5	19
97392	2020-07-16 14:14:54	2020-07-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":3}]	14677	delivery	5	22
97393	2020-07-16 14:16:42	2020-07-16	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	37794	delivery	5	25
97394	2020-07-16 14:18:02	2020-07-16	8	[{"id_menu":5,"count":1}]	6224	delivery	5	13
97395	2020-07-16 14:19:46	2020-07-16	9	[{"id_menu":7,"count":1}]	37796	delivery	5	14
97396	2020-07-16 14:20:39	2020-07-16	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	37607	delivery	5	31
97397	2020-07-16 14:23:22	2020-07-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	28026	delivery	5	31
97398	2020-07-16 14:25:22	2020-07-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	18348	pick-up	0	21
97399	2020-07-16 14:27:18	2020-07-16	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4918	pick-up	0	35
97400	2020-07-16 14:33:53	2020-07-16	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	9758	delivery	5	40
97401	2020-07-16 14:34:18	2020-07-16	9	[{"id_menu":6,"count":1}]	21101	pick-up	0	9
97402	2020-07-16 14:35:31	2020-07-16	17	[{"id_menu":4,"count":2}]	11789	delivery	5	22
97403	2020-07-16 14:35:35	2020-07-16	12	[{"id_menu":3,"count":1}]	7338	delivery	5	17
97404	2020-07-16 14:36:42	2020-07-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2951	delivery	5	28
97405	2020-07-16 14:36:44	2020-07-16	12	[{"id_menu":1,"count":1}]	14722	delivery	5	17
97406	2020-07-16 14:43:48	2020-07-16	55	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	21936	delivery	5	60
97407	2020-07-16 14:44:00	2020-07-16	12	[{"id_menu":1,"count":1}]	13593	delivery	5	17
97408	2020-07-16 14:49:26	2020-07-16	9	[{"id_menu":7,"count":1}]	37694	pick-up	0	9
97409	2020-07-16 14:51:03	2020-07-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37700	delivery	5	23
97410	2020-07-16 14:51:17	2020-07-16	8	[{"id_menu":5,"count":1}]	37636	delivery	5	13
97411	2020-07-16 14:52:37	2020-07-16	14	[{"id_menu":2,"count":1}]	14756	pick-up	0	14
97412	2020-07-16 14:52:52	2020-07-16	9	[{"id_menu":7,"count":2}]	24814	delivery	5	14
97413	2020-07-16 14:53:49	2020-07-16	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8052	delivery	5	37
97414	2020-07-16 14:56:50	2020-07-16	8	[{"id_menu":5,"count":1}]	2142	pick-up	0	8
97415	2020-07-16 14:56:51	2020-07-16	9	[{"id_menu":6,"count":1}]	37722	delivery	5	14
97416	2020-07-16 14:58:05	2020-07-16	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	37759	delivery	5	28
97417	2020-07-16 14:59:47	2020-07-16	8	[{"id_menu":5,"count":1}]	37635	delivery	5	13
97418	2020-07-16 15:00:31	2020-07-16	17	[{"id_menu":4,"count":1}]	21155	pick-up	0	17
97419	2020-07-16 15:01:04	2020-07-16	8	[{"id_menu":5,"count":1}]	37815	delivery	5	13
97420	2020-07-16 15:01:34	2020-07-16	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	12795	delivery	5	26
97421	2020-07-16 15:04:45	2020-07-16	8	[{"id_menu":5,"count":1}]	24504	delivery	5	13
97422	2020-07-16 15:04:57	2020-07-16	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	27426	delivery	5	26
97423	2020-07-16 15:12:54	2020-07-16	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	27023	delivery	5	31
97424	2020-07-16 15:13:00	2020-07-16	8	[{"id_menu":5,"count":1}]	37779	delivery	5	13
97425	2020-07-16 15:13:20	2020-07-16	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	36549	delivery	5	53
97426	2020-07-16 15:14:11	2020-07-16	9	[{"id_menu":7,"count":1}]	8908	delivery	5	14
97427	2020-07-16 15:18:09	2020-07-16	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	28456	pick-up	0	32
97428	2020-07-16 15:21:24	2020-07-16	8	[{"id_menu":5,"count":1}]	396	delivery	5	13
97429	2020-07-16 15:25:57	2020-07-16	32	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	37736	delivery	5	37
97430	2020-07-16 15:28:06	2020-07-16	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	30853	delivery	5	39
97431	2020-07-16 15:34:34	2020-07-16	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	754	pick-up	0	17
97432	2020-07-16 15:34:56	2020-07-16	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	33447	delivery	5	31
97433	2020-07-16 15:41:44	2020-07-16	17	[{"id_menu":4,"count":1}]	37679	delivery	5	22
97434	2020-07-16 15:42:17	2020-07-16	9	[{"id_menu":7,"count":1}]	37804	delivery	5	14
97435	2020-07-16 15:42:23	2020-07-16	9	[{"id_menu":7,"count":1}]	37704	delivery	5	14
97436	2020-07-16 15:45:36	2020-07-16	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36687	pick-up	0	38
97437	2020-07-16 15:45:39	2020-07-16	12	[{"id_menu":1,"count":1}]	25944	pick-up	0	12
97438	2020-07-16 15:46:44	2020-07-16	14	[{"id_menu":2,"count":1}]	4971	delivery	5	19
97439	2020-07-16 15:48:15	2020-07-16	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	26523	delivery	5	26
97440	2020-07-16 15:50:36	2020-07-16	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	381	delivery	5	31
97441	2020-07-16 15:53:07	2020-07-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	36832	delivery	5	26
97442	2020-07-16 16:07:55	2020-07-16	12	[{"id_menu":1,"count":1}]	10917	delivery	5	17
97443	2020-07-16 16:12:40	2020-07-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11750	delivery	5	23
97444	2020-07-16 16:15:30	2020-07-16	9	[{"id_menu":6,"count":1}]	37702	delivery	5	14
97445	2020-07-16 16:15:49	2020-07-16	8	[{"id_menu":5,"count":1}]	721	pick-up	0	8
97446	2020-07-16 16:22:18	2020-07-16	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1860	delivery	5	36
97447	2020-07-16 16:23:14	2020-07-16	9	[{"id_menu":7,"count":1}]	37685	delivery	5	14
97448	2020-07-16 16:27:56	2020-07-16	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	6207	delivery	5	26
97449	2020-07-16 16:29:58	2020-07-16	9	[{"id_menu":6,"count":1}]	11206	delivery	5	14
97450	2020-07-16 16:31:10	2020-07-16	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	37666	delivery	5	27
97451	2020-07-16 16:35:03	2020-07-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":3}]	13730	delivery	5	31
97452	2020-07-16 16:35:22	2020-07-16	14	[{"id_menu":2,"count":1}]	22892	delivery	5	19
97453	2020-07-16 16:36:39	2020-07-16	8	[{"id_menu":5,"count":1}]	37619	delivery	5	13
97454	2020-07-16 16:37:38	2020-07-16	9	[{"id_menu":6,"count":1}]	37602	delivery	5	14
97455	2020-07-16 16:39:06	2020-07-16	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	37824	delivery	5	43
97456	2020-07-16 16:39:30	2020-07-16	14	[{"id_menu":2,"count":1}]	22153	delivery	5	19
97457	2020-07-16 16:42:13	2020-07-16	17	[{"id_menu":4,"count":1}]	7689	pick-up	0	17
97458	2020-07-16 16:42:58	2020-07-16	9	[{"id_menu":6,"count":1}]	2101	delivery	5	14
97459	2020-07-16 16:44:31	2020-07-16	12	[{"id_menu":3,"count":1}]	27936	delivery	5	17
97460	2020-07-16 16:45:02	2020-07-16	8	[{"id_menu":5,"count":1}]	20598	delivery	5	13
97461	2020-07-16 16:49:59	2020-07-16	12	[{"id_menu":1,"count":1}]	27208	delivery	5	17
97462	2020-07-16 16:51:19	2020-07-16	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20398	delivery	5	39
97463	2020-07-16 16:51:24	2020-07-16	14	[{"id_menu":2,"count":1}]	37661	delivery	5	19
97464	2020-07-16 16:57:02	2020-07-16	9	[{"id_menu":6,"count":1}]	48	delivery	5	14
97465	2020-07-16 16:58:03	2020-07-16	8	[{"id_menu":5,"count":1}]	24461	delivery	5	13
97466	2020-07-16 17:00:46	2020-07-16	17	[{"id_menu":4,"count":1}]	37751	delivery	5	22
97467	2020-07-16 17:02:26	2020-07-16	9	[{"id_menu":6,"count":1}]	37783	delivery	5	14
97468	2020-07-16 17:03:05	2020-07-16	9	[{"id_menu":6,"count":1}]	4714	pick-up	0	9
97469	2020-07-16 17:03:22	2020-07-16	14	[{"id_menu":2,"count":1}]	37682	delivery	5	19
97470	2020-07-16 17:04:58	2020-07-16	9	[{"id_menu":6,"count":1}]	36349	delivery	5	14
97471	2020-07-16 17:08:07	2020-07-16	12	[{"id_menu":3,"count":2}]	11878	delivery	5	17
97472	2020-07-16 17:08:11	2020-07-16	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	37041	delivery	5	30
97473	2020-07-16 17:11:17	2020-07-16	8	[{"id_menu":5,"count":1}]	37773	delivery	5	13
97474	2020-07-16 17:12:33	2020-07-16	9	[{"id_menu":6,"count":1}]	37819	delivery	5	14
97475	2020-07-16 17:13:44	2020-07-16	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	37732	delivery	5	22
97476	2020-07-16 17:17:47	2020-07-16	9	[{"id_menu":6,"count":1}]	20467	delivery	5	14
97477	2020-07-16 17:20:24	2020-07-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	13855	pick-up	0	23
97478	2020-07-16 17:22:55	2020-07-16	9	[{"id_menu":7,"count":1}]	37634	delivery	5	14
97479	2020-07-16 17:25:31	2020-07-16	12	[{"id_menu":1,"count":1}]	18294	pick-up	0	12
97480	2020-07-16 17:25:57	2020-07-16	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11093	delivery	5	36
97481	2020-07-16 17:27:18	2020-07-16	9	[{"id_menu":6,"count":1}]	37612	delivery	5	14
97482	2020-07-16 17:27:50	2020-07-16	14	[{"id_menu":2,"count":1}]	37711	delivery	5	19
97483	2020-07-16 17:28:46	2020-07-16	9	[{"id_menu":7,"count":1}]	37784	delivery	5	14
97484	2020-07-16 17:29:52	2020-07-16	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	11357	delivery	5	31
97485	2020-07-16 17:35:22	2020-07-16	14	[{"id_menu":2,"count":1}]	37631	delivery	5	19
97486	2020-07-16 17:35:40	2020-07-16	9	[{"id_menu":6,"count":1}]	37649	delivery	5	14
97487	2020-07-16 17:38:27	2020-07-16	9	[{"id_menu":6,"count":1}]	37790	delivery	5	14
97488	2020-07-16 17:39:40	2020-07-16	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	5536	pick-up	0	29
97489	2020-07-16 17:41:26	2020-07-16	12	[{"id_menu":1,"count":1}]	37777	delivery	5	17
97490	2020-07-16 17:41:52	2020-07-16	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	34639	pick-up	0	20
97491	2020-07-16 17:42:39	2020-07-16	8	[{"id_menu":5,"count":1}]	25634	delivery	5	13
97492	2020-07-16 17:47:22	2020-07-16	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	3814	pick-up	0	26
97493	2020-07-16 17:49:11	2020-07-16	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	37683	delivery	5	31
97494	2020-07-16 17:52:46	2020-07-16	8	[{"id_menu":5,"count":1}]	37674	delivery	5	13
97495	2020-07-16 17:53:08	2020-07-16	8	[{"id_menu":5,"count":1}]	37604	delivery	5	13
97496	2020-07-16 17:53:45	2020-07-16	8	[{"id_menu":5,"count":1}]	35051	delivery	5	13
97497	2020-07-16 17:54:26	2020-07-16	12	[{"id_menu":1,"count":1}]	33883	delivery	5	17
97498	2020-07-16 17:55:32	2020-07-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	37280	delivery	5	28
97499	2020-07-16 17:57:49	2020-07-16	14	[{"id_menu":2,"count":1}]	37637	pick-up	0	14
97500	2020-07-16 17:58:55	2020-07-16	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1442	delivery	5	25
97501	2020-07-16 17:59:08	2020-07-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	5875	pick-up	0	23
97502	2020-07-16 17:59:35	2020-07-16	9	[{"id_menu":6,"count":1}]	36322	delivery	5	14
97503	2020-07-16 18:01:56	2020-07-16	17	[{"id_menu":4,"count":1}]	37808	delivery	5	22
97504	2020-07-16 18:03:37	2020-07-16	8	[{"id_menu":5,"count":1}]	37723	delivery	5	13
97505	2020-07-16 18:04:41	2020-07-16	17	[{"id_menu":4,"count":1}]	22934	delivery	5	22
97506	2020-07-16 18:04:49	2020-07-16	8	[{"id_menu":5,"count":1}]	10200	delivery	5	13
97507	2020-07-16 18:06:59	2020-07-16	9	[{"id_menu":7,"count":1}]	37782	delivery	5	14
97508	2020-07-16 18:08:26	2020-07-16	17	[{"id_menu":4,"count":1}]	17464	delivery	5	22
97509	2020-07-16 18:13:45	2020-07-16	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12895	delivery	5	36
97510	2020-07-16 18:15:08	2020-07-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	37594	delivery	5	22
97511	2020-07-16 18:16:41	2020-07-16	17	[{"id_menu":4,"count":1}]	37681	pick-up	0	17
97512	2020-07-16 18:17:26	2020-07-16	9	[{"id_menu":7,"count":1}]	2287	pick-up	0	9
97513	2020-07-16 18:18:55	2020-07-16	9	[{"id_menu":6,"count":1}]	17881	delivery	5	14
97514	2020-07-16 18:21:07	2020-07-16	9	[{"id_menu":6,"count":1}]	10938	delivery	5	14
97515	2020-07-16 18:24:55	2020-07-16	9	[{"id_menu":7,"count":1}]	176	delivery	5	14
97516	2020-07-16 18:25:52	2020-07-16	8	[{"id_menu":5,"count":1}]	27104	delivery	5	13
97517	2020-07-16 18:26:07	2020-07-16	8	[{"id_menu":5,"count":1}]	37675	delivery	5	13
97518	2020-07-16 18:28:01	2020-07-16	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	37609	delivery	5	26
97519	2020-07-16 18:31:18	2020-07-16	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	37813	delivery	5	22
97520	2020-07-16 18:32:26	2020-07-16	9	[{"id_menu":7,"count":1}]	37746	delivery	5	14
97521	2020-07-16 18:34:19	2020-07-16	14	[{"id_menu":2,"count":1}]	32	delivery	5	19
97522	2020-07-16 18:35:04	2020-07-16	17	[{"id_menu":4,"count":1}]	37724	delivery	5	22
97523	2020-07-16 18:38:06	2020-07-16	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	37730	pick-up	0	29
97524	2020-07-16 18:39:35	2020-07-16	8	[{"id_menu":5,"count":1}]	27783	delivery	5	13
97525	2020-07-16 18:43:20	2020-07-16	9	[{"id_menu":6,"count":1}]	4368	pick-up	0	9
97526	2020-07-16 18:50:28	2020-07-16	9	[{"id_menu":7,"count":1}]	34595	delivery	5	14
97527	2020-07-16 18:52:13	2020-07-16	17	[{"id_menu":4,"count":1}]	29470	delivery	5	22
97528	2020-07-16 18:52:44	2020-07-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	37708	delivery	5	22
97529	2020-07-16 18:54:02	2020-07-16	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37816	delivery	5	40
97530	2020-07-16 18:54:29	2020-07-16	14	[{"id_menu":2,"count":1}]	24295	delivery	5	19
97531	2020-07-16 18:54:39	2020-07-16	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37625	delivery	5	35
97532	2020-07-16 18:54:55	2020-07-16	12	[{"id_menu":3,"count":1}]	11797	pick-up	0	12
97533	2020-07-16 18:58:13	2020-07-16	9	[{"id_menu":6,"count":1}]	31733	delivery	5	14
97534	2020-07-16 19:02:47	2020-07-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	35951	delivery	5	22
97535	2020-07-16 19:07:12	2020-07-16	9	[{"id_menu":7,"count":1}]	12231	delivery	5	14
97536	2020-07-16 19:08:56	2020-07-16	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15594	pick-up	0	40
97537	2020-07-16 19:09:43	2020-07-16	12	[{"id_menu":1,"count":1}]	34935	delivery	5	17
97538	2020-07-16 19:10:54	2020-07-16	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	27159	delivery	5	36
97539	2020-07-16 19:12:29	2020-07-16	8	[{"id_menu":5,"count":1}]	27793	pick-up	0	8
97540	2020-07-16 19:13:15	2020-07-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	36772	delivery	5	28
97541	2020-07-16 19:13:46	2020-07-16	9	[{"id_menu":7,"count":1}]	17998	delivery	5	14
97542	2020-07-16 19:20:05	2020-07-16	12	[{"id_menu":3,"count":3}]	213	delivery	5	17
97543	2020-07-16 19:20:15	2020-07-16	14	[{"id_menu":2,"count":1}]	37755	pick-up	0	14
97544	2020-07-16 19:24:37	2020-07-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12945	delivery	5	31
97545	2020-07-16 19:25:09	2020-07-16	12	[{"id_menu":3,"count":1}]	4702	delivery	5	17
97546	2020-07-16 19:25:12	2020-07-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":3}]	27918	delivery	5	23
97547	2020-07-16 19:25:40	2020-07-16	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	24724	delivery	5	22
97548	2020-07-16 19:26:08	2020-07-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24511	delivery	5	23
97549	2020-07-16 19:26:35	2020-07-16	9	[{"id_menu":7,"count":1}]	24197	delivery	5	14
97550	2020-07-16 19:30:08	2020-07-16	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9081	delivery	5	36
97551	2020-07-16 19:33:09	2020-07-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	16632	pick-up	0	23
97552	2020-07-16 19:34:49	2020-07-16	14	[{"id_menu":2,"count":1}]	37739	pick-up	0	14
97553	2020-07-16 19:38:19	2020-07-16	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	20711	delivery	5	27
97554	2020-07-16 19:40:32	2020-07-16	8	[{"id_menu":5,"count":1}]	11316	delivery	5	13
97555	2020-07-16 19:41:20	2020-07-16	8	[{"id_menu":5,"count":1}]	25685	delivery	5	13
97556	2020-07-16 19:48:29	2020-07-16	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	10415	pick-up	0	20
97557	2020-07-16 19:49:12	2020-07-16	12	[{"id_menu":3,"count":1}]	9531	pick-up	0	12
97558	2020-07-16 19:54:13	2020-07-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	21562	delivery	5	26
97559	2020-07-16 19:58:19	2020-07-16	9	[{"id_menu":7,"count":1}]	2771	pick-up	0	9
97560	2020-07-16 19:58:34	2020-07-16	9	[{"id_menu":7,"count":1}]	22140	delivery	5	14
97561	2020-07-16 19:58:37	2020-07-16	9	[{"id_menu":6,"count":1}]	21154	delivery	5	14
97562	2020-07-16 19:59:01	2020-07-16	43	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	16893	delivery	5	48
97563	2020-07-16 20:01:11	2020-07-16	9	[{"id_menu":7,"count":1}]	9586	delivery	5	14
97564	2020-07-16 20:01:20	2020-07-16	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	19729	pick-up	0	21
97565	2020-07-16 20:03:12	2020-07-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":3}]	35807	delivery	5	28
97566	2020-07-16 20:06:45	2020-07-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32378	delivery	5	23
97567	2020-07-16 20:09:22	2020-07-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	37640	delivery	5	22
97568	2020-07-16 20:15:50	2020-07-16	12	[{"id_menu":3,"count":1}]	37713	delivery	5	17
97569	2020-07-16 20:17:13	2020-07-16	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	37599	delivery	5	40
97570	2020-07-16 20:18:39	2020-07-16	14	[{"id_menu":2,"count":1}]	28648	delivery	5	19
97571	2020-07-16 20:20:16	2020-07-16	12	[{"id_menu":3,"count":1}]	22965	pick-up	0	12
97572	2020-07-16 20:22:21	2020-07-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	22453	delivery	5	28
97573	2020-07-16 20:23:39	2020-07-16	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	37775	delivery	5	40
97574	2020-07-16 20:23:43	2020-07-16	9	[{"id_menu":7,"count":1}]	37786	delivery	5	14
97575	2020-07-16 20:24:30	2020-07-16	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	22283	pick-up	0	24
97576	2020-07-16 20:25:11	2020-07-16	12	[{"id_menu":1,"count":1}]	669	delivery	5	17
97577	2020-07-16 20:25:46	2020-07-16	12	[{"id_menu":3,"count":1}]	24996	pick-up	0	12
97578	2020-07-16 20:27:07	2020-07-16	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13054	pick-up	0	30
97579	2020-07-16 20:29:25	2020-07-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3851	pick-up	0	17
97580	2020-07-16 20:39:10	2020-07-16	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	3834	pick-up	0	26
97581	2020-07-16 20:42:49	2020-07-16	9	[{"id_menu":7,"count":1}]	37613	delivery	5	14
97582	2020-07-16 20:43:27	2020-07-16	12	[{"id_menu":1,"count":1}]	35194	delivery	5	17
97583	2020-07-16 20:44:05	2020-07-16	14	[{"id_menu":2,"count":1}]	749	pick-up	0	14
97584	2020-07-16 20:44:07	2020-07-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1031	delivery	5	28
97585	2020-07-16 20:47:26	2020-07-16	9	[{"id_menu":6,"count":1}]	33045	delivery	5	14
97586	2020-07-16 21:03:18	2020-07-16	9	[{"id_menu":6,"count":1}]	37778	delivery	5	14
97587	2020-07-16 21:05:32	2020-07-16	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	37754	delivery	5	31
97588	2020-07-16 21:06:19	2020-07-16	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	22168	delivery	5	30
97589	2020-07-16 21:07:18	2020-07-16	9	[{"id_menu":6,"count":1}]	37714	delivery	5	14
97590	2020-07-16 21:09:10	2020-07-16	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	14865	delivery	5	40
97591	2020-07-16 21:11:32	2020-07-16	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	36255	delivery	5	40
97592	2020-07-16 21:12:10	2020-07-16	17	[{"id_menu":4,"count":1}]	35201	delivery	5	22
97593	2020-07-16 21:13:51	2020-07-16	8	[{"id_menu":5,"count":1}]	5241	pick-up	0	8
97594	2020-07-16 21:21:54	2020-07-16	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":2}]	13014	delivery	5	31
97595	2020-07-16 21:22:04	2020-07-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	37692	delivery	5	22
97596	2020-07-16 21:23:09	2020-07-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	37810	delivery	5	26
97597	2020-07-16 21:24:06	2020-07-16	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	37624	delivery	5	45
97598	2020-07-16 21:26:53	2020-07-16	17	[{"id_menu":4,"count":1}]	23147	pick-up	0	17
97599	2020-07-16 21:30:20	2020-07-16	9	[{"id_menu":7,"count":1}]	37821	delivery	5	14
97600	2020-07-16 21:36:54	2020-07-16	12	[{"id_menu":3,"count":1}]	37653	delivery	5	17
97601	2020-07-16 21:42:25	2020-07-16	12	[{"id_menu":3,"count":1}]	10189	pick-up	0	12
97602	2020-07-16 21:43:02	2020-07-16	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3668	delivery	5	26
97603	2020-07-16 21:43:25	2020-07-16	17	[{"id_menu":4,"count":1}]	6	delivery	5	22
97604	2020-07-16 21:47:25	2020-07-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":3}]	19753	delivery	5	28
97605	2020-07-16 21:50:13	2020-07-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	37400	pick-up	0	26
97606	2020-07-16 21:50:27	2020-07-16	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	32063	delivery	5	31
97607	2020-07-16 21:51:31	2020-07-16	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	35105	delivery	5	34
97608	2020-07-16 21:53:20	2020-07-16	12	[{"id_menu":1,"count":1}]	36138	delivery	5	17
97609	2020-07-16 21:54:52	2020-07-16	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15571	delivery	5	35
97610	2020-07-16 21:54:54	2020-07-16	8	[{"id_menu":5,"count":1}]	18390	delivery	5	13
97611	2020-07-16 21:56:11	2020-07-16	14	[{"id_menu":2,"count":2}]	26556	delivery	5	19
97612	2020-07-16 21:57:26	2020-07-16	9	[{"id_menu":7,"count":1}]	33870	delivery	5	14
97613	2020-07-16 21:59:36	2020-07-16	14	[{"id_menu":2,"count":1}]	11326	pick-up	0	14
97614	2020-07-16 21:59:43	2020-07-16	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37756	delivery	5	40
97615	2020-07-16 22:00:47	2020-07-16	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	37641	delivery	5	45
97616	2020-07-16 22:02:07	2020-07-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	22923	delivery	5	28
97617	2020-07-16 22:05:56	2020-07-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6622	delivery	5	22
97618	2020-07-16 22:06:51	2020-07-16	12	[{"id_menu":1,"count":1}]	8335	pick-up	0	12
97619	2020-07-16 22:08:12	2020-07-16	12	[{"id_menu":3,"count":1}]	11816	delivery	5	17
97620	2020-07-16 22:11:13	2020-07-16	12	[{"id_menu":3,"count":1}]	10425	pick-up	0	12
97621	2020-07-16 22:13:10	2020-07-16	12	[{"id_menu":3,"count":1}]	8778	pick-up	0	12
97622	2020-07-16 22:14:53	2020-07-16	12	[{"id_menu":3,"count":1}]	22363	delivery	5	17
97623	2020-07-16 22:15:26	2020-07-16	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	37391	delivery	5	30
97624	2020-07-16 22:18:24	2020-07-16	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	37591	delivery	5	55
97625	2020-07-16 22:19:01	2020-07-16	9	[{"id_menu":7,"count":1}]	37642	delivery	5	14
97626	2020-07-16 22:22:03	2020-07-16	14	[{"id_menu":2,"count":1}]	15449	pick-up	0	14
97627	2020-07-16 22:25:00	2020-07-16	8	[{"id_menu":5,"count":1}]	22246	delivery	5	13
97628	2020-07-16 22:35:40	2020-07-16	12	[{"id_menu":1,"count":1}]	17544	pick-up	0	12
97629	2020-07-16 22:40:41	2020-07-16	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14347	delivery	5	52
97630	2020-07-16 22:42:38	2020-07-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	35595	delivery	5	26
97631	2020-07-16 22:43:05	2020-07-16	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	34081	delivery	5	44
97632	2020-07-16 22:53:53	2020-07-16	9	[{"id_menu":7,"count":1}]	16282	delivery	5	14
97633	2020-07-16 22:54:35	2020-07-16	9	[{"id_menu":7,"count":1}]	37745	delivery	5	14
97634	2020-07-16 22:55:33	2020-07-16	14	[{"id_menu":2,"count":1}]	37678	pick-up	0	14
97635	2020-07-16 22:59:03	2020-07-16	12	[{"id_menu":3,"count":1}]	37616	delivery	5	17
97636	2020-07-16 22:59:13	2020-07-16	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	1316	delivery	5	23
97637	2020-07-16 23:00:23	2020-07-16	9	[{"id_menu":6,"count":1}]	18602	pick-up	0	9
97638	2020-07-16 23:01:35	2020-07-16	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	29931	delivery	5	39
97639	2020-07-16 23:02:12	2020-07-16	14	[{"id_menu":2,"count":1}]	1681	pick-up	0	14
97640	2020-07-16 23:02:50	2020-07-16	14	[{"id_menu":2,"count":1}]	13393	delivery	5	19
97641	2020-07-16 23:03:31	2020-07-16	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12650	delivery	5	39
97642	2020-07-16 23:06:05	2020-07-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	16450	delivery	5	26
97643	2020-07-16 23:08:25	2020-07-16	9	[{"id_menu":6,"count":1}]	37791	delivery	5	14
97644	2020-07-16 23:12:16	2020-07-16	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	33109	delivery	5	22
97645	2020-07-16 23:17:14	2020-07-16	9	[{"id_menu":7,"count":1}]	4040	delivery	5	14
97646	2020-07-16 23:17:33	2020-07-16	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	13270	delivery	5	36
97647	2020-07-16 23:18:30	2020-07-16	8	[{"id_menu":5,"count":1}]	37596	delivery	5	13
97648	2020-07-16 23:21:42	2020-07-16	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	37805	delivery	5	40
97649	2020-07-16 23:22:41	2020-07-16	17	[{"id_menu":4,"count":1}]	31661	pick-up	0	17
97650	2020-07-16 23:23:05	2020-07-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	5662	delivery	5	26
97651	2020-07-16 23:23:28	2020-07-16	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	24842	delivery	5	36
97652	2020-07-16 23:28:20	2020-07-16	17	[{"id_menu":4,"count":1}]	37691	delivery	5	22
97653	2020-07-16 23:29:18	2020-07-16	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34096	delivery	5	48
97654	2020-07-16 23:32:22	2020-07-16	9	[{"id_menu":6,"count":1}]	37761	delivery	5	14
97655	2020-07-16 23:32:50	2020-07-16	12	[{"id_menu":3,"count":1}]	31180	delivery	5	17
97656	2020-07-16 23:36:53	2020-07-16	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	31930	delivery	5	25
97657	2020-07-16 23:38:29	2020-07-16	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":3}]	37655	delivery	5	26
97658	2020-07-16 23:38:47	2020-07-16	12	[{"id_menu":1,"count":1}]	21182	delivery	5	17
97659	2020-07-16 23:42:08	2020-07-16	17	[{"id_menu":4,"count":1}]	91	pick-up	0	17
97660	2020-07-16 23:44:28	2020-07-16	17	[{"id_menu":4,"count":1}]	37788	delivery	5	22
97661	2020-07-16 23:45:21	2020-07-16	9	[{"id_menu":7,"count":1}]	37823	delivery	5	14
97662	2020-07-16 23:46:25	2020-07-16	12	[{"id_menu":3,"count":1}]	37271	pick-up	0	12
97663	2020-07-16 23:51:34	2020-07-16	14	[{"id_menu":2,"count":1}]	9804	pick-up	0	14
97664	2020-07-16 23:54:23	2020-07-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":3}]	37652	delivery	5	22
97665	2020-07-16 23:55:00	2020-07-16	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	18897	delivery	5	23
97666	2020-07-16 23:58:07	2020-07-16	9	[{"id_menu":6,"count":1}]	26152	delivery	5	14
97667	2020-07-16 23:58:09	2020-07-16	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	19978	delivery	5	40
97668	2020-07-16 23:58:43	2020-07-16	12	[{"id_menu":3,"count":1}]	37698	delivery	5	17
97669	2020-07-16 23:59:33	2020-07-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	12932	delivery	5	28
97670	2020-07-16 23:59:40	2020-07-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	37663	delivery	5	28
97671	2020-07-17 00:02:50	2020-07-17	12	[{"id_menu":3,"count":1}]	24170	pick-up	0	12
97672	2020-07-17 00:04:06	2020-07-17	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	24165	delivery	5	25
97673	2020-07-17 00:07:49	2020-07-17	14	[{"id_menu":2,"count":2}]	397	delivery	5	19
97674	2020-07-17 00:08:24	2020-07-17	12	[{"id_menu":1,"count":1}]	37810	delivery	5	17
97675	2020-07-17 00:11:04	2020-07-17	14	[{"id_menu":2,"count":1}]	37907	delivery	5	19
97676	2020-07-17 00:13:00	2020-07-17	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	29895	delivery	5	26
97677	2020-07-17 00:15:54	2020-07-17	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	3544	pick-up	0	20
97678	2020-07-17 00:18:15	2020-07-17	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	20354	delivery	5	23
97679	2020-07-17 00:21:53	2020-07-17	14	[{"id_menu":2,"count":1}]	787	pick-up	0	14
97680	2020-07-17 00:24:59	2020-07-17	9	[{"id_menu":6,"count":1}]	11979	delivery	5	14
97681	2020-07-17 00:25:39	2020-07-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	25067	delivery	5	28
97682	2020-07-17 00:27:00	2020-07-17	14	[{"id_menu":2,"count":1}]	15720	pick-up	0	14
97683	2020-07-17 00:27:48	2020-07-17	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14061	delivery	5	35
97684	2020-07-17 00:28:06	2020-07-17	9	[{"id_menu":7,"count":1}]	38035	delivery	5	14
97685	2020-07-17 00:29:29	2020-07-17	9	[{"id_menu":6,"count":1}]	38070	delivery	5	14
97686	2020-07-17 00:29:36	2020-07-17	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	5167	pick-up	0	20
97687	2020-07-17 00:30:37	2020-07-17	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	18090	delivery	5	27
97688	2020-07-17 00:35:47	2020-07-17	17	[{"id_menu":4,"count":1}]	29929	delivery	5	22
97689	2020-07-17 00:36:23	2020-07-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18927	delivery	5	23
97690	2020-07-17 00:37:59	2020-07-17	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31358	delivery	5	40
97691	2020-07-17 00:45:39	2020-07-17	12	[{"id_menu":3,"count":1}]	21899	pick-up	0	12
97692	2020-07-17 00:46:32	2020-07-17	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	21418	delivery	5	42
97693	2020-07-17 00:53:05	2020-07-17	8	[{"id_menu":5,"count":1}]	33771	delivery	5	13
97694	2020-07-17 00:54:09	2020-07-17	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	35814	delivery	5	27
97695	2020-07-17 00:57:58	2020-07-17	8	[{"id_menu":5,"count":1}]	32503	pick-up	0	8
97696	2020-07-17 00:58:42	2020-07-17	9	[{"id_menu":6,"count":1}]	76	delivery	5	14
97697	2020-07-17 01:00:16	2020-07-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	37990	delivery	5	31
97698	2020-07-17 01:01:30	2020-07-17	12	[{"id_menu":3,"count":1}]	21410	delivery	5	17
97699	2020-07-17 01:04:51	2020-07-17	14	[{"id_menu":2,"count":1}]	14979	delivery	5	19
97700	2020-07-17 01:06:23	2020-07-17	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38059	delivery	5	40
97701	2020-07-17 01:06:38	2020-07-17	9	[{"id_menu":7,"count":1}]	37860	pick-up	0	9
97702	2020-07-17 01:06:42	2020-07-17	12	[{"id_menu":1,"count":1}]	4368	pick-up	0	12
97703	2020-07-17 01:07:55	2020-07-17	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	37945	delivery	5	27
97704	2020-07-17 01:17:09	2020-07-17	12	[{"id_menu":3,"count":1}]	8574	pick-up	0	12
97705	2020-07-17 01:18:22	2020-07-17	8	[{"id_menu":5,"count":1}]	35064	delivery	5	13
97706	2020-07-17 01:19:52	2020-07-17	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	6164	pick-up	0	26
97707	2020-07-17 01:20:01	2020-07-17	12	[{"id_menu":1,"count":2}]	37833	delivery	5	17
97708	2020-07-17 01:21:57	2020-07-17	14	[{"id_menu":2,"count":2}]	38084	pick-up	0	14
97709	2020-07-17 01:23:57	2020-07-17	12	[{"id_menu":3,"count":1}]	20765	pick-up	0	12
97710	2020-07-17 01:24:48	2020-07-17	14	[{"id_menu":2,"count":1}]	27359	delivery	5	19
97711	2020-07-17 01:25:22	2020-07-17	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	37919	delivery	5	22
97712	2020-07-17 01:26:21	2020-07-17	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	28959	delivery	5	31
97713	2020-07-17 01:26:55	2020-07-17	17	[{"id_menu":4,"count":1}]	10771	delivery	5	22
97714	2020-07-17 01:27:51	2020-07-17	12	[{"id_menu":3,"count":1}]	16955	delivery	5	17
97715	2020-07-17 01:30:30	2020-07-17	17	[{"id_menu":4,"count":1}]	13948	delivery	5	22
97716	2020-07-17 01:36:19	2020-07-17	14	[{"id_menu":2,"count":1}]	26853	delivery	5	19
97717	2020-07-17 01:38:59	2020-07-17	12	[{"id_menu":3,"count":1}]	35855	pick-up	0	12
97718	2020-07-17 01:40:20	2020-07-17	14	[{"id_menu":2,"count":1}]	12578	pick-up	0	14
97719	2020-07-17 01:41:22	2020-07-17	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	38008	delivery	5	22
97720	2020-07-17 01:42:05	2020-07-17	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9923	delivery	5	31
97721	2020-07-17 01:42:38	2020-07-17	9	[{"id_menu":7,"count":1}]	37910	delivery	5	14
97722	2020-07-17 01:43:07	2020-07-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	38072	delivery	5	31
97723	2020-07-17 01:44:33	2020-07-17	9	[{"id_menu":6,"count":1}]	3755	pick-up	0	9
97724	2020-07-17 01:46:06	2020-07-17	29	[{"id_menu":3,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25377	delivery	5	34
97725	2020-07-17 01:49:11	2020-07-17	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	24616	delivery	5	25
97726	2020-07-17 01:51:03	2020-07-17	9	[{"id_menu":6,"count":1}]	37941	delivery	5	14
97727	2020-07-17 01:51:07	2020-07-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38063	delivery	5	23
97728	2020-07-17 01:59:48	2020-07-17	12	[{"id_menu":1,"count":1}]	14191	delivery	5	17
97729	2020-07-17 02:03:24	2020-07-17	9	[{"id_menu":7,"count":1}]	37917	delivery	5	14
97730	2020-07-17 02:04:45	2020-07-17	17	[{"id_menu":4,"count":1}]	18309	pick-up	0	17
97731	2020-07-17 02:14:23	2020-07-17	12	[{"id_menu":3,"count":1}]	28728	delivery	5	17
97732	2020-07-17 02:14:40	2020-07-17	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	38010	delivery	5	26
97733	2020-07-17 02:21:35	2020-07-17	12	[{"id_menu":1,"count":1}]	1649	delivery	5	17
97734	2020-07-17 02:21:59	2020-07-17	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	37868	delivery	5	26
97735	2020-07-17 02:22:14	2020-07-17	12	[{"id_menu":1,"count":1}]	6665	delivery	5	17
97736	2020-07-17 02:29:22	2020-07-17	17	[{"id_menu":4,"count":1}]	37968	pick-up	0	17
97737	2020-07-17 02:35:03	2020-07-17	14	[{"id_menu":2,"count":1}]	37535	delivery	5	19
97738	2020-07-17 02:36:49	2020-07-17	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5126	delivery	5	45
97739	2020-07-17 02:40:18	2020-07-17	9	[{"id_menu":6,"count":1}]	5192	delivery	5	14
97740	2020-07-17 02:41:27	2020-07-17	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	33346	delivery	5	34
97741	2020-07-17 02:41:29	2020-07-17	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	38001	delivery	5	39
97742	2020-07-17 02:44:28	2020-07-17	9	[{"id_menu":7,"count":1}]	37921	delivery	5	14
97743	2020-07-17 02:46:10	2020-07-17	12	[{"id_menu":1,"count":1}]	8146	pick-up	0	12
97744	2020-07-17 02:50:25	2020-07-17	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	37911	delivery	5	27
97745	2020-07-17 02:52:48	2020-07-17	14	[{"id_menu":2,"count":2}]	37857	delivery	5	19
97746	2020-07-17 02:54:43	2020-07-17	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	19741	delivery	5	34
97747	2020-07-17 02:55:41	2020-07-17	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	20384	delivery	5	40
97748	2020-07-17 02:56:04	2020-07-17	12	[{"id_menu":1,"count":1}]	2351	pick-up	0	12
97749	2020-07-17 02:57:29	2020-07-17	12	[{"id_menu":1,"count":1}]	7162	delivery	5	17
97750	2020-07-17 02:58:00	2020-07-17	14	[{"id_menu":2,"count":1}]	35715	delivery	5	19
97751	2020-07-17 03:06:01	2020-07-17	12	[{"id_menu":1,"count":1}]	2715	delivery	5	17
97752	2020-07-17 03:07:53	2020-07-17	9	[{"id_menu":7,"count":1}]	1618	pick-up	0	9
97753	2020-07-17 03:08:44	2020-07-17	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":2}]	37893	delivery	5	26
97754	2020-07-17 03:14:11	2020-07-17	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	38012	delivery	5	37
97755	2020-07-17 03:22:56	2020-07-17	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28636	delivery	5	31
97756	2020-07-17 03:26:58	2020-07-17	9	[{"id_menu":6,"count":1}]	10476	delivery	5	14
97757	2020-07-17 03:26:59	2020-07-17	14	[{"id_menu":2,"count":1}]	17423	pick-up	0	14
97758	2020-07-17 03:27:13	2020-07-17	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	35315	delivery	5	40
97759	2020-07-17 03:28:37	2020-07-17	8	[{"id_menu":5,"count":1}]	5688	pick-up	0	8
97760	2020-07-17 03:30:22	2020-07-17	17	[{"id_menu":4,"count":1}]	37870	delivery	5	22
97761	2020-07-17 03:32:33	2020-07-17	9	[{"id_menu":6,"count":1}]	23959	pick-up	0	9
97762	2020-07-17 03:32:37	2020-07-17	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	14947	pick-up	0	31
97763	2020-07-17 03:34:04	2020-07-17	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	7330	delivery	5	26
97764	2020-07-17 03:34:10	2020-07-17	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	3231	delivery	5	45
97765	2020-07-17 03:34:35	2020-07-17	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38104	delivery	5	54
97766	2020-07-17 03:35:13	2020-07-17	9	[{"id_menu":7,"count":1}]	16528	delivery	5	14
97767	2020-07-17 03:39:34	2020-07-17	14	[{"id_menu":2,"count":1}]	31458	delivery	5	19
97768	2020-07-17 03:39:54	2020-07-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	23500	delivery	5	28
97769	2020-07-17 03:39:55	2020-07-17	9	[{"id_menu":7,"count":1}]	27970	delivery	5	14
97770	2020-07-17 03:41:08	2020-07-17	9	[{"id_menu":7,"count":1}]	20971	delivery	5	14
97771	2020-07-17 03:42:46	2020-07-17	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	788	delivery	5	36
97772	2020-07-17 03:45:18	2020-07-17	9	[{"id_menu":7,"count":1}]	794	delivery	5	14
97773	2020-07-17 03:46:44	2020-07-17	9	[{"id_menu":7,"count":1}]	27287	delivery	5	14
97774	2020-07-17 03:47:12	2020-07-17	17	[{"id_menu":4,"count":1}]	596	pick-up	0	17
97775	2020-07-17 03:47:21	2020-07-17	17	[{"id_menu":4,"count":1}]	1869	delivery	5	22
97776	2020-07-17 03:49:07	2020-07-17	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	11158	delivery	5	36
97777	2020-07-17 03:50:34	2020-07-17	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	28808	delivery	5	36
97778	2020-07-17 03:52:40	2020-07-17	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	477	delivery	5	25
97779	2020-07-17 03:52:43	2020-07-17	9	[{"id_menu":7,"count":1}]	31192	pick-up	0	9
97780	2020-07-17 03:57:01	2020-07-17	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	37992	delivery	5	22
97781	2020-07-17 04:01:35	2020-07-17	17	[{"id_menu":4,"count":1}]	15582	pick-up	0	17
97782	2020-07-17 04:03:57	2020-07-17	9	[{"id_menu":7,"count":1}]	38066	delivery	5	14
97783	2020-07-17 04:04:16	2020-07-17	14	[{"id_menu":2,"count":1}]	9888	delivery	5	19
97784	2020-07-17 04:04:33	2020-07-17	9	[{"id_menu":6,"count":1}]	18642	delivery	5	14
97785	2020-07-17 04:06:05	2020-07-17	9	[{"id_menu":7,"count":1}]	37946	delivery	5	14
97786	2020-07-17 04:08:20	2020-07-17	9	[{"id_menu":6,"count":1}]	7040	delivery	5	14
97787	2020-07-17 04:09:09	2020-07-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35796	delivery	5	23
97788	2020-07-17 04:10:10	2020-07-17	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	28067	delivery	5	22
97789	2020-07-17 04:10:23	2020-07-17	9	[{"id_menu":7,"count":2}]	36347	pick-up	0	9
97790	2020-07-17 04:11:44	2020-07-17	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	37956	delivery	5	39
97791	2020-07-17 04:12:12	2020-07-17	8	[{"id_menu":5,"count":1}]	26911	pick-up	0	8
97792	2020-07-17 04:13:26	2020-07-17	9	[{"id_menu":6,"count":1}]	30226	delivery	5	14
97793	2020-07-17 04:13:50	2020-07-17	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	32697	delivery	5	45
97794	2020-07-17 04:14:18	2020-07-17	12	[{"id_menu":1,"count":1}]	37832	delivery	5	17
97795	2020-07-17 04:15:50	2020-07-17	12	[{"id_menu":1,"count":1}]	24989	delivery	5	17
97796	2020-07-17 04:16:55	2020-07-17	9	[{"id_menu":7,"count":1}]	36456	delivery	5	14
97797	2020-07-17 04:17:06	2020-07-17	14	[{"id_menu":2,"count":1}]	37901	delivery	5	19
97798	2020-07-17 04:21:44	2020-07-17	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2499	delivery	5	31
97799	2020-07-17 04:28:31	2020-07-17	12	[{"id_menu":1,"count":1}]	37949	delivery	5	17
97800	2020-07-17 04:31:46	2020-07-17	9	[{"id_menu":6,"count":1}]	11116	pick-up	0	9
97801	2020-07-17 04:32:14	2020-07-17	9	[{"id_menu":6,"count":1}]	6478	delivery	5	14
97802	2020-07-17 04:33:30	2020-07-17	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	38060	delivery	5	26
97803	2020-07-17 04:35:40	2020-07-17	9	[{"id_menu":7,"count":1}]	31571	pick-up	0	9
97804	2020-07-17 04:36:18	2020-07-17	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	37935	delivery	5	28
97805	2020-07-17 04:38:38	2020-07-17	8	[{"id_menu":5,"count":1}]	38064	delivery	5	13
97806	2020-07-17 04:39:24	2020-07-17	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	36273	delivery	5	26
97807	2020-07-17 04:39:32	2020-07-17	12	[{"id_menu":1,"count":1}]	15906	delivery	5	17
97808	2020-07-17 04:39:40	2020-07-17	8	[{"id_menu":5,"count":1}]	37887	pick-up	0	8
97809	2020-07-17 04:40:46	2020-07-17	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24078	delivery	5	36
97810	2020-07-17 04:43:19	2020-07-17	14	[{"id_menu":2,"count":1}]	13865	delivery	5	19
97811	2020-07-17 04:45:21	2020-07-17	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	24513	pick-up	0	25
97812	2020-07-17 04:45:21	2020-07-17	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31717	delivery	5	49
97813	2020-07-17 04:46:00	2020-07-17	17	[{"id_menu":4,"count":1}]	32410	pick-up	0	17
97814	2020-07-17 04:46:06	2020-07-17	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	38089	delivery	5	42
97815	2020-07-17 04:48:05	2020-07-17	14	[{"id_menu":2,"count":1}]	37998	delivery	5	19
97816	2020-07-17 04:48:08	2020-07-17	8	[{"id_menu":5,"count":1}]	112	pick-up	0	8
97817	2020-07-17 04:50:58	2020-07-17	14	[{"id_menu":2,"count":1}]	38107	delivery	5	19
97818	2020-07-17 04:51:49	2020-07-17	9	[{"id_menu":7,"count":2}]	24171	delivery	5	14
97819	2020-07-17 04:52:25	2020-07-17	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	12236	delivery	5	44
97820	2020-07-17 04:59:36	2020-07-17	12	[{"id_menu":3,"count":1}]	37865	delivery	5	17
97821	2020-07-17 04:59:43	2020-07-17	9	[{"id_menu":6,"count":2}]	630	pick-up	0	9
97822	2020-07-17 05:00:58	2020-07-17	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	38056	delivery	5	29
97823	2020-07-17 05:03:13	2020-07-17	14	[{"id_menu":2,"count":1}]	38100	delivery	5	19
97824	2020-07-17 05:06:04	2020-07-17	9	[{"id_menu":6,"count":1}]	29097	delivery	5	14
97825	2020-07-17 05:07:44	2020-07-17	14	[{"id_menu":2,"count":1}]	37889	delivery	5	19
97826	2020-07-17 05:09:20	2020-07-17	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	38024	delivery	5	40
97827	2020-07-17 05:10:30	2020-07-17	14	[{"id_menu":2,"count":1}]	28230	delivery	5	19
97828	2020-07-17 05:11:14	2020-07-17	9	[{"id_menu":6,"count":1}]	37532	pick-up	0	9
97829	2020-07-17 05:13:06	2020-07-17	9	[{"id_menu":7,"count":1}]	37947	delivery	5	14
97830	2020-07-17 05:16:04	2020-07-17	9	[{"id_menu":6,"count":1}]	37965	delivery	5	14
97831	2020-07-17 05:18:38	2020-07-17	14	[{"id_menu":2,"count":1}]	30704	delivery	5	19
97832	2020-07-17 05:19:27	2020-07-17	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	639	pick-up	0	31
97833	2020-07-17 05:20:31	2020-07-17	12	[{"id_menu":3,"count":1}]	4867	pick-up	0	12
97834	2020-07-17 05:22:05	2020-07-17	9	[{"id_menu":6,"count":1}]	15829	pick-up	0	9
97835	2020-07-17 05:23:53	2020-07-17	12	[{"id_menu":3,"count":1}]	38091	delivery	5	17
97836	2020-07-17 05:26:01	2020-07-17	12	[{"id_menu":3,"count":1}]	37993	delivery	5	17
97837	2020-07-17 05:33:22	2020-07-17	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	35529	delivery	5	43
97838	2020-07-17 05:33:58	2020-07-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	38085	delivery	5	31
97839	2020-07-17 05:35:08	2020-07-17	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2080	pick-up	0	26
97840	2020-07-17 05:35:09	2020-07-17	14	[{"id_menu":2,"count":2}]	38041	delivery	5	19
97841	2020-07-17 05:35:43	2020-07-17	14	[{"id_menu":2,"count":1}]	26153	delivery	5	19
97842	2020-07-17 05:43:03	2020-07-17	9	[{"id_menu":7,"count":1}]	13881	delivery	5	14
97843	2020-07-17 05:44:39	2020-07-17	17	[{"id_menu":4,"count":1}]	32040	delivery	5	22
97844	2020-07-17 05:49:39	2020-07-17	14	[{"id_menu":2,"count":1}]	37792	delivery	5	19
97845	2020-07-17 05:54:19	2020-07-17	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	36375	delivery	5	36
97846	2020-07-17 05:59:08	2020-07-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	26279	delivery	5	28
97847	2020-07-17 05:59:56	2020-07-17	9	[{"id_menu":6,"count":1}]	37894	delivery	5	14
97848	2020-07-17 06:03:33	2020-07-17	17	[{"id_menu":4,"count":1}]	37872	delivery	5	22
97849	2020-07-17 06:08:56	2020-07-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	10717	pick-up	0	23
97850	2020-07-17 06:10:49	2020-07-17	9	[{"id_menu":6,"count":1}]	2416	pick-up	0	9
97851	2020-07-17 06:19:54	2020-07-17	9	[{"id_menu":7,"count":1}]	2951	delivery	5	14
97852	2020-07-17 06:22:28	2020-07-17	9	[{"id_menu":6,"count":1}]	33004	delivery	5	14
97853	2020-07-17 06:25:14	2020-07-17	17	[{"id_menu":4,"count":1}]	37960	delivery	5	22
97854	2020-07-17 06:28:03	2020-07-17	8	[{"id_menu":5,"count":1}]	36569	delivery	5	13
97855	2020-07-17 06:28:09	2020-07-17	14	[{"id_menu":2,"count":1}]	24768	delivery	5	19
97856	2020-07-17 06:34:33	2020-07-17	9	[{"id_menu":6,"count":1}]	12977	delivery	5	14
97857	2020-07-17 06:37:43	2020-07-17	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	38103	delivery	5	40
97858	2020-07-17 06:38:42	2020-07-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	37853	delivery	5	23
97859	2020-07-17 06:43:54	2020-07-17	12	[{"id_menu":1,"count":1}]	28685	delivery	5	17
97860	2020-07-17 06:56:16	2020-07-17	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	14378	pick-up	0	37
97861	2020-07-17 06:59:48	2020-07-17	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	4483	delivery	5	34
97862	2020-07-17 07:03:50	2020-07-17	9	[{"id_menu":6,"count":1}]	38088	delivery	5	14
97863	2020-07-17 07:06:10	2020-07-17	9	[{"id_menu":6,"count":1}]	37955	pick-up	0	9
97864	2020-07-17 07:07:58	2020-07-17	17	[{"id_menu":4,"count":1}]	3655	pick-up	0	17
97865	2020-07-17 07:12:39	2020-07-17	17	[{"id_menu":4,"count":1}]	8039	delivery	5	22
97866	2020-07-17 07:13:23	2020-07-17	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	37855	delivery	5	31
97867	2020-07-17 07:14:08	2020-07-17	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2572	delivery	5	45
97868	2020-07-17 07:14:28	2020-07-17	14	[{"id_menu":2,"count":1}]	640	pick-up	0	14
97869	2020-07-17 07:15:29	2020-07-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	32111	delivery	5	28
97870	2020-07-17 07:17:44	2020-07-17	9	[{"id_menu":7,"count":1}]	33169	delivery	5	14
97871	2020-07-17 07:19:25	2020-07-17	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	37986	delivery	5	26
97872	2020-07-17 07:19:27	2020-07-17	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	26392	delivery	5	36
97873	2020-07-17 07:20:51	2020-07-17	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	34885	delivery	5	31
97874	2020-07-17 07:28:47	2020-07-17	8	[{"id_menu":5,"count":1}]	5584	delivery	5	13
97875	2020-07-17 07:28:57	2020-07-17	9	[{"id_menu":7,"count":1}]	36986	delivery	5	14
97876	2020-07-17 07:29:56	2020-07-17	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	38079	delivery	5	26
97877	2020-07-17 07:32:26	2020-07-17	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	27838	delivery	5	30
97878	2020-07-17 07:35:57	2020-07-17	8	[{"id_menu":5,"count":1}]	37948	delivery	5	13
97879	2020-07-17 07:36:30	2020-07-17	12	[{"id_menu":1,"count":1}]	35792	delivery	5	17
97880	2020-07-17 07:42:32	2020-07-17	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	33547	delivery	5	30
97881	2020-07-17 07:42:40	2020-07-17	9	[{"id_menu":6,"count":1}]	31444	delivery	5	14
97882	2020-07-17 07:43:32	2020-07-17	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	33326	delivery	5	51
97883	2020-07-17 07:43:40	2020-07-17	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	7689	pick-up	0	21
97884	2020-07-17 07:45:13	2020-07-17	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	37886	delivery	5	36
97885	2020-07-17 07:49:05	2020-07-17	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	36045	delivery	5	22
97886	2020-07-17 07:49:11	2020-07-17	9	[{"id_menu":7,"count":1}]	1770	pick-up	0	9
97887	2020-07-17 07:54:42	2020-07-17	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26792	delivery	5	43
97888	2020-07-17 08:01:47	2020-07-17	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	8180	pick-up	0	26
97889	2020-07-17 08:02:37	2020-07-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	36713	delivery	5	28
97890	2020-07-17 08:03:01	2020-07-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28030	pick-up	0	18
97891	2020-07-17 08:04:49	2020-07-17	12	[{"id_menu":3,"count":1}]	24354	pick-up	0	12
97892	2020-07-17 08:10:00	2020-07-17	12	[{"id_menu":3,"count":1}]	1472	delivery	5	17
97893	2020-07-17 08:11:56	2020-07-17	17	[{"id_menu":4,"count":1}]	2324	delivery	5	22
97894	2020-07-17 08:12:44	2020-07-17	9	[{"id_menu":6,"count":1}]	19480	delivery	5	14
97895	2020-07-17 08:13:06	2020-07-17	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1053	pick-up	0	21
97896	2020-07-17 08:14:17	2020-07-17	14	[{"id_menu":2,"count":1}]	37842	delivery	5	19
97897	2020-07-17 08:16:22	2020-07-17	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	38051	delivery	5	25
97898	2020-07-17 08:17:22	2020-07-17	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21377	delivery	5	35
97899	2020-07-17 08:17:23	2020-07-17	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	121	delivery	5	31
97900	2020-07-17 08:17:37	2020-07-17	12	[{"id_menu":1,"count":1}]	5194	delivery	5	17
97901	2020-07-17 08:24:12	2020-07-17	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38019	delivery	5	45
97902	2020-07-17 08:24:54	2020-07-17	14	[{"id_menu":2,"count":1}]	2909	delivery	5	19
97903	2020-07-17 08:25:17	2020-07-17	17	[{"id_menu":4,"count":1}]	20937	delivery	5	22
97904	2020-07-17 08:25:23	2020-07-17	17	[{"id_menu":4,"count":1}]	7891	pick-up	0	17
97905	2020-07-17 08:31:16	2020-07-17	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	13768	delivery	5	26
97906	2020-07-17 08:32:19	2020-07-17	8	[{"id_menu":5,"count":1}]	37975	delivery	5	13
97907	2020-07-17 08:32:56	2020-07-17	9	[{"id_menu":7,"count":1}]	2867	pick-up	0	9
97908	2020-07-17 08:35:14	2020-07-17	14	[{"id_menu":2,"count":1}]	19841	pick-up	0	14
97909	2020-07-17 08:37:00	2020-07-17	8	[{"id_menu":5,"count":1}]	38047	delivery	5	13
97910	2020-07-17 08:37:06	2020-07-17	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	23928	delivery	5	30
97911	2020-07-17 08:37:07	2020-07-17	9	[{"id_menu":6,"count":1}]	37914	pick-up	0	9
97912	2020-07-17 08:38:05	2020-07-17	9	[{"id_menu":7,"count":1}]	13826	delivery	5	14
97913	2020-07-17 08:38:56	2020-07-17	14	[{"id_menu":2,"count":1}]	38033	delivery	5	19
97914	2020-07-17 08:39:50	2020-07-17	9	[{"id_menu":7,"count":1}]	23392	delivery	5	14
97915	2020-07-17 08:41:09	2020-07-17	14	[{"id_menu":2,"count":1}]	25343	delivery	5	19
97916	2020-07-17 08:41:42	2020-07-17	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5822	delivery	5	45
97917	2020-07-17 08:41:52	2020-07-17	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33989	delivery	5	35
97918	2020-07-17 08:42:16	2020-07-17	9	[{"id_menu":7,"count":1}]	16036	delivery	5	14
97919	2020-07-17 08:43:08	2020-07-17	8	[{"id_menu":5,"count":1}]	5286	pick-up	0	8
97920	2020-07-17 08:43:10	2020-07-17	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36502	delivery	5	49
97921	2020-07-17 08:46:23	2020-07-17	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	11271	delivery	5	43
97922	2020-07-17 08:46:35	2020-07-17	8	[{"id_menu":5,"count":1}]	8727	delivery	5	13
97923	2020-07-17 09:03:16	2020-07-17	9	[{"id_menu":6,"count":1}]	37928	delivery	5	14
97924	2020-07-17 09:05:14	2020-07-17	17	[{"id_menu":4,"count":1}]	37846	delivery	5	22
97925	2020-07-17 09:06:28	2020-07-17	9	[{"id_menu":7,"count":1}]	6735	delivery	5	14
97926	2020-07-17 09:06:49	2020-07-17	12	[{"id_menu":1,"count":1}]	24048	delivery	5	17
97927	2020-07-17 09:08:13	2020-07-17	9	[{"id_menu":7,"count":1}]	38052	pick-up	0	9
97928	2020-07-17 09:09:20	2020-07-17	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	37249	pick-up	0	26
97929	2020-07-17 09:09:30	2020-07-17	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	9106	pick-up	0	35
97930	2020-07-17 09:10:03	2020-07-17	9	[{"id_menu":7,"count":1}]	17940	delivery	5	14
97931	2020-07-17 09:10:41	2020-07-17	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27501	delivery	5	34
97932	2020-07-17 09:26:10	2020-07-17	14	[{"id_menu":2,"count":1}]	21671	delivery	5	19
97933	2020-07-17 09:26:45	2020-07-17	17	[{"id_menu":4,"count":1}]	260	pick-up	0	17
97934	2020-07-17 09:31:57	2020-07-17	8	[{"id_menu":5,"count":1}]	33212	delivery	5	13
97935	2020-07-17 09:33:13	2020-07-17	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7444	delivery	5	45
97936	2020-07-17 09:33:18	2020-07-17	14	[{"id_menu":2,"count":1}]	11474	delivery	5	19
97937	2020-07-17 09:34:01	2020-07-17	9	[{"id_menu":7,"count":1}]	38003	delivery	5	14
97938	2020-07-17 09:34:09	2020-07-17	14	[{"id_menu":2,"count":1}]	27265	delivery	5	19
97939	2020-07-17 09:34:53	2020-07-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	37849	pick-up	0	26
97940	2020-07-17 09:35:06	2020-07-17	9	[{"id_menu":7,"count":1}]	38054	delivery	5	14
97941	2020-07-17 09:42:50	2020-07-17	12	[{"id_menu":1,"count":1}]	25735	pick-up	0	12
97942	2020-07-17 09:42:59	2020-07-17	12	[{"id_menu":1,"count":1}]	34733	delivery	5	17
97943	2020-07-17 09:43:03	2020-07-17	9	[{"id_menu":7,"count":1}]	854	delivery	5	14
97944	2020-07-17 09:44:36	2020-07-17	9	[{"id_menu":7,"count":1}]	37890	delivery	5	14
97945	2020-07-17 09:46:17	2020-07-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	23552	delivery	5	28
97946	2020-07-17 09:46:28	2020-07-17	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	22430	delivery	5	22
97947	2020-07-17 09:46:55	2020-07-17	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5947	pick-up	0	25
97948	2020-07-17 09:47:27	2020-07-17	12	[{"id_menu":1,"count":1}]	33774	delivery	5	17
97949	2020-07-17 09:48:04	2020-07-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	26376	pick-up	0	23
97950	2020-07-17 09:48:52	2020-07-17	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10567	delivery	5	35
97951	2020-07-17 09:53:06	2020-07-17	14	[{"id_menu":2,"count":1}]	37989	delivery	5	19
97952	2020-07-17 09:57:13	2020-07-17	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	31378	delivery	5	25
97953	2020-07-17 09:58:21	2020-07-17	17	[{"id_menu":4,"count":1}]	3125	delivery	5	22
97954	2020-07-17 09:59:43	2020-07-17	17	[{"id_menu":4,"count":1}]	38074	delivery	5	22
97955	2020-07-17 10:00:32	2020-07-17	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5861	delivery	5	37
97956	2020-07-17 10:02:03	2020-07-17	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	10541	pick-up	0	26
97957	2020-07-17 10:06:56	2020-07-17	9	[{"id_menu":6,"count":1}]	1684	pick-up	0	9
97958	2020-07-17 10:09:38	2020-07-17	9	[{"id_menu":6,"count":1}]	37838	delivery	5	14
97959	2020-07-17 10:15:34	2020-07-17	12	[{"id_menu":1,"count":1}]	5769	delivery	5	17
97960	2020-07-17 10:17:07	2020-07-17	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	37981	delivery	5	36
97961	2020-07-17 10:20:53	2020-07-17	14	[{"id_menu":2,"count":1}]	3859	pick-up	0	14
97962	2020-07-17 10:24:01	2020-07-17	14	[{"id_menu":2,"count":1}]	24900	delivery	5	19
97963	2020-07-17 10:31:56	2020-07-17	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	37879	delivery	5	30
97964	2020-07-17 10:32:10	2020-07-17	9	[{"id_menu":6,"count":1}]	5746	delivery	5	14
97965	2020-07-17 10:37:35	2020-07-17	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30182	delivery	5	35
97966	2020-07-17 10:39:24	2020-07-17	9	[{"id_menu":7,"count":1}]	38034	delivery	5	14
97967	2020-07-17 10:40:20	2020-07-17	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	38043	delivery	5	39
97968	2020-07-17 10:40:33	2020-07-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6055	delivery	5	31
97969	2020-07-17 10:41:01	2020-07-17	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	34186	delivery	5	43
97970	2020-07-17 10:43:32	2020-07-17	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	32918	delivery	5	25
97971	2020-07-17 10:43:55	2020-07-17	9	[{"id_menu":6,"count":1}]	31353	delivery	5	14
97972	2020-07-17 10:47:01	2020-07-17	12	[{"id_menu":1,"count":1}]	1179	delivery	5	17
97973	2020-07-17 10:48:23	2020-07-17	14	[{"id_menu":2,"count":1}]	32447	delivery	5	19
97974	2020-07-17 10:53:17	2020-07-17	9	[{"id_menu":7,"count":1}]	38093	delivery	5	14
97975	2020-07-17 10:54:36	2020-07-17	12	[{"id_menu":1,"count":1}]	16794	pick-up	0	12
97976	2020-07-17 10:54:37	2020-07-17	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	38031	delivery	5	42
97977	2020-07-17 10:57:43	2020-07-17	9	[{"id_menu":7,"count":1}]	37840	delivery	5	14
97978	2020-07-17 10:58:06	2020-07-17	8	[{"id_menu":5,"count":1}]	11115	delivery	5	13
97979	2020-07-17 11:05:26	2020-07-17	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	36075	pick-up	0	29
97980	2020-07-17 11:06:04	2020-07-17	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	37952	delivery	5	22
97981	2020-07-17 11:06:40	2020-07-17	12	[{"id_menu":1,"count":1}]	37850	delivery	5	17
97982	2020-07-17 11:10:18	2020-07-17	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	35115	delivery	5	31
97983	2020-07-17 11:11:48	2020-07-17	9	[{"id_menu":6,"count":1}]	38102	delivery	5	14
97984	2020-07-17 11:12:45	2020-07-17	14	[{"id_menu":2,"count":2}]	38105	delivery	5	19
97985	2020-07-17 11:15:38	2020-07-17	9	[{"id_menu":7,"count":1}]	11141	delivery	5	14
97986	2020-07-17 11:18:09	2020-07-17	14	[{"id_menu":2,"count":1}]	29231	delivery	5	19
97987	2020-07-17 11:19:23	2020-07-17	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	14963	delivery	5	35
97988	2020-07-17 11:26:54	2020-07-17	17	[{"id_menu":4,"count":2}]	11083	pick-up	0	17
97989	2020-07-17 11:28:34	2020-07-17	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	37918	delivery	5	48
97990	2020-07-17 11:29:48	2020-07-17	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34374	delivery	5	47
97991	2020-07-17 11:35:42	2020-07-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38045	delivery	5	23
97992	2020-07-17 11:39:28	2020-07-17	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	37861	delivery	5	25
97993	2020-07-17 11:41:32	2020-07-17	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	861	pick-up	0	34
97994	2020-07-17 11:43:24	2020-07-17	9	[{"id_menu":7,"count":1}]	614	delivery	5	14
97995	2020-07-17 11:44:20	2020-07-17	9	[{"id_menu":6,"count":1}]	651	delivery	5	14
97996	2020-07-17 11:47:35	2020-07-17	8	[{"id_menu":5,"count":1}]	38027	pick-up	0	8
97997	2020-07-17 11:54:35	2020-07-17	17	[{"id_menu":4,"count":1}]	8385	delivery	5	22
97998	2020-07-17 11:58:08	2020-07-17	9	[{"id_menu":6,"count":1}]	38106	delivery	5	14
97999	2020-07-17 11:59:15	2020-07-17	9	[{"id_menu":7,"count":1}]	38014	delivery	5	14
98000	2020-07-17 12:00:30	2020-07-17	12	[{"id_menu":1,"count":1}]	37994	delivery	5	17
98001	2020-07-17 12:12:54	2020-07-17	17	[{"id_menu":4,"count":1}]	36180	delivery	5	22
98002	2020-07-17 12:13:00	2020-07-17	17	[{"id_menu":4,"count":1}]	7019	pick-up	0	17
98003	2020-07-17 12:15:48	2020-07-17	9	[{"id_menu":6,"count":1}]	24518	delivery	5	14
98004	2020-07-17 12:23:20	2020-07-17	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	21107	delivery	5	40
98005	2020-07-17 12:24:15	2020-07-17	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11317	delivery	5	36
98006	2020-07-17 12:28:38	2020-07-17	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	38013	delivery	5	22
98007	2020-07-17 12:29:57	2020-07-17	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37906	delivery	5	40
98008	2020-07-17 12:32:12	2020-07-17	17	[{"id_menu":4,"count":1}]	3851	pick-up	0	17
98009	2020-07-17 12:32:28	2020-07-17	8	[{"id_menu":5,"count":1}]	13667	delivery	5	13
98010	2020-07-17 12:32:55	2020-07-17	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7416	delivery	5	35
98011	2020-07-17 12:35:43	2020-07-17	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	24444	delivery	5	39
98012	2020-07-17 12:46:07	2020-07-17	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	8487	delivery	5	27
98013	2020-07-17 12:50:52	2020-07-17	9	[{"id_menu":6,"count":1}]	37851	delivery	5	14
98014	2020-07-17 12:51:04	2020-07-17	17	[{"id_menu":4,"count":2}]	15218	delivery	5	22
98015	2020-07-17 12:52:17	2020-07-17	9	[{"id_menu":6,"count":1}]	38046	delivery	5	14
98016	2020-07-17 12:55:40	2020-07-17	14	[{"id_menu":2,"count":1}]	37866	delivery	5	19
98017	2020-07-17 13:01:06	2020-07-17	8	[{"id_menu":5,"count":2}]	1490	pick-up	0	8
98018	2020-07-17 13:02:41	2020-07-17	12	[{"id_menu":1,"count":1}]	193	pick-up	0	12
98019	2020-07-17 13:04:06	2020-07-17	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9230	delivery	5	30
98020	2020-07-17 13:04:11	2020-07-17	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	18298	delivery	5	37
98021	2020-07-17 13:04:25	2020-07-17	17	[{"id_menu":4,"count":1}]	4811	delivery	5	22
98022	2020-07-17 13:05:14	2020-07-17	14	[{"id_menu":2,"count":2}]	37961	delivery	5	19
98023	2020-07-17 13:09:26	2020-07-17	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	26527	delivery	5	34
98024	2020-07-17 13:10:52	2020-07-17	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	33647	pick-up	0	26
98025	2020-07-17 13:12:57	2020-07-17	12	[{"id_menu":1,"count":1}]	37995	delivery	5	17
98026	2020-07-17 13:13:16	2020-07-17	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	32687	delivery	5	29
98027	2020-07-17 13:15:51	2020-07-17	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4937	pick-up	0	35
98028	2020-07-17 13:16:19	2020-07-17	9	[{"id_menu":7,"count":1}]	28545	delivery	5	14
98029	2020-07-17 13:16:51	2020-07-17	9	[{"id_menu":6,"count":1}]	4394	delivery	5	14
98030	2020-07-17 13:22:55	2020-07-17	14	[{"id_menu":2,"count":1}]	5758	pick-up	0	14
98031	2020-07-17 13:24:46	2020-07-17	14	[{"id_menu":2,"count":1}]	20912	delivery	5	19
98032	2020-07-17 13:25:59	2020-07-17	8	[{"id_menu":5,"count":1}]	38029	delivery	5	13
98033	2020-07-17 13:29:55	2020-07-17	9	[{"id_menu":7,"count":1}]	21105	delivery	5	14
98034	2020-07-17 13:32:13	2020-07-17	14	[{"id_menu":2,"count":1}]	30508	delivery	5	19
98035	2020-07-17 13:32:54	2020-07-17	12	[{"id_menu":3,"count":1}]	996	pick-up	0	12
98036	2020-07-17 13:33:53	2020-07-17	12	[{"id_menu":3,"count":1}]	37978	delivery	5	17
98037	2020-07-17 13:36:28	2020-07-17	9	[{"id_menu":6,"count":1}]	38023	delivery	5	14
98038	2020-07-17 13:36:28	2020-07-17	8	[{"id_menu":5,"count":1}]	20504	delivery	5	13
98039	2020-07-17 13:37:14	2020-07-17	12	[{"id_menu":1,"count":1}]	38081	delivery	5	17
98040	2020-07-17 13:37:27	2020-07-17	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	37943	delivery	5	40
98041	2020-07-17 13:41:42	2020-07-17	9	[{"id_menu":7,"count":1}]	38004	pick-up	0	9
98042	2020-07-17 13:41:54	2020-07-17	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2339	pick-up	0	29
98043	2020-07-17 13:44:02	2020-07-17	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	37268	delivery	5	22
98044	2020-07-17 13:45:28	2020-07-17	14	[{"id_menu":2,"count":1}]	38083	delivery	5	19
98045	2020-07-17 13:49:15	2020-07-17	9	[{"id_menu":6,"count":1}]	7057	pick-up	0	9
98046	2020-07-17 13:50:06	2020-07-17	8	[{"id_menu":5,"count":1}]	6317	pick-up	0	8
98047	2020-07-17 13:53:01	2020-07-17	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	15400	pick-up	0	21
98048	2020-07-17 13:53:04	2020-07-17	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38053	delivery	5	35
98049	2020-07-17 13:53:05	2020-07-17	17	[{"id_menu":4,"count":1}]	9997	delivery	5	22
98050	2020-07-17 13:53:21	2020-07-17	12	[{"id_menu":1,"count":1}]	21857	delivery	5	17
98051	2020-07-17 13:56:52	2020-07-17	12	[{"id_menu":1,"count":2}]	24011	pick-up	0	12
98052	2020-07-17 14:00:05	2020-07-17	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	37979	delivery	5	22
98053	2020-07-17 14:02:26	2020-07-17	8	[{"id_menu":5,"count":1}]	37867	delivery	5	13
98054	2020-07-17 14:02:40	2020-07-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	31906	delivery	5	31
98055	2020-07-17 14:10:34	2020-07-17	12	[{"id_menu":3,"count":1}]	28898	delivery	5	17
98056	2020-07-17 14:12:03	2020-07-17	17	[{"id_menu":4,"count":1}]	29419	pick-up	0	17
98057	2020-07-17 14:12:49	2020-07-17	17	[{"id_menu":4,"count":1}]	20338	delivery	5	22
98058	2020-07-17 14:13:58	2020-07-17	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	38101	delivery	5	26
98059	2020-07-17 14:14:53	2020-07-17	14	[{"id_menu":2,"count":1}]	16549	pick-up	0	14
98060	2020-07-17 14:20:20	2020-07-17	17	[{"id_menu":4,"count":1}]	18856	pick-up	0	17
98061	2020-07-17 14:21:46	2020-07-17	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	633	delivery	5	36
98062	2020-07-17 14:23:24	2020-07-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	24948	delivery	5	28
98063	2020-07-17 14:27:42	2020-07-17	9	[{"id_menu":7,"count":1}]	37892	delivery	5	14
98064	2020-07-17 14:27:55	2020-07-17	17	[{"id_menu":4,"count":2}]	21570	delivery	5	22
98065	2020-07-17 14:27:57	2020-07-17	17	[{"id_menu":4,"count":1}]	1715	pick-up	0	17
98066	2020-07-17 14:29:02	2020-07-17	9	[{"id_menu":7,"count":1}]	38075	delivery	5	14
98067	2020-07-17 14:32:20	2020-07-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8561	pick-up	0	26
98068	2020-07-17 14:32:28	2020-07-17	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	16010	delivery	5	36
98069	2020-07-17 14:34:32	2020-07-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	10666	delivery	5	28
98070	2020-07-17 14:36:05	2020-07-17	14	[{"id_menu":2,"count":1}]	30005	pick-up	0	14
98071	2020-07-17 14:37:11	2020-07-17	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	38073	delivery	5	30
98072	2020-07-17 14:42:45	2020-07-17	9	[{"id_menu":6,"count":1}]	11186	delivery	5	14
98073	2020-07-17 14:44:09	2020-07-17	8	[{"id_menu":5,"count":1}]	37959	delivery	5	13
98074	2020-07-17 14:46:01	2020-07-17	17	[{"id_menu":4,"count":1}]	31537	delivery	5	22
98075	2020-07-17 14:47:23	2020-07-17	9	[{"id_menu":7,"count":1}]	37884	delivery	5	14
98076	2020-07-17 14:58:43	2020-07-17	12	[{"id_menu":1,"count":1}]	33446	pick-up	0	12
98077	2020-07-17 14:59:13	2020-07-17	9	[{"id_menu":6,"count":2}]	26338	delivery	5	14
98078	2020-07-17 15:07:06	2020-07-17	9	[{"id_menu":7,"count":1}]	37	pick-up	0	9
98079	2020-07-17 15:10:42	2020-07-17	9	[{"id_menu":6,"count":1}]	37903	delivery	5	14
98080	2020-07-17 15:12:19	2020-07-17	9	[{"id_menu":6,"count":1}]	2993	pick-up	0	9
98081	2020-07-17 15:15:35	2020-07-17	14	[{"id_menu":2,"count":1}]	37874	delivery	5	19
98082	2020-07-17 15:16:26	2020-07-17	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":2}]	37912	delivery	5	26
98083	2020-07-17 15:17:56	2020-07-17	8	[{"id_menu":5,"count":1}]	32010	delivery	5	13
98084	2020-07-17 15:20:08	2020-07-17	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	27574	delivery	5	30
98085	2020-07-17 15:22:22	2020-07-17	12	[{"id_menu":3,"count":1}]	17472	delivery	5	17
98086	2020-07-17 15:24:39	2020-07-17	9	[{"id_menu":7,"count":1}]	38065	delivery	5	14
98087	2020-07-17 15:25:17	2020-07-17	14	[{"id_menu":2,"count":1}]	38009	delivery	5	19
98088	2020-07-17 15:31:22	2020-07-17	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	678	pick-up	0	17
98089	2020-07-17 15:34:56	2020-07-17	12	[{"id_menu":3,"count":1}]	295	pick-up	0	12
98090	2020-07-17 15:36:09	2020-07-17	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	31091	delivery	5	40
98091	2020-07-17 15:39:46	2020-07-17	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	36668	delivery	5	31
98092	2020-07-17 15:43:44	2020-07-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	38099	delivery	5	28
98093	2020-07-17 15:46:03	2020-07-17	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10814	delivery	5	31
98094	2020-07-17 15:46:56	2020-07-17	12	[{"id_menu":1,"count":1}]	14427	delivery	5	17
98095	2020-07-17 15:49:10	2020-07-17	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	37852	delivery	5	30
98096	2020-07-17 15:52:18	2020-07-17	9	[{"id_menu":6,"count":1}]	32214	pick-up	0	9
98097	2020-07-17 15:53:33	2020-07-17	8	[{"id_menu":5,"count":1}]	38057	delivery	5	13
98098	2020-07-17 15:54:46	2020-07-17	12	[{"id_menu":1,"count":1}]	37997	delivery	5	17
98099	2020-07-17 15:55:43	2020-07-17	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	38087	delivery	5	38
98100	2020-07-17 15:55:48	2020-07-17	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	37876	delivery	5	29
98101	2020-07-17 15:55:56	2020-07-17	17	[{"id_menu":4,"count":1}]	4471	delivery	5	22
98102	2020-07-17 15:56:35	2020-07-17	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	37936	delivery	5	22
98103	2020-07-17 15:57:23	2020-07-17	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	31759	delivery	5	22
98104	2020-07-17 15:57:31	2020-07-17	12	[{"id_menu":3,"count":1}]	16774	delivery	5	17
98105	2020-07-17 16:10:55	2020-07-17	12	[{"id_menu":1,"count":1}]	401	pick-up	0	12
98106	2020-07-17 16:15:27	2020-07-17	12	[{"id_menu":3,"count":1}]	10100	pick-up	0	12
98107	2020-07-17 16:18:26	2020-07-17	14	[{"id_menu":2,"count":2}]	27676	delivery	5	19
98108	2020-07-17 16:29:57	2020-07-17	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	27142	delivery	5	39
98109	2020-07-17 16:30:47	2020-07-17	17	[{"id_menu":4,"count":1}]	5311	delivery	5	22
98110	2020-07-17 16:31:35	2020-07-17	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	18218	delivery	5	30
98111	2020-07-17 16:32:35	2020-07-17	12	[{"id_menu":3,"count":1}]	15594	pick-up	0	12
98112	2020-07-17 16:33:33	2020-07-17	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	38068	delivery	5	31
98113	2020-07-17 16:35:08	2020-07-17	9	[{"id_menu":7,"count":1}]	3779	delivery	5	14
98114	2020-07-17 16:36:05	2020-07-17	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	14201	delivery	5	23
98115	2020-07-17 16:36:06	2020-07-17	8	[{"id_menu":5,"count":1}]	37957	delivery	5	13
98116	2020-07-17 16:38:07	2020-07-17	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	35493	delivery	5	26
98117	2020-07-17 16:47:53	2020-07-17	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	8223	delivery	5	35
98118	2020-07-17 16:51:31	2020-07-17	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1143	delivery	5	26
98119	2020-07-17 16:52:21	2020-07-17	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":2}]	24001	delivery	5	26
98120	2020-07-17 16:53:06	2020-07-17	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3548	delivery	5	46
98121	2020-07-17 16:54:35	2020-07-17	14	[{"id_menu":2,"count":1}]	38108	delivery	5	19
98122	2020-07-17 16:55:32	2020-07-17	14	[{"id_menu":2,"count":1}]	37966	delivery	5	19
98123	2020-07-17 16:55:42	2020-07-17	9	[{"id_menu":6,"count":1}]	37969	delivery	5	14
98124	2020-07-17 16:58:10	2020-07-17	14	[{"id_menu":2,"count":1}]	14063	delivery	5	19
98125	2020-07-17 17:02:27	2020-07-17	12	[{"id_menu":3,"count":1}]	9996	delivery	5	17
98126	2020-07-17 17:04:24	2020-07-17	9	[{"id_menu":7,"count":1}]	18619	delivery	5	14
98127	2020-07-17 17:05:35	2020-07-17	12	[{"id_menu":3,"count":1}]	37923	delivery	5	17
98128	2020-07-17 17:06:32	2020-07-17	8	[{"id_menu":5,"count":1}]	38018	pick-up	0	8
98129	2020-07-17 17:06:48	2020-07-17	12	[{"id_menu":3,"count":1}]	31726	pick-up	0	12
98130	2020-07-17 17:11:41	2020-07-17	14	[{"id_menu":2,"count":1}]	3227	pick-up	0	14
98131	2020-07-17 17:12:38	2020-07-17	12	[{"id_menu":1,"count":1}]	21599	delivery	5	17
98132	2020-07-17 17:13:01	2020-07-17	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15909	delivery	5	51
98133	2020-07-17 17:17:02	2020-07-17	9	[{"id_menu":6,"count":1}]	37950	delivery	5	14
98134	2020-07-17 17:17:52	2020-07-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	37929	delivery	5	31
98135	2020-07-17 17:18:50	2020-07-17	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	38097	delivery	5	27
98136	2020-07-17 17:19:11	2020-07-17	17	[{"id_menu":4,"count":1}]	37983	delivery	5	22
98137	2020-07-17 17:23:56	2020-07-17	12	[{"id_menu":3,"count":1}]	37522	delivery	5	17
98138	2020-07-17 17:26:36	2020-07-17	9	[{"id_menu":6,"count":1}]	37762	pick-up	0	9
98139	2020-07-17 17:30:21	2020-07-17	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	19868	delivery	5	26
98140	2020-07-17 17:34:23	2020-07-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3116	pick-up	0	23
98141	2020-07-17 17:34:35	2020-07-17	14	[{"id_menu":2,"count":1}]	25337	pick-up	0	14
98142	2020-07-17 17:37:55	2020-07-17	9	[{"id_menu":7,"count":1}]	37982	delivery	5	14
98143	2020-07-17 17:38:30	2020-07-17	17	[{"id_menu":4,"count":1}]	1343	pick-up	0	17
98144	2020-07-17 17:39:41	2020-07-17	9	[{"id_menu":7,"count":1}]	37973	delivery	5	14
98145	2020-07-17 17:39:59	2020-07-17	14	[{"id_menu":2,"count":1}]	15718	delivery	5	19
98146	2020-07-17 17:40:58	2020-07-17	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	30002	delivery	5	26
98147	2020-07-17 17:43:39	2020-07-17	8	[{"id_menu":5,"count":1}]	37988	delivery	5	13
98148	2020-07-17 17:43:50	2020-07-17	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	21357	pick-up	0	20
98149	2020-07-17 17:45:54	2020-07-17	9	[{"id_menu":7,"count":1}]	18147	pick-up	0	9
98150	2020-07-17 17:46:46	2020-07-17	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	13596	delivery	5	31
98151	2020-07-17 17:48:22	2020-07-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	37848	pick-up	0	23
98152	2020-07-17 17:51:17	2020-07-17	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	703	delivery	5	28
98153	2020-07-17 17:53:13	2020-07-17	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	37977	delivery	5	31
98154	2020-07-17 17:53:31	2020-07-17	12	[{"id_menu":3,"count":2}]	2771	pick-up	0	12
98155	2020-07-17 17:55:51	2020-07-17	9	[{"id_menu":6,"count":1}]	37189	delivery	5	14
98156	2020-07-17 17:57:17	2020-07-17	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	37902	delivery	5	26
98157	2020-07-17 17:57:51	2020-07-17	8	[{"id_menu":5,"count":1}]	18417	delivery	5	13
98158	2020-07-17 18:05:04	2020-07-17	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	35930	delivery	5	25
98159	2020-07-17 18:12:24	2020-07-17	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	24040	delivery	5	37
98160	2020-07-17 18:13:06	2020-07-17	9	[{"id_menu":7,"count":1}]	37985	delivery	5	14
98161	2020-07-17 18:13:56	2020-07-17	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	2536	pick-up	0	22
98162	2020-07-17 18:15:07	2020-07-17	9	[{"id_menu":7,"count":1}]	37942	delivery	5	14
98163	2020-07-17 18:16:55	2020-07-17	9	[{"id_menu":6,"count":1}]	37938	delivery	5	14
98164	2020-07-17 18:22:24	2020-07-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	37835	delivery	5	31
98165	2020-07-17 18:24:59	2020-07-17	14	[{"id_menu":2,"count":1}]	10946	delivery	5	19
98166	2020-07-17 18:26:52	2020-07-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	37962	delivery	5	28
98167	2020-07-17 18:28:51	2020-07-17	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	5718	delivery	5	36
98168	2020-07-17 18:33:55	2020-07-17	9	[{"id_menu":6,"count":1}]	32191	delivery	5	14
98169	2020-07-17 18:36:26	2020-07-17	9	[{"id_menu":6,"count":1}]	29601	delivery	5	14
98170	2020-07-17 18:36:40	2020-07-17	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	11387	delivery	5	26
98171	2020-07-17 18:46:07	2020-07-17	9	[{"id_menu":6,"count":1}]	519	pick-up	0	9
98172	2020-07-17 18:49:41	2020-07-17	12	[{"id_menu":3,"count":1}]	9633	delivery	5	17
98173	2020-07-17 18:49:52	2020-07-17	8	[{"id_menu":5,"count":1}]	37916	delivery	5	13
98174	2020-07-17 18:51:08	2020-07-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	34163	delivery	5	31
98175	2020-07-17 18:55:37	2020-07-17	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	37896	delivery	5	34
98176	2020-07-17 18:59:25	2020-07-17	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	37958	delivery	5	25
98177	2020-07-17 19:13:11	2020-07-17	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	37881	delivery	5	22
98178	2020-07-17 19:13:26	2020-07-17	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	24731	delivery	5	40
98179	2020-07-17 19:13:37	2020-07-17	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38030	delivery	5	48
98180	2020-07-17 19:15:09	2020-07-17	9	[{"id_menu":7,"count":1}]	37897	delivery	5	14
98181	2020-07-17 19:15:52	2020-07-17	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	33636	delivery	5	35
98182	2020-07-17 19:16:32	2020-07-17	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	37862	pick-up	0	34
98183	2020-07-17 19:21:07	2020-07-17	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23356	delivery	5	22
98184	2020-07-17 19:25:07	2020-07-17	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	8303	delivery	5	36
98185	2020-07-17 19:25:18	2020-07-17	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	3169	delivery	5	22
98186	2020-07-17 19:27:50	2020-07-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12359	delivery	5	23
98187	2020-07-17 19:30:07	2020-07-17	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	38095	delivery	5	34
98188	2020-07-17 19:32:14	2020-07-17	14	[{"id_menu":2,"count":1}]	4324	delivery	5	19
98189	2020-07-17 19:36:39	2020-07-17	9	[{"id_menu":7,"count":1}]	37908	pick-up	0	9
98190	2020-07-17 19:38:02	2020-07-17	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	10562	delivery	5	34
98191	2020-07-17 19:40:01	2020-07-17	9	[{"id_menu":7,"count":3}]	10730	delivery	5	14
98192	2020-07-17 19:42:02	2020-07-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	36590	delivery	5	28
98193	2020-07-17 19:43:25	2020-07-17	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23665	delivery	5	36
98194	2020-07-17 19:45:38	2020-07-17	14	[{"id_menu":2,"count":1}]	38042	delivery	5	19
98195	2020-07-17 19:47:34	2020-07-17	14	[{"id_menu":2,"count":3}]	9366	delivery	5	19
98196	2020-07-17 19:48:08	2020-07-17	14	[{"id_menu":2,"count":1}]	16825	pick-up	0	14
98197	2020-07-17 19:48:20	2020-07-17	14	[{"id_menu":2,"count":1}]	3316	delivery	5	19
98198	2020-07-17 19:48:57	2020-07-17	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	173	delivery	5	36
98199	2020-07-17 19:49:41	2020-07-17	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12151	delivery	5	31
98200	2020-07-17 19:50:00	2020-07-17	38	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	37812	delivery	5	43
98201	2020-07-17 19:52:22	2020-07-17	9	[{"id_menu":6,"count":1}]	34035	delivery	5	14
98202	2020-07-17 19:55:56	2020-07-17	9	[{"id_menu":6,"count":1}]	30120	delivery	5	14
98203	2020-07-17 19:56:57	2020-07-17	12	[{"id_menu":3,"count":1}]	37834	pick-up	0	12
98204	2020-07-17 20:10:30	2020-07-17	9	[{"id_menu":6,"count":1}]	38076	delivery	5	14
98205	2020-07-17 20:11:24	2020-07-17	12	[{"id_menu":1,"count":1}]	33273	delivery	5	17
98206	2020-07-17 20:16:54	2020-07-17	8	[{"id_menu":5,"count":1}]	38109	delivery	5	13
98207	2020-07-17 20:19:23	2020-07-17	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	27256	delivery	5	40
98208	2020-07-17 20:26:49	2020-07-17	8	[{"id_menu":5,"count":1}]	38028	delivery	5	13
98209	2020-07-17 20:31:29	2020-07-17	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	33608	delivery	5	43
98210	2020-07-17 20:38:03	2020-07-17	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13885	delivery	5	45
98211	2020-07-17 20:38:57	2020-07-17	9	[{"id_menu":6,"count":1}]	37964	delivery	5	14
98212	2020-07-17 20:39:14	2020-07-17	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9621	delivery	5	34
98213	2020-07-17 20:42:28	2020-07-17	12	[{"id_menu":3,"count":1}]	22808	delivery	5	17
98214	2020-07-17 20:43:48	2020-07-17	14	[{"id_menu":2,"count":1}]	18220	delivery	5	19
98215	2020-07-17 20:45:04	2020-07-17	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4120	delivery	5	36
98216	2020-07-17 20:46:36	2020-07-17	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	2929	delivery	5	23
98217	2020-07-17 20:46:52	2020-07-17	12	[{"id_menu":1,"count":1}]	25296	pick-up	0	12
98218	2020-07-17 20:50:27	2020-07-17	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2065	pick-up	0	29
98219	2020-07-17 20:51:41	2020-07-17	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37954	delivery	5	37
98220	2020-07-17 20:52:14	2020-07-17	17	[{"id_menu":4,"count":1}]	21892	delivery	5	22
98221	2020-07-17 20:52:29	2020-07-17	17	[{"id_menu":4,"count":1}]	22894	delivery	5	22
98222	2020-07-17 20:54:14	2020-07-17	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	27106	delivery	5	26
98223	2020-07-17 20:56:22	2020-07-17	17	[{"id_menu":4,"count":1}]	36467	pick-up	0	17
98224	2020-07-17 20:57:45	2020-07-17	14	[{"id_menu":2,"count":1}]	24975	delivery	5	19
98225	2020-07-17 21:01:31	2020-07-17	8	[{"id_menu":5,"count":1}]	35275	pick-up	0	8
98226	2020-07-17 21:01:38	2020-07-17	17	[{"id_menu":4,"count":2}]	38098	delivery	5	22
98227	2020-07-17 21:01:54	2020-07-17	12	[{"id_menu":3,"count":1}]	19292	delivery	5	17
98228	2020-07-17 21:03:09	2020-07-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38039	delivery	5	23
98229	2020-07-17 21:03:48	2020-07-17	17	[{"id_menu":4,"count":1}]	32048	delivery	5	22
98230	2020-07-17 21:03:57	2020-07-17	17	[{"id_menu":4,"count":2}]	31210	delivery	5	22
98231	2020-07-17 21:05:00	2020-07-17	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	37904	delivery	5	36
98232	2020-07-17 21:05:45	2020-07-17	9	[{"id_menu":6,"count":1}]	16295	pick-up	0	9
98233	2020-07-17 21:11:05	2020-07-17	8	[{"id_menu":5,"count":1}]	38080	delivery	5	13
98234	2020-07-17 21:11:11	2020-07-17	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19307	delivery	5	40
98235	2020-07-17 21:12:13	2020-07-17	8	[{"id_menu":5,"count":1}]	37991	delivery	5	13
98236	2020-07-17 21:15:28	2020-07-17	14	[{"id_menu":2,"count":2}]	904	delivery	5	19
98237	2020-07-17 21:15:44	2020-07-17	8	[{"id_menu":5,"count":1}]	37858	delivery	5	13
98238	2020-07-17 21:24:49	2020-07-17	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	35517	delivery	5	26
98239	2020-07-17 21:30:22	2020-07-17	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	28293	pick-up	0	26
98240	2020-07-17 21:31:40	2020-07-17	12	[{"id_menu":1,"count":1}]	2310	pick-up	0	12
98241	2020-07-17 21:39:03	2020-07-17	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	6007	delivery	5	26
98242	2020-07-17 21:42:09	2020-07-17	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31178	delivery	5	31
98243	2020-07-17 21:42:15	2020-07-17	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	38025	delivery	5	34
98244	2020-07-17 21:43:43	2020-07-17	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	21514	delivery	5	42
98245	2020-07-17 21:48:23	2020-07-17	9	[{"id_menu":6,"count":1}]	5041	pick-up	0	9
98246	2020-07-17 21:51:24	2020-07-17	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	38086	delivery	5	40
98247	2020-07-17 21:55:37	2020-07-17	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4374	delivery	5	27
98248	2020-07-17 22:05:18	2020-07-17	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	37878	delivery	5	44
98249	2020-07-17 22:06:05	2020-07-17	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14655	delivery	5	31
98250	2020-07-17 22:07:00	2020-07-17	12	[{"id_menu":1,"count":1}]	37839	pick-up	0	12
98251	2020-07-17 22:08:47	2020-07-17	12	[{"id_menu":3,"count":1}]	38037	delivery	5	17
98252	2020-07-17 22:09:53	2020-07-17	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	32819	delivery	5	26
98253	2020-07-17 22:16:19	2020-07-17	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	3913	delivery	5	22
98254	2020-07-17 22:18:14	2020-07-17	12	[{"id_menu":3,"count":1}]	30498	delivery	5	17
98255	2020-07-17 22:18:38	2020-07-17	14	[{"id_menu":2,"count":1}]	2760	pick-up	0	14
98256	2020-07-17 22:18:55	2020-07-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18202	pick-up	0	18
98257	2020-07-17 22:19:43	2020-07-17	9	[{"id_menu":6,"count":1}]	4094	delivery	5	14
98258	2020-07-17 22:28:31	2020-07-17	9	[{"id_menu":6,"count":1}]	37831	delivery	5	14
98259	2020-07-17 22:31:30	2020-07-17	9	[{"id_menu":6,"count":1}]	38017	pick-up	0	9
98260	2020-07-17 22:32:44	2020-07-17	17	[{"id_menu":4,"count":1}]	37863	pick-up	0	17
98261	2020-07-17 22:37:40	2020-07-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	37939	delivery	5	28
98262	2020-07-17 22:39:04	2020-07-17	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4595	pick-up	0	17
98263	2020-07-17 22:44:44	2020-07-17	14	[{"id_menu":2,"count":1}]	37871	delivery	5	19
98264	2020-07-17 22:48:31	2020-07-17	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	37895	delivery	5	45
98265	2020-07-17 22:53:56	2020-07-17	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	22192	delivery	5	37
98266	2020-07-17 22:54:04	2020-07-17	12	[{"id_menu":1,"count":1}]	8057	delivery	5	17
98267	2020-07-17 22:55:02	2020-07-17	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	38016	delivery	5	39
98268	2020-07-17 22:55:54	2020-07-17	9	[{"id_menu":7,"count":1}]	22470	delivery	5	14
98269	2020-07-17 22:55:57	2020-07-17	12	[{"id_menu":1,"count":1}]	27914	pick-up	0	12
98270	2020-07-17 22:57:40	2020-07-17	14	[{"id_menu":2,"count":1}]	37924	delivery	5	19
98271	2020-07-17 22:58:00	2020-07-17	8	[{"id_menu":5,"count":1}]	293	pick-up	0	8
98272	2020-07-17 23:00:40	2020-07-17	9	[{"id_menu":6,"count":1}]	38077	delivery	5	14
98273	2020-07-17 23:01:31	2020-07-17	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	34969	delivery	5	43
98274	2020-07-17 23:02:16	2020-07-17	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	25590	delivery	5	31
98275	2020-07-17 23:07:13	2020-07-17	9	[{"id_menu":7,"count":2}]	27325	delivery	5	14
98276	2020-07-17 23:13:26	2020-07-17	14	[{"id_menu":2,"count":1}]	37905	delivery	5	19
98277	2020-07-17 23:16:58	2020-07-17	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	15540	delivery	5	25
98278	2020-07-17 23:17:01	2020-07-17	12	[{"id_menu":1,"count":1}]	35986	pick-up	0	12
98279	2020-07-17 23:18:36	2020-07-17	12	[{"id_menu":3,"count":1}]	20300	pick-up	0	12
98280	2020-07-17 23:18:56	2020-07-17	12	[{"id_menu":3,"count":1}]	37900	delivery	5	17
98281	2020-07-17 23:22:51	2020-07-17	12	[{"id_menu":1,"count":1}]	30393	pick-up	0	12
98282	2020-07-17 23:24:20	2020-07-17	14	[{"id_menu":2,"count":1}]	38002	delivery	5	19
98283	2020-07-17 23:27:24	2020-07-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19578	delivery	5	23
98284	2020-07-17 23:30:26	2020-07-17	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	10479	delivery	5	26
98285	2020-07-17 23:30:43	2020-07-17	12	[{"id_menu":1,"count":1}]	23602	pick-up	0	12
98286	2020-07-17 23:32:08	2020-07-17	14	[{"id_menu":2,"count":1}]	2907	pick-up	0	14
98287	2020-07-17 23:36:54	2020-07-17	9	[{"id_menu":7,"count":2}]	35645	delivery	5	14
98288	2020-07-17 23:37:50	2020-07-17	8	[{"id_menu":5,"count":1}]	2272	pick-up	0	8
98289	2020-07-17 23:44:02	2020-07-17	9	[{"id_menu":6,"count":1}]	17655	delivery	5	14
98290	2020-07-17 23:45:50	2020-07-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	8746	delivery	5	28
98291	2020-07-17 23:47:17	2020-07-17	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":2}]	5979	delivery	5	22
98292	2020-07-17 23:47:34	2020-07-17	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27572	delivery	5	34
98293	2020-07-17 23:47:49	2020-07-17	9	[{"id_menu":7,"count":1}]	38058	delivery	5	14
98294	2020-07-17 23:49:39	2020-07-17	9	[{"id_menu":6,"count":1}]	23898	delivery	5	14
98295	2020-07-17 23:57:28	2020-07-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	37882	delivery	5	28
98296	2020-07-17 23:59:30	2020-07-17	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	38090	delivery	5	22
98297	2020-07-18 00:00:19	2020-07-18	12	[{"id_menu":3,"count":1}]	12717	delivery	5	17
98298	2020-07-18 00:01:45	2020-07-18	9	[{"id_menu":7,"count":1}]	17398	delivery	5	14
98299	2020-07-18 00:01:57	2020-07-18	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	38251	delivery	5	40
98300	2020-07-18 00:02:28	2020-07-18	8	[{"id_menu":5,"count":1}]	13732	pick-up	0	8
98301	2020-07-18 00:02:33	2020-07-18	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	38185	delivery	5	51
98302	2020-07-18 00:04:07	2020-07-18	17	[{"id_menu":4,"count":3}]	13137	delivery	5	22
98303	2020-07-18 00:07:51	2020-07-18	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4825	pick-up	0	22
98304	2020-07-18 00:08:08	2020-07-18	14	[{"id_menu":2,"count":2}]	12053	pick-up	0	14
98305	2020-07-18 00:10:07	2020-07-18	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35998	delivery	5	35
98306	2020-07-18 00:14:06	2020-07-18	9	[{"id_menu":6,"count":1}]	964	delivery	5	14
98307	2020-07-18 00:14:25	2020-07-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	38217	delivery	5	22
98308	2020-07-18 00:17:42	2020-07-18	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	27447	delivery	5	26
98309	2020-07-18 00:18:25	2020-07-18	14	[{"id_menu":2,"count":1}]	24437	delivery	5	19
98310	2020-07-18 00:20:17	2020-07-18	9	[{"id_menu":7,"count":1}]	19304	pick-up	0	9
98311	2020-07-18 00:21:16	2020-07-18	9	[{"id_menu":6,"count":1}]	38271	delivery	5	14
98312	2020-07-18 00:21:37	2020-07-18	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	38132	delivery	5	34
98313	2020-07-18 00:22:22	2020-07-18	17	[{"id_menu":4,"count":1}]	31563	delivery	5	22
98314	2020-07-18 00:22:55	2020-07-18	14	[{"id_menu":2,"count":1}]	2165	pick-up	0	14
98315	2020-07-18 00:23:28	2020-07-18	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	30762	delivery	5	34
98316	2020-07-18 00:26:35	2020-07-18	14	[{"id_menu":2,"count":1}]	8561	pick-up	0	14
98317	2020-07-18 00:27:11	2020-07-18	9	[{"id_menu":6,"count":1}]	31735	pick-up	0	9
98318	2020-07-18 00:32:44	2020-07-18	14	[{"id_menu":2,"count":1}]	21813	delivery	5	19
98319	2020-07-18 00:33:21	2020-07-18	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":2}]	38148	delivery	5	30
98320	2020-07-18 00:38:53	2020-07-18	8	[{"id_menu":5,"count":1}]	23521	pick-up	0	8
98321	2020-07-18 00:40:36	2020-07-18	17	[{"id_menu":4,"count":1}]	9331	pick-up	0	17
98322	2020-07-18 00:40:52	2020-07-18	9	[{"id_menu":6,"count":1}]	30254	delivery	5	14
98323	2020-07-18 00:43:36	2020-07-18	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	290	pick-up	0	26
98324	2020-07-18 00:47:25	2020-07-18	9	[{"id_menu":7,"count":1}]	38214	delivery	5	14
98325	2020-07-18 00:50:08	2020-07-18	9	[{"id_menu":7,"count":1}]	1344	pick-up	0	9
98326	2020-07-18 00:54:46	2020-07-18	12	[{"id_menu":3,"count":1}]	9172	delivery	5	17
98327	2020-07-18 00:57:57	2020-07-18	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	38167	delivery	5	36
98328	2020-07-18 00:59:31	2020-07-18	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	10695	delivery	5	34
98329	2020-07-18 00:59:33	2020-07-18	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	8893	delivery	5	23
98330	2020-07-18 01:01:13	2020-07-18	12	[{"id_menu":3,"count":1}]	38238	delivery	5	17
98331	2020-07-18 01:03:17	2020-07-18	12	[{"id_menu":3,"count":1}]	18390	delivery	5	17
98332	2020-07-18 01:04:56	2020-07-18	12	[{"id_menu":1,"count":2}]	21411	delivery	5	17
98333	2020-07-18 01:06:53	2020-07-18	9	[{"id_menu":6,"count":2}]	23621	delivery	5	14
98334	2020-07-18 01:07:35	2020-07-18	12	[{"id_menu":1,"count":2}]	38316	pick-up	0	12
98335	2020-07-18 01:07:57	2020-07-18	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38220	delivery	5	40
98336	2020-07-18 01:09:23	2020-07-18	9	[{"id_menu":7,"count":1}]	38192	pick-up	0	9
98337	2020-07-18 01:12:53	2020-07-18	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	32785	delivery	5	40
98338	2020-07-18 01:18:52	2020-07-18	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	22064	delivery	5	36
98339	2020-07-18 01:19:17	2020-07-18	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	38129	delivery	5	27
98340	2020-07-18 01:20:34	2020-07-18	12	[{"id_menu":1,"count":1}]	10264	pick-up	0	12
98341	2020-07-18 01:21:00	2020-07-18	14	[{"id_menu":2,"count":1}]	38280	delivery	5	19
98342	2020-07-18 01:25:29	2020-07-18	8	[{"id_menu":5,"count":1}]	38293	delivery	5	13
98343	2020-07-18 01:25:57	2020-07-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5085	delivery	5	23
98344	2020-07-18 01:27:42	2020-07-18	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	38174	delivery	5	29
98345	2020-07-18 01:29:00	2020-07-18	9	[{"id_menu":7,"count":1}]	38332	delivery	5	14
98346	2020-07-18 01:34:42	2020-07-18	9	[{"id_menu":6,"count":1}]	15127	delivery	5	14
98347	2020-07-18 01:35:28	2020-07-18	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	34812	delivery	5	27
98348	2020-07-18 01:36:10	2020-07-18	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	14061	delivery	5	46
98349	2020-07-18 01:37:30	2020-07-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	20867	delivery	5	28
98350	2020-07-18 01:37:42	2020-07-18	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	11237	delivery	5	43
98351	2020-07-18 01:40:34	2020-07-18	14	[{"id_menu":2,"count":1}]	28357	pick-up	0	14
98352	2020-07-18 01:41:04	2020-07-18	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	38308	delivery	5	26
98353	2020-07-18 01:41:13	2020-07-18	17	[{"id_menu":4,"count":1}]	36932	delivery	5	22
98354	2020-07-18 01:42:03	2020-07-18	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	35456	pick-up	0	26
98355	2020-07-18 01:44:15	2020-07-18	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	32611	delivery	5	48
98356	2020-07-18 01:45:28	2020-07-18	9	[{"id_menu":7,"count":2}]	38254	delivery	5	14
98357	2020-07-18 01:46:37	2020-07-18	9	[{"id_menu":6,"count":1}]	440	delivery	5	14
98358	2020-07-18 01:46:43	2020-07-18	9	[{"id_menu":6,"count":2}]	38164	delivery	5	14
98359	2020-07-18 01:48:13	2020-07-18	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	38136	delivery	5	31
98360	2020-07-18 01:48:44	2020-07-18	8	[{"id_menu":5,"count":1}]	38198	delivery	5	13
98361	2020-07-18 01:49:26	2020-07-18	9	[{"id_menu":6,"count":1}]	10260	delivery	5	14
98362	2020-07-18 01:54:30	2020-07-18	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	13538	delivery	5	44
98363	2020-07-18 01:57:14	2020-07-18	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	13987	delivery	5	28
98364	2020-07-18 01:58:36	2020-07-18	9	[{"id_menu":7,"count":1}]	32376	delivery	5	14
98365	2020-07-18 01:59:56	2020-07-18	12	[{"id_menu":3,"count":1}]	18931	delivery	5	17
98366	2020-07-18 01:59:59	2020-07-18	8	[{"id_menu":5,"count":1}]	37272	delivery	5	13
98367	2020-07-18 02:02:01	2020-07-18	8	[{"id_menu":5,"count":1}]	38176	delivery	5	13
98368	2020-07-18 02:05:25	2020-07-18	14	[{"id_menu":2,"count":1}]	7688	pick-up	0	14
98369	2020-07-18 02:06:20	2020-07-18	8	[{"id_menu":5,"count":1}]	38341	delivery	5	13
98370	2020-07-18 02:06:29	2020-07-18	9	[{"id_menu":6,"count":1}]	38298	delivery	5	14
98371	2020-07-18 02:08:07	2020-07-18	9	[{"id_menu":7,"count":1}]	38303	delivery	5	14
98372	2020-07-18 02:09:03	2020-07-18	12	[{"id_menu":3,"count":1}]	6342	pick-up	0	12
98373	2020-07-18 02:10:12	2020-07-18	9	[{"id_menu":6,"count":1}]	25483	delivery	5	14
98374	2020-07-18 02:10:25	2020-07-18	12	[{"id_menu":3,"count":1}]	12204	delivery	5	17
98375	2020-07-18 02:13:06	2020-07-18	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	5331	delivery	5	26
98376	2020-07-18 02:14:52	2020-07-18	17	[{"id_menu":4,"count":1}]	17578	pick-up	0	17
98377	2020-07-18 02:15:01	2020-07-18	9	[{"id_menu":6,"count":1}]	12248	pick-up	0	9
98378	2020-07-18 02:19:11	2020-07-18	12	[{"id_menu":3,"count":1}]	5130	delivery	5	17
98379	2020-07-18 02:26:06	2020-07-18	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":3}]	37625	delivery	5	26
98380	2020-07-18 02:31:21	2020-07-18	12	[{"id_menu":1,"count":1}]	15325	delivery	5	17
98381	2020-07-18 02:32:03	2020-07-18	12	[{"id_menu":1,"count":1}]	20547	delivery	5	17
98382	2020-07-18 02:32:08	2020-07-18	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	38153	delivery	5	26
98383	2020-07-18 02:32:24	2020-07-18	14	[{"id_menu":2,"count":1}]	38312	delivery	5	19
98384	2020-07-18 02:32:27	2020-07-18	14	[{"id_menu":2,"count":1}]	19277	pick-up	0	14
98385	2020-07-18 02:35:04	2020-07-18	8	[{"id_menu":5,"count":1}]	24668	delivery	5	13
98386	2020-07-18 02:37:06	2020-07-18	9	[{"id_menu":6,"count":1}]	16518	delivery	5	14
98387	2020-07-18 02:37:48	2020-07-18	9	[{"id_menu":6,"count":1}]	11283	delivery	5	14
98388	2020-07-18 02:39:17	2020-07-18	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	38213	delivery	5	22
98389	2020-07-18 02:39:53	2020-07-18	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	38171	delivery	5	34
98390	2020-07-18 02:41:02	2020-07-18	8	[{"id_menu":5,"count":1}]	18168	pick-up	0	8
98391	2020-07-18 02:41:26	2020-07-18	8	[{"id_menu":5,"count":1}]	38233	delivery	5	13
98392	2020-07-18 02:45:29	2020-07-18	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	37012	delivery	5	23
98393	2020-07-18 02:52:24	2020-07-18	8	[{"id_menu":5,"count":1}]	38150	delivery	5	13
98394	2020-07-18 02:52:51	2020-07-18	12	[{"id_menu":3,"count":1}]	37074	delivery	5	17
98395	2020-07-18 02:53:39	2020-07-18	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	17209	delivery	5	27
98396	2020-07-18 02:54:14	2020-07-18	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38263	delivery	5	37
98397	2020-07-18 02:57:51	2020-07-18	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	20711	delivery	5	45
98398	2020-07-18 03:02:23	2020-07-18	14	[{"id_menu":2,"count":1}]	38292	delivery	5	19
98399	2020-07-18 03:02:40	2020-07-18	14	[{"id_menu":2,"count":1}]	29586	pick-up	0	14
98400	2020-07-18 03:03:51	2020-07-18	17	[{"id_menu":4,"count":1}]	28975	delivery	5	22
98401	2020-07-18 03:04:49	2020-07-18	9	[{"id_menu":7,"count":1}]	38283	delivery	5	14
98402	2020-07-18 03:09:03	2020-07-18	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	38261	delivery	5	45
98403	2020-07-18 03:09:55	2020-07-18	9	[{"id_menu":6,"count":1}]	8946	delivery	5	14
98404	2020-07-18 03:12:29	2020-07-18	14	[{"id_menu":2,"count":1}]	38134	delivery	5	19
98405	2020-07-18 03:13:28	2020-07-18	38	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	38267	pick-up	0	38
98406	2020-07-18 03:14:07	2020-07-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	38346	delivery	5	28
98407	2020-07-18 03:15:02	2020-07-18	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	21817	delivery	5	26
98408	2020-07-18 03:15:44	2020-07-18	12	[{"id_menu":3,"count":1}]	29424	delivery	5	17
98409	2020-07-18 03:17:14	2020-07-18	14	[{"id_menu":2,"count":1}]	36308	delivery	5	19
98410	2020-07-18 03:17:26	2020-07-18	9	[{"id_menu":6,"count":1}]	5659	delivery	5	14
98411	2020-07-18 03:18:30	2020-07-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	38197	delivery	5	22
98412	2020-07-18 03:19:10	2020-07-18	9	[{"id_menu":7,"count":1}]	1839	pick-up	0	9
98413	2020-07-18 03:22:58	2020-07-18	8	[{"id_menu":5,"count":1}]	4973	pick-up	0	8
98414	2020-07-18 03:28:01	2020-07-18	14	[{"id_menu":2,"count":1}]	909	pick-up	0	14
98415	2020-07-18 03:28:16	2020-07-18	9	[{"id_menu":6,"count":1}]	26483	delivery	5	14
98416	2020-07-18 03:28:23	2020-07-18	17	[{"id_menu":5,"count":3},{"id_menu":7,"count":1}]	17514	delivery	5	22
98417	2020-07-18 03:31:03	2020-07-18	30	[{"id_menu":1,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27348	delivery	5	35
98418	2020-07-18 03:31:57	2020-07-18	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	15114	delivery	5	40
98419	2020-07-18 03:34:28	2020-07-18	14	[{"id_menu":2,"count":1}]	38290	delivery	5	19
98420	2020-07-18 03:35:06	2020-07-18	12	[{"id_menu":3,"count":1}]	33394	delivery	5	17
98421	2020-07-18 03:37:26	2020-07-18	14	[{"id_menu":2,"count":1}]	38229	delivery	5	19
98422	2020-07-18 03:39:09	2020-07-18	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	36361	delivery	5	48
98423	2020-07-18 03:40:28	2020-07-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	38285	delivery	5	22
98424	2020-07-18 03:42:27	2020-07-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1706	delivery	5	28
98425	2020-07-18 03:44:07	2020-07-18	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11089	pick-up	0	35
98426	2020-07-18 03:44:50	2020-07-18	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	28896	delivery	5	31
98427	2020-07-18 03:46:16	2020-07-18	9	[{"id_menu":6,"count":1}]	10008	pick-up	0	9
98428	2020-07-18 03:47:03	2020-07-18	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16421	delivery	5	36
98429	2020-07-18 03:47:26	2020-07-18	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	38190	delivery	5	39
98430	2020-07-18 03:47:47	2020-07-18	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	12367	pick-up	0	39
98431	2020-07-18 03:49:13	2020-07-18	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	38128	delivery	5	44
98432	2020-07-18 03:50:47	2020-07-18	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	22015	pick-up	0	29
98433	2020-07-18 03:50:59	2020-07-18	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	35161	pick-up	0	43
98434	2020-07-18 03:54:30	2020-07-18	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38315	delivery	5	37
98435	2020-07-18 03:54:57	2020-07-18	12	[{"id_menu":1,"count":1}]	24129	delivery	5	17
98436	2020-07-18 03:55:11	2020-07-18	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	15902	delivery	5	28
98437	2020-07-18 03:57:59	2020-07-18	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	21633	delivery	5	43
98438	2020-07-18 04:01:27	2020-07-18	8	[{"id_menu":5,"count":1}]	9533	pick-up	0	8
98439	2020-07-18 04:05:06	2020-07-18	14	[{"id_menu":2,"count":1}]	5099	pick-up	0	14
98440	2020-07-18 04:11:08	2020-07-18	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7476	delivery	5	34
98441	2020-07-18 04:11:11	2020-07-18	14	[{"id_menu":2,"count":1}]	6228	delivery	5	19
98442	2020-07-18 04:12:48	2020-07-18	12	[{"id_menu":3,"count":1}]	38243	delivery	5	17
98443	2020-07-18 04:22:32	2020-07-18	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4023	delivery	5	31
98444	2020-07-18 04:25:00	2020-07-18	14	[{"id_menu":2,"count":1}]	38306	delivery	5	19
98445	2020-07-18 04:25:20	2020-07-18	9	[{"id_menu":6,"count":1}]	15013	delivery	5	14
98446	2020-07-18 04:27:04	2020-07-18	12	[{"id_menu":3,"count":3}]	32346	delivery	5	17
98447	2020-07-18 04:28:04	2020-07-18	17	[{"id_menu":4,"count":1}]	18847	delivery	5	22
98448	2020-07-18 04:28:18	2020-07-18	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4659	delivery	5	31
98449	2020-07-18 04:28:40	2020-07-18	12	[{"id_menu":1,"count":1}]	33351	delivery	5	17
98450	2020-07-18 04:35:08	2020-07-18	9	[{"id_menu":6,"count":2}]	38247	delivery	5	14
98451	2020-07-18 04:36:25	2020-07-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	3506	delivery	5	28
98452	2020-07-18 04:37:45	2020-07-18	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	27551	delivery	5	40
98453	2020-07-18 04:38:01	2020-07-18	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	38211	pick-up	0	29
98454	2020-07-18 04:38:36	2020-07-18	9	[{"id_menu":7,"count":1}]	3010	pick-up	0	9
98455	2020-07-18 04:39:06	2020-07-18	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	38240	delivery	5	26
98456	2020-07-18 04:44:05	2020-07-18	17	[{"id_menu":4,"count":2}]	38146	delivery	5	22
98457	2020-07-18 04:45:46	2020-07-18	17	[{"id_menu":4,"count":1}]	19399	delivery	5	22
98458	2020-07-18 04:46:31	2020-07-18	12	[{"id_menu":3,"count":1}]	31466	delivery	5	17
98459	2020-07-18 04:47:54	2020-07-18	9	[{"id_menu":7,"count":1}]	25473	delivery	5	14
98460	2020-07-18 04:51:24	2020-07-18	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	38144	pick-up	0	17
98461	2020-07-18 04:51:25	2020-07-18	9	[{"id_menu":6,"count":1}]	23590	delivery	5	14
98462	2020-07-18 04:54:12	2020-07-18	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	17003	delivery	5	31
98463	2020-07-18 04:54:15	2020-07-18	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	32594	delivery	5	40
98464	2020-07-18 05:00:37	2020-07-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38205	delivery	5	23
98465	2020-07-18 05:01:57	2020-07-18	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15437	delivery	5	40
98466	2020-07-18 05:02:47	2020-07-18	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	38223	delivery	5	30
98467	2020-07-18 05:04:21	2020-07-18	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	24965	delivery	5	31
98468	2020-07-18 05:04:55	2020-07-18	8	[{"id_menu":5,"count":1}]	16471	delivery	5	13
98469	2020-07-18 05:08:02	2020-07-18	12	[{"id_menu":3,"count":1}]	27082	delivery	5	17
98470	2020-07-18 05:09:33	2020-07-18	12	[{"id_menu":3,"count":1}]	38288	delivery	5	17
98471	2020-07-18 05:09:42	2020-07-18	9	[{"id_menu":7,"count":1}]	14947	pick-up	0	9
98472	2020-07-18 05:11:36	2020-07-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	26130	pick-up	0	23
98473	2020-07-18 05:16:08	2020-07-18	14	[{"id_menu":2,"count":1}]	5861	delivery	5	19
98474	2020-07-18 05:16:54	2020-07-18	9	[{"id_menu":7,"count":1}]	26826	delivery	5	14
98475	2020-07-18 05:16:58	2020-07-18	9	[{"id_menu":7,"count":1}]	16686	delivery	5	14
98476	2020-07-18 05:17:06	2020-07-18	8	[{"id_menu":5,"count":1}]	2276	pick-up	0	8
98477	2020-07-18 05:17:21	2020-07-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38115	delivery	5	23
98478	2020-07-18 05:18:06	2020-07-18	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	3403	delivery	5	29
98479	2020-07-18 05:19:45	2020-07-18	9	[{"id_menu":7,"count":1}]	4223	delivery	5	14
98480	2020-07-18 05:20:12	2020-07-18	8	[{"id_menu":5,"count":1}]	38121	delivery	5	13
98481	2020-07-18 05:21:53	2020-07-18	14	[{"id_menu":2,"count":1}]	1862	pick-up	0	14
98482	2020-07-18 05:23:03	2020-07-18	9	[{"id_menu":6,"count":1}]	34479	delivery	5	14
98483	2020-07-18 05:24:46	2020-07-18	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38201	delivery	5	40
98484	2020-07-18 05:29:28	2020-07-18	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	38111	delivery	5	22
98485	2020-07-18 05:33:22	2020-07-18	17	[{"id_menu":4,"count":1}]	12945	delivery	5	22
98486	2020-07-18 05:33:35	2020-07-18	8	[{"id_menu":5,"count":1}]	38154	delivery	5	13
98487	2020-07-18 05:39:54	2020-07-18	14	[{"id_menu":2,"count":1}]	38244	pick-up	0	14
98488	2020-07-18 05:40:11	2020-07-18	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	38329	delivery	5	39
98489	2020-07-18 05:43:34	2020-07-18	17	[{"id_menu":4,"count":1}]	38345	pick-up	0	17
98490	2020-07-18 05:45:51	2020-07-18	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	38112	delivery	5	26
98491	2020-07-18 05:46:13	2020-07-18	14	[{"id_menu":2,"count":1}]	18908	delivery	5	19
98492	2020-07-18 05:48:38	2020-07-18	9	[{"id_menu":6,"count":1}]	36663	delivery	5	14
98493	2020-07-18 05:49:17	2020-07-18	14	[{"id_menu":2,"count":1}]	10284	delivery	5	19
98494	2020-07-18 05:50:28	2020-07-18	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	19212	delivery	5	25
98495	2020-07-18 05:52:35	2020-07-18	14	[{"id_menu":2,"count":1}]	33769	delivery	5	19
98496	2020-07-18 05:52:54	2020-07-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28570	delivery	5	23
98497	2020-07-18 05:55:17	2020-07-18	8	[{"id_menu":5,"count":1}]	20382	delivery	5	13
98498	2020-07-18 05:58:10	2020-07-18	12	[{"id_menu":1,"count":1}]	21483	pick-up	0	12
98499	2020-07-18 05:58:13	2020-07-18	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	321	pick-up	0	21
98500	2020-07-18 05:59:08	2020-07-18	9	[{"id_menu":7,"count":1}]	31876	pick-up	0	9
98501	2020-07-18 06:00:01	2020-07-18	9	[{"id_menu":6,"count":1}]	31062	delivery	5	14
98502	2020-07-18 06:01:19	2020-07-18	17	[{"id_menu":4,"count":1}]	38142	delivery	5	22
98503	2020-07-18 06:01:58	2020-07-18	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9459	delivery	5	31
98504	2020-07-18 06:02:29	2020-07-18	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	8050	delivery	5	25
98505	2020-07-18 06:03:47	2020-07-18	8	[{"id_menu":5,"count":1}]	6813	delivery	5	13
98506	2020-07-18 06:04:15	2020-07-18	12	[{"id_menu":1,"count":1}]	25785	delivery	5	17
98507	2020-07-18 06:08:15	2020-07-18	17	[{"id_menu":4,"count":1}]	38287	delivery	5	22
98508	2020-07-18 06:13:18	2020-07-18	9	[{"id_menu":6,"count":1}]	28717	delivery	5	14
98509	2020-07-18 06:20:04	2020-07-18	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	14990	delivery	5	45
98510	2020-07-18 06:21:55	2020-07-18	17	[{"id_menu":4,"count":1}]	5036	delivery	5	22
98511	2020-07-18 06:26:30	2020-07-18	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	18202	pick-up	0	40
98512	2020-07-18 06:30:34	2020-07-18	12	[{"id_menu":1,"count":1}]	38160	delivery	5	17
98513	2020-07-18 06:33:08	2020-07-18	9	[{"id_menu":7,"count":1}]	24755	delivery	5	14
98514	2020-07-18 06:34:06	2020-07-18	17	[{"id_menu":4,"count":1}]	34068	delivery	5	22
98515	2020-07-18 06:35:22	2020-07-18	14	[{"id_menu":2,"count":1}]	28786	delivery	5	19
98516	2020-07-18 06:37:18	2020-07-18	9	[{"id_menu":7,"count":1}]	38159	delivery	5	14
98517	2020-07-18 06:37:27	2020-07-18	17	[{"id_menu":4,"count":1}]	9054	delivery	5	22
98518	2020-07-18 06:37:29	2020-07-18	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	17790	pick-up	0	39
98519	2020-07-18 06:40:53	2020-07-18	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	38237	delivery	5	45
98520	2020-07-18 06:41:03	2020-07-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	38200	delivery	5	28
98521	2020-07-18 06:45:47	2020-07-18	12	[{"id_menu":3,"count":1}]	38166	pick-up	0	12
98522	2020-07-18 06:48:01	2020-07-18	12	[{"id_menu":1,"count":1}]	17748	delivery	5	17
98523	2020-07-18 06:48:12	2020-07-18	14	[{"id_menu":2,"count":1}]	4811	delivery	5	19
98524	2020-07-18 06:49:56	2020-07-18	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	26444	delivery	5	31
98525	2020-07-18 06:49:56	2020-07-18	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	207	pick-up	0	31
98526	2020-07-18 06:50:18	2020-07-18	9	[{"id_menu":6,"count":1}]	26373	pick-up	0	9
98527	2020-07-18 06:50:57	2020-07-18	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	6358	delivery	5	26
98528	2020-07-18 06:50:57	2020-07-18	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	4960	pick-up	0	29
98529	2020-07-18 06:53:18	2020-07-18	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3271	delivery	5	27
98530	2020-07-18 06:53:23	2020-07-18	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	709	pick-up	0	21
98531	2020-07-18 06:54:16	2020-07-18	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	26577	delivery	5	53
98532	2020-07-18 06:54:19	2020-07-18	9	[{"id_menu":7,"count":1}]	778	pick-up	0	9
98533	2020-07-18 06:54:32	2020-07-18	14	[{"id_menu":2,"count":1}]	1306	pick-up	0	14
98534	2020-07-18 06:55:00	2020-07-18	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	38137	delivery	5	40
98535	2020-07-18 06:58:55	2020-07-18	9	[{"id_menu":6,"count":1}]	38344	delivery	5	14
98536	2020-07-18 07:04:01	2020-07-18	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	5338	pick-up	0	31
98537	2020-07-18 07:05:16	2020-07-18	12	[{"id_menu":1,"count":1}]	2902	pick-up	0	12
98538	2020-07-18 07:06:52	2020-07-18	17	[{"id_menu":4,"count":1}]	38347	delivery	5	22
98539	2020-07-18 07:08:34	2020-07-18	39	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	32844	delivery	5	44
98540	2020-07-18 07:12:45	2020-07-18	9	[{"id_menu":7,"count":1}]	20518	delivery	5	14
98541	2020-07-18 07:13:01	2020-07-18	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	38035	delivery	5	23
98542	2020-07-18 07:13:01	2020-07-18	9	[{"id_menu":6,"count":1}]	38162	delivery	5	14
98543	2020-07-18 07:13:50	2020-07-18	12	[{"id_menu":3,"count":1}]	38284	delivery	5	17
98544	2020-07-18 07:14:23	2020-07-18	8	[{"id_menu":5,"count":2}]	36603	delivery	5	13
98545	2020-07-18 07:14:26	2020-07-18	8	[{"id_menu":5,"count":1}]	38310	pick-up	0	8
98546	2020-07-18 07:15:57	2020-07-18	14	[{"id_menu":2,"count":1}]	1603	delivery	5	19
98547	2020-07-18 07:16:06	2020-07-18	12	[{"id_menu":1,"count":2}]	11262	pick-up	0	12
98548	2020-07-18 07:19:33	2020-07-18	9	[{"id_menu":7,"count":2}]	14741	delivery	5	14
98549	2020-07-18 07:19:46	2020-07-18	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	38126	delivery	5	57
98550	2020-07-18 07:22:03	2020-07-18	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	26855	delivery	5	31
98551	2020-07-18 07:22:08	2020-07-18	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	38195	delivery	5	26
98552	2020-07-18 07:23:58	2020-07-18	14	[{"id_menu":2,"count":1}]	8180	delivery	5	19
98553	2020-07-18 07:24:03	2020-07-18	9	[{"id_menu":6,"count":1}]	38325	delivery	5	14
98554	2020-07-18 07:30:50	2020-07-18	9	[{"id_menu":7,"count":1}]	31696	delivery	5	14
98555	2020-07-18 07:30:57	2020-07-18	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	38305	delivery	5	22
98556	2020-07-18 07:35:27	2020-07-18	12	[{"id_menu":1,"count":1}]	25283	delivery	5	17
98557	2020-07-18 07:35:58	2020-07-18	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	38277	delivery	5	45
98558	2020-07-18 07:37:11	2020-07-18	8	[{"id_menu":5,"count":1}]	33774	delivery	5	13
98559	2020-07-18 07:37:23	2020-07-18	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	38326	delivery	5	25
98560	2020-07-18 07:37:31	2020-07-18	14	[{"id_menu":2,"count":1}]	38249	delivery	5	19
98561	2020-07-18 07:37:34	2020-07-18	9	[{"id_menu":7,"count":2}]	13507	delivery	5	14
98562	2020-07-18 07:39:12	2020-07-18	17	[{"id_menu":4,"count":1}]	24325	delivery	5	22
98563	2020-07-18 07:40:42	2020-07-18	14	[{"id_menu":2,"count":1}]	18257	delivery	5	19
98564	2020-07-18 07:40:56	2020-07-18	9	[{"id_menu":6,"count":1}]	996	delivery	5	14
98565	2020-07-18 07:41:42	2020-07-18	8	[{"id_menu":5,"count":1}]	32358	delivery	5	13
98566	2020-07-18 07:45:29	2020-07-18	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	38155	pick-up	0	29
98567	2020-07-18 07:51:51	2020-07-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	38340	delivery	5	22
98568	2020-07-18 07:51:54	2020-07-18	9	[{"id_menu":6,"count":1}]	38336	pick-up	0	9
98569	2020-07-18 07:53:11	2020-07-18	17	[{"id_menu":4,"count":1}]	35829	delivery	5	22
98570	2020-07-18 07:53:27	2020-07-18	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	38338	delivery	5	26
98571	2020-07-18 07:53:29	2020-07-18	17	[{"id_menu":4,"count":1}]	32363	delivery	5	22
98572	2020-07-18 07:54:24	2020-07-18	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	31151	delivery	5	55
98573	2020-07-18 07:57:41	2020-07-18	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	38202	delivery	5	34
98574	2020-07-18 08:02:09	2020-07-18	17	[{"id_menu":4,"count":1}]	38270	delivery	5	22
98575	2020-07-18 08:03:18	2020-07-18	12	[{"id_menu":3,"count":1}]	18683	delivery	5	17
98576	2020-07-18 08:04:09	2020-07-18	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38125	delivery	5	47
98577	2020-07-18 08:05:23	2020-07-18	9	[{"id_menu":7,"count":1}]	13236	delivery	5	14
98578	2020-07-18 08:05:51	2020-07-18	12	[{"id_menu":1,"count":1}]	38149	pick-up	0	12
98579	2020-07-18 08:07:25	2020-07-18	12	[{"id_menu":1,"count":1}]	38180	delivery	5	17
98580	2020-07-18 08:10:50	2020-07-18	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	189	pick-up	0	39
98581	2020-07-18 08:12:53	2020-07-18	17	[{"id_menu":4,"count":2}]	38177	delivery	5	22
98582	2020-07-18 08:13:49	2020-07-18	12	[{"id_menu":1,"count":1}]	27664	delivery	5	17
98583	2020-07-18 08:14:19	2020-07-18	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	26905	delivery	5	45
98584	2020-07-18 08:15:01	2020-07-18	9	[{"id_menu":7,"count":1}]	36733	pick-up	0	9
98585	2020-07-18 08:15:12	2020-07-18	17	[{"id_menu":4,"count":1}]	23653	delivery	5	22
98586	2020-07-18 08:15:43	2020-07-18	12	[{"id_menu":3,"count":1}]	17941	delivery	5	17
98587	2020-07-18 08:20:22	2020-07-18	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	264	delivery	5	48
98588	2020-07-18 08:22:03	2020-07-18	9	[{"id_menu":6,"count":1}]	6176	delivery	5	14
98589	2020-07-18 08:27:17	2020-07-18	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	38282	pick-up	0	21
98590	2020-07-18 08:27:21	2020-07-18	12	[{"id_menu":3,"count":1}]	6910	pick-up	0	12
98591	2020-07-18 08:29:09	2020-07-18	17	[{"id_menu":4,"count":1}]	4411	delivery	5	22
98592	2020-07-18 08:33:39	2020-07-18	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	22626	delivery	5	36
98593	2020-07-18 08:34:59	2020-07-18	8	[{"id_menu":5,"count":1}]	29762	delivery	5	13
98594	2020-07-18 08:36:16	2020-07-18	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	21109	pick-up	0	51
98595	2020-07-18 08:36:32	2020-07-18	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	38278	delivery	5	44
98596	2020-07-18 08:36:33	2020-07-18	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	602	delivery	5	34
98597	2020-07-18 08:42:01	2020-07-18	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37920	delivery	5	43
98598	2020-07-18 08:42:41	2020-07-18	14	[{"id_menu":2,"count":1}]	38274	delivery	5	19
98599	2020-07-18 08:46:18	2020-07-18	17	[{"id_menu":4,"count":1}]	18990	delivery	5	22
98600	2020-07-18 08:47:25	2020-07-18	12	[{"id_menu":3,"count":1}]	3264	delivery	5	17
98601	2020-07-18 08:49:12	2020-07-18	14	[{"id_menu":2,"count":1}]	27300	delivery	5	19
98602	2020-07-18 08:49:33	2020-07-18	14	[{"id_menu":2,"count":1}]	38255	delivery	5	19
98603	2020-07-18 08:50:23	2020-07-18	12	[{"id_menu":1,"count":1}]	1578	pick-up	0	12
98604	2020-07-18 08:51:04	2020-07-18	17	[{"id_menu":4,"count":1}]	7710	delivery	5	22
98605	2020-07-18 08:53:40	2020-07-18	8	[{"id_menu":5,"count":1}]	7107	delivery	5	13
98606	2020-07-18 08:54:11	2020-07-18	9	[{"id_menu":6,"count":1}]	9749	pick-up	0	9
98607	2020-07-18 08:54:52	2020-07-18	14	[{"id_menu":2,"count":1}]	38203	delivery	5	19
98608	2020-07-18 08:55:03	2020-07-18	9	[{"id_menu":6,"count":1}]	593	pick-up	0	9
98609	2020-07-18 08:55:27	2020-07-18	9	[{"id_menu":6,"count":1}]	5994	delivery	5	14
98610	2020-07-18 08:56:10	2020-07-18	9	[{"id_menu":6,"count":1}]	4575	delivery	5	14
98611	2020-07-18 08:59:58	2020-07-18	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	10153	pick-up	0	22
98612	2020-07-18 09:00:08	2020-07-18	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	22357	delivery	5	31
98613	2020-07-18 09:00:32	2020-07-18	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2561	delivery	5	31
98614	2020-07-18 09:05:38	2020-07-18	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4868	delivery	5	34
98615	2020-07-18 09:08:23	2020-07-18	9	[{"id_menu":6,"count":1}]	12225	delivery	5	14
98616	2020-07-18 09:09:06	2020-07-18	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	35285	delivery	5	22
98617	2020-07-18 09:09:17	2020-07-18	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	17174	pick-up	0	20
98618	2020-07-18 09:09:21	2020-07-18	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	3418	delivery	5	29
98619	2020-07-18 09:10:41	2020-07-18	17	[{"id_menu":4,"count":1}]	6140	delivery	5	22
98620	2020-07-18 09:12:13	2020-07-18	9	[{"id_menu":6,"count":1}]	38127	delivery	5	14
98621	2020-07-18 09:13:20	2020-07-18	9	[{"id_menu":6,"count":1}]	38118	delivery	5	14
98622	2020-07-18 09:14:57	2020-07-18	9	[{"id_menu":6,"count":1}]	36502	delivery	5	14
98623	2020-07-18 09:16:08	2020-07-18	14	[{"id_menu":2,"count":1}]	19724	delivery	5	19
98624	2020-07-18 09:18:14	2020-07-18	9	[{"id_menu":6,"count":1}]	38262	delivery	5	14
98625	2020-07-18 09:18:21	2020-07-18	14	[{"id_menu":2,"count":1}]	26994	delivery	5	19
98626	2020-07-18 09:18:22	2020-07-18	14	[{"id_menu":2,"count":1}]	38291	delivery	5	19
98627	2020-07-18 09:21:23	2020-07-18	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	38313	delivery	5	23
98628	2020-07-18 09:22:41	2020-07-18	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	24697	pick-up	0	20
98629	2020-07-18 09:24:56	2020-07-18	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8215	delivery	5	39
98630	2020-07-18 09:25:32	2020-07-18	17	[{"id_menu":4,"count":1}]	34640	delivery	5	22
98631	2020-07-18 09:28:02	2020-07-18	8	[{"id_menu":5,"count":1}]	38156	delivery	5	13
98632	2020-07-18 09:28:14	2020-07-18	12	[{"id_menu":3,"count":1}]	23427	delivery	5	17
98633	2020-07-18 09:28:59	2020-07-18	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	36922	delivery	5	25
98634	2020-07-18 09:34:45	2020-07-18	9	[{"id_menu":6,"count":1}]	31411	delivery	5	14
98635	2020-07-18 09:40:03	2020-07-18	17	[{"id_menu":4,"count":1}]	17502	pick-up	0	17
98636	2020-07-18 09:40:09	2020-07-18	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	16250	delivery	5	22
98637	2020-07-18 09:41:40	2020-07-18	9	[{"id_menu":6,"count":1}]	8372	pick-up	0	9
98638	2020-07-18 09:47:11	2020-07-18	14	[{"id_menu":2,"count":1}]	6554	delivery	5	19
98639	2020-07-18 09:48:23	2020-07-18	17	[{"id_menu":4,"count":1}]	1181	pick-up	0	17
98640	2020-07-18 09:51:44	2020-07-18	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	38157	delivery	5	36
98641	2020-07-18 09:52:05	2020-07-18	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	32581	pick-up	0	35
98642	2020-07-18 10:00:14	2020-07-18	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1819	pick-up	0	25
98643	2020-07-18 10:02:18	2020-07-18	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17078	delivery	5	48
98644	2020-07-18 10:03:23	2020-07-18	14	[{"id_menu":2,"count":1}]	2140	pick-up	0	14
98645	2020-07-18 10:03:57	2020-07-18	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14838	delivery	5	39
98646	2020-07-18 10:05:35	2020-07-18	9	[{"id_menu":6,"count":1}]	29215	delivery	5	14
98647	2020-07-18 10:05:40	2020-07-18	9	[{"id_menu":7,"count":1}]	34999	pick-up	0	9
98648	2020-07-18 10:06:21	2020-07-18	14	[{"id_menu":2,"count":1}]	38114	delivery	5	19
98649	2020-07-18 10:06:25	2020-07-18	12	[{"id_menu":3,"count":1}]	9001	delivery	5	17
98650	2020-07-18 10:07:19	2020-07-18	17	[{"id_menu":4,"count":1}]	38301	pick-up	0	17
98651	2020-07-18 10:07:47	2020-07-18	12	[{"id_menu":3,"count":1}]	38163	pick-up	0	12
98652	2020-07-18 10:11:06	2020-07-18	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	24882	delivery	5	31
98653	2020-07-18 10:14:14	2020-07-18	9	[{"id_menu":7,"count":1}]	37694	pick-up	0	9
98654	2020-07-18 10:16:21	2020-07-18	17	[{"id_menu":4,"count":1}]	34582	pick-up	0	17
98655	2020-07-18 10:18:27	2020-07-18	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2282	pick-up	0	22
98656	2020-07-18 10:20:33	2020-07-18	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	38199	delivery	5	31
98657	2020-07-18 10:21:30	2020-07-18	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15190	delivery	5	31
98658	2020-07-18 10:25:36	2020-07-18	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	7144	delivery	5	25
98659	2020-07-18 10:26:14	2020-07-18	9	[{"id_menu":6,"count":1}]	1559	delivery	5	14
98660	2020-07-18 10:26:22	2020-07-18	8	[{"id_menu":5,"count":1}]	27819	delivery	5	13
98661	2020-07-18 10:27:05	2020-07-18	14	[{"id_menu":2,"count":1}]	20780	pick-up	0	14
98662	2020-07-18 10:30:09	2020-07-18	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	8500	delivery	5	36
98663	2020-07-18 10:34:43	2020-07-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	38322	delivery	5	28
98664	2020-07-18 10:36:13	2020-07-18	9	[{"id_menu":7,"count":1}]	38342	delivery	5	14
98665	2020-07-18 10:36:26	2020-07-18	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	33230	delivery	5	39
98666	2020-07-18 10:37:50	2020-07-18	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	25124	delivery	5	22
98667	2020-07-18 10:38:19	2020-07-18	17	[{"id_menu":4,"count":1}]	13651	delivery	5	22
98668	2020-07-18 10:44:44	2020-07-18	9	[{"id_menu":7,"count":3}]	38320	delivery	5	14
98669	2020-07-18 10:44:56	2020-07-18	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	5834	delivery	5	45
98670	2020-07-18 10:47:24	2020-07-18	14	[{"id_menu":2,"count":1}]	14306	delivery	5	19
98671	2020-07-18 10:47:49	2020-07-18	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	31323	delivery	5	39
98672	2020-07-18 10:48:55	2020-07-18	17	[{"id_menu":4,"count":1}]	29917	delivery	5	22
98673	2020-07-18 10:51:26	2020-07-18	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	38348	delivery	5	25
98674	2020-07-18 10:56:10	2020-07-18	9	[{"id_menu":7,"count":1}]	4658	pick-up	0	9
98675	2020-07-18 10:57:46	2020-07-18	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38140	delivery	5	37
98676	2020-07-18 10:57:51	2020-07-18	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	31763	delivery	5	42
98677	2020-07-18 10:58:30	2020-07-18	9	[{"id_menu":6,"count":1}]	38296	delivery	5	14
98678	2020-07-18 11:00:56	2020-07-18	12	[{"id_menu":3,"count":1}]	11228	delivery	5	17
98679	2020-07-18 11:01:17	2020-07-18	8	[{"id_menu":5,"count":3}]	37589	delivery	5	13
98680	2020-07-18 11:02:16	2020-07-18	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	23735	pick-up	0	26
98681	2020-07-18 11:02:37	2020-07-18	14	[{"id_menu":2,"count":1}]	10289	delivery	5	19
98682	2020-07-18 11:03:55	2020-07-18	9	[{"id_menu":7,"count":2}]	464	pick-up	0	9
98683	2020-07-18 11:04:48	2020-07-18	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15105	delivery	5	22
98684	2020-07-18 11:05:30	2020-07-18	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	223	pick-up	0	25
98685	2020-07-18 11:06:12	2020-07-18	14	[{"id_menu":2,"count":1}]	38116	delivery	5	19
98686	2020-07-18 11:08:56	2020-07-18	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	38225	delivery	5	31
98687	2020-07-18 11:10:20	2020-07-18	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	15578	delivery	5	26
98688	2020-07-18 11:11:26	2020-07-18	17	[{"id_menu":4,"count":1}]	38286	delivery	5	22
98689	2020-07-18 11:11:51	2020-07-18	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	36788	delivery	5	31
98690	2020-07-18 11:12:19	2020-07-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	32603	delivery	5	23
98691	2020-07-18 11:13:50	2020-07-18	12	[{"id_menu":3,"count":1}]	9322	delivery	5	17
98692	2020-07-18 11:16:17	2020-07-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	38311	delivery	5	28
98693	2020-07-18 11:17:01	2020-07-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27758	delivery	5	22
98694	2020-07-18 11:17:38	2020-07-18	8	[{"id_menu":5,"count":1}]	34944	delivery	5	13
98695	2020-07-18 11:17:59	2020-07-18	9	[{"id_menu":6,"count":3}]	28617	delivery	5	14
98696	2020-07-18 11:18:38	2020-07-18	12	[{"id_menu":3,"count":1}]	32138	delivery	5	17
98697	2020-07-18 11:19:01	2020-07-18	12	[{"id_menu":3,"count":1}]	13757	pick-up	0	12
98698	2020-07-18 11:21:06	2020-07-18	14	[{"id_menu":2,"count":1}]	11183	pick-up	0	14
98699	2020-07-18 11:23:25	2020-07-18	12	[{"id_menu":1,"count":1}]	32146	delivery	5	17
98700	2020-07-18 11:23:50	2020-07-18	9	[{"id_menu":7,"count":1}]	286	pick-up	0	9
98701	2020-07-18 11:33:28	2020-07-18	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	36435	delivery	5	22
98702	2020-07-18 11:35:09	2020-07-18	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	38276	delivery	5	40
98703	2020-07-18 11:38:07	2020-07-18	8	[{"id_menu":5,"count":1}]	38273	delivery	5	13
98704	2020-07-18 11:38:11	2020-07-18	17	[{"id_menu":4,"count":1}]	6369	pick-up	0	17
98705	2020-07-18 11:41:57	2020-07-18	12	[{"id_menu":1,"count":1}]	22590	delivery	5	17
98706	2020-07-18 11:44:15	2020-07-18	9	[{"id_menu":6,"count":1}]	38343	delivery	5	14
98707	2020-07-18 11:45:02	2020-07-18	9	[{"id_menu":6,"count":1}]	34438	delivery	5	14
98708	2020-07-18 11:46:42	2020-07-18	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	35315	delivery	5	45
98709	2020-07-18 11:50:59	2020-07-18	8	[{"id_menu":5,"count":1}]	38279	delivery	5	13
98710	2020-07-18 11:52:00	2020-07-18	14	[{"id_menu":2,"count":1}]	18225	delivery	5	19
98711	2020-07-18 11:53:12	2020-07-18	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	10374	pick-up	0	31
98712	2020-07-18 11:56:58	2020-07-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9014	delivery	5	23
98713	2020-07-18 11:57:59	2020-07-18	9	[{"id_menu":6,"count":1}]	24769	delivery	5	14
98714	2020-07-18 11:58:11	2020-07-18	17	[{"id_menu":4,"count":1}]	25815	delivery	5	22
98715	2020-07-18 11:59:44	2020-07-18	12	[{"id_menu":1,"count":1}]	31954	delivery	5	17
98716	2020-07-18 12:00:00	2020-07-18	14	[{"id_menu":2,"count":1}]	38258	delivery	5	19
98717	2020-07-18 12:01:19	2020-07-18	8	[{"id_menu":5,"count":1}]	1485	delivery	5	13
98718	2020-07-18 12:03:31	2020-07-18	9	[{"id_menu":7,"count":1}]	38158	delivery	5	14
98719	2020-07-18 12:03:43	2020-07-18	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":2}]	38169	delivery	5	22
98720	2020-07-18 12:03:49	2020-07-18	9	[{"id_menu":6,"count":1}]	30841	delivery	5	14
98721	2020-07-18 12:09:35	2020-07-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	19034	pick-up	0	23
98722	2020-07-18 12:11:23	2020-07-18	8	[{"id_menu":5,"count":1}]	38187	delivery	5	13
98723	2020-07-18 12:12:31	2020-07-18	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14320	delivery	5	43
98724	2020-07-18 12:13:56	2020-07-18	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	38206	delivery	5	53
98725	2020-07-18 12:15:23	2020-07-18	9	[{"id_menu":6,"count":1}]	27970	delivery	5	14
98726	2020-07-18 12:17:04	2020-07-18	9	[{"id_menu":6,"count":1}]	27744	delivery	5	14
98727	2020-07-18 12:19:43	2020-07-18	17	[{"id_menu":4,"count":1}]	26536	delivery	5	22
98728	2020-07-18 12:21:21	2020-07-18	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	20988	delivery	5	31
98729	2020-07-18 12:22:06	2020-07-18	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2070	pick-up	0	26
98730	2020-07-18 12:23:29	2020-07-18	14	[{"id_menu":2,"count":1}]	2875	pick-up	0	14
98731	2020-07-18 12:25:32	2020-07-18	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8365	delivery	5	44
98732	2020-07-18 12:26:22	2020-07-18	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	27183	delivery	5	36
98733	2020-07-18 12:26:36	2020-07-18	14	[{"id_menu":2,"count":1}]	11519	pick-up	0	14
98734	2020-07-18 12:27:23	2020-07-18	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	35512	delivery	5	53
98735	2020-07-18 12:27:40	2020-07-18	9	[{"id_menu":7,"count":1}]	31205	delivery	5	14
98736	2020-07-18 12:27:51	2020-07-18	9	[{"id_menu":7,"count":1}]	26220	delivery	5	14
98737	2020-07-18 12:29:30	2020-07-18	14	[{"id_menu":2,"count":1}]	24377	delivery	5	19
98738	2020-07-18 12:33:11	2020-07-18	12	[{"id_menu":1,"count":1}]	1968	pick-up	0	12
98739	2020-07-18 12:34:45	2020-07-18	14	[{"id_menu":2,"count":1}]	12242	delivery	5	19
98740	2020-07-18 12:35:02	2020-07-18	8	[{"id_menu":5,"count":1}]	20799	delivery	5	13
98741	2020-07-18 12:36:11	2020-07-18	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	14662	delivery	5	25
98742	2020-07-18 12:36:21	2020-07-18	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	20199	delivery	5	26
98743	2020-07-18 12:36:50	2020-07-18	14	[{"id_menu":2,"count":1}]	3178	delivery	5	19
98744	2020-07-18 12:38:14	2020-07-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	38219	delivery	5	28
98745	2020-07-18 12:39:03	2020-07-18	9	[{"id_menu":7,"count":1}]	32180	delivery	5	14
98746	2020-07-18 12:39:18	2020-07-18	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	13256	pick-up	0	21
98747	2020-07-18 12:40:49	2020-07-18	9	[{"id_menu":7,"count":2}]	21785	pick-up	0	9
98748	2020-07-18 12:43:50	2020-07-18	12	[{"id_menu":1,"count":1}]	31249	pick-up	0	12
98749	2020-07-18 12:44:14	2020-07-18	9	[{"id_menu":7,"count":1}]	38248	delivery	5	14
98750	2020-07-18 12:44:29	2020-07-18	14	[{"id_menu":2,"count":1}]	9859	pick-up	0	14
98751	2020-07-18 12:45:21	2020-07-18	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	30607	delivery	5	39
98752	2020-07-18 12:47:34	2020-07-18	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	38135	delivery	5	22
98753	2020-07-18 12:53:04	2020-07-18	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	38266	delivery	5	40
98754	2020-07-18 12:54:26	2020-07-18	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12623	pick-up	0	31
98755	2020-07-18 12:55:33	2020-07-18	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	12450	delivery	5	36
98756	2020-07-18 12:55:36	2020-07-18	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	38194	delivery	5	30
98757	2020-07-18 12:56:10	2020-07-18	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	38113	delivery	5	40
98758	2020-07-18 12:56:16	2020-07-18	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	38252	delivery	5	31
98759	2020-07-18 12:58:32	2020-07-18	12	[{"id_menu":1,"count":2}]	18090	delivery	5	17
98760	2020-07-18 13:01:15	2020-07-18	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	29	pick-up	0	38
98761	2020-07-18 13:03:33	2020-07-18	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	29470	delivery	5	31
98762	2020-07-18 13:04:06	2020-07-18	12	[{"id_menu":1,"count":1}]	4652	pick-up	0	12
98763	2020-07-18 13:04:41	2020-07-18	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	38152	delivery	5	39
98764	2020-07-18 13:06:40	2020-07-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	9844	delivery	5	28
98765	2020-07-18 13:07:05	2020-07-18	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	27538	pick-up	0	29
98766	2020-07-18 13:07:38	2020-07-18	9	[{"id_menu":7,"count":1}]	38172	delivery	5	14
98767	2020-07-18 13:08:53	2020-07-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15063	delivery	5	23
98768	2020-07-18 13:10:11	2020-07-18	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	25212	delivery	5	43
98769	2020-07-18 13:13:22	2020-07-18	14	[{"id_menu":2,"count":1}]	38330	delivery	5	19
98770	2020-07-18 13:17:06	2020-07-18	9	[{"id_menu":7,"count":1}]	14733	delivery	5	14
98771	2020-07-18 13:18:06	2020-07-18	8	[{"id_menu":5,"count":1}]	10197	delivery	5	13
98772	2020-07-18 13:18:53	2020-07-18	9	[{"id_menu":6,"count":1}]	38170	delivery	5	14
98773	2020-07-18 13:19:11	2020-07-18	17	[{"id_menu":4,"count":1}]	38189	delivery	5	22
98774	2020-07-18 13:20:38	2020-07-18	9	[{"id_menu":6,"count":1}]	38186	delivery	5	14
98775	2020-07-18 13:20:39	2020-07-18	34	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	38122	delivery	5	39
98776	2020-07-18 13:24:32	2020-07-18	8	[{"id_menu":5,"count":1}]	36265	delivery	5	13
98777	2020-07-18 13:32:11	2020-07-18	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	38178	delivery	5	34
98778	2020-07-18 13:33:13	2020-07-18	12	[{"id_menu":1,"count":1}]	30751	delivery	5	17
98779	2020-07-18 13:37:11	2020-07-18	17	[{"id_menu":4,"count":2}]	38204	delivery	5	22
98780	2020-07-18 13:44:12	2020-07-18	8	[{"id_menu":5,"count":1}]	38181	delivery	5	13
98781	2020-07-18 13:44:21	2020-07-18	8	[{"id_menu":5,"count":1}]	7711	delivery	5	13
98782	2020-07-18 13:52:03	2020-07-18	9	[{"id_menu":6,"count":1}]	38117	delivery	5	14
98783	2020-07-18 13:52:15	2020-07-18	9	[{"id_menu":6,"count":2}]	34216	delivery	5	14
98784	2020-07-18 13:55:14	2020-07-18	8	[{"id_menu":5,"count":1}]	8627	delivery	5	13
98785	2020-07-18 13:57:16	2020-07-18	9	[{"id_menu":7,"count":1}]	38179	delivery	5	14
98786	2020-07-18 13:58:04	2020-07-18	8	[{"id_menu":5,"count":1}]	547	pick-up	0	8
98787	2020-07-18 13:58:26	2020-07-18	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	38151	delivery	5	23
98788	2020-07-18 14:00:13	2020-07-18	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	37759	delivery	5	40
98789	2020-07-18 14:00:29	2020-07-18	9	[{"id_menu":7,"count":1}]	17700	pick-up	0	9
98790	2020-07-18 14:04:13	2020-07-18	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	38242	pick-up	0	20
98791	2020-07-18 14:06:27	2020-07-18	14	[{"id_menu":2,"count":1}]	5972	delivery	5	19
98792	2020-07-18 14:06:48	2020-07-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17169	delivery	5	22
98793	2020-07-18 14:14:38	2020-07-18	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	10001	delivery	5	42
98794	2020-07-18 14:18:11	2020-07-18	9	[{"id_menu":6,"count":1}]	33876	delivery	5	14
98795	2020-07-18 14:19:16	2020-07-18	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	33530	pick-up	0	25
98796	2020-07-18 14:19:36	2020-07-18	8	[{"id_menu":5,"count":1}]	2928	pick-up	0	8
98797	2020-07-18 14:19:36	2020-07-18	14	[{"id_menu":2,"count":4}]	38241	delivery	5	19
98798	2020-07-18 14:20:49	2020-07-18	14	[{"id_menu":2,"count":1}]	38334	delivery	5	19
98799	2020-07-18 14:21:56	2020-07-18	9	[{"id_menu":6,"count":2}]	8687	delivery	5	14
98800	2020-07-18 14:22:02	2020-07-18	9	[{"id_menu":6,"count":1}]	2441	pick-up	0	9
98801	2020-07-18 14:27:26	2020-07-18	8	[{"id_menu":5,"count":1}]	27546	delivery	5	13
98802	2020-07-18 14:27:36	2020-07-18	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	15776	delivery	5	26
98803	2020-07-18 14:30:15	2020-07-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9599	delivery	5	23
98804	2020-07-18 14:32:04	2020-07-18	12	[{"id_menu":3,"count":1}]	13669	delivery	5	17
98805	2020-07-18 14:34:36	2020-07-18	9	[{"id_menu":6,"count":1}]	11006	delivery	5	14
98806	2020-07-18 14:35:02	2020-07-18	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	743	pick-up	0	21
98807	2020-07-18 14:36:29	2020-07-18	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	38218	delivery	5	27
98808	2020-07-18 14:38:45	2020-07-18	12	[{"id_menu":1,"count":1}]	38207	delivery	5	17
98809	2020-07-18 14:39:34	2020-07-18	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	21386	pick-up	0	29
98810	2020-07-18 14:40:57	2020-07-18	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4943	pick-up	0	52
98811	2020-07-18 14:46:06	2020-07-18	12	[{"id_menu":1,"count":1}]	17404	delivery	5	17
98812	2020-07-18 14:47:33	2020-07-18	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	27990	delivery	5	26
98813	2020-07-18 14:48:41	2020-07-18	12	[{"id_menu":3,"count":1}]	3002	pick-up	0	12
98814	2020-07-18 14:50:01	2020-07-18	17	[{"id_menu":4,"count":1}]	38319	delivery	5	22
98815	2020-07-18 14:55:06	2020-07-18	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	38161	delivery	5	45
98816	2020-07-18 14:55:52	2020-07-18	14	[{"id_menu":2,"count":1}]	2615	pick-up	0	14
98817	2020-07-18 14:57:52	2020-07-18	9	[{"id_menu":6,"count":1}]	23601	delivery	5	14
98818	2020-07-18 14:57:52	2020-07-18	9	[{"id_menu":7,"count":1}]	38182	delivery	5	14
98819	2020-07-18 14:59:10	2020-07-18	9	[{"id_menu":7,"count":1}]	14429	delivery	5	14
98820	2020-07-18 15:02:03	2020-07-18	9	[{"id_menu":7,"count":1}]	1282	pick-up	0	9
98821	2020-07-18 15:04:46	2020-07-18	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	38309	delivery	5	36
98822	2020-07-18 15:05:36	2020-07-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	26951	delivery	5	22
98823	2020-07-18 15:07:54	2020-07-18	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38216	delivery	5	52
98824	2020-07-18 15:13:03	2020-07-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5858	delivery	5	28
98825	2020-07-18 15:14:12	2020-07-18	9	[{"id_menu":6,"count":1}]	23023	delivery	5	14
98826	2020-07-18 15:16:21	2020-07-18	9	[{"id_menu":6,"count":1}]	34336	delivery	5	14
98827	2020-07-18 15:19:38	2020-07-18	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	38275	delivery	5	30
98828	2020-07-18 15:23:58	2020-07-18	12	[{"id_menu":3,"count":1}]	35411	delivery	5	17
98829	2020-07-18 15:25:40	2020-07-18	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	38335	delivery	5	26
98830	2020-07-18 15:25:58	2020-07-18	12	[{"id_menu":1,"count":1}]	38268	pick-up	0	12
98831	2020-07-18 15:27:12	2020-07-18	9	[{"id_menu":6,"count":1}]	26409	delivery	5	14
98832	2020-07-18 15:27:58	2020-07-18	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	9088	delivery	5	26
98833	2020-07-18 15:28:04	2020-07-18	14	[{"id_menu":2,"count":1}]	38327	delivery	5	19
98834	2020-07-18 15:36:52	2020-07-18	17	[{"id_menu":4,"count":1}]	13495	pick-up	0	17
98835	2020-07-18 15:39:47	2020-07-18	12	[{"id_menu":3,"count":1}]	38227	delivery	5	17
98836	2020-07-18 15:42:57	2020-07-18	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	17988	delivery	5	37
98837	2020-07-18 15:43:03	2020-07-18	17	[{"id_menu":4,"count":1}]	1731	delivery	5	22
98838	2020-07-18 15:45:26	2020-07-18	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9865	delivery	5	37
98839	2020-07-18 15:49:35	2020-07-18	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7207	delivery	5	31
98840	2020-07-18 15:51:30	2020-07-18	9	[{"id_menu":6,"count":1}]	29045	delivery	5	14
98841	2020-07-18 15:52:07	2020-07-18	17	[{"id_menu":4,"count":1}]	6101	pick-up	0	17
98842	2020-07-18 15:52:39	2020-07-18	14	[{"id_menu":2,"count":1}]	24041	pick-up	0	14
98843	2020-07-18 15:52:55	2020-07-18	8	[{"id_menu":5,"count":1}]	16271	delivery	5	13
98844	2020-07-18 15:57:57	2020-07-18	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8358	pick-up	0	29
98845	2020-07-18 15:59:16	2020-07-18	17	[{"id_menu":4,"count":1}]	26603	pick-up	0	17
98846	2020-07-18 15:59:40	2020-07-18	12	[{"id_menu":1,"count":1}]	31929	pick-up	0	12
98847	2020-07-18 16:02:01	2020-07-18	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	19052	pick-up	0	31
98848	2020-07-18 16:02:11	2020-07-18	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	38228	delivery	5	22
98849	2020-07-18 16:05:13	2020-07-18	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	669	pick-up	0	26
98850	2020-07-18 16:09:35	2020-07-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33974	delivery	5	23
98851	2020-07-18 16:09:57	2020-07-18	9	[{"id_menu":6,"count":1}]	7766	delivery	5	14
98852	2020-07-18 16:12:29	2020-07-18	14	[{"id_menu":2,"count":1}]	15720	pick-up	0	14
98853	2020-07-18 16:16:39	2020-07-18	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	38210	delivery	5	40
98854	2020-07-18 16:19:39	2020-07-18	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37612	delivery	5	37
98855	2020-07-18 16:21:24	2020-07-18	12	[{"id_menu":3,"count":1}]	9019	pick-up	0	12
98856	2020-07-18 16:21:35	2020-07-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	21257	delivery	5	28
98857	2020-07-18 16:25:13	2020-07-18	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	38184	delivery	5	30
98858	2020-07-18 16:27:31	2020-07-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1937	delivery	5	28
98859	2020-07-18 16:29:39	2020-07-18	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	21685	delivery	5	27
98860	2020-07-18 16:31:19	2020-07-18	14	[{"id_menu":2,"count":1}]	5633	delivery	5	19
98861	2020-07-18 16:32:59	2020-07-18	17	[{"id_menu":4,"count":1}]	31666	pick-up	0	17
98862	2020-07-18 16:33:41	2020-07-18	9	[{"id_menu":6,"count":1}]	38246	delivery	5	14
98863	2020-07-18 16:35:35	2020-07-18	14	[{"id_menu":2,"count":1}]	19382	delivery	5	19
98864	2020-07-18 16:36:18	2020-07-18	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":2}]	17045	delivery	5	31
98865	2020-07-18 16:36:38	2020-07-18	12	[{"id_menu":1,"count":1}]	32144	delivery	5	17
98866	2020-07-18 16:37:43	2020-07-18	9	[{"id_menu":7,"count":1}]	21078	delivery	5	14
98867	2020-07-18 16:38:07	2020-07-18	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2931	delivery	5	35
98868	2020-07-18 16:40:16	2020-07-18	9	[{"id_menu":6,"count":1}]	21009	delivery	5	14
98869	2020-07-18 16:44:52	2020-07-18	8	[{"id_menu":5,"count":1}]	359	pick-up	0	8
98870	2020-07-18 16:46:15	2020-07-18	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10661	delivery	5	35
98871	2020-07-18 16:48:33	2020-07-18	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7292	delivery	5	48
98872	2020-07-18 16:49:08	2020-07-18	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	13061	delivery	5	40
98873	2020-07-18 16:49:16	2020-07-18	12	[{"id_menu":1,"count":1}]	15394	delivery	5	17
98874	2020-07-18 16:51:20	2020-07-18	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	1988	pick-up	0	21
98875	2020-07-18 16:52:32	2020-07-18	9	[{"id_menu":7,"count":1}]	33731	delivery	5	14
98876	2020-07-18 16:55:21	2020-07-18	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	20211	delivery	5	31
98877	2020-07-18 16:59:02	2020-07-18	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":3}]	37446	delivery	5	26
98878	2020-07-18 16:59:43	2020-07-18	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":3}]	8286	pick-up	0	26
98879	2020-07-18 17:01:11	2020-07-18	14	[{"id_menu":2,"count":1}]	38234	delivery	5	19
98880	2020-07-18 17:01:23	2020-07-18	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	24100	delivery	5	43
98881	2020-07-18 17:01:47	2020-07-18	9	[{"id_menu":7,"count":1}]	19504	pick-up	0	9
98882	2020-07-18 17:02:05	2020-07-18	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	18096	delivery	5	31
98883	2020-07-18 17:02:23	2020-07-18	9	[{"id_menu":7,"count":1}]	15865	delivery	5	14
98884	2020-07-18 17:05:58	2020-07-18	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	21267	delivery	5	43
98885	2020-07-18 17:07:53	2020-07-18	9	[{"id_menu":6,"count":1}]	38304	pick-up	0	9
98886	2020-07-18 17:12:51	2020-07-18	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	22259	delivery	5	26
98887	2020-07-18 17:14:49	2020-07-18	8	[{"id_menu":5,"count":1}]	28009	pick-up	0	8
98888	2020-07-18 17:15:19	2020-07-18	9	[{"id_menu":6,"count":1}]	38235	delivery	5	14
98889	2020-07-18 17:16:44	2020-07-18	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	28053	delivery	5	35
98890	2020-07-18 17:20:45	2020-07-18	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	33997	delivery	5	51
98891	2020-07-18 17:23:55	2020-07-18	12	[{"id_menu":3,"count":1}]	8347	pick-up	0	12
98892	2020-07-18 17:26:34	2020-07-18	9	[{"id_menu":6,"count":1}]	35499	delivery	5	14
98893	2020-07-18 17:34:05	2020-07-18	17	[{"id_menu":4,"count":1}]	34710	pick-up	0	17
98894	2020-07-18 17:38:51	2020-07-18	9	[{"id_menu":6,"count":1}]	7973	delivery	5	14
98895	2020-07-18 17:39:10	2020-07-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	33211	delivery	5	23
98896	2020-07-18 17:40:31	2020-07-18	9	[{"id_menu":7,"count":1}]	30083	delivery	5	14
98897	2020-07-18 17:42:10	2020-07-18	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":2}]	21461	delivery	5	22
98898	2020-07-18 17:45:32	2020-07-18	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23551	delivery	5	31
98899	2020-07-18 17:50:42	2020-07-18	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16541	delivery	5	22
98900	2020-07-18 17:51:45	2020-07-18	9	[{"id_menu":7,"count":1}]	38302	delivery	5	14
98901	2020-07-18 17:52:39	2020-07-18	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	38143	delivery	5	52
98902	2020-07-18 17:54:13	2020-07-18	12	[{"id_menu":1,"count":1}]	38224	delivery	5	17
98903	2020-07-18 17:55:07	2020-07-18	17	[{"id_menu":4,"count":1}]	5729	pick-up	0	17
98904	2020-07-18 17:56:48	2020-07-18	12	[{"id_menu":3,"count":1}]	11857	delivery	5	17
98905	2020-07-18 17:57:14	2020-07-18	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38130	delivery	5	31
98906	2020-07-18 17:57:19	2020-07-18	17	[{"id_menu":4,"count":1}]	38259	delivery	5	22
98907	2020-07-18 17:57:49	2020-07-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23253	pick-up	0	17
98908	2020-07-18 18:02:11	2020-07-18	9	[{"id_menu":7,"count":1}]	9774	delivery	5	14
98909	2020-07-18 18:02:39	2020-07-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	19312	delivery	5	28
98910	2020-07-18 18:06:22	2020-07-18	9	[{"id_menu":6,"count":1}]	1053	pick-up	0	9
98911	2020-07-18 18:09:44	2020-07-18	8	[{"id_menu":5,"count":1}]	35287	delivery	5	13
98912	2020-07-18 18:10:13	2020-07-18	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	37761	delivery	5	26
98913	2020-07-18 18:12:00	2020-07-18	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	23378	delivery	5	44
98914	2020-07-18 18:12:10	2020-07-18	14	[{"id_menu":2,"count":1}]	13400	pick-up	0	14
98915	2020-07-18 18:13:02	2020-07-18	17	[{"id_menu":4,"count":1}]	38250	delivery	5	22
98916	2020-07-18 18:13:18	2020-07-18	9	[{"id_menu":6,"count":1}]	6883	delivery	5	14
98917	2020-07-18 18:14:28	2020-07-18	9	[{"id_menu":6,"count":1}]	6715	pick-up	0	9
98918	2020-07-18 18:14:56	2020-07-18	17	[{"id_menu":4,"count":1}]	24656	delivery	5	22
98919	2020-07-18 18:16:10	2020-07-18	12	[{"id_menu":3,"count":1}]	28965	delivery	5	17
98920	2020-07-18 18:19:57	2020-07-18	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	6948	pick-up	0	35
98921	2020-07-18 18:23:41	2020-07-18	9	[{"id_menu":6,"count":1}]	16787	delivery	5	14
98922	2020-07-18 18:24:39	2020-07-18	9	[{"id_menu":7,"count":1}]	38257	delivery	5	14
98923	2020-07-18 18:27:25	2020-07-18	8	[{"id_menu":5,"count":1}]	38272	delivery	5	13
98924	2020-07-18 18:31:46	2020-07-18	8	[{"id_menu":5,"count":2}]	38175	delivery	5	13
98925	2020-07-18 18:32:21	2020-07-18	9	[{"id_menu":7,"count":1}]	27233	delivery	5	14
98926	2020-07-18 18:34:25	2020-07-18	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	38232	delivery	5	39
98927	2020-07-18 18:39:42	2020-07-18	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	30609	delivery	5	26
98928	2020-07-18 18:40:08	2020-07-18	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	38209	delivery	5	26
98929	2020-07-18 18:42:15	2020-07-18	9	[{"id_menu":6,"count":1}]	2237	delivery	5	14
98930	2020-07-18 18:43:09	2020-07-18	8	[{"id_menu":5,"count":1}]	29688	delivery	5	13
98931	2020-07-18 18:44:02	2020-07-18	12	[{"id_menu":3,"count":1}]	38337	delivery	5	17
98932	2020-07-18 18:47:43	2020-07-18	12	[{"id_menu":1,"count":1}]	382	delivery	5	17
98933	2020-07-18 18:49:23	2020-07-18	17	[{"id_menu":4,"count":1}]	38239	delivery	5	22
98934	2020-07-18 18:49:43	2020-07-18	14	[{"id_menu":2,"count":1}]	38120	pick-up	0	14
98935	2020-07-18 18:50:24	2020-07-18	9	[{"id_menu":7,"count":1}]	33652	delivery	5	14
98936	2020-07-18 18:50:30	2020-07-18	12	[{"id_menu":3,"count":1}]	30093	pick-up	0	12
98937	2020-07-18 18:52:55	2020-07-18	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10495	delivery	5	44
98938	2020-07-18 18:57:55	2020-07-18	8	[{"id_menu":5,"count":1}]	6957	pick-up	0	8
98939	2020-07-18 18:59:15	2020-07-18	8	[{"id_menu":5,"count":1}]	38208	delivery	5	13
98940	2020-07-18 19:00:02	2020-07-18	12	[{"id_menu":3,"count":1}]	6772	delivery	5	17
98941	2020-07-18 19:00:29	2020-07-18	9	[{"id_menu":7,"count":1}]	6499	delivery	5	14
98942	2020-07-18 19:00:29	2020-07-18	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	14057	delivery	5	36
98943	2020-07-18 19:00:52	2020-07-18	14	[{"id_menu":2,"count":1}]	1296	pick-up	0	14
98944	2020-07-18 19:05:40	2020-07-18	12	[{"id_menu":1,"count":1}]	5325	delivery	5	17
98945	2020-07-18 19:06:27	2020-07-18	12	[{"id_menu":3,"count":1}]	38289	delivery	5	17
98946	2020-07-18 19:07:00	2020-07-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28320	delivery	5	23
98947	2020-07-18 19:08:41	2020-07-18	14	[{"id_menu":2,"count":1}]	14906	delivery	5	19
98948	2020-07-18 19:08:45	2020-07-18	8	[{"id_menu":5,"count":1}]	38333	delivery	5	13
98949	2020-07-18 19:10:34	2020-07-18	17	[{"id_menu":4,"count":2}]	8191	delivery	5	22
98950	2020-07-18 19:16:55	2020-07-18	8	[{"id_menu":5,"count":1}]	25549	delivery	5	13
98951	2020-07-18 19:18:10	2020-07-18	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	5597	delivery	5	28
98952	2020-07-18 19:20:13	2020-07-18	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29689	delivery	5	45
98953	2020-07-18 19:24:20	2020-07-18	9	[{"id_menu":6,"count":1}]	18335	delivery	5	14
98954	2020-07-18 19:26:48	2020-07-18	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	38231	delivery	5	42
98955	2020-07-18 19:28:18	2020-07-18	12	[{"id_menu":3,"count":1}]	14732	delivery	5	17
98956	2020-07-18 19:30:34	2020-07-18	9	[{"id_menu":6,"count":1}]	2216	pick-up	0	9
98957	2020-07-18 19:35:15	2020-07-18	9	[{"id_menu":7,"count":1}]	38119	delivery	5	14
98958	2020-07-18 19:35:34	2020-07-18	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	38295	delivery	5	36
98959	2020-07-18 19:36:26	2020-07-18	14	[{"id_menu":2,"count":1}]	36357	pick-up	0	14
98960	2020-07-18 19:36:49	2020-07-18	9	[{"id_menu":6,"count":1}]	31571	pick-up	0	9
98961	2020-07-18 19:38:19	2020-07-18	9	[{"id_menu":6,"count":1}]	31120	delivery	5	14
98962	2020-07-18 19:38:40	2020-07-18	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	32792	delivery	5	36
98963	2020-07-18 19:39:23	2020-07-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	38307	delivery	5	28
98964	2020-07-18 19:42:12	2020-07-18	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	38323	delivery	5	45
98965	2020-07-18 19:43:42	2020-07-18	17	[{"id_menu":4,"count":1}]	32437	delivery	5	22
98966	2020-07-18 19:44:40	2020-07-18	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2310	delivery	5	31
98967	2020-07-18 19:44:42	2020-07-18	9	[{"id_menu":7,"count":1}]	23166	delivery	5	14
98968	2020-07-18 19:46:50	2020-07-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	33716	delivery	5	22
98969	2020-07-18 19:50:49	2020-07-18	17	[{"id_menu":4,"count":1}]	21243	delivery	5	22
98970	2020-07-18 19:51:51	2020-07-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	17138	pick-up	0	23
98971	2020-07-18 19:54:10	2020-07-18	9	[{"id_menu":6,"count":2}]	38188	delivery	5	14
98972	2020-07-18 19:55:47	2020-07-18	12	[{"id_menu":3,"count":1}]	20493	pick-up	0	12
98973	2020-07-18 19:55:50	2020-07-18	14	[{"id_menu":2,"count":1}]	31113	delivery	5	19
98974	2020-07-18 19:56:28	2020-07-18	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34003	delivery	5	49
98975	2020-07-18 19:57:10	2020-07-18	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	31743	delivery	5	48
98976	2020-07-18 19:58:17	2020-07-18	9	[{"id_menu":6,"count":1}]	6633	delivery	5	14
98977	2020-07-18 19:59:02	2020-07-18	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	27051	delivery	5	45
98978	2020-07-18 19:59:55	2020-07-18	17	[{"id_menu":4,"count":1}]	5066	delivery	5	22
98979	2020-07-18 20:06:26	2020-07-18	8	[{"id_menu":5,"count":1}]	38183	delivery	5	13
98980	2020-07-18 20:06:40	2020-07-18	9	[{"id_menu":6,"count":1}]	310	pick-up	0	9
98981	2020-07-18 20:07:53	2020-07-18	12	[{"id_menu":3,"count":1}]	12718	pick-up	0	12
98982	2020-07-18 20:10:59	2020-07-18	9	[{"id_menu":7,"count":1}]	38264	pick-up	0	9
98983	2020-07-18 20:14:48	2020-07-18	17	[{"id_menu":4,"count":1}]	7006	delivery	5	22
98984	2020-07-18 20:15:01	2020-07-18	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	22476	pick-up	0	21
98985	2020-07-18 20:16:41	2020-07-18	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	35335	pick-up	0	31
98986	2020-07-18 20:18:04	2020-07-18	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3765	pick-up	0	25
98987	2020-07-18 20:19:49	2020-07-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	38318	delivery	5	22
98988	2020-07-18 20:19:55	2020-07-18	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	7764	delivery	5	27
98989	2020-07-18 20:29:12	2020-07-18	12	[{"id_menu":3,"count":1}]	1554	pick-up	0	12
98990	2020-07-18 20:40:20	2020-07-18	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":2}]	5758	delivery	5	29
98991	2020-07-18 20:41:02	2020-07-18	8	[{"id_menu":5,"count":1}]	19596	delivery	5	13
98992	2020-07-18 20:42:45	2020-07-18	12	[{"id_menu":1,"count":1}]	33683	delivery	5	17
98993	2020-07-18 20:43:07	2020-07-18	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	29754	delivery	5	23
98994	2020-07-18 20:44:02	2020-07-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38260	delivery	5	23
98995	2020-07-18 20:52:34	2020-07-18	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	32268	pick-up	0	20
98996	2020-07-18 20:54:39	2020-07-18	8	[{"id_menu":5,"count":1}]	38294	delivery	5	13
98997	2020-07-18 20:59:23	2020-07-18	9	[{"id_menu":7,"count":1}]	14649	delivery	5	14
98998	2020-07-18 21:04:33	2020-07-18	17	[{"id_menu":4,"count":1}]	18612	delivery	5	22
98999	2020-07-18 21:06:01	2020-07-18	12	[{"id_menu":3,"count":1}]	32735	delivery	5	17
99000	2020-07-18 21:06:37	2020-07-18	12	[{"id_menu":1,"count":1}]	5255	pick-up	0	12
99001	2020-07-18 21:07:58	2020-07-18	17	[{"id_menu":4,"count":1}]	38226	delivery	5	22
99002	2020-07-18 21:09:30	2020-07-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	20138	delivery	5	28
99003	2020-07-18 21:13:49	2020-07-18	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	26021	delivery	5	26
99004	2020-07-18 21:13:50	2020-07-18	9	[{"id_menu":6,"count":1}]	32122	delivery	5	14
99005	2020-07-18 21:14:47	2020-07-18	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	16426	delivery	5	31
99006	2020-07-18 21:15:01	2020-07-18	9	[{"id_menu":6,"count":1}]	34959	delivery	5	14
99007	2020-07-18 21:18:45	2020-07-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2432	delivery	5	28
99008	2020-07-18 21:19:44	2020-07-18	14	[{"id_menu":2,"count":2}]	24409	delivery	5	19
99009	2020-07-18 21:20:25	2020-07-18	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	27545	delivery	5	26
99010	2020-07-18 21:21:12	2020-07-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3444	delivery	5	22
99011	2020-07-18 21:23:38	2020-07-18	17	[{"id_menu":4,"count":1}]	15675	delivery	5	22
99012	2020-07-18 21:26:34	2020-07-18	14	[{"id_menu":2,"count":2}]	8730	pick-up	0	14
99013	2020-07-18 21:27:03	2020-07-18	12	[{"id_menu":1,"count":1}]	9528	pick-up	0	12
99014	2020-07-18 21:31:12	2020-07-18	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	38165	delivery	5	27
99015	2020-07-18 21:32:02	2020-07-18	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	38191	delivery	5	31
99016	2020-07-18 21:36:11	2020-07-18	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	15456	delivery	5	48
99017	2020-07-18 21:36:39	2020-07-18	9	[{"id_menu":6,"count":1}]	18977	delivery	5	14
99018	2020-07-18 21:38:16	2020-07-18	9	[{"id_menu":7,"count":1}]	35296	delivery	5	14
99019	2020-07-18 21:39:14	2020-07-18	12	[{"id_menu":1,"count":1}]	12268	pick-up	0	12
99020	2020-07-18 21:40:06	2020-07-18	8	[{"id_menu":5,"count":1}]	38297	delivery	5	13
99021	2020-07-18 21:45:29	2020-07-18	9	[{"id_menu":7,"count":1}]	38123	delivery	5	14
99022	2020-07-18 21:47:15	2020-07-18	9	[{"id_menu":6,"count":1}]	24955	pick-up	0	9
99023	2020-07-18 21:49:03	2020-07-18	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	36704	delivery	5	23
99024	2020-07-18 21:55:39	2020-07-18	9	[{"id_menu":7,"count":1}]	30629	delivery	5	14
99025	2020-07-18 21:57:32	2020-07-18	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	33480	pick-up	0	43
99026	2020-07-18 21:59:05	2020-07-18	14	[{"id_menu":2,"count":1}]	28390	delivery	5	19
99027	2020-07-18 21:59:08	2020-07-18	8	[{"id_menu":5,"count":1}]	22629	delivery	5	13
99028	2020-07-18 22:01:28	2020-07-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38173	delivery	5	23
99029	2020-07-18 22:02:31	2020-07-18	12	[{"id_menu":1,"count":1}]	14127	delivery	5	17
99030	2020-07-18 22:04:44	2020-07-18	9	[{"id_menu":6,"count":1}]	25601	delivery	5	14
99031	2020-07-18 22:10:24	2020-07-18	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	22296	pick-up	0	22
99032	2020-07-18 22:11:45	2020-07-18	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	16170	delivery	5	31
99033	2020-07-18 22:13:36	2020-07-18	17	[{"id_menu":4,"count":1}]	38138	delivery	5	22
99034	2020-07-18 22:15:13	2020-07-18	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	38300	delivery	5	40
99035	2020-07-18 22:20:07	2020-07-18	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	38269	delivery	5	45
99036	2020-07-18 22:23:29	2020-07-18	17	[{"id_menu":4,"count":1}]	6729	delivery	5	22
99037	2020-07-18 22:26:38	2020-07-18	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15549	delivery	5	36
99038	2020-07-18 22:28:38	2020-07-18	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	38253	delivery	5	45
99039	2020-07-18 22:28:46	2020-07-18	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	15899	delivery	5	26
99040	2020-07-18 22:30:47	2020-07-18	17	[{"id_menu":4,"count":1}]	38145	delivery	5	22
99041	2020-07-18 22:31:16	2020-07-18	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	38265	delivery	5	26
99042	2020-07-18 22:31:32	2020-07-18	9	[{"id_menu":7,"count":1}]	6217	delivery	5	14
99043	2020-07-18 22:36:53	2020-07-18	9	[{"id_menu":6,"count":1}]	13878	delivery	5	14
99044	2020-07-18 22:42:29	2020-07-18	9	[{"id_menu":6,"count":1}]	28569	delivery	5	14
99045	2020-07-18 22:42:45	2020-07-18	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	581	delivery	5	26
99046	2020-07-18 22:44:47	2020-07-18	9	[{"id_menu":7,"count":1}]	5935	delivery	5	14
99047	2020-07-18 22:46:36	2020-07-18	12	[{"id_menu":1,"count":1}]	4874	delivery	5	17
99048	2020-07-18 22:46:55	2020-07-18	12	[{"id_menu":1,"count":1}]	38339	delivery	5	17
99049	2020-07-18 22:49:26	2020-07-18	9	[{"id_menu":7,"count":1}]	2191	pick-up	0	9
99050	2020-07-18 22:49:37	2020-07-18	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38230	delivery	5	31
99051	2020-07-18 22:51:36	2020-07-18	9	[{"id_menu":6,"count":1}]	38215	delivery	5	14
99052	2020-07-18 22:56:37	2020-07-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	38256	delivery	5	28
99053	2020-07-18 23:01:43	2020-07-18	14	[{"id_menu":2,"count":1}]	7706	pick-up	0	14
99054	2020-07-18 23:02:08	2020-07-18	9	[{"id_menu":6,"count":1}]	28665	delivery	5	14
99055	2020-07-18 23:05:52	2020-07-18	8	[{"id_menu":5,"count":1}]	32750	delivery	5	13
99056	2020-07-18 23:06:25	2020-07-18	14	[{"id_menu":2,"count":1}]	35885	pick-up	0	14
99057	2020-07-18 23:14:52	2020-07-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	38314	delivery	5	22
99058	2020-07-18 23:17:07	2020-07-18	12	[{"id_menu":3,"count":1}]	847	delivery	5	17
99059	2020-07-18 23:18:00	2020-07-18	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	37273	pick-up	0	26
99060	2020-07-18 23:20:27	2020-07-18	8	[{"id_menu":5,"count":1}]	38133	pick-up	0	8
99061	2020-07-18 23:21:39	2020-07-18	12	[{"id_menu":3,"count":1}]	23585	pick-up	0	12
99062	2020-07-18 23:22:03	2020-07-18	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	38331	delivery	5	25
99063	2020-07-18 23:25:58	2020-07-18	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28465	delivery	5	39
99064	2020-07-18 23:33:46	2020-07-18	9	[{"id_menu":6,"count":1}]	20599	delivery	5	14
99065	2020-07-18 23:36:08	2020-07-18	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	38139	delivery	5	31
99066	2020-07-18 23:39:51	2020-07-18	9	[{"id_menu":6,"count":1}]	38196	delivery	5	14
99067	2020-07-18 23:39:52	2020-07-18	9	[{"id_menu":6,"count":1}]	38193	delivery	5	14
99068	2020-07-18 23:41:41	2020-07-18	9	[{"id_menu":6,"count":1}]	38141	delivery	5	14
99069	2020-07-18 23:42:16	2020-07-18	14	[{"id_menu":2,"count":1}]	38236	delivery	5	19
99070	2020-07-18 23:44:24	2020-07-18	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	24251	delivery	5	31
99071	2020-07-18 23:45:27	2020-07-18	14	[{"id_menu":2,"count":1}]	21490	delivery	5	19
99072	2020-07-18 23:47:14	2020-07-18	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	27618	delivery	5	39
99073	2020-07-18 23:49:25	2020-07-18	14	[{"id_menu":2,"count":1}]	38324	delivery	5	19
99074	2020-07-18 23:49:41	2020-07-18	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	8503	delivery	5	25
99075	2020-07-18 23:50:59	2020-07-18	8	[{"id_menu":5,"count":1}]	38281	delivery	5	13
99076	2020-07-18 23:51:29	2020-07-18	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1081	pick-up	0	17
99077	2020-07-18 23:52:33	2020-07-18	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	38317	delivery	5	23
99078	2020-07-18 23:52:47	2020-07-18	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	38245	pick-up	0	35
99079	2020-07-18 23:52:54	2020-07-18	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12662	delivery	5	34
99080	2020-07-18 23:53:08	2020-07-18	9	[{"id_menu":7,"count":1}]	3567	pick-up	0	9
99081	2020-07-18 23:53:35	2020-07-18	9	[{"id_menu":6,"count":1}]	16813	pick-up	0	9
99082	2020-07-18 23:59:00	2020-07-18	17	[{"id_menu":4,"count":1}]	38147	delivery	5	22
99083	2020-07-19 00:02:00	2020-07-19	12	[{"id_menu":1,"count":1}]	13717	delivery	5	17
99084	2020-07-19 00:02:15	2020-07-19	9	[{"id_menu":7,"count":1}]	9797	delivery	5	14
99085	2020-07-19 00:02:27	2020-07-19	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	22830	delivery	5	52
99086	2020-07-19 00:03:41	2020-07-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35411	delivery	5	23
99087	2020-07-19 00:03:59	2020-07-19	12	[{"id_menu":1,"count":1}]	3825	delivery	5	17
99088	2020-07-19 00:04:14	2020-07-19	12	[{"id_menu":1,"count":2}]	3903	delivery	5	17
99089	2020-07-19 00:05:06	2020-07-19	9	[{"id_menu":7,"count":1}]	16307	delivery	5	14
99090	2020-07-19 00:06:14	2020-07-19	9	[{"id_menu":6,"count":1}]	20183	delivery	5	14
99091	2020-07-19 00:07:15	2020-07-19	12	[{"id_menu":3,"count":1}]	4172	pick-up	0	12
99092	2020-07-19 00:08:09	2020-07-19	12	[{"id_menu":3,"count":1}]	30731	delivery	5	17
99093	2020-07-19 00:08:09	2020-07-19	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	34882	pick-up	0	26
99094	2020-07-19 00:09:39	2020-07-19	17	[{"id_menu":4,"count":1}]	3380	pick-up	0	17
99095	2020-07-19 00:10:59	2020-07-19	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	38357	delivery	5	37
99096	2020-07-19 00:11:30	2020-07-19	12	[{"id_menu":3,"count":1}]	15752	delivery	5	17
99097	2020-07-19 00:12:06	2020-07-19	14	[{"id_menu":2,"count":1}]	38457	delivery	5	19
99098	2020-07-19 00:12:19	2020-07-19	14	[{"id_menu":2,"count":1}]	25887	pick-up	0	14
99099	2020-07-19 00:14:01	2020-07-19	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	22505	delivery	5	28
99100	2020-07-19 00:14:52	2020-07-19	14	[{"id_menu":2,"count":1}]	38370	pick-up	0	14
99101	2020-07-19 00:15:33	2020-07-19	9	[{"id_menu":6,"count":1}]	24044	delivery	5	14
99102	2020-07-19 00:16:16	2020-07-19	9	[{"id_menu":6,"count":1}]	23047	delivery	5	14
99103	2020-07-19 00:21:05	2020-07-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	38374	delivery	5	22
99104	2020-07-19 00:22:27	2020-07-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	27076	delivery	5	31
99105	2020-07-19 00:24:18	2020-07-19	8	[{"id_menu":5,"count":1}]	7447	delivery	5	13
99106	2020-07-19 00:30:58	2020-07-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1406	pick-up	0	23
99107	2020-07-19 00:31:54	2020-07-19	12	[{"id_menu":1,"count":1}]	3050	delivery	5	17
99108	2020-07-19 00:33:56	2020-07-19	12	[{"id_menu":3,"count":1}]	38513	delivery	5	17
99109	2020-07-19 00:35:53	2020-07-19	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	38383	delivery	5	27
99110	2020-07-19 00:36:24	2020-07-19	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16039	pick-up	0	40
99111	2020-07-19 00:36:33	2020-07-19	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	4400	pick-up	0	29
99112	2020-07-19 00:45:37	2020-07-19	12	[{"id_menu":1,"count":1}]	3877	delivery	5	17
99113	2020-07-19 00:49:39	2020-07-19	9	[{"id_menu":7,"count":1}]	25041	delivery	5	14
99114	2020-07-19 00:51:30	2020-07-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22935	delivery	5	23
99115	2020-07-19 00:52:38	2020-07-19	17	[{"id_menu":4,"count":1}]	33875	delivery	5	22
99116	2020-07-19 01:00:33	2020-07-19	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	575	delivery	5	31
99117	2020-07-19 01:00:41	2020-07-19	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	30099	delivery	5	26
99118	2020-07-19 01:02:54	2020-07-19	8	[{"id_menu":5,"count":1}]	34383	delivery	5	13
99119	2020-07-19 01:04:15	2020-07-19	8	[{"id_menu":5,"count":1}]	7096	pick-up	0	8
99120	2020-07-19 01:04:38	2020-07-19	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	11428	delivery	5	39
99121	2020-07-19 01:10:36	2020-07-19	8	[{"id_menu":5,"count":1}]	38438	delivery	5	13
99122	2020-07-19 01:11:27	2020-07-19	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	25839	delivery	5	25
99123	2020-07-19 01:13:24	2020-07-19	12	[{"id_menu":1,"count":1}]	8787	delivery	5	17
99124	2020-07-19 01:14:54	2020-07-19	12	[{"id_menu":1,"count":1}]	18643	pick-up	0	12
99125	2020-07-19 01:16:50	2020-07-19	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29254	delivery	5	35
99126	2020-07-19 01:17:39	2020-07-19	8	[{"id_menu":5,"count":1}]	34976	delivery	5	13
99127	2020-07-19 01:18:40	2020-07-19	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	38541	delivery	5	39
99128	2020-07-19 01:18:45	2020-07-19	17	[{"id_menu":4,"count":1}]	20780	pick-up	0	17
99129	2020-07-19 01:22:35	2020-07-19	17	[{"id_menu":4,"count":1}]	19566	delivery	5	22
99130	2020-07-19 01:22:51	2020-07-19	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	38497	delivery	5	29
99131	2020-07-19 01:27:16	2020-07-19	9	[{"id_menu":7,"count":1}]	28255	delivery	5	14
99132	2020-07-19 01:29:08	2020-07-19	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	20789	delivery	5	43
99133	2020-07-19 01:29:40	2020-07-19	12	[{"id_menu":1,"count":1}]	1244	delivery	5	17
99134	2020-07-19 01:31:24	2020-07-19	12	[{"id_menu":1,"count":1}]	21479	delivery	5	17
99135	2020-07-19 01:31:38	2020-07-19	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34544	delivery	5	37
99136	2020-07-19 01:32:03	2020-07-19	8	[{"id_menu":5,"count":1}]	7796	delivery	5	13
99137	2020-07-19 01:33:03	2020-07-19	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	30117	delivery	5	38
99138	2020-07-19 01:35:24	2020-07-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	36316	delivery	5	22
99139	2020-07-19 01:35:37	2020-07-19	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	26273	delivery	5	26
99140	2020-07-19 01:35:49	2020-07-19	9	[{"id_menu":7,"count":1}]	36330	delivery	5	14
99141	2020-07-19 01:36:48	2020-07-19	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	38459	delivery	5	43
99142	2020-07-19 01:40:38	2020-07-19	12	[{"id_menu":3,"count":1}]	20782	pick-up	0	12
99143	2020-07-19 01:41:45	2020-07-19	9	[{"id_menu":6,"count":1}]	4818	delivery	5	14
99144	2020-07-19 01:45:18	2020-07-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	38548	delivery	5	28
99145	2020-07-19 01:47:07	2020-07-19	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	30777	pick-up	0	20
99146	2020-07-19 01:49:20	2020-07-19	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	38501	delivery	5	38
99147	2020-07-19 01:49:52	2020-07-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	21979	delivery	5	22
99148	2020-07-19 01:50:17	2020-07-19	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1582	pick-up	0	35
99149	2020-07-19 01:50:26	2020-07-19	12	[{"id_menu":1,"count":1}]	4747	pick-up	0	12
99150	2020-07-19 01:51:44	2020-07-19	17	[{"id_menu":4,"count":1}]	15090	pick-up	0	17
99151	2020-07-19 01:52:12	2020-07-19	17	[{"id_menu":4,"count":1}]	27583	delivery	5	22
99152	2020-07-19 01:53:33	2020-07-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	38358	delivery	5	22
99153	2020-07-19 02:00:19	2020-07-19	12	[{"id_menu":1,"count":2}]	10330	pick-up	0	12
99154	2020-07-19 02:03:37	2020-07-19	9	[{"id_menu":7,"count":1}]	6825	pick-up	0	9
99155	2020-07-19 02:03:44	2020-07-19	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	38351	delivery	5	48
99156	2020-07-19 02:06:15	2020-07-19	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	36888	delivery	5	36
99157	2020-07-19 02:06:24	2020-07-19	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	29483	delivery	5	30
99158	2020-07-19 02:06:41	2020-07-19	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	7253	delivery	5	27
99159	2020-07-19 02:06:53	2020-07-19	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	30935	delivery	5	26
99160	2020-07-19 02:07:23	2020-07-19	9	[{"id_menu":7,"count":1}]	4021	delivery	5	14
99161	2020-07-19 02:11:49	2020-07-19	9	[{"id_menu":7,"count":1}]	27862	pick-up	0	9
99162	2020-07-19 02:11:53	2020-07-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24397	delivery	5	22
99163	2020-07-19 02:13:04	2020-07-19	12	[{"id_menu":3,"count":1}]	17241	delivery	5	17
99164	2020-07-19 02:13:49	2020-07-19	12	[{"id_menu":3,"count":1}]	25189	delivery	5	17
99165	2020-07-19 02:16:51	2020-07-19	17	[{"id_menu":4,"count":1}]	9684	delivery	5	22
99166	2020-07-19 02:19:46	2020-07-19	9	[{"id_menu":6,"count":1}]	31369	pick-up	0	9
99167	2020-07-19 02:20:43	2020-07-19	14	[{"id_menu":2,"count":1}]	21109	pick-up	0	14
99168	2020-07-19 02:21:12	2020-07-19	8	[{"id_menu":5,"count":1}]	26557	delivery	5	13
99169	2020-07-19 02:23:20	2020-07-19	9	[{"id_menu":7,"count":1}]	4837	delivery	5	14
99170	2020-07-19 02:24:25	2020-07-19	14	[{"id_menu":2,"count":1}]	15769	pick-up	0	14
99171	2020-07-19 02:26:17	2020-07-19	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	38545	delivery	5	25
99172	2020-07-19 02:29:10	2020-07-19	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":3}]	38539	delivery	5	25
99173	2020-07-19 02:30:41	2020-07-19	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16627	delivery	5	45
99174	2020-07-19 02:31:26	2020-07-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	9836	delivery	5	28
99175	2020-07-19 02:33:08	2020-07-19	12	[{"id_menu":3,"count":1}]	31226	pick-up	0	12
99176	2020-07-19 02:38:14	2020-07-19	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	23794	delivery	5	38
99177	2020-07-19 02:40:52	2020-07-19	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	32604	delivery	5	26
99178	2020-07-19 02:42:10	2020-07-19	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	18826	delivery	5	26
99179	2020-07-19 02:42:44	2020-07-19	12	[{"id_menu":3,"count":1}]	26934	delivery	5	17
99180	2020-07-19 02:49:48	2020-07-19	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	33531	delivery	5	26
99181	2020-07-19 02:58:13	2020-07-19	9	[{"id_menu":6,"count":1}]	38476	delivery	5	14
99182	2020-07-19 02:58:58	2020-07-19	12	[{"id_menu":1,"count":1}]	2715	pick-up	0	12
99183	2020-07-19 03:01:17	2020-07-19	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	38463	delivery	5	31
99184	2020-07-19 03:03:09	2020-07-19	12	[{"id_menu":3,"count":1}]	3372	pick-up	0	12
99185	2020-07-19 03:05:23	2020-07-19	9	[{"id_menu":6,"count":1}]	1896	pick-up	0	9
99186	2020-07-19 03:06:29	2020-07-19	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	27686	delivery	5	57
99187	2020-07-19 03:06:34	2020-07-19	9	[{"id_menu":7,"count":1}]	6080	delivery	5	14
99188	2020-07-19 03:07:05	2020-07-19	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	33979	delivery	5	31
99189	2020-07-19 03:12:22	2020-07-19	9	[{"id_menu":7,"count":1}]	38386	pick-up	0	9
99190	2020-07-19 03:13:05	2020-07-19	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27556	delivery	5	51
99191	2020-07-19 03:13:13	2020-07-19	17	[{"id_menu":4,"count":1}]	2143	pick-up	0	17
99192	2020-07-19 03:13:18	2020-07-19	12	[{"id_menu":3,"count":1}]	18733	pick-up	0	12
99193	2020-07-19 03:13:59	2020-07-19	8	[{"id_menu":5,"count":1}]	13057	pick-up	0	8
99194	2020-07-19 03:15:04	2020-07-19	9	[{"id_menu":7,"count":1}]	25626	delivery	5	14
99195	2020-07-19 03:15:06	2020-07-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	29983	delivery	5	28
99196	2020-07-19 03:15:35	2020-07-19	9	[{"id_menu":7,"count":1}]	16308	pick-up	0	9
99197	2020-07-19 03:17:24	2020-07-19	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	11787	delivery	5	26
99198	2020-07-19 03:18:09	2020-07-19	12	[{"id_menu":3,"count":1}]	36342	delivery	5	17
99199	2020-07-19 03:21:30	2020-07-19	12	[{"id_menu":1,"count":1}]	38486	delivery	5	17
99200	2020-07-19 03:21:44	2020-07-19	17	[{"id_menu":4,"count":1}]	29231	pick-up	0	17
99201	2020-07-19 03:21:53	2020-07-19	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14222	delivery	5	31
99202	2020-07-19 03:22:50	2020-07-19	9	[{"id_menu":6,"count":1}]	31819	delivery	5	14
99203	2020-07-19 03:23:42	2020-07-19	12	[{"id_menu":3,"count":1}]	5224	pick-up	0	12
99204	2020-07-19 03:24:10	2020-07-19	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	11488	delivery	5	26
99205	2020-07-19 03:25:16	2020-07-19	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	17579	delivery	5	30
99206	2020-07-19 03:25:28	2020-07-19	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":2}]	18894	delivery	5	22
99207	2020-07-19 03:26:25	2020-07-19	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	8628	delivery	5	26
99208	2020-07-19 03:29:03	2020-07-19	9	[{"id_menu":6,"count":1}]	1241	pick-up	0	9
99209	2020-07-19 03:30:00	2020-07-19	14	[{"id_menu":2,"count":1}]	38375	delivery	5	19
99210	2020-07-19 03:32:00	2020-07-19	12	[{"id_menu":3,"count":1}]	28361	pick-up	0	12
99211	2020-07-19 03:33:36	2020-07-19	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	38427	delivery	5	40
99212	2020-07-19 03:37:31	2020-07-19	9	[{"id_menu":7,"count":1}]	19362	delivery	5	14
99213	2020-07-19 03:37:39	2020-07-19	17	[{"id_menu":4,"count":1}]	24325	delivery	5	22
99214	2020-07-19 03:39:06	2020-07-19	17	[{"id_menu":4,"count":1}]	38536	pick-up	0	17
99215	2020-07-19 03:40:32	2020-07-19	9	[{"id_menu":6,"count":1}]	15194	pick-up	0	9
99216	2020-07-19 03:42:08	2020-07-19	14	[{"id_menu":2,"count":1}]	381	pick-up	0	14
99217	2020-07-19 03:43:52	2020-07-19	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17850	delivery	5	49
99218	2020-07-19 03:48:10	2020-07-19	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	38510	pick-up	0	43
99219	2020-07-19 03:48:46	2020-07-19	9	[{"id_menu":7,"count":1}]	3233	pick-up	0	9
99220	2020-07-19 03:50:52	2020-07-19	14	[{"id_menu":2,"count":1}]	21968	delivery	5	19
99221	2020-07-19 03:52:49	2020-07-19	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	28456	pick-up	0	22
99222	2020-07-19 03:53:15	2020-07-19	9	[{"id_menu":6,"count":1}]	6929	delivery	5	14
99223	2020-07-19 03:54:33	2020-07-19	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	26921	delivery	5	31
99224	2020-07-19 03:57:11	2020-07-19	9	[{"id_menu":6,"count":1}]	38505	delivery	5	14
99225	2020-07-19 03:58:35	2020-07-19	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	38511	delivery	5	43
99226	2020-07-19 04:07:22	2020-07-19	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	38421	delivery	5	31
99227	2020-07-19 04:08:21	2020-07-19	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1322	delivery	5	31
99228	2020-07-19 04:08:39	2020-07-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	20968	delivery	5	22
99229	2020-07-19 04:13:04	2020-07-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27187	pick-up	0	18
99230	2020-07-19 04:13:49	2020-07-19	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	38354	delivery	5	43
99231	2020-07-19 04:15:21	2020-07-19	12	[{"id_menu":3,"count":1}]	520	pick-up	0	12
99232	2020-07-19 04:15:22	2020-07-19	12	[{"id_menu":1,"count":1}]	10612	delivery	5	17
99233	2020-07-19 04:15:31	2020-07-19	14	[{"id_menu":2,"count":2}]	10876	delivery	5	19
99234	2020-07-19 04:15:35	2020-07-19	12	[{"id_menu":1,"count":1}]	35441	delivery	5	17
99235	2020-07-19 04:16:04	2020-07-19	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	806	pick-up	0	26
99236	2020-07-19 04:19:36	2020-07-19	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38435	delivery	5	37
99237	2020-07-19 04:23:22	2020-07-19	9	[{"id_menu":7,"count":1}]	19716	delivery	5	14
99238	2020-07-19 04:23:29	2020-07-19	14	[{"id_menu":2,"count":1}]	2507	delivery	5	19
99239	2020-07-19 04:23:29	2020-07-19	12	[{"id_menu":1,"count":1}]	38514	delivery	5	17
99240	2020-07-19 04:23:53	2020-07-19	9	[{"id_menu":7,"count":3}]	38537	delivery	5	14
99241	2020-07-19 04:25:31	2020-07-19	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1168	pick-up	0	25
99242	2020-07-19 04:25:54	2020-07-19	14	[{"id_menu":2,"count":1}]	29235	delivery	5	19
99243	2020-07-19 04:29:58	2020-07-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7814	pick-up	0	26
99244	2020-07-19 04:30:46	2020-07-19	9	[{"id_menu":6,"count":1}]	26359	delivery	5	14
99245	2020-07-19 04:31:16	2020-07-19	14	[{"id_menu":2,"count":1}]	38559	delivery	5	19
99246	2020-07-19 04:33:21	2020-07-19	8	[{"id_menu":5,"count":1}]	31467	delivery	5	13
99247	2020-07-19 04:33:27	2020-07-19	9	[{"id_menu":7,"count":1}]	17384	delivery	5	14
99248	2020-07-19 04:33:31	2020-07-19	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	19164	delivery	5	26
99249	2020-07-19 04:33:37	2020-07-19	9	[{"id_menu":7,"count":1}]	331	delivery	5	14
99250	2020-07-19 04:33:54	2020-07-19	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	35937	delivery	5	30
99251	2020-07-19 04:36:05	2020-07-19	9	[{"id_menu":6,"count":1}]	37077	pick-up	0	9
99252	2020-07-19 04:36:11	2020-07-19	25	[{"id_menu":4,"count":3},{"id_menu":5,"count":1}]	11572	delivery	5	30
99253	2020-07-19 04:38:45	2020-07-19	9	[{"id_menu":7,"count":1}]	3742	delivery	5	14
99254	2020-07-19 04:38:48	2020-07-19	8	[{"id_menu":5,"count":1}]	612	pick-up	0	8
99255	2020-07-19 04:39:25	2020-07-19	9	[{"id_menu":6,"count":1}]	38372	delivery	5	14
99256	2020-07-19 04:40:31	2020-07-19	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38436	delivery	5	52
99257	2020-07-19 04:41:03	2020-07-19	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	33528	delivery	5	26
99258	2020-07-19 04:41:13	2020-07-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2874	pick-up	0	23
99259	2020-07-19 04:44:03	2020-07-19	17	[{"id_menu":4,"count":1}]	574	pick-up	0	17
99260	2020-07-19 04:44:52	2020-07-19	29	[{"id_menu":3,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	38525	delivery	5	34
99261	2020-07-19 04:45:31	2020-07-19	9	[{"id_menu":6,"count":1}]	38359	delivery	5	14
99262	2020-07-19 04:48:29	2020-07-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	13028	delivery	5	28
99263	2020-07-19 04:48:52	2020-07-19	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	18791	delivery	5	25
99264	2020-07-19 04:50:10	2020-07-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	5350	pick-up	0	31
99265	2020-07-19 04:52:07	2020-07-19	8	[{"id_menu":5,"count":1}]	12895	delivery	5	13
99266	2020-07-19 04:55:31	2020-07-19	12	[{"id_menu":3,"count":1}]	8018	pick-up	0	12
99267	2020-07-19 04:56:17	2020-07-19	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	32999	delivery	5	23
99268	2020-07-19 04:56:50	2020-07-19	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	38406	delivery	5	39
99269	2020-07-19 04:56:57	2020-07-19	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	18860	delivery	5	26
99270	2020-07-19 04:57:18	2020-07-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	440	delivery	5	23
99271	2020-07-19 04:59:13	2020-07-19	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	32828	delivery	5	40
99272	2020-07-19 05:02:36	2020-07-19	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1299	pick-up	0	48
99273	2020-07-19 05:03:53	2020-07-19	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11867	delivery	5	37
99274	2020-07-19 05:07:13	2020-07-19	9	[{"id_menu":6,"count":1}]	13891	delivery	5	14
99275	2020-07-19 05:07:56	2020-07-19	14	[{"id_menu":2,"count":1}]	38398	delivery	5	19
99276	2020-07-19 05:11:23	2020-07-19	12	[{"id_menu":1,"count":1}]	1953	pick-up	0	12
99277	2020-07-19 05:12:37	2020-07-19	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5699	delivery	5	30
99278	2020-07-19 05:13:52	2020-07-19	12	[{"id_menu":3,"count":1}]	21155	pick-up	0	12
99279	2020-07-19 05:15:54	2020-07-19	8	[{"id_menu":5,"count":1}]	193	pick-up	0	8
99280	2020-07-19 05:17:00	2020-07-19	9	[{"id_menu":6,"count":1}]	5383	pick-up	0	9
99281	2020-07-19 05:19:24	2020-07-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16420	delivery	5	22
99282	2020-07-19 05:20:22	2020-07-19	8	[{"id_menu":5,"count":1}]	38502	delivery	5	13
99283	2020-07-19 05:21:42	2020-07-19	8	[{"id_menu":5,"count":1}]	11546	delivery	5	13
99284	2020-07-19 05:22:17	2020-07-19	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	25496	delivery	5	26
99285	2020-07-19 05:23:05	2020-07-19	9	[{"id_menu":6,"count":1}]	18375	delivery	5	14
99286	2020-07-19 05:24:35	2020-07-19	12	[{"id_menu":3,"count":1}]	3597	delivery	5	17
99287	2020-07-19 05:25:15	2020-07-19	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	38475	delivery	5	36
99288	2020-07-19 05:27:35	2020-07-19	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	11676	delivery	5	31
99289	2020-07-19 05:29:35	2020-07-19	9	[{"id_menu":7,"count":1}]	28934	delivery	5	14
99290	2020-07-19 05:29:47	2020-07-19	8	[{"id_menu":5,"count":1}]	38487	delivery	5	13
99291	2020-07-19 05:32:08	2020-07-19	9	[{"id_menu":7,"count":1}]	16147	delivery	5	14
99292	2020-07-19 05:32:26	2020-07-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	38496	delivery	5	31
99293	2020-07-19 05:32:51	2020-07-19	9	[{"id_menu":6,"count":1}]	795	pick-up	0	9
99294	2020-07-19 05:34:54	2020-07-19	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	38426	delivery	5	30
99295	2020-07-19 05:35:33	2020-07-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	33126	pick-up	0	31
99296	2020-07-19 05:39:47	2020-07-19	9	[{"id_menu":6,"count":1}]	38369	delivery	5	14
99297	2020-07-19 05:42:26	2020-07-19	9	[{"id_menu":7,"count":2}]	16144	delivery	5	14
99298	2020-07-19 05:42:52	2020-07-19	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	38439	delivery	5	31
99299	2020-07-19 05:42:57	2020-07-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	38445	delivery	5	28
99300	2020-07-19 05:45:39	2020-07-19	8	[{"id_menu":5,"count":1}]	8300	delivery	5	13
99301	2020-07-19 05:46:03	2020-07-19	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	12735	delivery	5	25
99302	2020-07-19 05:49:33	2020-07-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	36812	delivery	5	23
99303	2020-07-19 05:52:47	2020-07-19	8	[{"id_menu":5,"count":1}]	11004	delivery	5	13
99304	2020-07-19 05:52:54	2020-07-19	14	[{"id_menu":2,"count":1}]	38530	delivery	5	19
99305	2020-07-19 05:55:24	2020-07-19	8	[{"id_menu":5,"count":1}]	29845	delivery	5	13
99306	2020-07-19 05:56:42	2020-07-19	9	[{"id_menu":7,"count":1}]	17533	delivery	5	14
99307	2020-07-19 05:58:27	2020-07-19	8	[{"id_menu":5,"count":1}]	19981	delivery	5	13
99308	2020-07-19 05:58:35	2020-07-19	14	[{"id_menu":2,"count":1}]	7308	delivery	5	19
99309	2020-07-19 06:00:47	2020-07-19	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3636	delivery	5	42
99310	2020-07-19 06:03:11	2020-07-19	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	37355	delivery	5	34
99311	2020-07-19 06:03:51	2020-07-19	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	27060	delivery	5	40
99312	2020-07-19 06:09:42	2020-07-19	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	9365	delivery	5	34
99313	2020-07-19 06:13:03	2020-07-19	9	[{"id_menu":7,"count":1}]	31161	delivery	5	14
99314	2020-07-19 06:14:33	2020-07-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38544	delivery	5	23
99315	2020-07-19 06:14:44	2020-07-19	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38540	delivery	5	54
99316	2020-07-19 06:15:07	2020-07-19	9	[{"id_menu":6,"count":2}]	4139	pick-up	0	9
99317	2020-07-19 06:15:48	2020-07-19	14	[{"id_menu":2,"count":1}]	22116	pick-up	0	14
99318	2020-07-19 06:16:05	2020-07-19	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	37486	delivery	5	23
99319	2020-07-19 06:18:03	2020-07-19	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	38405	delivery	5	45
99320	2020-07-19 06:18:46	2020-07-19	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	34525	delivery	5	31
99321	2020-07-19 06:19:51	2020-07-19	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	38009	delivery	5	40
99322	2020-07-19 06:20:06	2020-07-19	9	[{"id_menu":6,"count":1}]	38391	delivery	5	14
99323	2020-07-19 06:20:24	2020-07-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	1074	delivery	5	28
99324	2020-07-19 06:24:52	2020-07-19	12	[{"id_menu":1,"count":1}]	38356	delivery	5	17
99325	2020-07-19 06:26:02	2020-07-19	17	[{"id_menu":4,"count":1}]	26450	delivery	5	22
99326	2020-07-19 06:26:36	2020-07-19	12	[{"id_menu":3,"count":1}]	27985	delivery	5	17
99327	2020-07-19 06:27:01	2020-07-19	12	[{"id_menu":1,"count":2}]	22290	delivery	5	17
99328	2020-07-19 06:28:03	2020-07-19	14	[{"id_menu":2,"count":1}]	4912	delivery	5	19
99329	2020-07-19 06:28:22	2020-07-19	8	[{"id_menu":5,"count":1}]	15504	delivery	5	13
99330	2020-07-19 06:29:15	2020-07-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16750	delivery	5	23
99331	2020-07-19 06:31:14	2020-07-19	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	12593	pick-up	0	29
99332	2020-07-19 06:33:49	2020-07-19	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	38119	delivery	5	31
99333	2020-07-19 06:36:25	2020-07-19	9	[{"id_menu":7,"count":1}]	32259	delivery	5	14
99334	2020-07-19 06:40:11	2020-07-19	17	[{"id_menu":4,"count":1}]	37439	delivery	5	22
99335	2020-07-19 06:41:08	2020-07-19	17	[{"id_menu":4,"count":1}]	10968	delivery	5	22
99336	2020-07-19 06:43:19	2020-07-19	17	[{"id_menu":4,"count":1}]	25404	delivery	5	22
99337	2020-07-19 06:45:18	2020-07-19	8	[{"id_menu":5,"count":1}]	23911	delivery	5	13
99338	2020-07-19 06:46:30	2020-07-19	8	[{"id_menu":5,"count":1}]	28189	delivery	5	13
99339	2020-07-19 06:47:56	2020-07-19	9	[{"id_menu":6,"count":2}]	38373	delivery	5	14
99340	2020-07-19 06:52:52	2020-07-19	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	4578	pick-up	0	26
99341	2020-07-19 06:56:28	2020-07-19	8	[{"id_menu":5,"count":1}]	38403	delivery	5	13
99342	2020-07-19 06:58:08	2020-07-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	27246	delivery	5	22
99343	2020-07-19 06:59:51	2020-07-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23083	delivery	5	22
99344	2020-07-19 07:00:44	2020-07-19	14	[{"id_menu":2,"count":1}]	20315	delivery	5	19
99345	2020-07-19 07:00:46	2020-07-19	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	9821	delivery	5	22
99346	2020-07-19 07:02:38	2020-07-19	14	[{"id_menu":2,"count":2}]	27001	pick-up	0	14
99347	2020-07-19 07:03:56	2020-07-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	37799	delivery	5	22
99348	2020-07-19 07:05:09	2020-07-19	9	[{"id_menu":6,"count":1}]	32636	delivery	5	14
99349	2020-07-19 07:06:38	2020-07-19	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	17161	delivery	5	34
99350	2020-07-19 07:07:30	2020-07-19	9	[{"id_menu":7,"count":1}]	24755	delivery	5	14
99351	2020-07-19 07:08:13	2020-07-19	17	[{"id_menu":4,"count":1}]	12320	delivery	5	22
99352	2020-07-19 07:09:04	2020-07-19	14	[{"id_menu":2,"count":1}]	25778	delivery	5	19
99353	2020-07-19 07:10:00	2020-07-19	9	[{"id_menu":6,"count":1}]	3558	delivery	5	14
99354	2020-07-19 07:10:18	2020-07-19	8	[{"id_menu":5,"count":1}]	1657	pick-up	0	8
99355	2020-07-19 07:12:46	2020-07-19	8	[{"id_menu":5,"count":1}]	37034	delivery	5	13
99356	2020-07-19 07:15:07	2020-07-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20617	delivery	5	22
99357	2020-07-19 07:15:14	2020-07-19	14	[{"id_menu":2,"count":2}]	5811	pick-up	0	14
99358	2020-07-19 07:16:20	2020-07-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	32054	delivery	5	22
99359	2020-07-19 07:18:57	2020-07-19	14	[{"id_menu":2,"count":1}]	26139	delivery	5	19
99360	2020-07-19 07:19:01	2020-07-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38504	delivery	5	23
99361	2020-07-19 07:20:51	2020-07-19	12	[{"id_menu":3,"count":1}]	38450	delivery	5	17
99362	2020-07-19 07:26:13	2020-07-19	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	18490	pick-up	0	21
99363	2020-07-19 07:27:04	2020-07-19	17	[{"id_menu":4,"count":1}]	38469	delivery	5	22
99364	2020-07-19 07:27:52	2020-07-19	9	[{"id_menu":7,"count":1}]	3901	delivery	5	14
99365	2020-07-19 07:33:53	2020-07-19	8	[{"id_menu":5,"count":1}]	13931	delivery	5	13
99366	2020-07-19 07:35:31	2020-07-19	9	[{"id_menu":6,"count":1}]	29115	delivery	5	14
99367	2020-07-19 07:35:38	2020-07-19	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	16528	delivery	5	27
99368	2020-07-19 07:36:58	2020-07-19	9	[{"id_menu":7,"count":1}]	9312	delivery	5	14
99369	2020-07-19 07:37:25	2020-07-19	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1143	pick-up	0	21
99370	2020-07-19 07:37:25	2020-07-19	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	19031	delivery	5	26
99371	2020-07-19 07:43:07	2020-07-19	17	[{"id_menu":4,"count":1}]	38492	delivery	5	22
99372	2020-07-19 07:43:33	2020-07-19	8	[{"id_menu":5,"count":1}]	13070	delivery	5	13
99373	2020-07-19 07:43:38	2020-07-19	14	[{"id_menu":2,"count":1}]	2574	pick-up	0	14
99374	2020-07-19 07:43:59	2020-07-19	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":2}]	17721	delivery	5	28
99375	2020-07-19 07:47:58	2020-07-19	9	[{"id_menu":6,"count":1}]	38376	delivery	5	14
99376	2020-07-19 07:48:57	2020-07-19	9	[{"id_menu":7,"count":1}]	36887	delivery	5	14
99377	2020-07-19 07:50:44	2020-07-19	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":2}]	14702	delivery	5	31
99378	2020-07-19 07:52:04	2020-07-19	9	[{"id_menu":6,"count":1}]	25069	delivery	5	14
99379	2020-07-19 07:53:42	2020-07-19	9	[{"id_menu":7,"count":2}]	3730	pick-up	0	9
99380	2020-07-19 07:55:42	2020-07-19	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	38479	delivery	5	31
99381	2020-07-19 07:56:26	2020-07-19	9	[{"id_menu":6,"count":2}]	8794	delivery	5	14
99382	2020-07-19 07:57:55	2020-07-19	12	[{"id_menu":3,"count":1}]	26342	delivery	5	17
99383	2020-07-19 07:58:14	2020-07-19	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	9053	pick-up	0	43
99384	2020-07-19 08:00:08	2020-07-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	24336	delivery	5	23
99385	2020-07-19 08:00:29	2020-07-19	9	[{"id_menu":7,"count":1}]	38416	delivery	5	14
99386	2020-07-19 08:05:16	2020-07-19	9	[{"id_menu":7,"count":1}]	38532	delivery	5	14
99387	2020-07-19 08:05:34	2020-07-19	9	[{"id_menu":7,"count":1}]	34508	delivery	5	14
99388	2020-07-19 08:07:52	2020-07-19	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5303	delivery	5	36
99389	2020-07-19 08:07:56	2020-07-19	12	[{"id_menu":1,"count":1}]	6395	delivery	5	17
99390	2020-07-19 08:12:17	2020-07-19	12	[{"id_menu":3,"count":1}]	14792	delivery	5	17
99391	2020-07-19 08:12:25	2020-07-19	8	[{"id_menu":5,"count":1}]	17848	delivery	5	13
99392	2020-07-19 08:14:58	2020-07-19	9	[{"id_menu":6,"count":1}]	38522	delivery	5	14
99393	2020-07-19 08:15:23	2020-07-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	27283	delivery	5	22
99394	2020-07-19 08:16:01	2020-07-19	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	35390	delivery	5	34
99395	2020-07-19 08:19:32	2020-07-19	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19718	delivery	5	34
99396	2020-07-19 08:19:33	2020-07-19	17	[{"id_menu":4,"count":1}]	29225	delivery	5	22
99397	2020-07-19 08:21:45	2020-07-19	8	[{"id_menu":5,"count":1}]	6798	pick-up	0	8
99398	2020-07-19 08:23:17	2020-07-19	14	[{"id_menu":2,"count":1}]	23147	delivery	5	19
99399	2020-07-19 08:27:57	2020-07-19	12	[{"id_menu":3,"count":1}]	36811	delivery	5	17
99400	2020-07-19 08:30:59	2020-07-19	17	[{"id_menu":4,"count":1}]	3393	delivery	5	22
99401	2020-07-19 08:33:55	2020-07-19	9	[{"id_menu":7,"count":1}]	33326	delivery	5	14
99402	2020-07-19 08:35:56	2020-07-19	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	38432	delivery	5	30
99403	2020-07-19 08:36:33	2020-07-19	9	[{"id_menu":7,"count":1}]	29749	delivery	5	14
99404	2020-07-19 08:36:53	2020-07-19	9	[{"id_menu":6,"count":1}]	11237	delivery	5	14
99405	2020-07-19 08:37:08	2020-07-19	9	[{"id_menu":6,"count":1}]	23733	pick-up	0	9
99406	2020-07-19 08:37:37	2020-07-19	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	38562	delivery	5	26
99407	2020-07-19 08:40:11	2020-07-19	17	[{"id_menu":4,"count":1}]	38409	delivery	5	22
99408	2020-07-19 08:41:19	2020-07-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	22797	delivery	5	28
99409	2020-07-19 08:41:55	2020-07-19	12	[{"id_menu":3,"count":1}]	38551	delivery	5	17
99410	2020-07-19 08:44:13	2020-07-19	8	[{"id_menu":5,"count":1}]	28094	delivery	5	13
99411	2020-07-19 08:45:02	2020-07-19	9	[{"id_menu":7,"count":1}]	35587	pick-up	0	9
99412	2020-07-19 08:45:12	2020-07-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5201	delivery	5	23
99413	2020-07-19 08:49:31	2020-07-19	14	[{"id_menu":2,"count":1}]	14972	pick-up	0	14
99414	2020-07-19 08:54:37	2020-07-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1435	pick-up	0	26
99415	2020-07-19 08:55:34	2020-07-19	17	[{"id_menu":4,"count":1}]	7559	delivery	5	22
99416	2020-07-19 08:56:11	2020-07-19	17	[{"id_menu":4,"count":1}]	10555	pick-up	0	17
99417	2020-07-19 08:57:38	2020-07-19	9	[{"id_menu":6,"count":1}]	21774	delivery	5	14
99418	2020-07-19 08:58:56	2020-07-19	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	20792	delivery	5	26
99419	2020-07-19 09:04:24	2020-07-19	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38413	delivery	5	31
99420	2020-07-19 09:04:36	2020-07-19	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	32184	delivery	5	26
99421	2020-07-19 09:05:49	2020-07-19	17	[{"id_menu":4,"count":1}]	38382	pick-up	0	17
99422	2020-07-19 09:07:41	2020-07-19	17	[{"id_menu":4,"count":1}]	17046	pick-up	0	17
99423	2020-07-19 09:10:40	2020-07-19	14	[{"id_menu":2,"count":1}]	38526	delivery	5	19
99424	2020-07-19 09:11:01	2020-07-19	9	[{"id_menu":7,"count":1}]	37531	pick-up	0	9
99425	2020-07-19 09:11:32	2020-07-19	9	[{"id_menu":6,"count":3}]	38490	delivery	5	14
99426	2020-07-19 09:16:34	2020-07-19	12	[{"id_menu":3,"count":1}]	2244	delivery	5	17
99427	2020-07-19 09:17:12	2020-07-19	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	26416	delivery	5	34
99428	2020-07-19 09:18:37	2020-07-19	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18234	delivery	5	43
99429	2020-07-19 09:19:16	2020-07-19	17	[{"id_menu":4,"count":1}]	38524	pick-up	0	17
99430	2020-07-19 09:20:03	2020-07-19	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	7244	delivery	5	34
99431	2020-07-19 09:20:56	2020-07-19	14	[{"id_menu":2,"count":1}]	5701	pick-up	0	14
99432	2020-07-19 09:21:04	2020-07-19	8	[{"id_menu":5,"count":1}]	38412	delivery	5	13
99433	2020-07-19 09:22:49	2020-07-19	9	[{"id_menu":7,"count":2}]	38423	delivery	5	14
99434	2020-07-19 09:23:47	2020-07-19	9	[{"id_menu":7,"count":1}]	29220	delivery	5	14
99435	2020-07-19 09:26:44	2020-07-19	9	[{"id_menu":7,"count":1}]	12664	delivery	5	14
99436	2020-07-19 09:26:51	2020-07-19	9	[{"id_menu":6,"count":2}]	13544	delivery	5	14
99437	2020-07-19 09:31:45	2020-07-19	17	[{"id_menu":4,"count":1}]	38380	delivery	5	22
99438	2020-07-19 09:32:18	2020-07-19	8	[{"id_menu":5,"count":1}]	15097	pick-up	0	8
99439	2020-07-19 09:33:30	2020-07-19	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	38355	delivery	5	36
99440	2020-07-19 09:35:00	2020-07-19	17	[{"id_menu":4,"count":1}]	12870	delivery	5	22
99441	2020-07-19 09:36:31	2020-07-19	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	37456	delivery	5	31
99442	2020-07-19 09:37:44	2020-07-19	9	[{"id_menu":6,"count":1}]	38521	delivery	5	14
99443	2020-07-19 09:37:53	2020-07-19	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	11262	delivery	5	30
99444	2020-07-19 09:37:56	2020-07-19	8	[{"id_menu":5,"count":1}]	203	pick-up	0	8
99445	2020-07-19 09:39:40	2020-07-19	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	16758	delivery	5	30
99446	2020-07-19 09:44:05	2020-07-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	22952	pick-up	0	23
99447	2020-07-19 09:45:45	2020-07-19	14	[{"id_menu":2,"count":1}]	17906	pick-up	0	14
99448	2020-07-19 09:45:58	2020-07-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	34019	delivery	5	28
99449	2020-07-19 09:48:17	2020-07-19	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	16228	pick-up	0	25
99450	2020-07-19 09:48:42	2020-07-19	14	[{"id_menu":2,"count":2}]	18586	delivery	5	19
99451	2020-07-19 09:49:08	2020-07-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	10530	delivery	5	36
99452	2020-07-19 09:49:30	2020-07-19	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	38454	delivery	5	31
99453	2020-07-19 09:54:19	2020-07-19	9	[{"id_menu":6,"count":1}]	38520	delivery	5	14
99454	2020-07-19 09:56:58	2020-07-19	8	[{"id_menu":5,"count":1}]	730	pick-up	0	8
99455	2020-07-19 10:00:21	2020-07-19	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	32455	delivery	5	25
99456	2020-07-19 10:00:28	2020-07-19	9	[{"id_menu":7,"count":2}]	38152	delivery	5	14
99457	2020-07-19 10:05:50	2020-07-19	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3702	delivery	5	34
99458	2020-07-19 10:06:40	2020-07-19	9	[{"id_menu":6,"count":1}]	9217	delivery	5	14
99459	2020-07-19 10:07:58	2020-07-19	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	16152	delivery	5	26
99460	2020-07-19 10:10:00	2020-07-19	9	[{"id_menu":7,"count":1}]	33698	pick-up	0	9
99461	2020-07-19 10:10:16	2020-07-19	8	[{"id_menu":5,"count":1}]	38465	delivery	5	13
99462	2020-07-19 10:12:03	2020-07-19	34	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	38377	delivery	5	39
99463	2020-07-19 10:12:32	2020-07-19	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	32002	pick-up	0	21
99464	2020-07-19 10:12:49	2020-07-19	9	[{"id_menu":6,"count":1}]	28634	pick-up	0	9
99465	2020-07-19 10:13:56	2020-07-19	12	[{"id_menu":1,"count":1}]	5506	delivery	5	17
99466	2020-07-19 10:13:59	2020-07-19	9	[{"id_menu":7,"count":1}]	38449	delivery	5	14
99467	2020-07-19 10:15:37	2020-07-19	12	[{"id_menu":3,"count":1}]	24292	delivery	5	17
99468	2020-07-19 10:17:07	2020-07-19	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	17916	delivery	5	43
99469	2020-07-19 10:18:55	2020-07-19	17	[{"id_menu":4,"count":1}]	13911	pick-up	0	17
99470	2020-07-19 10:19:39	2020-07-19	9	[{"id_menu":6,"count":1}]	38500	delivery	5	14
99471	2020-07-19 10:20:14	2020-07-19	8	[{"id_menu":5,"count":1}]	13995	delivery	5	13
99472	2020-07-19 10:20:51	2020-07-19	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14735	delivery	5	36
99473	2020-07-19 10:22:55	2020-07-19	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	35061	delivery	5	22
99474	2020-07-19 10:23:32	2020-07-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38499	delivery	5	23
99475	2020-07-19 10:24:24	2020-07-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	38547	delivery	5	31
99476	2020-07-19 10:24:57	2020-07-19	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	36089	delivery	5	39
99477	2020-07-19 10:25:37	2020-07-19	12	[{"id_menu":3,"count":2}]	38538	delivery	5	17
99478	2020-07-19 10:27:13	2020-07-19	12	[{"id_menu":1,"count":1}]	12274	pick-up	0	12
99479	2020-07-19 10:27:22	2020-07-19	9	[{"id_menu":7,"count":1}]	30751	pick-up	0	9
99480	2020-07-19 10:29:10	2020-07-19	9	[{"id_menu":6,"count":3}]	17763	delivery	5	14
99481	2020-07-19 10:31:38	2020-07-19	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	28357	delivery	5	27
99482	2020-07-19 10:33:18	2020-07-19	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	13497	pick-up	0	35
99483	2020-07-19 10:34:45	2020-07-19	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18840	delivery	5	34
99484	2020-07-19 10:37:34	2020-07-19	9	[{"id_menu":6,"count":1}]	35079	delivery	5	14
99485	2020-07-19 10:37:47	2020-07-19	9	[{"id_menu":7,"count":1}]	27469	delivery	5	14
99486	2020-07-19 10:39:01	2020-07-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	14480	pick-up	0	23
99487	2020-07-19 10:42:38	2020-07-19	14	[{"id_menu":2,"count":1}]	38442	delivery	5	19
99488	2020-07-19 10:44:05	2020-07-19	9	[{"id_menu":6,"count":1}]	149	pick-up	0	9
99489	2020-07-19 10:44:19	2020-07-19	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	38462	delivery	5	22
99490	2020-07-19 10:46:52	2020-07-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32894	delivery	5	23
99491	2020-07-19 10:47:18	2020-07-19	14	[{"id_menu":2,"count":1}]	17594	pick-up	0	14
99492	2020-07-19 10:48:00	2020-07-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	24882	delivery	5	28
99493	2020-07-19 10:49:30	2020-07-19	12	[{"id_menu":3,"count":1}]	3898	delivery	5	17
99494	2020-07-19 10:50:43	2020-07-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	34551	pick-up	0	17
99495	2020-07-19 10:52:18	2020-07-19	12	[{"id_menu":3,"count":1}]	30625	delivery	5	17
99496	2020-07-19 10:53:14	2020-07-19	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	14239	pick-up	0	21
99497	2020-07-19 10:54:58	2020-07-19	12	[{"id_menu":1,"count":2}]	68	pick-up	0	12
99498	2020-07-19 10:55:23	2020-07-19	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	38556	pick-up	0	24
99499	2020-07-19 10:56:11	2020-07-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	27730	delivery	5	28
99500	2020-07-19 10:57:23	2020-07-19	8	[{"id_menu":5,"count":1}]	38473	pick-up	0	8
99501	2020-07-19 10:58:52	2020-07-19	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":3}]	27808	delivery	5	34
99502	2020-07-19 11:02:37	2020-07-19	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	12857	delivery	5	31
99503	2020-07-19 11:05:38	2020-07-19	14	[{"id_menu":2,"count":1}]	11824	pick-up	0	14
99504	2020-07-19 11:07:19	2020-07-19	12	[{"id_menu":3,"count":1}]	38437	delivery	5	17
99505	2020-07-19 11:08:41	2020-07-19	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	1645	pick-up	0	34
99506	2020-07-19 11:10:29	2020-07-19	9	[{"id_menu":6,"count":1}]	4478	delivery	5	14
99507	2020-07-19 11:11:35	2020-07-19	14	[{"id_menu":2,"count":1}]	23023	delivery	5	19
99508	2020-07-19 11:11:45	2020-07-19	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	13930	pick-up	0	21
99509	2020-07-19 11:13:09	2020-07-19	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	38529	delivery	5	26
99510	2020-07-19 11:13:45	2020-07-19	9	[{"id_menu":6,"count":1}]	38411	delivery	5	14
99511	2020-07-19 11:14:13	2020-07-19	17	[{"id_menu":4,"count":1}]	38316	delivery	5	22
99512	2020-07-19 11:19:00	2020-07-19	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	13182	delivery	5	38
99513	2020-07-19 11:19:03	2020-07-19	8	[{"id_menu":5,"count":1}]	23404	delivery	5	13
99514	2020-07-19 11:25:36	2020-07-19	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	38272	delivery	5	39
99515	2020-07-19 11:27:03	2020-07-19	17	[{"id_menu":4,"count":2}]	9728	pick-up	0	17
99516	2020-07-19 11:29:27	2020-07-19	14	[{"id_menu":2,"count":1}]	28375	delivery	5	19
99517	2020-07-19 11:30:06	2020-07-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27575	delivery	5	22
99518	2020-07-19 11:30:49	2020-07-19	9	[{"id_menu":7,"count":2}]	26133	delivery	5	14
99519	2020-07-19 11:31:53	2020-07-19	12	[{"id_menu":3,"count":1}]	30903	delivery	5	17
99520	2020-07-19 11:32:55	2020-07-19	12	[{"id_menu":1,"count":1}]	27177	delivery	5	17
99521	2020-07-19 11:33:02	2020-07-19	9	[{"id_menu":7,"count":1}]	33100	delivery	5	14
99522	2020-07-19 11:37:48	2020-07-19	9	[{"id_menu":6,"count":1}]	21993	delivery	5	14
99523	2020-07-19 11:40:10	2020-07-19	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	38455	delivery	5	34
99524	2020-07-19 11:41:39	2020-07-19	14	[{"id_menu":2,"count":1}]	17084	delivery	5	19
99525	2020-07-19 11:43:29	2020-07-19	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	38400	delivery	5	30
99526	2020-07-19 11:45:29	2020-07-19	12	[{"id_menu":1,"count":1}]	7046	pick-up	0	12
99527	2020-07-19 11:48:46	2020-07-19	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14795	delivery	5	48
99528	2020-07-19 11:49:20	2020-07-19	12	[{"id_menu":3,"count":1}]	1860	pick-up	0	12
99529	2020-07-19 11:50:18	2020-07-19	9	[{"id_menu":7,"count":1}]	38378	delivery	5	14
99530	2020-07-19 11:53:50	2020-07-19	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":2}]	15208	delivery	5	25
99531	2020-07-19 11:54:17	2020-07-19	8	[{"id_menu":5,"count":1}]	24435	pick-up	0	8
99532	2020-07-19 11:55:18	2020-07-19	14	[{"id_menu":2,"count":1}]	31554	pick-up	0	14
99533	2020-07-19 12:00:38	2020-07-19	12	[{"id_menu":1,"count":1}]	38483	delivery	5	17
99534	2020-07-19 12:03:09	2020-07-19	9	[{"id_menu":7,"count":1}]	36310	pick-up	0	9
99535	2020-07-19 12:03:33	2020-07-19	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	23931	delivery	5	30
99536	2020-07-19 12:08:34	2020-07-19	12	[{"id_menu":1,"count":1}]	15292	pick-up	0	12
99537	2020-07-19 12:11:24	2020-07-19	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	7431	delivery	5	40
99538	2020-07-19 12:12:45	2020-07-19	9	[{"id_menu":6,"count":1}]	38464	delivery	5	14
99539	2020-07-19 12:12:53	2020-07-19	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	32317	delivery	5	40
99540	2020-07-19 12:13:32	2020-07-19	17	[{"id_menu":4,"count":1}]	1676	delivery	5	22
99541	2020-07-19 12:18:47	2020-07-19	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	38508	delivery	5	31
99542	2020-07-19 12:20:34	2020-07-19	9	[{"id_menu":7,"count":1}]	25629	delivery	5	14
99543	2020-07-19 12:20:38	2020-07-19	12	[{"id_menu":1,"count":1}]	1548	delivery	5	17
99544	2020-07-19 12:21:15	2020-07-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38415	delivery	5	23
99545	2020-07-19 12:22:27	2020-07-19	12	[{"id_menu":1,"count":1}]	38560	pick-up	0	12
99546	2020-07-19 12:22:47	2020-07-19	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	38481	delivery	5	31
99547	2020-07-19 12:24:47	2020-07-19	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	32178	pick-up	0	24
99548	2020-07-19 12:27:52	2020-07-19	14	[{"id_menu":2,"count":1}]	23021	delivery	5	19
99549	2020-07-19 12:29:50	2020-07-19	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	997	pick-up	0	21
99550	2020-07-19 12:29:51	2020-07-19	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	34918	delivery	5	30
99551	2020-07-19 12:33:27	2020-07-19	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	38554	pick-up	0	22
99552	2020-07-19 12:34:19	2020-07-19	8	[{"id_menu":5,"count":1}]	38452	delivery	5	13
99553	2020-07-19 12:37:53	2020-07-19	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	4828	delivery	5	40
99554	2020-07-19 12:38:37	2020-07-19	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	20845	delivery	5	39
99555	2020-07-19 12:38:41	2020-07-19	17	[{"id_menu":4,"count":1}]	7098	delivery	5	22
99556	2020-07-19 12:39:46	2020-07-19	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	38428	delivery	5	43
99557	2020-07-19 12:40:40	2020-07-19	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	30695	delivery	5	26
99558	2020-07-19 12:41:53	2020-07-19	8	[{"id_menu":5,"count":1}]	32481	delivery	5	13
99559	2020-07-19 12:43:16	2020-07-19	17	[{"id_menu":4,"count":1}]	10989	pick-up	0	17
99560	2020-07-19 12:43:55	2020-07-19	14	[{"id_menu":2,"count":1}]	38420	delivery	5	19
99561	2020-07-19 12:44:18	2020-07-19	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19767	delivery	5	35
99562	2020-07-19 12:45:33	2020-07-19	17	[{"id_menu":4,"count":2}]	29497	delivery	5	22
99563	2020-07-19 12:46:38	2020-07-19	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27785	delivery	5	43
99564	2020-07-19 12:53:34	2020-07-19	12	[{"id_menu":1,"count":1}]	12814	delivery	5	17
99565	2020-07-19 12:54:38	2020-07-19	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30477	delivery	5	43
99566	2020-07-19 12:54:54	2020-07-19	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	35131	pick-up	0	29
99567	2020-07-19 12:55:17	2020-07-19	17	[{"id_menu":4,"count":2}]	2777	pick-up	0	17
99568	2020-07-19 12:56:33	2020-07-19	12	[{"id_menu":3,"count":1}]	20549	delivery	5	17
99569	2020-07-19 12:57:32	2020-07-19	12	[{"id_menu":3,"count":1}]	36146	delivery	5	17
99570	2020-07-19 13:00:58	2020-07-19	9	[{"id_menu":7,"count":1}]	5426	pick-up	0	9
99571	2020-07-19 13:02:45	2020-07-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38408	delivery	5	23
99572	2020-07-19 13:03:32	2020-07-19	12	[{"id_menu":1,"count":1}]	24018	pick-up	0	12
99573	2020-07-19 13:05:42	2020-07-19	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27925	delivery	5	37
99574	2020-07-19 13:06:55	2020-07-19	9	[{"id_menu":6,"count":1}]	38468	delivery	5	14
99575	2020-07-19 13:07:14	2020-07-19	9	[{"id_menu":6,"count":1}]	21475	delivery	5	14
99576	2020-07-19 13:07:20	2020-07-19	9	[{"id_menu":7,"count":1}]	2993	pick-up	0	9
99577	2020-07-19 13:10:21	2020-07-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38285	delivery	5	23
99578	2020-07-19 13:10:25	2020-07-19	9	[{"id_menu":7,"count":1}]	38404	delivery	5	14
99579	2020-07-19 13:12:37	2020-07-19	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	38389	delivery	5	39
99580	2020-07-19 13:13:56	2020-07-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	786	delivery	5	31
99581	2020-07-19 13:15:11	2020-07-19	14	[{"id_menu":2,"count":1}]	2655	delivery	5	19
99582	2020-07-19 13:21:50	2020-07-19	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	38407	delivery	5	34
99583	2020-07-19 13:28:03	2020-07-19	12	[{"id_menu":1,"count":1}]	4479	pick-up	0	12
99584	2020-07-19 13:28:40	2020-07-19	12	[{"id_menu":1,"count":1}]	19956	delivery	5	17
99585	2020-07-19 13:30:41	2020-07-19	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	8713	delivery	5	30
99586	2020-07-19 13:31:46	2020-07-19	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	38546	delivery	5	36
99587	2020-07-19 13:33:36	2020-07-19	8	[{"id_menu":5,"count":1}]	36679	pick-up	0	8
99588	2020-07-19 13:35:47	2020-07-19	9	[{"id_menu":7,"count":1}]	38366	delivery	5	14
99589	2020-07-19 13:36:11	2020-07-19	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7232	delivery	5	48
99590	2020-07-19 13:37:42	2020-07-19	8	[{"id_menu":5,"count":1}]	38399	delivery	5	13
99591	2020-07-19 13:38:26	2020-07-19	17	[{"id_menu":4,"count":1}]	37983	delivery	5	22
99592	2020-07-19 13:42:44	2020-07-19	14	[{"id_menu":2,"count":1}]	35444	delivery	5	19
99593	2020-07-19 13:46:07	2020-07-19	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	10950	delivery	5	31
99594	2020-07-19 13:51:17	2020-07-19	14	[{"id_menu":2,"count":1}]	38467	delivery	5	19
99595	2020-07-19 13:56:32	2020-07-19	9	[{"id_menu":6,"count":1}]	38466	delivery	5	14
99596	2020-07-19 13:59:37	2020-07-19	9	[{"id_menu":7,"count":1}]	38489	delivery	5	14
99597	2020-07-19 13:59:38	2020-07-19	14	[{"id_menu":2,"count":1}]	4729	delivery	5	19
99598	2020-07-19 14:00:20	2020-07-19	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	38451	delivery	5	34
99599	2020-07-19 14:02:07	2020-07-19	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	38430	delivery	5	34
99600	2020-07-19 14:02:45	2020-07-19	12	[{"id_menu":1,"count":1}]	28167	delivery	5	17
99601	2020-07-19 14:04:02	2020-07-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13642	delivery	5	31
99602	2020-07-19 14:07:09	2020-07-19	12	[{"id_menu":1,"count":1}]	25337	delivery	5	17
99603	2020-07-19 14:08:16	2020-07-19	8	[{"id_menu":5,"count":1}]	38494	pick-up	0	8
99604	2020-07-19 14:11:38	2020-07-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8546	delivery	5	23
99605	2020-07-19 14:18:01	2020-07-19	12	[{"id_menu":3,"count":1}]	34991	delivery	5	17
99606	2020-07-19 14:22:35	2020-07-19	12	[{"id_menu":1,"count":1}]	1307	pick-up	0	12
99607	2020-07-19 14:22:54	2020-07-19	8	[{"id_menu":5,"count":1}]	38484	pick-up	0	8
99608	2020-07-19 14:25:49	2020-07-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	18180	pick-up	0	31
99609	2020-07-19 14:27:01	2020-07-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15671	delivery	5	31
99610	2020-07-19 14:27:40	2020-07-19	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	26140	delivery	5	39
99611	2020-07-19 14:27:57	2020-07-19	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	20781	delivery	5	22
99612	2020-07-19 14:29:27	2020-07-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38396	delivery	5	23
99613	2020-07-19 14:30:02	2020-07-19	9	[{"id_menu":7,"count":1}]	24365	delivery	5	14
99614	2020-07-19 14:32:22	2020-07-19	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	38393	pick-up	0	25
99615	2020-07-19 14:33:22	2020-07-19	8	[{"id_menu":5,"count":1}]	38433	delivery	5	13
99616	2020-07-19 14:35:21	2020-07-19	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38471	delivery	5	35
99617	2020-07-19 14:37:01	2020-07-19	17	[{"id_menu":4,"count":1}]	38361	delivery	5	22
99618	2020-07-19 14:40:52	2020-07-19	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	38495	delivery	5	36
99619	2020-07-19 14:42:26	2020-07-19	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10038	pick-up	0	37
99620	2020-07-19 14:42:37	2020-07-19	14	[{"id_menu":2,"count":1}]	36111	delivery	5	19
99621	2020-07-19 14:43:10	2020-07-19	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2615	pick-up	0	25
99622	2020-07-19 14:45:09	2020-07-19	9	[{"id_menu":6,"count":2}]	38431	delivery	5	14
99623	2020-07-19 14:45:44	2020-07-19	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	26594	delivery	5	25
99624	2020-07-19 14:52:21	2020-07-19	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	38493	delivery	5	30
99625	2020-07-19 14:52:28	2020-07-19	8	[{"id_menu":5,"count":1}]	15176	delivery	5	13
99626	2020-07-19 14:55:35	2020-07-19	9	[{"id_menu":6,"count":1}]	17655	delivery	5	14
99627	2020-07-19 14:56:58	2020-07-19	12	[{"id_menu":1,"count":1}]	12620	delivery	5	17
99628	2020-07-19 14:58:00	2020-07-19	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	33495	delivery	5	31
99629	2020-07-19 14:58:23	2020-07-19	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26614	delivery	5	35
99630	2020-07-19 15:02:12	2020-07-19	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1809	pick-up	0	25
99631	2020-07-19 15:03:18	2020-07-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	28377	pick-up	0	31
99632	2020-07-19 15:05:33	2020-07-19	9	[{"id_menu":6,"count":1}]	32325	pick-up	0	9
99633	2020-07-19 15:06:31	2020-07-19	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10692	pick-up	0	29
99634	2020-07-19 15:07:42	2020-07-19	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	37801	delivery	5	26
99635	2020-07-19 15:08:47	2020-07-19	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	38561	delivery	5	31
99636	2020-07-19 15:09:02	2020-07-19	12	[{"id_menu":3,"count":1}]	17209	pick-up	0	12
99637	2020-07-19 15:09:22	2020-07-19	8	[{"id_menu":5,"count":1}]	37835	delivery	5	13
99638	2020-07-19 15:10:03	2020-07-19	9	[{"id_menu":7,"count":1}]	78	pick-up	0	9
99639	2020-07-19 15:10:16	2020-07-19	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	38472	delivery	5	40
99640	2020-07-19 15:10:57	2020-07-19	9	[{"id_menu":6,"count":1}]	19399	delivery	5	14
99641	2020-07-19 15:11:08	2020-07-19	9	[{"id_menu":6,"count":1}]	19512	delivery	5	14
99642	2020-07-19 15:12:09	2020-07-19	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	19228	delivery	5	23
99643	2020-07-19 15:17:30	2020-07-19	8	[{"id_menu":5,"count":1}]	35885	pick-up	0	8
99644	2020-07-19 15:18:45	2020-07-19	9	[{"id_menu":7,"count":1}]	20192	delivery	5	14
99645	2020-07-19 15:20:03	2020-07-19	9	[{"id_menu":6,"count":1}]	15979	delivery	5	14
99646	2020-07-19 15:21:40	2020-07-19	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38381	delivery	5	37
99647	2020-07-19 15:22:47	2020-07-19	14	[{"id_menu":2,"count":1}]	7012	pick-up	0	14
99648	2020-07-19 15:23:00	2020-07-19	9	[{"id_menu":7,"count":1}]	36808	delivery	5	14
99649	2020-07-19 15:25:15	2020-07-19	14	[{"id_menu":2,"count":2}]	16737	pick-up	0	14
99650	2020-07-19 15:27:10	2020-07-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	23350	pick-up	0	26
99651	2020-07-19 15:28:00	2020-07-19	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16426	delivery	5	45
99652	2020-07-19 15:30:52	2020-07-19	17	[{"id_menu":4,"count":1}]	2942	delivery	5	22
99653	2020-07-19 15:32:09	2020-07-19	12	[{"id_menu":1,"count":1}]	30452	delivery	5	17
99654	2020-07-19 15:32:43	2020-07-19	8	[{"id_menu":5,"count":1}]	38519	delivery	5	13
99655	2020-07-19 15:32:55	2020-07-19	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	38390	delivery	5	38
99656	2020-07-19 15:34:33	2020-07-19	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	33949	delivery	5	38
99657	2020-07-19 15:36:33	2020-07-19	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	16091	delivery	5	30
99658	2020-07-19 15:41:34	2020-07-19	8	[{"id_menu":5,"count":1}]	35012	delivery	5	13
99659	2020-07-19 15:41:42	2020-07-19	14	[{"id_menu":2,"count":1}]	38461	pick-up	0	14
99660	2020-07-19 15:45:11	2020-07-19	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	38414	delivery	5	34
99661	2020-07-19 15:45:31	2020-07-19	8	[{"id_menu":5,"count":1}]	38564	delivery	5	13
99662	2020-07-19 15:47:10	2020-07-19	14	[{"id_menu":2,"count":1}]	38566	delivery	5	19
99663	2020-07-19 15:47:13	2020-07-19	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	6651	delivery	5	37
99664	2020-07-19 15:50:54	2020-07-19	17	[{"id_menu":4,"count":1}]	38395	delivery	5	22
99665	2020-07-19 15:57:05	2020-07-19	8	[{"id_menu":5,"count":2}]	12292	delivery	5	13
99666	2020-07-19 15:57:22	2020-07-19	14	[{"id_menu":2,"count":1}]	19657	delivery	5	19
99667	2020-07-19 15:58:04	2020-07-19	17	[{"id_menu":4,"count":1}]	6490	pick-up	0	17
99668	2020-07-19 16:02:02	2020-07-19	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	38456	delivery	5	36
99669	2020-07-19 16:03:22	2020-07-19	9	[{"id_menu":7,"count":1}]	38379	delivery	5	14
99670	2020-07-19 16:03:51	2020-07-19	12	[{"id_menu":1,"count":1}]	2413	pick-up	0	12
99671	2020-07-19 16:04:03	2020-07-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	11455	delivery	5	28
99672	2020-07-19 16:04:25	2020-07-19	9	[{"id_menu":6,"count":2}]	17236	pick-up	0	9
99673	2020-07-19 16:06:31	2020-07-19	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	10667	delivery	5	34
99674	2020-07-19 16:07:07	2020-07-19	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	38512	delivery	5	56
99675	2020-07-19 16:08:12	2020-07-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	36344	delivery	5	28
99676	2020-07-19 16:15:04	2020-07-19	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	5047	delivery	5	26
99677	2020-07-19 16:15:42	2020-07-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	36682	delivery	5	31
99678	2020-07-19 16:16:10	2020-07-19	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	38523	delivery	5	51
99679	2020-07-19 16:16:34	2020-07-19	9	[{"id_menu":6,"count":1}]	10112	delivery	5	14
99680	2020-07-19 16:20:21	2020-07-19	9	[{"id_menu":6,"count":1}]	16857	delivery	5	14
99681	2020-07-19 16:24:05	2020-07-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	29263	delivery	5	28
99682	2020-07-19 16:27:09	2020-07-19	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	38470	delivery	5	34
99683	2020-07-19 16:29:08	2020-07-19	8	[{"id_menu":5,"count":1}]	16150	delivery	5	13
99684	2020-07-19 16:30:24	2020-07-19	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	19356	delivery	5	42
99685	2020-07-19 16:30:43	2020-07-19	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	29856	delivery	5	43
99686	2020-07-19 16:30:45	2020-07-19	9	[{"id_menu":7,"count":1}]	17067	delivery	5	14
99687	2020-07-19 16:33:30	2020-07-19	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	12338	delivery	5	29
99688	2020-07-19 16:33:46	2020-07-19	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	18746	delivery	5	40
99689	2020-07-19 16:34:54	2020-07-19	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	15035	delivery	5	40
99690	2020-07-19 16:36:05	2020-07-19	17	[{"id_menu":4,"count":2}]	11464	delivery	5	22
99691	2020-07-19 16:37:22	2020-07-19	9	[{"id_menu":7,"count":1}]	5817	delivery	5	14
99692	2020-07-19 16:37:36	2020-07-19	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	16197	delivery	5	27
99693	2020-07-19 16:40:28	2020-07-19	9	[{"id_menu":7,"count":2}]	37986	delivery	5	14
99694	2020-07-19 16:44:46	2020-07-19	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	38419	pick-up	0	24
99695	2020-07-19 16:44:50	2020-07-19	14	[{"id_menu":2,"count":1}]	4997	pick-up	0	14
99696	2020-07-19 16:46:19	2020-07-19	9	[{"id_menu":6,"count":1}]	6293	delivery	5	14
99697	2020-07-19 16:46:33	2020-07-19	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	38552	delivery	5	26
99698	2020-07-19 16:49:00	2020-07-19	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	21021	delivery	5	31
99699	2020-07-19 16:50:46	2020-07-19	17	[{"id_menu":4,"count":1}]	38533	delivery	5	22
99700	2020-07-19 16:53:35	2020-07-19	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	9088	delivery	5	39
99701	2020-07-19 16:54:39	2020-07-19	12	[{"id_menu":1,"count":1}]	38558	delivery	5	17
99702	2020-07-19 16:55:50	2020-07-19	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3002	delivery	5	34
99703	2020-07-19 16:58:18	2020-07-19	12	[{"id_menu":3,"count":1}]	13498	pick-up	0	12
99704	2020-07-19 16:59:16	2020-07-19	14	[{"id_menu":2,"count":1}]	4193	pick-up	0	14
99705	2020-07-19 17:00:25	2020-07-19	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	19729	delivery	5	28
99706	2020-07-19 17:01:36	2020-07-19	14	[{"id_menu":2,"count":2}]	25590	delivery	5	19
99707	2020-07-19 17:02:05	2020-07-19	9	[{"id_menu":6,"count":1}]	13794	delivery	5	14
99708	2020-07-19 17:02:50	2020-07-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	27908	delivery	5	28
99709	2020-07-19 17:06:06	2020-07-19	17	[{"id_menu":4,"count":1}]	9829	pick-up	0	17
99710	2020-07-19 17:07:59	2020-07-19	9	[{"id_menu":6,"count":1}]	38506	delivery	5	14
99711	2020-07-19 17:08:15	2020-07-19	12	[{"id_menu":3,"count":1}]	28091	pick-up	0	12
99712	2020-07-19 17:09:33	2020-07-19	14	[{"id_menu":2,"count":1}]	38509	delivery	5	19
99713	2020-07-19 17:10:09	2020-07-19	9	[{"id_menu":6,"count":1}]	7125	delivery	5	14
99714	2020-07-19 17:10:53	2020-07-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	13187	delivery	5	28
99715	2020-07-19 17:11:21	2020-07-19	9	[{"id_menu":7,"count":1}]	25492	delivery	5	14
99716	2020-07-19 17:11:36	2020-07-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	20836	delivery	5	31
99717	2020-07-19 17:11:39	2020-07-19	9	[{"id_menu":6,"count":1}]	36853	delivery	5	14
99718	2020-07-19 17:11:42	2020-07-19	12	[{"id_menu":1,"count":1}]	38491	delivery	5	17
99719	2020-07-19 17:11:50	2020-07-19	12	[{"id_menu":1,"count":2}]	17372	pick-up	0	12
99720	2020-07-19 17:14:24	2020-07-19	8	[{"id_menu":5,"count":1}]	24203	delivery	5	13
99721	2020-07-19 17:14:39	2020-07-19	12	[{"id_menu":1,"count":1}]	13310	delivery	5	17
99722	2020-07-19 17:18:57	2020-07-19	9	[{"id_menu":6,"count":1}]	3104	pick-up	0	9
99723	2020-07-19 17:22:06	2020-07-19	12	[{"id_menu":1,"count":1}]	16722	delivery	5	17
99724	2020-07-19 17:25:18	2020-07-19	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	5075	pick-up	0	22
99725	2020-07-19 17:27:41	2020-07-19	12	[{"id_menu":1,"count":1}]	16822	pick-up	0	12
99726	2020-07-19 17:27:52	2020-07-19	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	38550	delivery	5	35
99727	2020-07-19 17:27:53	2020-07-19	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	7841	delivery	5	31
99728	2020-07-19 17:28:24	2020-07-19	17	[{"id_menu":4,"count":1}]	22041	delivery	5	22
99729	2020-07-19 17:28:49	2020-07-19	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	38425	delivery	5	26
99730	2020-07-19 17:29:44	2020-07-19	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	10255	delivery	5	26
99731	2020-07-19 17:30:35	2020-07-19	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2651	delivery	5	45
99732	2020-07-19 17:36:35	2020-07-19	9	[{"id_menu":7,"count":1}]	4309	delivery	5	14
99733	2020-07-19 17:36:42	2020-07-19	17	[{"id_menu":4,"count":1}]	27725	delivery	5	22
99734	2020-07-19 17:36:42	2020-07-19	14	[{"id_menu":2,"count":1}]	9635	pick-up	0	14
99735	2020-07-19 17:37:21	2020-07-19	9	[{"id_menu":6,"count":1}]	38392	delivery	5	14
99736	2020-07-19 17:39:46	2020-07-19	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	27769	delivery	5	40
99737	2020-07-19 17:41:30	2020-07-19	17	[{"id_menu":4,"count":1}]	11937	delivery	5	22
99738	2020-07-19 17:42:45	2020-07-19	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	22511	delivery	5	34
99739	2020-07-19 17:43:35	2020-07-19	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	7277	delivery	5	35
99740	2020-07-19 17:44:32	2020-07-19	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	17056	pick-up	0	24
99741	2020-07-19 17:44:55	2020-07-19	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38542	delivery	5	43
99742	2020-07-19 17:49:43	2020-07-19	9	[{"id_menu":6,"count":1}]	1523	delivery	5	14
99743	2020-07-19 17:51:23	2020-07-19	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28644	delivery	5	45
99744	2020-07-19 17:51:53	2020-07-19	9	[{"id_menu":7,"count":1}]	20840	delivery	5	14
99745	2020-07-19 17:52:31	2020-07-19	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	31937	delivery	5	43
99746	2020-07-19 17:53:29	2020-07-19	12	[{"id_menu":3,"count":1}]	13495	pick-up	0	12
99747	2020-07-19 17:57:28	2020-07-19	14	[{"id_menu":2,"count":1}]	33717	delivery	5	19
99748	2020-07-19 17:59:01	2020-07-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	32450	delivery	5	28
99749	2020-07-19 18:00:57	2020-07-19	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	38367	pick-up	0	26
99750	2020-07-19 18:02:34	2020-07-19	12	[{"id_menu":1,"count":1}]	3817	delivery	5	17
99751	2020-07-19 18:04:26	2020-07-19	14	[{"id_menu":2,"count":2}]	32500	delivery	5	19
99752	2020-07-19 18:07:50	2020-07-19	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	38549	delivery	5	25
99753	2020-07-19 18:08:17	2020-07-19	9	[{"id_menu":7,"count":1}]	30555	delivery	5	14
99754	2020-07-19 18:09:47	2020-07-19	12	[{"id_menu":3,"count":1}]	14662	pick-up	0	12
99755	2020-07-19 18:09:48	2020-07-19	14	[{"id_menu":2,"count":1}]	32613	delivery	5	19
99756	2020-07-19 18:10:39	2020-07-19	8	[{"id_menu":5,"count":1}]	27936	delivery	5	13
99757	2020-07-19 18:10:56	2020-07-19	14	[{"id_menu":2,"count":1}]	38429	delivery	5	19
99758	2020-07-19 18:14:37	2020-07-19	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30407	delivery	5	35
99759	2020-07-19 18:16:18	2020-07-19	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27803	delivery	5	36
99760	2020-07-19 18:18:19	2020-07-19	14	[{"id_menu":2,"count":1}]	22045	pick-up	0	14
99761	2020-07-19 18:18:23	2020-07-19	17	[{"id_menu":4,"count":1}]	38410	delivery	5	22
99762	2020-07-19 18:19:08	2020-07-19	8	[{"id_menu":5,"count":1}]	15158	pick-up	0	8
99763	2020-07-19 18:19:33	2020-07-19	9	[{"id_menu":6,"count":1}]	2967	pick-up	0	9
99764	2020-07-19 18:20:29	2020-07-19	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	36801	delivery	5	34
99765	2020-07-19 18:20:47	2020-07-19	12	[{"id_menu":1,"count":1}]	37787	delivery	5	17
99766	2020-07-19 18:21:55	2020-07-19	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	38531	delivery	5	39
99767	2020-07-19 18:22:40	2020-07-19	17	[{"id_menu":4,"count":1}]	31906	delivery	5	22
99768	2020-07-19 18:29:36	2020-07-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38447	delivery	5	23
99769	2020-07-19 18:29:47	2020-07-19	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	281	pick-up	0	21
99770	2020-07-19 18:30:08	2020-07-19	9	[{"id_menu":6,"count":1}]	38422	delivery	5	14
99771	2020-07-19 18:30:16	2020-07-19	12	[{"id_menu":3,"count":1}]	37299	delivery	5	17
99772	2020-07-19 18:31:24	2020-07-19	9	[{"id_menu":6,"count":1}]	29328	delivery	5	14
99773	2020-07-19 18:35:08	2020-07-19	9	[{"id_menu":6,"count":1}]	11219	delivery	5	14
99774	2020-07-19 18:37:07	2020-07-19	12	[{"id_menu":3,"count":1}]	4184	delivery	5	17
99775	2020-07-19 18:37:13	2020-07-19	14	[{"id_menu":2,"count":1}]	38565	pick-up	0	14
99776	2020-07-19 18:37:21	2020-07-19	12	[{"id_menu":1,"count":1}]	32652	pick-up	0	12
99777	2020-07-19 18:39:20	2020-07-19	12	[{"id_menu":1,"count":1}]	38518	delivery	5	17
99778	2020-07-19 18:40:28	2020-07-19	9	[{"id_menu":7,"count":1}]	12693	delivery	5	14
99779	2020-07-19 18:43:21	2020-07-19	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	38507	delivery	5	34
99780	2020-07-19 18:53:01	2020-07-19	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	29226	pick-up	0	29
99781	2020-07-19 18:53:02	2020-07-19	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	4498	delivery	5	31
99782	2020-07-19 18:53:35	2020-07-19	12	[{"id_menu":3,"count":1}]	23800	delivery	5	17
99783	2020-07-19 18:56:53	2020-07-19	12	[{"id_menu":3,"count":1}]	17421	delivery	5	17
99784	2020-07-19 18:57:17	2020-07-19	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	38528	pick-up	0	21
99785	2020-07-19 18:58:17	2020-07-19	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	38543	delivery	5	45
99786	2020-07-19 18:59:03	2020-07-19	8	[{"id_menu":5,"count":1}]	38478	delivery	5	13
99787	2020-07-19 19:00:39	2020-07-19	9	[{"id_menu":7,"count":1}]	23822	delivery	5	14
99788	2020-07-19 19:03:49	2020-07-19	8	[{"id_menu":5,"count":1}]	34644	delivery	5	13
99789	2020-07-19 19:05:18	2020-07-19	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11046	delivery	5	49
99790	2020-07-19 19:05:19	2020-07-19	9	[{"id_menu":7,"count":1}]	10874	delivery	5	14
99791	2020-07-19 19:06:21	2020-07-19	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	38488	delivery	5	34
99792	2020-07-19 19:06:23	2020-07-19	9	[{"id_menu":6,"count":1}]	17500	pick-up	0	9
99793	2020-07-19 19:06:45	2020-07-19	9	[{"id_menu":6,"count":1}]	36268	delivery	5	14
99794	2020-07-19 19:10:12	2020-07-19	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	4652	delivery	5	25
99795	2020-07-19 19:11:01	2020-07-19	9	[{"id_menu":7,"count":1}]	25913	delivery	5	14
99796	2020-07-19 19:12:01	2020-07-19	12	[{"id_menu":1,"count":1}]	38563	delivery	5	17
99797	2020-07-19 19:12:09	2020-07-19	12	[{"id_menu":1,"count":1}]	38352	delivery	5	17
99798	2020-07-19 19:12:15	2020-07-19	9	[{"id_menu":7,"count":2}]	12935	delivery	5	14
99799	2020-07-19 19:12:20	2020-07-19	8	[{"id_menu":5,"count":1}]	38517	delivery	5	13
99800	2020-07-19 19:12:53	2020-07-19	12	[{"id_menu":3,"count":1}]	16133	delivery	5	17
99801	2020-07-19 19:13:12	2020-07-19	14	[{"id_menu":2,"count":2}]	1640	delivery	5	19
99802	2020-07-19 19:16:07	2020-07-19	9	[{"id_menu":6,"count":1}]	23295	delivery	5	14
99803	2020-07-19 19:17:59	2020-07-19	14	[{"id_menu":2,"count":1}]	22712	delivery	5	19
99804	2020-07-19 19:18:36	2020-07-19	14	[{"id_menu":2,"count":1}]	12808	pick-up	0	14
99805	2020-07-19 19:20:14	2020-07-19	14	[{"id_menu":2,"count":1}]	6594	delivery	5	19
99806	2020-07-19 19:24:54	2020-07-19	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4223	delivery	5	34
99807	2020-07-19 19:28:23	2020-07-19	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	35474	delivery	5	31
99808	2020-07-19 19:28:53	2020-07-19	17	[{"id_menu":4,"count":1}]	37893	delivery	5	22
99809	2020-07-19 19:30:14	2020-07-19	14	[{"id_menu":2,"count":1}]	2807	delivery	5	19
99810	2020-07-19 19:30:48	2020-07-19	8	[{"id_menu":5,"count":1}]	4090	pick-up	0	8
99811	2020-07-19 19:31:31	2020-07-19	9	[{"id_menu":7,"count":1}]	37821	delivery	5	14
99812	2020-07-19 19:32:43	2020-07-19	9	[{"id_menu":6,"count":1}]	22259	delivery	5	14
99813	2020-07-19 19:34:05	2020-07-19	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8337	delivery	5	31
99814	2020-07-19 19:37:44	2020-07-19	14	[{"id_menu":2,"count":1}]	38417	pick-up	0	14
99815	2020-07-19 19:38:17	2020-07-19	8	[{"id_menu":5,"count":1}]	25572	delivery	5	13
99816	2020-07-19 19:38:27	2020-07-19	12	[{"id_menu":1,"count":1}]	30260	delivery	5	17
99817	2020-07-19 19:38:45	2020-07-19	17	[{"id_menu":4,"count":1}]	38418	delivery	5	22
99818	2020-07-19 19:39:52	2020-07-19	9	[{"id_menu":7,"count":1}]	28315	delivery	5	14
99819	2020-07-19 19:40:46	2020-07-19	14	[{"id_menu":2,"count":1}]	1667	pick-up	0	14
99820	2020-07-19 19:41:13	2020-07-19	9	[{"id_menu":6,"count":1}]	15164	delivery	5	14
99821	2020-07-19 19:41:53	2020-07-19	9	[{"id_menu":7,"count":1}]	22808	delivery	5	14
99822	2020-07-19 19:42:59	2020-07-19	9	[{"id_menu":6,"count":1}]	26002	delivery	5	14
99823	2020-07-19 19:44:24	2020-07-19	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	352	pick-up	0	23
99824	2020-07-19 19:46:26	2020-07-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21310	delivery	5	23
99825	2020-07-19 19:51:55	2020-07-19	12	[{"id_menu":1,"count":1}]	38364	delivery	5	17
99826	2020-07-19 19:54:50	2020-07-19	14	[{"id_menu":2,"count":1}]	28116	delivery	5	19
99827	2020-07-19 19:55:14	2020-07-19	9	[{"id_menu":6,"count":1}]	6055	delivery	5	14
99828	2020-07-19 19:57:10	2020-07-19	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	38460	delivery	5	26
99829	2020-07-19 20:00:45	2020-07-19	8	[{"id_menu":5,"count":2}]	14913	delivery	5	13
99830	2020-07-19 20:01:43	2020-07-19	9	[{"id_menu":7,"count":1}]	6994	pick-up	0	9
99831	2020-07-19 20:03:42	2020-07-19	9	[{"id_menu":6,"count":1}]	1520	pick-up	0	9
99832	2020-07-19 20:04:26	2020-07-19	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3173	delivery	5	26
99833	2020-07-19 20:09:20	2020-07-19	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	38535	delivery	5	27
99834	2020-07-19 20:09:52	2020-07-19	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	5763	delivery	5	26
99835	2020-07-19 20:10:11	2020-07-19	12	[{"id_menu":1,"count":1}]	38394	pick-up	0	12
99836	2020-07-19 20:10:13	2020-07-19	9	[{"id_menu":7,"count":1}]	38440	delivery	5	14
99837	2020-07-19 20:11:36	2020-07-19	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	11764	delivery	5	26
99838	2020-07-19 20:12:59	2020-07-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	38446	delivery	5	28
99839	2020-07-19 20:13:08	2020-07-19	8	[{"id_menu":5,"count":1}]	27577	pick-up	0	8
99840	2020-07-19 20:14:18	2020-07-19	9	[{"id_menu":6,"count":1}]	31266	delivery	5	14
99841	2020-07-19 20:14:29	2020-07-19	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	16217	delivery	5	30
99842	2020-07-19 20:15:32	2020-07-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7007	delivery	5	22
99843	2020-07-19 20:16:49	2020-07-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20114	delivery	5	22
99844	2020-07-19 20:17:28	2020-07-19	9	[{"id_menu":7,"count":1}]	15110	pick-up	0	9
99845	2020-07-19 20:18:09	2020-07-19	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	31836	delivery	5	25
99846	2020-07-19 20:20:01	2020-07-19	9	[{"id_menu":7,"count":1}]	38485	delivery	5	14
99847	2020-07-19 20:21:53	2020-07-19	12	[{"id_menu":1,"count":1}]	38482	pick-up	0	12
99848	2020-07-19 20:22:07	2020-07-19	9	[{"id_menu":6,"count":1}]	8479	delivery	5	14
99849	2020-07-19 20:23:24	2020-07-19	9	[{"id_menu":7,"count":1}]	38555	pick-up	0	9
99850	2020-07-19 20:29:39	2020-07-19	8	[{"id_menu":5,"count":1}]	138	delivery	5	13
99851	2020-07-19 20:29:57	2020-07-19	17	[{"id_menu":4,"count":1}]	1742	pick-up	0	17
99852	2020-07-19 20:31:18	2020-07-19	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	19971	delivery	5	26
99853	2020-07-19 20:32:22	2020-07-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	38371	delivery	5	28
99854	2020-07-19 20:32:52	2020-07-19	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7731	delivery	5	44
99855	2020-07-19 20:33:42	2020-07-19	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	38388	delivery	5	23
99856	2020-07-19 20:34:01	2020-07-19	9	[{"id_menu":7,"count":1}]	28340	delivery	5	14
99857	2020-07-19 20:34:25	2020-07-19	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	29421	delivery	5	26
99858	2020-07-19 20:34:29	2020-07-19	17	[{"id_menu":4,"count":2}]	5368	delivery	5	22
99859	2020-07-19 20:35:04	2020-07-19	9	[{"id_menu":7,"count":1}]	31076	pick-up	0	9
99860	2020-07-19 20:35:54	2020-07-19	9	[{"id_menu":7,"count":1}]	35985	delivery	5	14
99861	2020-07-19 20:37:14	2020-07-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	15815	delivery	5	28
99862	2020-07-19 20:37:30	2020-07-19	12	[{"id_menu":1,"count":1}]	24485	pick-up	0	12
99863	2020-07-19 20:39:41	2020-07-19	12	[{"id_menu":1,"count":1}]	38402	pick-up	0	12
99864	2020-07-19 20:41:35	2020-07-19	12	[{"id_menu":3,"count":1}]	14862	delivery	5	17
99865	2020-07-19 20:42:18	2020-07-19	9	[{"id_menu":7,"count":1}]	19818	delivery	5	14
99866	2020-07-19 20:46:05	2020-07-19	17	[{"id_menu":4,"count":1}]	14406	pick-up	0	17
99867	2020-07-19 20:47:01	2020-07-19	9	[{"id_menu":7,"count":1}]	28387	delivery	5	14
99868	2020-07-19 20:47:33	2020-07-19	12	[{"id_menu":3,"count":1}]	21372	delivery	5	17
99869	2020-07-19 20:48:49	2020-07-19	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	10580	pick-up	0	29
99870	2020-07-19 20:50:50	2020-07-19	17	[{"id_menu":4,"count":1}]	38534	delivery	5	22
99871	2020-07-19 20:52:00	2020-07-19	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18174	delivery	5	53
99872	2020-07-19 20:54:34	2020-07-19	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	17245	pick-up	0	37
99873	2020-07-19 20:57:15	2020-07-19	12	[{"id_menu":1,"count":2}]	8045	delivery	5	17
99874	2020-07-19 21:01:22	2020-07-19	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4445	pick-up	0	43
99875	2020-07-19 21:04:06	2020-07-19	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	38434	delivery	5	45
99876	2020-07-19 21:04:45	2020-07-19	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	12437	pick-up	0	21
99877	2020-07-19 21:07:57	2020-07-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	14121	delivery	5	28
99878	2020-07-19 21:08:31	2020-07-19	12	[{"id_menu":1,"count":1}]	9028	delivery	5	17
99879	2020-07-19 21:09:27	2020-07-19	14	[{"id_menu":2,"count":1}]	6975	pick-up	0	14
99880	2020-07-19 21:10:57	2020-07-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	38474	delivery	5	36
99881	2020-07-19 21:12:06	2020-07-19	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	32488	pick-up	0	35
99882	2020-07-19 21:13:02	2020-07-19	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	21690	delivery	5	26
99883	2020-07-19 21:14:08	2020-07-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23709	pick-up	0	18
99884	2020-07-19 21:15:48	2020-07-19	8	[{"id_menu":5,"count":3}]	19593	delivery	5	13
99885	2020-07-19 21:16:23	2020-07-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30284	delivery	5	23
99886	2020-07-19 21:18:57	2020-07-19	8	[{"id_menu":5,"count":1}]	9128	pick-up	0	8
99887	2020-07-19 21:20:10	2020-07-19	9	[{"id_menu":6,"count":1}]	2968	delivery	5	14
99888	2020-07-19 21:21:09	2020-07-19	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	17528	delivery	5	26
99889	2020-07-19 21:24:38	2020-07-19	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3540	delivery	5	38
99890	2020-07-19 21:25:33	2020-07-19	9	[{"id_menu":6,"count":1}]	15627	delivery	5	14
99891	2020-07-19 21:27:46	2020-07-19	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15614	delivery	5	35
99892	2020-07-19 21:27:48	2020-07-19	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	4465	pick-up	0	26
99893	2020-07-19 21:28:45	2020-07-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	16984	pick-up	0	23
99894	2020-07-19 21:30:39	2020-07-19	8	[{"id_menu":5,"count":1}]	13632	delivery	5	13
99895	2020-07-19 21:32:33	2020-07-19	17	[{"id_menu":4,"count":1}]	31848	delivery	5	22
99896	2020-07-19 21:32:54	2020-07-19	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38553	delivery	5	35
99897	2020-07-19 21:34:51	2020-07-19	17	[{"id_menu":4,"count":1}]	11732	pick-up	0	17
99898	2020-07-19 21:35:04	2020-07-19	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7064	delivery	5	37
99899	2020-07-19 21:36:32	2020-07-19	14	[{"id_menu":2,"count":1}]	38458	delivery	5	19
99900	2020-07-19 21:39:16	2020-07-19	17	[{"id_menu":4,"count":2}]	12894	delivery	5	22
99901	2020-07-19 21:41:30	2020-07-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12452	delivery	5	22
99902	2020-07-19 21:47:54	2020-07-19	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	38441	delivery	5	31
99903	2020-07-19 21:48:05	2020-07-19	9	[{"id_menu":6,"count":1}]	23213	delivery	5	14
99904	2020-07-19 21:48:28	2020-07-19	14	[{"id_menu":2,"count":1}]	18749	pick-up	0	14
99905	2020-07-19 21:48:54	2020-07-19	17	[{"id_menu":4,"count":1}]	172	delivery	5	22
99906	2020-07-19 21:49:40	2020-07-19	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	38384	delivery	5	46
99907	2020-07-19 21:50:46	2020-07-19	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	35870	pick-up	0	26
99908	2020-07-19 21:51:25	2020-07-19	9	[{"id_menu":7,"count":1}]	4502	pick-up	0	9
99909	2020-07-19 21:53:53	2020-07-19	14	[{"id_menu":2,"count":1}]	38503	delivery	5	19
99910	2020-07-19 21:55:32	2020-07-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3883	delivery	5	28
99911	2020-07-19 21:56:44	2020-07-19	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	38353	delivery	5	30
99912	2020-07-19 22:00:08	2020-07-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5975	delivery	5	22
99913	2020-07-19 22:00:35	2020-07-19	17	[{"id_menu":4,"count":1}]	5760	pick-up	0	17
99914	2020-07-19 22:00:46	2020-07-19	12	[{"id_menu":3,"count":1}]	27614	delivery	5	17
99915	2020-07-19 22:05:33	2020-07-19	9	[{"id_menu":7,"count":1}]	38239	pick-up	0	9
99916	2020-07-19 22:07:05	2020-07-19	12	[{"id_menu":1,"count":2}]	18045	delivery	5	17
99917	2020-07-19 22:12:52	2020-07-19	17	[{"id_menu":4,"count":1}]	1170	pick-up	0	17
99918	2020-07-19 22:13:30	2020-07-19	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	38516	delivery	5	23
99919	2020-07-19 22:18:13	2020-07-19	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	2946	pick-up	0	43
99920	2020-07-19 22:20:02	2020-07-19	8	[{"id_menu":5,"count":1}]	21223	delivery	5	13
99921	2020-07-19 22:22:52	2020-07-19	12	[{"id_menu":3,"count":1}]	15864	delivery	5	17
99922	2020-07-19 22:24:36	2020-07-19	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	28006	delivery	5	27
99923	2020-07-19 22:26:46	2020-07-19	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	38385	delivery	5	31
99924	2020-07-19 22:26:52	2020-07-19	9	[{"id_menu":7,"count":1}]	8505	delivery	5	14
99925	2020-07-19 22:27:34	2020-07-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	38350	delivery	5	28
99926	2020-07-19 22:28:17	2020-07-19	8	[{"id_menu":5,"count":1}]	29392	delivery	5	13
99927	2020-07-19 22:28:18	2020-07-19	8	[{"id_menu":5,"count":1}]	6916	pick-up	0	8
99928	2020-07-19 22:28:23	2020-07-19	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	22688	delivery	5	26
99929	2020-07-19 22:30:33	2020-07-19	41	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	38480	delivery	5	46
99930	2020-07-19 22:30:55	2020-07-19	17	[{"id_menu":4,"count":1}]	38362	delivery	5	22
99931	2020-07-19 22:31:19	2020-07-19	9	[{"id_menu":6,"count":1}]	38397	delivery	5	14
99932	2020-07-19 22:31:36	2020-07-19	43	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1722	pick-up	0	43
99933	2020-07-19 22:33:42	2020-07-19	8	[{"id_menu":5,"count":1}]	38557	delivery	5	13
99934	2020-07-19 22:34:39	2020-07-19	9	[{"id_menu":7,"count":1}]	31631	delivery	5	14
99935	2020-07-19 22:36:11	2020-07-19	9	[{"id_menu":7,"count":1}]	16721	delivery	5	14
99936	2020-07-19 22:37:00	2020-07-19	12	[{"id_menu":1,"count":1}]	4710	pick-up	0	12
99937	2020-07-19 22:39:36	2020-07-19	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	29394	pick-up	0	20
99938	2020-07-19 22:41:30	2020-07-19	9	[{"id_menu":7,"count":1}]	9241	pick-up	0	9
99939	2020-07-19 22:45:06	2020-07-19	8	[{"id_menu":5,"count":1}]	38363	delivery	5	13
99940	2020-07-19 22:48:09	2020-07-19	12	[{"id_menu":1,"count":1}]	7118	pick-up	0	12
99941	2020-07-19 22:50:00	2020-07-19	14	[{"id_menu":2,"count":1}]	30409	delivery	5	19
99942	2020-07-19 22:53:00	2020-07-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	38365	delivery	5	28
99943	2020-07-19 22:57:08	2020-07-19	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	32144	pick-up	0	26
99944	2020-07-19 22:58:00	2020-07-19	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15360	delivery	5	31
99945	2020-07-19 22:59:23	2020-07-19	17	[{"id_menu":4,"count":1}]	19386	delivery	5	22
99946	2020-07-19 23:06:07	2020-07-19	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	38443	delivery	5	25
99947	2020-07-19 23:06:57	2020-07-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28879	delivery	5	23
99948	2020-07-19 23:07:20	2020-07-19	8	[{"id_menu":5,"count":1}]	34521	delivery	5	13
99949	2020-07-19 23:12:10	2020-07-19	14	[{"id_menu":2,"count":1}]	16482	pick-up	0	14
99950	2020-07-19 23:13:49	2020-07-19	9	[{"id_menu":6,"count":1}]	28592	pick-up	0	9
99951	2020-07-19 23:15:16	2020-07-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32119	delivery	5	22
99952	2020-07-19 23:16:32	2020-07-19	12	[{"id_menu":3,"count":1}]	38448	delivery	5	17
99953	2020-07-19 23:18:39	2020-07-19	14	[{"id_menu":2,"count":1}]	34433	delivery	5	19
99954	2020-07-19 23:25:20	2020-07-19	14	[{"id_menu":2,"count":1}]	38477	delivery	5	19
99955	2020-07-19 23:33:20	2020-07-19	9	[{"id_menu":7,"count":1}]	20341	delivery	5	14
99956	2020-07-19 23:35:19	2020-07-19	14	[{"id_menu":2,"count":1}]	16967	pick-up	0	14
99957	2020-07-19 23:35:56	2020-07-19	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	25064	delivery	5	27
99958	2020-07-19 23:35:58	2020-07-19	12	[{"id_menu":1,"count":1}]	24171	delivery	5	17
99959	2020-07-19 23:36:38	2020-07-19	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	10293	delivery	5	31
99960	2020-07-19 23:37:23	2020-07-19	14	[{"id_menu":2,"count":1}]	38527	delivery	5	19
99961	2020-07-19 23:39:11	2020-07-19	17	[{"id_menu":4,"count":1}]	38360	delivery	5	22
99962	2020-07-19 23:40:20	2020-07-19	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	38113	delivery	5	30
99963	2020-07-19 23:40:47	2020-07-19	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":3}]	38387	delivery	5	26
99964	2020-07-19 23:40:59	2020-07-19	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	38424	delivery	5	30
99965	2020-07-19 23:42:27	2020-07-19	17	[{"id_menu":4,"count":1}]	38515	delivery	5	22
99966	2020-07-19 23:44:11	2020-07-19	14	[{"id_menu":2,"count":1}]	16416	pick-up	0	14
99967	2020-07-19 23:47:39	2020-07-19	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	25780	pick-up	0	38
99968	2020-07-19 23:52:02	2020-07-19	17	[{"id_menu":4,"count":1}]	38498	pick-up	0	17
99969	2020-07-19 23:56:16	2020-07-19	12	[{"id_menu":1,"count":1}]	8976	delivery	5	17
99970	2020-07-19 23:57:45	2020-07-19	14	[{"id_menu":2,"count":1}]	38444	delivery	5	19
99971	2020-07-19 23:58:23	2020-07-19	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	38453	delivery	5	39
99972	2020-07-19 23:58:28	2020-07-19	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	344	pick-up	0	21
99973	2020-07-19 23:58:58	2020-07-19	9	[{"id_menu":6,"count":1}]	31092	delivery	5	14
99974	2020-07-19 23:59:12	2020-07-19	9	[{"id_menu":7,"count":1}]	38401	delivery	5	14
99975	2020-07-20 00:04:05	2020-07-20	14	[{"id_menu":2,"count":1}]	13034	pick-up	0	14
99976	2020-07-20 00:08:09	2020-07-20	9	[{"id_menu":6,"count":1}]	4020	pick-up	0	9
99977	2020-07-20 00:11:59	2020-07-20	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2110	pick-up	0	29
99978	2020-07-20 00:20:53	2020-07-20	17	[{"id_menu":4,"count":1}]	22374	delivery	5	22
99979	2020-07-20 00:23:06	2020-07-20	9	[{"id_menu":6,"count":1}]	38665	delivery	5	14
99980	2020-07-20 00:34:48	2020-07-20	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	18494	delivery	5	31
99981	2020-07-20 00:37:58	2020-07-20	9	[{"id_menu":6,"count":1}]	24630	delivery	5	14
99982	2020-07-20 00:42:55	2020-07-20	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16434	pick-up	0	35
99983	2020-07-20 00:46:31	2020-07-20	9	[{"id_menu":7,"count":1}]	21401	delivery	5	14
99984	2020-07-20 00:46:41	2020-07-20	14	[{"id_menu":2,"count":1}]	1889	pick-up	0	14
99985	2020-07-20 00:47:09	2020-07-20	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	13082	delivery	5	36
99986	2020-07-20 00:49:08	2020-07-20	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	38667	pick-up	0	24
99987	2020-07-20 00:49:34	2020-07-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17378	delivery	5	22
99988	2020-07-20 01:09:31	2020-07-20	9	[{"id_menu":6,"count":1}]	20457	delivery	5	14
99989	2020-07-20 01:19:01	2020-07-20	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2946	delivery	5	26
99990	2020-07-20 01:19:38	2020-07-20	9	[{"id_menu":6,"count":1}]	29192	delivery	5	14
99991	2020-07-20 01:23:47	2020-07-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38725	delivery	5	23
99992	2020-07-20 01:28:24	2020-07-20	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	35812	pick-up	0	20
99993	2020-07-20 01:34:23	2020-07-20	14	[{"id_menu":2,"count":1}]	17785	delivery	5	19
99994	2020-07-20 01:34:31	2020-07-20	37	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	38653	delivery	5	42
99995	2020-07-20 01:34:48	2020-07-20	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	964	delivery	5	26
99996	2020-07-20 01:35:44	2020-07-20	9	[{"id_menu":6,"count":2}]	38652	delivery	5	14
99997	2020-07-20 01:36:33	2020-07-20	14	[{"id_menu":2,"count":1}]	17874	delivery	5	19
99998	2020-07-20 01:41:23	2020-07-20	14	[{"id_menu":2,"count":1}]	38685	pick-up	0	14
99999	2020-07-20 01:42:47	2020-07-20	8	[{"id_menu":5,"count":1}]	26754	delivery	5	13
100000	2020-07-20 01:43:51	2020-07-20	17	[{"id_menu":4,"count":1}]	38616	delivery	5	22
100001	2020-07-20 01:43:53	2020-07-20	12	[{"id_menu":1,"count":1}]	8883	pick-up	0	12
100002	2020-07-20 01:47:05	2020-07-20	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	28098	delivery	5	36
100003	2020-07-20 01:48:22	2020-07-20	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	38251	delivery	5	36
100004	2020-07-20 01:53:48	2020-07-20	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	28978	delivery	5	31
100005	2020-07-20 02:01:11	2020-07-20	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	27936	delivery	5	40
100006	2020-07-20 02:09:23	2020-07-20	12	[{"id_menu":3,"count":1}]	32697	delivery	5	17
100007	2020-07-20 02:16:27	2020-07-20	8	[{"id_menu":5,"count":1}]	32401	delivery	5	13
100008	2020-07-20 02:20:17	2020-07-20	12	[{"id_menu":3,"count":1}]	32012	pick-up	0	12
100009	2020-07-20 02:22:24	2020-07-20	9	[{"id_menu":6,"count":1}]	30766	pick-up	0	9
100010	2020-07-20 02:24:17	2020-07-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	38738	delivery	5	28
100011	2020-07-20 02:31:21	2020-07-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	18902	delivery	5	28
100012	2020-07-20 02:32:47	2020-07-20	17	[{"id_menu":4,"count":1}]	16829	pick-up	0	17
100013	2020-07-20 02:35:06	2020-07-20	12	[{"id_menu":1,"count":1}]	6074	delivery	5	17
100014	2020-07-20 02:40:40	2020-07-20	8	[{"id_menu":5,"count":1}]	4393	pick-up	0	8
100015	2020-07-20 02:41:53	2020-07-20	12	[{"id_menu":3,"count":1}]	38599	delivery	5	17
100016	2020-07-20 02:45:26	2020-07-20	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	21216	delivery	5	40
100017	2020-07-20 02:50:07	2020-07-20	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	38690	delivery	5	22
100018	2020-07-20 02:51:31	2020-07-20	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38724	pick-up	0	30
100019	2020-07-20 02:52:42	2020-07-20	8	[{"id_menu":5,"count":1}]	38689	delivery	5	13
100020	2020-07-20 02:55:10	2020-07-20	8	[{"id_menu":5,"count":1}]	1656	pick-up	0	8
100021	2020-07-20 03:03:11	2020-07-20	9	[{"id_menu":7,"count":2}]	12085	delivery	5	14
100022	2020-07-20 03:03:17	2020-07-20	14	[{"id_menu":2,"count":1}]	24816	delivery	5	19
100023	2020-07-20 03:04:34	2020-07-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5648	pick-up	0	18
100024	2020-07-20 03:06:19	2020-07-20	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	38691	delivery	5	31
100025	2020-07-20 03:06:51	2020-07-20	9	[{"id_menu":7,"count":1}]	21601	pick-up	0	9
100026	2020-07-20 03:07:13	2020-07-20	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14081	pick-up	0	26
100027	2020-07-20 03:16:51	2020-07-20	8	[{"id_menu":5,"count":1}]	1249	pick-up	0	8
100028	2020-07-20 03:23:06	2020-07-20	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	38620	pick-up	0	26
100029	2020-07-20 03:23:48	2020-07-20	26	[{"id_menu":2,"count":3},{"id_menu":3,"count":1}]	37761	delivery	5	31
100030	2020-07-20 03:35:34	2020-07-20	12	[{"id_menu":1,"count":1}]	26434	delivery	5	17
100031	2020-07-20 03:38:54	2020-07-20	9	[{"id_menu":7,"count":1}]	27018	delivery	5	14
100032	2020-07-20 03:44:35	2020-07-20	8	[{"id_menu":5,"count":1}]	12040	delivery	5	13
100033	2020-07-20 03:48:38	2020-07-20	29	[{"id_menu":3,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	38707	delivery	5	34
100034	2020-07-20 03:52:17	2020-07-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	38637	delivery	5	28
100035	2020-07-20 03:54:34	2020-07-20	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14756	delivery	5	31
100036	2020-07-20 04:01:33	2020-07-20	9	[{"id_menu":6,"count":1}]	2374	pick-up	0	9
100037	2020-07-20 04:01:34	2020-07-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":3}]	28137	pick-up	0	18
100038	2020-07-20 04:06:02	2020-07-20	9	[{"id_menu":6,"count":1}]	15391	delivery	5	14
100039	2020-07-20 04:06:30	2020-07-20	8	[{"id_menu":5,"count":1}]	17141	pick-up	0	8
100040	2020-07-20 04:15:14	2020-07-20	9	[{"id_menu":7,"count":1}]	29988	pick-up	0	9
100041	2020-07-20 04:16:18	2020-07-20	14	[{"id_menu":2,"count":1}]	7848	pick-up	0	14
100042	2020-07-20 04:22:29	2020-07-20	12	[{"id_menu":1,"count":1}]	8640	pick-up	0	12
100043	2020-07-20 04:24:43	2020-07-20	9	[{"id_menu":6,"count":1}]	13134	pick-up	0	9
100044	2020-07-20 04:26:25	2020-07-20	14	[{"id_menu":2,"count":1}]	38733	delivery	5	19
100045	2020-07-20 04:29:30	2020-07-20	17	[{"id_menu":4,"count":1}]	981	pick-up	0	17
100046	2020-07-20 04:33:36	2020-07-20	9	[{"id_menu":7,"count":1}]	38714	delivery	5	14
100047	2020-07-20 04:33:49	2020-07-20	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	31760	delivery	5	40
100048	2020-07-20 04:34:54	2020-07-20	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	24130	delivery	5	40
100049	2020-07-20 04:35:02	2020-07-20	12	[{"id_menu":1,"count":1}]	23450	delivery	5	17
100050	2020-07-20 04:35:13	2020-07-20	9	[{"id_menu":7,"count":1}]	24369	delivery	5	14
100051	2020-07-20 04:38:25	2020-07-20	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	14770	delivery	5	52
100052	2020-07-20 04:39:11	2020-07-20	12	[{"id_menu":1,"count":1}]	25361	delivery	5	17
100053	2020-07-20 04:39:22	2020-07-20	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	38747	delivery	5	26
100054	2020-07-20 04:39:29	2020-07-20	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	38567	delivery	5	26
100055	2020-07-20 04:39:58	2020-07-20	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	21825	pick-up	0	33
100056	2020-07-20 04:41:11	2020-07-20	17	[{"id_menu":4,"count":1}]	33828	pick-up	0	17
100057	2020-07-20 04:46:13	2020-07-20	14	[{"id_menu":2,"count":1}]	11232	pick-up	0	14
100058	2020-07-20 04:49:01	2020-07-20	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	38663	delivery	5	26
100059	2020-07-20 04:51:00	2020-07-20	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	36465	delivery	5	40
100060	2020-07-20 04:56:44	2020-07-20	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	8877	delivery	5	26
100061	2020-07-20 04:59:40	2020-07-20	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	31015	delivery	5	38
100062	2020-07-20 05:06:03	2020-07-20	9	[{"id_menu":6,"count":1}]	26237	delivery	5	14
100063	2020-07-20 05:10:09	2020-07-20	26	[{"id_menu":4,"count":3},{"id_menu":6,"count":1}]	38698	delivery	5	31
100064	2020-07-20 05:13:52	2020-07-20	12	[{"id_menu":1,"count":1}]	38634	delivery	5	17
100065	2020-07-20 05:17:07	2020-07-20	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27124	delivery	5	35
100066	2020-07-20 05:18:47	2020-07-20	8	[{"id_menu":5,"count":1}]	23863	delivery	5	13
100067	2020-07-20 05:19:39	2020-07-20	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	37851	delivery	5	26
100068	2020-07-20 05:21:35	2020-07-20	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	15892	delivery	5	29
100069	2020-07-20 05:26:24	2020-07-20	17	[{"id_menu":4,"count":1}]	36956	delivery	5	22
100070	2020-07-20 05:32:12	2020-07-20	9	[{"id_menu":6,"count":1}]	3452	delivery	5	14
100071	2020-07-20 05:33:16	2020-07-20	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	12425	delivery	5	31
100072	2020-07-20 05:34:52	2020-07-20	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	2648	delivery	5	22
100073	2020-07-20 05:36:22	2020-07-20	12	[{"id_menu":1,"count":1}]	36966	pick-up	0	12
100074	2020-07-20 05:36:46	2020-07-20	9	[{"id_menu":6,"count":1}]	38677	delivery	5	14
100075	2020-07-20 05:36:51	2020-07-20	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	38742	delivery	5	48
100076	2020-07-20 05:37:07	2020-07-20	9	[{"id_menu":7,"count":1}]	38700	delivery	5	14
100077	2020-07-20 05:38:29	2020-07-20	14	[{"id_menu":2,"count":1}]	238	delivery	5	19
100078	2020-07-20 05:38:58	2020-07-20	12	[{"id_menu":3,"count":1}]	23937	delivery	5	17
100079	2020-07-20 05:41:41	2020-07-20	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	10692	pick-up	0	40
100080	2020-07-20 05:50:06	2020-07-20	9	[{"id_menu":7,"count":1}]	36138	delivery	5	14
100081	2020-07-20 05:54:10	2020-07-20	9	[{"id_menu":6,"count":1}]	16852	delivery	5	14
100082	2020-07-20 05:56:36	2020-07-20	29	[{"id_menu":3,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	38670	delivery	5	34
100083	2020-07-20 05:58:10	2020-07-20	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	16943	delivery	5	34
100084	2020-07-20 06:01:32	2020-07-20	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17362	pick-up	0	38
100085	2020-07-20 06:02:20	2020-07-20	12	[{"id_menu":1,"count":1}]	38662	delivery	5	17
100086	2020-07-20 06:02:47	2020-07-20	12	[{"id_menu":1,"count":1}]	37952	delivery	5	17
100087	2020-07-20 06:05:30	2020-07-20	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6023	delivery	5	40
100088	2020-07-20 06:10:01	2020-07-20	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	38706	delivery	5	25
100089	2020-07-20 06:29:13	2020-07-20	17	[{"id_menu":4,"count":1}]	8938	pick-up	0	17
100090	2020-07-20 06:30:11	2020-07-20	9	[{"id_menu":6,"count":1}]	30614	pick-up	0	9
100091	2020-07-20 06:43:18	2020-07-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7968	delivery	5	28
100092	2020-07-20 06:43:35	2020-07-20	9	[{"id_menu":7,"count":1}]	12855	pick-up	0	9
100093	2020-07-20 06:51:27	2020-07-20	12	[{"id_menu":3,"count":1}]	36	delivery	5	17
100094	2020-07-20 06:53:11	2020-07-20	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	16225	delivery	5	44
100095	2020-07-20 06:54:57	2020-07-20	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2735	pick-up	0	31
100096	2020-07-20 07:01:10	2020-07-20	9	[{"id_menu":6,"count":1}]	4072	delivery	5	14
100097	2020-07-20 07:05:41	2020-07-20	17	[{"id_menu":4,"count":1}]	1568	pick-up	0	17
100098	2020-07-20 07:07:51	2020-07-20	14	[{"id_menu":2,"count":1}]	16487	delivery	5	19
100099	2020-07-20 07:08:59	2020-07-20	12	[{"id_menu":1,"count":1}]	38645	delivery	5	17
100100	2020-07-20 07:11:02	2020-07-20	8	[{"id_menu":5,"count":1}]	32571	delivery	5	13
100101	2020-07-20 07:14:12	2020-07-20	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	38717	delivery	5	46
100102	2020-07-20 07:15:15	2020-07-20	17	[{"id_menu":4,"count":1}]	22610	delivery	5	22
100103	2020-07-20 07:18:24	2020-07-20	14	[{"id_menu":2,"count":1}]	38701	delivery	5	19
100104	2020-07-20 07:22:44	2020-07-20	12	[{"id_menu":1,"count":1}]	18658	delivery	5	17
100105	2020-07-20 07:25:24	2020-07-20	9	[{"id_menu":7,"count":1}]	38718	delivery	5	14
100106	2020-07-20 07:26:24	2020-07-20	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	38635	delivery	5	23
100107	2020-07-20 07:26:38	2020-07-20	9	[{"id_menu":6,"count":1}]	141	pick-up	0	9
100108	2020-07-20 07:26:52	2020-07-20	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	12508	delivery	5	27
100109	2020-07-20 07:28:06	2020-07-20	9	[{"id_menu":7,"count":1}]	31374	pick-up	0	9
100110	2020-07-20 07:29:38	2020-07-20	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16450	delivery	5	39
100111	2020-07-20 07:35:41	2020-07-20	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	22564	delivery	5	48
100112	2020-07-20 07:36:19	2020-07-20	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	7098	pick-up	0	35
100113	2020-07-20 07:37:25	2020-07-20	17	[{"id_menu":4,"count":1}]	3353	pick-up	0	17
100114	2020-07-20 07:38:23	2020-07-20	12	[{"id_menu":1,"count":1}]	27141	delivery	5	17
100115	2020-07-20 07:40:58	2020-07-20	12	[{"id_menu":3,"count":1}]	10511	delivery	5	17
100116	2020-07-20 07:47:25	2020-07-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38576	delivery	5	23
100117	2020-07-20 07:49:54	2020-07-20	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	29154	delivery	5	43
100118	2020-07-20 07:52:53	2020-07-20	17	[{"id_menu":4,"count":1}]	28754	delivery	5	22
100119	2020-07-20 08:01:03	2020-07-20	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	16228	pick-up	0	31
100120	2020-07-20 08:07:33	2020-07-20	9	[{"id_menu":7,"count":2}]	38709	delivery	5	14
100121	2020-07-20 08:09:35	2020-07-20	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	23761	delivery	5	26
100122	2020-07-20 08:12:47	2020-07-20	14	[{"id_menu":2,"count":1}]	36004	pick-up	0	14
100123	2020-07-20 08:13:43	2020-07-20	12	[{"id_menu":1,"count":1}]	12552	pick-up	0	12
100124	2020-07-20 08:16:25	2020-07-20	12	[{"id_menu":1,"count":1}]	6825	delivery	5	17
100125	2020-07-20 08:21:31	2020-07-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9640	pick-up	0	23
100126	2020-07-20 08:28:42	2020-07-20	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	16121	delivery	5	26
100127	2020-07-20 08:29:48	2020-07-20	17	[{"id_menu":4,"count":1}]	38624	pick-up	0	17
100128	2020-07-20 08:34:02	2020-07-20	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	22167	delivery	5	34
100129	2020-07-20 08:34:35	2020-07-20	8	[{"id_menu":5,"count":1}]	8600	delivery	5	13
100130	2020-07-20 08:35:08	2020-07-20	9	[{"id_menu":6,"count":1}]	22777	delivery	5	14
100131	2020-07-20 08:36:42	2020-07-20	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	38674	delivery	5	31
100132	2020-07-20 08:42:56	2020-07-20	8	[{"id_menu":5,"count":1}]	24089	delivery	5	13
100133	2020-07-20 08:47:13	2020-07-20	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7760	pick-up	0	17
100134	2020-07-20 09:00:57	2020-07-20	9	[{"id_menu":6,"count":1}]	38590	delivery	5	14
100135	2020-07-20 09:10:02	2020-07-20	9	[{"id_menu":6,"count":1}]	11892	pick-up	0	9
100136	2020-07-20 09:15:02	2020-07-20	9	[{"id_menu":7,"count":1}]	27168	pick-up	0	9
100137	2020-07-20 09:18:19	2020-07-20	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	38723	delivery	5	48
100138	2020-07-20 09:19:30	2020-07-20	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	33560	delivery	5	36
100139	2020-07-20 09:23:48	2020-07-20	17	[{"id_menu":4,"count":1}]	3735	delivery	5	22
100140	2020-07-20 09:29:27	2020-07-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	38630	delivery	5	22
100141	2020-07-20 09:38:19	2020-07-20	12	[{"id_menu":1,"count":1}]	8887	pick-up	0	12
100142	2020-07-20 09:40:16	2020-07-20	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	25606	delivery	5	26
100143	2020-07-20 09:45:00	2020-07-20	9	[{"id_menu":6,"count":1}]	17496	delivery	5	14
100144	2020-07-20 09:49:28	2020-07-20	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	31995	delivery	5	36
100145	2020-07-20 09:52:42	2020-07-20	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	30163	delivery	5	28
100146	2020-07-20 09:58:05	2020-07-20	9	[{"id_menu":7,"count":1}]	4760	pick-up	0	9
100147	2020-07-20 10:03:18	2020-07-20	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	35105	delivery	5	22
100148	2020-07-20 10:07:50	2020-07-20	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	38728	delivery	5	28
100149	2020-07-20 10:09:38	2020-07-20	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	8141	pick-up	0	29
100150	2020-07-20 10:19:31	2020-07-20	17	[{"id_menu":4,"count":1}]	19399	delivery	5	22
100151	2020-07-20 10:22:58	2020-07-20	8	[{"id_menu":5,"count":1}]	19045	delivery	5	13
100152	2020-07-20 10:26:31	2020-07-20	8	[{"id_menu":5,"count":1}]	11503	delivery	5	13
100153	2020-07-20 10:28:35	2020-07-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	26994	delivery	5	28
100154	2020-07-20 10:32:32	2020-07-20	9	[{"id_menu":6,"count":1}]	38573	delivery	5	14
100155	2020-07-20 10:33:49	2020-07-20	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	38577	delivery	5	43
100156	2020-07-20 10:35:30	2020-07-20	9	[{"id_menu":7,"count":1}]	38629	delivery	5	14
100157	2020-07-20 10:35:40	2020-07-20	14	[{"id_menu":2,"count":1}]	38642	delivery	5	19
100158	2020-07-20 10:40:39	2020-07-20	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38568	delivery	5	48
100159	2020-07-20 10:40:52	2020-07-20	8	[{"id_menu":5,"count":1}]	36515	delivery	5	13
100160	2020-07-20 10:41:06	2020-07-20	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	33421	delivery	5	31
100161	2020-07-20 10:45:49	2020-07-20	9	[{"id_menu":6,"count":1}]	37279	delivery	5	14
100162	2020-07-20 10:49:21	2020-07-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	4260	pick-up	0	23
100163	2020-07-20 10:54:24	2020-07-20	9	[{"id_menu":6,"count":1}]	38745	delivery	5	14
100164	2020-07-20 10:58:16	2020-07-20	8	[{"id_menu":5,"count":1}]	23551	delivery	5	13
100165	2020-07-20 11:06:16	2020-07-20	8	[{"id_menu":5,"count":1}]	9198	pick-up	0	8
100166	2020-07-20 11:09:22	2020-07-20	9	[{"id_menu":6,"count":1}]	11732	pick-up	0	9
100167	2020-07-20 11:10:55	2020-07-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	38598	delivery	5	22
100168	2020-07-20 11:11:37	2020-07-20	17	[{"id_menu":4,"count":1}]	16897	delivery	5	22
100169	2020-07-20 11:14:08	2020-07-20	14	[{"id_menu":2,"count":1}]	2438	pick-up	0	14
100170	2020-07-20 11:16:26	2020-07-20	17	[{"id_menu":4,"count":1}]	38646	delivery	5	22
100171	2020-07-20 11:17:30	2020-07-20	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	38592	delivery	5	30
100172	2020-07-20 11:17:34	2020-07-20	12	[{"id_menu":3,"count":1}]	14845	pick-up	0	12
100173	2020-07-20 11:19:16	2020-07-20	17	[{"id_menu":4,"count":2}]	22055	delivery	5	22
100174	2020-07-20 11:19:35	2020-07-20	17	[{"id_menu":4,"count":1}]	38678	delivery	5	22
100175	2020-07-20 11:23:18	2020-07-20	14	[{"id_menu":2,"count":1}]	38583	delivery	5	19
100176	2020-07-20 11:27:10	2020-07-20	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	27306	delivery	5	31
100177	2020-07-20 11:28:46	2020-07-20	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	23257	delivery	5	31
100178	2020-07-20 11:32:07	2020-07-20	9	[{"id_menu":7,"count":1}]	38608	delivery	5	14
100179	2020-07-20 11:33:31	2020-07-20	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	4794	delivery	5	37
100180	2020-07-20 11:34:46	2020-07-20	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	568	delivery	5	34
100181	2020-07-20 11:38:21	2020-07-20	8	[{"id_menu":5,"count":1}]	38735	delivery	5	13
100182	2020-07-20 11:41:11	2020-07-20	12	[{"id_menu":1,"count":1}]	14391	pick-up	0	12
100183	2020-07-20 11:45:27	2020-07-20	38	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3426	pick-up	0	38
100184	2020-07-20 11:47:21	2020-07-20	9	[{"id_menu":7,"count":1}]	25079	delivery	5	14
100185	2020-07-20 11:54:51	2020-07-20	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	38648	delivery	5	23
100186	2020-07-20 11:55:51	2020-07-20	9	[{"id_menu":7,"count":1}]	9093	delivery	5	14
100187	2020-07-20 12:07:29	2020-07-20	9	[{"id_menu":7,"count":1}]	22554	delivery	5	14
100188	2020-07-20 12:08:46	2020-07-20	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	10480	delivery	5	31
100189	2020-07-20 12:08:55	2020-07-20	17	[{"id_menu":4,"count":2}]	216	pick-up	0	17
100190	2020-07-20 12:17:07	2020-07-20	17	[{"id_menu":4,"count":1}]	21472	pick-up	0	17
100191	2020-07-20 12:24:28	2020-07-20	14	[{"id_menu":2,"count":1}]	31641	pick-up	0	14
100192	2020-07-20 12:26:36	2020-07-20	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12865	delivery	5	22
100193	2020-07-20 12:32:34	2020-07-20	8	[{"id_menu":5,"count":1}]	18379	delivery	5	13
100194	2020-07-20 12:33:57	2020-07-20	8	[{"id_menu":5,"count":1}]	38627	delivery	5	13
100195	2020-07-20 12:34:25	2020-07-20	8	[{"id_menu":5,"count":1}]	38734	delivery	5	13
100196	2020-07-20 12:38:12	2020-07-20	12	[{"id_menu":3,"count":1}]	17421	delivery	5	17
100197	2020-07-20 12:45:16	2020-07-20	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	38727	delivery	5	30
100198	2020-07-20 12:45:20	2020-07-20	14	[{"id_menu":2,"count":1}]	29371	delivery	5	19
100199	2020-07-20 12:49:15	2020-07-20	9	[{"id_menu":6,"count":1}]	34441	delivery	5	14
100200	2020-07-20 12:55:14	2020-07-20	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38696	delivery	5	35
100201	2020-07-20 12:59:17	2020-07-20	9	[{"id_menu":6,"count":1}]	15987	pick-up	0	9
100202	2020-07-20 13:06:48	2020-07-20	14	[{"id_menu":2,"count":1}]	531	delivery	5	19
100203	2020-07-20 13:10:42	2020-07-20	12	[{"id_menu":3,"count":1}]	7343	delivery	5	17
100204	2020-07-20 13:12:35	2020-07-20	12	[{"id_menu":3,"count":1}]	19637	delivery	5	17
100205	2020-07-20 13:14:03	2020-07-20	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38748	delivery	5	43
100206	2020-07-20 13:18:23	2020-07-20	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1918	delivery	5	25
100207	2020-07-20 13:20:31	2020-07-20	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	38609	delivery	5	26
100208	2020-07-20 13:24:43	2020-07-20	8	[{"id_menu":5,"count":1}]	38611	delivery	5	13
100209	2020-07-20 13:26:15	2020-07-20	9	[{"id_menu":6,"count":1}]	14284	delivery	5	14
100210	2020-07-20 13:35:51	2020-07-20	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	34812	delivery	5	40
100211	2020-07-20 13:40:23	2020-07-20	9	[{"id_menu":7,"count":1}]	38749	delivery	5	14
100212	2020-07-20 13:45:59	2020-07-20	9	[{"id_menu":7,"count":1}]	38669	delivery	5	14
100213	2020-07-20 13:46:43	2020-07-20	17	[{"id_menu":4,"count":1}]	18147	pick-up	0	17
100214	2020-07-20 13:47:18	2020-07-20	41	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3839	delivery	5	46
100215	2020-07-20 13:47:19	2020-07-20	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4935	delivery	5	40
100216	2020-07-20 13:48:32	2020-07-20	9	[{"id_menu":7,"count":1}]	16608	delivery	5	14
100217	2020-07-20 13:53:21	2020-07-20	17	[{"id_menu":4,"count":2}]	27	delivery	5	22
100218	2020-07-20 14:05:37	2020-07-20	9	[{"id_menu":7,"count":1}]	38713	delivery	5	14
100219	2020-07-20 14:08:04	2020-07-20	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	38655	delivery	5	36
100220	2020-07-20 14:10:47	2020-07-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21064	delivery	5	22
100221	2020-07-20 14:10:57	2020-07-20	8	[{"id_menu":5,"count":1}]	38704	delivery	5	13
100222	2020-07-20 14:11:34	2020-07-20	8	[{"id_menu":5,"count":1}]	32402	pick-up	0	8
100223	2020-07-20 14:15:25	2020-07-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	36025	delivery	5	22
100224	2020-07-20 14:19:51	2020-07-20	12	[{"id_menu":3,"count":1}]	38572	delivery	5	17
100225	2020-07-20 14:22:28	2020-07-20	14	[{"id_menu":2,"count":1}]	24851	pick-up	0	14
100226	2020-07-20 14:22:41	2020-07-20	9	[{"id_menu":6,"count":1}]	19627	delivery	5	14
100227	2020-07-20 14:27:14	2020-07-20	14	[{"id_menu":2,"count":1}]	18456	delivery	5	19
100228	2020-07-20 14:35:45	2020-07-20	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15508	delivery	5	46
100229	2020-07-20 14:39:50	2020-07-20	17	[{"id_menu":4,"count":2}]	11666	delivery	5	22
100230	2020-07-20 14:41:00	2020-07-20	9	[{"id_menu":6,"count":1}]	18093	delivery	5	14
100231	2020-07-20 14:42:43	2020-07-20	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38654	delivery	5	37
100232	2020-07-20 14:44:13	2020-07-20	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	1269	delivery	5	28
100233	2020-07-20 14:45:23	2020-07-20	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21493	delivery	5	39
100234	2020-07-20 14:45:45	2020-07-20	12	[{"id_menu":1,"count":1}]	787	pick-up	0	12
100235	2020-07-20 14:46:08	2020-07-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	21765	delivery	5	28
100236	2020-07-20 14:46:31	2020-07-20	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38578	delivery	5	48
100237	2020-07-20 14:58:04	2020-07-20	17	[{"id_menu":4,"count":1}]	24943	pick-up	0	17
100238	2020-07-20 15:07:37	2020-07-20	9	[{"id_menu":6,"count":1}]	507	delivery	5	14
100239	2020-07-20 15:09:07	2020-07-20	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	5248	pick-up	0	21
100240	2020-07-20 15:17:37	2020-07-20	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	5513	delivery	5	26
100241	2020-07-20 15:20:48	2020-07-20	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	38589	delivery	5	27
100242	2020-07-20 15:24:28	2020-07-20	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	38602	pick-up	0	26
100243	2020-07-20 15:32:05	2020-07-20	9	[{"id_menu":6,"count":1}]	38600	delivery	5	14
100244	2020-07-20 15:35:58	2020-07-20	9	[{"id_menu":6,"count":1}]	4889	pick-up	0	9
100245	2020-07-20 15:36:57	2020-07-20	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38292	delivery	5	49
100246	2020-07-20 15:37:09	2020-07-20	8	[{"id_menu":5,"count":1}]	28748	delivery	5	13
100247	2020-07-20 15:38:20	2020-07-20	9	[{"id_menu":6,"count":1}]	5356	delivery	5	14
100248	2020-07-20 15:39:32	2020-07-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	17674	delivery	5	28
100249	2020-07-20 15:39:54	2020-07-20	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	21121	pick-up	0	26
100250	2020-07-20 15:43:14	2020-07-20	9	[{"id_menu":6,"count":1}]	38683	delivery	5	14
100251	2020-07-20 15:46:12	2020-07-20	9	[{"id_menu":6,"count":1}]	30024	delivery	5	14
100252	2020-07-20 15:48:36	2020-07-20	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31477	delivery	5	49
100253	2020-07-20 15:56:39	2020-07-20	9	[{"id_menu":7,"count":1}]	31829	delivery	5	14
100254	2020-07-20 15:56:40	2020-07-20	9	[{"id_menu":7,"count":1}]	12159	delivery	5	14
100255	2020-07-20 16:01:47	2020-07-20	8	[{"id_menu":5,"count":1}]	38601	pick-up	0	8
100256	2020-07-20 16:01:51	2020-07-20	9	[{"id_menu":6,"count":1}]	38699	delivery	5	14
100257	2020-07-20 16:06:23	2020-07-20	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	38649	delivery	5	39
100258	2020-07-20 16:12:39	2020-07-20	14	[{"id_menu":2,"count":1}]	17623	delivery	5	19
100259	2020-07-20 16:15:17	2020-07-20	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	22568	pick-up	0	21
100260	2020-07-20 16:19:32	2020-07-20	14	[{"id_menu":2,"count":2}]	20183	delivery	5	19
100261	2020-07-20 16:23:52	2020-07-20	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38664	delivery	5	40
100262	2020-07-20 16:27:50	2020-07-20	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	37539	delivery	5	22
100263	2020-07-20 16:28:11	2020-07-20	12	[{"id_menu":1,"count":1}]	38579	delivery	5	17
100264	2020-07-20 16:28:20	2020-07-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	30334	delivery	5	22
100265	2020-07-20 16:30:21	2020-07-20	17	[{"id_menu":4,"count":1}]	38569	delivery	5	22
100266	2020-07-20 16:32:33	2020-07-20	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	11580	delivery	5	29
100267	2020-07-20 16:33:36	2020-07-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	14779	delivery	5	28
100268	2020-07-20 16:41:13	2020-07-20	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	38628	delivery	5	40
100269	2020-07-20 16:54:32	2020-07-20	17	[{"id_menu":4,"count":1}]	16264	pick-up	0	17
100270	2020-07-20 16:57:25	2020-07-20	17	[{"id_menu":4,"count":1}]	1104	pick-up	0	17
100337	2020-07-20 21:29:59	2020-07-20	9	[{"id_menu":7,"count":1}]	23322	delivery	5	14
100271	2020-07-20 16:59:41	2020-07-20	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	11138	delivery	5	52
100272	2020-07-20 17:02:16	2020-07-20	9	[{"id_menu":7,"count":1}]	38697	delivery	5	14
100273	2020-07-20 17:02:34	2020-07-20	12	[{"id_menu":3,"count":1}]	38625	delivery	5	17
100274	2020-07-20 17:09:29	2020-07-20	17	[{"id_menu":4,"count":1}]	35141	delivery	5	22
100275	2020-07-20 17:11:22	2020-07-20	14	[{"id_menu":2,"count":1}]	27107	delivery	5	19
100276	2020-07-20 17:13:05	2020-07-20	9	[{"id_menu":6,"count":1}]	26679	delivery	5	14
100277	2020-07-20 17:13:30	2020-07-20	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	38585	delivery	5	31
100278	2020-07-20 17:16:08	2020-07-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4912	delivery	5	22
100279	2020-07-20 17:17:17	2020-07-20	8	[{"id_menu":5,"count":1}]	34232	delivery	5	13
100280	2020-07-20 17:19:43	2020-07-20	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	38736	delivery	5	48
100281	2020-07-20 17:28:55	2020-07-20	14	[{"id_menu":2,"count":1}]	2056	pick-up	0	14
100282	2020-07-20 17:28:56	2020-07-20	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	38750	pick-up	0	26
100283	2020-07-20 17:36:17	2020-07-20	12	[{"id_menu":3,"count":1}]	38617	delivery	5	17
100284	2020-07-20 17:45:44	2020-07-20	12	[{"id_menu":3,"count":1}]	32219	delivery	5	17
100285	2020-07-20 17:46:21	2020-07-20	12	[{"id_menu":1,"count":1}]	38656	delivery	5	17
100286	2020-07-20 17:48:11	2020-07-20	12	[{"id_menu":1,"count":1}]	36327	delivery	5	17
100287	2020-07-20 17:50:49	2020-07-20	14	[{"id_menu":2,"count":1}]	1088	delivery	5	19
100288	2020-07-20 18:07:03	2020-07-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	18137	delivery	5	28
100289	2020-07-20 18:11:29	2020-07-20	17	[{"id_menu":4,"count":2}]	25571	delivery	5	22
100290	2020-07-20 18:17:11	2020-07-20	9	[{"id_menu":7,"count":1}]	26549	delivery	5	14
100291	2020-07-20 18:23:04	2020-07-20	17	[{"id_menu":4,"count":1}]	34481	delivery	5	22
100292	2020-07-20 18:25:17	2020-07-20	17	[{"id_menu":4,"count":2}]	30629	delivery	5	22
100293	2020-07-20 18:26:47	2020-07-20	17	[{"id_menu":4,"count":2}]	37694	pick-up	0	17
100294	2020-07-20 18:48:28	2020-07-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38622	delivery	5	23
100295	2020-07-20 18:53:16	2020-07-20	9	[{"id_menu":7,"count":1}]	19486	pick-up	0	9
100296	2020-07-20 18:54:28	2020-07-20	8	[{"id_menu":5,"count":1}]	12022	delivery	5	13
100297	2020-07-20 19:01:25	2020-07-20	8	[{"id_menu":5,"count":1}]	35784	pick-up	0	8
100298	2020-07-20 19:03:06	2020-07-20	8	[{"id_menu":5,"count":1}]	30969	delivery	5	13
100299	2020-07-20 19:06:47	2020-07-20	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	34596	delivery	5	44
100300	2020-07-20 19:10:00	2020-07-20	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	38621	delivery	5	48
100301	2020-07-20 19:13:54	2020-07-20	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13000	delivery	5	34
100302	2020-07-20 19:21:58	2020-07-20	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2269	pick-up	0	29
100303	2020-07-20 19:22:08	2020-07-20	9	[{"id_menu":6,"count":1}]	7304	delivery	5	14
100304	2020-07-20 19:27:04	2020-07-20	12	[{"id_menu":1,"count":1}]	33405	delivery	5	17
100305	2020-07-20 19:30:10	2020-07-20	8	[{"id_menu":5,"count":1}]	38712	delivery	5	13
100306	2020-07-20 19:37:05	2020-07-20	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	38732	delivery	5	31
100307	2020-07-20 19:39:06	2020-07-20	9	[{"id_menu":7,"count":1}]	36300	delivery	5	14
100308	2020-07-20 19:43:28	2020-07-20	9	[{"id_menu":6,"count":2}]	22177	delivery	5	14
100309	2020-07-20 19:51:11	2020-07-20	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38682	delivery	5	31
100310	2020-07-20 19:54:47	2020-07-20	9	[{"id_menu":7,"count":1}]	3651	pick-up	0	9
100311	2020-07-20 20:02:36	2020-07-20	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	38694	delivery	5	42
100312	2020-07-20 20:04:50	2020-07-20	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	5629	delivery	5	26
100313	2020-07-20 20:10:52	2020-07-20	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38702	delivery	5	43
100314	2020-07-20 20:14:18	2020-07-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31347	delivery	5	23
100315	2020-07-20 20:14:47	2020-07-20	17	[{"id_menu":4,"count":1}]	38615	delivery	5	22
100316	2020-07-20 20:15:09	2020-07-20	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	23946	pick-up	0	17
100317	2020-07-20 20:17:59	2020-07-20	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	38103	delivery	5	30
100318	2020-07-20 20:21:07	2020-07-20	14	[{"id_menu":2,"count":1}]	38668	delivery	5	19
100319	2020-07-20 20:32:17	2020-07-20	9	[{"id_menu":6,"count":1}]	16010	delivery	5	14
100320	2020-07-20 20:33:57	2020-07-20	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	30229	delivery	5	27
100321	2020-07-20 20:37:32	2020-07-20	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1799	pick-up	0	24
100322	2020-07-20 20:41:22	2020-07-20	17	[{"id_menu":4,"count":1}]	23810	delivery	5	22
100323	2020-07-20 20:41:36	2020-07-20	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13767	pick-up	0	17
100324	2020-07-20 20:45:09	2020-07-20	17	[{"id_menu":4,"count":1}]	38675	delivery	5	22
100325	2020-07-20 20:51:58	2020-07-20	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	38619	delivery	5	43
100326	2020-07-20 20:53:03	2020-07-20	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1383	pick-up	0	26
100327	2020-07-20 20:53:12	2020-07-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33353	delivery	5	23
100328	2020-07-20 20:56:18	2020-07-20	12	[{"id_menu":3,"count":1}]	9509	delivery	5	17
100329	2020-07-20 20:59:32	2020-07-20	9	[{"id_menu":7,"count":1}]	26185	delivery	5	14
100330	2020-07-20 21:04:59	2020-07-20	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	3212	delivery	5	25
100331	2020-07-20 21:05:38	2020-07-20	12	[{"id_menu":3,"count":1}]	12480	delivery	5	17
100332	2020-07-20 21:10:53	2020-07-20	12	[{"id_menu":3,"count":1}]	38647	delivery	5	17
100333	2020-07-20 21:11:44	2020-07-20	9	[{"id_menu":6,"count":1}]	14368	delivery	5	14
100334	2020-07-20 21:11:59	2020-07-20	12	[{"id_menu":1,"count":1}]	204	delivery	5	17
100335	2020-07-20 21:24:52	2020-07-20	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21295	delivery	5	22
100336	2020-07-20 21:29:55	2020-07-20	14	[{"id_menu":2,"count":1}]	7624	pick-up	0	14
100338	2020-07-20 21:30:44	2020-07-20	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38705	delivery	5	37
100339	2020-07-20 21:31:29	2020-07-20	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27344	delivery	5	22
100340	2020-07-20 21:32:35	2020-07-20	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	32767	delivery	5	40
100341	2020-07-20 21:41:32	2020-07-20	8	[{"id_menu":5,"count":1}]	38613	delivery	5	13
100342	2020-07-20 21:42:36	2020-07-20	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8283	delivery	5	43
100343	2020-07-20 21:44:14	2020-07-20	14	[{"id_menu":2,"count":1}]	14480	pick-up	0	14
100344	2020-07-20 21:51:37	2020-07-20	9	[{"id_menu":6,"count":2}]	528	delivery	5	14
100345	2020-07-20 21:54:27	2020-07-20	9	[{"id_menu":6,"count":1}]	38594	delivery	5	14
100346	2020-07-20 21:54:46	2020-07-20	14	[{"id_menu":2,"count":1}]	22639	delivery	5	19
100347	2020-07-20 21:57:50	2020-07-20	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16792	pick-up	0	30
100348	2020-07-20 21:57:51	2020-07-20	14	[{"id_menu":2,"count":1}]	32588	delivery	5	19
100349	2020-07-20 21:58:21	2020-07-20	9	[{"id_menu":7,"count":1}]	38644	delivery	5	14
100350	2020-07-20 22:01:11	2020-07-20	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	5238	pick-up	0	26
100351	2020-07-20 22:08:44	2020-07-20	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	32900	delivery	5	34
100352	2020-07-20 22:08:54	2020-07-20	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	28472	delivery	5	40
100353	2020-07-20 22:09:46	2020-07-20	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	38737	delivery	5	37
100354	2020-07-20 22:10:14	2020-07-20	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	38597	delivery	5	46
100355	2020-07-20 22:24:09	2020-07-20	17	[{"id_menu":4,"count":1}]	15333	delivery	5	22
100356	2020-07-20 22:25:30	2020-07-20	9	[{"id_menu":7,"count":1}]	35325	pick-up	0	9
100357	2020-07-20 22:32:29	2020-07-20	9	[{"id_menu":7,"count":1}]	15927	delivery	5	14
100358	2020-07-20 22:34:13	2020-07-20	9	[{"id_menu":6,"count":2}]	38739	delivery	5	14
100359	2020-07-20 22:40:47	2020-07-20	9	[{"id_menu":6,"count":1}]	12012	delivery	5	14
100360	2020-07-20 22:40:55	2020-07-20	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24069	delivery	5	37
100361	2020-07-20 22:43:26	2020-07-20	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	33813	pick-up	0	26
100362	2020-07-20 22:53:31	2020-07-20	17	[{"id_menu":4,"count":1}]	4682	pick-up	0	17
100363	2020-07-20 22:57:46	2020-07-20	9	[{"id_menu":7,"count":1}]	32492	delivery	5	14
100364	2020-07-20 22:59:13	2020-07-20	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	38657	pick-up	0	41
100365	2020-07-20 23:04:13	2020-07-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	38581	delivery	5	28
100366	2020-07-20 23:05:45	2020-07-20	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	13982	delivery	5	29
100367	2020-07-20 23:06:28	2020-07-20	8	[{"id_menu":5,"count":3}]	23278	delivery	5	13
100368	2020-07-20 23:11:10	2020-07-20	14	[{"id_menu":2,"count":1}]	4298	delivery	5	19
100369	2020-07-20 23:12:41	2020-07-20	8	[{"id_menu":5,"count":1}]	19442	pick-up	0	8
100370	2020-07-20 23:14:14	2020-07-20	9	[{"id_menu":7,"count":1}]	34506	delivery	5	14
100371	2020-07-20 23:14:59	2020-07-20	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	38639	delivery	5	25
100372	2020-07-20 23:27:36	2020-07-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	38633	delivery	5	22
100373	2020-07-20 23:28:00	2020-07-20	9	[{"id_menu":7,"count":2}]	29505	delivery	5	14
100374	2020-07-20 23:31:04	2020-07-20	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	30227	delivery	5	57
100375	2020-07-20 23:33:10	2020-07-20	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12020	delivery	5	43
100376	2020-07-20 23:39:13	2020-07-20	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	38638	delivery	5	48
100377	2020-07-20 23:39:26	2020-07-20	9	[{"id_menu":6,"count":2}]	38610	delivery	5	14
100378	2020-07-20 23:42:57	2020-07-20	8	[{"id_menu":5,"count":1}]	35953	pick-up	0	8
100379	2020-07-20 23:43:31	2020-07-20	8	[{"id_menu":5,"count":1}]	23607	pick-up	0	8
100380	2020-07-20 23:45:16	2020-07-20	8	[{"id_menu":5,"count":1}]	16985	pick-up	0	8
100381	2020-07-20 23:49:50	2020-07-20	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	38729	delivery	5	31
100382	2020-07-20 23:52:48	2020-07-20	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19020	delivery	5	34
100383	2020-07-20 23:53:27	2020-07-20	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38716	delivery	5	37
100384	2020-07-20 23:56:02	2020-07-20	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9132	delivery	5	43
100385	2020-07-20 23:58:55	2020-07-20	9	[{"id_menu":7,"count":1}]	4451	pick-up	0	9
100386	2020-07-20 23:59:51	2020-07-20	9	[{"id_menu":6,"count":1}]	18948	delivery	5	14
100387	2020-07-21 00:02:42	2020-07-21	12	[{"id_menu":1,"count":1}]	32294	delivery	5	17
100388	2020-07-21 00:03:12	2020-07-21	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	5135	delivery	5	22
100389	2020-07-21 00:03:34	2020-07-21	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	17505	delivery	5	31
100390	2020-07-21 00:03:38	2020-07-21	9	[{"id_menu":6,"count":1}]	38799	delivery	5	14
100391	2020-07-21 00:05:43	2020-07-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	35135	delivery	5	22
100392	2020-07-21 00:09:49	2020-07-21	12	[{"id_menu":3,"count":1}]	38844	pick-up	0	12
100393	2020-07-21 00:10:48	2020-07-21	14	[{"id_menu":2,"count":1}]	26580	pick-up	0	14
100394	2020-07-21 00:14:14	2020-07-21	14	[{"id_menu":2,"count":1}]	21464	delivery	5	19
100395	2020-07-21 00:14:21	2020-07-21	17	[{"id_menu":4,"count":1}]	9031	pick-up	0	17
100396	2020-07-21 00:14:58	2020-07-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	38968	delivery	5	28
100397	2020-07-21 00:17:19	2020-07-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":3}]	24630	delivery	5	28
100398	2020-07-21 00:20:00	2020-07-21	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2710	delivery	5	26
100399	2020-07-21 00:22:33	2020-07-21	9	[{"id_menu":6,"count":1}]	9082	delivery	5	14
100400	2020-07-21 00:23:40	2020-07-21	8	[{"id_menu":5,"count":1}]	38990	delivery	5	13
100401	2020-07-21 00:24:10	2020-07-21	14	[{"id_menu":2,"count":1}]	38872	delivery	5	19
100402	2020-07-21 00:24:14	2020-07-21	17	[{"id_menu":4,"count":1}]	743	pick-up	0	17
100403	2020-07-21 00:26:00	2020-07-21	9	[{"id_menu":6,"count":1}]	38923	delivery	5	14
100404	2020-07-21 00:30:10	2020-07-21	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	4060	delivery	5	28
100405	2020-07-21 00:32:24	2020-07-21	8	[{"id_menu":5,"count":1}]	36221	delivery	5	13
100406	2020-07-21 00:42:07	2020-07-21	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5093	delivery	5	31
100407	2020-07-21 00:45:11	2020-07-21	14	[{"id_menu":2,"count":1}]	38921	delivery	5	19
100408	2020-07-21 00:47:52	2020-07-21	17	[{"id_menu":4,"count":1}]	38906	delivery	5	22
100409	2020-07-21 00:48:26	2020-07-21	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	38845	delivery	5	34
100410	2020-07-21 00:51:26	2020-07-21	9	[{"id_menu":6,"count":1}]	38993	delivery	5	14
100411	2020-07-21 00:57:07	2020-07-21	9	[{"id_menu":7,"count":1}]	38984	delivery	5	14
100412	2020-07-21 01:01:20	2020-07-21	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14667	delivery	5	53
100413	2020-07-21 01:03:58	2020-07-21	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	38964	delivery	5	26
100414	2020-07-21 01:04:15	2020-07-21	14	[{"id_menu":2,"count":1}]	6120	pick-up	0	14
100415	2020-07-21 01:04:31	2020-07-21	12	[{"id_menu":3,"count":1}]	9804	delivery	5	17
100416	2020-07-21 01:11:06	2020-07-21	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	29663	delivery	5	30
100417	2020-07-21 01:15:23	2020-07-21	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	11671	delivery	5	31
100418	2020-07-21 01:19:16	2020-07-21	9	[{"id_menu":7,"count":1}]	21308	pick-up	0	9
100419	2020-07-21 01:19:58	2020-07-21	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38801	delivery	5	52
100420	2020-07-21 01:26:33	2020-07-21	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	37555	delivery	5	36
100421	2020-07-21 01:34:08	2020-07-21	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37055	delivery	5	37
100422	2020-07-21 01:35:38	2020-07-21	17	[{"id_menu":4,"count":1}]	4578	pick-up	0	17
100423	2020-07-21 01:40:56	2020-07-21	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	4975	delivery	5	26
100424	2020-07-21 01:41:02	2020-07-21	17	[{"id_menu":4,"count":2}]	29576	delivery	5	22
100425	2020-07-21 01:41:37	2020-07-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	38822	delivery	5	23
100426	2020-07-21 01:41:47	2020-07-21	8	[{"id_menu":5,"count":1}]	12486	delivery	5	13
100427	2020-07-21 01:43:15	2020-07-21	9	[{"id_menu":7,"count":1}]	7186	delivery	5	14
100428	2020-07-21 01:43:30	2020-07-21	8	[{"id_menu":5,"count":1}]	18173	delivery	5	13
100429	2020-07-21 01:46:08	2020-07-21	9	[{"id_menu":6,"count":1}]	10791	delivery	5	14
100430	2020-07-21 01:47:42	2020-07-21	12	[{"id_menu":1,"count":1}]	6439	pick-up	0	12
100431	2020-07-21 01:51:13	2020-07-21	12	[{"id_menu":1,"count":1}]	38812	pick-up	0	12
100432	2020-07-21 01:52:27	2020-07-21	8	[{"id_menu":5,"count":1}]	22424	delivery	5	13
100433	2020-07-21 01:52:38	2020-07-21	9	[{"id_menu":7,"count":1}]	29285	delivery	5	14
100434	2020-07-21 02:04:51	2020-07-21	14	[{"id_menu":2,"count":1}]	38894	delivery	5	19
100435	2020-07-21 02:15:06	2020-07-21	9	[{"id_menu":6,"count":1}]	6338	delivery	5	14
100436	2020-07-21 02:16:57	2020-07-21	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6811	delivery	5	34
100437	2020-07-21 02:20:33	2020-07-21	9	[{"id_menu":7,"count":1}]	9492	delivery	5	14
100438	2020-07-21 02:24:12	2020-07-21	14	[{"id_menu":2,"count":1}]	37720	delivery	5	19
100439	2020-07-21 02:24:31	2020-07-21	9	[{"id_menu":7,"count":1}]	19892	delivery	5	14
100440	2020-07-21 02:25:40	2020-07-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	92	delivery	5	28
100441	2020-07-21 02:26:16	2020-07-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22337	pick-up	0	18
100442	2020-07-21 02:26:49	2020-07-21	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	23785	delivery	5	35
100443	2020-07-21 02:27:09	2020-07-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	13248	delivery	5	31
100444	2020-07-21 02:27:50	2020-07-21	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	28173	delivery	5	30
100445	2020-07-21 02:30:31	2020-07-21	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	38755	delivery	5	43
100446	2020-07-21 02:39:43	2020-07-21	12	[{"id_menu":1,"count":1}]	38821	delivery	5	17
100447	2020-07-21 02:44:59	2020-07-21	12	[{"id_menu":1,"count":1}]	38967	delivery	5	17
100448	2020-07-21 02:50:50	2020-07-21	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	20338	pick-up	0	29
100449	2020-07-21 02:51:43	2020-07-21	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2880	delivery	5	34
100450	2020-07-21 02:51:46	2020-07-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	38989	delivery	5	22
100451	2020-07-21 02:52:39	2020-07-21	9	[{"id_menu":6,"count":1}]	520	pick-up	0	9
100452	2020-07-21 02:56:15	2020-07-21	8	[{"id_menu":5,"count":1}]	5125	pick-up	0	8
100453	2020-07-21 03:04:59	2020-07-21	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	26827	delivery	5	39
100454	2020-07-21 03:05:47	2020-07-21	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	25506	delivery	5	25
100455	2020-07-21 03:07:57	2020-07-21	12	[{"id_menu":3,"count":1}]	36831	pick-up	0	12
100456	2020-07-21 03:09:34	2020-07-21	9	[{"id_menu":6,"count":1}]	30153	pick-up	0	9
100457	2020-07-21 03:09:53	2020-07-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	38885	delivery	5	31
100458	2020-07-21 03:10:09	2020-07-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	16767	delivery	5	28
100459	2020-07-21 03:12:11	2020-07-21	9	[{"id_menu":6,"count":1}]	34674	delivery	5	14
100460	2020-07-21 03:13:58	2020-07-21	9	[{"id_menu":6,"count":1}]	1041	delivery	5	14
100461	2020-07-21 03:18:20	2020-07-21	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5183	delivery	5	45
100462	2020-07-21 03:22:19	2020-07-21	12	[{"id_menu":1,"count":1}]	38854	delivery	5	17
100463	2020-07-21 03:24:12	2020-07-21	9	[{"id_menu":6,"count":1}]	16746	delivery	5	14
100464	2020-07-21 03:31:48	2020-07-21	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":2}]	38912	pick-up	0	23
100465	2020-07-21 03:33:56	2020-07-21	8	[{"id_menu":5,"count":1}]	38927	delivery	5	13
100466	2020-07-21 03:34:00	2020-07-21	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	12188	delivery	5	34
100467	2020-07-21 03:35:49	2020-07-21	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	23863	delivery	5	30
100468	2020-07-21 03:37:33	2020-07-21	8	[{"id_menu":5,"count":1}]	11601	pick-up	0	8
100469	2020-07-21 03:38:17	2020-07-21	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	38776	delivery	5	34
100470	2020-07-21 03:40:00	2020-07-21	14	[{"id_menu":2,"count":1}]	32575	delivery	5	19
100471	2020-07-21 03:41:49	2020-07-21	17	[{"id_menu":4,"count":1}]	31950	pick-up	0	17
100472	2020-07-21 03:47:55	2020-07-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28375	delivery	5	22
100473	2020-07-21 03:49:42	2020-07-21	14	[{"id_menu":2,"count":1}]	7613	delivery	5	19
100474	2020-07-21 03:50:23	2020-07-21	9	[{"id_menu":6,"count":1}]	38961	delivery	5	14
100475	2020-07-21 03:50:31	2020-07-21	9	[{"id_menu":6,"count":1}]	29847	delivery	5	14
100476	2020-07-21 03:54:11	2020-07-21	8	[{"id_menu":5,"count":1}]	9564	delivery	5	13
100477	2020-07-21 03:54:11	2020-07-21	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	38842	delivery	5	25
100478	2020-07-21 03:55:08	2020-07-21	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33593	delivery	5	35
100479	2020-07-21 03:57:25	2020-07-21	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	35806	pick-up	0	31
100480	2020-07-21 04:04:01	2020-07-21	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3314	pick-up	0	38
100481	2020-07-21 04:12:38	2020-07-21	8	[{"id_menu":5,"count":1}]	38930	delivery	5	13
100482	2020-07-21 04:13:28	2020-07-21	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	38780	delivery	5	40
100483	2020-07-21 04:18:58	2020-07-21	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25952	delivery	5	35
100484	2020-07-21 04:21:12	2020-07-21	12	[{"id_menu":3,"count":1}]	33623	delivery	5	17
100485	2020-07-21 04:31:53	2020-07-21	29	[{"id_menu":3,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	38916	delivery	5	34
100486	2020-07-21 04:31:54	2020-07-21	17	[{"id_menu":4,"count":2}]	11732	pick-up	0	17
100487	2020-07-21 04:32:21	2020-07-21	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	32256	delivery	5	31
100488	2020-07-21 04:33:23	2020-07-21	17	[{"id_menu":4,"count":1}]	31102	delivery	5	22
100489	2020-07-21 04:38:09	2020-07-21	12	[{"id_menu":1,"count":1}]	38751	delivery	5	17
100490	2020-07-21 04:40:31	2020-07-21	17	[{"id_menu":4,"count":2}]	38865	delivery	5	22
100491	2020-07-21 04:51:53	2020-07-21	9	[{"id_menu":6,"count":1}]	19883	delivery	5	14
100492	2020-07-21 04:53:48	2020-07-21	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38757	delivery	5	37
100493	2020-07-21 04:59:07	2020-07-21	12	[{"id_menu":3,"count":1}]	30036	delivery	5	17
100494	2020-07-21 04:59:50	2020-07-21	14	[{"id_menu":2,"count":1}]	38814	delivery	5	19
100495	2020-07-21 05:00:39	2020-07-21	9	[{"id_menu":7,"count":1}]	38897	pick-up	0	9
100496	2020-07-21 05:04:46	2020-07-21	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	38858	delivery	5	40
100497	2020-07-21 05:07:31	2020-07-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8750	delivery	5	31
100498	2020-07-21 05:08:00	2020-07-21	9	[{"id_menu":6,"count":1}]	8654	delivery	5	14
100499	2020-07-21 05:08:54	2020-07-21	14	[{"id_menu":2,"count":1}]	22244	delivery	5	19
100500	2020-07-21 05:10:44	2020-07-21	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	7459	delivery	5	26
100501	2020-07-21 05:15:08	2020-07-21	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	38907	delivery	5	26
100502	2020-07-21 05:16:11	2020-07-21	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37641	delivery	5	52
100503	2020-07-21 05:22:33	2020-07-21	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	6591	pick-up	0	26
100504	2020-07-21 05:26:13	2020-07-21	12	[{"id_menu":3,"count":1}]	31082	delivery	5	17
100505	2020-07-21 05:32:38	2020-07-21	9	[{"id_menu":6,"count":1}]	38840	delivery	5	14
100506	2020-07-21 05:33:03	2020-07-21	14	[{"id_menu":2,"count":1}]	27992	pick-up	0	14
100507	2020-07-21 05:33:06	2020-07-21	14	[{"id_menu":2,"count":1}]	36403	delivery	5	19
100508	2020-07-21 05:33:33	2020-07-21	9	[{"id_menu":6,"count":1}]	34050	delivery	5	14
100509	2020-07-21 05:47:56	2020-07-21	9	[{"id_menu":6,"count":1}]	30014	delivery	5	14
100510	2020-07-21 05:49:21	2020-07-21	9	[{"id_menu":7,"count":1}]	3240	delivery	5	14
100511	2020-07-21 05:54:33	2020-07-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18923	delivery	5	22
100512	2020-07-21 05:56:48	2020-07-21	8	[{"id_menu":5,"count":2}]	38970	delivery	5	13
100513	2020-07-21 05:57:01	2020-07-21	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	38866	delivery	5	31
100514	2020-07-21 06:00:17	2020-07-21	14	[{"id_menu":2,"count":1}]	35052	delivery	5	19
100515	2020-07-21 06:02:57	2020-07-21	9	[{"id_menu":7,"count":2}]	38920	delivery	5	14
100516	2020-07-21 06:05:17	2020-07-21	8	[{"id_menu":5,"count":1}]	17835	delivery	5	13
100517	2020-07-21 06:08:48	2020-07-21	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	38873	delivery	5	42
100518	2020-07-21 06:10:17	2020-07-21	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	38965	delivery	5	23
100519	2020-07-21 06:11:00	2020-07-21	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	22212	delivery	5	26
100520	2020-07-21 06:14:43	2020-07-21	9	[{"id_menu":7,"count":1}]	13941	delivery	5	14
100521	2020-07-21 06:15:05	2020-07-21	14	[{"id_menu":2,"count":1}]	4100	delivery	5	19
100522	2020-07-21 06:15:51	2020-07-21	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	3109	pick-up	0	21
100523	2020-07-21 06:17:00	2020-07-21	12	[{"id_menu":3,"count":1}]	17970	delivery	5	17
100524	2020-07-21 06:17:32	2020-07-21	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	10281	pick-up	0	20
100525	2020-07-21 06:19:26	2020-07-21	14	[{"id_menu":2,"count":1}]	26621	delivery	5	19
100526	2020-07-21 06:19:36	2020-07-21	12	[{"id_menu":3,"count":1}]	4293	delivery	5	17
100527	2020-07-21 06:19:37	2020-07-21	9	[{"id_menu":6,"count":1}]	14256	delivery	5	14
100528	2020-07-21 06:24:15	2020-07-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30472	delivery	5	23
100529	2020-07-21 06:26:51	2020-07-21	17	[{"id_menu":4,"count":1}]	4594	delivery	5	22
100530	2020-07-21 06:28:09	2020-07-21	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3106	delivery	5	48
100531	2020-07-21 06:28:11	2020-07-21	9	[{"id_menu":6,"count":1}]	2678	delivery	5	14
100532	2020-07-21 06:28:26	2020-07-21	12	[{"id_menu":1,"count":1}]	38999	delivery	5	17
100533	2020-07-21 06:30:06	2020-07-21	9	[{"id_menu":6,"count":2}]	38975	delivery	5	14
100534	2020-07-21 06:30:32	2020-07-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20553	delivery	5	22
100535	2020-07-21 06:31:40	2020-07-21	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	4655	delivery	5	36
100536	2020-07-21 06:33:23	2020-07-21	9	[{"id_menu":7,"count":1}]	14558	pick-up	0	9
100537	2020-07-21 06:36:15	2020-07-21	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26473	delivery	5	52
100538	2020-07-21 06:37:45	2020-07-21	17	[{"id_menu":4,"count":1}]	16586	delivery	5	22
100539	2020-07-21 06:42:56	2020-07-21	12	[{"id_menu":1,"count":1}]	9629	pick-up	0	12
100540	2020-07-21 06:43:52	2020-07-21	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	38949	delivery	5	31
100541	2020-07-21 06:44:58	2020-07-21	17	[{"id_menu":4,"count":1}]	344	pick-up	0	17
100542	2020-07-21 06:45:28	2020-07-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	9379	delivery	5	28
100543	2020-07-21 06:51:04	2020-07-21	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	33900	delivery	5	25
100544	2020-07-21 06:52:47	2020-07-21	9	[{"id_menu":7,"count":1}]	33998	delivery	5	14
100545	2020-07-21 06:59:11	2020-07-21	12	[{"id_menu":3,"count":1}]	38580	pick-up	0	12
100546	2020-07-21 07:10:28	2020-07-21	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	38788	delivery	5	29
100547	2020-07-21 07:11:46	2020-07-21	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2443	delivery	5	26
100548	2020-07-21 07:13:07	2020-07-21	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	38879	pick-up	0	26
100549	2020-07-21 07:13:50	2020-07-21	12	[{"id_menu":1,"count":1}]	4041	pick-up	0	12
100550	2020-07-21 07:19:37	2020-07-21	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	38802	delivery	5	40
100551	2020-07-21 07:22:49	2020-07-21	12	[{"id_menu":1,"count":1}]	25997	pick-up	0	12
100552	2020-07-21 07:23:35	2020-07-21	17	[{"id_menu":4,"count":1}]	38836	delivery	5	22
100553	2020-07-21 07:24:13	2020-07-21	9	[{"id_menu":6,"count":1}]	17577	delivery	5	14
100554	2020-07-21 07:29:41	2020-07-21	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	932	delivery	5	23
100555	2020-07-21 07:31:11	2020-07-21	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	5410	pick-up	0	20
100556	2020-07-21 07:31:27	2020-07-21	9	[{"id_menu":7,"count":1}]	8097	delivery	5	14
100557	2020-07-21 07:33:24	2020-07-21	8	[{"id_menu":5,"count":1}]	3133	delivery	5	13
100558	2020-07-21 07:36:01	2020-07-21	9	[{"id_menu":7,"count":1}]	26299	delivery	5	14
100559	2020-07-21 07:37:50	2020-07-21	9	[{"id_menu":7,"count":1}]	38142	delivery	5	14
100560	2020-07-21 07:38:14	2020-07-21	17	[{"id_menu":4,"count":3}]	38808	delivery	5	22
100561	2020-07-21 07:38:35	2020-07-21	12	[{"id_menu":3,"count":1}]	38806	delivery	5	17
100562	2020-07-21 07:40:33	2020-07-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":3}]	21024	delivery	5	23
100563	2020-07-21 07:43:49	2020-07-21	9	[{"id_menu":6,"count":1}]	33716	delivery	5	14
100564	2020-07-21 07:45:43	2020-07-21	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	38850	delivery	5	51
100565	2020-07-21 07:50:32	2020-07-21	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	36819	delivery	5	25
100566	2020-07-21 07:51:08	2020-07-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	36458	pick-up	0	17
100567	2020-07-21 07:52:53	2020-07-21	9	[{"id_menu":6,"count":1}]	37770	delivery	5	14
100568	2020-07-21 07:58:16	2020-07-21	9	[{"id_menu":6,"count":1}]	5104	delivery	5	14
100569	2020-07-21 08:03:23	2020-07-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	10458	delivery	5	28
100570	2020-07-21 08:03:43	2020-07-21	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	28652	pick-up	0	29
100571	2020-07-21 08:14:57	2020-07-21	8	[{"id_menu":5,"count":1}]	38824	delivery	5	13
100572	2020-07-21 08:15:36	2020-07-21	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	38936	delivery	5	34
100573	2020-07-21 08:18:19	2020-07-21	9	[{"id_menu":7,"count":1}]	16042	delivery	5	14
100574	2020-07-21 08:18:24	2020-07-21	17	[{"id_menu":4,"count":1}]	2492	pick-up	0	17
100575	2020-07-21 08:19:46	2020-07-21	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	38785	delivery	5	55
100576	2020-07-21 08:22:49	2020-07-21	14	[{"id_menu":2,"count":1}]	31764	delivery	5	19
100577	2020-07-21 08:24:08	2020-07-21	17	[{"id_menu":4,"count":1}]	30459	delivery	5	22
100578	2020-07-21 08:24:40	2020-07-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	32506	delivery	5	22
100579	2020-07-21 08:33:10	2020-07-21	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7110	delivery	5	42
100580	2020-07-21 08:37:01	2020-07-21	12	[{"id_menu":1,"count":1}]	11262	pick-up	0	12
100581	2020-07-21 08:38:19	2020-07-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38895	delivery	5	23
100582	2020-07-21 08:42:46	2020-07-21	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	29754	delivery	5	31
100583	2020-07-21 08:42:55	2020-07-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	38778	delivery	5	28
100584	2020-07-21 08:45:00	2020-07-21	9	[{"id_menu":6,"count":1}]	25311	delivery	5	14
100585	2020-07-21 08:46:46	2020-07-21	12	[{"id_menu":1,"count":1}]	38934	delivery	5	17
100586	2020-07-21 08:47:35	2020-07-21	9	[{"id_menu":6,"count":1}]	405	delivery	5	14
100587	2020-07-21 08:55:12	2020-07-21	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	38974	delivery	5	28
100588	2020-07-21 08:59:56	2020-07-21	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25876	delivery	5	40
100589	2020-07-21 09:01:40	2020-07-21	17	[{"id_menu":4,"count":1}]	5026	delivery	5	22
100590	2020-07-21 09:04:13	2020-07-21	12	[{"id_menu":1,"count":1}]	1641	delivery	5	17
100591	2020-07-21 09:13:40	2020-07-21	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	3115	delivery	5	25
100592	2020-07-21 09:15:35	2020-07-21	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	13444	delivery	5	26
100593	2020-07-21 09:17:27	2020-07-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38869	delivery	5	23
100594	2020-07-21 09:18:18	2020-07-21	9	[{"id_menu":7,"count":1}]	22187	delivery	5	14
100595	2020-07-21 09:19:29	2020-07-21	9	[{"id_menu":7,"count":1}]	19639	delivery	5	14
100596	2020-07-21 09:22:37	2020-07-21	14	[{"id_menu":2,"count":1}]	34174	delivery	5	19
100597	2020-07-21 09:24:47	2020-07-21	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38763	delivery	5	49
100598	2020-07-21 09:26:07	2020-07-21	9	[{"id_menu":7,"count":1}]	38831	delivery	5	14
100599	2020-07-21 09:31:58	2020-07-21	14	[{"id_menu":2,"count":1}]	1993	pick-up	0	14
100600	2020-07-21 09:39:25	2020-07-21	9	[{"id_menu":7,"count":1}]	16709	delivery	5	14
100601	2020-07-21 09:41:59	2020-07-21	9	[{"id_menu":6,"count":1}]	381	pick-up	0	9
100602	2020-07-21 09:43:54	2020-07-21	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	14606	delivery	5	25
100603	2020-07-21 09:48:24	2020-07-21	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	36097	delivery	5	26
100604	2020-07-21 09:50:56	2020-07-21	9	[{"id_menu":6,"count":1}]	36113	delivery	5	14
100605	2020-07-21 09:51:33	2020-07-21	17	[{"id_menu":4,"count":1}]	14010	pick-up	0	17
100606	2020-07-21 09:51:42	2020-07-21	12	[{"id_menu":1,"count":1}]	1115	pick-up	0	12
100607	2020-07-21 09:54:00	2020-07-21	12	[{"id_menu":1,"count":1}]	2728	delivery	5	17
100608	2020-07-21 09:55:34	2020-07-21	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":3}]	10630	delivery	5	26
100609	2020-07-21 09:55:47	2020-07-21	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	38898	delivery	5	56
100610	2020-07-21 09:56:06	2020-07-21	12	[{"id_menu":1,"count":1}]	38752	delivery	5	17
100611	2020-07-21 10:02:21	2020-07-21	12	[{"id_menu":3,"count":1}]	4223	delivery	5	17
100612	2020-07-21 10:03:58	2020-07-21	8	[{"id_menu":5,"count":1}]	16754	delivery	5	13
100613	2020-07-21 10:11:56	2020-07-21	8	[{"id_menu":5,"count":1}]	18957	delivery	5	13
100614	2020-07-21 10:13:44	2020-07-21	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	38939	delivery	5	36
100615	2020-07-21 10:14:34	2020-07-21	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1564	pick-up	0	26
100616	2020-07-21 10:18:28	2020-07-21	12	[{"id_menu":3,"count":1}]	31033	delivery	5	17
100617	2020-07-21 10:23:12	2020-07-21	12	[{"id_menu":3,"count":1}]	8511	delivery	5	17
100618	2020-07-21 10:26:09	2020-07-21	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	5257	pick-up	0	34
100619	2020-07-21 10:36:34	2020-07-21	8	[{"id_menu":5,"count":1}]	1657	pick-up	0	8
100620	2020-07-21 10:38:02	2020-07-21	12	[{"id_menu":3,"count":1}]	38877	delivery	5	17
100621	2020-07-21 10:42:25	2020-07-21	14	[{"id_menu":2,"count":1}]	13171	delivery	5	19
100622	2020-07-21 10:47:50	2020-07-21	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	38948	pick-up	0	31
100623	2020-07-21 10:48:22	2020-07-21	14	[{"id_menu":2,"count":1}]	38951	delivery	5	19
100624	2020-07-21 10:52:16	2020-07-21	14	[{"id_menu":2,"count":1}]	38867	delivery	5	19
100625	2020-07-21 10:58:49	2020-07-21	9	[{"id_menu":6,"count":1}]	38929	delivery	5	14
100626	2020-07-21 11:00:49	2020-07-21	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38794	delivery	5	37
100627	2020-07-21 11:01:05	2020-07-21	12	[{"id_menu":1,"count":1}]	6410	pick-up	0	12
100628	2020-07-21 11:01:09	2020-07-21	12	[{"id_menu":3,"count":1}]	38928	delivery	5	17
100629	2020-07-21 11:02:48	2020-07-21	8	[{"id_menu":5,"count":1}]	38890	delivery	5	13
100630	2020-07-21 11:03:28	2020-07-21	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	14710	pick-up	0	21
100631	2020-07-21 11:05:43	2020-07-21	9	[{"id_menu":6,"count":1}]	38769	delivery	5	14
100632	2020-07-21 11:06:55	2020-07-21	14	[{"id_menu":2,"count":1}]	27287	delivery	5	19
100633	2020-07-21 11:10:29	2020-07-21	17	[{"id_menu":4,"count":1}]	38998	delivery	5	22
100634	2020-07-21 11:12:06	2020-07-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	38899	delivery	5	22
100635	2020-07-21 11:12:43	2020-07-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13507	delivery	5	23
100636	2020-07-21 11:16:01	2020-07-21	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	30484	delivery	5	26
100637	2020-07-21 11:16:06	2020-07-21	9	[{"id_menu":7,"count":1}]	35409	delivery	5	14
100638	2020-07-21 11:16:37	2020-07-21	17	[{"id_menu":4,"count":1}]	213	pick-up	0	17
100639	2020-07-21 11:16:49	2020-07-21	14	[{"id_menu":2,"count":1}]	20450	pick-up	0	14
100640	2020-07-21 11:17:24	2020-07-21	12	[{"id_menu":3,"count":1}]	7919	pick-up	0	12
100641	2020-07-21 11:20:11	2020-07-21	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	38976	delivery	5	26
100642	2020-07-21 11:20:28	2020-07-21	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	38646	delivery	5	39
100643	2020-07-21 11:20:37	2020-07-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	31165	delivery	5	28
100644	2020-07-21 11:21:42	2020-07-21	12	[{"id_menu":1,"count":1}]	2868	delivery	5	17
100645	2020-07-21 11:25:11	2020-07-21	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	33119	pick-up	0	41
100646	2020-07-21 11:25:47	2020-07-21	8	[{"id_menu":5,"count":1}]	38977	delivery	5	13
100647	2020-07-21 11:26:05	2020-07-21	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3250	delivery	5	37
100648	2020-07-21 11:27:06	2020-07-21	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	38887	delivery	5	27
100649	2020-07-21 11:28:09	2020-07-21	12	[{"id_menu":1,"count":1}]	20	pick-up	0	12
100650	2020-07-21 11:28:31	2020-07-21	8	[{"id_menu":5,"count":1}]	29691	delivery	5	13
100651	2020-07-21 11:28:58	2020-07-21	17	[{"id_menu":4,"count":1}]	23411	pick-up	0	17
100652	2020-07-21 11:32:00	2020-07-21	17	[{"id_menu":4,"count":1}]	311	delivery	5	22
100653	2020-07-21 11:34:57	2020-07-21	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38819	delivery	5	40
100654	2020-07-21 11:38:45	2020-07-21	9	[{"id_menu":6,"count":1}]	31172	delivery	5	14
100655	2020-07-21 11:39:24	2020-07-21	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	38810	delivery	5	31
100656	2020-07-21 11:39:37	2020-07-21	12	[{"id_menu":3,"count":1}]	12536	delivery	5	17
100657	2020-07-21 11:43:07	2020-07-21	9	[{"id_menu":7,"count":1}]	36802	delivery	5	14
100658	2020-07-21 11:43:32	2020-07-21	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2549	pick-up	0	20
100659	2020-07-21 11:47:51	2020-07-21	9	[{"id_menu":7,"count":1}]	5281	pick-up	0	9
100660	2020-07-21 11:50:50	2020-07-21	8	[{"id_menu":5,"count":1}]	10598	delivery	5	13
100661	2020-07-21 11:52:12	2020-07-21	9	[{"id_menu":6,"count":2}]	5206	delivery	5	14
100662	2020-07-21 11:53:34	2020-07-21	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	225	pick-up	0	26
100663	2020-07-21 12:04:04	2020-07-21	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6880	delivery	5	34
100664	2020-07-21 12:07:45	2020-07-21	17	[{"id_menu":4,"count":1}]	38938	delivery	5	22
100665	2020-07-21 12:12:55	2020-07-21	12	[{"id_menu":1,"count":1}]	30793	delivery	5	17
100666	2020-07-21 12:16:29	2020-07-21	14	[{"id_menu":2,"count":1}]	38962	pick-up	0	14
100667	2020-07-21 12:18:48	2020-07-21	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	18922	delivery	5	43
100668	2020-07-21 12:20:09	2020-07-21	9	[{"id_menu":6,"count":1}]	22477	pick-up	0	9
100669	2020-07-21 12:23:29	2020-07-21	9	[{"id_menu":6,"count":2}]	38952	delivery	5	14
100670	2020-07-21 12:25:22	2020-07-21	12	[{"id_menu":1,"count":1}]	8311	delivery	5	17
100671	2020-07-21 12:26:26	2020-07-21	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	19798	delivery	5	26
100672	2020-07-21 12:29:42	2020-07-21	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	32204	delivery	5	40
100673	2020-07-21 12:29:47	2020-07-21	17	[{"id_menu":4,"count":1}]	527	pick-up	0	17
100674	2020-07-21 12:36:00	2020-07-21	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	36045	delivery	5	46
100675	2020-07-21 12:39:10	2020-07-21	14	[{"id_menu":2,"count":1}]	38767	delivery	5	19
100676	2020-07-21 12:41:01	2020-07-21	14	[{"id_menu":2,"count":1}]	14027	pick-up	0	14
100677	2020-07-21 12:44:57	2020-07-21	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	38813	delivery	5	25
100678	2020-07-21 12:47:13	2020-07-21	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	8900	pick-up	0	32
100679	2020-07-21 12:48:07	2020-07-21	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	38941	delivery	5	40
100680	2020-07-21 12:51:49	2020-07-21	14	[{"id_menu":2,"count":1}]	38988	delivery	5	19
100681	2020-07-21 12:54:03	2020-07-21	8	[{"id_menu":5,"count":1}]	14903	pick-up	0	8
100682	2020-07-21 12:58:37	2020-07-21	38	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	26112	delivery	5	43
100683	2020-07-21 12:59:16	2020-07-21	8	[{"id_menu":5,"count":1}]	27691	delivery	5	13
100684	2020-07-21 12:59:57	2020-07-21	9	[{"id_menu":6,"count":1}]	16261	delivery	5	14
100685	2020-07-21 13:06:28	2020-07-21	8	[{"id_menu":5,"count":1}]	30796	delivery	5	13
100686	2020-07-21 13:08:55	2020-07-21	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33813	delivery	5	31
100687	2020-07-21 13:09:31	2020-07-21	12	[{"id_menu":3,"count":1}]	24069	delivery	5	17
100688	2020-07-21 13:11:30	2020-07-21	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	38827	delivery	5	31
100689	2020-07-21 13:12:41	2020-07-21	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35581	delivery	5	37
100690	2020-07-21 13:13:34	2020-07-21	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	30722	delivery	5	23
100691	2020-07-21 13:14:08	2020-07-21	17	[{"id_menu":4,"count":1}]	7481	pick-up	0	17
100692	2020-07-21 13:15:00	2020-07-21	17	[{"id_menu":4,"count":1}]	25214	delivery	5	22
100693	2020-07-21 13:18:06	2020-07-21	17	[{"id_menu":4,"count":1}]	29541	pick-up	0	17
100694	2020-07-21 13:22:30	2020-07-21	12	[{"id_menu":1,"count":1}]	38901	delivery	5	17
100695	2020-07-21 13:28:40	2020-07-21	9	[{"id_menu":6,"count":1}]	17815	delivery	5	14
100696	2020-07-21 13:28:51	2020-07-21	17	[{"id_menu":4,"count":1}]	23267	delivery	5	22
100697	2020-07-21 13:29:55	2020-07-21	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	15127	delivery	5	26
100698	2020-07-21 13:32:05	2020-07-21	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8397	delivery	5	39
100699	2020-07-21 13:37:44	2020-07-21	14	[{"id_menu":2,"count":1}]	38868	delivery	5	19
100700	2020-07-21 13:39:36	2020-07-21	9	[{"id_menu":7,"count":1}]	10753	delivery	5	14
100701	2020-07-21 13:45:02	2020-07-21	17	[{"id_menu":4,"count":1}]	35479	delivery	5	22
100702	2020-07-21 13:50:37	2020-07-21	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38792	delivery	5	40
100703	2020-07-21 13:54:50	2020-07-21	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13471	delivery	5	36
100704	2020-07-21 13:54:55	2020-07-21	34	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	24694	delivery	5	39
100705	2020-07-21 14:00:04	2020-07-21	9	[{"id_menu":6,"count":1}]	38771	pick-up	0	9
100706	2020-07-21 14:01:23	2020-07-21	9	[{"id_menu":7,"count":1}]	38944	delivery	5	14
100707	2020-07-21 14:05:02	2020-07-21	12	[{"id_menu":1,"count":1}]	38756	delivery	5	17
100708	2020-07-21 14:06:16	2020-07-21	14	[{"id_menu":2,"count":1}]	31006	pick-up	0	14
100709	2020-07-21 14:07:48	2020-07-21	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	10558	delivery	5	45
100710	2020-07-21 14:13:18	2020-07-21	12	[{"id_menu":3,"count":1}]	23921	delivery	5	17
100711	2020-07-21 14:13:54	2020-07-21	17	[{"id_menu":4,"count":1}]	38793	delivery	5	22
100712	2020-07-21 14:14:01	2020-07-21	14	[{"id_menu":2,"count":1}]	38882	delivery	5	19
100713	2020-07-21 14:19:05	2020-07-21	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	30753	delivery	5	36
100714	2020-07-21 14:19:35	2020-07-21	34	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	7261	delivery	5	39
100715	2020-07-21 14:20:13	2020-07-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	38851	pick-up	0	23
100716	2020-07-21 14:23:51	2020-07-21	17	[{"id_menu":4,"count":1}]	4094	pick-up	0	17
100717	2020-07-21 14:24:41	2020-07-21	14	[{"id_menu":2,"count":1}]	21540	delivery	5	19
100718	2020-07-21 14:27:11	2020-07-21	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	33100	delivery	5	27
100719	2020-07-21 14:27:41	2020-07-21	8	[{"id_menu":5,"count":1}]	19332	delivery	5	13
100720	2020-07-21 14:30:53	2020-07-21	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	506	delivery	5	28
100721	2020-07-21 14:31:57	2020-07-21	17	[{"id_menu":4,"count":1}]	10200	delivery	5	22
100722	2020-07-21 14:35:47	2020-07-21	12	[{"id_menu":1,"count":1}]	9097	pick-up	0	12
100723	2020-07-21 14:36:21	2020-07-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	38891	delivery	5	22
100724	2020-07-21 14:37:52	2020-07-21	17	[{"id_menu":4,"count":1}]	389	pick-up	0	17
100725	2020-07-21 14:38:18	2020-07-21	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	7299	delivery	5	26
100726	2020-07-21 14:45:24	2020-07-21	17	[{"id_menu":4,"count":1}]	2776	pick-up	0	17
100727	2020-07-21 14:45:25	2020-07-21	9	[{"id_menu":6,"count":1}]	13110	pick-up	0	9
100728	2020-07-21 14:51:22	2020-07-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38892	delivery	5	23
100729	2020-07-21 14:52:50	2020-07-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	25658	delivery	5	28
100730	2020-07-21 14:54:17	2020-07-21	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	38839	delivery	5	22
100731	2020-07-21 14:54:41	2020-07-21	9	[{"id_menu":6,"count":1}]	20247	delivery	5	14
100732	2020-07-21 15:00:39	2020-07-21	8	[{"id_menu":5,"count":1}]	26091	delivery	5	13
100733	2020-07-21 15:09:03	2020-07-21	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	38761	delivery	5	34
100734	2020-07-21 15:12:22	2020-07-21	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26767	delivery	5	48
100735	2020-07-21 15:13:30	2020-07-21	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	36990	delivery	5	43
100736	2020-07-21 15:17:00	2020-07-21	12	[{"id_menu":3,"count":1}]	3168	pick-up	0	12
100737	2020-07-21 15:18:13	2020-07-21	12	[{"id_menu":3,"count":1}]	38909	delivery	5	17
100738	2020-07-21 15:20:10	2020-07-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17196	delivery	5	31
100739	2020-07-21 15:21:14	2020-07-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	38790	delivery	5	31
100740	2020-07-21 15:21:15	2020-07-21	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	26087	delivery	5	37
100741	2020-07-21 15:21:35	2020-07-21	9	[{"id_menu":7,"count":1}]	17913	delivery	5	14
100742	2020-07-21 15:23:50	2020-07-21	17	[{"id_menu":4,"count":1}]	37804	delivery	5	22
100743	2020-07-21 15:26:40	2020-07-21	9	[{"id_menu":7,"count":1}]	6174	delivery	5	14
100744	2020-07-21 15:27:33	2020-07-21	9	[{"id_menu":6,"count":1}]	10499	delivery	5	14
100745	2020-07-21 15:29:21	2020-07-21	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	38860	delivery	5	39
100746	2020-07-21 15:34:20	2020-07-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	38781	delivery	5	31
100747	2020-07-21 15:37:49	2020-07-21	8	[{"id_menu":5,"count":1}]	17429	delivery	5	13
100748	2020-07-21 15:39:39	2020-07-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	38913	delivery	5	28
100749	2020-07-21 15:41:32	2020-07-21	9	[{"id_menu":6,"count":1}]	32192	delivery	5	14
100750	2020-07-21 15:42:43	2020-07-21	9	[{"id_menu":7,"count":1}]	5269	delivery	5	14
100751	2020-07-21 15:44:35	2020-07-21	17	[{"id_menu":4,"count":1}]	38956	delivery	5	22
100752	2020-07-21 15:49:26	2020-07-21	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	30169	delivery	5	40
100753	2020-07-21 15:52:34	2020-07-21	17	[{"id_menu":4,"count":1}]	8598	delivery	5	22
100754	2020-07-21 15:56:19	2020-07-21	12	[{"id_menu":3,"count":1}]	7053	pick-up	0	12
100755	2020-07-21 15:59:29	2020-07-21	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	23777	delivery	5	37
100756	2020-07-21 16:01:18	2020-07-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9319	delivery	5	22
100757	2020-07-21 16:01:19	2020-07-21	12	[{"id_menu":3,"count":1}]	20867	delivery	5	17
100758	2020-07-21 16:03:00	2020-07-21	9	[{"id_menu":6,"count":1}]	35669	delivery	5	14
100759	2020-07-21 16:09:08	2020-07-21	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	11006	delivery	5	27
100760	2020-07-21 16:09:50	2020-07-21	9	[{"id_menu":7,"count":1}]	34995	delivery	5	14
100761	2020-07-21 16:10:26	2020-07-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	38874	delivery	5	31
100762	2020-07-21 16:11:07	2020-07-21	9	[{"id_menu":6,"count":1}]	38762	delivery	5	14
100763	2020-07-21 16:13:30	2020-07-21	8	[{"id_menu":5,"count":1}]	7465	pick-up	0	8
100764	2020-07-21 16:13:50	2020-07-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	16337	delivery	5	28
100765	2020-07-21 16:21:26	2020-07-21	8	[{"id_menu":5,"count":1}]	38661	delivery	5	13
100766	2020-07-21 16:25:23	2020-07-21	9	[{"id_menu":6,"count":1}]	5180	pick-up	0	9
100767	2020-07-21 16:27:08	2020-07-21	17	[{"id_menu":4,"count":1}]	26676	delivery	5	22
100768	2020-07-21 16:28:21	2020-07-21	14	[{"id_menu":2,"count":1}]	13410	pick-up	0	14
100769	2020-07-21 16:33:24	2020-07-21	12	[{"id_menu":1,"count":1}]	6581	delivery	5	17
100770	2020-07-21 16:39:09	2020-07-21	14	[{"id_menu":2,"count":1}]	32300	delivery	5	19
100771	2020-07-21 16:41:18	2020-07-21	9	[{"id_menu":7,"count":1}]	38837	pick-up	0	9
100772	2020-07-21 16:50:23	2020-07-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11995	delivery	5	22
100773	2020-07-21 16:51:28	2020-07-21	12	[{"id_menu":1,"count":1}]	9898	pick-up	0	12
100774	2020-07-21 16:53:18	2020-07-21	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	10806	delivery	5	26
100775	2020-07-21 16:54:46	2020-07-21	9	[{"id_menu":6,"count":1}]	38931	delivery	5	14
100776	2020-07-21 16:55:30	2020-07-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6429	delivery	5	31
100777	2020-07-21 17:01:50	2020-07-21	8	[{"id_menu":5,"count":1}]	38864	delivery	5	13
100778	2020-07-21 17:02:18	2020-07-21	14	[{"id_menu":2,"count":1}]	38876	delivery	5	19
100779	2020-07-21 17:04:47	2020-07-21	9	[{"id_menu":7,"count":1}]	38994	pick-up	0	9
100780	2020-07-21 17:05:57	2020-07-21	17	[{"id_menu":4,"count":1}]	22419	delivery	5	22
100781	2020-07-21 17:07:59	2020-07-21	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	38820	delivery	5	31
100782	2020-07-21 17:08:23	2020-07-21	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24141	delivery	5	48
100783	2020-07-21 17:14:25	2020-07-21	8	[{"id_menu":5,"count":1}]	15645	pick-up	0	8
100784	2020-07-21 17:15:36	2020-07-21	8	[{"id_menu":5,"count":1}]	15621	delivery	5	13
100785	2020-07-21 17:17:31	2020-07-21	9	[{"id_menu":7,"count":1}]	12534	pick-up	0	9
100786	2020-07-21 17:17:41	2020-07-21	8	[{"id_menu":5,"count":1}]	28315	delivery	5	13
100787	2020-07-21 17:21:15	2020-07-21	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	38774	delivery	5	26
100788	2020-07-21 17:24:27	2020-07-21	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	38764	delivery	5	34
100789	2020-07-21 17:27:34	2020-07-21	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	15684	delivery	5	40
100790	2020-07-21 17:29:33	2020-07-21	8	[{"id_menu":5,"count":1}]	35245	pick-up	0	8
100791	2020-07-21 17:30:56	2020-07-21	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	38972	delivery	5	53
100792	2020-07-21 17:31:06	2020-07-21	9	[{"id_menu":7,"count":1}]	38940	delivery	5	14
100793	2020-07-21 17:31:09	2020-07-21	8	[{"id_menu":5,"count":1}]	24032	delivery	5	13
100794	2020-07-21 17:49:07	2020-07-21	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	16462	delivery	5	42
100795	2020-07-21 17:57:16	2020-07-21	12	[{"id_menu":3,"count":1}]	38973	delivery	5	17
100796	2020-07-21 17:58:02	2020-07-21	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38856	delivery	5	35
100797	2020-07-21 17:59:37	2020-07-21	12	[{"id_menu":1,"count":1}]	19434	pick-up	0	12
100798	2020-07-21 18:05:23	2020-07-21	9	[{"id_menu":6,"count":1}]	38997	pick-up	0	9
100799	2020-07-21 18:05:35	2020-07-21	14	[{"id_menu":2,"count":1}]	38795	pick-up	0	14
100800	2020-07-21 18:18:32	2020-07-21	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	260	pick-up	0	21
100801	2020-07-21 18:22:44	2020-07-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":3}]	12938	delivery	5	28
100802	2020-07-21 18:24:57	2020-07-21	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	11470	pick-up	0	21
100803	2020-07-21 18:25:48	2020-07-21	12	[{"id_menu":3,"count":1}]	8071	pick-up	0	12
100804	2020-07-21 18:27:27	2020-07-21	12	[{"id_menu":3,"count":1}]	21934	delivery	5	17
100805	2020-07-21 18:27:35	2020-07-21	17	[{"id_menu":4,"count":1}]	38773	pick-up	0	17
100806	2020-07-21 18:28:00	2020-07-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18687	pick-up	0	17
100807	2020-07-21 18:30:44	2020-07-21	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	9089	delivery	5	28
100808	2020-07-21 18:31:16	2020-07-21	9	[{"id_menu":6,"count":1}]	28587	delivery	5	14
100809	2020-07-21 18:33:35	2020-07-21	8	[{"id_menu":5,"count":1}]	1161	pick-up	0	8
100810	2020-07-21 18:37:54	2020-07-21	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	9464	delivery	5	27
100811	2020-07-21 18:41:58	2020-07-21	9	[{"id_menu":7,"count":1}]	8046	delivery	5	14
100812	2020-07-21 18:42:21	2020-07-21	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	13313	delivery	5	38
100813	2020-07-21 18:42:53	2020-07-21	17	[{"id_menu":4,"count":1}]	11945	delivery	5	22
100814	2020-07-21 18:50:55	2020-07-21	14	[{"id_menu":2,"count":1}]	24987	delivery	5	19
100815	2020-07-21 18:51:35	2020-07-21	17	[{"id_menu":4,"count":1}]	29365	delivery	5	22
100816	2020-07-21 18:51:35	2020-07-21	17	[{"id_menu":4,"count":1}]	3846	pick-up	0	17
100817	2020-07-21 18:56:08	2020-07-21	12	[{"id_menu":3,"count":1}]	11289	pick-up	0	12
100818	2020-07-21 18:56:54	2020-07-21	9	[{"id_menu":7,"count":1}]	14255	delivery	5	14
100819	2020-07-21 18:58:41	2020-07-21	9	[{"id_menu":7,"count":1}]	4081	pick-up	0	9
100820	2020-07-21 18:59:26	2020-07-21	12	[{"id_menu":1,"count":1}]	14476	delivery	5	17
100821	2020-07-21 19:15:40	2020-07-21	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	38878	pick-up	0	26
100822	2020-07-21 19:18:35	2020-07-21	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	4592	delivery	5	40
100823	2020-07-21 19:22:19	2020-07-21	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	5596	delivery	5	26
100824	2020-07-21 19:28:32	2020-07-21	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":3}]	38846	delivery	5	30
100825	2020-07-21 19:36:46	2020-07-21	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	7958	pick-up	0	26
100826	2020-07-21 19:37:31	2020-07-21	9	[{"id_menu":6,"count":1}]	7603	pick-up	0	9
100827	2020-07-21 19:38:50	2020-07-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20225	delivery	5	23
100828	2020-07-21 19:41:33	2020-07-21	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	30790	delivery	5	30
100829	2020-07-21 19:41:55	2020-07-21	12	[{"id_menu":3,"count":1}]	38871	delivery	5	17
100830	2020-07-21 19:42:57	2020-07-21	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	38903	delivery	5	43
100831	2020-07-21 19:43:14	2020-07-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	14954	delivery	5	31
100832	2020-07-21 19:47:25	2020-07-21	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	609	delivery	5	38
100833	2020-07-21 19:49:10	2020-07-21	12	[{"id_menu":3,"count":1}]	38881	pick-up	0	12
100834	2020-07-21 19:59:49	2020-07-21	9	[{"id_menu":7,"count":1}]	5633	delivery	5	14
100835	2020-07-21 20:03:22	2020-07-21	9	[{"id_menu":6,"count":1}]	38857	pick-up	0	9
100836	2020-07-21 20:12:49	2020-07-21	17	[{"id_menu":4,"count":1}]	7071	delivery	5	22
100837	2020-07-21 20:17:13	2020-07-21	9	[{"id_menu":6,"count":2}]	29557	delivery	5	14
100838	2020-07-21 20:18:00	2020-07-21	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	15326	pick-up	0	24
100839	2020-07-21 20:20:19	2020-07-21	17	[{"id_menu":4,"count":1}]	23172	delivery	5	22
100840	2020-07-21 20:21:51	2020-07-21	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	38992	delivery	5	25
100841	2020-07-21 20:24:01	2020-07-21	12	[{"id_menu":1,"count":1}]	1375	pick-up	0	12
100842	2020-07-21 20:24:52	2020-07-21	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31159	delivery	5	39
100843	2020-07-21 20:25:08	2020-07-21	9	[{"id_menu":6,"count":1}]	35040	delivery	5	14
100844	2020-07-21 20:25:55	2020-07-21	14	[{"id_menu":2,"count":1}]	38770	delivery	5	19
100845	2020-07-21 20:27:12	2020-07-21	17	[{"id_menu":4,"count":1}]	9404	pick-up	0	17
100846	2020-07-21 20:27:15	2020-07-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	38779	delivery	5	28
100847	2020-07-21 20:39:19	2020-07-21	17	[{"id_menu":4,"count":1}]	5254	delivery	5	22
100848	2020-07-21 20:40:33	2020-07-21	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19698	delivery	5	35
100849	2020-07-21 20:41:55	2020-07-21	12	[{"id_menu":1,"count":1}]	18409	pick-up	0	12
100850	2020-07-21 20:42:41	2020-07-21	14	[{"id_menu":2,"count":1}]	30542	delivery	5	19
100851	2020-07-21 20:44:43	2020-07-21	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	34670	delivery	5	30
100852	2020-07-21 20:53:09	2020-07-21	17	[{"id_menu":4,"count":1}]	3245	pick-up	0	17
100853	2020-07-21 20:53:20	2020-07-21	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38817	delivery	5	40
100854	2020-07-21 20:54:45	2020-07-21	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	18085	delivery	5	40
100855	2020-07-21 20:57:42	2020-07-21	17	[{"id_menu":4,"count":1}]	338	delivery	5	22
100856	2020-07-21 20:58:27	2020-07-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	38848	delivery	5	31
100857	2020-07-21 21:00:45	2020-07-21	12	[{"id_menu":3,"count":1}]	38886	delivery	5	17
100858	2020-07-21 21:04:21	2020-07-21	9	[{"id_menu":7,"count":1}]	38843	delivery	5	14
100859	2020-07-21 21:04:28	2020-07-21	9	[{"id_menu":7,"count":1}]	38838	pick-up	0	9
100860	2020-07-21 21:05:09	2020-07-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	35265	pick-up	0	23
100861	2020-07-21 21:07:43	2020-07-21	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15614	delivery	5	31
100862	2020-07-21 21:09:50	2020-07-21	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	14531	pick-up	0	40
100863	2020-07-21 21:10:25	2020-07-21	9	[{"id_menu":6,"count":1}]	38954	delivery	5	14
100864	2020-07-21 21:12:55	2020-07-21	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	38966	delivery	5	40
100865	2020-07-21 21:16:23	2020-07-21	17	[{"id_menu":4,"count":1}]	20347	delivery	5	22
100866	2020-07-21 21:16:49	2020-07-21	17	[{"id_menu":4,"count":1}]	13187	delivery	5	22
100867	2020-07-21 21:17:12	2020-07-21	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	38830	delivery	5	36
100868	2020-07-21 21:23:46	2020-07-21	12	[{"id_menu":1,"count":1}]	24758	delivery	5	17
100869	2020-07-21 21:28:41	2020-07-21	9	[{"id_menu":7,"count":1}]	27591	delivery	5	14
100870	2020-07-21 21:29:24	2020-07-21	12	[{"id_menu":1,"count":1}]	16883	pick-up	0	12
100871	2020-07-21 21:30:42	2020-07-21	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	38829	delivery	5	26
100872	2020-07-21 21:32:11	2020-07-21	17	[{"id_menu":4,"count":1}]	6301	delivery	5	22
100873	2020-07-21 21:35:15	2020-07-21	9	[{"id_menu":7,"count":1}]	3275	pick-up	0	9
100874	2020-07-21 21:36:45	2020-07-21	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	38777	delivery	5	34
100875	2020-07-21 21:41:08	2020-07-21	12	[{"id_menu":3,"count":1}]	7151	pick-up	0	12
100876	2020-07-21 21:41:50	2020-07-21	9	[{"id_menu":6,"count":1}]	27228	delivery	5	14
100877	2020-07-21 21:48:06	2020-07-21	12	[{"id_menu":1,"count":1}]	23918	pick-up	0	12
100878	2020-07-21 21:50:44	2020-07-21	14	[{"id_menu":2,"count":1}]	29937	delivery	5	19
100879	2020-07-21 21:53:15	2020-07-21	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	34431	delivery	5	29
100880	2020-07-21 21:55:04	2020-07-21	9	[{"id_menu":6,"count":3}]	38828	delivery	5	14
100881	2020-07-21 21:56:06	2020-07-21	9	[{"id_menu":7,"count":1}]	7179	delivery	5	14
100882	2020-07-21 21:57:53	2020-07-21	9	[{"id_menu":6,"count":1}]	38861	delivery	5	14
100883	2020-07-21 21:57:57	2020-07-21	14	[{"id_menu":2,"count":1}]	38919	delivery	5	19
100884	2020-07-21 22:03:24	2020-07-21	14	[{"id_menu":2,"count":1}]	2048	delivery	5	19
100885	2020-07-21 22:03:41	2020-07-21	17	[{"id_menu":4,"count":1}]	31817	delivery	5	22
100886	2020-07-21 22:04:50	2020-07-21	12	[{"id_menu":1,"count":1}]	23391	delivery	5	17
100887	2020-07-21 22:18:18	2020-07-21	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	38815	pick-up	0	26
100888	2020-07-21 22:18:24	2020-07-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	38098	delivery	5	31
100889	2020-07-21 22:18:48	2020-07-21	12	[{"id_menu":1,"count":1}]	1435	pick-up	0	12
100890	2020-07-21 22:23:00	2020-07-21	9	[{"id_menu":6,"count":1}]	27080	delivery	5	14
100891	2020-07-21 22:25:08	2020-07-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	38880	delivery	5	31
100892	2020-07-21 22:25:22	2020-07-21	12	[{"id_menu":3,"count":1}]	38849	delivery	5	17
100893	2020-07-21 22:26:20	2020-07-21	12	[{"id_menu":3,"count":1}]	8660	delivery	5	17
100894	2020-07-21 22:26:45	2020-07-21	9	[{"id_menu":7,"count":1}]	15533	delivery	5	14
100895	2020-07-21 22:30:47	2020-07-21	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	31899	delivery	5	34
100896	2020-07-21 22:31:12	2020-07-21	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	38905	delivery	5	29
100897	2020-07-21 22:32:24	2020-07-21	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	38884	pick-up	0	33
100898	2020-07-21 22:36:33	2020-07-21	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	38811	delivery	5	31
100899	2020-07-21 22:37:10	2020-07-21	9	[{"id_menu":7,"count":1}]	38852	delivery	5	14
100900	2020-07-21 22:39:36	2020-07-21	17	[{"id_menu":4,"count":1}]	38823	delivery	5	22
100901	2020-07-21 22:42:35	2020-07-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	36455	delivery	5	28
100902	2020-07-21 22:44:41	2020-07-21	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	11515	delivery	5	39
100903	2020-07-21 22:46:33	2020-07-21	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	16738	delivery	5	28
100904	2020-07-21 22:47:02	2020-07-21	14	[{"id_menu":2,"count":1}]	36672	delivery	5	19
100905	2020-07-21 22:47:12	2020-07-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	37387	delivery	5	28
100906	2020-07-21 22:50:08	2020-07-21	9	[{"id_menu":6,"count":1}]	18343	delivery	5	14
100907	2020-07-21 22:55:44	2020-07-21	9	[{"id_menu":7,"count":1}]	38853	delivery	5	14
100908	2020-07-21 23:01:33	2020-07-21	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":3}]	10666	delivery	5	25
100909	2020-07-21 23:02:09	2020-07-21	12	[{"id_menu":3,"count":1}]	30786	delivery	5	17
100910	2020-07-21 23:02:41	2020-07-21	17	[{"id_menu":4,"count":1}]	36184	delivery	5	22
100911	2020-07-21 23:04:35	2020-07-21	9	[{"id_menu":6,"count":1}]	38166	pick-up	0	9
100912	2020-07-21 23:10:20	2020-07-21	14	[{"id_menu":2,"count":1}]	33219	delivery	5	19
100913	2020-07-21 23:13:39	2020-07-21	9	[{"id_menu":7,"count":1}]	26754	delivery	5	14
100914	2020-07-21 23:17:47	2020-07-21	8	[{"id_menu":5,"count":1}]	38902	delivery	5	13
100915	2020-07-21 23:18:36	2020-07-21	14	[{"id_menu":2,"count":1}]	2439	delivery	5	19
100916	2020-07-21 23:19:59	2020-07-21	17	[{"id_menu":4,"count":1}]	32664	delivery	5	22
100917	2020-07-21 23:20:09	2020-07-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9011	delivery	5	23
100918	2020-07-21 23:24:51	2020-07-21	14	[{"id_menu":2,"count":1}]	34580	delivery	5	19
100919	2020-07-21 23:25:36	2020-07-21	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8586	delivery	5	35
100920	2020-07-21 23:27:22	2020-07-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1148	delivery	5	31
100921	2020-07-21 23:28:22	2020-07-21	9	[{"id_menu":7,"count":1}]	36715	delivery	5	14
100922	2020-07-21 23:29:33	2020-07-21	12	[{"id_menu":3,"count":1}]	33708	pick-up	0	12
100923	2020-07-21 23:31:56	2020-07-21	17	[{"id_menu":4,"count":1}]	11342	delivery	5	22
100924	2020-07-21 23:32:19	2020-07-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	28288	delivery	5	22
100925	2020-07-21 23:35:19	2020-07-21	9	[{"id_menu":6,"count":1}]	35804	delivery	5	14
100926	2020-07-21 23:36:41	2020-07-21	12	[{"id_menu":1,"count":1}]	21440	delivery	5	17
100927	2020-07-21 23:53:13	2020-07-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	38943	delivery	5	22
100928	2020-07-21 23:56:20	2020-07-21	9	[{"id_menu":6,"count":1}]	11347	delivery	5	14
100929	2020-07-21 23:59:43	2020-07-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	26613	delivery	5	31
100930	2020-07-22 00:01:06	2020-07-22	12	[{"id_menu":1,"count":1}]	39053	delivery	5	17
100931	2020-07-22 00:01:23	2020-07-22	8	[{"id_menu":5,"count":1}]	38414	delivery	5	13
100932	2020-07-22 00:01:38	2020-07-22	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	31857	delivery	5	26
100933	2020-07-22 00:01:57	2020-07-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	25513	delivery	5	36
100934	2020-07-22 00:02:40	2020-07-22	9	[{"id_menu":7,"count":2}]	24725	delivery	5	14
100935	2020-07-22 00:04:04	2020-07-22	12	[{"id_menu":3,"count":1}]	39010	delivery	5	17
100936	2020-07-22 00:05:21	2020-07-22	12	[{"id_menu":1,"count":1}]	24203	delivery	5	17
100937	2020-07-22 00:08:11	2020-07-22	9	[{"id_menu":7,"count":1}]	39128	delivery	5	14
100938	2020-07-22 00:08:59	2020-07-22	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6600	pick-up	0	29
100939	2020-07-22 00:11:47	2020-07-22	14	[{"id_menu":2,"count":1}]	24012	delivery	5	19
100940	2020-07-22 00:13:09	2020-07-22	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	23665	delivery	5	40
100941	2020-07-22 00:20:35	2020-07-22	9	[{"id_menu":7,"count":1}]	39174	delivery	5	14
100942	2020-07-22 00:22:00	2020-07-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	39160	delivery	5	36
100943	2020-07-22 00:23:31	2020-07-22	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	39167	delivery	5	45
100944	2020-07-22 00:24:56	2020-07-22	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	31359	delivery	5	26
100945	2020-07-22 00:25:22	2020-07-22	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39086	delivery	5	39
100946	2020-07-22 00:27:15	2020-07-22	14	[{"id_menu":2,"count":1}]	2867	pick-up	0	14
100947	2020-07-22 00:28:00	2020-07-22	14	[{"id_menu":2,"count":1}]	13782	delivery	5	19
100948	2020-07-22 00:28:24	2020-07-22	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	36471	delivery	5	39
100949	2020-07-22 00:37:43	2020-07-22	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	39214	delivery	5	39
100950	2020-07-22 00:40:55	2020-07-22	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	39081	delivery	5	31
100951	2020-07-22 00:47:43	2020-07-22	9	[{"id_menu":7,"count":1}]	36168	pick-up	0	9
100952	2020-07-22 00:49:38	2020-07-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24767	pick-up	0	17
100953	2020-07-22 00:49:56	2020-07-22	9	[{"id_menu":6,"count":1}]	39154	delivery	5	14
100954	2020-07-22 00:50:31	2020-07-22	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27999	pick-up	0	30
100955	2020-07-22 00:50:41	2020-07-22	9	[{"id_menu":6,"count":1}]	9733	delivery	5	14
100956	2020-07-22 00:52:01	2020-07-22	17	[{"id_menu":4,"count":1}]	39063	delivery	5	22
100957	2020-07-22 00:55:43	2020-07-22	9	[{"id_menu":7,"count":1}]	39166	delivery	5	14
100958	2020-07-22 00:55:44	2020-07-22	9	[{"id_menu":7,"count":1}]	17091	delivery	5	14
100959	2020-07-22 00:56:12	2020-07-22	12	[{"id_menu":1,"count":1}]	30375	delivery	5	17
100960	2020-07-22 00:56:13	2020-07-22	17	[{"id_menu":4,"count":1}]	23241	delivery	5	22
100961	2020-07-22 00:58:20	2020-07-22	9	[{"id_menu":7,"count":1}]	26342	delivery	5	14
100962	2020-07-22 00:59:45	2020-07-22	8	[{"id_menu":5,"count":2}]	39129	delivery	5	13
100963	2020-07-22 01:00:27	2020-07-22	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	19011	pick-up	0	26
100964	2020-07-22 01:00:37	2020-07-22	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39146	delivery	5	39
100965	2020-07-22 01:01:04	2020-07-22	12	[{"id_menu":1,"count":1}]	1715	pick-up	0	12
100966	2020-07-22 01:09:07	2020-07-22	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	27565	delivery	5	43
100967	2020-07-22 01:09:59	2020-07-22	9	[{"id_menu":7,"count":1}]	26154	delivery	5	14
100968	2020-07-22 01:10:38	2020-07-22	9	[{"id_menu":7,"count":1}]	39156	delivery	5	14
100969	2020-07-22 01:11:12	2020-07-22	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	39026	delivery	5	31
100970	2020-07-22 01:13:40	2020-07-22	17	[{"id_menu":4,"count":1}]	466	delivery	5	22
100971	2020-07-22 01:19:22	2020-07-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39035	delivery	5	22
100972	2020-07-22 01:20:43	2020-07-22	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9139	delivery	5	36
100973	2020-07-22 01:21:17	2020-07-22	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9319	delivery	5	31
100974	2020-07-22 01:22:32	2020-07-22	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	24422	delivery	5	40
100975	2020-07-22 01:24:04	2020-07-22	14	[{"id_menu":2,"count":1}]	39148	delivery	5	19
100976	2020-07-22 01:24:29	2020-07-22	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	16620	delivery	5	26
100977	2020-07-22 01:28:03	2020-07-22	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39052	delivery	5	40
100978	2020-07-22 01:30:20	2020-07-22	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39051	delivery	5	37
100979	2020-07-22 01:30:46	2020-07-22	9	[{"id_menu":7,"count":1}]	2245	pick-up	0	9
100980	2020-07-22 01:32:22	2020-07-22	9	[{"id_menu":7,"count":1}]	16532	delivery	5	14
100981	2020-07-22 01:32:32	2020-07-22	12	[{"id_menu":3,"count":1}]	39215	pick-up	0	12
100982	2020-07-22 01:33:26	2020-07-22	17	[{"id_menu":4,"count":1}]	39134	delivery	5	22
100983	2020-07-22 01:34:45	2020-07-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14808	delivery	5	23
100984	2020-07-22 01:35:41	2020-07-22	9	[{"id_menu":7,"count":2}]	5296	delivery	5	14
100985	2020-07-22 01:38:30	2020-07-22	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3711	pick-up	0	26
100986	2020-07-22 01:44:05	2020-07-22	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	39107	delivery	5	34
100987	2020-07-22 01:51:14	2020-07-22	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	35489	delivery	5	31
100988	2020-07-22 02:08:51	2020-07-22	17	[{"id_menu":4,"count":1}]	15594	pick-up	0	17
100989	2020-07-22 02:09:51	2020-07-22	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	35740	pick-up	0	26
100990	2020-07-22 02:12:51	2020-07-22	12	[{"id_menu":1,"count":1}]	39045	delivery	5	17
100991	2020-07-22 02:14:39	2020-07-22	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	11435	pick-up	0	26
100992	2020-07-22 02:15:24	2020-07-22	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	39237	delivery	5	31
100993	2020-07-22 02:20:50	2020-07-22	12	[{"id_menu":3,"count":1}]	13720	delivery	5	17
100994	2020-07-22 02:21:08	2020-07-22	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	39006	delivery	5	43
100995	2020-07-22 02:21:52	2020-07-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	36839	pick-up	0	17
100996	2020-07-22 02:23:37	2020-07-22	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	39147	delivery	5	31
100997	2020-07-22 02:23:39	2020-07-22	9	[{"id_menu":6,"count":1}]	6678	delivery	5	14
100998	2020-07-22 02:24:46	2020-07-22	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	16831	delivery	5	28
100999	2020-07-22 02:25:23	2020-07-22	9	[{"id_menu":7,"count":1}]	2168	pick-up	0	9
101000	2020-07-22 02:27:34	2020-07-22	17	[{"id_menu":4,"count":1}]	39242	delivery	5	22
101001	2020-07-22 02:30:46	2020-07-22	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	39217	delivery	5	34
101002	2020-07-22 02:32:41	2020-07-22	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	39009	delivery	5	40
101003	2020-07-22 02:32:46	2020-07-22	9	[{"id_menu":7,"count":1}]	229	delivery	5	14
101004	2020-07-22 02:32:52	2020-07-22	8	[{"id_menu":5,"count":1}]	20071	delivery	5	13
101005	2020-07-22 02:36:28	2020-07-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8584	delivery	5	22
101006	2020-07-22 02:36:51	2020-07-22	9	[{"id_menu":6,"count":1}]	35126	delivery	5	14
101007	2020-07-22 02:39:09	2020-07-22	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	39013	delivery	5	34
101008	2020-07-22 02:43:51	2020-07-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7772	pick-up	0	23
101009	2020-07-22 02:44:01	2020-07-22	14	[{"id_menu":2,"count":1}]	2050	pick-up	0	14
101010	2020-07-22 02:44:41	2020-07-22	12	[{"id_menu":1,"count":1}]	34435	delivery	5	17
101011	2020-07-22 02:46:07	2020-07-22	14	[{"id_menu":2,"count":1}]	27039	pick-up	0	14
101012	2020-07-22 02:47:20	2020-07-22	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2885	delivery	5	31
101013	2020-07-22 02:49:11	2020-07-22	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	26966	delivery	5	43
101014	2020-07-22 02:50:26	2020-07-22	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1889	pick-up	0	20
101015	2020-07-22 02:51:57	2020-07-22	8	[{"id_menu":5,"count":1}]	37029	delivery	5	13
101016	2020-07-22 02:53:40	2020-07-22	9	[{"id_menu":7,"count":1}]	13529	pick-up	0	9
101017	2020-07-22 02:54:31	2020-07-22	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	24166	delivery	5	43
101018	2020-07-22 02:59:03	2020-07-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	39200	delivery	5	28
101019	2020-07-22 03:01:12	2020-07-22	8	[{"id_menu":5,"count":1}]	31602	delivery	5	13
101020	2020-07-22 03:01:17	2020-07-22	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	39075	delivery	5	26
101021	2020-07-22 03:08:42	2020-07-22	12	[{"id_menu":3,"count":1}]	39105	pick-up	0	12
101022	2020-07-22 03:14:23	2020-07-22	8	[{"id_menu":5,"count":1}]	28233	delivery	5	13
101023	2020-07-22 03:17:33	2020-07-22	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	34760	delivery	5	36
101024	2020-07-22 03:18:53	2020-07-22	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	39157	delivery	5	43
101025	2020-07-22 03:21:55	2020-07-22	12	[{"id_menu":1,"count":1}]	76	delivery	5	17
101026	2020-07-22 03:22:59	2020-07-22	9	[{"id_menu":7,"count":1}]	18479	delivery	5	14
101027	2020-07-22 03:23:21	2020-07-22	12	[{"id_menu":3,"count":1}]	355	pick-up	0	12
101028	2020-07-22 03:30:23	2020-07-22	14	[{"id_menu":2,"count":1}]	6090	delivery	5	19
101029	2020-07-22 03:38:39	2020-07-22	14	[{"id_menu":2,"count":1}]	2071	pick-up	0	14
101030	2020-07-22 03:38:44	2020-07-22	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	39203	delivery	5	26
101031	2020-07-22 03:39:39	2020-07-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39038	delivery	5	22
101032	2020-07-22 03:42:52	2020-07-22	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	15456	pick-up	0	24
101033	2020-07-22 03:47:19	2020-07-22	17	[{"id_menu":4,"count":1}]	34999	pick-up	0	17
101034	2020-07-22 03:50:08	2020-07-22	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6810	pick-up	0	26
101035	2020-07-22 03:50:14	2020-07-22	9	[{"id_menu":6,"count":1}]	12742	pick-up	0	9
101036	2020-07-22 03:53:14	2020-07-22	8	[{"id_menu":5,"count":1}]	15855	delivery	5	13
101037	2020-07-22 03:53:52	2020-07-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	11411	delivery	5	28
101038	2020-07-22 04:00:27	2020-07-22	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1498	delivery	5	40
101039	2020-07-22 04:01:08	2020-07-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	39097	delivery	5	36
101040	2020-07-22 04:01:59	2020-07-22	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	39165	delivery	5	40
101041	2020-07-22 04:03:52	2020-07-22	17	[{"id_menu":4,"count":1}]	31490	delivery	5	22
101042	2020-07-22 04:06:21	2020-07-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39123	delivery	5	23
101043	2020-07-22 04:09:57	2020-07-22	8	[{"id_menu":5,"count":1}]	29211	delivery	5	13
101044	2020-07-22 04:11:06	2020-07-22	9	[{"id_menu":7,"count":1}]	27208	delivery	5	14
101045	2020-07-22 04:12:36	2020-07-22	17	[{"id_menu":4,"count":1}]	4605	delivery	5	22
101046	2020-07-22 04:12:52	2020-07-22	12	[{"id_menu":3,"count":1}]	9715	delivery	5	17
101047	2020-07-22 04:13:25	2020-07-22	9	[{"id_menu":6,"count":1}]	868	pick-up	0	9
101048	2020-07-22 04:16:12	2020-07-22	8	[{"id_menu":5,"count":2}]	39155	delivery	5	13
101049	2020-07-22 04:16:36	2020-07-22	9	[{"id_menu":7,"count":2}]	4190	delivery	5	14
101050	2020-07-22 04:18:07	2020-07-22	12	[{"id_menu":3,"count":1}]	39172	pick-up	0	12
101051	2020-07-22 04:19:36	2020-07-22	12	[{"id_menu":3,"count":1}]	14167	delivery	5	17
101052	2020-07-22 04:20:22	2020-07-22	9	[{"id_menu":6,"count":1}]	24987	delivery	5	14
101053	2020-07-22 04:22:16	2020-07-22	17	[{"id_menu":4,"count":1}]	3971	pick-up	0	17
101054	2020-07-22 04:24:07	2020-07-22	12	[{"id_menu":1,"count":1}]	26919	delivery	5	17
101055	2020-07-22 04:24:18	2020-07-22	12	[{"id_menu":3,"count":1}]	916	pick-up	0	12
101056	2020-07-22 04:24:49	2020-07-22	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	35106	pick-up	0	22
101057	2020-07-22 04:25:30	2020-07-22	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	35872	pick-up	0	26
101058	2020-07-22 04:27:41	2020-07-22	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	371	delivery	5	31
101059	2020-07-22 04:28:55	2020-07-22	14	[{"id_menu":2,"count":1}]	754	pick-up	0	14
101060	2020-07-22 04:35:11	2020-07-22	9	[{"id_menu":6,"count":1}]	32455	delivery	5	14
101061	2020-07-22 04:35:11	2020-07-22	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	22711	delivery	5	31
101062	2020-07-22 04:36:07	2020-07-22	14	[{"id_menu":2,"count":1}]	39201	delivery	5	19
101063	2020-07-22 04:36:22	2020-07-22	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	39069	delivery	5	31
101064	2020-07-22 04:37:42	2020-07-22	17	[{"id_menu":4,"count":1}]	28357	pick-up	0	17
101065	2020-07-22 04:42:05	2020-07-22	9	[{"id_menu":6,"count":1}]	39080	delivery	5	14
101066	2020-07-22 04:44:25	2020-07-22	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39067	delivery	5	34
101067	2020-07-22 04:44:32	2020-07-22	17	[{"id_menu":4,"count":1}]	39111	delivery	5	22
101068	2020-07-22 04:45:00	2020-07-22	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	27615	delivery	5	34
101069	2020-07-22 04:46:01	2020-07-22	14	[{"id_menu":2,"count":2}]	16501	pick-up	0	14
101070	2020-07-22 04:50:49	2020-07-22	9	[{"id_menu":7,"count":1}]	39198	delivery	5	14
101071	2020-07-22 04:51:28	2020-07-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39083	delivery	5	22
101072	2020-07-22 04:54:36	2020-07-22	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5180	pick-up	0	37
101073	2020-07-22 04:55:46	2020-07-22	9	[{"id_menu":6,"count":1}]	39202	delivery	5	14
101074	2020-07-22 04:56:43	2020-07-22	12	[{"id_menu":1,"count":1}]	39210	delivery	5	17
101075	2020-07-22 04:56:58	2020-07-22	17	[{"id_menu":4,"count":1}]	2520	pick-up	0	17
101076	2020-07-22 04:59:27	2020-07-22	12	[{"id_menu":3,"count":1}]	12494	delivery	5	17
101077	2020-07-22 05:02:40	2020-07-22	8	[{"id_menu":5,"count":1}]	24176	delivery	5	13
101078	2020-07-22 05:04:31	2020-07-22	8	[{"id_menu":5,"count":1}]	39100	delivery	5	13
101079	2020-07-22 05:06:56	2020-07-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	34140	pick-up	0	23
101080	2020-07-22 05:09:23	2020-07-22	9	[{"id_menu":6,"count":1}]	2616	pick-up	0	9
101081	2020-07-22 05:11:02	2020-07-22	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	20792	delivery	5	30
101082	2020-07-22 05:13:01	2020-07-22	14	[{"id_menu":2,"count":1}]	30349	delivery	5	19
101083	2020-07-22 05:16:25	2020-07-22	12	[{"id_menu":3,"count":1}]	17332	delivery	5	17
101084	2020-07-22 05:19:21	2020-07-22	9	[{"id_menu":7,"count":2}]	39007	delivery	5	14
101085	2020-07-22 05:22:32	2020-07-22	9	[{"id_menu":6,"count":1}]	15313	delivery	5	14
101086	2020-07-22 05:24:41	2020-07-22	9	[{"id_menu":6,"count":2}]	6113	delivery	5	14
101087	2020-07-22 05:26:26	2020-07-22	9	[{"id_menu":7,"count":1}]	39188	delivery	5	14
101088	2020-07-22 05:32:21	2020-07-22	9	[{"id_menu":7,"count":1}]	15991	pick-up	0	9
101089	2020-07-22 05:37:38	2020-07-22	9	[{"id_menu":6,"count":1}]	29068	delivery	5	14
101090	2020-07-22 05:41:19	2020-07-22	9	[{"id_menu":7,"count":1}]	39189	delivery	5	14
101091	2020-07-22 05:41:52	2020-07-22	9	[{"id_menu":7,"count":1}]	39191	delivery	5	14
101092	2020-07-22 05:47:53	2020-07-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	4622	delivery	5	28
101093	2020-07-22 05:48:39	2020-07-22	12	[{"id_menu":1,"count":1}]	12297	delivery	5	17
101094	2020-07-22 05:49:19	2020-07-22	12	[{"id_menu":1,"count":1}]	39142	delivery	5	17
101095	2020-07-22 05:58:17	2020-07-22	8	[{"id_menu":5,"count":1}]	39005	delivery	5	13
101096	2020-07-22 06:05:38	2020-07-22	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3754	pick-up	0	25
101097	2020-07-22 06:08:55	2020-07-22	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	15864	delivery	5	34
101098	2020-07-22 06:09:54	2020-07-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	33225	delivery	5	22
101099	2020-07-22 06:10:27	2020-07-22	12	[{"id_menu":1,"count":2}]	601	delivery	5	17
101100	2020-07-22 06:11:36	2020-07-22	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	5262	delivery	5	46
101101	2020-07-22 06:14:49	2020-07-22	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	29001	pick-up	0	34
101102	2020-07-22 06:15:56	2020-07-22	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	32487	delivery	5	34
101103	2020-07-22 06:18:35	2020-07-22	9	[{"id_menu":7,"count":1}]	5699	delivery	5	14
101104	2020-07-22 06:24:00	2020-07-22	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	20869	delivery	5	36
101105	2020-07-22 06:25:15	2020-07-22	9	[{"id_menu":6,"count":1}]	25563	delivery	5	14
101106	2020-07-22 06:28:05	2020-07-22	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	39062	delivery	5	42
101107	2020-07-22 06:28:43	2020-07-22	9	[{"id_menu":7,"count":1}]	39113	delivery	5	14
101108	2020-07-22 06:32:40	2020-07-22	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	15082	pick-up	0	22
101109	2020-07-22 06:36:02	2020-07-22	14	[{"id_menu":2,"count":1}]	18051	delivery	5	19
101110	2020-07-22 06:36:19	2020-07-22	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	39179	delivery	5	26
101111	2020-07-22 06:38:02	2020-07-22	14	[{"id_menu":2,"count":1}]	10399	delivery	5	19
101112	2020-07-22 06:41:01	2020-07-22	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	39103	delivery	5	31
101113	2020-07-22 06:41:05	2020-07-22	9	[{"id_menu":6,"count":1}]	39145	delivery	5	14
101114	2020-07-22 06:41:38	2020-07-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34106	delivery	5	23
101115	2020-07-22 06:43:05	2020-07-22	12	[{"id_menu":3,"count":1}]	7835	pick-up	0	12
101116	2020-07-22 06:46:05	2020-07-22	9	[{"id_menu":6,"count":1}]	23084	pick-up	0	9
101117	2020-07-22 06:47:19	2020-07-22	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	39104	delivery	5	26
101118	2020-07-22 06:51:07	2020-07-22	12	[{"id_menu":3,"count":1}]	39021	delivery	5	17
101119	2020-07-22 06:51:45	2020-07-22	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19342	delivery	5	34
101120	2020-07-22 06:51:47	2020-07-22	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3420	pick-up	0	29
101121	2020-07-22 06:55:38	2020-07-22	8	[{"id_menu":5,"count":1}]	4242	pick-up	0	8
101122	2020-07-22 06:55:40	2020-07-22	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	39054	delivery	5	45
101123	2020-07-22 06:57:09	2020-07-22	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	39151	delivery	5	40
101124	2020-07-22 07:00:07	2020-07-22	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17610	delivery	5	53
101125	2020-07-22 07:00:11	2020-07-22	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	39093	delivery	5	34
101126	2020-07-22 07:01:04	2020-07-22	9	[{"id_menu":7,"count":1}]	16768	delivery	5	14
101127	2020-07-22 07:01:21	2020-07-22	9	[{"id_menu":6,"count":1}]	7410	pick-up	0	9
101128	2020-07-22 07:03:43	2020-07-22	9	[{"id_menu":7,"count":1}]	39049	delivery	5	14
101129	2020-07-22 07:07:15	2020-07-22	8	[{"id_menu":5,"count":2}]	11189	delivery	5	13
101130	2020-07-22 07:07:56	2020-07-22	9	[{"id_menu":7,"count":1}]	39162	delivery	5	14
101131	2020-07-22 07:09:04	2020-07-22	14	[{"id_menu":2,"count":2}]	16365	delivery	5	19
101132	2020-07-22 07:09:05	2020-07-22	9	[{"id_menu":7,"count":1}]	39225	delivery	5	14
101133	2020-07-22 07:14:32	2020-07-22	46	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	31172	delivery	5	51
101134	2020-07-22 07:19:20	2020-07-22	9	[{"id_menu":7,"count":1}]	9485	delivery	5	14
101135	2020-07-22 07:20:29	2020-07-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2809	delivery	5	23
101136	2020-07-22 07:25:59	2020-07-22	9	[{"id_menu":7,"count":2}]	39221	delivery	5	14
101137	2020-07-22 07:27:20	2020-07-22	9	[{"id_menu":6,"count":1}]	33131	delivery	5	14
101138	2020-07-22 07:28:54	2020-07-22	14	[{"id_menu":2,"count":1}]	4937	delivery	5	19
101139	2020-07-22 07:38:38	2020-07-22	14	[{"id_menu":2,"count":2}]	32848	delivery	5	19
101140	2020-07-22 07:44:10	2020-07-22	12	[{"id_menu":1,"count":2}]	39127	delivery	5	17
101141	2020-07-22 07:45:23	2020-07-22	8	[{"id_menu":5,"count":1}]	39025	pick-up	0	8
101142	2020-07-22 07:45:28	2020-07-22	14	[{"id_menu":2,"count":1}]	39130	delivery	5	19
101143	2020-07-22 07:50:33	2020-07-22	9	[{"id_menu":6,"count":1}]	28735	delivery	5	14
101144	2020-07-22 07:53:44	2020-07-22	8	[{"id_menu":5,"count":1}]	6846	delivery	5	13
101145	2020-07-22 08:00:35	2020-07-22	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	3537	delivery	5	31
101146	2020-07-22 08:06:37	2020-07-22	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	27808	delivery	5	45
101147	2020-07-22 08:07:40	2020-07-22	12	[{"id_menu":1,"count":1}]	4628	pick-up	0	12
101148	2020-07-22 08:10:09	2020-07-22	9	[{"id_menu":7,"count":2}]	26256	pick-up	0	9
101149	2020-07-22 08:11:31	2020-07-22	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	39207	delivery	5	43
101150	2020-07-22 08:13:41	2020-07-22	12	[{"id_menu":1,"count":1}]	12849	delivery	5	17
101151	2020-07-22 08:14:07	2020-07-22	14	[{"id_menu":2,"count":1}]	39040	delivery	5	19
101152	2020-07-22 08:17:46	2020-07-22	14	[{"id_menu":2,"count":1}]	24567	delivery	5	19
101153	2020-07-22 08:18:51	2020-07-22	12	[{"id_menu":1,"count":1}]	39019	pick-up	0	12
101154	2020-07-22 08:19:38	2020-07-22	12	[{"id_menu":3,"count":1}]	14969	delivery	5	17
101155	2020-07-22 08:24:21	2020-07-22	12	[{"id_menu":1,"count":1}]	19868	pick-up	0	12
101156	2020-07-22 08:24:27	2020-07-22	12	[{"id_menu":3,"count":1}]	17374	delivery	5	17
101157	2020-07-22 08:26:24	2020-07-22	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	34357	delivery	5	40
101158	2020-07-22 08:27:49	2020-07-22	8	[{"id_menu":5,"count":1}]	2827	pick-up	0	8
101159	2020-07-22 08:29:04	2020-07-22	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	39056	pick-up	0	35
101160	2020-07-22 08:32:12	2020-07-22	9	[{"id_menu":6,"count":1}]	9256	delivery	5	14
101161	2020-07-22 08:37:52	2020-07-22	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5071	delivery	5	43
101162	2020-07-22 08:39:10	2020-07-22	14	[{"id_menu":2,"count":1}]	1239	pick-up	0	14
101163	2020-07-22 08:42:27	2020-07-22	39	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	27651	delivery	5	44
101164	2020-07-22 08:44:58	2020-07-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31821	delivery	5	23
101165	2020-07-22 08:45:39	2020-07-22	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	35850	delivery	5	30
101166	2020-07-22 08:47:52	2020-07-22	17	[{"id_menu":4,"count":1}]	11519	pick-up	0	17
101167	2020-07-22 08:48:23	2020-07-22	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39048	delivery	5	34
101168	2020-07-22 08:49:56	2020-07-22	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	16186	pick-up	0	29
101169	2020-07-22 08:50:08	2020-07-22	17	[{"id_menu":4,"count":1}]	37132	delivery	5	22
101170	2020-07-22 08:51:09	2020-07-22	9	[{"id_menu":7,"count":1}]	39199	delivery	5	14
101171	2020-07-22 08:54:54	2020-07-22	14	[{"id_menu":2,"count":1}]	3399	pick-up	0	14
101172	2020-07-22 08:55:36	2020-07-22	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14149	delivery	5	22
101173	2020-07-22 09:00:18	2020-07-22	9	[{"id_menu":7,"count":1}]	23344	delivery	5	14
101174	2020-07-22 09:02:25	2020-07-22	9	[{"id_menu":6,"count":1}]	31081	delivery	5	14
101175	2020-07-22 09:04:13	2020-07-22	9	[{"id_menu":6,"count":1}]	32205	delivery	5	14
101176	2020-07-22 09:06:24	2020-07-22	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	11710	delivery	5	27
101177	2020-07-22 09:12:24	2020-07-22	8	[{"id_menu":5,"count":1}]	15703	delivery	5	13
101178	2020-07-22 09:12:50	2020-07-22	9	[{"id_menu":7,"count":3}]	38763	delivery	5	14
101179	2020-07-22 09:14:45	2020-07-22	12	[{"id_menu":1,"count":1}]	39003	pick-up	0	12
101180	2020-07-22 09:18:28	2020-07-22	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	39095	delivery	5	42
101181	2020-07-22 09:23:33	2020-07-22	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	39222	delivery	5	34
101182	2020-07-22 09:25:18	2020-07-22	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	39084	delivery	5	43
101183	2020-07-22 09:25:23	2020-07-22	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6188	pick-up	0	37
101184	2020-07-22 09:26:56	2020-07-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	4956	delivery	5	23
101185	2020-07-22 09:30:11	2020-07-22	9	[{"id_menu":6,"count":3}]	21514	delivery	5	14
101186	2020-07-22 09:35:31	2020-07-22	17	[{"id_menu":4,"count":1}]	35010	delivery	5	22
101187	2020-07-22 09:37:33	2020-07-22	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28081	delivery	5	34
101188	2020-07-22 09:38:54	2020-07-22	9	[{"id_menu":6,"count":1}]	39152	delivery	5	14
101189	2020-07-22 09:39:20	2020-07-22	9	[{"id_menu":6,"count":1}]	39085	delivery	5	14
101190	2020-07-22 09:41:51	2020-07-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	35058	pick-up	0	23
101191	2020-07-22 09:42:25	2020-07-22	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	39235	delivery	5	39
101192	2020-07-22 09:43:34	2020-07-22	12	[{"id_menu":1,"count":1}]	17784	delivery	5	17
101193	2020-07-22 09:43:45	2020-07-22	8	[{"id_menu":5,"count":1}]	39243	delivery	5	13
101194	2020-07-22 09:46:52	2020-07-22	12	[{"id_menu":1,"count":1}]	3518	delivery	5	17
101195	2020-07-22 09:48:36	2020-07-22	9	[{"id_menu":6,"count":1}]	39033	delivery	5	14
101196	2020-07-22 09:51:47	2020-07-22	12	[{"id_menu":1,"count":1}]	20494	delivery	5	17
101197	2020-07-22 09:52:09	2020-07-22	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	17500	pick-up	0	22
101198	2020-07-22 09:54:16	2020-07-22	9	[{"id_menu":7,"count":1}]	20295	delivery	5	14
101199	2020-07-22 09:55:27	2020-07-22	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	10340	delivery	5	45
101200	2020-07-22 09:55:40	2020-07-22	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	7678	delivery	5	26
101201	2020-07-22 09:58:03	2020-07-22	8	[{"id_menu":5,"count":1}]	39211	delivery	5	13
101202	2020-07-22 10:05:23	2020-07-22	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28775	delivery	5	36
101203	2020-07-22 10:23:39	2020-07-22	12	[{"id_menu":1,"count":1}]	19587	delivery	5	17
101204	2020-07-22 10:26:58	2020-07-22	12	[{"id_menu":3,"count":1}]	23597	delivery	5	17
101205	2020-07-22 10:27:19	2020-07-22	9	[{"id_menu":7,"count":1}]	39027	delivery	5	14
101206	2020-07-22 10:28:39	2020-07-22	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10914	delivery	5	31
101207	2020-07-22 10:29:15	2020-07-22	9	[{"id_menu":6,"count":1}]	17933	delivery	5	14
101208	2020-07-22 10:34:13	2020-07-22	17	[{"id_menu":4,"count":1}]	18491	delivery	5	22
101209	2020-07-22 10:36:04	2020-07-22	9	[{"id_menu":6,"count":1}]	30002	delivery	5	14
101210	2020-07-22 10:39:00	2020-07-22	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	38297	delivery	5	40
101211	2020-07-22 10:40:16	2020-07-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	39079	pick-up	0	23
101212	2020-07-22 10:41:51	2020-07-22	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28658	delivery	5	34
101213	2020-07-22 10:42:00	2020-07-22	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1255	pick-up	0	29
101214	2020-07-22 10:42:41	2020-07-22	9	[{"id_menu":6,"count":1}]	12129	pick-up	0	9
101215	2020-07-22 10:47:39	2020-07-22	12	[{"id_menu":3,"count":1}]	13261	delivery	5	17
101216	2020-07-22 10:48:26	2020-07-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30162	delivery	5	23
101217	2020-07-22 10:50:51	2020-07-22	17	[{"id_menu":4,"count":1}]	33984	delivery	5	22
101218	2020-07-22 11:03:13	2020-07-22	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10633	delivery	5	46
101219	2020-07-22 11:04:06	2020-07-22	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	16922	delivery	5	25
101220	2020-07-22 11:05:31	2020-07-22	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16226	pick-up	0	35
101221	2020-07-22 11:10:15	2020-07-22	17	[{"id_menu":4,"count":1}]	17291	delivery	5	22
101222	2020-07-22 11:10:16	2020-07-22	17	[{"id_menu":4,"count":1}]	17531	delivery	5	22
101223	2020-07-22 11:17:09	2020-07-22	17	[{"id_menu":4,"count":1}]	8852	delivery	5	22
101224	2020-07-22 11:21:12	2020-07-22	12	[{"id_menu":1,"count":1}]	35719	delivery	5	17
101225	2020-07-22 11:23:08	2020-07-22	14	[{"id_menu":2,"count":1}]	26311	pick-up	0	14
101226	2020-07-22 11:23:14	2020-07-22	9	[{"id_menu":6,"count":1}]	16979	pick-up	0	9
101227	2020-07-22 11:23:46	2020-07-22	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11342	delivery	5	37
101228	2020-07-22 11:26:36	2020-07-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	15120	pick-up	0	23
101229	2020-07-22 11:29:17	2020-07-22	9	[{"id_menu":7,"count":1}]	7217	delivery	5	14
101230	2020-07-22 11:30:36	2020-07-22	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	39064	delivery	5	45
101231	2020-07-22 11:31:18	2020-07-22	8	[{"id_menu":5,"count":1}]	11794	delivery	5	13
101232	2020-07-22 11:32:45	2020-07-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2227	pick-up	0	31
101233	2020-07-22 11:32:51	2020-07-22	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	24274	pick-up	0	26
101234	2020-07-22 11:33:11	2020-07-22	17	[{"id_menu":4,"count":1}]	8137	pick-up	0	17
101235	2020-07-22 11:35:32	2020-07-22	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	10043	delivery	5	23
101236	2020-07-22 11:37:26	2020-07-22	12	[{"id_menu":3,"count":1}]	15641	delivery	5	17
101237	2020-07-22 11:38:19	2020-07-22	9	[{"id_menu":6,"count":1}]	39012	delivery	5	14
101238	2020-07-22 11:38:55	2020-07-22	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2283	delivery	5	57
101239	2020-07-22 11:39:23	2020-07-22	9	[{"id_menu":7,"count":1}]	8474	pick-up	0	9
101240	2020-07-22 11:40:46	2020-07-22	8	[{"id_menu":5,"count":1}]	32091	pick-up	0	8
101241	2020-07-22 11:42:08	2020-07-22	12	[{"id_menu":3,"count":1}]	39171	delivery	5	17
101242	2020-07-22 11:48:14	2020-07-22	9	[{"id_menu":7,"count":1}]	27026	delivery	5	14
101243	2020-07-22 11:49:08	2020-07-22	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8104	delivery	5	44
101244	2020-07-22 11:49:51	2020-07-22	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	34812	delivery	5	25
101245	2020-07-22 11:59:42	2020-07-22	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	39094	delivery	5	31
101246	2020-07-22 12:04:31	2020-07-22	17	[{"id_menu":4,"count":1}]	39002	delivery	5	22
101247	2020-07-22 12:09:13	2020-07-22	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	39150	delivery	5	40
101248	2020-07-22 12:11:35	2020-07-22	9	[{"id_menu":6,"count":1}]	39044	delivery	5	14
101249	2020-07-22 12:11:44	2020-07-22	12	[{"id_menu":1,"count":1}]	23561	pick-up	0	12
101250	2020-07-22 12:16:01	2020-07-22	9	[{"id_menu":7,"count":1}]	39233	delivery	5	14
101251	2020-07-22 12:17:04	2020-07-22	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35331	delivery	5	37
101252	2020-07-22 12:18:40	2020-07-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	39059	delivery	5	28
101253	2020-07-22 12:22:21	2020-07-22	9	[{"id_menu":6,"count":1}]	21461	delivery	5	14
101254	2020-07-22 12:26:40	2020-07-22	9	[{"id_menu":6,"count":1}]	6484	pick-up	0	9
101255	2020-07-22 12:29:52	2020-07-22	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1256	delivery	5	55
101256	2020-07-22 12:38:08	2020-07-22	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	9238	delivery	5	31
101257	2020-07-22 12:38:27	2020-07-22	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	36944	delivery	5	34
101258	2020-07-22 12:41:17	2020-07-22	14	[{"id_menu":2,"count":1}]	11812	delivery	5	19
101259	2020-07-22 12:42:07	2020-07-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7821	delivery	5	22
101260	2020-07-22 12:42:27	2020-07-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7741	pick-up	0	31
101261	2020-07-22 12:42:30	2020-07-22	17	[{"id_menu":4,"count":1}]	39096	delivery	5	22
101262	2020-07-22 12:43:13	2020-07-22	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	35332	delivery	5	36
101263	2020-07-22 12:47:06	2020-07-22	12	[{"id_menu":1,"count":1}]	11073	delivery	5	17
101264	2020-07-22 12:48:30	2020-07-22	17	[{"id_menu":4,"count":1}]	9030	delivery	5	22
101265	2020-07-22 12:49:47	2020-07-22	17	[{"id_menu":4,"count":1}]	3697	delivery	5	22
101266	2020-07-22 12:56:21	2020-07-22	9	[{"id_menu":6,"count":1}]	18897	delivery	5	14
101267	2020-07-22 12:58:27	2020-07-22	17	[{"id_menu":4,"count":1}]	21218	delivery	5	22
101268	2020-07-22 13:01:53	2020-07-22	9	[{"id_menu":6,"count":1}]	8877	delivery	5	14
101269	2020-07-22 13:02:19	2020-07-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	25941	delivery	5	28
101270	2020-07-22 13:02:25	2020-07-22	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7086	pick-up	0	17
101271	2020-07-22 13:02:51	2020-07-22	17	[{"id_menu":4,"count":1}]	39028	delivery	5	22
101272	2020-07-22 13:06:58	2020-07-22	14	[{"id_menu":2,"count":1}]	2614	pick-up	0	14
101273	2020-07-22 13:07:11	2020-07-22	9	[{"id_menu":6,"count":1}]	27875	delivery	5	14
101274	2020-07-22 13:07:51	2020-07-22	17	[{"id_menu":4,"count":2}]	7591	delivery	5	22
101275	2020-07-22 13:09:41	2020-07-22	14	[{"id_menu":2,"count":1}]	6152	delivery	5	19
101276	2020-07-22 13:11:21	2020-07-22	9	[{"id_menu":7,"count":1}]	26930	pick-up	0	9
101277	2020-07-22 13:11:51	2020-07-22	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	17318	delivery	5	25
101278	2020-07-22 13:22:16	2020-07-22	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	39122	delivery	5	22
101279	2020-07-22 13:24:28	2020-07-22	9	[{"id_menu":6,"count":1}]	31747	delivery	5	14
101280	2020-07-22 13:27:09	2020-07-22	9	[{"id_menu":6,"count":1}]	4054	pick-up	0	9
101281	2020-07-22 13:27:51	2020-07-22	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	38617	delivery	5	40
101282	2020-07-22 13:29:04	2020-07-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	39137	delivery	5	23
101283	2020-07-22 13:31:08	2020-07-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10670	delivery	5	23
101284	2020-07-22 13:33:15	2020-07-22	9	[{"id_menu":6,"count":1}]	12421	delivery	5	14
101285	2020-07-22 13:33:33	2020-07-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32548	delivery	5	23
101286	2020-07-22 13:40:09	2020-07-22	12	[{"id_menu":3,"count":1}]	35036	delivery	5	17
101287	2020-07-22 13:41:23	2020-07-22	9	[{"id_menu":6,"count":1}]	17149	delivery	5	14
101288	2020-07-22 13:42:26	2020-07-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	34304	delivery	5	28
101289	2020-07-22 13:43:45	2020-07-22	9	[{"id_menu":7,"count":1}]	32762	delivery	5	14
101290	2020-07-22 13:47:42	2020-07-22	14	[{"id_menu":2,"count":1}]	39183	pick-up	0	14
101291	2020-07-22 13:48:31	2020-07-22	17	[{"id_menu":4,"count":1}]	30839	pick-up	0	17
101292	2020-07-22 13:51:57	2020-07-22	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	39140	delivery	5	31
101293	2020-07-22 13:55:23	2020-07-22	9	[{"id_menu":7,"count":1}]	39029	delivery	5	14
101294	2020-07-22 13:55:38	2020-07-22	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	39118	delivery	5	34
101295	2020-07-22 13:56:16	2020-07-22	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	24671	delivery	5	42
101296	2020-07-22 13:57:33	2020-07-22	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	39000	delivery	5	26
101297	2020-07-22 13:57:47	2020-07-22	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	39072	delivery	5	36
101298	2020-07-22 13:58:15	2020-07-22	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28965	delivery	5	40
101299	2020-07-22 14:03:26	2020-07-22	9	[{"id_menu":6,"count":1}]	3847	pick-up	0	9
101300	2020-07-22 14:04:25	2020-07-22	14	[{"id_menu":2,"count":1}]	34427	delivery	5	19
101301	2020-07-22 14:04:37	2020-07-22	9	[{"id_menu":6,"count":1}]	2082	pick-up	0	9
101302	2020-07-22 14:05:50	2020-07-22	14	[{"id_menu":2,"count":1}]	6298	delivery	5	19
101303	2020-07-22 14:07:03	2020-07-22	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	39244	delivery	5	27
101304	2020-07-22 14:07:05	2020-07-22	8	[{"id_menu":5,"count":1}]	26344	delivery	5	13
101305	2020-07-22 14:07:15	2020-07-22	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	15018	delivery	5	27
101306	2020-07-22 14:10:32	2020-07-22	9	[{"id_menu":6,"count":1}]	30677	delivery	5	14
101307	2020-07-22 14:22:20	2020-07-22	9	[{"id_menu":7,"count":1}]	15276	delivery	5	14
101308	2020-07-22 14:24:57	2020-07-22	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39077	delivery	5	53
101309	2020-07-22 14:29:39	2020-07-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30504	delivery	5	23
101310	2020-07-22 14:33:03	2020-07-22	9	[{"id_menu":6,"count":1}]	22482	delivery	5	14
101311	2020-07-22 14:33:41	2020-07-22	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21038	delivery	5	34
101312	2020-07-22 14:34:28	2020-07-22	9	[{"id_menu":6,"count":1}]	19287	pick-up	0	9
101313	2020-07-22 14:38:51	2020-07-22	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	39112	delivery	5	34
101314	2020-07-22 14:44:09	2020-07-22	14	[{"id_menu":2,"count":1}]	20756	delivery	5	19
101315	2020-07-22 14:48:35	2020-07-22	14	[{"id_menu":2,"count":1}]	1327	pick-up	0	14
101316	2020-07-22 14:49:43	2020-07-22	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1322	delivery	5	31
101317	2020-07-22 14:54:16	2020-07-22	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	39070	delivery	5	26
101318	2020-07-22 14:55:01	2020-07-22	12	[{"id_menu":3,"count":1}]	19857	delivery	5	17
101319	2020-07-22 14:59:19	2020-07-22	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	38476	delivery	5	45
101320	2020-07-22 14:59:24	2020-07-22	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	39177	pick-up	0	29
101321	2020-07-22 15:02:29	2020-07-22	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39098	delivery	5	34
101322	2020-07-22 15:06:02	2020-07-22	14	[{"id_menu":2,"count":1}]	12322	delivery	5	19
101323	2020-07-22 15:06:35	2020-07-22	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	21628	delivery	5	34
101324	2020-07-22 15:08:23	2020-07-22	14	[{"id_menu":2,"count":1}]	39131	delivery	5	19
101325	2020-07-22 15:14:12	2020-07-22	29	[{"id_menu":3,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39037	delivery	5	34
101326	2020-07-22 15:16:51	2020-07-22	12	[{"id_menu":1,"count":1}]	17911	delivery	5	17
101327	2020-07-22 15:22:08	2020-07-22	9	[{"id_menu":6,"count":2}]	39031	delivery	5	14
101328	2020-07-22 15:22:25	2020-07-22	9	[{"id_menu":7,"count":1}]	12889	pick-up	0	9
101329	2020-07-22 15:24:50	2020-07-22	8	[{"id_menu":5,"count":1}]	32855	delivery	5	13
101330	2020-07-22 15:28:22	2020-07-22	14	[{"id_menu":2,"count":1}]	12389	delivery	5	19
101331	2020-07-22 15:28:59	2020-07-22	12	[{"id_menu":1,"count":1}]	39141	delivery	5	17
101332	2020-07-22 15:31:52	2020-07-22	17	[{"id_menu":4,"count":1}]	22614	pick-up	0	17
101333	2020-07-22 15:33:26	2020-07-22	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	32947	delivery	5	27
101334	2020-07-22 15:37:46	2020-07-22	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	17790	delivery	5	31
101335	2020-07-22 15:38:10	2020-07-22	9	[{"id_menu":6,"count":2}]	38392	delivery	5	14
101336	2020-07-22 15:39:32	2020-07-22	12	[{"id_menu":3,"count":1}]	39030	delivery	5	17
101337	2020-07-22 15:44:19	2020-07-22	14	[{"id_menu":2,"count":1}]	2633	pick-up	0	14
101338	2020-07-22 15:44:26	2020-07-22	9	[{"id_menu":7,"count":1}]	15602	delivery	5	14
101339	2020-07-22 15:46:25	2020-07-22	9	[{"id_menu":6,"count":1}]	6243	pick-up	0	9
101340	2020-07-22 15:47:15	2020-07-22	12	[{"id_menu":3,"count":1}]	10308	delivery	5	17
101341	2020-07-22 15:48:01	2020-07-22	12	[{"id_menu":3,"count":1}]	21493	delivery	5	17
101342	2020-07-22 15:49:23	2020-07-22	12	[{"id_menu":3,"count":1}]	31554	delivery	5	17
101343	2020-07-22 15:51:44	2020-07-22	14	[{"id_menu":2,"count":1}]	2371	pick-up	0	14
101344	2020-07-22 15:52:37	2020-07-22	12	[{"id_menu":3,"count":1}]	39204	delivery	5	17
101345	2020-07-22 15:53:36	2020-07-22	17	[{"id_menu":4,"count":1}]	36980	delivery	5	22
101346	2020-07-22 16:01:21	2020-07-22	9	[{"id_menu":7,"count":1}]	22643	pick-up	0	9
101347	2020-07-22 16:05:39	2020-07-22	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	39109	delivery	5	31
101348	2020-07-22 16:07:53	2020-07-22	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	25444	delivery	5	37
101349	2020-07-22 16:08:11	2020-07-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	28851	delivery	5	28
101350	2020-07-22 16:10:32	2020-07-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13651	pick-up	0	17
101351	2020-07-22 16:12:10	2020-07-22	9	[{"id_menu":6,"count":1}]	26567	delivery	5	14
101352	2020-07-22 16:12:32	2020-07-22	14	[{"id_menu":2,"count":1}]	39110	delivery	5	19
101353	2020-07-22 16:12:58	2020-07-22	17	[{"id_menu":4,"count":1}]	1756	pick-up	0	17
101354	2020-07-22 16:13:08	2020-07-22	9	[{"id_menu":6,"count":1}]	39068	delivery	5	14
101355	2020-07-22 16:14:04	2020-07-22	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	16871	delivery	5	27
101356	2020-07-22 16:20:47	2020-07-22	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2232	pick-up	0	29
101357	2020-07-22 16:31:26	2020-07-22	8	[{"id_menu":5,"count":2}]	39087	delivery	5	13
101358	2020-07-22 16:33:27	2020-07-22	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	24356	delivery	5	25
101359	2020-07-22 16:35:07	2020-07-22	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	39050	delivery	5	37
101360	2020-07-22 16:35:13	2020-07-22	12	[{"id_menu":3,"count":1}]	27861	pick-up	0	12
101361	2020-07-22 16:37:56	2020-07-22	9	[{"id_menu":7,"count":1}]	39219	delivery	5	14
101362	2020-07-22 16:41:02	2020-07-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2443	delivery	5	28
101363	2020-07-22 16:41:52	2020-07-22	12	[{"id_menu":1,"count":2}]	1513	delivery	5	17
101364	2020-07-22 16:51:00	2020-07-22	8	[{"id_menu":5,"count":1}]	36355	delivery	5	13
101365	2020-07-22 16:52:13	2020-07-22	8	[{"id_menu":5,"count":1}]	16844	pick-up	0	8
101366	2020-07-22 16:57:23	2020-07-22	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38457	delivery	5	31
101367	2020-07-22 16:57:25	2020-07-22	9	[{"id_menu":6,"count":1}]	2613	pick-up	0	9
101368	2020-07-22 16:58:46	2020-07-22	12	[{"id_menu":1,"count":1}]	28478	delivery	5	17
101369	2020-07-22 16:59:31	2020-07-22	12	[{"id_menu":3,"count":1}]	1072	pick-up	0	12
101370	2020-07-22 17:05:00	2020-07-22	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	39190	delivery	5	43
101371	2020-07-22 17:07:34	2020-07-22	9	[{"id_menu":7,"count":1}]	21387	delivery	5	14
101372	2020-07-22 17:09:23	2020-07-22	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39034	delivery	5	34
101373	2020-07-22 17:11:45	2020-07-22	12	[{"id_menu":3,"count":1}]	38741	pick-up	0	12
101374	2020-07-22 17:12:05	2020-07-22	9	[{"id_menu":7,"count":1}]	21848	delivery	5	14
101375	2020-07-22 17:15:47	2020-07-22	9	[{"id_menu":7,"count":2}]	27399	delivery	5	14
101376	2020-07-22 17:16:51	2020-07-22	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	39126	delivery	5	34
101377	2020-07-22 17:20:20	2020-07-22	14	[{"id_menu":2,"count":1}]	5106	delivery	5	19
101378	2020-07-22 17:23:48	2020-07-22	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	26684	pick-up	0	24
101379	2020-07-22 17:25:30	2020-07-22	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11240	delivery	5	31
101380	2020-07-22 17:26:37	2020-07-22	8	[{"id_menu":5,"count":1}]	33827	pick-up	0	8
101381	2020-07-22 17:29:27	2020-07-22	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	39223	delivery	5	40
101382	2020-07-22 17:30:26	2020-07-22	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	27	pick-up	0	29
101383	2020-07-22 17:32:56	2020-07-22	8	[{"id_menu":5,"count":1}]	245	pick-up	0	8
101384	2020-07-22 17:33:36	2020-07-22	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13713	delivery	5	37
101385	2020-07-22 17:38:55	2020-07-22	9	[{"id_menu":6,"count":1}]	39076	delivery	5	14
101386	2020-07-22 17:40:36	2020-07-22	9	[{"id_menu":7,"count":1}]	39209	pick-up	0	9
101387	2020-07-22 17:41:38	2020-07-22	12	[{"id_menu":3,"count":1}]	20455	delivery	5	17
101388	2020-07-22 17:43:07	2020-07-22	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	33795	delivery	5	26
101389	2020-07-22 17:43:27	2020-07-22	9	[{"id_menu":6,"count":1}]	17695	delivery	5	14
101390	2020-07-22 17:44:15	2020-07-22	9	[{"id_menu":7,"count":1}]	39133	pick-up	0	9
101391	2020-07-22 17:45:06	2020-07-22	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23717	delivery	5	49
101392	2020-07-22 17:45:29	2020-07-22	14	[{"id_menu":2,"count":1}]	1140	pick-up	0	14
101393	2020-07-22 17:48:45	2020-07-22	8	[{"id_menu":5,"count":1}]	4847	pick-up	0	8
101394	2020-07-22 17:50:06	2020-07-22	8	[{"id_menu":5,"count":1}]	26208	pick-up	0	8
101395	2020-07-22 17:50:30	2020-07-22	9	[{"id_menu":7,"count":1}]	39178	delivery	5	14
101396	2020-07-22 17:50:39	2020-07-22	17	[{"id_menu":4,"count":1}]	16815	pick-up	0	17
101397	2020-07-22 17:52:46	2020-07-22	12	[{"id_menu":1,"count":1}]	39195	delivery	5	17
101398	2020-07-22 17:52:50	2020-07-22	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	39197	delivery	5	22
101399	2020-07-22 17:54:54	2020-07-22	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1934	pick-up	0	43
101400	2020-07-22 17:56:24	2020-07-22	17	[{"id_menu":4,"count":1}]	39058	delivery	5	22
101401	2020-07-22 17:56:28	2020-07-22	9	[{"id_menu":7,"count":1}]	20235	delivery	5	14
101402	2020-07-22 17:57:34	2020-07-22	9	[{"id_menu":7,"count":1}]	22188	pick-up	0	9
101403	2020-07-22 17:57:49	2020-07-22	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	39218	delivery	5	27
101404	2020-07-22 17:58:36	2020-07-22	17	[{"id_menu":4,"count":1}]	32601	delivery	5	22
101405	2020-07-22 17:58:59	2020-07-22	9	[{"id_menu":6,"count":2}]	39073	delivery	5	14
101406	2020-07-22 18:00:14	2020-07-22	12	[{"id_menu":3,"count":1}]	2448	pick-up	0	12
101407	2020-07-22 18:00:27	2020-07-22	12	[{"id_menu":3,"count":1}]	18253	pick-up	0	12
101408	2020-07-22 18:02:00	2020-07-22	9	[{"id_menu":6,"count":1}]	39011	delivery	5	14
101409	2020-07-22 18:08:19	2020-07-22	9	[{"id_menu":6,"count":1}]	153	delivery	5	14
101410	2020-07-22 18:08:43	2020-07-22	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	39119	pick-up	0	29
101411	2020-07-22 18:09:37	2020-07-22	12	[{"id_menu":3,"count":1}]	39099	delivery	5	17
101412	2020-07-22 18:10:58	2020-07-22	9	[{"id_menu":7,"count":1}]	26132	delivery	5	14
101413	2020-07-22 18:13:16	2020-07-22	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	988	delivery	5	43
101414	2020-07-22 18:13:43	2020-07-22	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	33916	delivery	5	30
101415	2020-07-22 18:14:26	2020-07-22	9	[{"id_menu":7,"count":1}]	16813	pick-up	0	9
101416	2020-07-22 18:18:22	2020-07-22	9	[{"id_menu":6,"count":1}]	39124	delivery	5	14
101417	2020-07-22 18:19:00	2020-07-22	9	[{"id_menu":6,"count":1}]	6156	pick-up	0	9
101418	2020-07-22 18:20:00	2020-07-22	9	[{"id_menu":6,"count":1}]	39212	delivery	5	14
101419	2020-07-22 18:20:15	2020-07-22	17	[{"id_menu":4,"count":1}]	7677	delivery	5	22
101420	2020-07-22 18:23:40	2020-07-22	9	[{"id_menu":6,"count":1}]	39089	delivery	5	14
101421	2020-07-22 18:26:20	2020-07-22	9	[{"id_menu":6,"count":1}]	1765	delivery	5	14
101422	2020-07-22 18:26:54	2020-07-22	17	[{"id_menu":4,"count":1}]	27089	delivery	5	22
101423	2020-07-22 18:29:46	2020-07-22	8	[{"id_menu":5,"count":1}]	39008	delivery	5	13
101424	2020-07-22 18:31:21	2020-07-22	12	[{"id_menu":3,"count":1}]	3648	delivery	5	17
101425	2020-07-22 18:31:28	2020-07-22	17	[{"id_menu":4,"count":1}]	31997	pick-up	0	17
101426	2020-07-22 18:32:25	2020-07-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	27161	pick-up	0	18
101427	2020-07-22 18:35:16	2020-07-22	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3567	pick-up	0	21
101428	2020-07-22 18:35:23	2020-07-22	9	[{"id_menu":6,"count":1}]	39149	delivery	5	14
101429	2020-07-22 18:43:12	2020-07-22	8	[{"id_menu":5,"count":1}]	7051	pick-up	0	8
101430	2020-07-22 18:43:58	2020-07-22	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12934	delivery	5	37
101431	2020-07-22 18:45:54	2020-07-22	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31509	pick-up	0	34
101432	2020-07-22 18:46:08	2020-07-22	9	[{"id_menu":6,"count":1}]	39116	delivery	5	14
101433	2020-07-22 18:50:01	2020-07-22	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	3871	delivery	5	31
101434	2020-07-22 18:50:56	2020-07-22	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	39102	delivery	5	39
101435	2020-07-22 18:56:15	2020-07-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7069	pick-up	0	23
101436	2020-07-22 18:57:28	2020-07-22	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39139	delivery	5	39
101437	2020-07-22 18:59:47	2020-07-22	14	[{"id_menu":2,"count":1}]	39239	delivery	5	19
101438	2020-07-22 19:04:20	2020-07-22	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	39227	delivery	5	43
101439	2020-07-22 19:06:56	2020-07-22	9	[{"id_menu":6,"count":1}]	36502	delivery	5	14
101440	2020-07-22 19:08:18	2020-07-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	30335	delivery	5	36
101441	2020-07-22 19:10:51	2020-07-22	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23334	delivery	5	31
101442	2020-07-22 19:12:57	2020-07-22	9	[{"id_menu":6,"count":1}]	39138	pick-up	0	9
101443	2020-07-22 19:16:11	2020-07-22	9	[{"id_menu":6,"count":1}]	24355	delivery	5	14
101444	2020-07-22 19:17:12	2020-07-22	9	[{"id_menu":7,"count":1}]	14610	delivery	5	14
101445	2020-07-22 19:18:59	2020-07-22	17	[{"id_menu":4,"count":1}]	13341	delivery	5	22
101446	2020-07-22 19:20:21	2020-07-22	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	38450	delivery	5	31
101447	2020-07-22 19:24:24	2020-07-22	17	[{"id_menu":4,"count":1}]	14388	delivery	5	22
101448	2020-07-22 19:28:00	2020-07-22	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	39241	pick-up	0	21
101449	2020-07-22 19:32:07	2020-07-22	17	[{"id_menu":4,"count":1}]	20797	pick-up	0	17
101450	2020-07-22 19:32:21	2020-07-22	14	[{"id_menu":2,"count":1}]	14591	delivery	5	19
101451	2020-07-22 19:35:55	2020-07-22	12	[{"id_menu":3,"count":1}]	28227	delivery	5	17
101452	2020-07-22 19:36:40	2020-07-22	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	39042	delivery	5	26
101453	2020-07-22 19:37:43	2020-07-22	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	39168	delivery	5	45
101454	2020-07-22 19:38:59	2020-07-22	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	184	pick-up	0	34
101455	2020-07-22 19:43:35	2020-07-22	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	18916	pick-up	0	24
101456	2020-07-22 19:45:24	2020-07-22	12	[{"id_menu":3,"count":1}]	17582	delivery	5	17
101457	2020-07-22 19:46:38	2020-07-22	9	[{"id_menu":6,"count":2}]	39231	delivery	5	14
101458	2020-07-22 19:49:47	2020-07-22	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	39238	pick-up	0	20
101459	2020-07-22 19:51:18	2020-07-22	9	[{"id_menu":6,"count":1}]	27648	delivery	5	14
101460	2020-07-22 19:53:44	2020-07-22	9	[{"id_menu":6,"count":1}]	39170	delivery	5	14
101461	2020-07-22 19:56:20	2020-07-22	8	[{"id_menu":5,"count":1}]	39232	delivery	5	13
101462	2020-07-22 19:58:12	2020-07-22	9	[{"id_menu":6,"count":1}]	15440	pick-up	0	9
101463	2020-07-22 20:03:41	2020-07-22	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	13226	delivery	5	36
101464	2020-07-22 20:04:50	2020-07-22	14	[{"id_menu":2,"count":1}]	2295	pick-up	0	14
101465	2020-07-22 20:06:43	2020-07-22	12	[{"id_menu":1,"count":1}]	39092	delivery	5	17
101466	2020-07-22 20:07:15	2020-07-22	12	[{"id_menu":1,"count":1}]	21288	delivery	5	17
101467	2020-07-22 20:09:40	2020-07-22	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	39186	pick-up	0	21
101468	2020-07-22 20:11:08	2020-07-22	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	36823	delivery	5	42
101469	2020-07-22 20:13:43	2020-07-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31610	pick-up	0	17
101470	2020-07-22 20:17:02	2020-07-22	17	[{"id_menu":4,"count":1}]	39065	delivery	5	22
101471	2020-07-22 20:22:52	2020-07-22	14	[{"id_menu":2,"count":1}]	27011	delivery	5	19
101472	2020-07-22 20:26:36	2020-07-22	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	39206	delivery	5	39
101473	2020-07-22 20:33:33	2020-07-22	14	[{"id_menu":2,"count":2}]	8426	delivery	5	19
101474	2020-07-22 20:35:03	2020-07-22	9	[{"id_menu":7,"count":1}]	2615	pick-up	0	9
101475	2020-07-22 20:38:25	2020-07-22	17	[{"id_menu":4,"count":1}]	39001	delivery	5	22
101476	2020-07-22 20:45:33	2020-07-22	9	[{"id_menu":7,"count":1}]	35003	delivery	5	14
101477	2020-07-22 20:46:52	2020-07-22	8	[{"id_menu":5,"count":1}]	39022	delivery	5	13
101478	2020-07-22 20:47:57	2020-07-22	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10005	delivery	5	45
101479	2020-07-22 20:54:24	2020-07-22	14	[{"id_menu":2,"count":1}]	30687	pick-up	0	14
101480	2020-07-22 20:54:24	2020-07-22	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	22334	delivery	5	23
101481	2020-07-22 20:56:44	2020-07-22	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39176	delivery	5	49
101482	2020-07-22 20:56:55	2020-07-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39043	delivery	5	22
101483	2020-07-22 20:58:01	2020-07-22	12	[{"id_menu":1,"count":1}]	39173	pick-up	0	12
101484	2020-07-22 20:59:00	2020-07-22	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	38196	delivery	5	42
101485	2020-07-22 20:59:03	2020-07-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19717	pick-up	0	18
101486	2020-07-22 21:01:55	2020-07-22	12	[{"id_menu":1,"count":1}]	16099	delivery	5	17
101487	2020-07-22 21:04:14	2020-07-22	9	[{"id_menu":6,"count":1}]	39224	delivery	5	14
101488	2020-07-22 21:08:40	2020-07-22	9	[{"id_menu":7,"count":1}]	39023	delivery	5	14
101489	2020-07-22 21:09:08	2020-07-22	12	[{"id_menu":1,"count":1}]	27429	pick-up	0	12
101490	2020-07-22 21:09:48	2020-07-22	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	4192	delivery	5	26
101491	2020-07-22 21:10:19	2020-07-22	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39213	delivery	5	35
101492	2020-07-22 21:10:45	2020-07-22	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	1000	pick-up	0	37
101493	2020-07-22 21:13:17	2020-07-22	9	[{"id_menu":6,"count":2}]	39135	delivery	5	14
101494	2020-07-22 21:30:08	2020-07-22	9	[{"id_menu":7,"count":1}]	10935	pick-up	0	9
101495	2020-07-22 21:35:32	2020-07-22	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6637	delivery	5	43
101496	2020-07-22 21:36:03	2020-07-22	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39120	delivery	5	35
101497	2020-07-22 21:36:48	2020-07-22	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	39194	delivery	5	34
101498	2020-07-22 21:39:07	2020-07-22	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	6173	pick-up	0	20
101499	2020-07-22 21:39:17	2020-07-22	12	[{"id_menu":3,"count":1}]	11083	pick-up	0	12
101500	2020-07-22 21:39:18	2020-07-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39057	delivery	5	22
101501	2020-07-22 21:42:13	2020-07-22	12	[{"id_menu":1,"count":1}]	11681	delivery	5	17
101502	2020-07-22 21:43:12	2020-07-22	14	[{"id_menu":2,"count":1}]	39055	delivery	5	19
101503	2020-07-22 21:43:35	2020-07-22	14	[{"id_menu":2,"count":1}]	16887	delivery	5	19
101504	2020-07-22 21:48:57	2020-07-22	9	[{"id_menu":6,"count":2}]	39020	delivery	5	14
101505	2020-07-22 21:49:31	2020-07-22	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	5344	delivery	5	31
101506	2020-07-22 21:51:15	2020-07-22	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	39205	delivery	5	22
101507	2020-07-22 21:53:56	2020-07-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39236	delivery	5	23
101508	2020-07-22 21:58:21	2020-07-22	14	[{"id_menu":2,"count":1}]	36025	delivery	5	19
101509	2020-07-22 21:58:40	2020-07-22	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39208	delivery	5	52
101510	2020-07-22 22:03:37	2020-07-22	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38576	delivery	5	35
101511	2020-07-22 22:04:38	2020-07-22	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	21290	delivery	5	26
101512	2020-07-22 22:06:09	2020-07-22	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39185	delivery	5	37
101513	2020-07-22 22:06:16	2020-07-22	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	26165	pick-up	0	26
101514	2020-07-22 22:07:39	2020-07-22	17	[{"id_menu":4,"count":1}]	35759	delivery	5	22
101515	2020-07-22 22:10:25	2020-07-22	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	39101	delivery	5	31
101516	2020-07-22 22:16:59	2020-07-22	9	[{"id_menu":7,"count":1}]	6182	pick-up	0	9
101517	2020-07-22 22:18:48	2020-07-22	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1847	pick-up	0	21
101518	2020-07-22 22:18:55	2020-07-22	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	25530	delivery	5	31
101519	2020-07-22 22:23:08	2020-07-22	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39163	delivery	5	35
101520	2020-07-22 22:25:41	2020-07-22	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29905	delivery	5	22
101521	2020-07-22 22:27:05	2020-07-22	9	[{"id_menu":7,"count":1}]	30766	pick-up	0	9
101522	2020-07-22 22:28:13	2020-07-22	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16068	delivery	5	34
101523	2020-07-22 22:30:20	2020-07-22	9	[{"id_menu":6,"count":2}]	39234	delivery	5	14
101524	2020-07-22 22:31:01	2020-07-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39047	pick-up	0	17
101525	2020-07-22 22:34:21	2020-07-22	9	[{"id_menu":7,"count":2}]	39240	delivery	5	14
101526	2020-07-22 22:36:37	2020-07-22	8	[{"id_menu":5,"count":1}]	39228	delivery	5	13
101527	2020-07-22 22:37:58	2020-07-22	17	[{"id_menu":4,"count":1}]	10382	delivery	5	22
101528	2020-07-22 22:38:29	2020-07-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	33022	pick-up	0	23
101529	2020-07-22 22:39:34	2020-07-22	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	36053	delivery	5	26
101530	2020-07-22 22:41:15	2020-07-22	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	2599	pick-up	0	40
101531	2020-07-22 22:42:21	2020-07-22	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	39121	delivery	5	26
101532	2020-07-22 22:45:13	2020-07-22	9	[{"id_menu":7,"count":1}]	4161	delivery	5	14
101533	2020-07-22 22:52:27	2020-07-22	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	3385	delivery	5	31
101534	2020-07-22 22:54:23	2020-07-22	14	[{"id_menu":2,"count":1}]	39144	delivery	5	19
101535	2020-07-22 22:56:07	2020-07-22	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	39074	delivery	5	57
101536	2020-07-22 22:56:30	2020-07-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	12912	pick-up	0	23
101537	2020-07-22 23:02:13	2020-07-22	8	[{"id_menu":5,"count":1}]	39181	delivery	5	13
101538	2020-07-22 23:07:06	2020-07-22	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	39180	delivery	5	22
101539	2020-07-22 23:15:38	2020-07-22	9	[{"id_menu":6,"count":1}]	19866	delivery	5	14
101540	2020-07-22 23:15:40	2020-07-22	9	[{"id_menu":6,"count":1}]	39091	delivery	5	14
101541	2020-07-22 23:17:58	2020-07-22	8	[{"id_menu":5,"count":1}]	683	pick-up	0	8
101542	2020-07-22 23:18:55	2020-07-22	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	39158	pick-up	0	26
101543	2020-07-22 23:19:15	2020-07-22	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	5526	delivery	5	26
101544	2020-07-22 23:20:12	2020-07-22	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	14763	delivery	5	45
101545	2020-07-22 23:21:33	2020-07-22	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	7020	delivery	5	31
101546	2020-07-22 23:25:40	2020-07-22	9	[{"id_menu":6,"count":1}]	26515	delivery	5	14
101547	2020-07-22 23:26:31	2020-07-22	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2850	delivery	5	39
101548	2020-07-22 23:29:26	2020-07-22	9	[{"id_menu":6,"count":1}]	4451	pick-up	0	9
101549	2020-07-22 23:29:27	2020-07-22	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":3}]	39187	delivery	5	31
101550	2020-07-22 23:30:22	2020-07-22	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	22464	pick-up	0	26
101551	2020-07-22 23:30:44	2020-07-22	12	[{"id_menu":1,"count":1}]	39108	delivery	5	17
101552	2020-07-22 23:32:03	2020-07-22	17	[{"id_menu":4,"count":1}]	39229	delivery	5	22
101553	2020-07-22 23:34:32	2020-07-22	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	25852	pick-up	0	51
101554	2020-07-22 23:39:32	2020-07-22	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	35249	delivery	5	40
101555	2020-07-22 23:39:50	2020-07-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	7792	delivery	5	22
101556	2020-07-22 23:47:21	2020-07-22	14	[{"id_menu":2,"count":1}]	4798	pick-up	0	14
101557	2020-07-22 23:47:28	2020-07-22	9	[{"id_menu":6,"count":1}]	33647	delivery	5	14
101558	2020-07-22 23:47:49	2020-07-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	39117	delivery	5	28
101559	2020-07-22 23:48:04	2020-07-22	12	[{"id_menu":3,"count":1}]	7725	delivery	5	17
101560	2020-07-22 23:48:38	2020-07-22	12	[{"id_menu":1,"count":1}]	29655	delivery	5	17
101561	2020-07-22 23:48:54	2020-07-22	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	39018	delivery	5	30
101562	2020-07-22 23:49:14	2020-07-22	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6776	delivery	5	48
101563	2020-07-22 23:49:43	2020-07-22	17	[{"id_menu":4,"count":1}]	7963	pick-up	0	17
101564	2020-07-22 23:56:51	2020-07-22	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	16706	delivery	5	44
101565	2020-07-22 23:56:56	2020-07-22	17	[{"id_menu":4,"count":1}]	39246	delivery	5	22
101566	2020-07-23 00:00:03	2020-07-23	12	[{"id_menu":1,"count":1}]	19047	delivery	5	17
101567	2020-07-23 00:04:02	2020-07-23	37	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2131	pick-up	0	37
101568	2020-07-23 00:04:56	2020-07-23	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	39274	delivery	5	34
101569	2020-07-23 00:05:28	2020-07-23	9	[{"id_menu":6,"count":1}]	5487	delivery	5	14
101570	2020-07-23 00:05:51	2020-07-23	12	[{"id_menu":1,"count":1}]	39350	delivery	5	17
101571	2020-07-23 00:11:04	2020-07-23	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	39373	delivery	5	35
101572	2020-07-23 00:17:48	2020-07-23	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39414	delivery	5	40
101573	2020-07-23 00:18:27	2020-07-23	9	[{"id_menu":7,"count":1}]	39404	delivery	5	14
101574	2020-07-23 00:21:13	2020-07-23	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	31432	delivery	5	43
101575	2020-07-23 00:21:17	2020-07-23	9	[{"id_menu":6,"count":3}]	11161	delivery	5	14
101576	2020-07-23 00:24:20	2020-07-23	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	20191	delivery	5	39
101577	2020-07-23 00:29:34	2020-07-23	9	[{"id_menu":6,"count":2}]	39311	delivery	5	14
101578	2020-07-23 00:29:43	2020-07-23	9	[{"id_menu":6,"count":1}]	23061	delivery	5	14
101579	2020-07-23 00:31:36	2020-07-23	9	[{"id_menu":7,"count":1}]	39305	delivery	5	14
101580	2020-07-23 00:34:09	2020-07-23	17	[{"id_menu":4,"count":1}]	8924	delivery	5	22
101581	2020-07-23 00:36:40	2020-07-23	12	[{"id_menu":3,"count":1}]	23642	delivery	5	17
101582	2020-07-23 00:37:23	2020-07-23	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4562	pick-up	0	26
101583	2020-07-23 00:38:14	2020-07-23	9	[{"id_menu":7,"count":1}]	34208	pick-up	0	9
101584	2020-07-23 00:38:49	2020-07-23	8	[{"id_menu":5,"count":4}]	15819	delivery	5	13
101585	2020-07-23 00:39:00	2020-07-23	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	39312	delivery	5	22
101586	2020-07-23 00:41:32	2020-07-23	8	[{"id_menu":5,"count":1}]	1978	pick-up	0	8
101587	2020-07-23 00:41:40	2020-07-23	9	[{"id_menu":7,"count":1}]	10651	delivery	5	14
101588	2020-07-23 00:44:56	2020-07-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	14864	delivery	5	28
101589	2020-07-23 00:47:22	2020-07-23	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	10670	delivery	5	52
101590	2020-07-23 00:49:00	2020-07-23	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	31448	delivery	5	31
101591	2020-07-23 00:50:26	2020-07-23	9	[{"id_menu":7,"count":1}]	17174	delivery	5	14
101592	2020-07-23 00:51:41	2020-07-23	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38787	delivery	5	31
101593	2020-07-23 00:53:07	2020-07-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	38219	delivery	5	31
101594	2020-07-23 00:58:24	2020-07-23	14	[{"id_menu":2,"count":1}]	37078	pick-up	0	14
101595	2020-07-23 01:03:53	2020-07-23	9	[{"id_menu":7,"count":1}]	10068	delivery	5	14
101596	2020-07-23 01:06:42	2020-07-23	9	[{"id_menu":6,"count":1}]	39409	pick-up	0	9
101597	2020-07-23 01:10:26	2020-07-23	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	24201	delivery	5	31
101598	2020-07-23 01:11:03	2020-07-23	12	[{"id_menu":1,"count":1}]	10935	pick-up	0	12
101599	2020-07-23 01:12:36	2020-07-23	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	30911	delivery	5	36
101600	2020-07-23 01:12:50	2020-07-23	12	[{"id_menu":1,"count":1}]	1836	pick-up	0	12
101601	2020-07-23 01:14:33	2020-07-23	17	[{"id_menu":4,"count":1}]	32564	delivery	5	22
101602	2020-07-23 01:14:41	2020-07-23	9	[{"id_menu":7,"count":1}]	37598	delivery	5	14
101603	2020-07-23 01:17:12	2020-07-23	12	[{"id_menu":3,"count":1}]	26377	delivery	5	17
101604	2020-07-23 01:21:25	2020-07-23	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	39411	delivery	5	26
101605	2020-07-23 01:21:40	2020-07-23	8	[{"id_menu":5,"count":1}]	4178	delivery	5	13
101606	2020-07-23 01:27:52	2020-07-23	8	[{"id_menu":5,"count":1}]	23881	pick-up	0	8
101607	2020-07-23 01:28:19	2020-07-23	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	27544	pick-up	0	20
101608	2020-07-23 01:29:02	2020-07-23	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8149	delivery	5	46
101609	2020-07-23 01:30:20	2020-07-23	14	[{"id_menu":2,"count":1}]	14710	pick-up	0	14
101610	2020-07-23 01:33:24	2020-07-23	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	9148	delivery	5	29
101611	2020-07-23 01:36:30	2020-07-23	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	28688	delivery	5	26
101612	2020-07-23 01:36:40	2020-07-23	9	[{"id_menu":7,"count":1}]	3002	delivery	5	14
101613	2020-07-23 01:39:55	2020-07-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	21793	delivery	5	31
101614	2020-07-23 01:40:01	2020-07-23	9	[{"id_menu":6,"count":1}]	39249	delivery	5	14
101615	2020-07-23 01:44:50	2020-07-23	12	[{"id_menu":1,"count":1}]	1373	pick-up	0	12
101616	2020-07-23 01:47:04	2020-07-23	29	[{"id_menu":3,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18069	delivery	5	34
101617	2020-07-23 01:50:17	2020-07-23	14	[{"id_menu":2,"count":2}]	32948	pick-up	0	14
101618	2020-07-23 01:52:33	2020-07-23	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	27484	delivery	5	31
101619	2020-07-23 01:52:53	2020-07-23	9	[{"id_menu":7,"count":1}]	39342	delivery	5	14
101620	2020-07-23 01:53:17	2020-07-23	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	21271	delivery	5	31
101621	2020-07-23 01:53:23	2020-07-23	8	[{"id_menu":5,"count":1}]	9816	pick-up	0	8
101622	2020-07-23 01:53:26	2020-07-23	8	[{"id_menu":5,"count":2}]	7192	delivery	5	13
101623	2020-07-23 01:55:29	2020-07-23	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1038	delivery	5	26
101624	2020-07-23 02:05:48	2020-07-23	9	[{"id_menu":7,"count":1}]	12197	delivery	5	14
101625	2020-07-23 02:08:34	2020-07-23	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3755	delivery	5	30
101626	2020-07-23 02:08:38	2020-07-23	14	[{"id_menu":2,"count":1}]	11163	delivery	5	19
101627	2020-07-23 02:09:29	2020-07-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37956	delivery	5	23
101628	2020-07-23 02:10:59	2020-07-23	8	[{"id_menu":5,"count":1}]	39343	delivery	5	13
101629	2020-07-23 02:14:37	2020-07-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39375	delivery	5	23
101630	2020-07-23 02:21:12	2020-07-23	9	[{"id_menu":6,"count":1}]	27089	delivery	5	14
101631	2020-07-23 02:23:12	2020-07-23	9	[{"id_menu":6,"count":1}]	30230	delivery	5	14
101632	2020-07-23 02:24:39	2020-07-23	17	[{"id_menu":4,"count":1}]	39270	delivery	5	22
101633	2020-07-23 02:24:43	2020-07-23	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	29722	delivery	5	45
101634	2020-07-23 02:33:27	2020-07-23	14	[{"id_menu":2,"count":1}]	39418	delivery	5	19
101635	2020-07-23 02:35:51	2020-07-23	12	[{"id_menu":1,"count":1}]	39435	delivery	5	17
101636	2020-07-23 02:39:11	2020-07-23	12	[{"id_menu":1,"count":1}]	39283	pick-up	0	12
101637	2020-07-23 02:43:45	2020-07-23	9	[{"id_menu":6,"count":1}]	39362	delivery	5	14
101638	2020-07-23 02:45:54	2020-07-23	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	39417	delivery	5	40
101639	2020-07-23 02:47:57	2020-07-23	9	[{"id_menu":6,"count":1}]	39271	delivery	5	14
101640	2020-07-23 02:48:00	2020-07-23	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	39324	delivery	5	31
101641	2020-07-23 02:50:54	2020-07-23	8	[{"id_menu":5,"count":1}]	28808	delivery	5	13
101642	2020-07-23 02:51:48	2020-07-23	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	39379	delivery	5	27
101643	2020-07-23 02:56:30	2020-07-23	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	21825	pick-up	0	29
101644	2020-07-23 02:59:20	2020-07-23	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	30356	delivery	5	46
101645	2020-07-23 03:00:17	2020-07-23	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	13495	pick-up	0	20
101646	2020-07-23 03:03:44	2020-07-23	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	9021	delivery	5	35
101647	2020-07-23 03:10:33	2020-07-23	9	[{"id_menu":7,"count":1}]	9175	delivery	5	14
101648	2020-07-23 03:11:15	2020-07-23	14	[{"id_menu":2,"count":1}]	16476	pick-up	0	14
101649	2020-07-23 03:11:29	2020-07-23	9	[{"id_menu":7,"count":1}]	14119	delivery	5	14
101650	2020-07-23 03:11:56	2020-07-23	9	[{"id_menu":6,"count":3}]	9479	delivery	5	14
101651	2020-07-23 03:13:39	2020-07-23	9	[{"id_menu":6,"count":1}]	39388	delivery	5	14
101652	2020-07-23 03:15:15	2020-07-23	9	[{"id_menu":7,"count":1}]	39330	delivery	5	14
101653	2020-07-23 03:17:55	2020-07-23	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	32173	delivery	5	57
101654	2020-07-23 03:19:22	2020-07-23	9	[{"id_menu":6,"count":1}]	6380	delivery	5	14
101655	2020-07-23 03:19:38	2020-07-23	17	[{"id_menu":4,"count":1}]	39253	delivery	5	22
101656	2020-07-23 03:20:15	2020-07-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15320	delivery	5	23
101657	2020-07-23 03:20:40	2020-07-23	8	[{"id_menu":5,"count":1}]	39341	delivery	5	13
101658	2020-07-23 03:20:45	2020-07-23	9	[{"id_menu":7,"count":1}]	12031	delivery	5	14
101659	2020-07-23 03:24:50	2020-07-23	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":2}]	30737	delivery	5	34
101660	2020-07-23 03:26:13	2020-07-23	12	[{"id_menu":3,"count":1}]	2616	pick-up	0	12
101661	2020-07-23 03:30:48	2020-07-23	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	30894	delivery	5	30
101662	2020-07-23 03:36:17	2020-07-23	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	5426	pick-up	0	22
101663	2020-07-23 03:37:23	2020-07-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	39436	delivery	5	31
101664	2020-07-23 03:38:01	2020-07-23	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9801	delivery	5	22
101665	2020-07-23 03:38:37	2020-07-23	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17595	delivery	5	37
101666	2020-07-23 03:40:54	2020-07-23	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	39356	pick-up	0	21
101667	2020-07-23 03:45:50	2020-07-23	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22146	delivery	5	31
101668	2020-07-23 03:53:48	2020-07-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	1526	pick-up	0	21
101669	2020-07-23 03:57:09	2020-07-23	12	[{"id_menu":1,"count":1}]	39422	delivery	5	17
101670	2020-07-23 03:57:49	2020-07-23	12	[{"id_menu":3,"count":1}]	25444	delivery	5	17
101671	2020-07-23 03:58:52	2020-07-23	12	[{"id_menu":3,"count":1}]	15797	pick-up	0	12
101672	2020-07-23 04:00:03	2020-07-23	9	[{"id_menu":6,"count":1}]	39304	delivery	5	14
101673	2020-07-23 04:00:20	2020-07-23	9	[{"id_menu":6,"count":1}]	39395	delivery	5	14
101674	2020-07-23 04:02:07	2020-07-23	9	[{"id_menu":6,"count":1}]	533	delivery	5	14
101675	2020-07-23 04:02:46	2020-07-23	9	[{"id_menu":7,"count":1}]	39383	delivery	5	14
101676	2020-07-23 04:10:13	2020-07-23	9	[{"id_menu":6,"count":1}]	36632	delivery	5	14
101677	2020-07-23 04:11:50	2020-07-23	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	39111	delivery	5	40
101678	2020-07-23 04:19:58	2020-07-23	14	[{"id_menu":2,"count":1}]	39326	delivery	5	19
101679	2020-07-23 04:20:12	2020-07-23	9	[{"id_menu":7,"count":1}]	39453	delivery	5	14
101680	2020-07-23 04:21:29	2020-07-23	8	[{"id_menu":5,"count":1}]	39397	pick-up	0	8
101681	2020-07-23 04:32:23	2020-07-23	14	[{"id_menu":2,"count":1}]	11983	delivery	5	19
101682	2020-07-23 04:37:25	2020-07-23	17	[{"id_menu":4,"count":1}]	37050	delivery	5	22
101683	2020-07-23 04:40:02	2020-07-23	17	[{"id_menu":4,"count":1}]	39429	delivery	5	22
101684	2020-07-23 04:43:16	2020-07-23	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	19906	delivery	5	22
101685	2020-07-23 04:47:27	2020-07-23	12	[{"id_menu":1,"count":1}]	21705	delivery	5	17
101686	2020-07-23 04:48:19	2020-07-23	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	20835	pick-up	0	23
101687	2020-07-23 04:53:23	2020-07-23	8	[{"id_menu":5,"count":1}]	28205	delivery	5	13
101688	2020-07-23 04:57:04	2020-07-23	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	39315	delivery	5	25
101689	2020-07-23 04:58:54	2020-07-23	12	[{"id_menu":1,"count":1}]	19741	delivery	5	17
101690	2020-07-23 05:01:16	2020-07-23	12	[{"id_menu":1,"count":1}]	5771	delivery	5	17
101691	2020-07-23 05:02:06	2020-07-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	27835	pick-up	0	26
101692	2020-07-23 05:02:13	2020-07-23	9	[{"id_menu":7,"count":1}]	1135	delivery	5	14
101693	2020-07-23 05:04:20	2020-07-23	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11590	delivery	5	22
101694	2020-07-23 05:16:36	2020-07-23	9	[{"id_menu":6,"count":1}]	21497	delivery	5	14
101695	2020-07-23 05:18:40	2020-07-23	9	[{"id_menu":6,"count":1}]	37776	delivery	5	14
101696	2020-07-23 05:18:52	2020-07-23	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2392	delivery	5	31
101697	2020-07-23 05:21:30	2020-07-23	9	[{"id_menu":6,"count":1}]	11527	delivery	5	14
101698	2020-07-23 05:21:58	2020-07-23	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11219	delivery	5	37
101699	2020-07-23 05:22:20	2020-07-23	14	[{"id_menu":2,"count":1}]	39284	pick-up	0	14
101700	2020-07-23 05:22:20	2020-07-23	12	[{"id_menu":3,"count":1}]	511	pick-up	0	12
101701	2020-07-23 05:23:53	2020-07-23	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3509	pick-up	0	38
101702	2020-07-23 05:24:38	2020-07-23	8	[{"id_menu":5,"count":1}]	23735	pick-up	0	8
101703	2020-07-23 05:27:35	2020-07-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	38860	delivery	5	31
101704	2020-07-23 05:28:18	2020-07-23	9	[{"id_menu":7,"count":1}]	3494	pick-up	0	9
101705	2020-07-23 05:28:32	2020-07-23	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	39288	delivery	5	25
101706	2020-07-23 05:28:48	2020-07-23	9	[{"id_menu":6,"count":1}]	39380	delivery	5	14
101707	2020-07-23 05:30:04	2020-07-23	8	[{"id_menu":5,"count":1}]	5048	delivery	5	13
101708	2020-07-23 05:35:29	2020-07-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39259	delivery	5	22
101709	2020-07-23 05:36:20	2020-07-23	9	[{"id_menu":6,"count":1}]	39321	delivery	5	14
101710	2020-07-23 05:39:32	2020-07-23	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24666	delivery	5	31
101711	2020-07-23 05:41:27	2020-07-23	14	[{"id_menu":2,"count":1}]	33546	pick-up	0	14
101712	2020-07-23 05:44:41	2020-07-23	12	[{"id_menu":1,"count":1}]	24838	delivery	5	17
101713	2020-07-23 05:45:25	2020-07-23	17	[{"id_menu":4,"count":1}]	12528	delivery	5	22
101714	2020-07-23 05:46:31	2020-07-23	12	[{"id_menu":1,"count":1}]	17041	pick-up	0	12
101715	2020-07-23 05:46:33	2020-07-23	9	[{"id_menu":6,"count":1}]	37502	delivery	5	14
101716	2020-07-23 05:49:11	2020-07-23	9	[{"id_menu":7,"count":1}]	35456	pick-up	0	9
101717	2020-07-23 05:50:25	2020-07-23	8	[{"id_menu":5,"count":1}]	11162	delivery	5	13
101718	2020-07-23 05:52:15	2020-07-23	17	[{"id_menu":4,"count":1}]	123	pick-up	0	17
101719	2020-07-23 05:53:17	2020-07-23	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	8540	delivery	5	34
101720	2020-07-23 06:01:24	2020-07-23	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	39385	delivery	5	26
101721	2020-07-23 06:01:47	2020-07-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	33019	delivery	5	28
101722	2020-07-23 06:02:33	2020-07-23	12	[{"id_menu":1,"count":1}]	17160	delivery	5	17
101723	2020-07-23 06:04:02	2020-07-23	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36576	delivery	5	31
101724	2020-07-23 06:04:25	2020-07-23	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	39376	delivery	5	27
101725	2020-07-23 06:07:19	2020-07-23	9	[{"id_menu":7,"count":1}]	39374	delivery	5	14
101726	2020-07-23 06:09:27	2020-07-23	14	[{"id_menu":2,"count":1}]	2631	pick-up	0	14
101727	2020-07-23 06:10:37	2020-07-23	9	[{"id_menu":6,"count":2}]	24759	delivery	5	14
101728	2020-07-23 06:11:40	2020-07-23	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	6200	delivery	5	31
101729	2020-07-23 06:11:55	2020-07-23	12	[{"id_menu":1,"count":1}]	126	pick-up	0	12
101730	2020-07-23 06:12:41	2020-07-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39392	delivery	5	23
101731	2020-07-23 06:17:30	2020-07-23	9	[{"id_menu":7,"count":1}]	39405	delivery	5	14
101732	2020-07-23 06:20:15	2020-07-23	9	[{"id_menu":7,"count":1}]	35096	pick-up	0	9
101733	2020-07-23 06:21:46	2020-07-23	14	[{"id_menu":2,"count":1}]	16754	delivery	5	19
101734	2020-07-23 06:24:21	2020-07-23	9	[{"id_menu":6,"count":1}]	6321	pick-up	0	9
101735	2020-07-23 06:26:20	2020-07-23	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	12070	pick-up	0	24
101736	2020-07-23 06:26:22	2020-07-23	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	39452	delivery	5	31
101737	2020-07-23 06:28:24	2020-07-23	17	[{"id_menu":4,"count":1}]	6278	pick-up	0	17
101738	2020-07-23 06:29:09	2020-07-23	8	[{"id_menu":5,"count":1}]	20894	delivery	5	13
101739	2020-07-23 06:32:50	2020-07-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	39431	delivery	5	28
101740	2020-07-23 06:36:30	2020-07-23	9	[{"id_menu":7,"count":2}]	24089	delivery	5	14
101741	2020-07-23 06:36:51	2020-07-23	14	[{"id_menu":2,"count":1}]	39306	delivery	5	19
101742	2020-07-23 06:37:59	2020-07-23	9	[{"id_menu":6,"count":1}]	25867	delivery	5	14
101743	2020-07-23 06:39:42	2020-07-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	39371	delivery	5	26
101744	2020-07-23 06:41:21	2020-07-23	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":3}]	38461	pick-up	0	29
101745	2020-07-23 06:44:05	2020-07-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":3}]	33517	delivery	5	22
101746	2020-07-23 06:45:34	2020-07-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1072	delivery	5	28
101747	2020-07-23 06:48:37	2020-07-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	28091	delivery	5	26
101748	2020-07-23 06:51:53	2020-07-23	9	[{"id_menu":7,"count":3}]	19726	delivery	5	14
101749	2020-07-23 06:52:44	2020-07-23	17	[{"id_menu":4,"count":1}]	4546	pick-up	0	17
101750	2020-07-23 06:56:21	2020-07-23	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13891	delivery	5	45
101751	2020-07-23 06:57:23	2020-07-23	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	39403	delivery	5	23
101752	2020-07-23 06:57:27	2020-07-23	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	9920	delivery	5	25
101753	2020-07-23 07:04:46	2020-07-23	17	[{"id_menu":4,"count":1}]	15731	pick-up	0	17
101754	2020-07-23 07:06:20	2020-07-23	8	[{"id_menu":5,"count":1}]	39280	delivery	5	13
101755	2020-07-23 07:07:57	2020-07-23	17	[{"id_menu":4,"count":1}]	34140	delivery	5	22
101756	2020-07-23 07:08:58	2020-07-23	14	[{"id_menu":2,"count":1}]	30969	delivery	5	19
101757	2020-07-23 07:10:16	2020-07-23	17	[{"id_menu":4,"count":1}]	7094	delivery	5	22
101758	2020-07-23 07:15:46	2020-07-23	8	[{"id_menu":5,"count":1}]	29223	delivery	5	13
101759	2020-07-23 07:20:27	2020-07-23	17	[{"id_menu":4,"count":1}]	5508	delivery	5	22
101760	2020-07-23 07:22:44	2020-07-23	8	[{"id_menu":5,"count":1}]	4688	pick-up	0	8
101761	2020-07-23 07:23:07	2020-07-23	8	[{"id_menu":5,"count":1}]	6369	pick-up	0	8
101762	2020-07-23 07:24:27	2020-07-23	17	[{"id_menu":4,"count":1}]	21808	delivery	5	22
101763	2020-07-23 07:29:07	2020-07-23	9	[{"id_menu":7,"count":1}]	2333	delivery	5	14
101764	2020-07-23 07:32:32	2020-07-23	14	[{"id_menu":2,"count":1}]	38843	delivery	5	19
101765	2020-07-23 07:32:39	2020-07-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	39317	pick-up	0	26
101766	2020-07-23 07:34:09	2020-07-23	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	39454	delivery	5	35
101767	2020-07-23 07:36:23	2020-07-23	12	[{"id_menu":3,"count":1}]	28490	delivery	5	17
101768	2020-07-23 07:37:33	2020-07-23	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	16982	delivery	5	38
101769	2020-07-23 07:39:29	2020-07-23	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	39293	delivery	5	30
101770	2020-07-23 07:43:29	2020-07-23	17	[{"id_menu":4,"count":1}]	33251	pick-up	0	17
101771	2020-07-23 07:45:42	2020-07-23	9	[{"id_menu":6,"count":1}]	8050	delivery	5	14
101772	2020-07-23 07:45:42	2020-07-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	39415	delivery	5	31
101773	2020-07-23 07:45:49	2020-07-23	12	[{"id_menu":3,"count":1}]	1174	pick-up	0	12
101774	2020-07-23 07:47:00	2020-07-23	14	[{"id_menu":2,"count":1}]	39336	delivery	5	19
101775	2020-07-23 07:47:19	2020-07-23	9	[{"id_menu":7,"count":1}]	39289	delivery	5	14
101776	2020-07-23 07:47:46	2020-07-23	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25477	delivery	5	40
101777	2020-07-23 07:50:08	2020-07-23	17	[{"id_menu":4,"count":1}]	10470	pick-up	0	17
101778	2020-07-23 07:51:15	2020-07-23	9	[{"id_menu":6,"count":1}]	39265	delivery	5	14
101779	2020-07-23 07:52:00	2020-07-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39421	delivery	5	22
101780	2020-07-23 07:54:17	2020-07-23	8	[{"id_menu":5,"count":1}]	20677	pick-up	0	8
101781	2020-07-23 07:55:59	2020-07-23	9	[{"id_menu":7,"count":1}]	37917	delivery	5	14
101782	2020-07-23 07:57:33	2020-07-23	12	[{"id_menu":1,"count":1}]	34023	delivery	5	17
101783	2020-07-23 08:04:00	2020-07-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	37983	delivery	5	31
101784	2020-07-23 08:07:55	2020-07-23	9	[{"id_menu":6,"count":1}]	28755	delivery	5	14
101785	2020-07-23 08:09:41	2020-07-23	14	[{"id_menu":2,"count":1}]	8030	pick-up	0	14
101786	2020-07-23 08:11:25	2020-07-23	17	[{"id_menu":4,"count":1}]	643	pick-up	0	17
101787	2020-07-23 08:12:07	2020-07-23	12	[{"id_menu":3,"count":1}]	29225	delivery	5	17
101788	2020-07-23 08:13:40	2020-07-23	12	[{"id_menu":3,"count":1}]	6399	pick-up	0	12
101789	2020-07-23 08:15:13	2020-07-23	17	[{"id_menu":4,"count":1}]	7443	delivery	5	22
101790	2020-07-23 08:17:13	2020-07-23	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	39335	delivery	5	43
101791	2020-07-23 08:23:15	2020-07-23	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3771	delivery	5	31
101792	2020-07-23 08:28:25	2020-07-23	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	19731	delivery	5	25
101793	2020-07-23 08:29:27	2020-07-23	12	[{"id_menu":3,"count":1}]	25149	delivery	5	17
101794	2020-07-23 08:29:31	2020-07-23	12	[{"id_menu":1,"count":1}]	6836	delivery	5	17
101795	2020-07-23 08:29:50	2020-07-23	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	7020	delivery	5	29
101796	2020-07-23 08:34:56	2020-07-23	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	39394	delivery	5	31
101797	2020-07-23 08:36:57	2020-07-23	12	[{"id_menu":3,"count":1}]	13996	pick-up	0	12
101798	2020-07-23 08:39:35	2020-07-23	12	[{"id_menu":1,"count":1}]	23350	pick-up	0	12
101799	2020-07-23 08:40:39	2020-07-23	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":2}]	23662	delivery	5	30
101800	2020-07-23 08:41:23	2020-07-23	8	[{"id_menu":5,"count":1}]	23551	delivery	5	13
101801	2020-07-23 08:44:39	2020-07-23	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2351	pick-up	0	22
101802	2020-07-23 08:46:05	2020-07-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	39364	delivery	5	31
101803	2020-07-23 08:48:15	2020-07-23	17	[{"id_menu":4,"count":1}]	31628	pick-up	0	17
101804	2020-07-23 08:52:23	2020-07-23	12	[{"id_menu":3,"count":1}]	22175	delivery	5	17
101805	2020-07-23 08:53:38	2020-07-23	8	[{"id_menu":5,"count":1}]	39344	delivery	5	13
101806	2020-07-23 08:54:36	2020-07-23	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	5736	pick-up	0	29
101807	2020-07-23 08:56:32	2020-07-23	9	[{"id_menu":6,"count":1}]	28055	delivery	5	14
101808	2020-07-23 09:00:03	2020-07-23	9	[{"id_menu":7,"count":1}]	23127	delivery	5	14
101809	2020-07-23 09:00:47	2020-07-23	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6453	delivery	5	30
101810	2020-07-23 09:02:15	2020-07-23	9	[{"id_menu":7,"count":1}]	39296	delivery	5	14
101811	2020-07-23 09:02:44	2020-07-23	9	[{"id_menu":6,"count":1}]	22844	pick-up	0	9
101812	2020-07-23 09:13:32	2020-07-23	12	[{"id_menu":1,"count":1}]	25365	delivery	5	17
101813	2020-07-23 09:14:58	2020-07-23	9	[{"id_menu":6,"count":1}]	21779	delivery	5	14
101814	2020-07-23 09:16:22	2020-07-23	12	[{"id_menu":1,"count":1}]	20867	delivery	5	17
101815	2020-07-23 09:16:30	2020-07-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	33919	delivery	5	36
101816	2020-07-23 09:17:49	2020-07-23	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2706	pick-up	0	43
101817	2020-07-23 09:17:59	2020-07-23	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7953	delivery	5	40
101818	2020-07-23 09:19:10	2020-07-23	9	[{"id_menu":7,"count":1}]	35545	delivery	5	14
101819	2020-07-23 09:25:14	2020-07-23	8	[{"id_menu":5,"count":1}]	5442	delivery	5	13
101820	2020-07-23 09:26:13	2020-07-23	14	[{"id_menu":2,"count":1}]	5125	pick-up	0	14
101821	2020-07-23 09:26:22	2020-07-23	9	[{"id_menu":6,"count":2}]	18090	delivery	5	14
101822	2020-07-23 09:27:33	2020-07-23	12	[{"id_menu":3,"count":1}]	39263	delivery	5	17
101823	2020-07-23 09:30:28	2020-07-23	9	[{"id_menu":7,"count":1}]	39269	delivery	5	14
101824	2020-07-23 09:31:14	2020-07-23	9	[{"id_menu":7,"count":1}]	3699	delivery	5	14
101825	2020-07-23 09:33:40	2020-07-23	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	36179	delivery	5	22
101826	2020-07-23 09:36:22	2020-07-23	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39369	delivery	5	35
101827	2020-07-23 09:36:38	2020-07-23	9	[{"id_menu":6,"count":1}]	36142	delivery	5	14
101828	2020-07-23 09:38:54	2020-07-23	17	[{"id_menu":4,"count":1}]	9996	delivery	5	22
101829	2020-07-23 09:39:52	2020-07-23	9	[{"id_menu":7,"count":1}]	14515	delivery	5	14
101830	2020-07-23 09:42:53	2020-07-23	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	39407	delivery	5	43
101831	2020-07-23 09:46:36	2020-07-23	14	[{"id_menu":2,"count":1}]	39278	delivery	5	19
101832	2020-07-23 09:47:49	2020-07-23	17	[{"id_menu":4,"count":2}]	39255	delivery	5	22
101833	2020-07-23 09:49:17	2020-07-23	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39386	delivery	5	45
101834	2020-07-23 09:49:41	2020-07-23	14	[{"id_menu":2,"count":1}]	6132	delivery	5	19
101835	2020-07-23 09:49:57	2020-07-23	9	[{"id_menu":7,"count":1}]	39320	delivery	5	14
101836	2020-07-23 09:52:15	2020-07-23	9	[{"id_menu":6,"count":1}]	28751	delivery	5	14
101837	2020-07-23 09:57:12	2020-07-23	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	9684	delivery	5	43
101838	2020-07-23 09:57:54	2020-07-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	37726	delivery	5	22
101839	2020-07-23 09:59:59	2020-07-23	12	[{"id_menu":1,"count":1}]	5041	pick-up	0	12
101840	2020-07-23 10:01:31	2020-07-23	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2667	delivery	5	30
101841	2020-07-23 10:02:12	2020-07-23	17	[{"id_menu":4,"count":1}]	31263	pick-up	0	17
101842	2020-07-23 10:03:20	2020-07-23	9	[{"id_menu":6,"count":1}]	16226	pick-up	0	9
101843	2020-07-23 10:03:38	2020-07-23	12	[{"id_menu":3,"count":1}]	39355	delivery	5	17
101844	2020-07-23 10:09:44	2020-07-23	9	[{"id_menu":6,"count":1}]	39287	delivery	5	14
101845	2020-07-23 10:10:30	2020-07-23	17	[{"id_menu":4,"count":1}]	1000	pick-up	0	17
101846	2020-07-23 10:15:56	2020-07-23	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	39352	pick-up	0	20
101847	2020-07-23 10:16:20	2020-07-23	9	[{"id_menu":6,"count":1}]	18805	delivery	5	14
101848	2020-07-23 10:17:36	2020-07-23	8	[{"id_menu":5,"count":1}]	14754	delivery	5	13
101849	2020-07-23 10:20:02	2020-07-23	14	[{"id_menu":2,"count":1}]	378	delivery	5	19
101850	2020-07-23 10:20:30	2020-07-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24041	pick-up	0	18
101851	2020-07-23 10:24:46	2020-07-23	9	[{"id_menu":7,"count":1}]	669	pick-up	0	9
101852	2020-07-23 10:26:48	2020-07-23	8	[{"id_menu":5,"count":1}]	15186	pick-up	0	8
101853	2020-07-23 10:27:32	2020-07-23	9	[{"id_menu":6,"count":1}]	31783	delivery	5	14
101854	2020-07-23 10:27:42	2020-07-23	8	[{"id_menu":5,"count":1}]	39279	delivery	5	13
101855	2020-07-23 10:28:55	2020-07-23	12	[{"id_menu":1,"count":1}]	16069	pick-up	0	12
101856	2020-07-23 10:36:30	2020-07-23	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30952	delivery	5	31
101857	2020-07-23 10:37:08	2020-07-23	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19725	delivery	5	34
101858	2020-07-23 10:37:15	2020-07-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	39340	delivery	5	31
101859	2020-07-23 10:38:16	2020-07-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39438	delivery	5	22
101860	2020-07-23 10:41:13	2020-07-23	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	39378	delivery	5	26
101861	2020-07-23 10:41:45	2020-07-23	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39400	delivery	5	36
101862	2020-07-23 10:48:57	2020-07-23	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	9387	delivery	5	34
101863	2020-07-23 10:51:40	2020-07-23	9	[{"id_menu":7,"count":1}]	24746	delivery	5	14
101864	2020-07-23 10:53:58	2020-07-23	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	8900	pick-up	0	26
101865	2020-07-23 10:57:38	2020-07-23	8	[{"id_menu":5,"count":1}]	39329	delivery	5	13
101866	2020-07-23 11:01:48	2020-07-23	9	[{"id_menu":7,"count":1}]	11074	pick-up	0	9
101867	2020-07-23 11:05:48	2020-07-23	8	[{"id_menu":5,"count":1}]	33422	pick-up	0	8
101868	2020-07-23 11:08:04	2020-07-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	12677	delivery	5	31
101869	2020-07-23 11:10:44	2020-07-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	770	pick-up	0	23
101870	2020-07-23 11:11:23	2020-07-23	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	34663	delivery	5	39
101871	2020-07-23 11:12:12	2020-07-23	14	[{"id_menu":2,"count":1}]	11618	delivery	5	19
101872	2020-07-23 11:15:41	2020-07-23	8	[{"id_menu":5,"count":1}]	37694	delivery	5	13
101873	2020-07-23 11:16:37	2020-07-23	9	[{"id_menu":6,"count":1}]	17067	delivery	5	14
101874	2020-07-23 11:18:02	2020-07-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39276	delivery	5	23
101875	2020-07-23 11:20:23	2020-07-23	23	[{"id_menu":2,"count":3},{"id_menu":6,"count":1}]	39262	delivery	5	28
101876	2020-07-23 11:22:46	2020-07-23	17	[{"id_menu":4,"count":1}]	39295	delivery	5	22
101877	2020-07-23 11:26:05	2020-07-23	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7937	pick-up	0	29
101878	2020-07-23 11:26:32	2020-07-23	20	[{"id_menu":1,"count":3},{"id_menu":5,"count":1}]	16346	delivery	5	25
101879	2020-07-23 11:27:40	2020-07-23	9	[{"id_menu":6,"count":2}]	39408	delivery	5	14
101880	2020-07-23 11:28:28	2020-07-23	9	[{"id_menu":6,"count":1}]	5434	delivery	5	14
101881	2020-07-23 11:33:39	2020-07-23	8	[{"id_menu":5,"count":1}]	12576	delivery	5	13
101882	2020-07-23 11:34:55	2020-07-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	39328	delivery	5	31
101883	2020-07-23 11:37:28	2020-07-23	12	[{"id_menu":1,"count":1}]	6551	delivery	5	17
101884	2020-07-23 11:37:56	2020-07-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20088	delivery	5	22
101885	2020-07-23 11:40:30	2020-07-23	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	33849	pick-up	0	26
101886	2020-07-23 11:42:42	2020-07-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	12278	pick-up	0	31
101887	2020-07-23 11:44:11	2020-07-23	17	[{"id_menu":4,"count":3}]	21246	delivery	5	22
101888	2020-07-23 11:45:12	2020-07-23	12	[{"id_menu":3,"count":1}]	30697	delivery	5	17
101889	2020-07-23 11:45:34	2020-07-23	8	[{"id_menu":5,"count":2}]	23157	delivery	5	13
101890	2020-07-23 11:46:31	2020-07-23	14	[{"id_menu":2,"count":1}]	8609	delivery	5	19
101891	2020-07-23 11:49:03	2020-07-23	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	39451	delivery	5	34
101892	2020-07-23 11:49:47	2020-07-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4624	delivery	5	36
101893	2020-07-23 11:50:52	2020-07-23	12	[{"id_menu":1,"count":1}]	38910	delivery	5	17
101894	2020-07-23 11:52:30	2020-07-23	8	[{"id_menu":5,"count":1}]	39290	delivery	5	13
101895	2020-07-23 11:54:07	2020-07-23	9	[{"id_menu":7,"count":1}]	36878	delivery	5	14
101896	2020-07-23 12:00:37	2020-07-23	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	27161	pick-up	0	24
101897	2020-07-23 12:01:22	2020-07-23	12	[{"id_menu":1,"count":1}]	39332	delivery	5	17
101898	2020-07-23 12:08:10	2020-07-23	14	[{"id_menu":2,"count":1}]	24853	delivery	5	19
101899	2020-07-23 12:08:42	2020-07-23	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	39449	delivery	5	44
101900	2020-07-23 12:13:04	2020-07-23	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20723	delivery	5	31
101901	2020-07-23 12:15:58	2020-07-23	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	24668	pick-up	0	26
101902	2020-07-23 12:16:27	2020-07-23	9	[{"id_menu":7,"count":2}]	7230	delivery	5	14
101903	2020-07-23 12:17:59	2020-07-23	9	[{"id_menu":7,"count":1}]	39440	delivery	5	14
101904	2020-07-23 12:18:58	2020-07-23	14	[{"id_menu":2,"count":1}]	31790	delivery	5	19
101905	2020-07-23 12:23:53	2020-07-23	9	[{"id_menu":7,"count":1}]	1579	delivery	5	14
101906	2020-07-23 12:24:50	2020-07-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	7345	delivery	5	31
101907	2020-07-23 12:24:50	2020-07-23	9	[{"id_menu":6,"count":2}]	16367	delivery	5	14
101908	2020-07-23 12:25:25	2020-07-23	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20997	delivery	5	48
101909	2020-07-23 12:26:22	2020-07-23	12	[{"id_menu":1,"count":2}]	14306	pick-up	0	12
101910	2020-07-23 12:29:19	2020-07-23	14	[{"id_menu":2,"count":1}]	25808	delivery	5	19
101911	2020-07-23 12:29:44	2020-07-23	14	[{"id_menu":2,"count":1}]	256	pick-up	0	14
101912	2020-07-23 12:32:16	2020-07-23	9	[{"id_menu":6,"count":1}]	39410	delivery	5	14
101913	2020-07-23 12:34:17	2020-07-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39441	pick-up	0	17
101914	2020-07-23 12:36:09	2020-07-23	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	19157	delivery	5	30
101915	2020-07-23 12:36:36	2020-07-23	9	[{"id_menu":6,"count":2}]	39252	pick-up	0	9
101916	2020-07-23 12:40:18	2020-07-23	8	[{"id_menu":5,"count":1}]	20293	pick-up	0	8
101917	2020-07-23 12:42:42	2020-07-23	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	22448	delivery	5	40
101918	2020-07-23 12:47:45	2020-07-23	12	[{"id_menu":1,"count":1}]	24900	delivery	5	17
101919	2020-07-23 12:47:53	2020-07-23	14	[{"id_menu":2,"count":1}]	9099	delivery	5	19
101920	2020-07-23 12:48:12	2020-07-23	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	28756	delivery	5	25
101921	2020-07-23 12:49:42	2020-07-23	8	[{"id_menu":5,"count":1}]	39300	pick-up	0	8
101922	2020-07-23 12:51:29	2020-07-23	9	[{"id_menu":6,"count":1}]	21002	delivery	5	14
101923	2020-07-23 12:52:57	2020-07-23	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	16498	delivery	5	34
101924	2020-07-23 12:53:52	2020-07-23	8	[{"id_menu":5,"count":1}]	39413	delivery	5	13
101925	2020-07-23 12:53:53	2020-07-23	9	[{"id_menu":7,"count":1}]	39294	delivery	5	14
101926	2020-07-23 12:55:18	2020-07-23	12	[{"id_menu":1,"count":1}]	39325	pick-up	0	12
101927	2020-07-23 12:56:56	2020-07-23	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28902	delivery	5	34
101928	2020-07-23 12:57:49	2020-07-23	17	[{"id_menu":4,"count":1}]	14290	delivery	5	22
101929	2020-07-23 13:00:02	2020-07-23	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3129	delivery	5	39
101930	2020-07-23 13:00:14	2020-07-23	9	[{"id_menu":6,"count":1}]	38382	pick-up	0	9
101931	2020-07-23 13:00:30	2020-07-23	8	[{"id_menu":5,"count":1}]	14679	pick-up	0	8
101932	2020-07-23 13:01:14	2020-07-23	14	[{"id_menu":2,"count":1}]	39333	delivery	5	19
101933	2020-07-23 13:01:58	2020-07-23	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	27571	delivery	5	38
101934	2020-07-23 13:02:56	2020-07-23	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	36830	delivery	5	34
101935	2020-07-23 13:05:00	2020-07-23	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	8274	delivery	5	26
101936	2020-07-23 13:07:23	2020-07-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15929	pick-up	0	26
101937	2020-07-23 13:09:40	2020-07-23	14	[{"id_menu":2,"count":1}]	39275	delivery	5	19
101938	2020-07-23 13:10:15	2020-07-23	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	19979	delivery	5	35
101939	2020-07-23 13:17:17	2020-07-23	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4065	pick-up	0	22
101940	2020-07-23 13:21:41	2020-07-23	9	[{"id_menu":6,"count":1}]	35202	delivery	5	14
101941	2020-07-23 13:23:11	2020-07-23	9	[{"id_menu":7,"count":1}]	7167	delivery	5	14
101942	2020-07-23 13:29:50	2020-07-23	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24057	delivery	5	34
101943	2020-07-23 13:31:10	2020-07-23	9	[{"id_menu":7,"count":1}]	1408	delivery	5	14
101944	2020-07-23 13:31:17	2020-07-23	12	[{"id_menu":3,"count":2}]	18405	pick-up	0	12
101945	2020-07-23 13:32:05	2020-07-23	14	[{"id_menu":2,"count":1}]	39393	delivery	5	19
101946	2020-07-23 13:33:42	2020-07-23	9	[{"id_menu":6,"count":1}]	39366	delivery	5	14
101947	2020-07-23 13:46:31	2020-07-23	12	[{"id_menu":3,"count":1}]	39447	delivery	5	17
101948	2020-07-23 13:49:21	2020-07-23	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	31805	delivery	5	26
101949	2020-07-23 13:53:04	2020-07-23	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	7208	delivery	5	26
101950	2020-07-23 13:57:08	2020-07-23	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	35350	pick-up	0	29
101951	2020-07-23 13:58:39	2020-07-23	8	[{"id_menu":5,"count":1}]	39402	delivery	5	13
101952	2020-07-23 13:58:44	2020-07-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	27556	delivery	5	23
101953	2020-07-23 13:59:57	2020-07-23	17	[{"id_menu":4,"count":1}]	12095	pick-up	0	17
101954	2020-07-23 14:02:27	2020-07-23	9	[{"id_menu":6,"count":1}]	20452	pick-up	0	9
101955	2020-07-23 14:03:45	2020-07-23	12	[{"id_menu":3,"count":1}]	8569	delivery	5	17
101956	2020-07-23 14:09:56	2020-07-23	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	14354	delivery	5	45
101957	2020-07-23 14:11:09	2020-07-23	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	32542	pick-up	0	21
101958	2020-07-23 14:13:00	2020-07-23	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19054	delivery	5	36
101959	2020-07-23 14:13:20	2020-07-23	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	39299	delivery	5	23
101960	2020-07-23 14:16:04	2020-07-23	9	[{"id_menu":7,"count":2}]	1963	pick-up	0	9
101961	2020-07-23 14:17:15	2020-07-23	9	[{"id_menu":7,"count":1}]	3191	pick-up	0	9
101962	2020-07-23 14:18:18	2020-07-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	39363	pick-up	0	23
101963	2020-07-23 14:19:00	2020-07-23	9	[{"id_menu":6,"count":2}]	12251	delivery	5	14
101964	2020-07-23 14:24:43	2020-07-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	20754	delivery	5	31
101965	2020-07-23 14:25:29	2020-07-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	26630	delivery	5	31
101966	2020-07-23 14:34:52	2020-07-23	12	[{"id_menu":1,"count":1}]	30771	pick-up	0	12
101967	2020-07-23 14:37:06	2020-07-23	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1862	delivery	5	34
101968	2020-07-23 14:37:22	2020-07-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	13451	delivery	5	26
101969	2020-07-23 14:39:22	2020-07-23	14	[{"id_menu":2,"count":1}]	39267	delivery	5	19
101970	2020-07-23 14:40:00	2020-07-23	12	[{"id_menu":3,"count":1}]	20817	delivery	5	17
101971	2020-07-23 14:41:59	2020-07-23	17	[{"id_menu":4,"count":1}]	10746	delivery	5	22
101972	2020-07-23 14:47:19	2020-07-23	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8380	delivery	5	52
101973	2020-07-23 14:48:44	2020-07-23	17	[{"id_menu":4,"count":1}]	4248	pick-up	0	17
101974	2020-07-23 14:51:13	2020-07-23	8	[{"id_menu":5,"count":1}]	39426	delivery	5	13
101975	2020-07-23 14:52:05	2020-07-23	12	[{"id_menu":3,"count":1}]	39442	pick-up	0	12
101976	2020-07-23 14:52:44	2020-07-23	14	[{"id_menu":2,"count":1}]	1331	pick-up	0	14
101977	2020-07-23 14:56:33	2020-07-23	17	[{"id_menu":4,"count":1}]	39327	delivery	5	22
101978	2020-07-23 14:58:04	2020-07-23	9	[{"id_menu":7,"count":1}]	22207	delivery	5	14
101979	2020-07-23 15:02:26	2020-07-23	14	[{"id_menu":2,"count":2}]	22799	delivery	5	19
101980	2020-07-23 15:03:21	2020-07-23	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3332	pick-up	0	25
101981	2020-07-23 15:04:49	2020-07-23	8	[{"id_menu":5,"count":1}]	39437	delivery	5	13
101982	2020-07-23 15:09:37	2020-07-23	9	[{"id_menu":7,"count":1}]	16195	delivery	5	14
101983	2020-07-23 15:10:11	2020-07-23	9	[{"id_menu":7,"count":1}]	8057	pick-up	0	9
101984	2020-07-23 15:16:10	2020-07-23	17	[{"id_menu":4,"count":1}]	1070	pick-up	0	17
101985	2020-07-23 15:18:31	2020-07-23	17	[{"id_menu":4,"count":2}]	39424	delivery	5	22
101986	2020-07-23 15:24:33	2020-07-23	9	[{"id_menu":6,"count":1}]	23540	delivery	5	14
101987	2020-07-23 15:25:37	2020-07-23	9	[{"id_menu":6,"count":1}]	22357	delivery	5	14
101988	2020-07-23 15:28:05	2020-07-23	8	[{"id_menu":5,"count":1}]	7618	pick-up	0	8
101989	2020-07-23 15:30:10	2020-07-23	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	34688	delivery	5	31
101990	2020-07-23 15:30:39	2020-07-23	9	[{"id_menu":6,"count":1}]	39257	delivery	5	14
101991	2020-07-23 15:36:01	2020-07-23	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	29145	delivery	5	38
101992	2020-07-23 15:36:21	2020-07-23	8	[{"id_menu":5,"count":2}]	1764	pick-up	0	8
101993	2020-07-23 15:37:32	2020-07-23	9	[{"id_menu":6,"count":2}]	21538	delivery	5	14
101994	2020-07-23 15:38:22	2020-07-23	12	[{"id_menu":1,"count":1}]	13328	pick-up	0	12
101995	2020-07-23 15:40:21	2020-07-23	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	39382	delivery	5	27
101996	2020-07-23 15:42:12	2020-07-23	14	[{"id_menu":2,"count":1}]	11106	delivery	5	19
101997	2020-07-23 15:42:29	2020-07-23	9	[{"id_menu":6,"count":1}]	39406	delivery	5	14
101998	2020-07-23 15:45:31	2020-07-23	17	[{"id_menu":4,"count":1}]	12542	pick-up	0	17
101999	2020-07-23 15:47:30	2020-07-23	12	[{"id_menu":3,"count":1}]	39268	delivery	5	17
102000	2020-07-23 15:49:28	2020-07-23	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1918	delivery	5	43
102001	2020-07-23 15:49:38	2020-07-23	9	[{"id_menu":7,"count":1}]	25905	pick-up	0	9
102002	2020-07-23 15:51:02	2020-07-23	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	37163	delivery	5	36
102003	2020-07-23 15:54:20	2020-07-23	9	[{"id_menu":6,"count":1}]	18591	delivery	5	14
102004	2020-07-23 15:54:53	2020-07-23	9	[{"id_menu":7,"count":1}]	14597	delivery	5	14
102005	2020-07-23 15:56:17	2020-07-23	9	[{"id_menu":6,"count":2}]	28067	delivery	5	14
102006	2020-07-23 15:57:14	2020-07-23	9	[{"id_menu":6,"count":1}]	34581	delivery	5	14
102007	2020-07-23 16:08:44	2020-07-23	9	[{"id_menu":7,"count":1}]	19020	delivery	5	14
102008	2020-07-23 16:10:59	2020-07-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	32903	delivery	5	31
102009	2020-07-23 16:11:06	2020-07-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	29780	delivery	5	28
102010	2020-07-23 16:13:56	2020-07-23	9	[{"id_menu":6,"count":1}]	39277	delivery	5	14
102011	2020-07-23 16:14:45	2020-07-23	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":2}]	39445	delivery	5	28
102012	2020-07-23 16:15:35	2020-07-23	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1436	delivery	5	39
102013	2020-07-23 16:19:09	2020-07-23	12	[{"id_menu":3,"count":1}]	9907	pick-up	0	12
102014	2020-07-23 16:21:08	2020-07-23	9	[{"id_menu":6,"count":1}]	39353	delivery	5	14
102015	2020-07-23 16:26:08	2020-07-23	12	[{"id_menu":1,"count":1}]	38131	delivery	5	17
102016	2020-07-23 16:27:50	2020-07-23	12	[{"id_menu":3,"count":1}]	23760	pick-up	0	12
102017	2020-07-23 16:32:44	2020-07-23	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	39443	delivery	5	48
102018	2020-07-23 16:33:18	2020-07-23	9	[{"id_menu":7,"count":1}]	17485	delivery	5	14
102019	2020-07-23 16:33:32	2020-07-23	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10142	pick-up	0	51
102020	2020-07-23 16:33:43	2020-07-23	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	9535	delivery	5	26
102021	2020-07-23 16:41:57	2020-07-23	9	[{"id_menu":6,"count":1}]	37508	delivery	5	14
102022	2020-07-23 16:44:24	2020-07-23	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	5730	delivery	5	34
102023	2020-07-23 16:45:20	2020-07-23	9	[{"id_menu":6,"count":1}]	1104	pick-up	0	9
102024	2020-07-23 16:47:16	2020-07-23	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	39433	delivery	5	30
102025	2020-07-23 16:48:58	2020-07-23	12	[{"id_menu":1,"count":1}]	20387	delivery	5	17
102026	2020-07-23 16:52:36	2020-07-23	17	[{"id_menu":4,"count":1}]	39258	delivery	5	22
102027	2020-07-23 17:10:48	2020-07-23	9	[{"id_menu":6,"count":1}]	150	pick-up	0	9
102028	2020-07-23 17:12:17	2020-07-23	12	[{"id_menu":1,"count":1}]	22214	pick-up	0	12
102029	2020-07-23 17:12:50	2020-07-23	9	[{"id_menu":6,"count":1}]	12397	delivery	5	14
102030	2020-07-23 17:14:26	2020-07-23	9	[{"id_menu":7,"count":1}]	3489	delivery	5	14
102031	2020-07-23 17:16:15	2020-07-23	34	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	18422	pick-up	0	34
102032	2020-07-23 17:16:24	2020-07-23	14	[{"id_menu":2,"count":1}]	3491	pick-up	0	14
102033	2020-07-23 17:22:30	2020-07-23	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	39316	delivery	5	22
102034	2020-07-23 17:23:01	2020-07-23	12	[{"id_menu":1,"count":1}]	30261	delivery	5	17
102035	2020-07-23 17:23:51	2020-07-23	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	39042	delivery	5	25
102036	2020-07-23 17:31:50	2020-07-23	8	[{"id_menu":5,"count":1}]	39398	delivery	5	13
102037	2020-07-23 17:33:30	2020-07-23	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	27625	delivery	5	25
102038	2020-07-23 17:33:53	2020-07-23	8	[{"id_menu":5,"count":1}]	3241	pick-up	0	8
102039	2020-07-23 17:34:30	2020-07-23	17	[{"id_menu":4,"count":1}]	25172	delivery	5	22
102040	2020-07-23 17:35:55	2020-07-23	12	[{"id_menu":3,"count":1}]	485	pick-up	0	12
102041	2020-07-23 17:36:35	2020-07-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	37131	delivery	5	22
102042	2020-07-23 17:38:17	2020-07-23	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	16897	delivery	5	26
102043	2020-07-23 17:39:28	2020-07-23	12	[{"id_menu":3,"count":1}]	6452	delivery	5	17
102044	2020-07-23 17:41:25	2020-07-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	39337	delivery	5	31
102045	2020-07-23 17:41:38	2020-07-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	36944	delivery	5	31
102046	2020-07-23 17:41:46	2020-07-23	12	[{"id_menu":1,"count":1}]	20012	delivery	5	17
102047	2020-07-23 17:47:22	2020-07-23	9	[{"id_menu":7,"count":2}]	6221	delivery	5	14
102048	2020-07-23 17:50:13	2020-07-23	9	[{"id_menu":7,"count":1}]	6145	pick-up	0	9
102049	2020-07-23 17:50:49	2020-07-23	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	39412	delivery	5	25
102050	2020-07-23 17:51:07	2020-07-23	12	[{"id_menu":1,"count":1}]	20170	delivery	5	17
102051	2020-07-23 17:55:01	2020-07-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	35424	delivery	5	28
102052	2020-07-23 17:58:48	2020-07-23	12	[{"id_menu":3,"count":1}]	3478	pick-up	0	12
102053	2020-07-23 18:02:01	2020-07-23	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	10038	delivery	5	26
102054	2020-07-23 18:03:09	2020-07-23	14	[{"id_menu":2,"count":1}]	39298	pick-up	0	14
102055	2020-07-23 18:03:51	2020-07-23	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11317	delivery	5	31
102056	2020-07-23 18:08:42	2020-07-23	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	39389	delivery	5	34
102057	2020-07-23 18:11:07	2020-07-23	9	[{"id_menu":6,"count":1}]	17052	delivery	5	14
102058	2020-07-23 18:11:21	2020-07-23	17	[{"id_menu":4,"count":1}]	1625	pick-up	0	17
102059	2020-07-23 18:12:20	2020-07-23	9	[{"id_menu":7,"count":1}]	39354	delivery	5	14
102060	2020-07-23 18:12:56	2020-07-23	14	[{"id_menu":2,"count":2}]	11932	delivery	5	19
102127	2020-07-23 20:47:42	2020-07-23	8	[{"id_menu":5,"count":1}]	28208	delivery	5	13
102061	2020-07-23 18:13:07	2020-07-23	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15616	delivery	5	43
102062	2020-07-23 18:16:22	2020-07-23	14	[{"id_menu":2,"count":1}]	39446	delivery	5	19
102063	2020-07-23 18:17:50	2020-07-23	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	20183	delivery	5	31
102064	2020-07-23 18:23:19	2020-07-23	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5602	delivery	5	39
102065	2020-07-23 18:28:21	2020-07-23	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	35080	delivery	5	25
102066	2020-07-23 18:29:13	2020-07-23	14	[{"id_menu":2,"count":1}]	27925	delivery	5	19
102067	2020-07-23 18:31:43	2020-07-23	12	[{"id_menu":3,"count":1}]	22238	delivery	5	17
102068	2020-07-23 18:32:26	2020-07-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	26098	delivery	5	28
102069	2020-07-23 18:33:09	2020-07-23	12	[{"id_menu":3,"count":1}]	4295	pick-up	0	12
102070	2020-07-23 18:33:17	2020-07-23	9	[{"id_menu":7,"count":1}]	31703	delivery	5	14
102071	2020-07-23 18:33:23	2020-07-23	12	[{"id_menu":1,"count":1}]	10387	pick-up	0	12
102072	2020-07-23 18:36:24	2020-07-23	9	[{"id_menu":6,"count":1}]	35726	delivery	5	14
102073	2020-07-23 18:43:10	2020-07-23	9	[{"id_menu":7,"count":1}]	6426	delivery	5	14
102074	2020-07-23 18:47:45	2020-07-23	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29263	delivery	5	36
102075	2020-07-23 18:48:42	2020-07-23	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	39448	delivery	5	26
102076	2020-07-23 18:49:21	2020-07-23	8	[{"id_menu":5,"count":2}]	27012	delivery	5	13
102077	2020-07-23 18:50:27	2020-07-23	8	[{"id_menu":5,"count":1}]	39119	delivery	5	13
102078	2020-07-23 18:55:11	2020-07-23	14	[{"id_menu":2,"count":1}]	39349	delivery	5	19
102079	2020-07-23 18:59:58	2020-07-23	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	32294	delivery	5	29
102080	2020-07-23 19:06:46	2020-07-23	14	[{"id_menu":2,"count":1}]	39399	delivery	5	19
102081	2020-07-23 19:06:47	2020-07-23	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15641	delivery	5	37
102082	2020-07-23 19:12:43	2020-07-23	9	[{"id_menu":6,"count":1}]	39309	pick-up	0	9
102083	2020-07-23 19:14:19	2020-07-23	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	39307	pick-up	0	21
102084	2020-07-23 19:14:23	2020-07-23	12	[{"id_menu":3,"count":1}]	39391	delivery	5	17
102085	2020-07-23 19:14:42	2020-07-23	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28323	delivery	5	34
102086	2020-07-23 19:19:22	2020-07-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	39347	delivery	5	28
102087	2020-07-23 19:21:39	2020-07-23	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	8355	pick-up	0	20
102088	2020-07-23 19:28:23	2020-07-23	14	[{"id_menu":2,"count":1}]	5768	delivery	5	19
102089	2020-07-23 19:30:36	2020-07-23	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	39334	delivery	5	36
102090	2020-07-23 19:34:44	2020-07-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	39360	delivery	5	28
102091	2020-07-23 19:36:02	2020-07-23	14	[{"id_menu":2,"count":1}]	31734	delivery	5	19
102092	2020-07-23 19:37:02	2020-07-23	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39285	delivery	5	48
102093	2020-07-23 19:37:22	2020-07-23	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4420	delivery	5	26
102094	2020-07-23 19:37:34	2020-07-23	9	[{"id_menu":7,"count":1}]	39046	delivery	5	14
102095	2020-07-23 19:41:24	2020-07-23	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	25998	delivery	5	26
102096	2020-07-23 19:42:11	2020-07-23	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	39396	delivery	5	39
102097	2020-07-23 19:46:24	2020-07-23	12	[{"id_menu":1,"count":1}]	39370	delivery	5	17
102098	2020-07-23 19:49:14	2020-07-23	17	[{"id_menu":4,"count":1}]	24105	delivery	5	22
102099	2020-07-23 19:49:20	2020-07-23	17	[{"id_menu":4,"count":1}]	35245	delivery	5	22
102100	2020-07-23 19:50:13	2020-07-23	17	[{"id_menu":4,"count":1}]	4315	pick-up	0	17
102101	2020-07-23 19:52:50	2020-07-23	14	[{"id_menu":2,"count":1}]	39260	delivery	5	19
102102	2020-07-23 19:53:07	2020-07-23	12	[{"id_menu":1,"count":1}]	13724	delivery	5	17
102103	2020-07-23 19:54:05	2020-07-23	9	[{"id_menu":7,"count":1}]	5996	delivery	5	14
102104	2020-07-23 20:00:00	2020-07-23	17	[{"id_menu":4,"count":1}]	39266	delivery	5	22
102105	2020-07-23 20:03:00	2020-07-23	12	[{"id_menu":1,"count":1}]	33441	delivery	5	17
102106	2020-07-23 20:03:34	2020-07-23	9	[{"id_menu":6,"count":1}]	29367	pick-up	0	9
102107	2020-07-23 20:04:06	2020-07-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5549	delivery	5	31
102108	2020-07-23 20:04:16	2020-07-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	32358	delivery	5	28
102109	2020-07-23 20:05:12	2020-07-23	14	[{"id_menu":2,"count":1}]	1376	pick-up	0	14
102110	2020-07-23 20:05:42	2020-07-23	17	[{"id_menu":4,"count":1}]	33049	delivery	5	22
102111	2020-07-23 20:06:59	2020-07-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	33551	delivery	5	36
102112	2020-07-23 20:07:12	2020-07-23	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	4137	pick-up	0	21
102113	2020-07-23 20:19:50	2020-07-23	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39428	delivery	5	54
102114	2020-07-23 20:24:54	2020-07-23	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	39286	delivery	5	40
102115	2020-07-23 20:25:33	2020-07-23	9	[{"id_menu":7,"count":1}]	5857	pick-up	0	9
102116	2020-07-23 20:27:44	2020-07-23	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20119	delivery	5	35
102117	2020-07-23 20:29:09	2020-07-23	9	[{"id_menu":6,"count":1}]	25650	delivery	5	14
102118	2020-07-23 20:30:44	2020-07-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3155	pick-up	0	23
102119	2020-07-23 20:35:52	2020-07-23	8	[{"id_menu":5,"count":1}]	23633	delivery	5	13
102120	2020-07-23 20:35:54	2020-07-23	9	[{"id_menu":6,"count":1}]	25235	delivery	5	14
102121	2020-07-23 20:37:29	2020-07-23	14	[{"id_menu":2,"count":1}]	39351	delivery	5	19
102122	2020-07-23 20:38:16	2020-07-23	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	3380	pick-up	0	23
102123	2020-07-23 20:38:23	2020-07-23	12	[{"id_menu":3,"count":1}]	8229	pick-up	0	12
102124	2020-07-23 20:38:50	2020-07-23	9	[{"id_menu":7,"count":1}]	6146	delivery	5	14
102125	2020-07-23 20:44:56	2020-07-23	14	[{"id_menu":2,"count":1}]	581	delivery	5	19
102126	2020-07-23 20:47:23	2020-07-23	9	[{"id_menu":7,"count":1}]	1627	pick-up	0	9
102128	2020-07-23 20:52:16	2020-07-23	9	[{"id_menu":6,"count":1}]	11709	delivery	5	14
102129	2020-07-23 20:52:39	2020-07-23	9	[{"id_menu":6,"count":2}]	2771	pick-up	0	9
102130	2020-07-23 20:56:14	2020-07-23	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39322	delivery	5	35
102131	2020-07-23 20:59:31	2020-07-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9962	pick-up	0	23
102132	2020-07-23 21:01:14	2020-07-23	9	[{"id_menu":6,"count":1}]	14774	pick-up	0	9
102133	2020-07-23 21:02:23	2020-07-23	9	[{"id_menu":6,"count":2}]	21671	delivery	5	14
102134	2020-07-23 21:04:35	2020-07-23	9	[{"id_menu":6,"count":1}]	399	delivery	5	14
102135	2020-07-23 21:07:54	2020-07-23	8	[{"id_menu":5,"count":1}]	37082	delivery	5	13
102136	2020-07-23 21:15:55	2020-07-23	12	[{"id_menu":3,"count":1}]	24733	pick-up	0	12
102137	2020-07-23 21:17:49	2020-07-23	9	[{"id_menu":6,"count":1}]	39450	delivery	5	14
102138	2020-07-23 21:18:32	2020-07-23	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	39261	delivery	5	39
102139	2020-07-23 21:18:56	2020-07-23	9	[{"id_menu":7,"count":1}]	12992	delivery	5	14
102140	2020-07-23 21:21:45	2020-07-23	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	24284	pick-up	0	21
102141	2020-07-23 21:22:15	2020-07-23	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	39318	delivery	5	27
102142	2020-07-23 21:22:39	2020-07-23	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26690	delivery	5	40
102143	2020-07-23 21:23:17	2020-07-23	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	449	pick-up	0	29
102144	2020-07-23 21:24:27	2020-07-23	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39432	delivery	5	34
102145	2020-07-23 21:25:46	2020-07-23	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3517	delivery	5	38
102146	2020-07-23 21:32:42	2020-07-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	39368	delivery	5	36
102147	2020-07-23 21:33:59	2020-07-23	14	[{"id_menu":2,"count":1}]	24093	pick-up	0	14
102148	2020-07-23 21:36:35	2020-07-23	17	[{"id_menu":4,"count":1}]	39331	delivery	5	22
102149	2020-07-23 21:46:21	2020-07-23	14	[{"id_menu":2,"count":1}]	39308	delivery	5	19
102150	2020-07-23 21:49:40	2020-07-23	17	[{"id_menu":4,"count":1}]	39292	delivery	5	22
102151	2020-07-23 21:54:23	2020-07-23	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	22075	delivery	5	26
102152	2020-07-23 21:58:43	2020-07-23	9	[{"id_menu":7,"count":1}]	23804	delivery	5	14
102153	2020-07-23 21:59:04	2020-07-23	9	[{"id_menu":6,"count":1}]	8071	delivery	5	14
102154	2020-07-23 22:01:47	2020-07-23	12	[{"id_menu":1,"count":1}]	3683	delivery	5	17
102155	2020-07-23 22:07:00	2020-07-23	8	[{"id_menu":5,"count":2}]	2273	pick-up	0	8
102156	2020-07-23 22:08:49	2020-07-23	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	9618	delivery	5	31
102157	2020-07-23 22:14:11	2020-07-23	12	[{"id_menu":1,"count":1}]	1208	pick-up	0	12
102158	2020-07-23 22:15:21	2020-07-23	8	[{"id_menu":5,"count":1}]	3780	pick-up	0	8
102159	2020-07-23 22:15:54	2020-07-23	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39338	delivery	5	31
102160	2020-07-23 22:17:02	2020-07-23	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39365	delivery	5	35
102161	2020-07-23 22:17:23	2020-07-23	12	[{"id_menu":1,"count":1}]	11183	pick-up	0	12
102162	2020-07-23 22:19:40	2020-07-23	12	[{"id_menu":1,"count":1}]	39301	delivery	5	17
102163	2020-07-23 22:20:05	2020-07-23	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10065	delivery	5	35
102164	2020-07-23 22:20:38	2020-07-23	14	[{"id_menu":2,"count":2}]	32184	pick-up	0	14
102165	2020-07-23 22:20:41	2020-07-23	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	39302	delivery	5	23
102166	2020-07-23 22:22:57	2020-07-23	9	[{"id_menu":6,"count":3}]	12914	delivery	5	14
102167	2020-07-23 22:23:12	2020-07-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	13639	pick-up	0	23
102168	2020-07-23 22:26:18	2020-07-23	12	[{"id_menu":3,"count":1}]	80	pick-up	0	12
102169	2020-07-23 22:28:10	2020-07-23	12	[{"id_menu":1,"count":1}]	34805	delivery	5	17
102170	2020-07-23 22:28:59	2020-07-23	9	[{"id_menu":7,"count":2}]	39345	delivery	5	14
102171	2020-07-23 22:30:08	2020-07-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39427	delivery	5	22
102172	2020-07-23 22:35:01	2020-07-23	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1318	pick-up	0	22
102173	2020-07-23 22:41:59	2020-07-23	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	19386	delivery	5	31
102174	2020-07-23 22:44:05	2020-07-23	12	[{"id_menu":3,"count":1}]	25754	delivery	5	17
102175	2020-07-23 22:44:26	2020-07-23	17	[{"id_menu":4,"count":1}]	340	pick-up	0	17
102176	2020-07-23 22:49:14	2020-07-23	12	[{"id_menu":3,"count":1}]	39250	delivery	5	17
102177	2020-07-23 22:50:45	2020-07-23	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	33909	delivery	5	26
102178	2020-07-23 22:51:15	2020-07-23	8	[{"id_menu":5,"count":1}]	30365	delivery	5	13
102179	2020-07-23 22:54:58	2020-07-23	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	39384	delivery	5	45
102180	2020-07-23 22:55:46	2020-07-23	8	[{"id_menu":5,"count":1}]	12297	delivery	5	13
102181	2020-07-23 22:56:45	2020-07-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21617	delivery	5	23
102182	2020-07-23 22:57:25	2020-07-23	8	[{"id_menu":5,"count":1}]	12450	delivery	5	13
102183	2020-07-23 22:57:52	2020-07-23	14	[{"id_menu":2,"count":1}]	11499	delivery	5	19
102184	2020-07-23 22:59:55	2020-07-23	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25658	delivery	5	35
102185	2020-07-23 23:02:16	2020-07-23	8	[{"id_menu":5,"count":1}]	35105	delivery	5	13
102186	2020-07-23 23:03:16	2020-07-23	8	[{"id_menu":5,"count":1}]	33581	delivery	5	13
102187	2020-07-23 23:03:26	2020-07-23	9	[{"id_menu":7,"count":1}]	15768	delivery	5	14
102188	2020-07-23 23:04:31	2020-07-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	9533	pick-up	0	23
102189	2020-07-23 23:05:02	2020-07-23	17	[{"id_menu":4,"count":1}]	39291	delivery	5	22
102190	2020-07-23 23:07:42	2020-07-23	9	[{"id_menu":6,"count":1}]	12078	delivery	5	14
102191	2020-07-23 23:11:47	2020-07-23	17	[{"id_menu":4,"count":1}]	1344	pick-up	0	17
102192	2020-07-23 23:12:29	2020-07-23	17	[{"id_menu":4,"count":1}]	13940	pick-up	0	17
102193	2020-07-23 23:14:06	2020-07-23	9	[{"id_menu":7,"count":1}]	10958	delivery	5	14
102194	2020-07-23 23:14:22	2020-07-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	7746	pick-up	0	26
102195	2020-07-23 23:14:34	2020-07-23	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	39080	delivery	5	34
102196	2020-07-23 23:16:22	2020-07-23	12	[{"id_menu":3,"count":1}]	39401	pick-up	0	12
102197	2020-07-23 23:17:29	2020-07-23	9	[{"id_menu":7,"count":1}]	20948	delivery	5	14
102198	2020-07-23 23:26:07	2020-07-23	14	[{"id_menu":2,"count":1}]	11383	pick-up	0	14
102199	2020-07-23 23:26:29	2020-07-23	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	2153	pick-up	0	26
102200	2020-07-23 23:26:30	2020-07-23	12	[{"id_menu":3,"count":2}]	557	pick-up	0	12
102201	2020-07-23 23:26:54	2020-07-23	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	37992	delivery	5	26
102202	2020-07-23 23:27:18	2020-07-23	9	[{"id_menu":7,"count":1}]	39297	delivery	5	14
102203	2020-07-23 23:27:40	2020-07-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39434	pick-up	0	18
102204	2020-07-23 23:27:43	2020-07-23	8	[{"id_menu":5,"count":1}]	38626	delivery	5	13
102205	2020-07-23 23:28:56	2020-07-23	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	39251	delivery	5	26
102206	2020-07-23 23:30:45	2020-07-23	17	[{"id_menu":4,"count":1}]	39419	delivery	5	22
102207	2020-07-23 23:32:45	2020-07-23	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	37480	delivery	5	31
102208	2020-07-23 23:33:09	2020-07-23	9	[{"id_menu":7,"count":1}]	111	delivery	5	14
102209	2020-07-23 23:35:17	2020-07-23	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	39423	pick-up	0	50
102210	2020-07-23 23:35:37	2020-07-23	9	[{"id_menu":6,"count":1}]	35287	delivery	5	14
102211	2020-07-23 23:36:51	2020-07-23	9	[{"id_menu":6,"count":2}]	39313	delivery	5	14
102212	2020-07-23 23:37:54	2020-07-23	9	[{"id_menu":7,"count":2}]	27019	pick-up	0	9
102213	2020-07-23 23:40:35	2020-07-23	17	[{"id_menu":4,"count":1}]	21594	delivery	5	22
102214	2020-07-23 23:40:52	2020-07-23	9	[{"id_menu":7,"count":1}]	1183	pick-up	0	9
102215	2020-07-23 23:42:20	2020-07-23	9	[{"id_menu":7,"count":1}]	6773	delivery	5	14
102216	2020-07-23 23:47:02	2020-07-23	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4685	pick-up	0	22
102217	2020-07-23 23:54:45	2020-07-23	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39372	delivery	5	37
102218	2020-07-23 23:55:45	2020-07-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	19711	pick-up	0	26
102219	2020-07-23 23:56:39	2020-07-23	9	[{"id_menu":6,"count":1}]	39387	delivery	5	14
102220	2020-07-23 23:57:17	2020-07-23	9	[{"id_menu":6,"count":1}]	17210	delivery	5	14
102221	2020-07-23 23:58:52	2020-07-23	14	[{"id_menu":2,"count":1}]	11992	pick-up	0	14
102222	2020-07-23 23:59:37	2020-07-23	14	[{"id_menu":2,"count":1}]	12784	delivery	5	19
102223	2020-07-24 00:02:46	2020-07-24	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	39674	delivery	5	25
102224	2020-07-24 00:02:54	2020-07-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3570	delivery	5	28
102225	2020-07-24 00:03:12	2020-07-24	9	[{"id_menu":7,"count":1}]	6745	pick-up	0	9
102226	2020-07-24 00:03:56	2020-07-24	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25550	delivery	5	34
102227	2020-07-24 00:04:56	2020-07-24	9	[{"id_menu":6,"count":1}]	34299	delivery	5	14
102228	2020-07-24 00:06:56	2020-07-24	8	[{"id_menu":5,"count":1}]	847	pick-up	0	8
102229	2020-07-24 00:14:04	2020-07-24	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	18981	pick-up	0	26
102230	2020-07-24 00:16:36	2020-07-24	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	38380	delivery	5	37
102231	2020-07-24 00:20:25	2020-07-24	9	[{"id_menu":7,"count":1}]	39665	delivery	5	14
102232	2020-07-24 00:20:36	2020-07-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39683	delivery	5	23
102233	2020-07-24 00:21:16	2020-07-24	9	[{"id_menu":7,"count":1}]	36105	delivery	5	14
102234	2020-07-24 00:22:22	2020-07-24	8	[{"id_menu":5,"count":1}]	39733	delivery	5	13
102235	2020-07-24 00:23:11	2020-07-24	12	[{"id_menu":1,"count":2}]	13568	delivery	5	17
102236	2020-07-24 00:23:13	2020-07-24	12	[{"id_menu":3,"count":1}]	25930	pick-up	0	12
102237	2020-07-24 00:25:10	2020-07-24	9	[{"id_menu":7,"count":1}]	39545	delivery	5	14
102238	2020-07-24 00:27:05	2020-07-24	14	[{"id_menu":2,"count":1}]	39570	delivery	5	19
102239	2020-07-24 00:30:05	2020-07-24	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39642	delivery	5	35
102240	2020-07-24 00:31:03	2020-07-24	9	[{"id_menu":7,"count":1}]	39729	pick-up	0	9
102241	2020-07-24 00:31:55	2020-07-24	8	[{"id_menu":5,"count":1}]	23713	pick-up	0	8
102242	2020-07-24 00:32:44	2020-07-24	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12180	delivery	5	22
102243	2020-07-24 00:40:03	2020-07-24	17	[{"id_menu":4,"count":1}]	17196	delivery	5	22
102244	2020-07-24 00:42:21	2020-07-24	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	35885	delivery	5	48
102245	2020-07-24 00:43:05	2020-07-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29353	delivery	5	22
102246	2020-07-24 00:43:41	2020-07-24	9	[{"id_menu":7,"count":1}]	35408	delivery	5	14
102247	2020-07-24 00:44:28	2020-07-24	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	39489	delivery	5	27
102248	2020-07-24 00:44:40	2020-07-24	17	[{"id_menu":4,"count":1}]	1086	pick-up	0	17
102249	2020-07-24 00:48:16	2020-07-24	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	11529	delivery	5	43
102250	2020-07-24 00:52:20	2020-07-24	9	[{"id_menu":6,"count":1}]	17559	delivery	5	14
102251	2020-07-24 00:56:09	2020-07-24	8	[{"id_menu":5,"count":3}]	39476	delivery	5	13
102252	2020-07-24 00:57:23	2020-07-24	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10491	delivery	5	44
102253	2020-07-24 01:05:35	2020-07-24	9	[{"id_menu":7,"count":1}]	39459	delivery	5	14
102254	2020-07-24 01:15:53	2020-07-24	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	5762	delivery	5	25
102255	2020-07-24 01:19:15	2020-07-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":3}]	39670	delivery	5	23
102256	2020-07-24 01:20:38	2020-07-24	9	[{"id_menu":6,"count":1}]	27127	pick-up	0	9
102257	2020-07-24 01:21:02	2020-07-24	17	[{"id_menu":4,"count":1}]	39598	delivery	5	22
102258	2020-07-24 01:21:44	2020-07-24	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	9637	delivery	5	36
102259	2020-07-24 01:27:30	2020-07-24	12	[{"id_menu":1,"count":1}]	4629	delivery	5	17
102260	2020-07-24 01:27:50	2020-07-24	9	[{"id_menu":6,"count":1}]	39525	delivery	5	14
102261	2020-07-24 01:30:01	2020-07-24	8	[{"id_menu":5,"count":1}]	39475	delivery	5	13
102262	2020-07-24 01:30:26	2020-07-24	12	[{"id_menu":1,"count":1}]	39648	delivery	5	17
102263	2020-07-24 01:31:44	2020-07-24	17	[{"id_menu":4,"count":1}]	36839	pick-up	0	17
102264	2020-07-24 01:32:26	2020-07-24	9	[{"id_menu":7,"count":1}]	20444	delivery	5	14
102265	2020-07-24 01:32:28	2020-07-24	8	[{"id_menu":5,"count":1}]	39634	delivery	5	13
102266	2020-07-24 01:35:15	2020-07-24	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	39644	delivery	5	40
102267	2020-07-24 01:36:52	2020-07-24	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	12900	delivery	5	25
102268	2020-07-24 01:38:36	2020-07-24	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	39471	delivery	5	31
102269	2020-07-24 01:42:22	2020-07-24	9	[{"id_menu":6,"count":1}]	25241	delivery	5	14
102270	2020-07-24 01:44:37	2020-07-24	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	39617	delivery	5	30
102271	2020-07-24 01:44:53	2020-07-24	8	[{"id_menu":5,"count":1}]	39544	delivery	5	13
102272	2020-07-24 01:46:17	2020-07-24	9	[{"id_menu":7,"count":1}]	34238	delivery	5	14
102273	2020-07-24 01:47:13	2020-07-24	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	30679	delivery	5	26
102274	2020-07-24 01:56:09	2020-07-24	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	29358	delivery	5	26
102275	2020-07-24 01:58:12	2020-07-24	12	[{"id_menu":3,"count":1}]	39632	pick-up	0	12
102276	2020-07-24 01:59:07	2020-07-24	8	[{"id_menu":5,"count":1}]	39484	delivery	5	13
102277	2020-07-24 02:02:21	2020-07-24	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	29146	delivery	5	39
102278	2020-07-24 02:03:20	2020-07-24	9	[{"id_menu":7,"count":2}]	22056	delivery	5	14
102279	2020-07-24 02:06:06	2020-07-24	37	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	31329	delivery	5	42
102280	2020-07-24 02:12:55	2020-07-24	12	[{"id_menu":1,"count":1}]	26452	pick-up	0	12
102281	2020-07-24 02:13:14	2020-07-24	12	[{"id_menu":1,"count":1}]	37885	delivery	5	17
102282	2020-07-24 02:25:44	2020-07-24	8	[{"id_menu":5,"count":1}]	39529	delivery	5	13
102283	2020-07-24 02:29:07	2020-07-24	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	39552	delivery	5	31
102284	2020-07-24 02:29:21	2020-07-24	9	[{"id_menu":6,"count":1}]	36574	delivery	5	14
102285	2020-07-24 02:36:56	2020-07-24	17	[{"id_menu":4,"count":1}]	2317	pick-up	0	17
102286	2020-07-24 02:39:05	2020-07-24	8	[{"id_menu":5,"count":1}]	22238	delivery	5	13
102287	2020-07-24 02:40:22	2020-07-24	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	27196	delivery	5	39
102288	2020-07-24 02:51:57	2020-07-24	9	[{"id_menu":7,"count":1}]	39600	delivery	5	14
102289	2020-07-24 02:54:29	2020-07-24	9	[{"id_menu":6,"count":1}]	25298	delivery	5	14
102290	2020-07-24 02:54:56	2020-07-24	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39548	delivery	5	39
102291	2020-07-24 02:57:58	2020-07-24	9	[{"id_menu":7,"count":1}]	10249	delivery	5	14
102292	2020-07-24 02:58:11	2020-07-24	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6147	pick-up	0	26
102293	2020-07-24 03:00:43	2020-07-24	9	[{"id_menu":6,"count":1}]	23074	delivery	5	14
102294	2020-07-24 03:00:56	2020-07-24	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	16345	delivery	5	25
102295	2020-07-24 03:01:39	2020-07-24	9	[{"id_menu":7,"count":1}]	24165	delivery	5	14
102296	2020-07-24 03:02:38	2020-07-24	8	[{"id_menu":5,"count":1}]	39528	delivery	5	13
102297	2020-07-24 03:06:07	2020-07-24	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13236	delivery	5	34
102298	2020-07-24 03:09:31	2020-07-24	14	[{"id_menu":2,"count":1}]	2291	delivery	5	19
102299	2020-07-24 03:10:41	2020-07-24	9	[{"id_menu":6,"count":1}]	39669	delivery	5	14
102300	2020-07-24 03:14:13	2020-07-24	14	[{"id_menu":2,"count":1}]	13911	delivery	5	19
102301	2020-07-24 03:14:26	2020-07-24	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	39535	delivery	5	40
102302	2020-07-24 03:25:59	2020-07-24	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	39536	pick-up	0	26
102303	2020-07-24 03:26:36	2020-07-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	39710	delivery	5	28
102304	2020-07-24 03:27:00	2020-07-24	9	[{"id_menu":6,"count":1}]	24018	pick-up	0	9
102305	2020-07-24 03:28:11	2020-07-24	12	[{"id_menu":1,"count":1}]	21846	delivery	5	17
102306	2020-07-24 03:29:43	2020-07-24	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	13621	delivery	5	39
102307	2020-07-24 03:29:44	2020-07-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	39510	delivery	5	28
102308	2020-07-24 03:30:51	2020-07-24	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22819	delivery	5	54
102309	2020-07-24 03:31:00	2020-07-24	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11096	delivery	5	36
102310	2020-07-24 03:31:04	2020-07-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	18393	pick-up	0	26
102311	2020-07-24 03:33:48	2020-07-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39566	delivery	5	23
102312	2020-07-24 03:34:00	2020-07-24	12	[{"id_menu":3,"count":1}]	4087	pick-up	0	12
102313	2020-07-24 03:34:23	2020-07-24	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	30867	delivery	5	25
102314	2020-07-24 03:34:40	2020-07-24	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	6732	delivery	5	39
102315	2020-07-24 03:38:06	2020-07-24	9	[{"id_menu":7,"count":1}]	39556	delivery	5	14
102316	2020-07-24 03:39:52	2020-07-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39720	delivery	5	23
102317	2020-07-24 03:43:40	2020-07-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	37758	delivery	5	31
102318	2020-07-24 03:44:11	2020-07-24	12	[{"id_menu":3,"count":1}]	21836	delivery	5	17
102319	2020-07-24 03:49:27	2020-07-24	12	[{"id_menu":1,"count":1}]	3173	delivery	5	17
102320	2020-07-24 03:49:27	2020-07-24	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	39505	delivery	5	36
102321	2020-07-24 03:51:01	2020-07-24	8	[{"id_menu":5,"count":1}]	39660	delivery	5	13
102322	2020-07-24 03:52:10	2020-07-24	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	34612	delivery	5	45
102323	2020-07-24 03:52:19	2020-07-24	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	39684	delivery	5	28
102324	2020-07-24 03:53:38	2020-07-24	12	[{"id_menu":3,"count":1}]	39519	delivery	5	17
102325	2020-07-24 03:53:58	2020-07-24	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	39482	delivery	5	26
102326	2020-07-24 03:54:38	2020-07-24	17	[{"id_menu":4,"count":1}]	39549	delivery	5	22
102327	2020-07-24 03:54:44	2020-07-24	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8553	delivery	5	34
102328	2020-07-24 03:58:39	2020-07-24	8	[{"id_menu":5,"count":1}]	39522	delivery	5	13
102329	2020-07-24 04:01:00	2020-07-24	17	[{"id_menu":5,"count":3},{"id_menu":7,"count":1}]	37586	delivery	5	22
102330	2020-07-24 04:01:59	2020-07-24	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	31890	delivery	5	42
102331	2020-07-24 04:04:08	2020-07-24	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39492	delivery	5	40
102332	2020-07-24 04:10:01	2020-07-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	39696	delivery	5	28
102333	2020-07-24 04:12:50	2020-07-24	9	[{"id_menu":6,"count":1}]	39521	delivery	5	14
102334	2020-07-24 04:13:40	2020-07-24	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	38480	delivery	5	25
102335	2020-07-24 04:14:42	2020-07-24	9	[{"id_menu":6,"count":1}]	39540	delivery	5	14
102336	2020-07-24 04:14:46	2020-07-24	17	[{"id_menu":4,"count":1}]	4658	pick-up	0	17
102337	2020-07-24 04:15:36	2020-07-24	12	[{"id_menu":1,"count":1}]	2572	pick-up	0	12
102338	2020-07-24 04:18:11	2020-07-24	9	[{"id_menu":7,"count":1}]	36813	delivery	5	14
102339	2020-07-24 04:19:33	2020-07-24	12	[{"id_menu":1,"count":1}]	13248	delivery	5	17
102340	2020-07-24 04:22:32	2020-07-24	9	[{"id_menu":7,"count":1}]	3494	pick-up	0	9
102341	2020-07-24 04:23:27	2020-07-24	17	[{"id_menu":4,"count":1}]	16529	delivery	5	22
102342	2020-07-24 04:27:16	2020-07-24	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	30777	delivery	5	31
102343	2020-07-24 04:29:03	2020-07-24	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39667	delivery	5	39
102344	2020-07-24 04:30:44	2020-07-24	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	3900	pick-up	0	25
102345	2020-07-24 04:33:28	2020-07-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	39657	delivery	5	31
102346	2020-07-24 04:35:18	2020-07-24	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39508	delivery	5	52
102347	2020-07-24 04:36:08	2020-07-24	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	17430	pick-up	0	21
102348	2020-07-24 04:36:57	2020-07-24	9	[{"id_menu":6,"count":1}]	36798	delivery	5	14
102349	2020-07-24 04:38:13	2020-07-24	12	[{"id_menu":1,"count":1}]	35764	pick-up	0	12
102350	2020-07-24 04:39:07	2020-07-24	17	[{"id_menu":4,"count":1}]	39707	delivery	5	22
102351	2020-07-24 04:40:19	2020-07-24	9	[{"id_menu":7,"count":1}]	39691	delivery	5	14
102352	2020-07-24 04:46:09	2020-07-24	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	11784	delivery	5	29
102353	2020-07-24 04:47:22	2020-07-24	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	34551	pick-up	0	21
102354	2020-07-24 04:47:47	2020-07-24	12	[{"id_menu":1,"count":1}]	32143	delivery	5	17
102355	2020-07-24 04:49:38	2020-07-24	9	[{"id_menu":6,"count":1}]	15105	delivery	5	14
102356	2020-07-24 04:51:29	2020-07-24	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39550	delivery	5	35
102357	2020-07-24 04:54:37	2020-07-24	17	[{"id_menu":4,"count":1}]	28532	pick-up	0	17
102358	2020-07-24 04:59:34	2020-07-24	9	[{"id_menu":6,"count":1}]	3227	pick-up	0	9
102359	2020-07-24 05:06:32	2020-07-24	9	[{"id_menu":7,"count":1}]	8224	pick-up	0	9
102360	2020-07-24 05:08:49	2020-07-24	9	[{"id_menu":7,"count":2}]	28118	pick-up	0	9
102361	2020-07-24 05:09:39	2020-07-24	9	[{"id_menu":6,"count":1}]	36681	delivery	5	14
102362	2020-07-24 05:11:13	2020-07-24	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	39712	delivery	5	38
102363	2020-07-24 05:13:28	2020-07-24	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7383	pick-up	0	26
102364	2020-07-24 05:17:00	2020-07-24	14	[{"id_menu":2,"count":1}]	1808	delivery	5	19
102365	2020-07-24 05:21:49	2020-07-24	9	[{"id_menu":7,"count":1}]	39697	delivery	5	14
102366	2020-07-24 05:21:49	2020-07-24	14	[{"id_menu":2,"count":1}]	7058	delivery	5	19
102367	2020-07-24 05:22:05	2020-07-24	8	[{"id_menu":5,"count":1}]	37761	delivery	5	13
102368	2020-07-24 05:25:14	2020-07-24	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	758	delivery	5	46
102369	2020-07-24 05:26:37	2020-07-24	9	[{"id_menu":7,"count":1}]	39595	delivery	5	14
102370	2020-07-24 05:27:08	2020-07-24	9	[{"id_menu":7,"count":2}]	20938	delivery	5	14
102371	2020-07-24 05:27:29	2020-07-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	39623	delivery	5	23
102372	2020-07-24 05:29:14	2020-07-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3198	pick-up	0	18
102373	2020-07-24 05:31:15	2020-07-24	9	[{"id_menu":7,"count":1}]	4172	pick-up	0	9
102374	2020-07-24 05:35:00	2020-07-24	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	27775	delivery	5	31
102375	2020-07-24 05:36:47	2020-07-24	9	[{"id_menu":6,"count":1}]	33258	delivery	5	14
102376	2020-07-24 05:38:22	2020-07-24	9	[{"id_menu":6,"count":1}]	4224	delivery	5	14
102377	2020-07-24 05:40:07	2020-07-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	39576	delivery	5	22
102378	2020-07-24 05:44:38	2020-07-24	9	[{"id_menu":6,"count":1}]	14189	pick-up	0	9
102379	2020-07-24 05:48:27	2020-07-24	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	28177	delivery	5	36
102380	2020-07-24 05:48:38	2020-07-24	14	[{"id_menu":2,"count":1}]	13257	delivery	5	19
102381	2020-07-24 05:52:22	2020-07-24	22	[{"id_menu":2,"count":3},{"id_menu":5,"count":1}]	34990	delivery	5	27
102382	2020-07-24 06:01:46	2020-07-24	14	[{"id_menu":2,"count":1}]	39701	delivery	5	19
102383	2020-07-24 06:01:54	2020-07-24	14	[{"id_menu":2,"count":1}]	33889	pick-up	0	14
102384	2020-07-24 06:03:27	2020-07-24	9	[{"id_menu":7,"count":1}]	37833	delivery	5	14
102385	2020-07-24 06:05:01	2020-07-24	9	[{"id_menu":6,"count":1}]	5780	delivery	5	14
102386	2020-07-24 06:06:35	2020-07-24	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	39512	delivery	5	26
102387	2020-07-24 06:09:09	2020-07-24	9	[{"id_menu":6,"count":1}]	26208	pick-up	0	9
102388	2020-07-24 06:10:15	2020-07-24	9	[{"id_menu":7,"count":1}]	39572	delivery	5	14
102389	2020-07-24 06:14:37	2020-07-24	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	37454	delivery	5	48
102390	2020-07-24 06:16:54	2020-07-24	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	24273	delivery	5	40
102391	2020-07-24 06:17:11	2020-07-24	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2541	pick-up	0	21
102392	2020-07-24 06:19:04	2020-07-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6148	delivery	5	28
102393	2020-07-24 06:19:10	2020-07-24	9	[{"id_menu":6,"count":1}]	27820	pick-up	0	9
102394	2020-07-24 06:20:31	2020-07-24	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	21176	delivery	5	39
102395	2020-07-24 06:21:40	2020-07-24	14	[{"id_menu":2,"count":1}]	39724	delivery	5	19
102396	2020-07-24 06:21:55	2020-07-24	17	[{"id_menu":4,"count":1}]	609	pick-up	0	17
102397	2020-07-24 06:23:43	2020-07-24	34	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	30486	delivery	5	39
102398	2020-07-24 06:24:33	2020-07-24	17	[{"id_menu":4,"count":1}]	18746	pick-up	0	17
102399	2020-07-24 06:28:02	2020-07-24	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	12567	delivery	5	31
102400	2020-07-24 06:28:44	2020-07-24	12	[{"id_menu":3,"count":1}]	24792	delivery	5	17
102401	2020-07-24 06:29:01	2020-07-24	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29417	delivery	5	34
102402	2020-07-24 06:30:53	2020-07-24	14	[{"id_menu":2,"count":1}]	5996	delivery	5	19
102403	2020-07-24 06:31:37	2020-07-24	14	[{"id_menu":2,"count":1}]	1885	delivery	5	19
102404	2020-07-24 06:33:40	2020-07-24	14	[{"id_menu":2,"count":1}]	39723	delivery	5	19
102405	2020-07-24 06:36:23	2020-07-24	9	[{"id_menu":6,"count":1}]	23613	delivery	5	14
102406	2020-07-24 06:37:16	2020-07-24	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29349	delivery	5	35
102407	2020-07-24 06:37:34	2020-07-24	17	[{"id_menu":4,"count":1}]	30013	delivery	5	22
102408	2020-07-24 06:40:07	2020-07-24	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	28756	delivery	5	28
102409	2020-07-24 06:40:47	2020-07-24	17	[{"id_menu":4,"count":1}]	39474	delivery	5	22
102410	2020-07-24 06:44:06	2020-07-24	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	547	delivery	5	38
102411	2020-07-24 06:45:23	2020-07-24	9	[{"id_menu":6,"count":1}]	39706	delivery	5	14
102412	2020-07-24 06:49:30	2020-07-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32116	delivery	5	23
102413	2020-07-24 06:53:00	2020-07-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3949	pick-up	0	23
102414	2020-07-24 06:55:25	2020-07-24	12	[{"id_menu":1,"count":1}]	39480	delivery	5	17
102415	2020-07-24 06:57:42	2020-07-24	9	[{"id_menu":6,"count":2}]	39602	delivery	5	14
102416	2020-07-24 06:58:59	2020-07-24	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	643	pick-up	0	37
102417	2020-07-24 07:01:10	2020-07-24	14	[{"id_menu":2,"count":1}]	39322	delivery	5	19
102418	2020-07-24 07:01:24	2020-07-24	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	33220	pick-up	0	31
102419	2020-07-24 07:02:47	2020-07-24	9	[{"id_menu":7,"count":1}]	39716	delivery	5	14
102420	2020-07-24 07:12:37	2020-07-24	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	17443	delivery	5	39
102421	2020-07-24 07:13:54	2020-07-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":3}]	27874	delivery	5	31
102422	2020-07-24 07:15:29	2020-07-24	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20942	delivery	5	39
102423	2020-07-24 07:17:17	2020-07-24	9	[{"id_menu":6,"count":1}]	39547	delivery	5	14
102424	2020-07-24 07:19:50	2020-07-24	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	35455	delivery	5	34
102425	2020-07-24 07:21:58	2020-07-24	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	34267	delivery	5	37
102426	2020-07-24 07:24:51	2020-07-24	9	[{"id_menu":6,"count":1}]	12685	delivery	5	14
102427	2020-07-24 07:30:13	2020-07-24	17	[{"id_menu":4,"count":1}]	30553	delivery	5	22
102428	2020-07-24 07:31:52	2020-07-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39490	delivery	5	23
102429	2020-07-24 07:32:01	2020-07-24	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8781	delivery	5	45
102430	2020-07-24 07:32:40	2020-07-24	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	29743	delivery	5	26
102431	2020-07-24 07:34:25	2020-07-24	9	[{"id_menu":7,"count":1}]	3560	delivery	5	14
102432	2020-07-24 07:36:38	2020-07-24	9	[{"id_menu":6,"count":1}]	39659	delivery	5	14
102433	2020-07-24 07:38:13	2020-07-24	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	8729	delivery	5	23
102434	2020-07-24 07:40:54	2020-07-24	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	35894	delivery	5	26
102435	2020-07-24 07:41:02	2020-07-24	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	39555	delivery	5	25
102436	2020-07-24 07:41:28	2020-07-24	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39654	delivery	5	31
102437	2020-07-24 07:42:40	2020-07-24	9	[{"id_menu":6,"count":1}]	39666	delivery	5	14
102438	2020-07-24 07:44:16	2020-07-24	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28441	delivery	5	35
102439	2020-07-24 07:45:16	2020-07-24	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24920	delivery	5	31
102440	2020-07-24 07:46:38	2020-07-24	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13343	delivery	5	36
102441	2020-07-24 07:47:27	2020-07-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	8496	delivery	5	28
102442	2020-07-24 07:48:20	2020-07-24	17	[{"id_menu":4,"count":1}]	32839	delivery	5	22
102443	2020-07-24 07:49:03	2020-07-24	9	[{"id_menu":6,"count":1}]	39532	delivery	5	14
102444	2020-07-24 07:53:15	2020-07-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18929	delivery	5	23
102445	2020-07-24 07:53:32	2020-07-24	9	[{"id_menu":7,"count":1}]	12838	delivery	5	14
102446	2020-07-24 08:01:54	2020-07-24	8	[{"id_menu":5,"count":1}]	39717	delivery	5	13
102447	2020-07-24 08:06:04	2020-07-24	9	[{"id_menu":6,"count":1}]	2367	pick-up	0	9
102448	2020-07-24 08:07:50	2020-07-24	14	[{"id_menu":2,"count":1}]	39520	delivery	5	19
102449	2020-07-24 08:08:18	2020-07-24	9	[{"id_menu":6,"count":1}]	11132	delivery	5	14
102450	2020-07-24 08:15:02	2020-07-24	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	39687	delivery	5	22
102451	2020-07-24 08:19:19	2020-07-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2310	pick-up	0	23
102452	2020-07-24 08:20:39	2020-07-24	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	39518	delivery	5	31
102453	2020-07-24 08:21:37	2020-07-24	17	[{"id_menu":4,"count":1}]	30108	pick-up	0	17
102454	2020-07-24 08:23:21	2020-07-24	14	[{"id_menu":2,"count":1}]	21502	delivery	5	19
102455	2020-07-24 08:28:32	2020-07-24	9	[{"id_menu":6,"count":1}]	28066	delivery	5	14
102456	2020-07-24 08:31:53	2020-07-24	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	21612	delivery	5	26
102457	2020-07-24 08:32:51	2020-07-24	9	[{"id_menu":7,"count":1}]	28576	pick-up	0	9
102458	2020-07-24 08:36:48	2020-07-24	12	[{"id_menu":1,"count":1}]	26150	pick-up	0	12
102459	2020-07-24 08:39:56	2020-07-24	9	[{"id_menu":7,"count":1}]	14813	delivery	5	14
102460	2020-07-24 08:42:33	2020-07-24	9	[{"id_menu":6,"count":1}]	24987	delivery	5	14
102461	2020-07-24 08:43:45	2020-07-24	12	[{"id_menu":1,"count":1}]	39653	delivery	5	17
102462	2020-07-24 08:44:04	2020-07-24	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13606	delivery	5	39
102463	2020-07-24 08:44:35	2020-07-24	9	[{"id_menu":6,"count":1}]	32325	pick-up	0	9
102464	2020-07-24 08:45:15	2020-07-24	9	[{"id_menu":6,"count":1}]	4097	delivery	5	14
102465	2020-07-24 08:45:22	2020-07-24	14	[{"id_menu":2,"count":1}]	39472	delivery	5	19
102466	2020-07-24 08:50:18	2020-07-24	17	[{"id_menu":4,"count":1}]	2444	pick-up	0	17
102467	2020-07-24 08:51:01	2020-07-24	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	31969	delivery	5	34
102468	2020-07-24 08:52:46	2020-07-24	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20265	delivery	5	31
102469	2020-07-24 08:54:13	2020-07-24	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	21794	delivery	5	26
102470	2020-07-24 08:54:17	2020-07-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11534	pick-up	0	18
102471	2020-07-24 08:54:41	2020-07-24	14	[{"id_menu":2,"count":1}]	13855	pick-up	0	14
102472	2020-07-24 09:00:19	2020-07-24	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12148	delivery	5	36
102473	2020-07-24 09:04:34	2020-07-24	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	39554	delivery	5	40
102474	2020-07-24 09:10:56	2020-07-24	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	25861	delivery	5	35
102475	2020-07-24 09:12:05	2020-07-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13713	delivery	5	22
102476	2020-07-24 09:12:58	2020-07-24	9	[{"id_menu":7,"count":1}]	39640	delivery	5	14
102477	2020-07-24 09:14:30	2020-07-24	8	[{"id_menu":5,"count":1}]	22516	delivery	5	13
102478	2020-07-24 09:16:44	2020-07-24	9	[{"id_menu":7,"count":2}]	21388	delivery	5	14
102479	2020-07-24 09:16:49	2020-07-24	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8438	delivery	5	52
102480	2020-07-24 09:17:05	2020-07-24	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	39464	delivery	5	34
102481	2020-07-24 09:18:16	2020-07-24	12	[{"id_menu":3,"count":1}]	26271	pick-up	0	12
102482	2020-07-24 09:18:42	2020-07-24	12	[{"id_menu":3,"count":1}]	16949	delivery	5	17
102483	2020-07-24 09:19:47	2020-07-24	12	[{"id_menu":1,"count":1}]	39682	delivery	5	17
102484	2020-07-24 09:20:44	2020-07-24	8	[{"id_menu":5,"count":1}]	15631	delivery	5	13
102485	2020-07-24 09:21:59	2020-07-24	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	39709	pick-up	0	24
102486	2020-07-24 09:22:27	2020-07-24	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	27757	delivery	5	48
102487	2020-07-24 09:22:31	2020-07-24	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	15680	delivery	5	23
102488	2020-07-24 09:25:27	2020-07-24	8	[{"id_menu":5,"count":1}]	2756	pick-up	0	8
102489	2020-07-24 09:25:36	2020-07-24	17	[{"id_menu":4,"count":1}]	24994	pick-up	0	17
102490	2020-07-24 09:26:56	2020-07-24	9	[{"id_menu":7,"count":1}]	30953	delivery	5	14
102491	2020-07-24 09:27:48	2020-07-24	17	[{"id_menu":4,"count":1}]	17660	delivery	5	22
102492	2020-07-24 09:28:40	2020-07-24	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	10267	delivery	5	52
102493	2020-07-24 09:32:17	2020-07-24	9	[{"id_menu":7,"count":2}]	39477	delivery	5	14
102494	2020-07-24 09:33:54	2020-07-24	12	[{"id_menu":3,"count":1}]	29052	pick-up	0	12
102495	2020-07-24 09:34:09	2020-07-24	8	[{"id_menu":5,"count":1}]	39585	delivery	5	13
102496	2020-07-24 09:36:04	2020-07-24	9	[{"id_menu":7,"count":1}]	27223	delivery	5	14
102497	2020-07-24 09:38:47	2020-07-24	9	[{"id_menu":7,"count":1}]	8123	pick-up	0	9
102498	2020-07-24 09:40:08	2020-07-24	12	[{"id_menu":1,"count":1}]	9303	pick-up	0	12
102499	2020-07-24 09:41:00	2020-07-24	17	[{"id_menu":4,"count":1}]	16804	delivery	5	22
102500	2020-07-24 09:44:39	2020-07-24	17	[{"id_menu":4,"count":1}]	25276	pick-up	0	17
102501	2020-07-24 09:46:56	2020-07-24	17	[{"id_menu":4,"count":1}]	39488	delivery	5	22
102502	2020-07-24 09:54:08	2020-07-24	12	[{"id_menu":1,"count":1}]	39564	delivery	5	17
102503	2020-07-24 09:54:09	2020-07-24	9	[{"id_menu":7,"count":1}]	30053	delivery	5	14
102504	2020-07-24 09:56:31	2020-07-24	9	[{"id_menu":7,"count":2}]	31616	delivery	5	14
102505	2020-07-24 09:56:43	2020-07-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	774	delivery	5	28
102506	2020-07-24 09:57:07	2020-07-24	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	27130	delivery	5	40
102507	2020-07-24 09:58:14	2020-07-24	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39467	delivery	5	36
102508	2020-07-24 09:59:00	2020-07-24	8	[{"id_menu":5,"count":1}]	4655	delivery	5	13
102509	2020-07-24 09:59:35	2020-07-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	39559	delivery	5	31
102510	2020-07-24 09:59:43	2020-07-24	9	[{"id_menu":7,"count":1}]	39650	delivery	5	14
102511	2020-07-24 09:59:54	2020-07-24	17	[{"id_menu":4,"count":1}]	39715	delivery	5	22
102512	2020-07-24 10:06:03	2020-07-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	14546	delivery	5	28
102513	2020-07-24 10:07:10	2020-07-24	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	39542	delivery	5	31
102514	2020-07-24 10:08:10	2020-07-24	9	[{"id_menu":7,"count":1}]	37983	pick-up	0	9
102515	2020-07-24 10:08:44	2020-07-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	39589	delivery	5	31
102516	2020-07-24 10:09:31	2020-07-24	9	[{"id_menu":6,"count":2}]	5430	pick-up	0	9
102517	2020-07-24 10:09:36	2020-07-24	9	[{"id_menu":6,"count":1}]	39478	delivery	5	14
102518	2020-07-24 10:10:44	2020-07-24	17	[{"id_menu":4,"count":1}]	39705	pick-up	0	17
102519	2020-07-24 10:11:04	2020-07-24	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	39569	delivery	5	31
102520	2020-07-24 10:14:00	2020-07-24	17	[{"id_menu":4,"count":1}]	12772	delivery	5	22
102521	2020-07-24 10:17:03	2020-07-24	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	10589	pick-up	0	21
102522	2020-07-24 10:17:26	2020-07-24	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39700	delivery	5	22
102523	2020-07-24 10:17:34	2020-07-24	12	[{"id_menu":1,"count":1}]	35213	pick-up	0	12
102524	2020-07-24 10:18:18	2020-07-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	18533	delivery	5	28
102525	2020-07-24 10:18:31	2020-07-24	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	6192	delivery	5	25
102526	2020-07-24 10:19:42	2020-07-24	12	[{"id_menu":3,"count":1}]	337	pick-up	0	12
102527	2020-07-24 10:22:18	2020-07-24	9	[{"id_menu":6,"count":1}]	39686	delivery	5	14
102528	2020-07-24 10:22:55	2020-07-24	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39568	pick-up	0	17
102529	2020-07-24 10:24:04	2020-07-24	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39622	delivery	5	37
102530	2020-07-24 10:25:27	2020-07-24	14	[{"id_menu":2,"count":1}]	39611	delivery	5	19
102531	2020-07-24 10:31:56	2020-07-24	9	[{"id_menu":6,"count":1}]	16572	delivery	5	14
102532	2020-07-24 10:36:00	2020-07-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	36111	delivery	5	31
102533	2020-07-24 10:37:18	2020-07-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	38497	delivery	5	28
102534	2020-07-24 10:42:51	2020-07-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2372	delivery	5	28
102535	2020-07-24 10:49:00	2020-07-24	9	[{"id_menu":6,"count":1}]	39499	delivery	5	14
102536	2020-07-24 10:53:08	2020-07-24	14	[{"id_menu":2,"count":1}]	39612	delivery	5	19
102537	2020-07-24 10:53:24	2020-07-24	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	20820	pick-up	0	29
102538	2020-07-24 10:54:26	2020-07-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1581	pick-up	0	26
102539	2020-07-24 10:56:31	2020-07-24	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	17113	delivery	5	43
102540	2020-07-24 10:57:12	2020-07-24	9	[{"id_menu":6,"count":1}]	31467	delivery	5	14
102541	2020-07-24 11:02:28	2020-07-24	12	[{"id_menu":3,"count":1}]	31902	delivery	5	17
102542	2020-07-24 11:05:05	2020-07-24	14	[{"id_menu":2,"count":1}]	28101	delivery	5	19
102543	2020-07-24 11:11:14	2020-07-24	9	[{"id_menu":6,"count":2}]	24320	delivery	5	14
102544	2020-07-24 11:14:37	2020-07-24	9	[{"id_menu":7,"count":1}]	39704	delivery	5	14
102545	2020-07-24 11:15:45	2020-07-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	11415	delivery	5	31
102546	2020-07-24 11:16:28	2020-07-24	9	[{"id_menu":7,"count":1}]	5550	delivery	5	14
102547	2020-07-24 11:16:34	2020-07-24	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	25857	delivery	5	36
102548	2020-07-24 11:17:09	2020-07-24	9	[{"id_menu":6,"count":2}]	37330	delivery	5	14
102549	2020-07-24 11:18:20	2020-07-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4522	delivery	5	28
102550	2020-07-24 11:22:50	2020-07-24	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3012	delivery	5	34
102551	2020-07-24 11:26:11	2020-07-24	14	[{"id_menu":2,"count":1}]	29309	delivery	5	19
102552	2020-07-24 11:27:19	2020-07-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	39718	delivery	5	28
102553	2020-07-24 11:28:37	2020-07-24	12	[{"id_menu":3,"count":1}]	18593	delivery	5	17
102554	2020-07-24 11:31:04	2020-07-24	8	[{"id_menu":5,"count":1}]	39326	pick-up	0	8
102555	2020-07-24 11:35:07	2020-07-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39479	delivery	5	23
102556	2020-07-24 11:42:35	2020-07-24	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8586	delivery	5	44
102557	2020-07-24 11:43:49	2020-07-24	9	[{"id_menu":6,"count":1}]	39608	delivery	5	14
102558	2020-07-24 11:49:00	2020-07-24	14	[{"id_menu":2,"count":1}]	4578	delivery	5	19
102559	2020-07-24 11:51:09	2020-07-24	9	[{"id_menu":6,"count":1}]	3883	delivery	5	14
102560	2020-07-24 11:52:52	2020-07-24	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27620	delivery	5	35
102561	2020-07-24 11:53:03	2020-07-24	14	[{"id_menu":2,"count":1}]	3139	pick-up	0	14
102562	2020-07-24 11:56:54	2020-07-24	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	34999	delivery	5	34
102563	2020-07-24 11:57:49	2020-07-24	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	35374	delivery	5	28
102564	2020-07-24 12:00:05	2020-07-24	12	[{"id_menu":1,"count":1}]	3741	delivery	5	17
102565	2020-07-24 12:00:46	2020-07-24	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	26116	delivery	5	43
102566	2020-07-24 12:04:07	2020-07-24	9	[{"id_menu":6,"count":1}]	12791	delivery	5	14
102567	2020-07-24 12:08:25	2020-07-24	9	[{"id_menu":6,"count":1}]	33307	delivery	5	14
102568	2020-07-24 12:09:18	2020-07-24	12	[{"id_menu":3,"count":1}]	39692	delivery	5	17
102569	2020-07-24 12:09:35	2020-07-24	17	[{"id_menu":4,"count":1}]	12935	delivery	5	22
102570	2020-07-24 12:10:15	2020-07-24	12	[{"id_menu":1,"count":1}]	13609	delivery	5	17
102571	2020-07-24 12:10:49	2020-07-24	17	[{"id_menu":4,"count":1}]	39629	delivery	5	22
102572	2020-07-24 12:11:52	2020-07-24	9	[{"id_menu":6,"count":1}]	18750	delivery	5	14
102573	2020-07-24 12:12:10	2020-07-24	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39658	delivery	5	53
102574	2020-07-24 12:15:06	2020-07-24	12	[{"id_menu":1,"count":1}]	39530	pick-up	0	12
102575	2020-07-24 12:15:18	2020-07-24	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19542	delivery	5	22
102576	2020-07-24 12:16:21	2020-07-24	14	[{"id_menu":2,"count":1}]	14325	delivery	5	19
102577	2020-07-24 12:20:13	2020-07-24	9	[{"id_menu":6,"count":1}]	23748	delivery	5	14
102578	2020-07-24 12:20:19	2020-07-24	17	[{"id_menu":4,"count":1}]	2536	delivery	5	22
102579	2020-07-24 12:27:30	2020-07-24	17	[{"id_menu":4,"count":1}]	39641	delivery	5	22
102580	2020-07-24 12:27:34	2020-07-24	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	35961	delivery	5	34
102581	2020-07-24 12:28:39	2020-07-24	9	[{"id_menu":7,"count":1}]	15594	pick-up	0	9
102582	2020-07-24 12:28:47	2020-07-24	9	[{"id_menu":6,"count":1}]	39560	delivery	5	14
102583	2020-07-24 12:31:25	2020-07-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	39455	delivery	5	22
102584	2020-07-24 12:31:43	2020-07-24	9	[{"id_menu":7,"count":1}]	28422	delivery	5	14
102585	2020-07-24 12:35:07	2020-07-24	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	36744	delivery	5	26
102586	2020-07-24 12:36:01	2020-07-24	12	[{"id_menu":1,"count":1}]	2061	pick-up	0	12
102587	2020-07-24 12:37:09	2020-07-24	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	32936	pick-up	0	24
102588	2020-07-24 12:43:47	2020-07-24	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	39579	pick-up	0	29
102589	2020-07-24 12:47:53	2020-07-24	12	[{"id_menu":1,"count":1}]	39562	delivery	5	17
102590	2020-07-24 12:49:56	2020-07-24	9	[{"id_menu":7,"count":1}]	34476	pick-up	0	9
102591	2020-07-24 12:50:41	2020-07-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	39647	delivery	5	31
102592	2020-07-24 12:54:11	2020-07-24	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	33544	delivery	5	57
102593	2020-07-24 12:55:09	2020-07-24	9	[{"id_menu":7,"count":1}]	15948	pick-up	0	9
102594	2020-07-24 12:55:42	2020-07-24	8	[{"id_menu":5,"count":1}]	32305	delivery	5	13
102595	2020-07-24 13:01:44	2020-07-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	23902	delivery	5	28
102596	2020-07-24 13:02:41	2020-07-24	12	[{"id_menu":1,"count":1}]	39584	delivery	5	17
102597	2020-07-24 13:03:32	2020-07-24	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39491	delivery	5	39
102598	2020-07-24 13:04:03	2020-07-24	8	[{"id_menu":5,"count":1}]	16708	delivery	5	13
102599	2020-07-24 13:04:28	2020-07-24	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20172	delivery	5	48
102600	2020-07-24 13:04:30	2020-07-24	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4170	pick-up	0	31
102601	2020-07-24 13:09:06	2020-07-24	17	[{"id_menu":4,"count":1}]	11898	delivery	5	22
102602	2020-07-24 13:10:03	2020-07-24	12	[{"id_menu":1,"count":1}]	12150	delivery	5	17
102603	2020-07-24 13:15:26	2020-07-24	9	[{"id_menu":6,"count":1}]	28815	delivery	5	14
102604	2020-07-24 13:17:19	2020-07-24	8	[{"id_menu":5,"count":1}]	21608	delivery	5	13
102605	2020-07-24 13:18:18	2020-07-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	39661	delivery	5	31
102606	2020-07-24 13:18:46	2020-07-24	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	8358	pick-up	0	21
102607	2020-07-24 13:20:42	2020-07-24	14	[{"id_menu":2,"count":1}]	39730	delivery	5	19
102608	2020-07-24 13:21:34	2020-07-24	14	[{"id_menu":2,"count":1}]	1334	pick-up	0	14
102609	2020-07-24 13:22:51	2020-07-24	14	[{"id_menu":2,"count":1}]	39509	pick-up	0	14
102610	2020-07-24 13:23:49	2020-07-24	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	26837	delivery	5	31
102611	2020-07-24 13:25:07	2020-07-24	17	[{"id_menu":4,"count":1}]	11754	pick-up	0	17
102612	2020-07-24 13:32:18	2020-07-24	14	[{"id_menu":2,"count":1}]	39031	delivery	5	19
102613	2020-07-24 13:33:00	2020-07-24	17	[{"id_menu":4,"count":1}]	34919	delivery	5	22
102614	2020-07-24 13:33:12	2020-07-24	8	[{"id_menu":5,"count":1}]	39732	delivery	5	13
102615	2020-07-24 13:33:19	2020-07-24	12	[{"id_menu":3,"count":1}]	37400	pick-up	0	12
102616	2020-07-24 13:33:46	2020-07-24	14	[{"id_menu":2,"count":1}]	19156	delivery	5	19
102617	2020-07-24 13:34:28	2020-07-24	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	12599	delivery	5	28
102618	2020-07-24 13:36:23	2020-07-24	12	[{"id_menu":1,"count":1}]	27456	delivery	5	17
102619	2020-07-24 13:38:20	2020-07-24	12	[{"id_menu":1,"count":1}]	15391	delivery	5	17
102620	2020-07-24 13:38:24	2020-07-24	12	[{"id_menu":1,"count":1}]	30797	delivery	5	17
102621	2020-07-24 13:39:13	2020-07-24	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	39469	delivery	5	36
102622	2020-07-24 13:46:41	2020-07-24	9	[{"id_menu":6,"count":1}]	9714	delivery	5	14
102623	2020-07-24 13:49:55	2020-07-24	17	[{"id_menu":4,"count":1}]	1944	delivery	5	22
102624	2020-07-24 13:54:38	2020-07-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4943	pick-up	0	23
102625	2020-07-24 13:54:43	2020-07-24	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	23720	delivery	5	26
102626	2020-07-24 13:59:15	2020-07-24	14	[{"id_menu":2,"count":1}]	2129	delivery	5	19
102627	2020-07-24 14:02:07	2020-07-24	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	39567	delivery	5	45
102628	2020-07-24 14:03:18	2020-07-24	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39676	delivery	5	40
102629	2020-07-24 14:03:28	2020-07-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	39656	delivery	5	22
102630	2020-07-24 14:08:14	2020-07-24	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	31351	pick-up	0	26
102631	2020-07-24 14:08:33	2020-07-24	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	27082	pick-up	0	43
102632	2020-07-24 14:08:49	2020-07-24	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	11795	delivery	5	40
102633	2020-07-24 14:11:04	2020-07-24	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	39533	delivery	5	36
102634	2020-07-24 14:12:24	2020-07-24	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	26446	delivery	5	34
102635	2020-07-24 14:16:12	2020-07-24	14	[{"id_menu":2,"count":1}]	14648	delivery	5	19
102636	2020-07-24 14:20:55	2020-07-24	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	39527	delivery	5	45
102637	2020-07-24 14:22:10	2020-07-24	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	23023	delivery	5	37
102638	2020-07-24 14:29:15	2020-07-24	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	35031	delivery	5	30
102639	2020-07-24 14:29:54	2020-07-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	11764	pick-up	0	23
102640	2020-07-24 14:30:27	2020-07-24	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21779	delivery	5	31
102641	2020-07-24 14:31:07	2020-07-24	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3869	delivery	5	26
102642	2020-07-24 14:32:44	2020-07-24	14	[{"id_menu":2,"count":1}]	32050	delivery	5	19
102643	2020-07-24 14:40:01	2020-07-24	9	[{"id_menu":6,"count":1}]	39582	delivery	5	14
102644	2020-07-24 14:45:34	2020-07-24	17	[{"id_menu":4,"count":1}]	4804	delivery	5	22
102645	2020-07-24 14:47:05	2020-07-24	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	39461	delivery	5	35
102646	2020-07-24 14:49:09	2020-07-24	12	[{"id_menu":1,"count":1}]	5167	pick-up	0	12
102647	2020-07-24 14:52:12	2020-07-24	14	[{"id_menu":2,"count":1}]	39625	delivery	5	19
102648	2020-07-24 14:53:17	2020-07-24	12	[{"id_menu":3,"count":1}]	32452	delivery	5	17
102649	2020-07-24 14:54:03	2020-07-24	8	[{"id_menu":5,"count":2}]	39539	delivery	5	13
102650	2020-07-24 14:56:54	2020-07-24	9	[{"id_menu":6,"count":1}]	39643	delivery	5	14
102651	2020-07-24 14:57:07	2020-07-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	21716	delivery	5	28
102652	2020-07-24 14:58:06	2020-07-24	9	[{"id_menu":7,"count":1}]	29805	delivery	5	14
102653	2020-07-24 15:01:24	2020-07-24	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13106	delivery	5	51
102654	2020-07-24 15:03:20	2020-07-24	9	[{"id_menu":7,"count":1}]	39719	delivery	5	14
102655	2020-07-24 15:04:08	2020-07-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	30762	pick-up	0	26
102656	2020-07-24 15:04:18	2020-07-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	39523	delivery	5	22
102657	2020-07-24 15:04:28	2020-07-24	9	[{"id_menu":7,"count":1}]	24765	delivery	5	14
102658	2020-07-24 15:06:16	2020-07-24	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9953	delivery	5	31
102659	2020-07-24 15:06:21	2020-07-24	12	[{"id_menu":1,"count":1}]	4715	delivery	5	17
102660	2020-07-24 15:06:26	2020-07-24	8	[{"id_menu":5,"count":1}]	5117	delivery	5	13
102661	2020-07-24 15:07:14	2020-07-24	14	[{"id_menu":2,"count":1}]	39638	delivery	5	19
102662	2020-07-24 15:07:44	2020-07-24	9	[{"id_menu":7,"count":1}]	27780	delivery	5	14
102663	2020-07-24 15:09:57	2020-07-24	8	[{"id_menu":5,"count":1}]	30359	delivery	5	13
102664	2020-07-24 15:10:13	2020-07-24	8	[{"id_menu":5,"count":1}]	99	delivery	5	13
102665	2020-07-24 15:11:00	2020-07-24	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	39702	delivery	5	25
102666	2020-07-24 15:11:56	2020-07-24	17	[{"id_menu":4,"count":1}]	5917	pick-up	0	17
102667	2020-07-24 15:13:00	2020-07-24	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24625	delivery	5	40
102668	2020-07-24 15:13:05	2020-07-24	12	[{"id_menu":3,"count":1}]	31882	delivery	5	17
102669	2020-07-24 15:13:14	2020-07-24	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	31523	delivery	5	27
102670	2020-07-24 15:13:42	2020-07-24	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	6887	pick-up	0	25
102671	2020-07-24 15:13:59	2020-07-24	17	[{"id_menu":4,"count":1}]	22349	delivery	5	22
102672	2020-07-24 15:14:12	2020-07-24	12	[{"id_menu":3,"count":1}]	39727	delivery	5	17
102673	2020-07-24 15:16:11	2020-07-24	12	[{"id_menu":1,"count":1}]	39501	delivery	5	17
102674	2020-07-24 15:17:55	2020-07-24	9	[{"id_menu":7,"count":1}]	25916	delivery	5	14
102675	2020-07-24 15:19:09	2020-07-24	17	[{"id_menu":4,"count":1}]	39728	delivery	5	22
102676	2020-07-24 15:19:33	2020-07-24	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	32846	pick-up	0	25
102677	2020-07-24 15:21:28	2020-07-24	8	[{"id_menu":5,"count":1}]	1524	pick-up	0	8
102678	2020-07-24 15:23:21	2020-07-24	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	30391	delivery	5	36
102679	2020-07-24 15:24:45	2020-07-24	17	[{"id_menu":4,"count":1}]	29990	pick-up	0	17
102680	2020-07-24 15:26:00	2020-07-24	9	[{"id_menu":6,"count":1}]	36358	delivery	5	14
102681	2020-07-24 15:30:16	2020-07-24	9	[{"id_menu":7,"count":1}]	39498	delivery	5	14
102682	2020-07-24 15:31:57	2020-07-24	14	[{"id_menu":2,"count":1}]	20811	delivery	5	19
102683	2020-07-24 15:34:10	2020-07-24	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	39590	delivery	5	26
102684	2020-07-24 15:37:59	2020-07-24	17	[{"id_menu":4,"count":1}]	27567	delivery	5	22
102685	2020-07-24 15:39:48	2020-07-24	17	[{"id_menu":4,"count":1}]	25695	delivery	5	22
102686	2020-07-24 15:42:45	2020-07-24	8	[{"id_menu":5,"count":1}]	6664	delivery	5	13
102687	2020-07-24 15:43:37	2020-07-24	17	[{"id_menu":4,"count":2}]	39596	delivery	5	22
102688	2020-07-24 15:44:43	2020-07-24	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16156	delivery	5	48
102689	2020-07-24 15:45:39	2020-07-24	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	27639	delivery	5	37
102690	2020-07-24 15:47:47	2020-07-24	9	[{"id_menu":7,"count":1}]	39633	delivery	5	14
102691	2020-07-24 15:48:48	2020-07-24	9	[{"id_menu":6,"count":1}]	39458	delivery	5	14
102692	2020-07-24 15:49:14	2020-07-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4983	delivery	5	28
102693	2020-07-24 15:52:08	2020-07-24	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	21377	delivery	5	26
102694	2020-07-24 15:56:18	2020-07-24	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	759	pick-up	0	21
102695	2020-07-24 15:57:23	2020-07-24	9	[{"id_menu":7,"count":1}]	30286	delivery	5	14
102696	2020-07-24 15:58:29	2020-07-24	17	[{"id_menu":4,"count":1}]	31847	pick-up	0	17
102697	2020-07-24 16:01:10	2020-07-24	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39142	delivery	5	37
102698	2020-07-24 16:01:15	2020-07-24	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	39693	delivery	5	26
102699	2020-07-24 16:03:30	2020-07-24	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	39689	delivery	5	35
102700	2020-07-24 16:04:49	2020-07-24	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	27269	delivery	5	31
102701	2020-07-24 16:05:14	2020-07-24	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	35366	delivery	5	37
102702	2020-07-24 16:06:18	2020-07-24	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32805	delivery	5	35
102703	2020-07-24 16:09:29	2020-07-24	12	[{"id_menu":3,"count":1}]	39135	delivery	5	17
102704	2020-07-24 16:09:31	2020-07-24	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39481	delivery	5	22
102705	2020-07-24 16:12:07	2020-07-24	9	[{"id_menu":6,"count":1}]	6885	delivery	5	14
102706	2020-07-24 16:17:37	2020-07-24	9	[{"id_menu":6,"count":2}]	30790	delivery	5	14
102707	2020-07-24 16:19:24	2020-07-24	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	33196	pick-up	0	24
102708	2020-07-24 16:26:29	2020-07-24	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8546	pick-up	0	35
102709	2020-07-24 16:38:07	2020-07-24	12	[{"id_menu":1,"count":1}]	12011	pick-up	0	12
102710	2020-07-24 16:38:32	2020-07-24	8	[{"id_menu":5,"count":1}]	39713	delivery	5	13
102711	2020-07-24 16:39:26	2020-07-24	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	18343	delivery	5	27
102712	2020-07-24 16:44:40	2020-07-24	37	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	11686	pick-up	0	37
102713	2020-07-24 16:45:18	2020-07-24	12	[{"id_menu":1,"count":1}]	3066	pick-up	0	12
102714	2020-07-24 16:50:43	2020-07-24	9	[{"id_menu":6,"count":1}]	1487	pick-up	0	9
102715	2020-07-24 16:53:26	2020-07-24	14	[{"id_menu":2,"count":1}]	39621	delivery	5	19
102716	2020-07-24 16:56:42	2020-07-24	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	36863	delivery	5	45
102717	2020-07-24 16:58:03	2020-07-24	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	39581	delivery	5	43
102718	2020-07-24 16:58:04	2020-07-24	12	[{"id_menu":1,"count":1}]	39614	delivery	5	17
102719	2020-07-24 16:58:22	2020-07-24	9	[{"id_menu":6,"count":1}]	39688	delivery	5	14
102720	2020-07-24 17:01:47	2020-07-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	39465	pick-up	0	17
102721	2020-07-24 17:02:16	2020-07-24	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	39561	delivery	5	23
102722	2020-07-24 17:02:20	2020-07-24	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	39517	delivery	5	31
102723	2020-07-24 17:02:43	2020-07-24	14	[{"id_menu":2,"count":1}]	39500	delivery	5	19
102724	2020-07-24 17:03:01	2020-07-24	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	18472	delivery	5	34
102725	2020-07-24 17:05:11	2020-07-24	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17381	delivery	5	40
102726	2020-07-24 17:09:23	2020-07-24	9	[{"id_menu":7,"count":1}]	22928	delivery	5	14
102727	2020-07-24 17:09:34	2020-07-24	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	39486	delivery	5	43
102728	2020-07-24 17:10:19	2020-07-24	9	[{"id_menu":6,"count":1}]	6814	delivery	5	14
102729	2020-07-24 17:12:54	2020-07-24	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39651	delivery	5	22
102730	2020-07-24 17:15:43	2020-07-24	9	[{"id_menu":6,"count":1}]	39285	delivery	5	14
102731	2020-07-24 17:16:02	2020-07-24	12	[{"id_menu":1,"count":2}]	10656	delivery	5	17
102732	2020-07-24 17:18:01	2020-07-24	9	[{"id_menu":6,"count":1}]	15989	delivery	5	14
102733	2020-07-24 17:18:06	2020-07-24	9	[{"id_menu":7,"count":2}]	24990	delivery	5	14
102734	2020-07-24 17:22:43	2020-07-24	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39563	delivery	5	39
102735	2020-07-24 17:26:35	2020-07-24	9	[{"id_menu":6,"count":1}]	39575	delivery	5	14
102736	2020-07-24 17:37:10	2020-07-24	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	16287	delivery	5	40
102737	2020-07-24 17:37:12	2020-07-24	14	[{"id_menu":2,"count":1}]	24022	delivery	5	19
102738	2020-07-24 17:37:57	2020-07-24	9	[{"id_menu":7,"count":1}]	22860	delivery	5	14
102739	2020-07-24 17:38:14	2020-07-24	9	[{"id_menu":7,"count":1}]	14023	delivery	5	14
102740	2020-07-24 17:39:17	2020-07-24	8	[{"id_menu":5,"count":2}]	5959	pick-up	0	8
102741	2020-07-24 17:40:53	2020-07-24	8	[{"id_menu":5,"count":1}]	39487	pick-up	0	8
102742	2020-07-24 17:43:34	2020-07-24	9	[{"id_menu":7,"count":1}]	10488	delivery	5	14
102743	2020-07-24 17:50:43	2020-07-24	14	[{"id_menu":2,"count":1}]	38229	delivery	5	19
102744	2020-07-24 17:54:02	2020-07-24	9	[{"id_menu":6,"count":1}]	33582	delivery	5	14
102745	2020-07-24 17:57:42	2020-07-24	14	[{"id_menu":2,"count":1}]	15048	pick-up	0	14
102746	2020-07-24 17:57:44	2020-07-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17481	delivery	5	23
102747	2020-07-24 18:00:31	2020-07-24	9	[{"id_menu":7,"count":2}]	39463	delivery	5	14
102748	2020-07-24 18:01:06	2020-07-24	9	[{"id_menu":6,"count":1}]	39280	delivery	5	14
102749	2020-07-24 18:02:49	2020-07-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	39538	delivery	5	22
102750	2020-07-24 18:05:48	2020-07-24	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	39583	delivery	5	39
102751	2020-07-24 18:06:54	2020-07-24	14	[{"id_menu":2,"count":1}]	12284	pick-up	0	14
102752	2020-07-24 18:06:56	2020-07-24	17	[{"id_menu":4,"count":2}]	39645	delivery	5	22
102753	2020-07-24 18:09:49	2020-07-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6320	delivery	5	28
102754	2020-07-24 18:14:18	2020-07-24	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	30921	pick-up	0	35
102755	2020-07-24 18:17:07	2020-07-24	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	37279	delivery	5	31
102756	2020-07-24 18:17:24	2020-07-24	8	[{"id_menu":5,"count":1}]	39722	delivery	5	13
102757	2020-07-24 18:18:08	2020-07-24	9	[{"id_menu":7,"count":1}]	14451	pick-up	0	9
102758	2020-07-24 18:18:43	2020-07-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4062	pick-up	0	23
102759	2020-07-24 18:19:41	2020-07-24	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	39462	delivery	5	36
102760	2020-07-24 18:22:42	2020-07-24	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	39603	delivery	5	30
102761	2020-07-24 18:26:21	2020-07-24	8	[{"id_menu":5,"count":1}]	3114	delivery	5	13
102762	2020-07-24 18:30:10	2020-07-24	17	[{"id_menu":4,"count":1}]	39620	pick-up	0	17
102763	2020-07-24 18:31:37	2020-07-24	17	[{"id_menu":4,"count":1}]	32572	delivery	5	22
102764	2020-07-24 18:31:49	2020-07-24	12	[{"id_menu":1,"count":1}]	10103	delivery	5	17
102765	2020-07-24 18:32:14	2020-07-24	12	[{"id_menu":3,"count":1}]	20400	delivery	5	17
102766	2020-07-24 18:36:06	2020-07-24	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	37209	delivery	5	36
102767	2020-07-24 18:39:10	2020-07-24	8	[{"id_menu":5,"count":1}]	15127	delivery	5	13
102768	2020-07-24 18:40:28	2020-07-24	14	[{"id_menu":2,"count":1}]	6156	pick-up	0	14
102769	2020-07-24 18:42:15	2020-07-24	12	[{"id_menu":1,"count":1}]	5068	pick-up	0	12
102770	2020-07-24 18:45:41	2020-07-24	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	4959	pick-up	0	43
102771	2020-07-24 18:55:32	2020-07-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11938	delivery	5	31
102772	2020-07-24 18:55:50	2020-07-24	9	[{"id_menu":6,"count":1}]	39483	delivery	5	14
102773	2020-07-24 18:56:49	2020-07-24	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	39514	delivery	5	26
102774	2020-07-24 19:00:15	2020-07-24	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	39626	delivery	5	48
102775	2020-07-24 19:08:18	2020-07-24	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	4308	delivery	5	25
102776	2020-07-24 19:11:36	2020-07-24	17	[{"id_menu":4,"count":1}]	38349	delivery	5	22
102777	2020-07-24 19:12:32	2020-07-24	17	[{"id_menu":4,"count":1}]	39679	delivery	5	22
102778	2020-07-24 19:15:32	2020-07-24	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	29429	pick-up	0	38
102779	2020-07-24 19:16:13	2020-07-24	9	[{"id_menu":6,"count":2}]	39497	delivery	5	14
102780	2020-07-24 19:17:03	2020-07-24	12	[{"id_menu":3,"count":1}]	16170	delivery	5	17
102781	2020-07-24 19:19:07	2020-07-24	9	[{"id_menu":6,"count":1}]	33877	pick-up	0	9
102782	2020-07-24 19:26:37	2020-07-24	8	[{"id_menu":5,"count":1}]	8594	delivery	5	13
102783	2020-07-24 19:28:37	2020-07-24	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	36690	delivery	5	27
102784	2020-07-24 19:31:15	2020-07-24	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	39457	delivery	5	42
102785	2020-07-24 19:32:22	2020-07-24	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	21236	delivery	5	28
102786	2020-07-24 19:32:22	2020-07-24	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	24964	pick-up	0	35
102787	2020-07-24 19:32:37	2020-07-24	14	[{"id_menu":2,"count":1}]	10995	delivery	5	19
102788	2020-07-24 19:33:16	2020-07-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	22590	delivery	5	22
102789	2020-07-24 19:33:34	2020-07-24	14	[{"id_menu":2,"count":2}]	39594	delivery	5	19
102790	2020-07-24 19:34:33	2020-07-24	8	[{"id_menu":5,"count":1}]	21257	delivery	5	13
102791	2020-07-24 19:35:47	2020-07-24	8	[{"id_menu":5,"count":1}]	39551	delivery	5	13
102792	2020-07-24 19:38:58	2020-07-24	9	[{"id_menu":6,"count":1}]	29662	delivery	5	14
102793	2020-07-24 19:39:20	2020-07-24	9	[{"id_menu":7,"count":1}]	360	pick-up	0	9
102794	2020-07-24 19:39:47	2020-07-24	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	39610	delivery	5	25
102795	2020-07-24 19:45:37	2020-07-24	9	[{"id_menu":6,"count":1}]	36206	delivery	5	14
102796	2020-07-24 19:50:12	2020-07-24	9	[{"id_menu":7,"count":1}]	21990	delivery	5	14
102797	2020-07-24 19:50:27	2020-07-24	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	38630	delivery	5	26
102798	2020-07-24 19:55:28	2020-07-24	9	[{"id_menu":7,"count":1}]	30783	delivery	5	14
102799	2020-07-24 19:56:46	2020-07-24	9	[{"id_menu":7,"count":1}]	39721	delivery	5	14
102800	2020-07-24 20:03:49	2020-07-24	9	[{"id_menu":6,"count":2}]	39607	delivery	5	14
102801	2020-07-24 20:08:29	2020-07-24	9	[{"id_menu":7,"count":1}]	3086	delivery	5	14
102802	2020-07-24 20:09:07	2020-07-24	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	30469	delivery	5	26
102803	2020-07-24 20:17:00	2020-07-24	9	[{"id_menu":6,"count":1}]	24573	delivery	5	14
102804	2020-07-24 20:18:48	2020-07-24	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	37201	delivery	5	36
102805	2020-07-24 20:18:52	2020-07-24	9	[{"id_menu":7,"count":2}]	17488	delivery	5	14
102806	2020-07-24 20:23:35	2020-07-24	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	39593	delivery	5	43
102807	2020-07-24 20:27:31	2020-07-24	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15290	delivery	5	37
102808	2020-07-24 20:33:27	2020-07-24	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	39628	delivery	5	39
102809	2020-07-24 20:33:33	2020-07-24	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	39675	delivery	5	26
102810	2020-07-24 20:35:32	2020-07-24	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	18309	pick-up	0	31
102811	2020-07-24 20:38:07	2020-07-24	14	[{"id_menu":2,"count":1}]	13905	delivery	5	19
102812	2020-07-24 20:40:19	2020-07-24	14	[{"id_menu":2,"count":1}]	19313	delivery	5	19
102813	2020-07-24 20:41:30	2020-07-24	12	[{"id_menu":1,"count":1}]	33895	delivery	5	17
102814	2020-07-24 20:42:42	2020-07-24	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	7253	delivery	5	34
102815	2020-07-24 20:44:33	2020-07-24	14	[{"id_menu":2,"count":1}]	37897	delivery	5	19
102816	2020-07-24 20:44:44	2020-07-24	9	[{"id_menu":6,"count":1}]	32070	delivery	5	14
102817	2020-07-24 20:50:23	2020-07-24	9	[{"id_menu":7,"count":1}]	9188	delivery	5	14
102818	2020-07-24 20:57:34	2020-07-24	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39606	delivery	5	22
102819	2020-07-24 20:58:57	2020-07-24	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	33849	pick-up	0	26
102820	2020-07-24 20:58:58	2020-07-24	8	[{"id_menu":5,"count":1}]	461	delivery	5	13
102821	2020-07-24 21:00:29	2020-07-24	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	10495	delivery	5	34
102822	2020-07-24 21:01:19	2020-07-24	14	[{"id_menu":2,"count":1}]	39663	delivery	5	19
102823	2020-07-24 21:01:19	2020-07-24	14	[{"id_menu":2,"count":1}]	9815	delivery	5	19
102824	2020-07-24 21:04:08	2020-07-24	12	[{"id_menu":3,"count":1}]	39695	pick-up	0	12
102825	2020-07-24 21:07:56	2020-07-24	9	[{"id_menu":7,"count":1}]	14593	pick-up	0	9
102826	2020-07-24 21:08:32	2020-07-24	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	23986	delivery	5	26
102827	2020-07-24 21:09:35	2020-07-24	9	[{"id_menu":7,"count":1}]	22844	pick-up	0	9
102828	2020-07-24 21:10:31	2020-07-24	14	[{"id_menu":2,"count":1}]	2081	delivery	5	19
102829	2020-07-24 21:11:42	2020-07-24	14	[{"id_menu":2,"count":1}]	25982	delivery	5	19
102830	2020-07-24 21:12:06	2020-07-24	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	30781	delivery	5	22
102831	2020-07-24 21:12:10	2020-07-24	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1931	pick-up	0	21
102832	2020-07-24 21:15:15	2020-07-24	9	[{"id_menu":6,"count":1}]	39678	delivery	5	14
102833	2020-07-24 21:18:07	2020-07-24	9	[{"id_menu":7,"count":1}]	6591	delivery	5	14
102834	2020-07-24 21:24:14	2020-07-24	17	[{"id_menu":4,"count":1}]	12321	delivery	5	22
102835	2020-07-24 21:25:09	2020-07-24	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38942	delivery	5	35
102836	2020-07-24 21:27:03	2020-07-24	9	[{"id_menu":7,"count":1}]	26373	pick-up	0	9
102837	2020-07-24 21:27:19	2020-07-24	17	[{"id_menu":4,"count":1}]	13212	delivery	5	22
102838	2020-07-24 21:29:16	2020-07-24	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	19753	delivery	5	26
102839	2020-07-24 21:30:23	2020-07-24	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":2}]	3077	delivery	5	27
102840	2020-07-24 21:34:19	2020-07-24	8	[{"id_menu":5,"count":1}]	39587	delivery	5	13
102841	2020-07-24 21:34:55	2020-07-24	9	[{"id_menu":7,"count":1}]	5961	delivery	5	14
102842	2020-07-24 21:35:05	2020-07-24	12	[{"id_menu":1,"count":1}]	39662	pick-up	0	12
102843	2020-07-24 21:36:21	2020-07-24	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5819	delivery	5	42
102844	2020-07-24 21:37:05	2020-07-24	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3858	pick-up	0	22
102845	2020-07-24 21:38:16	2020-07-24	9	[{"id_menu":6,"count":1}]	23349	pick-up	0	9
102846	2020-07-24 21:38:30	2020-07-24	14	[{"id_menu":2,"count":1}]	39439	delivery	5	19
102847	2020-07-24 21:40:24	2020-07-24	8	[{"id_menu":5,"count":1}]	39646	delivery	5	13
102848	2020-07-24 21:44:06	2020-07-24	17	[{"id_menu":4,"count":1}]	13289	pick-up	0	17
102849	2020-07-24 21:44:09	2020-07-24	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6826	delivery	5	35
102850	2020-07-24 21:46:29	2020-07-24	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	13537	delivery	5	30
102851	2020-07-24 21:51:10	2020-07-24	9	[{"id_menu":6,"count":1}]	17194	pick-up	0	9
102852	2020-07-24 21:51:12	2020-07-24	17	[{"id_menu":4,"count":1}]	39672	pick-up	0	17
102853	2020-07-24 21:56:14	2020-07-24	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39639	delivery	5	39
102854	2020-07-24 21:59:18	2020-07-24	8	[{"id_menu":5,"count":1}]	36727	delivery	5	13
102855	2020-07-24 22:08:43	2020-07-24	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	4108	delivery	5	26
102856	2020-07-24 22:09:31	2020-07-24	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	27040	delivery	5	57
102857	2020-07-24 22:09:45	2020-07-24	9	[{"id_menu":6,"count":1}]	39537	delivery	5	14
102858	2020-07-24 22:10:41	2020-07-24	9	[{"id_menu":7,"count":1}]	7647	delivery	5	14
102859	2020-07-24 22:12:43	2020-07-24	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	34979	delivery	5	48
102860	2020-07-24 22:13:52	2020-07-24	8	[{"id_menu":5,"count":1}]	39473	delivery	5	13
102861	2020-07-24 22:14:24	2020-07-24	12	[{"id_menu":1,"count":1}]	6800	delivery	5	17
102862	2020-07-24 22:17:40	2020-07-24	17	[{"id_menu":4,"count":1}]	39516	delivery	5	22
102863	2020-07-24 22:20:54	2020-07-24	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	6876	delivery	5	28
102864	2020-07-24 22:24:38	2020-07-24	14	[{"id_menu":2,"count":1}]	2771	delivery	5	19
102865	2020-07-24 22:25:26	2020-07-24	9	[{"id_menu":7,"count":1}]	14480	delivery	5	14
102866	2020-07-24 22:25:37	2020-07-24	9	[{"id_menu":6,"count":1}]	39604	delivery	5	14
102867	2020-07-24 22:27:29	2020-07-24	12	[{"id_menu":1,"count":1}]	39588	delivery	5	17
102868	2020-07-24 22:27:34	2020-07-24	12	[{"id_menu":1,"count":1}]	25482	delivery	5	17
102869	2020-07-24 22:34:01	2020-07-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18836	delivery	5	22
102870	2020-07-24 22:35:05	2020-07-24	8	[{"id_menu":5,"count":2}]	17571	delivery	5	13
102871	2020-07-24 22:36:21	2020-07-24	17	[{"id_menu":4,"count":1}]	38109	delivery	5	22
102872	2020-07-24 22:37:43	2020-07-24	9	[{"id_menu":7,"count":1}]	28050	delivery	5	14
102873	2020-07-24 22:40:58	2020-07-24	12	[{"id_menu":1,"count":1}]	8314	delivery	5	17
102874	2020-07-24 22:42:19	2020-07-24	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8052	delivery	5	39
102875	2020-07-24 22:43:13	2020-07-24	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	30474	delivery	5	29
102876	2020-07-24 22:48:05	2020-07-24	12	[{"id_menu":1,"count":1}]	32862	delivery	5	17
102877	2020-07-24 22:48:52	2020-07-24	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38746	delivery	5	31
102878	2020-07-24 22:50:14	2020-07-24	12	[{"id_menu":1,"count":1}]	39558	delivery	5	17
102879	2020-07-24 22:51:03	2020-07-24	14	[{"id_menu":2,"count":1}]	5254	delivery	5	19
102880	2020-07-24 22:53:17	2020-07-24	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	31328	delivery	5	42
102881	2020-07-24 22:56:57	2020-07-24	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	38593	delivery	5	25
102882	2020-07-24 22:57:03	2020-07-24	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	26984	pick-up	0	26
102883	2020-07-24 23:02:00	2020-07-24	9	[{"id_menu":6,"count":1}]	39546	delivery	5	14
102884	2020-07-24 23:02:17	2020-07-24	9	[{"id_menu":6,"count":1}]	1339	delivery	5	14
102885	2020-07-24 23:03:52	2020-07-24	9	[{"id_menu":7,"count":1}]	39506	delivery	5	14
102886	2020-07-24 23:10:21	2020-07-24	12	[{"id_menu":1,"count":1}]	39664	delivery	5	17
102887	2020-07-24 23:11:48	2020-07-24	12	[{"id_menu":1,"count":1}]	19366	delivery	5	17
102888	2020-07-24 23:15:41	2020-07-24	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	437	delivery	5	23
102889	2020-07-24 23:17:46	2020-07-24	9	[{"id_menu":7,"count":1}]	39597	delivery	5	14
102890	2020-07-24 23:19:00	2020-07-24	12	[{"id_menu":3,"count":1}]	39573	delivery	5	17
102891	2020-07-24 23:22:48	2020-07-24	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	39671	delivery	5	39
102892	2020-07-24 23:23:09	2020-07-24	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	39495	delivery	5	37
102893	2020-07-24 23:27:46	2020-07-24	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	17352	delivery	5	31
102894	2020-07-24 23:29:19	2020-07-24	14	[{"id_menu":2,"count":1}]	39493	delivery	5	19
102895	2020-07-24 23:31:55	2020-07-24	14	[{"id_menu":2,"count":1}]	12024	delivery	5	19
102896	2020-07-24 23:35:12	2020-07-24	8	[{"id_menu":5,"count":1}]	8632	delivery	5	13
102897	2020-07-24 23:35:38	2020-07-24	9	[{"id_menu":6,"count":1}]	1764	pick-up	0	9
102898	2020-07-24 23:41:06	2020-07-24	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28739	delivery	5	37
102899	2020-07-24 23:45:35	2020-07-24	9	[{"id_menu":6,"count":1}]	39708	delivery	5	14
102900	2020-07-24 23:46:06	2020-07-24	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	39699	delivery	5	25
102901	2020-07-24 23:49:32	2020-07-24	14	[{"id_menu":2,"count":1}]	39524	delivery	5	19
102902	2020-07-24 23:51:16	2020-07-24	12	[{"id_menu":1,"count":1}]	216	pick-up	0	12
102903	2020-07-24 23:51:59	2020-07-24	14	[{"id_menu":2,"count":1}]	5767	delivery	5	19
102904	2020-07-24 23:52:54	2020-07-24	12	[{"id_menu":1,"count":1}]	26694	delivery	5	17
102905	2020-07-25 00:01:16	2020-07-25	9	[{"id_menu":6,"count":1}]	4655	delivery	5	14
102906	2020-07-25 00:03:19	2020-07-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	28402	delivery	5	28
102907	2020-07-25 00:03:40	2020-07-25	9	[{"id_menu":6,"count":1}]	26628	pick-up	0	9
102908	2020-07-25 00:04:47	2020-07-25	17	[{"id_menu":4,"count":1}]	39824	pick-up	0	17
102909	2020-07-25 00:06:09	2020-07-25	9	[{"id_menu":7,"count":1}]	11390	pick-up	0	9
102910	2020-07-25 00:06:33	2020-07-25	17	[{"id_menu":4,"count":1}]	39893	delivery	5	22
102911	2020-07-25 00:11:35	2020-07-25	9	[{"id_menu":6,"count":1}]	18204	delivery	5	14
102912	2020-07-25 00:11:36	2020-07-25	14	[{"id_menu":2,"count":2}]	3078	delivery	5	19
102913	2020-07-25 00:12:39	2020-07-25	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	5098	delivery	5	38
102914	2020-07-25 00:14:29	2020-07-25	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	33439	delivery	5	43
102915	2020-07-25 00:20:00	2020-07-25	14	[{"id_menu":2,"count":1}]	39882	delivery	5	19
102916	2020-07-25 00:21:03	2020-07-25	9	[{"id_menu":6,"count":1}]	39886	delivery	5	14
102917	2020-07-25 00:21:20	2020-07-25	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	17181	delivery	5	31
102918	2020-07-25 00:26:54	2020-07-25	8	[{"id_menu":5,"count":1}]	1541	pick-up	0	8
102919	2020-07-25 00:27:07	2020-07-25	9	[{"id_menu":6,"count":1}]	29230	delivery	5	14
102920	2020-07-25 00:31:23	2020-07-25	9	[{"id_menu":7,"count":1}]	39799	delivery	5	14
102921	2020-07-25 00:33:16	2020-07-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39750	delivery	5	22
102922	2020-07-25 00:33:58	2020-07-25	8	[{"id_menu":5,"count":1}]	285	pick-up	0	8
102923	2020-07-25 00:34:58	2020-07-25	14	[{"id_menu":2,"count":1}]	22467	delivery	5	19
102924	2020-07-25 00:35:10	2020-07-25	9	[{"id_menu":6,"count":1}]	9274	delivery	5	14
102925	2020-07-25 00:35:31	2020-07-25	17	[{"id_menu":4,"count":1}]	13351	delivery	5	22
102926	2020-07-25 00:37:54	2020-07-25	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	2252	pick-up	0	24
102927	2020-07-25 00:40:56	2020-07-25	9	[{"id_menu":6,"count":1}]	23944	delivery	5	14
102928	2020-07-25 00:43:53	2020-07-25	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	30887	delivery	5	26
102929	2020-07-25 00:44:16	2020-07-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	782	delivery	5	23
102930	2020-07-25 00:53:03	2020-07-25	12	[{"id_menu":3,"count":1}]	24913	pick-up	0	12
102931	2020-07-25 00:53:50	2020-07-25	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	24171	delivery	5	45
102932	2020-07-25 00:55:16	2020-07-25	9	[{"id_menu":6,"count":1}]	39907	delivery	5	14
102933	2020-07-25 00:55:17	2020-07-25	12	[{"id_menu":3,"count":1}]	2366	pick-up	0	12
102934	2020-07-25 00:57:37	2020-07-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	17912	delivery	5	23
102935	2020-07-25 00:58:23	2020-07-25	14	[{"id_menu":2,"count":1}]	37453	delivery	5	19
102936	2020-07-25 01:00:23	2020-07-25	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	36458	delivery	5	25
102937	2020-07-25 01:01:18	2020-07-25	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	8866	delivery	5	23
102938	2020-07-25 01:02:27	2020-07-25	14	[{"id_menu":2,"count":1}]	13570	pick-up	0	14
102939	2020-07-25 01:03:40	2020-07-25	8	[{"id_menu":5,"count":1}]	38525	delivery	5	13
102940	2020-07-25 01:04:45	2020-07-25	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	39789	delivery	5	26
102941	2020-07-25 01:09:37	2020-07-25	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	18428	pick-up	0	34
102942	2020-07-25 01:19:07	2020-07-25	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	28908	delivery	5	23
102943	2020-07-25 01:21:42	2020-07-25	14	[{"id_menu":2,"count":1}]	39757	delivery	5	19
102944	2020-07-25 01:23:43	2020-07-25	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31074	delivery	5	36
102945	2020-07-25 01:24:26	2020-07-25	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	39785	delivery	5	26
102946	2020-07-25 01:25:20	2020-07-25	12	[{"id_menu":1,"count":1}]	3568	delivery	5	17
102947	2020-07-25 01:25:50	2020-07-25	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	701	delivery	5	34
102948	2020-07-25 01:26:02	2020-07-25	12	[{"id_menu":3,"count":1}]	39848	delivery	5	17
102949	2020-07-25 01:27:37	2020-07-25	17	[{"id_menu":4,"count":1}]	39759	delivery	5	22
102950	2020-07-25 01:30:52	2020-07-25	12	[{"id_menu":3,"count":1}]	5654	delivery	5	17
102951	2020-07-25 01:32:51	2020-07-25	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	21898	pick-up	0	29
102952	2020-07-25 01:34:05	2020-07-25	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	39843	delivery	5	40
102953	2020-07-25 01:35:30	2020-07-25	12	[{"id_menu":1,"count":1}]	33650	delivery	5	17
102954	2020-07-25 01:36:16	2020-07-25	17	[{"id_menu":4,"count":1}]	9112	pick-up	0	17
102955	2020-07-25 01:37:39	2020-07-25	12	[{"id_menu":1,"count":1}]	541	delivery	5	17
102956	2020-07-25 01:39:16	2020-07-25	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":3}]	39741	pick-up	0	21
102957	2020-07-25 01:41:44	2020-07-25	17	[{"id_menu":4,"count":1}]	39813	pick-up	0	17
102958	2020-07-25 01:45:10	2020-07-25	9	[{"id_menu":7,"count":1}]	15201	delivery	5	14
102959	2020-07-25 01:45:57	2020-07-25	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	39746	pick-up	0	26
102960	2020-07-25 01:49:18	2020-07-25	9	[{"id_menu":6,"count":3}]	21236	delivery	5	14
102961	2020-07-25 01:52:35	2020-07-25	14	[{"id_menu":2,"count":1}]	24943	delivery	5	19
102962	2020-07-25 01:52:59	2020-07-25	8	[{"id_menu":5,"count":1}]	34019	delivery	5	13
102963	2020-07-25 01:55:04	2020-07-25	8	[{"id_menu":5,"count":1}]	39287	delivery	5	13
102964	2020-07-25 01:55:34	2020-07-25	12	[{"id_menu":3,"count":1}]	39766	delivery	5	17
102965	2020-07-25 01:58:26	2020-07-25	12	[{"id_menu":3,"count":1}]	29187	delivery	5	17
102966	2020-07-25 01:59:00	2020-07-25	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	39910	pick-up	0	34
102967	2020-07-25 01:59:16	2020-07-25	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2054	pick-up	0	22
102968	2020-07-25 02:00:26	2020-07-25	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	15456	pick-up	0	29
102969	2020-07-25 02:02:19	2020-07-25	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	10719	delivery	5	26
102970	2020-07-25 02:02:46	2020-07-25	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39895	delivery	5	39
102971	2020-07-25 02:02:51	2020-07-25	9	[{"id_menu":7,"count":1}]	13120	delivery	5	14
102972	2020-07-25 02:03:58	2020-07-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31832	delivery	5	22
102973	2020-07-25 02:05:22	2020-07-25	8	[{"id_menu":5,"count":1}]	26694	delivery	5	13
102974	2020-07-25 02:11:51	2020-07-25	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39823	delivery	5	40
102975	2020-07-25 02:15:18	2020-07-25	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	39360	delivery	5	37
102976	2020-07-25 02:16:43	2020-07-25	12	[{"id_menu":3,"count":1}]	2030	pick-up	0	12
102977	2020-07-25 02:17:09	2020-07-25	12	[{"id_menu":1,"count":1}]	39797	delivery	5	17
102978	2020-07-25 02:17:19	2020-07-25	8	[{"id_menu":5,"count":1}]	34629	pick-up	0	8
102979	2020-07-25 02:17:48	2020-07-25	9	[{"id_menu":7,"count":1}]	9014	delivery	5	14
102980	2020-07-25 02:19:15	2020-07-25	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	39358	delivery	5	26
102981	2020-07-25 02:23:26	2020-07-25	17	[{"id_menu":4,"count":1}]	16380	pick-up	0	17
102982	2020-07-25 02:27:27	2020-07-25	8	[{"id_menu":5,"count":1}]	36664	delivery	5	13
102983	2020-07-25 02:33:10	2020-07-25	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	11811	delivery	5	48
102984	2020-07-25 02:37:16	2020-07-25	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	37201	delivery	5	28
102985	2020-07-25 02:44:34	2020-07-25	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	33670	delivery	5	43
102986	2020-07-25 02:45:07	2020-07-25	12	[{"id_menu":3,"count":1}]	39780	pick-up	0	12
102987	2020-07-25 02:47:44	2020-07-25	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2783	delivery	5	31
102988	2020-07-25 02:49:40	2020-07-25	12	[{"id_menu":1,"count":1}]	5548	pick-up	0	12
102989	2020-07-25 02:49:44	2020-07-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	39901	delivery	5	28
102990	2020-07-25 02:51:40	2020-07-25	12	[{"id_menu":1,"count":1}]	39782	delivery	5	17
102991	2020-07-25 02:56:51	2020-07-25	8	[{"id_menu":5,"count":1}]	2200	pick-up	0	8
102992	2020-07-25 02:58:53	2020-07-25	14	[{"id_menu":2,"count":1}]	39825	delivery	5	19
102993	2020-07-25 03:01:15	2020-07-25	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	34115	delivery	5	48
102994	2020-07-25 03:02:14	2020-07-25	14	[{"id_menu":2,"count":1}]	1677	pick-up	0	14
102995	2020-07-25 03:05:55	2020-07-25	9	[{"id_menu":6,"count":1}]	8432	delivery	5	14
102996	2020-07-25 03:14:12	2020-07-25	14	[{"id_menu":2,"count":1}]	5485	delivery	5	19
102997	2020-07-25 03:17:53	2020-07-25	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	27727	delivery	5	35
102998	2020-07-25 03:18:05	2020-07-25	17	[{"id_menu":4,"count":1}]	9546	delivery	5	22
102999	2020-07-25 03:19:57	2020-07-25	12	[{"id_menu":1,"count":1}]	38631	delivery	5	17
103000	2020-07-25 03:21:31	2020-07-25	9	[{"id_menu":7,"count":1}]	38895	delivery	5	14
103001	2020-07-25 03:21:59	2020-07-25	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	32484	delivery	5	22
103002	2020-07-25 03:24:15	2020-07-25	12	[{"id_menu":1,"count":1}]	39753	pick-up	0	12
103003	2020-07-25 03:27:13	2020-07-25	14	[{"id_menu":2,"count":1}]	7607	delivery	5	19
103004	2020-07-25 03:28:37	2020-07-25	9	[{"id_menu":6,"count":1}]	39817	pick-up	0	9
103005	2020-07-25 03:30:15	2020-07-25	12	[{"id_menu":3,"count":1}]	6515	delivery	5	17
103006	2020-07-25 03:30:25	2020-07-25	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4798	delivery	5	57
103007	2020-07-25 03:33:14	2020-07-25	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	30618	pick-up	0	26
103008	2020-07-25 03:33:51	2020-07-25	8	[{"id_menu":5,"count":1}]	39842	delivery	5	13
103009	2020-07-25 03:34:29	2020-07-25	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8882	delivery	5	31
103010	2020-07-25 03:36:17	2020-07-25	12	[{"id_menu":1,"count":1}]	2544	delivery	5	17
103011	2020-07-25 03:38:41	2020-07-25	9	[{"id_menu":7,"count":1}]	30070	delivery	5	14
103012	2020-07-25 03:38:44	2020-07-25	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	35585	delivery	5	38
103013	2020-07-25 03:39:49	2020-07-25	12	[{"id_menu":1,"count":1}]	39861	delivery	5	17
103014	2020-07-25 03:40:54	2020-07-25	17	[{"id_menu":4,"count":1}]	39894	delivery	5	22
103015	2020-07-25 03:42:21	2020-07-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1068	pick-up	0	17
103016	2020-07-25 03:42:35	2020-07-25	8	[{"id_menu":5,"count":1}]	39775	delivery	5	13
103017	2020-07-25 03:43:16	2020-07-25	9	[{"id_menu":7,"count":2}]	5486	delivery	5	14
103018	2020-07-25 03:43:56	2020-07-25	9	[{"id_menu":7,"count":1}]	39705	delivery	5	14
103019	2020-07-25 03:48:48	2020-07-25	9	[{"id_menu":6,"count":1}]	10162	delivery	5	14
103020	2020-07-25 03:49:40	2020-07-25	9	[{"id_menu":6,"count":1}]	34425	delivery	5	14
103021	2020-07-25 03:49:46	2020-07-25	17	[{"id_menu":4,"count":1}]	39853	delivery	5	22
103022	2020-07-25 03:51:21	2020-07-25	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20711	delivery	5	46
103023	2020-07-25 03:53:37	2020-07-25	8	[{"id_menu":5,"count":1}]	5610	delivery	5	13
103024	2020-07-25 03:57:10	2020-07-25	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12065	delivery	5	39
103025	2020-07-25 03:59:31	2020-07-25	9	[{"id_menu":6,"count":1}]	9716	pick-up	0	9
103026	2020-07-25 04:05:42	2020-07-25	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	39806	delivery	5	31
103027	2020-07-25 04:06:34	2020-07-25	9	[{"id_menu":6,"count":1}]	30413	delivery	5	14
103028	2020-07-25 04:07:10	2020-07-25	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	12983	delivery	5	35
103029	2020-07-25 04:07:17	2020-07-25	12	[{"id_menu":1,"count":1}]	4266	pick-up	0	12
103030	2020-07-25 04:10:37	2020-07-25	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":3}]	31181	delivery	5	30
103031	2020-07-25 04:13:16	2020-07-25	17	[{"id_menu":4,"count":1}]	31129	delivery	5	22
103032	2020-07-25 04:16:56	2020-07-25	17	[{"id_menu":4,"count":1}]	19901	delivery	5	22
103033	2020-07-25 04:18:30	2020-07-25	8	[{"id_menu":5,"count":1}]	5141	delivery	5	13
103034	2020-07-25 04:20:17	2020-07-25	9	[{"id_menu":6,"count":2}]	35265	pick-up	0	9
103035	2020-07-25 04:22:09	2020-07-25	12	[{"id_menu":1,"count":1}]	39	pick-up	0	12
103036	2020-07-25 04:28:50	2020-07-25	14	[{"id_menu":2,"count":1}]	29164	delivery	5	19
103037	2020-07-25 04:34:55	2020-07-25	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	15237	delivery	5	36
103038	2020-07-25 04:36:03	2020-07-25	8	[{"id_menu":5,"count":1}]	6055	delivery	5	13
103039	2020-07-25 04:36:30	2020-07-25	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	39742	delivery	5	39
103040	2020-07-25 04:41:10	2020-07-25	14	[{"id_menu":2,"count":1}]	39810	delivery	5	19
103041	2020-07-25 04:41:48	2020-07-25	12	[{"id_menu":1,"count":1}]	39801	delivery	5	17
103042	2020-07-25 04:42:37	2020-07-25	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	26860	pick-up	0	25
103043	2020-07-25 04:43:31	2020-07-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	23871	delivery	5	28
103044	2020-07-25 04:49:06	2020-07-25	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4182	delivery	5	27
103045	2020-07-25 04:49:19	2020-07-25	17	[{"id_menu":4,"count":1}]	6790	pick-up	0	17
103046	2020-07-25 04:50:00	2020-07-25	8	[{"id_menu":5,"count":1}]	14395	delivery	5	13
103047	2020-07-25 04:52:49	2020-07-25	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35118	delivery	5	52
103048	2020-07-25 04:54:50	2020-07-25	14	[{"id_menu":2,"count":1}]	39786	delivery	5	19
103049	2020-07-25 04:59:18	2020-07-25	12	[{"id_menu":3,"count":1}]	2699	delivery	5	17
103050	2020-07-25 05:00:00	2020-07-25	12	[{"id_menu":3,"count":1}]	36010	pick-up	0	12
103051	2020-07-25 05:02:50	2020-07-25	14	[{"id_menu":2,"count":1}]	39803	delivery	5	19
103052	2020-07-25 05:02:59	2020-07-25	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1722	delivery	5	40
103053	2020-07-25 05:03:02	2020-07-25	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	34106	pick-up	0	21
103054	2020-07-25 05:06:22	2020-07-25	12	[{"id_menu":3,"count":1}]	5257	pick-up	0	12
103055	2020-07-25 05:08:27	2020-07-25	9	[{"id_menu":7,"count":1}]	2197	delivery	5	14
103056	2020-07-25 05:09:04	2020-07-25	14	[{"id_menu":2,"count":1}]	26154	delivery	5	19
103057	2020-07-25 05:11:38	2020-07-25	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	32090	delivery	5	39
103058	2020-07-25 05:11:59	2020-07-25	8	[{"id_menu":5,"count":1}]	3064	delivery	5	13
103059	2020-07-25 05:19:09	2020-07-25	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	39682	delivery	5	30
103060	2020-07-25 05:21:38	2020-07-25	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39849	delivery	5	37
103061	2020-07-25 05:22:08	2020-07-25	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	17372	pick-up	0	31
103062	2020-07-25 05:23:48	2020-07-25	8	[{"id_menu":5,"count":1}]	1473	pick-up	0	8
103063	2020-07-25 05:24:33	2020-07-25	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	14391	pick-up	0	22
103064	2020-07-25 05:24:51	2020-07-25	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1393	delivery	5	31
103065	2020-07-25 05:25:24	2020-07-25	9	[{"id_menu":6,"count":1}]	38658	delivery	5	14
103066	2020-07-25 05:26:57	2020-07-25	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	37907	delivery	5	25
103067	2020-07-25 05:27:59	2020-07-25	9	[{"id_menu":7,"count":1}]	36836	delivery	5	14
103068	2020-07-25 05:30:38	2020-07-25	14	[{"id_menu":2,"count":1}]	7691	pick-up	0	14
103069	2020-07-25 05:30:44	2020-07-25	14	[{"id_menu":2,"count":1}]	39752	delivery	5	19
103070	2020-07-25 05:32:50	2020-07-25	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	39784	delivery	5	31
103071	2020-07-25 05:37:37	2020-07-25	17	[{"id_menu":4,"count":1}]	39816	delivery	5	22
103072	2020-07-25 05:44:15	2020-07-25	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	39900	delivery	5	40
103073	2020-07-25 05:47:33	2020-07-25	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	12049	delivery	5	26
103074	2020-07-25 05:52:54	2020-07-25	9	[{"id_menu":6,"count":1}]	12194	delivery	5	14
103075	2020-07-25 05:53:44	2020-07-25	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	22014	delivery	5	45
103076	2020-07-25 05:56:22	2020-07-25	12	[{"id_menu":3,"count":1}]	38372	pick-up	0	12
103077	2020-07-25 05:58:11	2020-07-25	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	17367	delivery	5	43
103078	2020-07-25 05:58:41	2020-07-25	9	[{"id_menu":6,"count":1}]	39755	delivery	5	14
103079	2020-07-25 05:59:04	2020-07-25	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	33456	delivery	5	36
103080	2020-07-25 06:02:35	2020-07-25	17	[{"id_menu":4,"count":1}]	38788	delivery	5	22
103081	2020-07-25 06:02:37	2020-07-25	9	[{"id_menu":7,"count":1}]	39758	delivery	5	14
103082	2020-07-25 06:02:52	2020-07-25	9	[{"id_menu":6,"count":1}]	39834	delivery	5	14
103083	2020-07-25 06:07:44	2020-07-25	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	39865	delivery	5	29
103084	2020-07-25 06:16:24	2020-07-25	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	35943	delivery	5	36
103085	2020-07-25 06:16:32	2020-07-25	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	24315	delivery	5	40
103086	2020-07-25 06:20:04	2020-07-25	9	[{"id_menu":6,"count":1}]	18171	delivery	5	14
103087	2020-07-25 06:20:46	2020-07-25	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20473	delivery	5	34
103088	2020-07-25 06:21:06	2020-07-25	8	[{"id_menu":5,"count":1}]	39820	delivery	5	13
103089	2020-07-25 06:23:53	2020-07-25	12	[{"id_menu":3,"count":1}]	9478	delivery	5	17
103090	2020-07-25 06:28:49	2020-07-25	9	[{"id_menu":6,"count":1}]	28532	pick-up	0	9
103091	2020-07-25 06:31:15	2020-07-25	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	14127	pick-up	0	26
103092	2020-07-25 06:32:32	2020-07-25	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	39903	delivery	5	34
103093	2020-07-25 06:37:39	2020-07-25	14	[{"id_menu":2,"count":1}]	15374	delivery	5	19
103094	2020-07-25 06:43:46	2020-07-25	9	[{"id_menu":6,"count":1}]	36025	delivery	5	14
103095	2020-07-25 06:44:39	2020-07-25	12	[{"id_menu":3,"count":1}]	27309	delivery	5	17
103096	2020-07-25 06:47:21	2020-07-25	9	[{"id_menu":6,"count":1}]	16450	delivery	5	14
103097	2020-07-25 06:52:55	2020-07-25	14	[{"id_menu":2,"count":1}]	39905	delivery	5	19
103098	2020-07-25 06:53:13	2020-07-25	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	38470	delivery	5	36
103099	2020-07-25 06:56:18	2020-07-25	12	[{"id_menu":1,"count":1}]	26582	delivery	5	17
103100	2020-07-25 06:57:43	2020-07-25	12	[{"id_menu":3,"count":2}]	31903	pick-up	0	12
103101	2020-07-25 06:59:37	2020-07-25	12	[{"id_menu":1,"count":1}]	39768	pick-up	0	12
103102	2020-07-25 07:03:06	2020-07-25	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	32503	pick-up	0	25
103103	2020-07-25 07:03:07	2020-07-25	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7261	delivery	5	40
103104	2020-07-25 07:05:16	2020-07-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16490	delivery	5	22
103105	2020-07-25 07:05:55	2020-07-25	9	[{"id_menu":7,"count":1}]	24326	pick-up	0	9
103106	2020-07-25 07:06:53	2020-07-25	9	[{"id_menu":6,"count":1}]	38100	delivery	5	14
103107	2020-07-25 07:08:16	2020-07-25	9	[{"id_menu":6,"count":1}]	4325	delivery	5	14
103108	2020-07-25 07:08:17	2020-07-25	12	[{"id_menu":3,"count":1}]	33593	delivery	5	17
103109	2020-07-25 07:11:52	2020-07-25	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	24922	delivery	5	31
103110	2020-07-25 07:12:39	2020-07-25	8	[{"id_menu":5,"count":1}]	39779	delivery	5	13
103111	2020-07-25 07:14:35	2020-07-25	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	18436	delivery	5	42
103112	2020-07-25 07:18:20	2020-07-25	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	39892	delivery	5	43
103113	2020-07-25 07:20:33	2020-07-25	38	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	34644	delivery	5	43
103114	2020-07-25 07:20:37	2020-07-25	9	[{"id_menu":6,"count":1}]	25379	delivery	5	14
103115	2020-07-25 07:21:15	2020-07-25	9	[{"id_menu":7,"count":1}]	1684	pick-up	0	9
103116	2020-07-25 07:21:33	2020-07-25	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	23435	delivery	5	38
103117	2020-07-25 07:23:51	2020-07-25	12	[{"id_menu":3,"count":1}]	31238	delivery	5	17
103118	2020-07-25 07:28:27	2020-07-25	14	[{"id_menu":2,"count":1}]	1765	delivery	5	19
103119	2020-07-25 07:28:48	2020-07-25	12	[{"id_menu":3,"count":2}]	24336	delivery	5	17
103120	2020-07-25 07:31:20	2020-07-25	12	[{"id_menu":1,"count":1}]	16461	pick-up	0	12
103121	2020-07-25 07:33:26	2020-07-25	12	[{"id_menu":1,"count":1}]	36358	pick-up	0	12
103122	2020-07-25 07:35:15	2020-07-25	8	[{"id_menu":5,"count":1}]	39762	delivery	5	13
103123	2020-07-25 07:37:43	2020-07-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	25430	delivery	5	23
103124	2020-07-25 07:38:20	2020-07-25	12	[{"id_menu":1,"count":1}]	39888	delivery	5	17
103125	2020-07-25 07:38:23	2020-07-25	17	[{"id_menu":4,"count":1}]	7431	delivery	5	22
103126	2020-07-25 07:46:50	2020-07-25	12	[{"id_menu":1,"count":1}]	1905	pick-up	0	12
103127	2020-07-25 07:48:35	2020-07-25	8	[{"id_menu":5,"count":1}]	32500	delivery	5	13
103128	2020-07-25 07:53:00	2020-07-25	9	[{"id_menu":6,"count":1}]	38927	delivery	5	14
103129	2020-07-25 07:54:07	2020-07-25	9	[{"id_menu":6,"count":1}]	39855	delivery	5	14
103130	2020-07-25 08:00:57	2020-07-25	14	[{"id_menu":2,"count":1}]	39881	delivery	5	19
103131	2020-07-25 08:01:34	2020-07-25	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	14488	delivery	5	26
103132	2020-07-25 08:01:37	2020-07-25	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	39793	delivery	5	35
103133	2020-07-25 08:03:07	2020-07-25	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	39743	delivery	5	31
103134	2020-07-25 08:08:05	2020-07-25	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	1701	delivery	5	31
103135	2020-07-25 08:08:45	2020-07-25	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	39828	delivery	5	35
103136	2020-07-25 08:14:16	2020-07-25	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8043	delivery	5	35
103137	2020-07-25 08:15:54	2020-07-25	8	[{"id_menu":5,"count":1}]	7562	delivery	5	13
103138	2020-07-25 08:18:47	2020-07-25	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	22214	pick-up	0	34
103139	2020-07-25 08:21:09	2020-07-25	12	[{"id_menu":3,"count":1}]	38382	delivery	5	17
103140	2020-07-25 08:21:38	2020-07-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	39771	delivery	5	31
103141	2020-07-25 08:22:48	2020-07-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	12012	pick-up	0	23
103142	2020-07-25 08:24:41	2020-07-25	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	511	pick-up	0	26
103143	2020-07-25 08:24:46	2020-07-25	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	39735	delivery	5	43
103144	2020-07-25 08:26:18	2020-07-25	8	[{"id_menu":5,"count":1}]	8540	delivery	5	13
103145	2020-07-25 08:26:42	2020-07-25	14	[{"id_menu":2,"count":1}]	12000	delivery	5	19
103146	2020-07-25 08:27:05	2020-07-25	14	[{"id_menu":2,"count":2}]	39830	delivery	5	19
103147	2020-07-25 08:28:09	2020-07-25	8	[{"id_menu":5,"count":1}]	39913	delivery	5	13
103148	2020-07-25 08:29:40	2020-07-25	12	[{"id_menu":1,"count":1}]	17091	delivery	5	17
103149	2020-07-25 08:32:29	2020-07-25	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5951	delivery	5	42
103150	2020-07-25 08:32:59	2020-07-25	12	[{"id_menu":1,"count":1}]	3205	pick-up	0	12
103151	2020-07-25 08:35:55	2020-07-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27632	delivery	5	23
103152	2020-07-25 08:36:23	2020-07-25	12	[{"id_menu":1,"count":1}]	37307	delivery	5	17
103153	2020-07-25 08:36:25	2020-07-25	9	[{"id_menu":6,"count":1}]	39242	delivery	5	14
103154	2020-07-25 08:37:31	2020-07-25	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	36481	delivery	5	25
103155	2020-07-25 08:37:56	2020-07-25	9	[{"id_menu":7,"count":1}]	29658	delivery	5	14
103156	2020-07-25 08:42:01	2020-07-25	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	10395	delivery	5	31
103157	2020-07-25 08:42:22	2020-07-25	9	[{"id_menu":7,"count":1}]	2041	pick-up	0	9
103158	2020-07-25 08:43:37	2020-07-25	12	[{"id_menu":3,"count":1}]	31447	pick-up	0	12
103159	2020-07-25 08:43:43	2020-07-25	12	[{"id_menu":3,"count":1}]	3115	pick-up	0	12
103160	2020-07-25 08:45:19	2020-07-25	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	14532	delivery	5	34
103161	2020-07-25 08:47:05	2020-07-25	17	[{"id_menu":4,"count":1}]	39875	delivery	5	22
103162	2020-07-25 08:50:00	2020-07-25	9	[{"id_menu":6,"count":1}]	30469	pick-up	0	9
103163	2020-07-25 08:50:25	2020-07-25	12	[{"id_menu":1,"count":1}]	37095	pick-up	0	12
103164	2020-07-25 08:51:09	2020-07-25	9	[{"id_menu":6,"count":1}]	9160	pick-up	0	9
103165	2020-07-25 08:51:18	2020-07-25	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	3048	pick-up	0	26
103166	2020-07-25 08:53:07	2020-07-25	17	[{"id_menu":4,"count":1}]	20841	delivery	5	22
103167	2020-07-25 08:53:57	2020-07-25	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15959	delivery	5	43
103168	2020-07-25 08:55:30	2020-07-25	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3077	delivery	5	26
103169	2020-07-25 08:56:29	2020-07-25	12	[{"id_menu":3,"count":1}]	35726	delivery	5	17
103170	2020-07-25 08:59:29	2020-07-25	9	[{"id_menu":6,"count":1}]	39870	delivery	5	14
103171	2020-07-25 08:59:38	2020-07-25	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	30367	delivery	5	48
103172	2020-07-25 09:04:08	2020-07-25	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	39852	delivery	5	27
103173	2020-07-25 09:05:03	2020-07-25	9	[{"id_menu":6,"count":1}]	39764	delivery	5	14
103174	2020-07-25 09:06:13	2020-07-25	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	361	pick-up	0	26
103175	2020-07-25 09:07:12	2020-07-25	9	[{"id_menu":7,"count":1}]	39915	delivery	5	14
103176	2020-07-25 09:07:45	2020-07-25	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	16071	delivery	5	43
103177	2020-07-25 09:08:23	2020-07-25	9	[{"id_menu":6,"count":1}]	37655	delivery	5	14
103178	2020-07-25 09:11:32	2020-07-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6608	pick-up	0	26
103179	2020-07-25 09:15:13	2020-07-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	39745	delivery	5	31
103180	2020-07-25 09:15:35	2020-07-25	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39827	delivery	5	31
103181	2020-07-25 09:20:10	2020-07-25	9	[{"id_menu":7,"count":1}]	39878	delivery	5	14
103182	2020-07-25 09:21:09	2020-07-25	12	[{"id_menu":3,"count":1}]	295	pick-up	0	12
103183	2020-07-25 09:22:40	2020-07-25	9	[{"id_menu":7,"count":1}]	17245	delivery	5	14
103184	2020-07-25 09:23:33	2020-07-25	12	[{"id_menu":3,"count":1}]	27556	delivery	5	17
103185	2020-07-25 09:27:02	2020-07-25	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	39866	delivery	5	26
103186	2020-07-25 09:27:29	2020-07-25	12	[{"id_menu":1,"count":1}]	11576	delivery	5	17
103187	2020-07-25 09:28:50	2020-07-25	9	[{"id_menu":7,"count":1}]	39874	delivery	5	14
103188	2020-07-25 09:29:20	2020-07-25	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10662	delivery	5	30
103189	2020-07-25 09:31:53	2020-07-25	17	[{"id_menu":4,"count":1}]	22042	delivery	5	22
103190	2020-07-25 09:34:55	2020-07-25	8	[{"id_menu":5,"count":1}]	1429	pick-up	0	8
103191	2020-07-25 09:40:44	2020-07-25	12	[{"id_menu":1,"count":1}]	5519	pick-up	0	12
103192	2020-07-25 09:41:50	2020-07-25	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	24605	delivery	5	39
103193	2020-07-25 09:42:13	2020-07-25	9	[{"id_menu":7,"count":1}]	39756	delivery	5	14
103194	2020-07-25 09:44:29	2020-07-25	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20079	delivery	5	49
103195	2020-07-25 09:45:40	2020-07-25	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	18067	delivery	5	25
103196	2020-07-25 09:49:14	2020-07-25	12	[{"id_menu":1,"count":1}]	5051	delivery	5	17
103197	2020-07-25 09:49:46	2020-07-25	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6900	delivery	5	52
103198	2020-07-25 09:52:01	2020-07-25	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	39883	pick-up	0	29
103199	2020-07-25 09:59:06	2020-07-25	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	36946	delivery	5	43
103200	2020-07-25 10:03:38	2020-07-25	9	[{"id_menu":6,"count":1}]	1280	pick-up	0	9
103201	2020-07-25 10:04:41	2020-07-25	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8852	delivery	5	37
103202	2020-07-25 10:06:01	2020-07-25	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	30230	delivery	5	23
103203	2020-07-25 10:07:31	2020-07-25	17	[{"id_menu":4,"count":1}]	8300	pick-up	0	17
103204	2020-07-25 10:08:59	2020-07-25	12	[{"id_menu":3,"count":1}]	9575	pick-up	0	12
103205	2020-07-25 10:14:27	2020-07-25	9	[{"id_menu":6,"count":1}]	9972	delivery	5	14
103206	2020-07-25 10:14:37	2020-07-25	17	[{"id_menu":4,"count":1}]	15913	delivery	5	22
103207	2020-07-25 10:14:41	2020-07-25	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	23130	delivery	5	31
103208	2020-07-25 10:20:35	2020-07-25	17	[{"id_menu":4,"count":1}]	30267	pick-up	0	17
103209	2020-07-25 10:24:58	2020-07-25	9	[{"id_menu":7,"count":1}]	2838	delivery	5	14
103210	2020-07-25 10:29:20	2020-07-25	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	10237	delivery	5	26
103211	2020-07-25 10:31:26	2020-07-25	14	[{"id_menu":2,"count":1}]	32343	delivery	5	19
103212	2020-07-25 10:31:34	2020-07-25	17	[{"id_menu":4,"count":1}]	6160	delivery	5	22
103213	2020-07-25 10:33:37	2020-07-25	17	[{"id_menu":4,"count":1}]	37455	delivery	5	22
103214	2020-07-25 10:36:44	2020-07-25	9	[{"id_menu":7,"count":1}]	13634	delivery	5	14
103215	2020-07-25 10:40:48	2020-07-25	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	39891	delivery	5	34
103216	2020-07-25 10:49:05	2020-07-25	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	21386	pick-up	0	26
103217	2020-07-25 10:50:04	2020-07-25	17	[{"id_menu":4,"count":1}]	7292	delivery	5	22
103218	2020-07-25 10:50:56	2020-07-25	8	[{"id_menu":5,"count":1}]	24763	delivery	5	13
103219	2020-07-25 10:51:09	2020-07-25	17	[{"id_menu":4,"count":1}]	10387	pick-up	0	17
103220	2020-07-25 10:53:01	2020-07-25	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	34163	delivery	5	40
103221	2020-07-25 10:57:00	2020-07-25	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	33271	delivery	5	30
103222	2020-07-25 10:57:38	2020-07-25	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	39740	delivery	5	48
103223	2020-07-25 10:58:32	2020-07-25	9	[{"id_menu":7,"count":1}]	3195	delivery	5	14
103224	2020-07-25 11:01:00	2020-07-25	9	[{"id_menu":6,"count":1}]	34245	pick-up	0	9
103225	2020-07-25 11:01:09	2020-07-25	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	17247	pick-up	0	22
103226	2020-07-25 11:01:29	2020-07-25	9	[{"id_menu":6,"count":1}]	21637	delivery	5	14
103227	2020-07-25 11:01:42	2020-07-25	8	[{"id_menu":5,"count":1}]	24143	pick-up	0	8
103228	2020-07-25 11:02:23	2020-07-25	9	[{"id_menu":6,"count":1}]	39908	delivery	5	14
103229	2020-07-25 11:03:01	2020-07-25	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	23997	pick-up	0	21
103230	2020-07-25 11:12:53	2020-07-25	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28094	delivery	5	39
103231	2020-07-25 11:13:12	2020-07-25	17	[{"id_menu":4,"count":1}]	39796	delivery	5	22
103232	2020-07-25 11:15:06	2020-07-25	14	[{"id_menu":2,"count":1}]	11786	delivery	5	19
103233	2020-07-25 11:16:36	2020-07-25	12	[{"id_menu":1,"count":1}]	587	pick-up	0	12
103234	2020-07-25 11:23:30	2020-07-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39896	delivery	5	23
103235	2020-07-25 11:24:54	2020-07-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39850	delivery	5	23
103236	2020-07-25 11:25:23	2020-07-25	9	[{"id_menu":6,"count":1}]	29169	delivery	5	14
103237	2020-07-25 11:26:20	2020-07-25	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19581	delivery	5	31
103238	2020-07-25 11:28:36	2020-07-25	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	39807	delivery	5	39
103239	2020-07-25 11:28:52	2020-07-25	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	39837	delivery	5	35
103240	2020-07-25 11:30:20	2020-07-25	9	[{"id_menu":7,"count":1}]	13019	pick-up	0	9
103241	2020-07-25 11:31:17	2020-07-25	12	[{"id_menu":1,"count":1}]	13187	delivery	5	17
103242	2020-07-25 11:32:10	2020-07-25	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29069	delivery	5	31
103243	2020-07-25 11:32:42	2020-07-25	8	[{"id_menu":5,"count":1}]	20749	delivery	5	13
103244	2020-07-25 11:33:36	2020-07-25	17	[{"id_menu":4,"count":1}]	27859	delivery	5	22
103245	2020-07-25 11:36:09	2020-07-25	12	[{"id_menu":3,"count":1}]	26899	delivery	5	17
103246	2020-07-25 11:36:47	2020-07-25	14	[{"id_menu":2,"count":1}]	38888	delivery	5	19
103247	2020-07-25 11:40:00	2020-07-25	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	18027	pick-up	0	26
103248	2020-07-25 11:42:45	2020-07-25	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39747	delivery	5	53
103249	2020-07-25 11:43:23	2020-07-25	8	[{"id_menu":5,"count":1}]	37077	pick-up	0	8
103250	2020-07-25 11:44:36	2020-07-25	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39800	delivery	5	49
103251	2020-07-25 11:51:08	2020-07-25	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	38940	delivery	5	40
103252	2020-07-25 11:54:38	2020-07-25	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	17835	delivery	5	39
103253	2020-07-25 11:55:44	2020-07-25	12	[{"id_menu":1,"count":1}]	2619	pick-up	0	12
103254	2020-07-25 12:01:04	2020-07-25	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39798	delivery	5	40
103255	2020-07-25 12:02:44	2020-07-25	8	[{"id_menu":5,"count":1}]	25550	delivery	5	13
103256	2020-07-25 12:03:01	2020-07-25	14	[{"id_menu":2,"count":1}]	14380	delivery	5	19
103257	2020-07-25 12:05:03	2020-07-25	8	[{"id_menu":5,"count":1}]	39884	delivery	5	13
103258	2020-07-25 12:07:20	2020-07-25	17	[{"id_menu":4,"count":1}]	34546	delivery	5	22
103259	2020-07-25 12:09:09	2020-07-25	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	39821	delivery	5	44
103260	2020-07-25 12:10:06	2020-07-25	8	[{"id_menu":5,"count":2}]	15422	delivery	5	13
103261	2020-07-25 12:10:47	2020-07-25	14	[{"id_menu":2,"count":1}]	31726	pick-up	0	14
103262	2020-07-25 12:13:35	2020-07-25	9	[{"id_menu":7,"count":1}]	39808	delivery	5	14
103263	2020-07-25 12:22:00	2020-07-25	14	[{"id_menu":2,"count":1}]	7491	delivery	5	19
103264	2020-07-25 12:23:15	2020-07-25	9	[{"id_menu":7,"count":1}]	39847	delivery	5	14
103265	2020-07-25 12:24:21	2020-07-25	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19511	delivery	5	34
103266	2020-07-25 12:25:05	2020-07-25	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	25141	pick-up	0	43
103267	2020-07-25 12:25:23	2020-07-25	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	11921	delivery	5	36
103268	2020-07-25 12:26:41	2020-07-25	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	39748	delivery	5	44
103269	2020-07-25 12:27:19	2020-07-25	8	[{"id_menu":5,"count":1}]	21358	pick-up	0	8
103270	2020-07-25 12:28:19	2020-07-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39818	delivery	5	22
103271	2020-07-25 12:28:35	2020-07-25	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	39844	delivery	5	31
103272	2020-07-25 12:29:36	2020-07-25	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	39879	pick-up	0	26
103273	2020-07-25 12:30:45	2020-07-25	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18221	delivery	5	22
103274	2020-07-25 12:30:53	2020-07-25	8	[{"id_menu":5,"count":1}]	925	pick-up	0	8
103275	2020-07-25 12:35:47	2020-07-25	8	[{"id_menu":5,"count":1}]	18380	delivery	5	13
103276	2020-07-25 12:38:33	2020-07-25	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	30238	delivery	5	40
103277	2020-07-25 12:39:11	2020-07-25	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2799	pick-up	0	22
103278	2020-07-25 12:39:38	2020-07-25	9	[{"id_menu":6,"count":1}]	39846	delivery	5	14
103279	2020-07-25 12:40:06	2020-07-25	9	[{"id_menu":7,"count":1}]	14165	delivery	5	14
103280	2020-07-25 12:42:00	2020-07-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	6593	delivery	5	23
103281	2020-07-25 12:44:05	2020-07-25	14	[{"id_menu":2,"count":1}]	10356	delivery	5	19
103282	2020-07-25 12:44:33	2020-07-25	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	30667	delivery	5	35
103283	2020-07-25 12:44:51	2020-07-25	17	[{"id_menu":4,"count":1}]	18630	delivery	5	22
103284	2020-07-25 12:45:02	2020-07-25	12	[{"id_menu":1,"count":1}]	9923	delivery	5	17
103285	2020-07-25 12:46:06	2020-07-25	14	[{"id_menu":2,"count":1}]	15155	delivery	5	19
103286	2020-07-25 12:46:08	2020-07-25	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	33946	delivery	5	22
103287	2020-07-25 12:47:48	2020-07-25	17	[{"id_menu":4,"count":1}]	39845	delivery	5	22
103288	2020-07-25 12:48:46	2020-07-25	17	[{"id_menu":4,"count":1}]	36605	delivery	5	22
103289	2020-07-25 12:52:00	2020-07-25	17	[{"id_menu":4,"count":1}]	25012	delivery	5	22
103290	2020-07-25 12:52:39	2020-07-25	17	[{"id_menu":4,"count":1}]	39836	delivery	5	22
103291	2020-07-25 12:52:59	2020-07-25	9	[{"id_menu":6,"count":1}]	39812	delivery	5	14
103292	2020-07-25 12:54:46	2020-07-25	9	[{"id_menu":6,"count":2}]	34103	delivery	5	14
103293	2020-07-25 13:00:10	2020-07-25	12	[{"id_menu":1,"count":1}]	19491	delivery	5	17
103294	2020-07-25 13:00:55	2020-07-25	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21	pick-up	0	32
103295	2020-07-25 13:10:37	2020-07-25	17	[{"id_menu":4,"count":1}]	23457	delivery	5	22
103296	2020-07-25 13:10:37	2020-07-25	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	39854	pick-up	0	26
103297	2020-07-25 13:10:44	2020-07-25	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8071	pick-up	0	40
103298	2020-07-25 13:12:45	2020-07-25	14	[{"id_menu":2,"count":1}]	32611	delivery	5	19
103299	2020-07-25 13:13:07	2020-07-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39869	delivery	5	23
103300	2020-07-25 13:13:33	2020-07-25	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	9483	pick-up	0	24
103301	2020-07-25 13:13:42	2020-07-25	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	2623	pick-up	0	24
103302	2020-07-25 13:15:43	2020-07-25	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	39906	delivery	5	26
103303	2020-07-25 13:16:03	2020-07-25	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36842	delivery	5	52
103304	2020-07-25 13:18:59	2020-07-25	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	20601	delivery	5	37
103305	2020-07-25 13:21:46	2020-07-25	14	[{"id_menu":2,"count":1}]	1293	delivery	5	19
103306	2020-07-25 13:22:46	2020-07-25	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39809	pick-up	0	30
103307	2020-07-25 13:23:31	2020-07-25	9	[{"id_menu":6,"count":1}]	39885	delivery	5	14
103308	2020-07-25 13:27:02	2020-07-25	9	[{"id_menu":6,"count":1}]	12057	delivery	5	14
103309	2020-07-25 13:28:08	2020-07-25	14	[{"id_menu":2,"count":1}]	5966	pick-up	0	14
103310	2020-07-25 13:30:27	2020-07-25	9	[{"id_menu":7,"count":1}]	39904	delivery	5	14
103311	2020-07-25 13:31:11	2020-07-25	12	[{"id_menu":3,"count":1}]	39872	pick-up	0	12
103312	2020-07-25 13:33:23	2020-07-25	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	29509	pick-up	0	31
103313	2020-07-25 13:33:24	2020-07-25	12	[{"id_menu":1,"count":1}]	17696	delivery	5	17
103314	2020-07-25 13:34:01	2020-07-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14425	pick-up	0	17
103315	2020-07-25 13:38:18	2020-07-25	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	39912	delivery	5	23
103316	2020-07-25 13:39:49	2020-07-25	9	[{"id_menu":6,"count":1}]	33673	delivery	5	14
103317	2020-07-25 13:40:20	2020-07-25	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	26195	delivery	5	34
103318	2020-07-25 13:40:51	2020-07-25	8	[{"id_menu":5,"count":1}]	9347	delivery	5	13
103319	2020-07-25 13:41:18	2020-07-25	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37830	pick-up	0	35
103320	2020-07-25 13:42:58	2020-07-25	14	[{"id_menu":2,"count":1}]	39814	delivery	5	19
103321	2020-07-25 13:43:56	2020-07-25	22	[{"id_menu":2,"count":3},{"id_menu":5,"count":1}]	39867	delivery	5	27
103322	2020-07-25 13:44:17	2020-07-25	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	21299	delivery	5	28
103323	2020-07-25 13:46:34	2020-07-25	9	[{"id_menu":6,"count":2}]	29159	delivery	5	14
103324	2020-07-25 13:47:17	2020-07-25	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	39840	delivery	5	22
103325	2020-07-25 13:51:16	2020-07-25	14	[{"id_menu":2,"count":1}]	2691	pick-up	0	14
103326	2020-07-25 14:05:23	2020-07-25	8	[{"id_menu":5,"count":1}]	39802	delivery	5	13
103327	2020-07-25 14:07:44	2020-07-25	9	[{"id_menu":7,"count":1}]	5506	pick-up	0	9
103328	2020-07-25 14:09:20	2020-07-25	12	[{"id_menu":1,"count":3}]	8763	delivery	5	17
103329	2020-07-25 14:11:18	2020-07-25	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	39863	delivery	5	39
103330	2020-07-25 14:14:55	2020-07-25	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	15629	delivery	5	25
103331	2020-07-25 14:22:00	2020-07-25	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	39772	delivery	5	45
103332	2020-07-25 14:22:12	2020-07-25	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	18752	delivery	5	38
103333	2020-07-25 14:22:21	2020-07-25	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11362	delivery	5	31
103334	2020-07-25 14:22:27	2020-07-25	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":3}]	14206	delivery	5	26
103335	2020-07-25 14:24:01	2020-07-25	14	[{"id_menu":2,"count":1}]	39889	delivery	5	19
103336	2020-07-25 14:24:41	2020-07-25	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	16571	pick-up	0	29
103337	2020-07-25 14:25:47	2020-07-25	9	[{"id_menu":6,"count":1}]	38434	delivery	5	14
103338	2020-07-25 14:28:37	2020-07-25	9	[{"id_menu":6,"count":1}]	2116	pick-up	0	9
103339	2020-07-25 14:32:21	2020-07-25	12	[{"id_menu":3,"count":1}]	37683	delivery	5	17
103340	2020-07-25 14:35:32	2020-07-25	9	[{"id_menu":7,"count":1}]	21934	delivery	5	14
103341	2020-07-25 14:46:10	2020-07-25	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	23779	delivery	5	26
103342	2020-07-25 14:51:09	2020-07-25	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	39860	delivery	5	38
103343	2020-07-25 14:56:27	2020-07-25	17	[{"id_menu":4,"count":1}]	20490	pick-up	0	17
103344	2020-07-25 14:59:07	2020-07-25	9	[{"id_menu":6,"count":2}]	28102	delivery	5	14
103345	2020-07-25 15:00:55	2020-07-25	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	16996	delivery	5	28
103346	2020-07-25 15:01:08	2020-07-25	12	[{"id_menu":3,"count":1}]	5958	delivery	5	17
103347	2020-07-25 15:01:33	2020-07-25	14	[{"id_menu":2,"count":1}]	39804	pick-up	0	14
103348	2020-07-25 15:03:36	2020-07-25	9	[{"id_menu":6,"count":1}]	36497	pick-up	0	9
103349	2020-07-25 15:04:37	2020-07-25	8	[{"id_menu":5,"count":1}]	18353	delivery	5	13
103350	2020-07-25 15:04:46	2020-07-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34288	delivery	5	23
103351	2020-07-25 15:05:28	2020-07-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	39890	pick-up	0	26
103352	2020-07-25 15:07:28	2020-07-25	14	[{"id_menu":2,"count":1}]	18479	delivery	5	19
103353	2020-07-25 15:09:26	2020-07-25	14	[{"id_menu":2,"count":1}]	39734	delivery	5	19
103354	2020-07-25 15:11:20	2020-07-25	14	[{"id_menu":2,"count":1}]	39091	delivery	5	19
103355	2020-07-25 15:11:27	2020-07-25	9	[{"id_menu":7,"count":1}]	39749	delivery	5	14
103356	2020-07-25 15:12:04	2020-07-25	9	[{"id_menu":6,"count":1}]	1685	delivery	5	14
103357	2020-07-25 15:12:32	2020-07-25	9	[{"id_menu":7,"count":1}]	26901	delivery	5	14
103358	2020-07-25 15:13:18	2020-07-25	55	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	39815	delivery	5	60
103359	2020-07-25 15:14:37	2020-07-25	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	24395	delivery	5	36
103360	2020-07-25 15:18:01	2020-07-25	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	8283	pick-up	0	26
103361	2020-07-25 15:20:50	2020-07-25	12	[{"id_menu":3,"count":1}]	39862	delivery	5	17
103362	2020-07-25 15:21:26	2020-07-25	17	[{"id_menu":4,"count":1}]	9682	pick-up	0	17
103363	2020-07-25 15:23:56	2020-07-25	9	[{"id_menu":7,"count":1}]	5681	delivery	5	14
103364	2020-07-25 15:24:12	2020-07-25	12	[{"id_menu":1,"count":1}]	1864	pick-up	0	12
103365	2020-07-25 15:25:31	2020-07-25	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35853	delivery	5	37
103366	2020-07-25 15:26:34	2020-07-25	14	[{"id_menu":2,"count":1}]	34762	delivery	5	19
103367	2020-07-25 15:29:09	2020-07-25	9	[{"id_menu":7,"count":1}]	37722	delivery	5	14
103368	2020-07-25 15:29:26	2020-07-25	12	[{"id_menu":3,"count":1}]	27579	delivery	5	17
103369	2020-07-25 15:34:10	2020-07-25	8	[{"id_menu":5,"count":1}]	39829	delivery	5	13
103370	2020-07-25 15:34:25	2020-07-25	9	[{"id_menu":7,"count":1}]	8728	delivery	5	14
103371	2020-07-25 15:35:32	2020-07-25	9	[{"id_menu":7,"count":1}]	35018	delivery	5	14
103372	2020-07-25 15:41:50	2020-07-25	8	[{"id_menu":5,"count":2}]	11089	delivery	5	13
103373	2020-07-25 15:43:01	2020-07-25	37	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	23155	delivery	5	42
103374	2020-07-25 15:43:23	2020-07-25	9	[{"id_menu":7,"count":2}]	27942	delivery	5	14
103375	2020-07-25 15:44:21	2020-07-25	14	[{"id_menu":2,"count":1}]	4561	delivery	5	19
103376	2020-07-25 15:45:33	2020-07-25	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4099	delivery	5	31
103377	2020-07-25 15:47:23	2020-07-25	12	[{"id_menu":1,"count":1}]	24098	delivery	5	17
103378	2020-07-25 15:48:06	2020-07-25	9	[{"id_menu":6,"count":1}]	8037	delivery	5	14
103379	2020-07-25 15:50:22	2020-07-25	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	444	pick-up	0	20
103380	2020-07-25 15:57:27	2020-07-25	29	[{"id_menu":1,"count":3},{"id_menu":4,"count":1}]	1101	delivery	5	34
103381	2020-07-25 15:58:44	2020-07-25	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":2}]	18711	delivery	5	22
103382	2020-07-25 16:01:59	2020-07-25	12	[{"id_menu":1,"count":2}]	34534	pick-up	0	12
103383	2020-07-25 16:05:01	2020-07-25	17	[{"id_menu":4,"count":1}]	25808	pick-up	0	17
103384	2020-07-25 16:10:19	2020-07-25	8	[{"id_menu":5,"count":1}]	16155	pick-up	0	8
103385	2020-07-25 16:11:43	2020-07-25	9	[{"id_menu":7,"count":2}]	36985	delivery	5	14
103386	2020-07-25 16:12:38	2020-07-25	8	[{"id_menu":5,"count":1}]	25755	delivery	5	13
103387	2020-07-25 16:13:30	2020-07-25	9	[{"id_menu":6,"count":1}]	39898	pick-up	0	9
103388	2020-07-25 16:22:03	2020-07-25	17	[{"id_menu":4,"count":1}]	29825	delivery	5	22
103389	2020-07-25 16:24:48	2020-07-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	31313	delivery	5	28
103390	2020-07-25 16:26:15	2020-07-25	9	[{"id_menu":6,"count":1}]	5143	pick-up	0	9
103391	2020-07-25 16:27:38	2020-07-25	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	39822	delivery	5	38
103392	2020-07-25 16:28:12	2020-07-25	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24668	pick-up	0	46
103393	2020-07-25 16:30:10	2020-07-25	14	[{"id_menu":2,"count":1}]	39773	delivery	5	19
103394	2020-07-25 16:37:31	2020-07-25	8	[{"id_menu":5,"count":1}]	10807	delivery	5	13
103395	2020-07-25 16:38:26	2020-07-25	9	[{"id_menu":6,"count":1}]	30024	delivery	5	14
103396	2020-07-25 16:38:45	2020-07-25	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39876	delivery	5	35
103397	2020-07-25 16:41:09	2020-07-25	8	[{"id_menu":5,"count":2}]	7508	delivery	5	13
103398	2020-07-25 16:42:00	2020-07-25	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16303	delivery	5	39
103399	2020-07-25 16:42:05	2020-07-25	12	[{"id_menu":1,"count":1}]	2057	delivery	5	17
103400	2020-07-25 16:42:39	2020-07-25	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	17623	delivery	5	48
103401	2020-07-25 16:46:15	2020-07-25	9	[{"id_menu":6,"count":1}]	16921	delivery	5	14
103402	2020-07-25 16:47:55	2020-07-25	9	[{"id_menu":7,"count":1}]	39737	delivery	5	14
103403	2020-07-25 16:48:50	2020-07-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	28815	delivery	5	28
103404	2020-07-25 16:49:45	2020-07-25	12	[{"id_menu":3,"count":1}]	36993	delivery	5	17
103405	2020-07-25 16:50:25	2020-07-25	14	[{"id_menu":2,"count":1}]	26611	delivery	5	19
103406	2020-07-25 16:51:09	2020-07-25	12	[{"id_menu":3,"count":1}]	39770	delivery	5	17
103407	2020-07-25 16:52:13	2020-07-25	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	305	delivery	5	31
103408	2020-07-25 16:53:47	2020-07-25	12	[{"id_menu":1,"count":1}]	32088	delivery	5	17
103409	2020-07-25 16:58:30	2020-07-25	17	[{"id_menu":4,"count":1}]	2659	pick-up	0	17
103410	2020-07-25 17:01:04	2020-07-25	14	[{"id_menu":2,"count":1}]	15281	delivery	5	19
103411	2020-07-25 17:02:37	2020-07-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":3}]	35375	delivery	5	28
103412	2020-07-25 17:05:26	2020-07-25	17	[{"id_menu":4,"count":1}]	35740	pick-up	0	17
103413	2020-07-25 17:06:43	2020-07-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	29841	delivery	5	22
103414	2020-07-25 17:07:18	2020-07-25	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	25301	delivery	5	43
103415	2020-07-25 17:08:16	2020-07-25	17	[{"id_menu":4,"count":1}]	39369	delivery	5	22
103416	2020-07-25 17:10:48	2020-07-25	9	[{"id_menu":6,"count":1}]	39794	delivery	5	14
103417	2020-07-25 17:10:59	2020-07-25	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	18730	delivery	5	45
103418	2020-07-25 17:14:56	2020-07-25	9	[{"id_menu":6,"count":1}]	36047	delivery	5	14
103419	2020-07-25 17:17:11	2020-07-25	9	[{"id_menu":6,"count":1}]	39897	delivery	5	14
103420	2020-07-25 17:18:28	2020-07-25	17	[{"id_menu":4,"count":1}]	26817	pick-up	0	17
103421	2020-07-25 17:18:34	2020-07-25	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	5155	delivery	5	43
103422	2020-07-25 17:24:39	2020-07-25	9	[{"id_menu":6,"count":1}]	13993	delivery	5	14
103423	2020-07-25 17:24:53	2020-07-25	9	[{"id_menu":6,"count":1}]	9744	delivery	5	14
103424	2020-07-25 17:25:18	2020-07-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	20182	delivery	5	28
103425	2020-07-25 17:26:35	2020-07-25	9	[{"id_menu":6,"count":1}]	33370	delivery	5	14
103426	2020-07-25 17:27:24	2020-07-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	39838	delivery	5	31
103427	2020-07-25 17:27:37	2020-07-25	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	11288	delivery	5	31
103428	2020-07-25 17:30:08	2020-07-25	12	[{"id_menu":3,"count":1}]	4172	delivery	5	17
103429	2020-07-25 17:31:05	2020-07-25	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	5371	delivery	5	35
103430	2020-07-25 17:33:10	2020-07-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13294	delivery	5	31
103431	2020-07-25 17:34:20	2020-07-25	9	[{"id_menu":6,"count":1}]	36549	delivery	5	14
103432	2020-07-25 17:34:42	2020-07-25	8	[{"id_menu":5,"count":1}]	754	pick-up	0	8
103433	2020-07-25 17:35:06	2020-07-25	17	[{"id_menu":4,"count":1}]	31545	delivery	5	22
103434	2020-07-25 17:36:53	2020-07-25	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	24950	pick-up	0	22
103435	2020-07-25 17:38:39	2020-07-25	12	[{"id_menu":1,"count":1}]	39839	pick-up	0	12
103436	2020-07-25 17:40:23	2020-07-25	14	[{"id_menu":2,"count":1}]	34137	delivery	5	19
103437	2020-07-25 17:41:25	2020-07-25	17	[{"id_menu":4,"count":1}]	39788	pick-up	0	17
103438	2020-07-25 17:41:55	2020-07-25	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7969	delivery	5	31
103439	2020-07-25 17:45:46	2020-07-25	17	[{"id_menu":4,"count":1}]	33313	pick-up	0	17
103440	2020-07-25 17:48:07	2020-07-25	14	[{"id_menu":2,"count":1}]	36188	delivery	5	19
103441	2020-07-25 17:49:14	2020-07-25	14	[{"id_menu":2,"count":1}]	39751	delivery	5	19
103442	2020-07-25 17:52:12	2020-07-25	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	15872	delivery	5	34
103443	2020-07-25 17:56:10	2020-07-25	8	[{"id_menu":5,"count":1}]	37968	delivery	5	13
103444	2020-07-25 17:56:16	2020-07-25	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	19172	delivery	5	48
103445	2020-07-25 17:58:12	2020-07-25	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	22750	pick-up	0	26
103446	2020-07-25 18:01:27	2020-07-25	8	[{"id_menu":5,"count":2}]	39754	delivery	5	13
103447	2020-07-25 18:03:00	2020-07-25	9	[{"id_menu":6,"count":1}]	39858	delivery	5	14
103448	2020-07-25 18:04:35	2020-07-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	22987	pick-up	0	26
103449	2020-07-25 18:04:49	2020-07-25	8	[{"id_menu":5,"count":1}]	39795	delivery	5	13
103450	2020-07-25 18:07:47	2020-07-25	17	[{"id_menu":4,"count":1}]	17748	delivery	5	22
103451	2020-07-25 18:09:12	2020-07-25	14	[{"id_menu":2,"count":1}]	7338	delivery	5	19
103452	2020-07-25 18:15:25	2020-07-25	17	[{"id_menu":4,"count":1}]	21270	delivery	5	22
103453	2020-07-25 18:18:51	2020-07-25	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	39887	delivery	5	45
103454	2020-07-25 18:21:17	2020-07-25	8	[{"id_menu":5,"count":1}]	29283	pick-up	0	8
103455	2020-07-25 18:21:17	2020-07-25	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	27726	delivery	5	39
103456	2020-07-25 18:24:49	2020-07-25	14	[{"id_menu":2,"count":1}]	16108	delivery	5	19
103457	2020-07-25 18:25:32	2020-07-25	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16444	delivery	5	36
103458	2020-07-25 18:26:15	2020-07-25	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	886	pick-up	0	22
103459	2020-07-25 18:26:48	2020-07-25	12	[{"id_menu":3,"count":1}]	7098	pick-up	0	12
103460	2020-07-25 18:29:24	2020-07-25	12	[{"id_menu":1,"count":1}]	39738	delivery	5	17
103461	2020-07-25 18:30:08	2020-07-25	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	17350	delivery	5	26
103462	2020-07-25 18:30:32	2020-07-25	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	662	pick-up	0	17
103463	2020-07-25 18:33:59	2020-07-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1180	pick-up	0	17
103464	2020-07-25 18:36:30	2020-07-25	17	[{"id_menu":4,"count":1}]	39826	pick-up	0	17
103465	2020-07-25 18:38:39	2020-07-25	17	[{"id_menu":4,"count":1}]	7919	delivery	5	22
103466	2020-07-25 18:43:24	2020-07-25	14	[{"id_menu":2,"count":1}]	8184	delivery	5	19
103467	2020-07-25 18:44:29	2020-07-25	9	[{"id_menu":7,"count":1}]	3600	delivery	5	14
103468	2020-07-25 18:45:18	2020-07-25	9	[{"id_menu":6,"count":1}]	3536	pick-up	0	9
103469	2020-07-25 18:46:14	2020-07-25	9	[{"id_menu":7,"count":1}]	24129	pick-up	0	9
103470	2020-07-25 18:49:13	2020-07-25	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	11063	delivery	5	23
103471	2020-07-25 18:51:14	2020-07-25	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28538	delivery	5	31
103472	2020-07-25 18:51:37	2020-07-25	8	[{"id_menu":5,"count":1}]	2690	pick-up	0	8
103473	2020-07-25 18:52:11	2020-07-25	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	11317	delivery	5	26
103474	2020-07-25 18:52:56	2020-07-25	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16059	delivery	5	49
103475	2020-07-25 18:56:07	2020-07-25	9	[{"id_menu":7,"count":1}]	39778	delivery	5	14
103476	2020-07-25 18:56:53	2020-07-25	17	[{"id_menu":4,"count":1}]	1498	delivery	5	22
103477	2020-07-25 18:58:52	2020-07-25	14	[{"id_menu":2,"count":1}]	27256	delivery	5	19
103478	2020-07-25 19:02:53	2020-07-25	9	[{"id_menu":7,"count":1}]	39520	delivery	5	14
103479	2020-07-25 19:03:42	2020-07-25	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	29532	delivery	5	38
103480	2020-07-25 19:04:23	2020-07-25	12	[{"id_menu":1,"count":1}]	39835	delivery	5	17
103481	2020-07-25 19:05:46	2020-07-25	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	32477	delivery	5	26
103482	2020-07-25 19:06:17	2020-07-25	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	660	pick-up	0	21
103483	2020-07-25 19:06:19	2020-07-25	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	39792	delivery	5	25
103484	2020-07-25 19:12:09	2020-07-25	9	[{"id_menu":7,"count":1}]	26590	delivery	5	14
103485	2020-07-25 19:12:17	2020-07-25	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	22714	delivery	5	34
103486	2020-07-25 19:14:14	2020-07-25	37	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4986	delivery	5	42
103487	2020-07-25 19:21:39	2020-07-25	8	[{"id_menu":5,"count":1}]	7515	delivery	5	13
103488	2020-07-25 19:22:19	2020-07-25	9	[{"id_menu":7,"count":1}]	39851	delivery	5	14
103489	2020-07-25 19:22:50	2020-07-25	14	[{"id_menu":2,"count":1}]	24253	delivery	5	19
103490	2020-07-25 19:27:15	2020-07-25	17	[{"id_menu":4,"count":1}]	28892	delivery	5	22
103491	2020-07-25 19:28:00	2020-07-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29529	delivery	5	23
103492	2020-07-25 19:28:59	2020-07-25	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	25764	delivery	5	34
103493	2020-07-25 19:29:28	2020-07-25	12	[{"id_menu":3,"count":1}]	1259	pick-up	0	12
103494	2020-07-25 19:31:12	2020-07-25	12	[{"id_menu":1,"count":1}]	18172	delivery	5	17
103495	2020-07-25 19:38:20	2020-07-25	9	[{"id_menu":6,"count":1}]	6491	delivery	5	14
103496	2020-07-25 19:39:04	2020-07-25	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	18233	delivery	5	52
103497	2020-07-25 19:39:35	2020-07-25	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	39767	delivery	5	36
103498	2020-07-25 19:42:00	2020-07-25	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	39832	delivery	5	28
103499	2020-07-25 19:47:22	2020-07-25	9	[{"id_menu":6,"count":1}]	10302	delivery	5	14
103500	2020-07-25 19:51:02	2020-07-25	12	[{"id_menu":3,"count":1}]	39856	delivery	5	17
103501	2020-07-25 19:51:41	2020-07-25	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	38809	delivery	5	22
103502	2020-07-25 19:52:07	2020-07-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	39831	delivery	5	28
103503	2020-07-25 19:52:30	2020-07-25	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	39873	delivery	5	40
103504	2020-07-25 19:52:38	2020-07-25	8	[{"id_menu":5,"count":1}]	25220	delivery	5	13
103505	2020-07-25 20:02:58	2020-07-25	14	[{"id_menu":2,"count":1}]	39760	pick-up	0	14
103506	2020-07-25 20:03:22	2020-07-25	9	[{"id_menu":6,"count":1}]	39819	delivery	5	14
103507	2020-07-25 20:03:57	2020-07-25	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	34431	delivery	5	29
103508	2020-07-25 20:05:45	2020-07-25	9	[{"id_menu":6,"count":1}]	39781	delivery	5	14
103509	2020-07-25 20:09:20	2020-07-25	8	[{"id_menu":5,"count":1}]	20970	pick-up	0	8
103510	2020-07-25 20:11:00	2020-07-25	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26343	delivery	5	49
103511	2020-07-25 20:11:07	2020-07-25	12	[{"id_menu":1,"count":1}]	11983	delivery	5	17
103512	2020-07-25 20:11:54	2020-07-25	9	[{"id_menu":6,"count":1}]	34058	delivery	5	14
103513	2020-07-25 20:14:31	2020-07-25	14	[{"id_menu":2,"count":1}]	1537	pick-up	0	14
103514	2020-07-25 20:14:33	2020-07-25	17	[{"id_menu":4,"count":1}]	11963	pick-up	0	17
103515	2020-07-25 20:16:45	2020-07-25	9	[{"id_menu":7,"count":1}]	37566	delivery	5	14
103516	2020-07-25 20:16:54	2020-07-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31260	delivery	5	23
103517	2020-07-25 20:18:05	2020-07-25	8	[{"id_menu":5,"count":1}]	17815	delivery	5	13
103518	2020-07-25 20:19:55	2020-07-25	17	[{"id_menu":4,"count":1}]	14465	delivery	5	22
103519	2020-07-25 20:20:24	2020-07-25	8	[{"id_menu":5,"count":1}]	33049	delivery	5	13
103520	2020-07-25 20:22:01	2020-07-25	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	12532	pick-up	0	35
103521	2020-07-25 20:23:32	2020-07-25	14	[{"id_menu":2,"count":1}]	39868	pick-up	0	14
103522	2020-07-25 20:27:14	2020-07-25	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24839	delivery	5	34
103523	2020-07-25 20:28:09	2020-07-25	9	[{"id_menu":7,"count":1}]	39899	delivery	5	14
103524	2020-07-25 20:29:17	2020-07-25	17	[{"id_menu":4,"count":1}]	3861	delivery	5	22
103525	2020-07-25 20:29:19	2020-07-25	9	[{"id_menu":6,"count":1}]	2050	pick-up	0	9
103526	2020-07-25 20:31:47	2020-07-25	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	38667	pick-up	0	17
103527	2020-07-25 20:33:33	2020-07-25	9	[{"id_menu":6,"count":1}]	26016	delivery	5	14
103528	2020-07-25 20:34:32	2020-07-25	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	23831	pick-up	0	21
103529	2020-07-25 20:35:12	2020-07-25	8	[{"id_menu":5,"count":1}]	38967	delivery	5	13
103530	2020-07-25 20:35:26	2020-07-25	14	[{"id_menu":2,"count":2}]	39880	pick-up	0	14
103531	2020-07-25 20:41:45	2020-07-25	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	38035	delivery	5	36
103532	2020-07-25 20:47:32	2020-07-25	17	[{"id_menu":4,"count":1}]	9304	pick-up	0	17
103533	2020-07-25 20:48:47	2020-07-25	12	[{"id_menu":3,"count":1}]	17582	pick-up	0	12
103534	2020-07-25 20:51:03	2020-07-25	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11464	delivery	5	43
103535	2020-07-25 20:56:41	2020-07-25	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5886	delivery	5	39
103536	2020-07-25 20:57:55	2020-07-25	17	[{"id_menu":4,"count":1}]	16186	pick-up	0	17
103537	2020-07-25 20:59:58	2020-07-25	9	[{"id_menu":6,"count":1}]	29527	delivery	5	14
103538	2020-07-25 21:00:18	2020-07-25	12	[{"id_menu":3,"count":1}]	2244	pick-up	0	12
103539	2020-07-25 21:00:45	2020-07-25	9	[{"id_menu":7,"count":1}]	13256	delivery	5	14
103540	2020-07-25 21:01:20	2020-07-25	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38680	delivery	5	37
103541	2020-07-25 21:02:59	2020-07-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	37253	delivery	5	28
103542	2020-07-25 21:04:38	2020-07-25	12	[{"id_menu":3,"count":1}]	28812	delivery	5	17
103543	2020-07-25 21:05:13	2020-07-25	9	[{"id_menu":7,"count":1}]	19802	delivery	5	14
103544	2020-07-25 21:06:15	2020-07-25	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39857	delivery	5	48
103545	2020-07-25 21:07:06	2020-07-25	9	[{"id_menu":7,"count":1}]	21741	delivery	5	14
103546	2020-07-25 21:07:47	2020-07-25	8	[{"id_menu":5,"count":1}]	27332	pick-up	0	8
103547	2020-07-25 21:08:56	2020-07-25	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	21152	delivery	5	31
103548	2020-07-25 21:09:37	2020-07-25	12	[{"id_menu":3,"count":1}]	38925	pick-up	0	12
103549	2020-07-25 21:13:17	2020-07-25	9	[{"id_menu":7,"count":1}]	27978	delivery	5	14
103550	2020-07-25 21:15:36	2020-07-25	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36310	delivery	5	35
103551	2020-07-25 21:15:57	2020-07-25	9	[{"id_menu":6,"count":1}]	9995	pick-up	0	9
103552	2020-07-25 21:16:06	2020-07-25	12	[{"id_menu":1,"count":1}]	12855	pick-up	0	12
103553	2020-07-25 21:18:43	2020-07-25	14	[{"id_menu":2,"count":1}]	25544	pick-up	0	14
103554	2020-07-25 21:19:26	2020-07-25	12	[{"id_menu":3,"count":1}]	31431	pick-up	0	12
103555	2020-07-25 21:19:37	2020-07-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	13012	delivery	5	31
103556	2020-07-25 21:20:56	2020-07-25	9	[{"id_menu":6,"count":1}]	2943	pick-up	0	9
103557	2020-07-25 21:22:50	2020-07-25	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	37512	delivery	5	56
103558	2020-07-25 21:23:42	2020-07-25	14	[{"id_menu":2,"count":1}]	32455	delivery	5	19
103559	2020-07-25 21:26:21	2020-07-25	9	[{"id_menu":7,"count":1}]	30100	pick-up	0	9
103560	2020-07-25 21:26:40	2020-07-25	14	[{"id_menu":2,"count":1}]	38473	pick-up	0	14
103561	2020-07-25 21:27:35	2020-07-25	8	[{"id_menu":5,"count":1}]	35096	delivery	5	13
103562	2020-07-25 21:31:41	2020-07-25	12	[{"id_menu":3,"count":1}]	34731	delivery	5	17
103563	2020-07-25 21:32:53	2020-07-25	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	35087	delivery	5	26
103564	2020-07-25 21:36:04	2020-07-25	8	[{"id_menu":5,"count":1}]	7049	delivery	5	13
103565	2020-07-25 21:36:34	2020-07-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16883	pick-up	0	26
103566	2020-07-25 21:38:17	2020-07-25	12	[{"id_menu":1,"count":1}]	39787	delivery	5	17
103567	2020-07-25 21:42:00	2020-07-25	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	17513	delivery	5	26
103568	2020-07-25 21:42:47	2020-07-25	8	[{"id_menu":5,"count":1}]	14662	pick-up	0	8
103569	2020-07-25 21:45:27	2020-07-25	14	[{"id_menu":2,"count":1}]	34140	pick-up	0	14
103570	2020-07-25 21:47:58	2020-07-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15449	pick-up	0	17
103571	2020-07-25 21:50:53	2020-07-25	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	39914	delivery	5	25
103572	2020-07-25 21:54:47	2020-07-25	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7924	delivery	5	43
103573	2020-07-25 21:56:49	2020-07-25	9	[{"id_menu":6,"count":1}]	6054	delivery	5	14
103574	2020-07-25 22:02:44	2020-07-25	14	[{"id_menu":2,"count":1}]	7595	delivery	5	19
103575	2020-07-25 22:03:20	2020-07-25	17	[{"id_menu":4,"count":1}]	126	pick-up	0	17
103576	2020-07-25 22:03:25	2020-07-25	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	39791	delivery	5	34
103577	2020-07-25 22:05:29	2020-07-25	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	16845	delivery	5	27
103578	2020-07-25 22:05:55	2020-07-25	9	[{"id_menu":7,"count":1}]	406	pick-up	0	9
103579	2020-07-25 22:07:03	2020-07-25	9	[{"id_menu":6,"count":1}]	15536	delivery	5	14
103580	2020-07-25 22:08:24	2020-07-25	17	[{"id_menu":4,"count":1}]	17784	delivery	5	22
103581	2020-07-25 22:12:58	2020-07-25	9	[{"id_menu":6,"count":1}]	2777	pick-up	0	9
103582	2020-07-25 22:15:02	2020-07-25	14	[{"id_menu":2,"count":1}]	9752	delivery	5	19
103583	2020-07-25 22:15:14	2020-07-25	9	[{"id_menu":7,"count":1}]	39761	delivery	5	14
103584	2020-07-25 22:17:21	2020-07-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	39911	delivery	5	28
103585	2020-07-25 22:23:02	2020-07-25	9	[{"id_menu":6,"count":1}]	16553	delivery	5	14
103586	2020-07-25 22:24:38	2020-07-25	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	39769	delivery	5	22
103587	2020-07-25 22:25:26	2020-07-25	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16177	delivery	5	31
103588	2020-07-25 22:25:26	2020-07-25	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	14475	delivery	5	25
103589	2020-07-25 22:25:27	2020-07-25	8	[{"id_menu":5,"count":1}]	22784	pick-up	0	8
103590	2020-07-25 22:28:26	2020-07-25	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	14373	delivery	5	29
103591	2020-07-25 22:31:29	2020-07-25	9	[{"id_menu":6,"count":1}]	28515	pick-up	0	9
103592	2020-07-25 22:32:17	2020-07-25	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39841	delivery	5	37
103593	2020-07-25 22:32:52	2020-07-25	9	[{"id_menu":6,"count":1}]	3626	delivery	5	14
103594	2020-07-25 22:34:44	2020-07-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	39187	delivery	5	31
103595	2020-07-25 22:34:44	2020-07-25	12	[{"id_menu":3,"count":1}]	15386	delivery	5	17
103596	2020-07-25 22:39:50	2020-07-25	9	[{"id_menu":7,"count":1}]	3006	delivery	5	14
103597	2020-07-25 22:39:56	2020-07-25	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	21134	delivery	5	40
103598	2020-07-25 22:41:23	2020-07-25	9	[{"id_menu":7,"count":1}]	39902	delivery	5	14
103599	2020-07-25 22:43:27	2020-07-25	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1373	pick-up	0	47
103600	2020-07-25 22:47:04	2020-07-25	17	[{"id_menu":4,"count":1}]	36045	delivery	5	22
103601	2020-07-25 22:50:17	2020-07-25	14	[{"id_menu":2,"count":1}]	5461	delivery	5	19
103602	2020-07-25 22:51:40	2020-07-25	17	[{"id_menu":4,"count":1}]	34508	delivery	5	22
103603	2020-07-25 22:52:12	2020-07-25	17	[{"id_menu":4,"count":1}]	6137	pick-up	0	17
103604	2020-07-25 22:52:31	2020-07-25	9	[{"id_menu":6,"count":1}]	39790	delivery	5	14
103605	2020-07-25 22:53:51	2020-07-25	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	32603	delivery	5	31
103606	2020-07-25 22:54:22	2020-07-25	17	[{"id_menu":4,"count":1}]	39763	delivery	5	22
103607	2020-07-25 22:58:01	2020-07-25	9	[{"id_menu":7,"count":1}]	26928	delivery	5	14
103608	2020-07-25 23:02:02	2020-07-25	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1003	pick-up	0	20
103609	2020-07-25 23:09:51	2020-07-25	9	[{"id_menu":6,"count":1}]	14884	pick-up	0	9
103610	2020-07-25 23:09:51	2020-07-25	14	[{"id_menu":2,"count":1}]	68	delivery	5	19
103611	2020-07-25 23:11:57	2020-07-25	14	[{"id_menu":2,"count":1}]	1700	pick-up	0	14
103612	2020-07-25 23:15:09	2020-07-25	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	39877	delivery	5	48
103613	2020-07-25 23:15:29	2020-07-25	17	[{"id_menu":4,"count":1}]	13741	delivery	5	22
103614	2020-07-25 23:19:30	2020-07-25	9	[{"id_menu":6,"count":1}]	32687	delivery	5	14
103615	2020-07-25 23:20:43	2020-07-25	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	39765	delivery	5	22
103616	2020-07-25 23:23:20	2020-07-25	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2398	pick-up	0	29
103617	2020-07-25 23:24:04	2020-07-25	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	6396	pick-up	0	26
103618	2020-07-25 23:25:47	2020-07-25	9	[{"id_menu":6,"count":1}]	3636	pick-up	0	9
103619	2020-07-25 23:26:17	2020-07-25	17	[{"id_menu":4,"count":1}]	15976	pick-up	0	17
103620	2020-07-25 23:26:22	2020-07-25	12	[{"id_menu":3,"count":1}]	1162	pick-up	0	12
103621	2020-07-25 23:28:30	2020-07-25	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27838	delivery	5	34
103622	2020-07-25 23:28:46	2020-07-25	14	[{"id_menu":2,"count":1}]	39736	delivery	5	19
103623	2020-07-25 23:29:39	2020-07-25	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	13858	pick-up	0	21
103624	2020-07-25 23:33:07	2020-07-25	8	[{"id_menu":5,"count":2}]	39805	delivery	5	13
103625	2020-07-25 23:33:36	2020-07-25	9	[{"id_menu":6,"count":1}]	38042	delivery	5	14
103626	2020-07-25 23:34:18	2020-07-25	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	39864	pick-up	0	29
103627	2020-07-25 23:36:00	2020-07-25	14	[{"id_menu":2,"count":1}]	38271	pick-up	0	14
103628	2020-07-25 23:36:23	2020-07-25	14	[{"id_menu":2,"count":1}]	36794	delivery	5	19
103629	2020-07-25 23:38:41	2020-07-25	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	8726	delivery	5	27
103630	2020-07-25 23:40:08	2020-07-25	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	23797	pick-up	0	23
103631	2020-07-25 23:40:34	2020-07-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10706	pick-up	0	26
103632	2020-07-25 23:43:18	2020-07-25	9	[{"id_menu":7,"count":1}]	12792	delivery	5	14
103633	2020-07-25 23:46:05	2020-07-25	14	[{"id_menu":2,"count":1}]	16679	delivery	5	19
103634	2020-07-25 23:46:39	2020-07-25	8	[{"id_menu":5,"count":1}]	11798	delivery	5	13
103635	2020-07-25 23:47:55	2020-07-25	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	9312	delivery	5	35
103636	2020-07-25 23:49:03	2020-07-25	9	[{"id_menu":7,"count":1}]	7870	delivery	5	14
103637	2020-07-25 23:52:22	2020-07-25	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	39909	delivery	5	31
103638	2020-07-25 23:53:58	2020-07-25	9	[{"id_menu":6,"count":1}]	39871	delivery	5	14
103639	2020-07-25 23:54:14	2020-07-25	17	[{"id_menu":4,"count":1}]	325	pick-up	0	17
103640	2020-07-25 23:56:15	2020-07-25	9	[{"id_menu":6,"count":1}]	39783	delivery	5	14
103641	2020-07-25 23:57:44	2020-07-25	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6174	delivery	5	30
103642	2020-07-26 00:01:16	2020-07-26	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	9672	delivery	5	52
103643	2020-07-26 00:01:21	2020-07-26	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	40124	delivery	5	26
103644	2020-07-26 00:01:45	2020-07-26	12	[{"id_menu":3,"count":1}]	17435	delivery	5	17
103645	2020-07-26 00:03:28	2020-07-26	14	[{"id_menu":2,"count":1}]	13706	pick-up	0	14
103646	2020-07-26 00:04:33	2020-07-26	9	[{"id_menu":6,"count":1}]	34428	delivery	5	14
103647	2020-07-26 00:05:10	2020-07-26	12	[{"id_menu":3,"count":1}]	18176	pick-up	0	12
103648	2020-07-26 00:05:46	2020-07-26	8	[{"id_menu":5,"count":1}]	1800	pick-up	0	8
103649	2020-07-26 00:05:57	2020-07-26	9	[{"id_menu":7,"count":1}]	40133	delivery	5	14
103650	2020-07-26 00:07:42	2020-07-26	9	[{"id_menu":7,"count":1}]	28385	delivery	5	14
103651	2020-07-26 00:07:51	2020-07-26	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	40167	delivery	5	30
103652	2020-07-26 00:10:43	2020-07-26	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	8612	delivery	5	38
103653	2020-07-26 00:11:06	2020-07-26	9	[{"id_menu":7,"count":1}]	40111	delivery	5	14
103654	2020-07-26 00:12:16	2020-07-26	17	[{"id_menu":4,"count":1}]	7806	pick-up	0	17
103655	2020-07-26 00:12:58	2020-07-26	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	8059	delivery	5	34
103656	2020-07-26 00:14:28	2020-07-26	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14207	delivery	5	36
103657	2020-07-26 00:15:06	2020-07-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	39982	delivery	5	26
103658	2020-07-26 00:15:41	2020-07-26	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	17091	delivery	5	29
103659	2020-07-26 00:16:50	2020-07-26	17	[{"id_menu":4,"count":1}]	8355	delivery	5	22
103660	2020-07-26 00:18:03	2020-07-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	20957	delivery	5	26
103661	2020-07-26 00:18:06	2020-07-26	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	13697	delivery	5	26
103662	2020-07-26 00:19:18	2020-07-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1239	pick-up	0	23
103663	2020-07-26 00:19:48	2020-07-26	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	28486	pick-up	0	26
103664	2020-07-26 00:21:36	2020-07-26	14	[{"id_menu":2,"count":1}]	38825	delivery	5	19
103665	2020-07-26 00:21:37	2020-07-26	17	[{"id_menu":4,"count":2}]	21334	pick-up	0	17
103666	2020-07-26 00:24:53	2020-07-26	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	23562	delivery	5	39
103667	2020-07-26 00:25:57	2020-07-26	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	3870	pick-up	0	20
103668	2020-07-26 00:26:15	2020-07-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	40205	delivery	5	28
103669	2020-07-26 00:28:16	2020-07-26	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	40063	delivery	5	25
103670	2020-07-26 00:28:42	2020-07-26	14	[{"id_menu":2,"count":1}]	4800	pick-up	0	14
103671	2020-07-26 00:28:59	2020-07-26	12	[{"id_menu":1,"count":1}]	28631	delivery	5	17
103672	2020-07-26 00:29:57	2020-07-26	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	31971	delivery	5	36
103673	2020-07-26 00:30:43	2020-07-26	14	[{"id_menu":2,"count":1}]	4513	delivery	5	19
103674	2020-07-26 00:35:24	2020-07-26	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	39961	delivery	5	36
103675	2020-07-26 00:37:13	2020-07-26	12	[{"id_menu":1,"count":1}]	40143	delivery	5	17
103676	2020-07-26 00:37:41	2020-07-26	12	[{"id_menu":3,"count":1}]	18755	pick-up	0	12
103677	2020-07-26 00:38:19	2020-07-26	12	[{"id_menu":1,"count":1}]	27968	delivery	5	17
103678	2020-07-26 00:42:49	2020-07-26	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	40158	delivery	5	48
103679	2020-07-26 00:45:09	2020-07-26	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	15040	pick-up	0	35
103680	2020-07-26 00:45:14	2020-07-26	9	[{"id_menu":6,"count":1}]	15275	delivery	5	14
103681	2020-07-26 00:46:40	2020-07-26	9	[{"id_menu":6,"count":1}]	28728	delivery	5	14
103682	2020-07-26 00:46:42	2020-07-26	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7571	delivery	5	31
103683	2020-07-26 00:46:47	2020-07-26	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39926	delivery	5	46
103684	2020-07-26 00:48:16	2020-07-26	9	[{"id_menu":7,"count":1}]	40126	delivery	5	14
103685	2020-07-26 00:49:38	2020-07-26	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	35877	delivery	5	26
103686	2020-07-26 00:51:17	2020-07-26	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3031	pick-up	0	26
103687	2020-07-26 00:53:11	2020-07-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34492	delivery	5	23
103688	2020-07-26 00:55:37	2020-07-26	8	[{"id_menu":5,"count":1}]	39492	delivery	5	13
103689	2020-07-26 00:56:39	2020-07-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4882	delivery	5	22
103690	2020-07-26 00:56:51	2020-07-26	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	22530	delivery	5	36
103691	2020-07-26 00:57:15	2020-07-26	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	16632	pick-up	0	20
103692	2020-07-26 00:58:30	2020-07-26	12	[{"id_menu":1,"count":1}]	1490	delivery	5	17
103693	2020-07-26 00:58:36	2020-07-26	14	[{"id_menu":2,"count":1}]	477	delivery	5	19
103694	2020-07-26 00:58:54	2020-07-26	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	31628	pick-up	0	25
103695	2020-07-26 01:05:00	2020-07-26	14	[{"id_menu":2,"count":1}]	226	pick-up	0	14
103696	2020-07-26 01:05:52	2020-07-26	9	[{"id_menu":6,"count":1}]	25814	delivery	5	14
103697	2020-07-26 01:08:14	2020-07-26	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	31013	delivery	5	22
103698	2020-07-26 01:10:14	2020-07-26	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40152	delivery	5	31
103699	2020-07-26 01:10:45	2020-07-26	8	[{"id_menu":5,"count":1}]	35701	delivery	5	13
103700	2020-07-26 01:12:32	2020-07-26	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40019	delivery	5	54
103701	2020-07-26 01:15:28	2020-07-26	14	[{"id_menu":2,"count":1}]	19803	pick-up	0	14
103702	2020-07-26 01:16:04	2020-07-26	17	[{"id_menu":4,"count":1}]	2130	delivery	5	22
103703	2020-07-26 01:16:27	2020-07-26	14	[{"id_menu":2,"count":1}]	4536	delivery	5	19
103704	2020-07-26 01:17:51	2020-07-26	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	40087	delivery	5	25
103705	2020-07-26 01:20:54	2020-07-26	12	[{"id_menu":1,"count":1}]	5913	pick-up	0	12
103706	2020-07-26 01:21:39	2020-07-26	12	[{"id_menu":1,"count":1}]	39935	delivery	5	17
103707	2020-07-26 01:21:58	2020-07-26	9	[{"id_menu":7,"count":1}]	39959	delivery	5	14
103708	2020-07-26 01:24:01	2020-07-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	19617	delivery	5	22
103709	2020-07-26 01:25:14	2020-07-26	8	[{"id_menu":5,"count":1}]	11401	pick-up	0	8
103710	2020-07-26 01:27:13	2020-07-26	17	[{"id_menu":4,"count":1}]	13676	delivery	5	22
103711	2020-07-26 01:33:42	2020-07-26	17	[{"id_menu":4,"count":2}]	40136	delivery	5	22
103712	2020-07-26 01:34:20	2020-07-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14008	pick-up	0	18
103713	2020-07-26 01:36:53	2020-07-26	8	[{"id_menu":5,"count":1}]	13836	delivery	5	13
103714	2020-07-26 01:37:49	2020-07-26	17	[{"id_menu":4,"count":1}]	40198	delivery	5	22
103715	2020-07-26 01:39:43	2020-07-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11402	delivery	5	22
103716	2020-07-26 01:40:39	2020-07-26	8	[{"id_menu":5,"count":1}]	36611	delivery	5	13
103717	2020-07-26 01:41:02	2020-07-26	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	40172	delivery	5	31
103718	2020-07-26 01:41:53	2020-07-26	12	[{"id_menu":1,"count":1}]	40194	delivery	5	17
103719	2020-07-26 01:43:57	2020-07-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16779	delivery	5	22
103720	2020-07-26 01:44:24	2020-07-26	8	[{"id_menu":5,"count":1}]	6434	delivery	5	13
103721	2020-07-26 01:44:26	2020-07-26	12	[{"id_menu":3,"count":1}]	35471	pick-up	0	12
103722	2020-07-26 01:44:30	2020-07-26	12	[{"id_menu":3,"count":1}]	34930	pick-up	0	12
103723	2020-07-26 01:45:33	2020-07-26	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	6342	pick-up	0	29
103724	2020-07-26 01:46:10	2020-07-26	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	11897	pick-up	0	26
103725	2020-07-26 01:46:59	2020-07-26	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3347	delivery	5	30
103726	2020-07-26 01:47:45	2020-07-26	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	538	delivery	5	39
103727	2020-07-26 01:47:59	2020-07-26	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	5584	delivery	5	42
103728	2020-07-26 01:54:10	2020-07-26	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	27461	delivery	5	40
103729	2020-07-26 01:54:58	2020-07-26	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	39922	delivery	5	44
103730	2020-07-26 01:55:59	2020-07-26	14	[{"id_menu":2,"count":1}]	40114	delivery	5	19
103731	2020-07-26 01:56:17	2020-07-26	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	40073	delivery	5	26
103732	2020-07-26 01:57:34	2020-07-26	12	[{"id_menu":3,"count":1}]	16578	delivery	5	17
103733	2020-07-26 01:57:38	2020-07-26	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	40138	delivery	5	27
103734	2020-07-26 02:00:02	2020-07-26	8	[{"id_menu":5,"count":1}]	18683	delivery	5	13
103735	2020-07-26 02:00:28	2020-07-26	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	28112	delivery	5	31
103736	2020-07-26 02:00:45	2020-07-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	19300	pick-up	0	21
103737	2020-07-26 02:00:50	2020-07-26	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	39740	pick-up	0	26
103738	2020-07-26 02:02:25	2020-07-26	9	[{"id_menu":7,"count":1}]	33589	delivery	5	14
103739	2020-07-26 02:03:39	2020-07-26	8	[{"id_menu":5,"count":1}]	40137	delivery	5	13
103740	2020-07-26 02:04:30	2020-07-26	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	39966	delivery	5	34
103741	2020-07-26 02:05:17	2020-07-26	9	[{"id_menu":6,"count":1}]	1523	pick-up	0	9
103742	2020-07-26 02:06:52	2020-07-26	17	[{"id_menu":4,"count":1}]	11572	delivery	5	22
103743	2020-07-26 02:07:01	2020-07-26	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	26127	pick-up	0	21
103744	2020-07-26 02:07:44	2020-07-26	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	7912	delivery	5	31
103745	2020-07-26 02:07:59	2020-07-26	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	9053	pick-up	0	32
103746	2020-07-26 02:10:52	2020-07-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	37688	delivery	5	28
103747	2020-07-26 02:13:26	2020-07-26	12	[{"id_menu":3,"count":2}]	35777	delivery	5	17
103748	2020-07-26 02:14:54	2020-07-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40093	delivery	5	23
103749	2020-07-26 02:15:23	2020-07-26	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	40085	pick-up	0	31
103750	2020-07-26 02:16:35	2020-07-26	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31581	pick-up	0	32
103751	2020-07-26 02:19:19	2020-07-26	14	[{"id_menu":2,"count":2}]	40109	pick-up	0	14
103752	2020-07-26 02:22:38	2020-07-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40108	delivery	5	23
103753	2020-07-26 02:22:59	2020-07-26	14	[{"id_menu":2,"count":1}]	16891	pick-up	0	14
103754	2020-07-26 02:24:45	2020-07-26	17	[{"id_menu":4,"count":1}]	15818	pick-up	0	17
103755	2020-07-26 02:24:49	2020-07-26	14	[{"id_menu":2,"count":1}]	40207	delivery	5	19
103756	2020-07-26 02:25:11	2020-07-26	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":2}]	40135	delivery	5	22
103757	2020-07-26 02:27:14	2020-07-26	14	[{"id_menu":2,"count":2}]	10500	delivery	5	19
103758	2020-07-26 02:28:30	2020-07-26	14	[{"id_menu":2,"count":1}]	10978	pick-up	0	14
103759	2020-07-26 02:28:56	2020-07-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	40127	delivery	5	22
103760	2020-07-26 02:31:54	2020-07-26	14	[{"id_menu":2,"count":1}]	31933	pick-up	0	14
103761	2020-07-26 02:32:24	2020-07-26	14	[{"id_menu":2,"count":1}]	37033	delivery	5	19
103762	2020-07-26 02:33:16	2020-07-26	9	[{"id_menu":6,"count":1}]	1453	pick-up	0	9
103763	2020-07-26 02:33:54	2020-07-26	9	[{"id_menu":6,"count":1}]	26248	delivery	5	14
103764	2020-07-26 02:35:39	2020-07-26	14	[{"id_menu":2,"count":1}]	10732	delivery	5	19
103765	2020-07-26 02:35:42	2020-07-26	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	10802	delivery	5	39
103766	2020-07-26 02:35:51	2020-07-26	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	27988	delivery	5	57
103767	2020-07-26 02:35:55	2020-07-26	49	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	39800	delivery	5	54
103768	2020-07-26 02:38:16	2020-07-26	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	40125	delivery	5	31
103769	2020-07-26 02:39:23	2020-07-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15750	delivery	5	22
103770	2020-07-26 02:39:51	2020-07-26	12	[{"id_menu":3,"count":2}]	5945	pick-up	0	12
103771	2020-07-26 02:40:00	2020-07-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4287	delivery	5	22
103772	2020-07-26 02:40:12	2020-07-26	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1924	pick-up	0	51
103773	2020-07-26 02:40:39	2020-07-26	9	[{"id_menu":7,"count":1}]	22339	delivery	5	14
103774	2020-07-26 02:40:51	2020-07-26	43	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	36302	delivery	5	48
103775	2020-07-26 02:41:01	2020-07-26	9	[{"id_menu":6,"count":1}]	5890	pick-up	0	9
103776	2020-07-26 02:42:23	2020-07-26	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	40195	delivery	5	23
103777	2020-07-26 02:42:58	2020-07-26	8	[{"id_menu":5,"count":1}]	40040	pick-up	0	8
103778	2020-07-26 02:43:18	2020-07-26	8	[{"id_menu":5,"count":1}]	22672	delivery	5	13
103779	2020-07-26 02:43:31	2020-07-26	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	3284	delivery	5	31
103780	2020-07-26 02:44:51	2020-07-26	17	[{"id_menu":4,"count":1}]	30533	delivery	5	22
103781	2020-07-26 02:47:44	2020-07-26	9	[{"id_menu":6,"count":1}]	5354	pick-up	0	9
103782	2020-07-26 02:48:04	2020-07-26	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3381	delivery	5	45
103783	2020-07-26 02:50:41	2020-07-26	9	[{"id_menu":6,"count":1}]	26402	delivery	5	14
103784	2020-07-26 02:54:24	2020-07-26	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37288	delivery	5	45
103785	2020-07-26 02:56:11	2020-07-26	14	[{"id_menu":2,"count":1}]	20540	delivery	5	19
103786	2020-07-26 02:56:50	2020-07-26	17	[{"id_menu":4,"count":1}]	24353	delivery	5	22
103787	2020-07-26 02:57:21	2020-07-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	40077	delivery	5	26
103788	2020-07-26 02:59:42	2020-07-26	17	[{"id_menu":4,"count":1}]	28083	pick-up	0	17
103789	2020-07-26 03:07:11	2020-07-26	12	[{"id_menu":3,"count":1}]	16592	delivery	5	17
103790	2020-07-26 03:07:37	2020-07-26	12	[{"id_menu":3,"count":1}]	39930	delivery	5	17
103791	2020-07-26 03:08:23	2020-07-26	12	[{"id_menu":1,"count":1}]	13400	pick-up	0	12
103792	2020-07-26 03:09:20	2020-07-26	9	[{"id_menu":6,"count":1}]	3531	delivery	5	14
103793	2020-07-26 03:09:34	2020-07-26	8	[{"id_menu":5,"count":1}]	40160	delivery	5	13
103794	2020-07-26 03:10:50	2020-07-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	33683	delivery	5	22
103795	2020-07-26 03:11:10	2020-07-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	40170	delivery	5	28
103796	2020-07-26 03:11:52	2020-07-26	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	31824	delivery	5	40
103797	2020-07-26 03:12:39	2020-07-26	14	[{"id_menu":2,"count":1}]	39577	delivery	5	19
103798	2020-07-26 03:17:38	2020-07-26	46	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	3211	delivery	5	51
103799	2020-07-26 03:17:39	2020-07-26	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	32899	delivery	5	31
103800	2020-07-26 03:19:31	2020-07-26	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	30256	pick-up	0	38
103801	2020-07-26 03:20:30	2020-07-26	14	[{"id_menu":2,"count":1}]	378	pick-up	0	14
103802	2020-07-26 03:20:52	2020-07-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34676	delivery	5	23
103803	2020-07-26 03:20:53	2020-07-26	9	[{"id_menu":6,"count":1}]	3372	pick-up	0	9
103804	2020-07-26 03:22:31	2020-07-26	9	[{"id_menu":6,"count":1}]	25246	delivery	5	14
103805	2020-07-26 03:23:00	2020-07-26	17	[{"id_menu":4,"count":1}]	14127	pick-up	0	17
103806	2020-07-26 03:23:11	2020-07-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	33333	delivery	5	31
103807	2020-07-26 03:24:03	2020-07-26	17	[{"id_menu":4,"count":1}]	35079	delivery	5	22
103808	2020-07-26 03:26:18	2020-07-26	17	[{"id_menu":4,"count":1}]	1196	pick-up	0	17
103809	2020-07-26 03:27:53	2020-07-26	14	[{"id_menu":2,"count":1}]	2810	pick-up	0	14
103810	2020-07-26 03:29:48	2020-07-26	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	11859	pick-up	0	21
103811	2020-07-26 03:30:05	2020-07-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	39986	delivery	5	23
103812	2020-07-26 03:30:52	2020-07-26	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40080	delivery	5	47
103813	2020-07-26 03:31:43	2020-07-26	14	[{"id_menu":2,"count":1}]	4485	delivery	5	19
103814	2020-07-26 03:33:07	2020-07-26	14	[{"id_menu":2,"count":2}]	10447	delivery	5	19
103815	2020-07-26 03:34:06	2020-07-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	31454	delivery	5	31
103816	2020-07-26 03:34:48	2020-07-26	12	[{"id_menu":1,"count":1}]	12095	pick-up	0	12
103817	2020-07-26 03:35:08	2020-07-26	8	[{"id_menu":5,"count":1}]	22740	delivery	5	13
103818	2020-07-26 03:35:56	2020-07-26	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9515	delivery	5	35
103819	2020-07-26 03:37:04	2020-07-26	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	39952	delivery	5	36
103820	2020-07-26 03:38:19	2020-07-26	9	[{"id_menu":7,"count":1}]	15216	delivery	5	14
103821	2020-07-26 03:38:44	2020-07-26	8	[{"id_menu":5,"count":1}]	40123	delivery	5	13
103822	2020-07-26 03:43:13	2020-07-26	9	[{"id_menu":6,"count":1}]	31519	delivery	5	14
103823	2020-07-26 03:44:23	2020-07-26	14	[{"id_menu":2,"count":1}]	29194	delivery	5	19
103824	2020-07-26 03:44:34	2020-07-26	14	[{"id_menu":2,"count":1}]	40100	delivery	5	19
103825	2020-07-26 03:45:00	2020-07-26	14	[{"id_menu":2,"count":1}]	3858	delivery	5	19
103826	2020-07-26 03:45:38	2020-07-26	9	[{"id_menu":6,"count":1}]	40057	pick-up	0	9
103827	2020-07-26 03:46:11	2020-07-26	8	[{"id_menu":5,"count":1}]	40016	delivery	5	13
103828	2020-07-26 03:48:09	2020-07-26	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	39931	delivery	5	40
103829	2020-07-26 03:48:45	2020-07-26	14	[{"id_menu":2,"count":1}]	29678	pick-up	0	14
103830	2020-07-26 03:48:58	2020-07-26	12	[{"id_menu":3,"count":1}]	35986	pick-up	0	12
103831	2020-07-26 03:49:42	2020-07-26	9	[{"id_menu":6,"count":1}]	27337	delivery	5	14
103832	2020-07-26 03:50:40	2020-07-26	12	[{"id_menu":3,"count":1}]	9043	pick-up	0	12
103833	2020-07-26 03:53:47	2020-07-26	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	35581	delivery	5	34
103834	2020-07-26 03:56:08	2020-07-26	8	[{"id_menu":5,"count":1}]	22311	delivery	5	13
103835	2020-07-26 04:00:02	2020-07-26	12	[{"id_menu":1,"count":1}]	21414	delivery	5	17
103836	2020-07-26 04:00:17	2020-07-26	12	[{"id_menu":1,"count":1}]	40088	delivery	5	17
103837	2020-07-26 04:01:43	2020-07-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14025	pick-up	0	17
103838	2020-07-26 04:05:22	2020-07-26	9	[{"id_menu":6,"count":1}]	40050	delivery	5	14
103839	2020-07-26 04:08:19	2020-07-26	9	[{"id_menu":7,"count":1}]	38813	delivery	5	14
103840	2020-07-26 04:09:14	2020-07-26	9	[{"id_menu":7,"count":1}]	11004	delivery	5	14
103841	2020-07-26 04:10:29	2020-07-26	14	[{"id_menu":2,"count":1}]	8529	pick-up	0	14
103842	2020-07-26 04:10:35	2020-07-26	9	[{"id_menu":7,"count":1}]	19285	delivery	5	14
103843	2020-07-26 04:11:10	2020-07-26	9	[{"id_menu":7,"count":2}]	39918	delivery	5	14
103844	2020-07-26 04:14:46	2020-07-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	40154	delivery	5	26
103845	2020-07-26 04:16:42	2020-07-26	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	35365	delivery	5	34
103846	2020-07-26 04:17:36	2020-07-26	14	[{"id_menu":2,"count":1}]	24322	delivery	5	19
103847	2020-07-26 04:17:38	2020-07-26	9	[{"id_menu":6,"count":1}]	40147	delivery	5	14
103848	2020-07-26 04:18:08	2020-07-26	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	24510	delivery	5	28
103849	2020-07-26 04:18:27	2020-07-26	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	40090	delivery	5	36
103850	2020-07-26 04:19:49	2020-07-26	9	[{"id_menu":6,"count":1}]	38004	delivery	5	14
103851	2020-07-26 04:20:25	2020-07-26	14	[{"id_menu":2,"count":1}]	33468	delivery	5	19
103852	2020-07-26 04:22:26	2020-07-26	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	31738	pick-up	0	50
103853	2020-07-26 04:23:35	2020-07-26	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	31115	delivery	5	48
103854	2020-07-26 04:25:37	2020-07-26	12	[{"id_menu":1,"count":1}]	34454	delivery	5	17
103855	2020-07-26 04:30:42	2020-07-26	12	[{"id_menu":3,"count":1}]	16794	delivery	5	17
103856	2020-07-26 04:31:54	2020-07-26	9	[{"id_menu":6,"count":1}]	39921	delivery	5	14
103857	2020-07-26 04:32:20	2020-07-26	8	[{"id_menu":5,"count":1}]	40187	delivery	5	13
103858	2020-07-26 04:34:11	2020-07-26	8	[{"id_menu":5,"count":1}]	40211	pick-up	0	8
103859	2020-07-26 04:37:58	2020-07-26	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	18947	delivery	5	26
103860	2020-07-26 04:38:40	2020-07-26	9	[{"id_menu":6,"count":1}]	40212	pick-up	0	9
103861	2020-07-26 04:40:03	2020-07-26	9	[{"id_menu":6,"count":1}]	39933	delivery	5	14
103862	2020-07-26 04:47:21	2020-07-26	9	[{"id_menu":7,"count":1}]	21265	delivery	5	14
103863	2020-07-26 04:47:31	2020-07-26	9	[{"id_menu":7,"count":1}]	28553	delivery	5	14
103864	2020-07-26 04:48:21	2020-07-26	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11023	pick-up	0	29
103865	2020-07-26 04:49:49	2020-07-26	17	[{"id_menu":4,"count":1}]	11681	delivery	5	22
103866	2020-07-26 04:51:39	2020-07-26	9	[{"id_menu":7,"count":1}]	40106	delivery	5	14
103867	2020-07-26 04:54:25	2020-07-26	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40199	delivery	5	48
103868	2020-07-26 04:59:08	2020-07-26	9	[{"id_menu":6,"count":1}]	15752	delivery	5	14
103869	2020-07-26 04:59:10	2020-07-26	17	[{"id_menu":4,"count":1}]	1169	pick-up	0	17
103870	2020-07-26 05:00:41	2020-07-26	12	[{"id_menu":1,"count":1}]	3030	delivery	5	17
103871	2020-07-26 05:04:38	2020-07-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13491	delivery	5	22
103872	2020-07-26 05:06:42	2020-07-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	35343	delivery	5	22
103873	2020-07-26 05:09:02	2020-07-26	12	[{"id_menu":3,"count":1}]	19091	pick-up	0	12
103874	2020-07-26 05:10:14	2020-07-26	14	[{"id_menu":2,"count":1}]	16496	delivery	5	19
103875	2020-07-26 05:10:47	2020-07-26	12	[{"id_menu":1,"count":1}]	39992	delivery	5	17
103876	2020-07-26 05:10:49	2020-07-26	9	[{"id_menu":7,"count":1}]	30410	pick-up	0	9
103877	2020-07-26 05:10:57	2020-07-26	17	[{"id_menu":4,"count":1}]	29597	delivery	5	22
103878	2020-07-26 05:13:58	2020-07-26	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	40032	delivery	5	40
103879	2020-07-26 05:17:43	2020-07-26	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	16920	delivery	5	30
103880	2020-07-26 05:19:38	2020-07-26	17	[{"id_menu":4,"count":1}]	40102	pick-up	0	17
103881	2020-07-26 05:19:58	2020-07-26	12	[{"id_menu":3,"count":1}]	24597	pick-up	0	12
103882	2020-07-26 05:21:29	2020-07-26	14	[{"id_menu":2,"count":1}]	39940	delivery	5	19
103883	2020-07-26 05:22:24	2020-07-26	9	[{"id_menu":7,"count":1}]	27957	delivery	5	14
103884	2020-07-26 05:23:50	2020-07-26	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	19726	delivery	5	34
103885	2020-07-26 05:28:40	2020-07-26	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	32133	delivery	5	31
103886	2020-07-26 05:30:27	2020-07-26	9	[{"id_menu":6,"count":1}]	29490	delivery	5	14
103887	2020-07-26 05:30:36	2020-07-26	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	40010	delivery	5	37
103888	2020-07-26 05:33:25	2020-07-26	9	[{"id_menu":6,"count":1}]	39972	delivery	5	14
103889	2020-07-26 05:34:15	2020-07-26	12	[{"id_menu":1,"count":1}]	40021	delivery	5	17
103890	2020-07-26 05:36:54	2020-07-26	14	[{"id_menu":2,"count":1}]	40117	delivery	5	19
103891	2020-07-26 05:38:00	2020-07-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	12611	delivery	5	28
103892	2020-07-26 05:40:35	2020-07-26	12	[{"id_menu":1,"count":1}]	15021	delivery	5	17
103893	2020-07-26 05:40:47	2020-07-26	12	[{"id_menu":1,"count":1}]	19798	pick-up	0	12
103894	2020-07-26 05:47:34	2020-07-26	12	[{"id_menu":1,"count":1}]	27790	delivery	5	17
103895	2020-07-26 05:47:39	2020-07-26	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	39997	delivery	5	40
103896	2020-07-26 05:47:44	2020-07-26	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1258	pick-up	0	40
103897	2020-07-26 05:48:14	2020-07-26	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	40067	delivery	5	43
103898	2020-07-26 05:49:41	2020-07-26	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	40153	delivery	5	29
103899	2020-07-26 05:49:49	2020-07-26	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2713	pick-up	0	26
103900	2020-07-26 05:52:07	2020-07-26	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2855	delivery	5	36
103901	2020-07-26 05:54:17	2020-07-26	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	35199	delivery	5	35
103902	2020-07-26 05:55:31	2020-07-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	24037	delivery	5	22
103903	2020-07-26 05:56:25	2020-07-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	32584	pick-up	0	23
103904	2020-07-26 05:57:04	2020-07-26	17	[{"id_menu":4,"count":1}]	39560	delivery	5	22
103905	2020-07-26 05:57:21	2020-07-26	8	[{"id_menu":5,"count":1}]	2715	pick-up	0	8
103906	2020-07-26 05:59:07	2020-07-26	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	31095	delivery	5	37
103907	2020-07-26 06:01:41	2020-07-26	14	[{"id_menu":2,"count":1}]	39938	delivery	5	19
103908	2020-07-26 06:01:48	2020-07-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2227	pick-up	0	21
103909	2020-07-26 06:03:17	2020-07-26	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	39927	delivery	5	25
103910	2020-07-26 06:04:55	2020-07-26	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	40103	delivery	5	31
103911	2020-07-26 06:08:05	2020-07-26	8	[{"id_menu":5,"count":1}]	1485	delivery	5	13
103912	2020-07-26 06:09:17	2020-07-26	8	[{"id_menu":5,"count":1}]	21386	delivery	5	13
103913	2020-07-26 06:12:11	2020-07-26	9	[{"id_menu":7,"count":1}]	32725	pick-up	0	9
103914	2020-07-26 06:16:12	2020-07-26	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	7964	delivery	5	27
103915	2020-07-26 06:18:40	2020-07-26	14	[{"id_menu":2,"count":2}]	12565	delivery	5	19
103916	2020-07-26 06:19:14	2020-07-26	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1780	pick-up	0	21
103917	2020-07-26 06:20:37	2020-07-26	12	[{"id_menu":3,"count":2}]	7595	delivery	5	17
103918	2020-07-26 06:20:39	2020-07-26	12	[{"id_menu":1,"count":1}]	40058	delivery	5	17
103919	2020-07-26 06:21:55	2020-07-26	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20383	delivery	5	35
103920	2020-07-26 06:26:41	2020-07-26	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8956	delivery	5	55
103921	2020-07-26 06:27:04	2020-07-26	17	[{"id_menu":4,"count":1}]	2498	pick-up	0	17
103922	2020-07-26 06:27:25	2020-07-26	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	40042	delivery	5	51
103923	2020-07-26 06:27:43	2020-07-26	12	[{"id_menu":1,"count":2}]	24828	delivery	5	17
103924	2020-07-26 06:27:48	2020-07-26	8	[{"id_menu":5,"count":1}]	3174	pick-up	0	8
103925	2020-07-26 06:27:52	2020-07-26	12	[{"id_menu":3,"count":1}]	3521	pick-up	0	12
103926	2020-07-26 06:28:55	2020-07-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	30022	delivery	5	31
103927	2020-07-26 06:28:56	2020-07-26	8	[{"id_menu":5,"count":1}]	16935	delivery	5	13
103928	2020-07-26 06:29:22	2020-07-26	9	[{"id_menu":7,"count":1}]	40149	delivery	5	14
103929	2020-07-26 06:31:01	2020-07-26	8	[{"id_menu":5,"count":1}]	4170	pick-up	0	8
103930	2020-07-26 06:34:55	2020-07-26	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	203	delivery	5	43
103931	2020-07-26 06:36:54	2020-07-26	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	14683	delivery	5	31
103932	2020-07-26 06:37:28	2020-07-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	37834	pick-up	0	23
103933	2020-07-26 06:39:06	2020-07-26	14	[{"id_menu":2,"count":1}]	39953	delivery	5	19
103934	2020-07-26 06:42:07	2020-07-26	8	[{"id_menu":5,"count":1}]	20784	delivery	5	13
103935	2020-07-26 06:43:24	2020-07-26	9	[{"id_menu":7,"count":1}]	34931	delivery	5	14
103936	2020-07-26 06:43:44	2020-07-26	9	[{"id_menu":7,"count":1}]	39989	pick-up	0	9
103937	2020-07-26 06:44:06	2020-07-26	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21071	delivery	5	40
103938	2020-07-26 06:52:19	2020-07-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	26459	delivery	5	31
103939	2020-07-26 06:59:33	2020-07-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32863	delivery	5	23
103940	2020-07-26 07:06:42	2020-07-26	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3032	pick-up	0	33
103941	2020-07-26 07:07:40	2020-07-26	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	22558	delivery	5	25
103942	2020-07-26 07:09:07	2020-07-26	9	[{"id_menu":7,"count":1}]	19931	delivery	5	14
103943	2020-07-26 07:09:09	2020-07-26	14	[{"id_menu":2,"count":1}]	39760	pick-up	0	14
103944	2020-07-26 07:09:37	2020-07-26	12	[{"id_menu":3,"count":1}]	14010	delivery	5	17
103945	2020-07-26 07:12:13	2020-07-26	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	40122	delivery	5	31
103946	2020-07-26 07:14:56	2020-07-26	14	[{"id_menu":2,"count":1}]	1528	pick-up	0	14
103947	2020-07-26 07:16:28	2020-07-26	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	39984	delivery	5	34
103948	2020-07-26 07:16:34	2020-07-26	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	9171	delivery	5	34
103949	2020-07-26 07:20:39	2020-07-26	9	[{"id_menu":6,"count":1}]	19382	delivery	5	14
103950	2020-07-26 07:21:10	2020-07-26	8	[{"id_menu":5,"count":1}]	20494	delivery	5	13
103951	2020-07-26 07:26:28	2020-07-26	14	[{"id_menu":2,"count":1}]	37694	delivery	5	19
103952	2020-07-26 07:29:43	2020-07-26	8	[{"id_menu":5,"count":1}]	40129	delivery	5	13
103953	2020-07-26 07:29:44	2020-07-26	9	[{"id_menu":6,"count":1}]	40173	pick-up	0	9
103954	2020-07-26 07:31:07	2020-07-26	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	28495	delivery	5	23
103955	2020-07-26 07:33:19	2020-07-26	12	[{"id_menu":3,"count":2}]	40157	delivery	5	17
103956	2020-07-26 07:34:21	2020-07-26	8	[{"id_menu":5,"count":1}]	31079	delivery	5	13
103957	2020-07-26 07:35:37	2020-07-26	14	[{"id_menu":2,"count":1}]	1266	delivery	5	19
103958	2020-07-26 07:36:36	2020-07-26	12	[{"id_menu":3,"count":1}]	15550	delivery	5	17
103959	2020-07-26 07:40:53	2020-07-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	39975	delivery	5	22
103960	2020-07-26 07:41:07	2020-07-26	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6366	delivery	5	40
103961	2020-07-26 07:42:33	2020-07-26	14	[{"id_menu":2,"count":2}]	12959	delivery	5	19
103962	2020-07-26 07:42:55	2020-07-26	8	[{"id_menu":5,"count":1}]	19183	pick-up	0	8
103963	2020-07-26 07:43:00	2020-07-26	12	[{"id_menu":3,"count":1}]	57	delivery	5	17
103964	2020-07-26 07:46:26	2020-07-26	8	[{"id_menu":5,"count":1}]	25105	delivery	5	13
103965	2020-07-26 07:46:55	2020-07-26	8	[{"id_menu":5,"count":1}]	34784	delivery	5	13
103966	2020-07-26 07:49:10	2020-07-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	4595	pick-up	0	26
103967	2020-07-26 07:50:52	2020-07-26	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	40182	delivery	5	37
103968	2020-07-26 07:51:15	2020-07-26	8	[{"id_menu":5,"count":1}]	6645	delivery	5	13
103969	2020-07-26 07:51:33	2020-07-26	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	17582	delivery	5	40
103970	2020-07-26 07:53:53	2020-07-26	9	[{"id_menu":7,"count":1}]	6221	pick-up	0	9
103971	2020-07-26 07:54:09	2020-07-26	14	[{"id_menu":2,"count":1}]	31438	delivery	5	19
103972	2020-07-26 08:00:01	2020-07-26	9	[{"id_menu":7,"count":1}]	29096	delivery	5	14
103973	2020-07-26 08:00:07	2020-07-26	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	40121	delivery	5	23
103974	2020-07-26 08:00:17	2020-07-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2637	delivery	5	26
103975	2020-07-26 08:00:17	2020-07-26	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	4754	delivery	5	23
103976	2020-07-26 08:01:00	2020-07-26	12	[{"id_menu":1,"count":1}]	40132	delivery	5	17
103977	2020-07-26 08:01:02	2020-07-26	9	[{"id_menu":7,"count":1}]	30328	delivery	5	14
103978	2020-07-26 08:01:49	2020-07-26	17	[{"id_menu":4,"count":1}]	40188	delivery	5	22
103979	2020-07-26 08:02:06	2020-07-26	12	[{"id_menu":1,"count":1}]	12760	delivery	5	17
103980	2020-07-26 08:03:05	2020-07-26	9	[{"id_menu":6,"count":1}]	39956	delivery	5	14
103981	2020-07-26 08:03:55	2020-07-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	27300	delivery	5	22
103982	2020-07-26 08:07:47	2020-07-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	6435	delivery	5	26
103983	2020-07-26 08:09:01	2020-07-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":3}]	40071	delivery	5	23
103984	2020-07-26 08:09:17	2020-07-26	8	[{"id_menu":5,"count":1}]	20026	delivery	5	13
103985	2020-07-26 08:09:31	2020-07-26	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	40007	delivery	5	39
103986	2020-07-26 08:10:12	2020-07-26	17	[{"id_menu":4,"count":1}]	1781	pick-up	0	17
103987	2020-07-26 08:10:58	2020-07-26	8	[{"id_menu":5,"count":1}]	143	delivery	5	13
103988	2020-07-26 08:12:08	2020-07-26	8	[{"id_menu":5,"count":1}]	40186	delivery	5	13
103989	2020-07-26 08:12:17	2020-07-26	9	[{"id_menu":6,"count":1}]	19229	delivery	5	14
103990	2020-07-26 08:14:32	2020-07-26	12	[{"id_menu":1,"count":1}]	32792	delivery	5	17
103991	2020-07-26 08:18:33	2020-07-26	12	[{"id_menu":1,"count":1}]	37034	delivery	5	17
103992	2020-07-26 08:21:12	2020-07-26	8	[{"id_menu":5,"count":1}]	9713	delivery	5	13
103993	2020-07-26 08:21:16	2020-07-26	8	[{"id_menu":5,"count":1}]	38989	delivery	5	13
103994	2020-07-26 08:21:20	2020-07-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	40115	delivery	5	26
103995	2020-07-26 08:21:56	2020-07-26	9	[{"id_menu":7,"count":1}]	115	delivery	5	14
103996	2020-07-26 08:22:28	2020-07-26	14	[{"id_menu":2,"count":1}]	6376	pick-up	0	14
103997	2020-07-26 08:22:57	2020-07-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	17850	delivery	5	28
103998	2020-07-26 08:25:00	2020-07-26	9	[{"id_menu":7,"count":1}]	18480	delivery	5	14
103999	2020-07-26 08:25:17	2020-07-26	9	[{"id_menu":7,"count":1}]	40036	pick-up	0	9
104000	2020-07-26 08:25:46	2020-07-26	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	27496	delivery	5	34
104001	2020-07-26 08:27:23	2020-07-26	8	[{"id_menu":5,"count":1}]	34805	delivery	5	13
104002	2020-07-26 08:29:38	2020-07-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7924	delivery	5	23
104003	2020-07-26 08:30:47	2020-07-26	9	[{"id_menu":6,"count":2}]	26591	delivery	5	14
104004	2020-07-26 08:34:03	2020-07-26	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	11887	pick-up	0	26
104005	2020-07-26 08:34:47	2020-07-26	14	[{"id_menu":2,"count":1}]	11249	delivery	5	19
104006	2020-07-26 08:36:15	2020-07-26	17	[{"id_menu":4,"count":1}]	38586	pick-up	0	17
104007	2020-07-26 08:37:47	2020-07-26	9	[{"id_menu":7,"count":1}]	40180	delivery	5	14
104008	2020-07-26 08:40:31	2020-07-26	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	21239	delivery	5	31
104009	2020-07-26 08:40:32	2020-07-26	14	[{"id_menu":2,"count":2}]	28724	delivery	5	19
104010	2020-07-26 08:41:31	2020-07-26	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	27875	delivery	5	30
104011	2020-07-26 08:43:36	2020-07-26	12	[{"id_menu":3,"count":1}]	19420	delivery	5	17
104012	2020-07-26 08:46:24	2020-07-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	318	delivery	5	23
104013	2020-07-26 08:47:35	2020-07-26	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	38556	delivery	5	40
104014	2020-07-26 08:48:01	2020-07-26	12	[{"id_menu":3,"count":1}]	39934	pick-up	0	12
104015	2020-07-26 08:48:59	2020-07-26	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	40183	delivery	5	34
104016	2020-07-26 08:50:04	2020-07-26	8	[{"id_menu":5,"count":2}]	40005	delivery	5	13
104017	2020-07-26 08:51:22	2020-07-26	17	[{"id_menu":4,"count":2}]	40089	pick-up	0	17
104018	2020-07-26 08:52:14	2020-07-26	9	[{"id_menu":7,"count":1}]	4414	delivery	5	14
104019	2020-07-26 08:53:13	2020-07-26	9	[{"id_menu":7,"count":1}]	34856	pick-up	0	9
104020	2020-07-26 08:53:50	2020-07-26	17	[{"id_menu":4,"count":1}]	40046	delivery	5	22
104021	2020-07-26 08:54:51	2020-07-26	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	32823	delivery	5	30
104022	2020-07-26 08:55:48	2020-07-26	17	[{"id_menu":4,"count":1}]	37729	delivery	5	22
104023	2020-07-26 08:58:00	2020-07-26	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":2}]	37948	delivery	5	26
104024	2020-07-26 09:00:28	2020-07-26	9	[{"id_menu":6,"count":1}]	1428	delivery	5	14
104025	2020-07-26 09:01:30	2020-07-26	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	39994	delivery	5	36
104026	2020-07-26 09:03:50	2020-07-26	9	[{"id_menu":7,"count":1}]	39964	delivery	5	14
104027	2020-07-26 09:05:41	2020-07-26	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1379	pick-up	0	26
104028	2020-07-26 09:05:43	2020-07-26	8	[{"id_menu":5,"count":1}]	40038	delivery	5	13
104029	2020-07-26 09:05:59	2020-07-26	9	[{"id_menu":6,"count":1}]	30193	delivery	5	14
104030	2020-07-26 09:07:00	2020-07-26	14	[{"id_menu":2,"count":1}]	38999	delivery	5	19
104031	2020-07-26 09:08:15	2020-07-26	9	[{"id_menu":6,"count":1}]	34525	delivery	5	14
104032	2020-07-26 09:11:58	2020-07-26	17	[{"id_menu":4,"count":1}]	18948	delivery	5	22
104033	2020-07-26 09:12:29	2020-07-26	12	[{"id_menu":3,"count":1}]	14427	pick-up	0	12
104034	2020-07-26 09:12:43	2020-07-26	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6769	pick-up	0	31
104035	2020-07-26 09:12:56	2020-07-26	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	10170	delivery	5	26
104036	2020-07-26 09:13:01	2020-07-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24171	delivery	5	23
104037	2020-07-26 09:14:57	2020-07-26	9	[{"id_menu":6,"count":1}]	32075	delivery	5	14
104038	2020-07-26 09:19:15	2020-07-26	9	[{"id_menu":7,"count":1}]	13236	delivery	5	14
104039	2020-07-26 09:21:03	2020-07-26	14	[{"id_menu":2,"count":1}]	8505	pick-up	0	14
104040	2020-07-26 09:22:08	2020-07-26	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	40209	delivery	5	36
104041	2020-07-26 09:23:35	2020-07-26	17	[{"id_menu":4,"count":1}]	11389	delivery	5	22
104042	2020-07-26 09:23:51	2020-07-26	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	36480	delivery	5	42
104043	2020-07-26 09:28:30	2020-07-26	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	30679	delivery	5	39
104044	2020-07-26 09:30:48	2020-07-26	9	[{"id_menu":6,"count":1}]	28176	delivery	5	14
104045	2020-07-26 09:34:55	2020-07-26	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28630	delivery	5	35
104046	2020-07-26 09:36:17	2020-07-26	12	[{"id_menu":1,"count":1}]	36885	delivery	5	17
104047	2020-07-26 09:37:21	2020-07-26	12	[{"id_menu":1,"count":1}]	31498	delivery	5	17
104116	2020-07-26 11:07:30	2020-07-26	9	[{"id_menu":6,"count":1}]	19729	pick-up	0	9
104048	2020-07-26 09:38:23	2020-07-26	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39946	delivery	5	39
104049	2020-07-26 09:43:17	2020-07-26	9	[{"id_menu":7,"count":1}]	17353	pick-up	0	9
104050	2020-07-26 09:43:29	2020-07-26	17	[{"id_menu":4,"count":1}]	25141	pick-up	0	17
104051	2020-07-26 09:45:08	2020-07-26	14	[{"id_menu":2,"count":1}]	11935	pick-up	0	14
104052	2020-07-26 09:45:22	2020-07-26	12	[{"id_menu":1,"count":1}]	29263	delivery	5	17
104053	2020-07-26 09:46:00	2020-07-26	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15485	delivery	5	31
104054	2020-07-26 09:46:25	2020-07-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	23075	delivery	5	26
104055	2020-07-26 09:48:02	2020-07-26	9	[{"id_menu":6,"count":1}]	26624	delivery	5	14
104056	2020-07-26 09:48:17	2020-07-26	12	[{"id_menu":1,"count":1}]	26046	delivery	5	17
104057	2020-07-26 09:51:27	2020-07-26	8	[{"id_menu":5,"count":1}]	20228	delivery	5	13
104058	2020-07-26 09:55:44	2020-07-26	17	[{"id_menu":4,"count":1}]	25954	pick-up	0	17
104059	2020-07-26 09:57:36	2020-07-26	9	[{"id_menu":7,"count":1}]	22572	delivery	5	14
104060	2020-07-26 09:58:28	2020-07-26	9	[{"id_menu":7,"count":1}]	21216	delivery	5	14
104061	2020-07-26 10:00:43	2020-07-26	9	[{"id_menu":7,"count":1}]	26743	delivery	5	14
104062	2020-07-26 10:02:01	2020-07-26	12	[{"id_menu":3,"count":1}]	5215	delivery	5	17
104063	2020-07-26 10:05:52	2020-07-26	9	[{"id_menu":6,"count":1}]	39947	delivery	5	14
104064	2020-07-26 10:08:32	2020-07-26	17	[{"id_menu":4,"count":1}]	34446	delivery	5	22
104065	2020-07-26 10:08:39	2020-07-26	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	25971	delivery	5	31
104066	2020-07-26 10:08:51	2020-07-26	14	[{"id_menu":2,"count":1}]	17649	pick-up	0	14
104067	2020-07-26 10:09:48	2020-07-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	25922	delivery	5	22
104068	2020-07-26 10:10:09	2020-07-26	9	[{"id_menu":6,"count":1}]	36095	delivery	5	14
104069	2020-07-26 10:10:40	2020-07-26	9	[{"id_menu":6,"count":1}]	33897	delivery	5	14
104070	2020-07-26 10:12:10	2020-07-26	8	[{"id_menu":5,"count":1}]	40190	delivery	5	13
104071	2020-07-26 10:15:39	2020-07-26	9	[{"id_menu":7,"count":1}]	38057	delivery	5	14
104072	2020-07-26 10:17:06	2020-07-26	9	[{"id_menu":6,"count":1}]	35869	delivery	5	14
104073	2020-07-26 10:19:39	2020-07-26	9	[{"id_menu":7,"count":1}]	40107	delivery	5	14
104074	2020-07-26 10:20:00	2020-07-26	14	[{"id_menu":2,"count":3}]	40018	delivery	5	19
104075	2020-07-26 10:20:34	2020-07-26	9	[{"id_menu":7,"count":1}]	28084	delivery	5	14
104076	2020-07-26 10:20:35	2020-07-26	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	40119	delivery	5	31
104077	2020-07-26 10:22:53	2020-07-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	40024	delivery	5	28
104078	2020-07-26 10:23:28	2020-07-26	9	[{"id_menu":7,"count":1}]	22483	delivery	5	14
104079	2020-07-26 10:26:19	2020-07-26	17	[{"id_menu":4,"count":1}]	18506	delivery	5	22
104080	2020-07-26 10:27:49	2020-07-26	9	[{"id_menu":7,"count":1}]	32214	pick-up	0	9
104081	2020-07-26 10:27:50	2020-07-26	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	40192	delivery	5	25
104082	2020-07-26 10:31:25	2020-07-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5729	delivery	5	22
104083	2020-07-26 10:32:07	2020-07-26	8	[{"id_menu":5,"count":1}]	39998	delivery	5	13
104084	2020-07-26 10:33:03	2020-07-26	9	[{"id_menu":7,"count":1}]	38461	delivery	5	14
104085	2020-07-26 10:33:59	2020-07-26	14	[{"id_menu":2,"count":1}]	35933	pick-up	0	14
104086	2020-07-26 10:34:07	2020-07-26	12	[{"id_menu":3,"count":1}]	40017	delivery	5	17
104087	2020-07-26 10:35:12	2020-07-26	9	[{"id_menu":7,"count":1}]	25068	delivery	5	14
104088	2020-07-26 10:36:36	2020-07-26	8	[{"id_menu":5,"count":1}]	25075	delivery	5	13
104089	2020-07-26 10:37:23	2020-07-26	8	[{"id_menu":5,"count":2}]	16263	delivery	5	13
104090	2020-07-26 10:37:33	2020-07-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":3}]	40086	delivery	5	22
104091	2020-07-26 10:38:16	2020-07-26	12	[{"id_menu":3,"count":1}]	31694	delivery	5	17
104092	2020-07-26 10:39:03	2020-07-26	9	[{"id_menu":7,"count":1}]	13656	pick-up	0	9
104093	2020-07-26 10:41:02	2020-07-26	9	[{"id_menu":7,"count":1}]	6924	pick-up	0	9
104094	2020-07-26 10:42:08	2020-07-26	12	[{"id_menu":3,"count":1}]	6740	delivery	5	17
104095	2020-07-26 10:44:07	2020-07-26	14	[{"id_menu":2,"count":1}]	39960	delivery	5	19
104096	2020-07-26 10:44:09	2020-07-26	9	[{"id_menu":7,"count":1}]	7053	pick-up	0	9
104097	2020-07-26 10:44:22	2020-07-26	9	[{"id_menu":7,"count":1}]	1906	delivery	5	14
104098	2020-07-26 10:45:47	2020-07-26	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	33730	pick-up	0	29
104099	2020-07-26 10:47:38	2020-07-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16090	delivery	5	31
104100	2020-07-26 10:47:56	2020-07-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20729	delivery	5	22
104101	2020-07-26 10:51:07	2020-07-26	12	[{"id_menu":3,"count":1}]	28755	delivery	5	17
104102	2020-07-26 10:51:30	2020-07-26	9	[{"id_menu":7,"count":1}]	25182	delivery	5	14
104103	2020-07-26 10:51:43	2020-07-26	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	40059	delivery	5	39
104104	2020-07-26 10:52:05	2020-07-26	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	12078	delivery	5	30
104105	2020-07-26 10:52:47	2020-07-26	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40011	delivery	5	37
104106	2020-07-26 10:54:02	2020-07-26	8	[{"id_menu":5,"count":1}]	36657	delivery	5	13
104107	2020-07-26 10:54:29	2020-07-26	9	[{"id_menu":6,"count":1}]	34038	delivery	5	14
104108	2020-07-26 10:55:38	2020-07-26	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24042	delivery	5	52
104109	2020-07-26 10:57:59	2020-07-26	9	[{"id_menu":6,"count":1}]	6173	pick-up	0	9
104110	2020-07-26 10:59:32	2020-07-26	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	24538	delivery	5	40
104111	2020-07-26 11:00:37	2020-07-26	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	40078	delivery	5	34
104112	2020-07-26 11:00:41	2020-07-26	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38743	delivery	5	37
104113	2020-07-26 11:02:22	2020-07-26	12	[{"id_menu":3,"count":1}]	15340	pick-up	0	12
104114	2020-07-26 11:03:08	2020-07-26	17	[{"id_menu":4,"count":1}]	8779	delivery	5	22
104115	2020-07-26 11:03:11	2020-07-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39985	delivery	5	22
104117	2020-07-26 11:08:10	2020-07-26	17	[{"id_menu":4,"count":1}]	6331	delivery	5	22
104118	2020-07-26 11:08:16	2020-07-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1663	delivery	5	26
104119	2020-07-26 11:10:17	2020-07-26	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	33981	delivery	5	36
104120	2020-07-26 11:11:01	2020-07-26	12	[{"id_menu":1,"count":1}]	5811	delivery	5	17
104121	2020-07-26 11:18:16	2020-07-26	17	[{"id_menu":4,"count":1}]	21184	pick-up	0	17
104122	2020-07-26 11:19:07	2020-07-26	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	22600	delivery	5	55
104123	2020-07-26 11:21:01	2020-07-26	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	31259	delivery	5	39
104124	2020-07-26 11:22:56	2020-07-26	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	40068	delivery	5	26
104125	2020-07-26 11:27:18	2020-07-26	9	[{"id_menu":6,"count":1}]	33293	pick-up	0	9
104126	2020-07-26 11:29:17	2020-07-26	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25728	delivery	5	35
104127	2020-07-26 11:30:19	2020-07-26	9	[{"id_menu":7,"count":1}]	6489	pick-up	0	9
104128	2020-07-26 11:32:34	2020-07-26	9	[{"id_menu":6,"count":1}]	4483	delivery	5	14
104129	2020-07-26 11:33:38	2020-07-26	17	[{"id_menu":4,"count":1}]	28487	pick-up	0	17
104130	2020-07-26 11:34:00	2020-07-26	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	29320	delivery	5	43
104131	2020-07-26 11:35:51	2020-07-26	9	[{"id_menu":7,"count":1}]	16660	delivery	5	14
104132	2020-07-26 11:36:25	2020-07-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	38120	delivery	5	31
104133	2020-07-26 11:41:19	2020-07-26	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38646	delivery	5	31
104134	2020-07-26 11:41:58	2020-07-26	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	37743	delivery	5	31
104135	2020-07-26 11:47:54	2020-07-26	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28080	delivery	5	35
104136	2020-07-26 11:48:13	2020-07-26	14	[{"id_menu":2,"count":1}]	2310	delivery	5	19
104137	2020-07-26 11:48:20	2020-07-26	17	[{"id_menu":4,"count":1}]	40044	delivery	5	22
104138	2020-07-26 11:48:28	2020-07-26	9	[{"id_menu":6,"count":1}]	11446	pick-up	0	9
104139	2020-07-26 11:51:45	2020-07-26	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	26271	delivery	5	25
104140	2020-07-26 11:52:22	2020-07-26	14	[{"id_menu":2,"count":1}]	23784	pick-up	0	14
104141	2020-07-26 11:53:04	2020-07-26	17	[{"id_menu":4,"count":1}]	40202	delivery	5	22
104142	2020-07-26 11:54:22	2020-07-26	14	[{"id_menu":2,"count":1}]	40096	pick-up	0	14
104143	2020-07-26 11:56:21	2020-07-26	9	[{"id_menu":6,"count":1}]	12648	pick-up	0	9
104144	2020-07-26 11:57:15	2020-07-26	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	20805	delivery	5	34
104145	2020-07-26 11:59:32	2020-07-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	26140	delivery	5	26
104146	2020-07-26 12:00:10	2020-07-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23859	delivery	5	23
104147	2020-07-26 12:01:26	2020-07-26	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	19397	delivery	5	31
104148	2020-07-26 12:01:59	2020-07-26	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	13275	delivery	5	31
104149	2020-07-26 12:04:07	2020-07-26	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	40105	delivery	5	34
104150	2020-07-26 12:08:31	2020-07-26	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24865	delivery	5	49
104151	2020-07-26 12:11:37	2020-07-26	9	[{"id_menu":7,"count":1}]	39932	delivery	5	14
104152	2020-07-26 12:12:05	2020-07-26	9	[{"id_menu":7,"count":1}]	39954	pick-up	0	9
104153	2020-07-26 12:12:26	2020-07-26	39	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4155	delivery	5	44
104154	2020-07-26 12:12:47	2020-07-26	17	[{"id_menu":4,"count":1}]	3382	pick-up	0	17
104155	2020-07-26 12:14:20	2020-07-26	17	[{"id_menu":4,"count":1}]	26861	delivery	5	22
104156	2020-07-26 12:18:08	2020-07-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	40178	delivery	5	31
104157	2020-07-26 12:19:55	2020-07-26	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	22628	delivery	5	42
104158	2020-07-26 12:20:41	2020-07-26	9	[{"id_menu":6,"count":1}]	2443	pick-up	0	9
104159	2020-07-26 12:20:56	2020-07-26	14	[{"id_menu":2,"count":1}]	40039	delivery	5	19
104160	2020-07-26 12:21:37	2020-07-26	8	[{"id_menu":5,"count":1}]	40006	delivery	5	13
104161	2020-07-26 12:24:44	2020-07-26	9	[{"id_menu":7,"count":2}]	15578	delivery	5	14
104162	2020-07-26 12:27:15	2020-07-26	12	[{"id_menu":1,"count":1}]	39981	delivery	5	17
104163	2020-07-26 12:28:54	2020-07-26	14	[{"id_menu":2,"count":4}]	2561	pick-up	0	14
104164	2020-07-26 12:29:40	2020-07-26	12	[{"id_menu":1,"count":1}]	32485	delivery	5	17
104165	2020-07-26 12:33:29	2020-07-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	40064	delivery	5	22
104166	2020-07-26 12:35:08	2020-07-26	9	[{"id_menu":6,"count":1}]	40141	delivery	5	14
104167	2020-07-26 12:35:15	2020-07-26	14	[{"id_menu":2,"count":1}]	18103	delivery	5	19
104168	2020-07-26 12:35:28	2020-07-26	12	[{"id_menu":3,"count":1}]	40020	delivery	5	17
104169	2020-07-26 12:37:03	2020-07-26	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	15626	delivery	5	37
104170	2020-07-26 12:38:32	2020-07-26	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	33959	delivery	5	31
104171	2020-07-26 12:38:43	2020-07-26	12	[{"id_menu":1,"count":1}]	20579	delivery	5	17
104172	2020-07-26 12:39:11	2020-07-26	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25865	delivery	5	39
104173	2020-07-26 12:40:55	2020-07-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	39943	delivery	5	23
104174	2020-07-26 12:40:57	2020-07-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2415	pick-up	0	26
104175	2020-07-26 12:41:00	2020-07-26	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	40159	delivery	5	42
104176	2020-07-26 12:41:34	2020-07-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	40165	delivery	5	31
104177	2020-07-26 12:42:10	2020-07-26	17	[{"id_menu":4,"count":2}]	36846	delivery	5	22
104178	2020-07-26 12:42:46	2020-07-26	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	23424	pick-up	0	21
104179	2020-07-26 12:43:49	2020-07-26	9	[{"id_menu":6,"count":1}]	1992	delivery	5	14
104180	2020-07-26 12:44:53	2020-07-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	34003	delivery	5	31
104181	2020-07-26 12:45:58	2020-07-26	12	[{"id_menu":3,"count":1}]	23581	pick-up	0	12
104182	2020-07-26 12:47:13	2020-07-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	40156	delivery	5	28
104183	2020-07-26 12:48:47	2020-07-26	8	[{"id_menu":5,"count":1}]	40181	delivery	5	13
104184	2020-07-26 12:48:57	2020-07-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15256	delivery	5	23
104185	2020-07-26 12:49:39	2020-07-26	9	[{"id_menu":6,"count":1}]	40097	delivery	5	14
104186	2020-07-26 12:51:04	2020-07-26	9	[{"id_menu":6,"count":1}]	40026	pick-up	0	9
104187	2020-07-26 12:51:19	2020-07-26	9	[{"id_menu":7,"count":1}]	9550	delivery	5	14
104188	2020-07-26 12:51:53	2020-07-26	8	[{"id_menu":5,"count":2}]	28289	pick-up	0	8
104189	2020-07-26 12:52:28	2020-07-26	9	[{"id_menu":7,"count":1}]	40014	delivery	5	14
104190	2020-07-26 12:53:11	2020-07-26	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	65	pick-up	0	26
104191	2020-07-26 12:54:38	2020-07-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	40022	delivery	5	26
104192	2020-07-26 12:55:06	2020-07-26	9	[{"id_menu":6,"count":1}]	40128	delivery	5	14
104193	2020-07-26 12:55:15	2020-07-26	12	[{"id_menu":1,"count":1}]	39923	delivery	5	17
104194	2020-07-26 12:55:58	2020-07-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	15110	pick-up	0	23
104195	2020-07-26 12:56:27	2020-07-26	12	[{"id_menu":1,"count":1}]	13563	delivery	5	17
104196	2020-07-26 12:58:34	2020-07-26	12	[{"id_menu":3,"count":1}]	4226	delivery	5	17
104197	2020-07-26 13:02:13	2020-07-26	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	676	delivery	5	31
104198	2020-07-26 13:04:05	2020-07-26	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	40053	delivery	5	36
104199	2020-07-26 13:04:53	2020-07-26	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40174	delivery	5	54
104200	2020-07-26 13:07:20	2020-07-26	17	[{"id_menu":4,"count":2}]	40031	delivery	5	22
104201	2020-07-26 13:07:56	2020-07-26	14	[{"id_menu":2,"count":1}]	40116	delivery	5	19
104202	2020-07-26 13:12:20	2020-07-26	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	40142	delivery	5	22
104203	2020-07-26 13:12:22	2020-07-26	12	[{"id_menu":3,"count":1}]	29127	delivery	5	17
104204	2020-07-26 13:13:00	2020-07-26	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1944	pick-up	0	21
104205	2020-07-26 13:14:08	2020-07-26	17	[{"id_menu":4,"count":1}]	1314	delivery	5	22
104206	2020-07-26 13:15:34	2020-07-26	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	25811	delivery	5	40
104207	2020-07-26 13:15:51	2020-07-26	9	[{"id_menu":6,"count":1}]	40166	delivery	5	14
104208	2020-07-26 13:16:30	2020-07-26	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	19399	delivery	5	55
104209	2020-07-26 13:20:15	2020-07-26	9	[{"id_menu":6,"count":1}]	40196	delivery	5	14
104210	2020-07-26 13:20:34	2020-07-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	26065	pick-up	0	26
104211	2020-07-26 13:22:16	2020-07-26	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	334	delivery	5	49
104212	2020-07-26 13:23:48	2020-07-26	17	[{"id_menu":4,"count":1}]	4281	delivery	5	22
104213	2020-07-26 13:24:34	2020-07-26	8	[{"id_menu":5,"count":1}]	40027	delivery	5	13
104214	2020-07-26 13:25:11	2020-07-26	9	[{"id_menu":6,"count":1}]	12108	delivery	5	14
104215	2020-07-26 13:25:29	2020-07-26	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	30306	pick-up	0	29
104216	2020-07-26 13:25:36	2020-07-26	12	[{"id_menu":1,"count":1}]	2641	delivery	5	17
104217	2020-07-26 13:26:22	2020-07-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	36310	delivery	5	26
104218	2020-07-26 13:26:45	2020-07-26	8	[{"id_menu":5,"count":1}]	40189	delivery	5	13
104219	2020-07-26 13:27:00	2020-07-26	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	18094	delivery	5	31
104220	2020-07-26 13:27:18	2020-07-26	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	40201	pick-up	0	17
104221	2020-07-26 13:27:42	2020-07-26	8	[{"id_menu":5,"count":1}]	19981	delivery	5	13
104222	2020-07-26 13:28:13	2020-07-26	9	[{"id_menu":6,"count":1}]	40139	pick-up	0	9
104223	2020-07-26 13:28:22	2020-07-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	5886	delivery	5	28
104224	2020-07-26 13:29:43	2020-07-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	13547	pick-up	0	23
104225	2020-07-26 13:30:35	2020-07-26	9	[{"id_menu":6,"count":1}]	40134	delivery	5	14
104226	2020-07-26 13:31:39	2020-07-26	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20573	delivery	5	47
104227	2020-07-26 13:32:13	2020-07-26	9	[{"id_menu":7,"count":1}]	533	delivery	5	14
104228	2020-07-26 13:33:09	2020-07-26	12	[{"id_menu":1,"count":1}]	11345	delivery	5	17
104229	2020-07-26 13:33:24	2020-07-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	40177	delivery	5	28
104230	2020-07-26 13:34:15	2020-07-26	9	[{"id_menu":7,"count":1}]	40049	pick-up	0	9
104231	2020-07-26 13:35:09	2020-07-26	8	[{"id_menu":5,"count":1}]	39958	delivery	5	13
104232	2020-07-26 13:35:49	2020-07-26	14	[{"id_menu":2,"count":1}]	22478	pick-up	0	14
104233	2020-07-26 13:35:56	2020-07-26	17	[{"id_menu":4,"count":1}]	39993	delivery	5	22
104234	2020-07-26 13:37:21	2020-07-26	12	[{"id_menu":1,"count":2}]	245	pick-up	0	12
104235	2020-07-26 13:38:28	2020-07-26	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19946	delivery	5	51
104236	2020-07-26 13:38:47	2020-07-26	8	[{"id_menu":5,"count":1}]	39971	delivery	5	13
104237	2020-07-26 13:40:36	2020-07-26	17	[{"id_menu":4,"count":1}]	39988	delivery	5	22
104238	2020-07-26 13:41:34	2020-07-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	25882	delivery	5	31
104239	2020-07-26 13:43:25	2020-07-26	12	[{"id_menu":1,"count":1}]	2197	pick-up	0	12
104240	2020-07-26 13:43:55	2020-07-26	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40140	delivery	5	31
104241	2020-07-26 13:44:06	2020-07-26	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	6387	delivery	5	39
104242	2020-07-26 13:47:18	2020-07-26	17	[{"id_menu":4,"count":1}]	10193	delivery	5	22
104243	2020-07-26 13:48:22	2020-07-26	9	[{"id_menu":6,"count":1}]	33452	pick-up	0	9
104244	2020-07-26 13:48:57	2020-07-26	9	[{"id_menu":7,"count":1}]	24040	delivery	5	14
104245	2020-07-26 13:50:39	2020-07-26	17	[{"id_menu":4,"count":1}]	32194	delivery	5	22
104246	2020-07-26 13:53:45	2020-07-26	9	[{"id_menu":7,"count":1}]	30673	delivery	5	14
104247	2020-07-26 13:54:09	2020-07-26	9	[{"id_menu":7,"count":1}]	39944	delivery	5	14
104248	2020-07-26 13:55:54	2020-07-26	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10653	delivery	5	45
104249	2020-07-26 13:58:16	2020-07-26	14	[{"id_menu":2,"count":1}]	11291	delivery	5	19
104250	2020-07-26 14:03:41	2020-07-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	7364	delivery	5	23
104251	2020-07-26 14:03:44	2020-07-26	8	[{"id_menu":5,"count":1}]	20070	delivery	5	13
104252	2020-07-26 14:04:29	2020-07-26	9	[{"id_menu":7,"count":1}]	28716	delivery	5	14
104253	2020-07-26 14:06:08	2020-07-26	9	[{"id_menu":6,"count":1}]	17502	delivery	5	14
104254	2020-07-26 14:06:56	2020-07-26	12	[{"id_menu":3,"count":1}]	21448	pick-up	0	12
104255	2020-07-26 14:07:28	2020-07-26	17	[{"id_menu":4,"count":1}]	40120	delivery	5	22
104256	2020-07-26 14:09:52	2020-07-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	10287	pick-up	0	21
104257	2020-07-26 14:10:06	2020-07-26	14	[{"id_menu":2,"count":1}]	12245	delivery	5	19
104258	2020-07-26 14:11:10	2020-07-26	8	[{"id_menu":5,"count":1}]	38659	delivery	5	13
104259	2020-07-26 14:12:00	2020-07-26	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40193	delivery	5	37
104260	2020-07-26 14:13:48	2020-07-26	9	[{"id_menu":7,"count":2}]	39991	delivery	5	14
104261	2020-07-26 14:14:09	2020-07-26	8	[{"id_menu":5,"count":1}]	12830	delivery	5	13
104262	2020-07-26 14:14:34	2020-07-26	17	[{"id_menu":4,"count":1}]	35038	pick-up	0	17
104263	2020-07-26 14:17:40	2020-07-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40095	delivery	5	23
104264	2020-07-26 14:17:58	2020-07-26	9	[{"id_menu":6,"count":1}]	40065	delivery	5	14
104265	2020-07-26 14:19:21	2020-07-26	9	[{"id_menu":7,"count":1}]	1791	pick-up	0	9
104266	2020-07-26 14:20:41	2020-07-26	17	[{"id_menu":4,"count":1}]	39917	delivery	5	22
104267	2020-07-26 14:20:55	2020-07-26	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	40043	delivery	5	38
104268	2020-07-26 14:27:33	2020-07-26	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	9934	pick-up	0	20
104269	2020-07-26 14:29:06	2020-07-26	9	[{"id_menu":6,"count":1}]	5839	delivery	5	14
104270	2020-07-26 14:30:37	2020-07-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	39987	delivery	5	28
104271	2020-07-26 14:32:22	2020-07-26	14	[{"id_menu":2,"count":1}]	11244	pick-up	0	14
104272	2020-07-26 14:32:49	2020-07-26	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	39928	delivery	5	40
104273	2020-07-26 14:33:28	2020-07-26	14	[{"id_menu":2,"count":1}]	3887	delivery	5	19
104274	2020-07-26 14:34:51	2020-07-26	9	[{"id_menu":7,"count":1}]	40084	delivery	5	14
104275	2020-07-26 14:35:08	2020-07-26	12	[{"id_menu":3,"count":1}]	251	pick-up	0	12
104276	2020-07-26 14:35:27	2020-07-26	9	[{"id_menu":6,"count":1}]	8333	delivery	5	14
104277	2020-07-26 14:35:32	2020-07-26	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10758	delivery	5	43
104278	2020-07-26 14:38:38	2020-07-26	12	[{"id_menu":1,"count":1}]	2752	pick-up	0	12
104279	2020-07-26 14:38:55	2020-07-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	34899	delivery	5	28
104280	2020-07-26 14:39:12	2020-07-26	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	36952	delivery	5	34
104281	2020-07-26 14:40:03	2020-07-26	17	[{"id_menu":4,"count":1}]	3529	pick-up	0	17
104282	2020-07-26 14:43:05	2020-07-26	14	[{"id_menu":2,"count":1}]	16461	delivery	5	19
104283	2020-07-26 14:43:41	2020-07-26	17	[{"id_menu":4,"count":1}]	40062	delivery	5	22
104284	2020-07-26 14:52:20	2020-07-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14756	pick-up	0	17
104285	2020-07-26 14:54:31	2020-07-26	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3540	delivery	5	34
104286	2020-07-26 14:55:11	2020-07-26	12	[{"id_menu":3,"count":1}]	38541	delivery	5	17
104287	2020-07-26 14:55:22	2020-07-26	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40146	delivery	5	31
104288	2020-07-26 14:59:19	2020-07-26	9	[{"id_menu":6,"count":1}]	1900	pick-up	0	9
104289	2020-07-26 15:02:38	2020-07-26	14	[{"id_menu":2,"count":1}]	8113	delivery	5	19
104290	2020-07-26 15:02:47	2020-07-26	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15103	delivery	5	37
104291	2020-07-26 15:04:46	2020-07-26	9	[{"id_menu":6,"count":1}]	25719	pick-up	0	9
104292	2020-07-26 15:05:02	2020-07-26	14	[{"id_menu":2,"count":1}]	19822	delivery	5	19
104293	2020-07-26 15:05:39	2020-07-26	14	[{"id_menu":2,"count":1}]	40083	delivery	5	19
104294	2020-07-26 15:05:57	2020-07-26	14	[{"id_menu":2,"count":1}]	40204	delivery	5	19
104295	2020-07-26 15:07:49	2020-07-26	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32647	delivery	5	54
104296	2020-07-26 15:08:11	2020-07-26	12	[{"id_menu":1,"count":1}]	32255	delivery	5	17
104297	2020-07-26 15:10:38	2020-07-26	9	[{"id_menu":6,"count":1}]	40072	pick-up	0	9
104298	2020-07-26 15:17:00	2020-07-26	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	1885	pick-up	0	35
104299	2020-07-26 15:17:47	2020-07-26	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	40002	delivery	5	43
104300	2020-07-26 15:18:35	2020-07-26	14	[{"id_menu":2,"count":1}]	39925	delivery	5	19
104301	2020-07-26 15:22:02	2020-07-26	9	[{"id_menu":6,"count":1}]	40171	delivery	5	14
104302	2020-07-26 15:23:09	2020-07-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	1836	pick-up	0	17
104303	2020-07-26 15:24:14	2020-07-26	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	20379	pick-up	0	37
104304	2020-07-26 15:26:37	2020-07-26	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	40004	delivery	5	36
104305	2020-07-26 15:34:21	2020-07-26	17	[{"id_menu":4,"count":1}]	40070	delivery	5	22
104306	2020-07-26 15:35:24	2020-07-26	9	[{"id_menu":7,"count":1}]	328	delivery	5	14
104307	2020-07-26 15:35:33	2020-07-26	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	14673	pick-up	0	37
104308	2020-07-26 15:36:41	2020-07-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	25420	delivery	5	31
104309	2020-07-26 15:37:10	2020-07-26	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	35806	pick-up	0	31
104310	2020-07-26 15:37:59	2020-07-26	9	[{"id_menu":7,"count":1}]	15166	pick-up	0	9
104311	2020-07-26 15:38:29	2020-07-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	28451	delivery	5	28
104312	2020-07-26 15:39:41	2020-07-26	9	[{"id_menu":7,"count":1}]	9701	delivery	5	14
104313	2020-07-26 15:42:23	2020-07-26	14	[{"id_menu":2,"count":1}]	1486	pick-up	0	14
104314	2020-07-26 15:44:26	2020-07-26	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	18831	delivery	5	43
104315	2020-07-26 15:44:56	2020-07-26	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19678	delivery	5	39
104316	2020-07-26 15:46:39	2020-07-26	9	[{"id_menu":7,"count":1}]	30036	delivery	5	14
104317	2020-07-26 15:46:43	2020-07-26	17	[{"id_menu":4,"count":1}]	2541	pick-up	0	17
104318	2020-07-26 15:49:38	2020-07-26	17	[{"id_menu":4,"count":1}]	23749	delivery	5	22
104319	2020-07-26 15:51:04	2020-07-26	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	40184	delivery	5	31
104320	2020-07-26 15:51:41	2020-07-26	17	[{"id_menu":4,"count":1}]	40003	delivery	5	22
104321	2020-07-26 15:51:51	2020-07-26	12	[{"id_menu":3,"count":1}]	40191	delivery	5	17
104322	2020-07-26 15:55:37	2020-07-26	9	[{"id_menu":6,"count":1}]	21369	delivery	5	14
104323	2020-07-26 15:55:52	2020-07-26	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	36250	delivery	5	44
104324	2020-07-26 15:55:58	2020-07-26	9	[{"id_menu":7,"count":1}]	40075	delivery	5	14
104325	2020-07-26 15:59:01	2020-07-26	8	[{"id_menu":5,"count":1}]	6808	delivery	5	13
104326	2020-07-26 16:02:08	2020-07-26	14	[{"id_menu":2,"count":1}]	33087	delivery	5	19
104327	2020-07-26 16:02:30	2020-07-26	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39995	delivery	5	35
104328	2020-07-26 16:03:08	2020-07-26	9	[{"id_menu":6,"count":1}]	4867	pick-up	0	9
104329	2020-07-26 16:04:19	2020-07-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	30356	delivery	5	31
104330	2020-07-26 16:04:33	2020-07-26	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39942	delivery	5	51
104331	2020-07-26 16:06:16	2020-07-26	9	[{"id_menu":7,"count":1}]	15022	delivery	5	14
104332	2020-07-26 16:08:08	2020-07-26	17	[{"id_menu":4,"count":1}]	262	pick-up	0	17
104333	2020-07-26 16:08:39	2020-07-26	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	31847	pick-up	0	21
104334	2020-07-26 16:10:22	2020-07-26	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	40056	delivery	5	43
104335	2020-07-26 16:10:43	2020-07-26	9	[{"id_menu":7,"count":1}]	8075	pick-up	0	9
104336	2020-07-26 16:10:43	2020-07-26	17	[{"id_menu":4,"count":1}]	40175	delivery	5	22
104337	2020-07-26 16:11:07	2020-07-26	8	[{"id_menu":5,"count":1}]	9273	delivery	5	13
104338	2020-07-26 16:11:54	2020-07-26	14	[{"id_menu":2,"count":1}]	30318	delivery	5	19
104339	2020-07-26 16:15:18	2020-07-26	8	[{"id_menu":5,"count":2}]	24407	delivery	5	13
104340	2020-07-26 16:17:36	2020-07-26	9	[{"id_menu":7,"count":1}]	6115	delivery	5	14
104341	2020-07-26 16:18:22	2020-07-26	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15350	delivery	5	45
104342	2020-07-26 16:18:27	2020-07-26	14	[{"id_menu":2,"count":1}]	37095	pick-up	0	14
104343	2020-07-26 16:21:47	2020-07-26	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40081	delivery	5	31
104344	2020-07-26 16:24:17	2020-07-26	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	40148	delivery	5	45
104345	2020-07-26 16:26:39	2020-07-26	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	37261	delivery	5	36
104346	2020-07-26 16:27:23	2020-07-26	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	453	delivery	5	36
104347	2020-07-26 16:27:54	2020-07-26	14	[{"id_menu":2,"count":1}]	39920	delivery	5	19
104348	2020-07-26 16:28:36	2020-07-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	38441	delivery	5	23
104349	2020-07-26 16:29:31	2020-07-26	9	[{"id_menu":7,"count":1}]	2133	pick-up	0	9
104350	2020-07-26 16:30:13	2020-07-26	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	7189	pick-up	0	35
104351	2020-07-26 16:32:09	2020-07-26	38	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14984	delivery	5	43
104352	2020-07-26 16:32:32	2020-07-26	9	[{"id_menu":6,"count":2}]	40144	delivery	5	14
104353	2020-07-26 16:32:42	2020-07-26	17	[{"id_menu":4,"count":1}]	40101	delivery	5	22
104354	2020-07-26 16:34:19	2020-07-26	17	[{"id_menu":4,"count":1}]	18320	delivery	5	22
104355	2020-07-26 16:35:19	2020-07-26	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	28074	pick-up	0	26
104356	2020-07-26 16:35:52	2020-07-26	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3444	pick-up	0	26
104357	2020-07-26 16:37:54	2020-07-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	24306	pick-up	0	21
104358	2020-07-26 16:38:38	2020-07-26	12	[{"id_menu":3,"count":1}]	39967	delivery	5	17
104359	2020-07-26 16:38:48	2020-07-26	14	[{"id_menu":2,"count":1}]	39979	delivery	5	19
104360	2020-07-26 16:41:04	2020-07-26	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	10537	pick-up	0	26
104361	2020-07-26 16:43:08	2020-07-26	17	[{"id_menu":4,"count":1}]	29249	delivery	5	22
104362	2020-07-26 16:48:33	2020-07-26	9	[{"id_menu":7,"count":1}]	22490	pick-up	0	9
104363	2020-07-26 16:49:23	2020-07-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	40151	delivery	5	22
104364	2020-07-26 16:54:03	2020-07-26	12	[{"id_menu":1,"count":1}]	30081	delivery	5	17
104365	2020-07-26 16:55:20	2020-07-26	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	40008	delivery	5	48
104366	2020-07-26 16:55:37	2020-07-26	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18475	delivery	5	34
104367	2020-07-26 16:56:16	2020-07-26	12	[{"id_menu":1,"count":3}]	22008	delivery	5	17
104368	2020-07-26 16:56:27	2020-07-26	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	20555	delivery	5	45
104369	2020-07-26 16:56:39	2020-07-26	12	[{"id_menu":3,"count":1}]	40130	delivery	5	17
104370	2020-07-26 16:58:07	2020-07-26	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	13	pick-up	0	21
104371	2020-07-26 16:58:07	2020-07-26	14	[{"id_menu":2,"count":1}]	39854	pick-up	0	14
104372	2020-07-26 16:59:16	2020-07-26	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39919	delivery	5	36
104373	2020-07-26 16:59:19	2020-07-26	9	[{"id_menu":6,"count":1}]	40048	delivery	5	14
104374	2020-07-26 16:59:43	2020-07-26	8	[{"id_menu":5,"count":1}]	6524	delivery	5	13
104375	2020-07-26 17:00:14	2020-07-26	9	[{"id_menu":6,"count":1}]	9372	delivery	5	14
104376	2020-07-26 17:00:20	2020-07-26	8	[{"id_menu":5,"count":2}]	13258	delivery	5	13
104442	2020-07-26 18:17:07	2020-07-26	8	[{"id_menu":5,"count":1}]	40052	delivery	5	13
104377	2020-07-26 17:00:34	2020-07-26	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	40104	delivery	5	40
104378	2020-07-26 17:02:33	2020-07-26	14	[{"id_menu":2,"count":1}]	39945	delivery	5	19
104379	2020-07-26 17:02:47	2020-07-26	17	[{"id_menu":4,"count":1}]	4812	pick-up	0	17
104380	2020-07-26 17:03:52	2020-07-26	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	173	pick-up	0	22
104381	2020-07-26 17:04:19	2020-07-26	9	[{"id_menu":6,"count":1}]	38551	delivery	5	14
104382	2020-07-26 17:04:46	2020-07-26	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25879	delivery	5	51
104383	2020-07-26 17:05:00	2020-07-26	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	18597	delivery	5	26
104384	2020-07-26 17:05:35	2020-07-26	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	39957	delivery	5	31
104385	2020-07-26 17:05:57	2020-07-26	9	[{"id_menu":7,"count":1}]	19790	delivery	5	14
104386	2020-07-26 17:06:04	2020-07-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	22850	delivery	5	26
104387	2020-07-26 17:06:13	2020-07-26	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	29560	delivery	5	39
104388	2020-07-26 17:06:28	2020-07-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	22788	delivery	5	28
104389	2020-07-26 17:07:24	2020-07-26	9	[{"id_menu":6,"count":1}]	2027	delivery	5	14
104390	2020-07-26 17:07:44	2020-07-26	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	3399	pick-up	0	22
104391	2020-07-26 17:09:09	2020-07-26	14	[{"id_menu":2,"count":2}]	9001	delivery	5	19
104392	2020-07-26 17:09:22	2020-07-26	9	[{"id_menu":7,"count":3}]	40009	delivery	5	14
104393	2020-07-26 17:10:16	2020-07-26	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	22081	delivery	5	40
104394	2020-07-26 17:10:48	2020-07-26	9	[{"id_menu":6,"count":1}]	40099	delivery	5	14
104395	2020-07-26 17:12:03	2020-07-26	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	40035	delivery	5	39
104396	2020-07-26 17:21:46	2020-07-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7718	pick-up	0	23
104397	2020-07-26 17:22:05	2020-07-26	9	[{"id_menu":7,"count":1}]	37167	delivery	5	14
104398	2020-07-26 17:22:38	2020-07-26	12	[{"id_menu":1,"count":1}]	27545	delivery	5	17
104399	2020-07-26 17:24:35	2020-07-26	14	[{"id_menu":2,"count":1}]	40033	delivery	5	19
104400	2020-07-26 17:25:54	2020-07-26	9	[{"id_menu":6,"count":1}]	40155	pick-up	0	9
104401	2020-07-26 17:28:07	2020-07-26	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	40066	delivery	5	30
104402	2020-07-26 17:28:10	2020-07-26	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40112	delivery	5	40
104403	2020-07-26 17:30:13	2020-07-26	14	[{"id_menu":2,"count":1}]	13758	delivery	5	19
104404	2020-07-26 17:31:19	2020-07-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13296	delivery	5	22
104405	2020-07-26 17:31:55	2020-07-26	9	[{"id_menu":6,"count":1}]	11470	pick-up	0	9
104406	2020-07-26 17:34:56	2020-07-26	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	10180	delivery	5	27
104407	2020-07-26 17:38:28	2020-07-26	9	[{"id_menu":7,"count":1}]	10018	delivery	5	14
104408	2020-07-26 17:39:10	2020-07-26	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	40013	delivery	5	26
104409	2020-07-26 17:42:45	2020-07-26	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	35184	delivery	5	43
104410	2020-07-26 17:43:43	2020-07-26	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40001	delivery	5	31
104411	2020-07-26 17:43:54	2020-07-26	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	3307	pick-up	0	24
104412	2020-07-26 17:45:08	2020-07-26	12	[{"id_menu":1,"count":1}]	23997	pick-up	0	12
104413	2020-07-26 17:46:09	2020-07-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	23084	pick-up	0	26
104414	2020-07-26 17:46:29	2020-07-26	9	[{"id_menu":6,"count":1}]	40185	delivery	5	14
104415	2020-07-26 17:48:22	2020-07-26	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	39973	delivery	5	27
104416	2020-07-26 17:48:40	2020-07-26	9	[{"id_menu":7,"count":1}]	16677	pick-up	0	9
104417	2020-07-26 17:49:23	2020-07-26	17	[{"id_menu":4,"count":1}]	22437	delivery	5	22
104418	2020-07-26 17:51:04	2020-07-26	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	10717	pick-up	0	21
104419	2020-07-26 17:51:20	2020-07-26	9	[{"id_menu":6,"count":1}]	6193	delivery	5	14
104420	2020-07-26 17:51:48	2020-07-26	17	[{"id_menu":4,"count":1}]	23400	delivery	5	22
104421	2020-07-26 17:52:57	2020-07-26	12	[{"id_menu":3,"count":1}]	2519	delivery	5	17
104422	2020-07-26 17:53:13	2020-07-26	17	[{"id_menu":4,"count":1}]	40131	delivery	5	22
104423	2020-07-26 17:53:16	2020-07-26	9	[{"id_menu":6,"count":2}]	24884	delivery	5	14
104424	2020-07-26 17:54:19	2020-07-26	9	[{"id_menu":6,"count":1}]	13837	delivery	5	14
104425	2020-07-26 17:55:25	2020-07-26	8	[{"id_menu":5,"count":1}]	1715	pick-up	0	8
104426	2020-07-26 17:58:42	2020-07-26	14	[{"id_menu":2,"count":1}]	27575	delivery	5	19
104427	2020-07-26 18:01:08	2020-07-26	14	[{"id_menu":2,"count":1}]	1571	delivery	5	19
104428	2020-07-26 18:02:14	2020-07-26	14	[{"id_menu":2,"count":1}]	24872	pick-up	0	14
104429	2020-07-26 18:02:55	2020-07-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	14092	delivery	5	26
104430	2020-07-26 18:05:22	2020-07-26	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6247	pick-up	0	29
104431	2020-07-26 18:05:57	2020-07-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15031	delivery	5	23
104432	2020-07-26 18:06:52	2020-07-26	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	9322	delivery	5	48
104433	2020-07-26 18:08:13	2020-07-26	9	[{"id_menu":6,"count":1}]	40015	pick-up	0	9
104434	2020-07-26 18:08:58	2020-07-26	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	32379	delivery	5	34
104435	2020-07-26 18:09:13	2020-07-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	11751	pick-up	0	23
104436	2020-07-26 18:09:56	2020-07-26	9	[{"id_menu":7,"count":1}]	27111	delivery	5	14
104437	2020-07-26 18:10:14	2020-07-26	9	[{"id_menu":7,"count":1}]	11979	delivery	5	14
104438	2020-07-26 18:11:31	2020-07-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	811	pick-up	0	23
104439	2020-07-26 18:12:07	2020-07-26	12	[{"id_menu":1,"count":1}]	10740	delivery	5	17
104440	2020-07-26 18:15:30	2020-07-26	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	12894	delivery	5	31
104441	2020-07-26 18:16:30	2020-07-26	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	40060	delivery	5	34
104443	2020-07-26 18:19:30	2020-07-26	8	[{"id_menu":5,"count":1}]	610	delivery	5	13
104444	2020-07-26 18:22:06	2020-07-26	9	[{"id_menu":6,"count":1}]	33895	delivery	5	14
104445	2020-07-26 18:22:22	2020-07-26	9	[{"id_menu":7,"count":1}]	33416	delivery	5	14
104446	2020-07-26 18:22:53	2020-07-26	9	[{"id_menu":6,"count":1}]	39977	delivery	5	14
104447	2020-07-26 18:23:44	2020-07-26	12	[{"id_menu":1,"count":1}]	7344	delivery	5	17
104448	2020-07-26 18:24:52	2020-07-26	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15889	delivery	5	36
104449	2020-07-26 18:25:38	2020-07-26	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	6400	delivery	5	23
104450	2020-07-26 18:27:13	2020-07-26	9	[{"id_menu":6,"count":1}]	2933	pick-up	0	9
104451	2020-07-26 18:32:44	2020-07-26	9	[{"id_menu":6,"count":1}]	12697	delivery	5	14
104452	2020-07-26 18:32:59	2020-07-26	9	[{"id_menu":7,"count":1}]	40145	delivery	5	14
104453	2020-07-26 18:33:52	2020-07-26	14	[{"id_menu":2,"count":1}]	24102	delivery	5	19
104454	2020-07-26 18:34:17	2020-07-26	12	[{"id_menu":1,"count":1}]	10727	pick-up	0	12
104455	2020-07-26 18:34:25	2020-07-26	12	[{"id_menu":3,"count":1}]	30580	delivery	5	17
104456	2020-07-26 18:34:56	2020-07-26	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	40161	delivery	5	34
104457	2020-07-26 18:38:34	2020-07-26	12	[{"id_menu":1,"count":1}]	40034	delivery	5	17
104458	2020-07-26 18:43:15	2020-07-26	9	[{"id_menu":6,"count":1}]	39990	delivery	5	14
104459	2020-07-26 18:43:37	2020-07-26	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	39968	delivery	5	39
104460	2020-07-26 18:45:04	2020-07-26	9	[{"id_menu":7,"count":2}]	40055	delivery	5	14
104461	2020-07-26 18:46:17	2020-07-26	9	[{"id_menu":6,"count":1}]	2735	pick-up	0	9
104462	2020-07-26 18:46:53	2020-07-26	9	[{"id_menu":6,"count":1}]	28610	delivery	5	14
104463	2020-07-26 18:47:49	2020-07-26	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	10339	delivery	5	40
104464	2020-07-26 18:49:28	2020-07-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	13272	delivery	5	28
104465	2020-07-26 18:50:25	2020-07-26	9	[{"id_menu":7,"count":1}]	39999	delivery	5	14
104466	2020-07-26 18:54:06	2020-07-26	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	23080	delivery	5	31
104467	2020-07-26 18:54:20	2020-07-26	9	[{"id_menu":6,"count":1}]	6920	delivery	5	14
104468	2020-07-26 18:54:26	2020-07-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	38468	pick-up	0	23
104469	2020-07-26 18:56:46	2020-07-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18123	delivery	5	22
104470	2020-07-26 18:57:49	2020-07-26	14	[{"id_menu":2,"count":1}]	2891	pick-up	0	14
104471	2020-07-26 18:58:05	2020-07-26	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	7206	pick-up	0	38
104472	2020-07-26 18:58:50	2020-07-26	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	24034	delivery	5	31
104473	2020-07-26 18:59:17	2020-07-26	9	[{"id_menu":6,"count":1}]	40023	delivery	5	14
104474	2020-07-26 18:59:23	2020-07-26	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2924	delivery	5	45
104475	2020-07-26 18:59:56	2020-07-26	17	[{"id_menu":4,"count":2}]	30469	pick-up	0	17
104476	2020-07-26 19:00:49	2020-07-26	9	[{"id_menu":6,"count":1}]	7851	delivery	5	14
104477	2020-07-26 19:01:11	2020-07-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	35726	delivery	5	26
104478	2020-07-26 19:01:33	2020-07-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5707	delivery	5	28
104479	2020-07-26 19:04:10	2020-07-26	8	[{"id_menu":5,"count":1}]	24385	delivery	5	13
104480	2020-07-26 19:04:17	2020-07-26	14	[{"id_menu":2,"count":1}]	40054	pick-up	0	14
104481	2020-07-26 19:05:43	2020-07-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	27703	delivery	5	28
104482	2020-07-26 19:06:33	2020-07-26	9	[{"id_menu":7,"count":1}]	6683	delivery	5	14
104483	2020-07-26 19:07:37	2020-07-26	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	74	pick-up	0	26
104484	2020-07-26 19:10:45	2020-07-26	8	[{"id_menu":5,"count":1}]	19249	delivery	5	13
104485	2020-07-26 19:10:58	2020-07-26	9	[{"id_menu":7,"count":1}]	7772	pick-up	0	9
104486	2020-07-26 19:11:05	2020-07-26	9	[{"id_menu":6,"count":1}]	39951	delivery	5	14
104487	2020-07-26 19:12:10	2020-07-26	12	[{"id_menu":1,"count":1}]	40079	delivery	5	17
104488	2020-07-26 19:16:30	2020-07-26	9	[{"id_menu":6,"count":1}]	12474	delivery	5	14
104489	2020-07-26 19:16:52	2020-07-26	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13875	delivery	5	31
104490	2020-07-26 19:17:11	2020-07-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	31185	delivery	5	28
104491	2020-07-26 19:18:09	2020-07-26	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	3677	delivery	5	34
104492	2020-07-26 19:20:38	2020-07-26	12	[{"id_menu":1,"count":1}]	39980	delivery	5	17
104493	2020-07-26 19:25:37	2020-07-26	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	13287	delivery	5	30
104494	2020-07-26 19:28:33	2020-07-26	9	[{"id_menu":7,"count":1}]	5634	delivery	5	14
104495	2020-07-26 19:32:28	2020-07-26	17	[{"id_menu":4,"count":1}]	3520	delivery	5	22
104496	2020-07-26 19:35:03	2020-07-26	8	[{"id_menu":5,"count":2}]	40164	delivery	5	13
104497	2020-07-26 19:35:25	2020-07-26	12	[{"id_menu":3,"count":1}]	31593	delivery	5	17
104498	2020-07-26 19:36:23	2020-07-26	9	[{"id_menu":7,"count":2}]	29023	delivery	5	14
104499	2020-07-26 19:36:55	2020-07-26	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	39924	delivery	5	26
104500	2020-07-26 19:37:11	2020-07-26	17	[{"id_menu":4,"count":1}]	22985	pick-up	0	17
104501	2020-07-26 19:37:41	2020-07-26	9	[{"id_menu":7,"count":1}]	36587	delivery	5	14
104502	2020-07-26 19:40:00	2020-07-26	17	[{"id_menu":4,"count":1}]	2140	delivery	5	22
104503	2020-07-26 19:40:35	2020-07-26	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	39949	delivery	5	27
104504	2020-07-26 19:43:32	2020-07-26	9	[{"id_menu":7,"count":1}]	40094	delivery	5	14
104505	2020-07-26 19:44:38	2020-07-26	12	[{"id_menu":1,"count":1}]	38760	delivery	5	17
104506	2020-07-26 19:44:56	2020-07-26	12	[{"id_menu":1,"count":1}]	2081	delivery	5	17
104507	2020-07-26 19:45:09	2020-07-26	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	31363	delivery	5	40
104508	2020-07-26 19:48:26	2020-07-26	9	[{"id_menu":6,"count":1}]	19442	delivery	5	14
104509	2020-07-26 19:49:17	2020-07-26	9	[{"id_menu":6,"count":1}]	5642	delivery	5	14
104510	2020-07-26 19:52:29	2020-07-26	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	17469	delivery	5	31
104511	2020-07-26 19:52:57	2020-07-26	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23897	delivery	5	48
104512	2020-07-26 19:53:34	2020-07-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39969	delivery	5	22
104513	2020-07-26 19:53:37	2020-07-26	9	[{"id_menu":6,"count":1}]	39963	delivery	5	14
104514	2020-07-26 19:56:17	2020-07-26	12	[{"id_menu":1,"count":1}]	39965	delivery	5	17
104515	2020-07-26 19:57:10	2020-07-26	14	[{"id_menu":2,"count":1}]	3755	pick-up	0	14
104516	2020-07-26 19:57:13	2020-07-26	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9728	pick-up	0	38
104517	2020-07-26 19:57:20	2020-07-26	9	[{"id_menu":6,"count":1}]	38713	delivery	5	14
104518	2020-07-26 19:58:07	2020-07-26	12	[{"id_menu":3,"count":1}]	37070	pick-up	0	12
104519	2020-07-26 19:59:35	2020-07-26	9	[{"id_menu":7,"count":1}]	14202	delivery	5	14
104520	2020-07-26 20:00:20	2020-07-26	14	[{"id_menu":2,"count":1}]	39976	delivery	5	19
104521	2020-07-26 20:03:23	2020-07-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39962	delivery	5	23
104522	2020-07-26 20:10:01	2020-07-26	14	[{"id_menu":2,"count":1}]	15474	delivery	5	19
104523	2020-07-26 20:10:19	2020-07-26	14	[{"id_menu":2,"count":1}]	39465	pick-up	0	14
104524	2020-07-26 20:10:36	2020-07-26	17	[{"id_menu":4,"count":1}]	7431	delivery	5	22
104525	2020-07-26 20:10:46	2020-07-26	9	[{"id_menu":6,"count":1}]	33998	delivery	5	14
104526	2020-07-26 20:12:09	2020-07-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	10281	pick-up	0	23
104527	2020-07-26 20:12:30	2020-07-26	9	[{"id_menu":7,"count":1}]	2189	delivery	5	14
104528	2020-07-26 20:13:47	2020-07-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	22257	delivery	5	31
104529	2020-07-26 20:16:03	2020-07-26	17	[{"id_menu":4,"count":1}]	3337	delivery	5	22
104530	2020-07-26 20:16:31	2020-07-26	12	[{"id_menu":1,"count":1}]	29114	delivery	5	17
104531	2020-07-26 20:16:36	2020-07-26	12	[{"id_menu":1,"count":1}]	40163	delivery	5	17
104532	2020-07-26 20:16:46	2020-07-26	9	[{"id_menu":6,"count":1}]	15954	delivery	5	14
104533	2020-07-26 20:19:08	2020-07-26	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	20595	pick-up	0	31
104534	2020-07-26 20:19:13	2020-07-26	12	[{"id_menu":3,"count":1}]	30209	delivery	5	17
104535	2020-07-26 20:19:33	2020-07-26	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	25580	pick-up	0	18
104536	2020-07-26 20:20:30	2020-07-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17875	delivery	5	31
104537	2020-07-26 20:21:56	2020-07-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	9125	delivery	5	26
104538	2020-07-26 20:23:56	2020-07-26	17	[{"id_menu":4,"count":1}]	11192	delivery	5	22
104539	2020-07-26 20:24:42	2020-07-26	9	[{"id_menu":6,"count":1}]	40000	delivery	5	14
104540	2020-07-26 20:25:26	2020-07-26	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11961	delivery	5	36
104541	2020-07-26 20:25:31	2020-07-26	9	[{"id_menu":6,"count":1}]	16604	delivery	5	14
104542	2020-07-26 20:25:36	2020-07-26	14	[{"id_menu":2,"count":1}]	25907	delivery	5	19
104543	2020-07-26 20:26:29	2020-07-26	9	[{"id_menu":7,"count":1}]	39955	delivery	5	14
104544	2020-07-26 20:29:05	2020-07-26	12	[{"id_menu":1,"count":1}]	20457	delivery	5	17
104545	2020-07-26 20:30:14	2020-07-26	14	[{"id_menu":2,"count":1}]	15357	delivery	5	19
104546	2020-07-26 20:32:20	2020-07-26	14	[{"id_menu":2,"count":1}]	30260	delivery	5	19
104547	2020-07-26 20:33:46	2020-07-26	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22373	delivery	5	47
104548	2020-07-26 20:34:42	2020-07-26	9	[{"id_menu":6,"count":2}]	3790	pick-up	0	9
104549	2020-07-26 20:36:23	2020-07-26	14	[{"id_menu":2,"count":1}]	33831	delivery	5	19
104550	2020-07-26 20:37:40	2020-07-26	9	[{"id_menu":7,"count":1}]	15831	delivery	5	14
104551	2020-07-26 20:37:52	2020-07-26	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	31900	delivery	5	26
104552	2020-07-26 20:38:46	2020-07-26	14	[{"id_menu":2,"count":1}]	1172	pick-up	0	14
104553	2020-07-26 20:39:08	2020-07-26	14	[{"id_menu":2,"count":1}]	6385	pick-up	0	14
104554	2020-07-26 20:41:06	2020-07-26	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	40110	delivery	5	26
104555	2020-07-26 20:41:08	2020-07-26	9	[{"id_menu":7,"count":1}]	40041	delivery	5	14
104556	2020-07-26 20:41:25	2020-07-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	25202	delivery	5	28
104557	2020-07-26 20:45:08	2020-07-26	12	[{"id_menu":3,"count":1}]	8783	delivery	5	17
104558	2020-07-26 20:45:43	2020-07-26	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33619	delivery	5	35
104559	2020-07-26 20:52:34	2020-07-26	9	[{"id_menu":7,"count":1}]	20687	delivery	5	14
104560	2020-07-26 20:58:12	2020-07-26	17	[{"id_menu":4,"count":1}]	14063	delivery	5	22
104561	2020-07-26 20:59:34	2020-07-26	9	[{"id_menu":6,"count":2}]	39941	delivery	5	14
104562	2020-07-26 21:00:31	2020-07-26	9	[{"id_menu":6,"count":1}]	19523	pick-up	0	9
104563	2020-07-26 21:03:07	2020-07-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	35595	delivery	5	22
104564	2020-07-26 21:06:30	2020-07-26	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	21612	pick-up	0	29
104565	2020-07-26 21:06:51	2020-07-26	9	[{"id_menu":6,"count":1}]	40208	delivery	5	14
104566	2020-07-26 21:09:14	2020-07-26	17	[{"id_menu":4,"count":1}]	19434	delivery	5	22
104567	2020-07-26 21:10:59	2020-07-26	17	[{"id_menu":4,"count":1}]	11262	delivery	5	22
104568	2020-07-26 21:16:18	2020-07-26	12	[{"id_menu":3,"count":1}]	40074	delivery	5	17
104569	2020-07-26 21:16:31	2020-07-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2874	pick-up	0	21
104570	2020-07-26 21:21:43	2020-07-26	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	31210	delivery	5	31
104571	2020-07-26 21:22:09	2020-07-26	14	[{"id_menu":2,"count":1}]	32732	delivery	5	19
104572	2020-07-26 21:22:46	2020-07-26	9	[{"id_menu":6,"count":1}]	1306	pick-up	0	9
104573	2020-07-26 21:25:57	2020-07-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39974	delivery	5	23
104574	2020-07-26 21:27:04	2020-07-26	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11417	delivery	5	40
104575	2020-07-26 21:27:34	2020-07-26	9	[{"id_menu":7,"count":1}]	35115	delivery	5	14
104576	2020-07-26 21:28:23	2020-07-26	17	[{"id_menu":4,"count":1}]	33100	pick-up	0	17
104577	2020-07-26 21:28:34	2020-07-26	14	[{"id_menu":2,"count":1}]	17054	delivery	5	19
104578	2020-07-26 21:30:14	2020-07-26	14	[{"id_menu":2,"count":1}]	39119	delivery	5	19
104579	2020-07-26 21:33:11	2020-07-26	14	[{"id_menu":2,"count":2}]	39939	delivery	5	19
104580	2020-07-26 21:33:14	2020-07-26	12	[{"id_menu":1,"count":1}]	23942	delivery	5	17
104581	2020-07-26 21:33:30	2020-07-26	12	[{"id_menu":3,"count":1}]	1076	pick-up	0	12
104582	2020-07-26 21:33:30	2020-07-26	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	40051	delivery	5	40
104583	2020-07-26 21:34:47	2020-07-26	12	[{"id_menu":1,"count":1}]	39983	delivery	5	17
104584	2020-07-26 21:34:55	2020-07-26	12	[{"id_menu":1,"count":1}]	40162	delivery	5	17
104585	2020-07-26 21:36:59	2020-07-26	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	40069	delivery	5	38
104586	2020-07-26 21:38:28	2020-07-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20193	delivery	5	22
104587	2020-07-26 21:39:58	2020-07-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6882	delivery	5	22
104588	2020-07-26 21:49:26	2020-07-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39936	delivery	5	22
104589	2020-07-26 21:52:00	2020-07-26	17	[{"id_menu":4,"count":1}]	96	delivery	5	22
104590	2020-07-26 21:58:30	2020-07-26	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	19371	delivery	5	25
104591	2020-07-26 21:58:40	2020-07-26	9	[{"id_menu":7,"count":1}]	40200	delivery	5	14
104592	2020-07-26 21:59:39	2020-07-26	17	[{"id_menu":4,"count":1}]	35648	delivery	5	22
104593	2020-07-26 22:05:20	2020-07-26	8	[{"id_menu":5,"count":1}]	1723	pick-up	0	8
104594	2020-07-26 22:06:14	2020-07-26	17	[{"id_menu":4,"count":1}]	30687	pick-up	0	17
104595	2020-07-26 22:06:23	2020-07-26	8	[{"id_menu":5,"count":1}]	36322	delivery	5	13
104596	2020-07-26 22:07:01	2020-07-26	8	[{"id_menu":5,"count":1}]	19349	delivery	5	13
104597	2020-07-26 22:07:10	2020-07-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":3}]	30582	delivery	5	28
104598	2020-07-26 22:08:31	2020-07-26	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	27388	delivery	5	40
104599	2020-07-26 22:08:56	2020-07-26	9	[{"id_menu":6,"count":1}]	3322	pick-up	0	9
104600	2020-07-26 22:11:06	2020-07-26	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	17691	delivery	5	31
104601	2020-07-26 22:11:29	2020-07-26	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	40025	delivery	5	46
104602	2020-07-26 22:11:44	2020-07-26	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	16924	delivery	5	31
104603	2020-07-26 22:12:30	2020-07-26	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":2}]	12231	delivery	5	28
104604	2020-07-26 22:12:35	2020-07-26	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	11130	delivery	5	25
104605	2020-07-26 22:13:17	2020-07-26	14	[{"id_menu":2,"count":1}]	40092	pick-up	0	14
104606	2020-07-26 22:13:20	2020-07-26	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13529	pick-up	0	35
104607	2020-07-26 22:13:35	2020-07-26	14	[{"id_menu":2,"count":1}]	39950	delivery	5	19
104608	2020-07-26 22:14:01	2020-07-26	17	[{"id_menu":4,"count":1}]	24195	delivery	5	22
104609	2020-07-26 22:14:09	2020-07-26	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14868	delivery	5	34
104610	2020-07-26 22:14:36	2020-07-26	8	[{"id_menu":5,"count":1}]	40076	delivery	5	13
104611	2020-07-26 22:14:44	2020-07-26	17	[{"id_menu":4,"count":1}]	39108	delivery	5	22
104612	2020-07-26 22:15:49	2020-07-26	14	[{"id_menu":2,"count":1}]	11844	delivery	5	19
104613	2020-07-26 22:18:13	2020-07-26	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	40113	delivery	5	26
104614	2020-07-26 22:20:58	2020-07-26	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	16967	pick-up	0	26
104615	2020-07-26 22:22:40	2020-07-26	12	[{"id_menu":3,"count":1}]	29233	delivery	5	17
104616	2020-07-26 22:23:27	2020-07-26	9	[{"id_menu":7,"count":1}]	40091	delivery	5	14
104617	2020-07-26 22:24:52	2020-07-26	9	[{"id_menu":7,"count":1}]	40037	delivery	5	14
104618	2020-07-26 22:27:36	2020-07-26	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24211	delivery	5	31
104619	2020-07-26 22:28:03	2020-07-26	9	[{"id_menu":7,"count":1}]	2919	delivery	5	14
104620	2020-07-26 22:28:42	2020-07-26	17	[{"id_menu":4,"count":1}]	13357	delivery	5	22
104621	2020-07-26 22:28:56	2020-07-26	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	27236	delivery	5	23
104622	2020-07-26 22:29:37	2020-07-26	14	[{"id_menu":2,"count":1}]	33698	pick-up	0	14
104623	2020-07-26 22:30:30	2020-07-26	12	[{"id_menu":1,"count":1}]	23510	delivery	5	17
104624	2020-07-26 22:32:24	2020-07-26	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	40029	delivery	5	36
104625	2020-07-26 22:32:32	2020-07-26	17	[{"id_menu":4,"count":1}]	2672	pick-up	0	17
104626	2020-07-26 22:34:00	2020-07-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9198	pick-up	0	17
104627	2020-07-26 22:36:35	2020-07-26	9	[{"id_menu":6,"count":1}]	40098	delivery	5	14
104628	2020-07-26 22:38:12	2020-07-26	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2546	pick-up	0	26
104629	2020-07-26 22:38:49	2020-07-26	9	[{"id_menu":6,"count":1}]	12786	delivery	5	14
104630	2020-07-26 22:40:25	2020-07-26	17	[{"id_menu":4,"count":1}]	40118	delivery	5	22
104631	2020-07-26 22:40:53	2020-07-26	14	[{"id_menu":2,"count":1}]	39978	delivery	5	19
104632	2020-07-26 22:41:22	2020-07-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32945	delivery	5	22
104633	2020-07-26 22:44:26	2020-07-26	12	[{"id_menu":1,"count":1}]	26075	delivery	5	17
104634	2020-07-26 22:45:55	2020-07-26	8	[{"id_menu":5,"count":1}]	34705	delivery	5	13
104635	2020-07-26 22:46:07	2020-07-26	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10876	delivery	5	44
104636	2020-07-26 22:47:46	2020-07-26	9	[{"id_menu":7,"count":1}]	33462	delivery	5	14
104637	2020-07-26 22:47:50	2020-07-26	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	32941	delivery	5	38
104638	2020-07-26 22:48:33	2020-07-26	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8730	pick-up	0	40
104639	2020-07-26 22:48:37	2020-07-26	12	[{"id_menu":1,"count":1}]	39916	delivery	5	17
104640	2020-07-26 22:49:46	2020-07-26	14	[{"id_menu":2,"count":1}]	40197	pick-up	0	14
104641	2020-07-26 22:50:01	2020-07-26	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	39970	delivery	5	31
104642	2020-07-26 22:50:18	2020-07-26	9	[{"id_menu":6,"count":1}]	10566	delivery	5	14
104643	2020-07-26 22:53:07	2020-07-26	9	[{"id_menu":6,"count":1}]	39776	delivery	5	14
104644	2020-07-26 22:53:50	2020-07-26	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20196	delivery	5	37
104645	2020-07-26 22:57:37	2020-07-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	39996	pick-up	0	23
104646	2020-07-26 22:58:38	2020-07-26	9	[{"id_menu":6,"count":1}]	5193	delivery	5	14
104647	2020-07-26 22:59:22	2020-07-26	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	16181	delivery	5	37
104648	2020-07-26 23:00:10	2020-07-26	9	[{"id_menu":6,"count":1}]	40045	delivery	5	14
104649	2020-07-26 23:02:48	2020-07-26	12	[{"id_menu":1,"count":1}]	4054	delivery	5	17
104650	2020-07-26 23:03:24	2020-07-26	9	[{"id_menu":6,"count":1}]	30648	pick-up	0	9
104651	2020-07-26 23:03:38	2020-07-26	9	[{"id_menu":6,"count":1}]	40061	delivery	5	14
104652	2020-07-26 23:03:58	2020-07-26	9	[{"id_menu":6,"count":1}]	24591	delivery	5	14
104653	2020-07-26 23:04:00	2020-07-26	9	[{"id_menu":7,"count":1}]	13858	pick-up	0	9
104654	2020-07-26 23:05:43	2020-07-26	8	[{"id_menu":5,"count":1}]	37460	pick-up	0	8
104655	2020-07-26 23:06:05	2020-07-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	25038	delivery	5	28
104656	2020-07-26 23:10:16	2020-07-26	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	39929	delivery	5	31
104657	2020-07-26 23:11:07	2020-07-26	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":2}]	12403	delivery	5	22
104658	2020-07-26 23:16:09	2020-07-26	9	[{"id_menu":6,"count":1}]	40012	delivery	5	14
104659	2020-07-26 23:19:16	2020-07-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	40047	delivery	5	28
104660	2020-07-26 23:21:14	2020-07-26	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	40168	delivery	5	31
104661	2020-07-26 23:22:02	2020-07-26	12	[{"id_menu":1,"count":1}]	40028	delivery	5	17
104662	2020-07-26 23:23:15	2020-07-26	9	[{"id_menu":6,"count":1}]	1810	pick-up	0	9
104663	2020-07-26 23:24:52	2020-07-26	8	[{"id_menu":5,"count":1}]	40210	delivery	5	13
104664	2020-07-26 23:26:48	2020-07-26	12	[{"id_menu":1,"count":1}]	34012	delivery	5	17
104665	2020-07-26 23:27:39	2020-07-26	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	40150	delivery	5	52
104666	2020-07-26 23:28:09	2020-07-26	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	11239	pick-up	0	26
104667	2020-07-26 23:29:44	2020-07-26	9	[{"id_menu":7,"count":1}]	39174	delivery	5	14
104668	2020-07-26 23:29:57	2020-07-26	14	[{"id_menu":2,"count":1}]	3688	delivery	5	19
104669	2020-07-26 23:30:31	2020-07-26	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40169	delivery	5	45
104670	2020-07-26 23:32:36	2020-07-26	8	[{"id_menu":5,"count":1}]	10142	delivery	5	13
104671	2020-07-26 23:33:58	2020-07-26	17	[{"id_menu":4,"count":1}]	3361	pick-up	0	17
104672	2020-07-26 23:35:45	2020-07-26	8	[{"id_menu":5,"count":2}]	36216	delivery	5	13
104673	2020-07-26 23:37:29	2020-07-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	37917	delivery	5	26
104674	2020-07-26 23:40:09	2020-07-26	17	[{"id_menu":4,"count":1}]	40030	delivery	5	22
104675	2020-07-26 23:40:25	2020-07-26	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	40179	delivery	5	34
104676	2020-07-26 23:40:49	2020-07-26	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32082	delivery	5	35
104677	2020-07-26 23:42:29	2020-07-26	17	[{"id_menu":4,"count":1}]	5461	delivery	5	22
104678	2020-07-26 23:44:41	2020-07-26	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	35831	delivery	5	38
104679	2020-07-26 23:46:28	2020-07-26	12	[{"id_menu":3,"count":1}]	40082	delivery	5	17
104680	2020-07-26 23:48:18	2020-07-26	17	[{"id_menu":4,"count":1}]	37089	delivery	5	22
104681	2020-07-26 23:49:02	2020-07-26	9	[{"id_menu":7,"count":1}]	33840	delivery	5	14
104682	2020-07-26 23:49:04	2020-07-26	9	[{"id_menu":7,"count":1}]	40206	pick-up	0	9
104683	2020-07-26 23:49:18	2020-07-26	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	37713	delivery	5	26
104684	2020-07-26 23:50:51	2020-07-26	14	[{"id_menu":2,"count":1}]	6742	delivery	5	19
104685	2020-07-26 23:51:16	2020-07-26	8	[{"id_menu":5,"count":1}]	32939	pick-up	0	8
104686	2020-07-26 23:52:13	2020-07-26	9	[{"id_menu":7,"count":1}]	37838	delivery	5	14
104687	2020-07-26 23:53:18	2020-07-26	14	[{"id_menu":2,"count":1}]	39948	delivery	5	19
104688	2020-07-26 23:54:10	2020-07-26	14	[{"id_menu":2,"count":1}]	295	pick-up	0	14
104689	2020-07-26 23:55:33	2020-07-26	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21728	delivery	5	54
104690	2020-07-26 23:57:22	2020-07-26	17	[{"id_menu":4,"count":1}]	40176	delivery	5	22
104691	2020-07-27 00:01:49	2020-07-27	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	22185	delivery	5	25
104692	2020-07-27 00:05:05	2020-07-27	9	[{"id_menu":7,"count":1}]	6662	pick-up	0	9
104693	2020-07-27 00:12:31	2020-07-27	9	[{"id_menu":6,"count":1}]	40447	delivery	5	14
104694	2020-07-27 00:25:06	2020-07-27	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	10187	delivery	5	26
104695	2020-07-27 00:25:51	2020-07-27	8	[{"id_menu":5,"count":1}]	36913	delivery	5	13
104696	2020-07-27 00:26:09	2020-07-27	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	24611	delivery	5	27
104697	2020-07-27 00:28:07	2020-07-27	9	[{"id_menu":6,"count":1}]	40398	delivery	5	14
104698	2020-07-27 00:28:49	2020-07-27	12	[{"id_menu":1,"count":1}]	6024	delivery	5	17
104699	2020-07-27 00:31:12	2020-07-27	9	[{"id_menu":7,"count":1}]	16767	delivery	5	14
104700	2020-07-27 00:38:59	2020-07-27	12	[{"id_menu":1,"count":1}]	40403	delivery	5	17
104701	2020-07-27 00:41:36	2020-07-27	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	9312	delivery	5	31
104702	2020-07-27 00:47:57	2020-07-27	9	[{"id_menu":6,"count":1}]	40332	delivery	5	14
104703	2020-07-27 00:48:24	2020-07-27	8	[{"id_menu":5,"count":1}]	1128	pick-up	0	8
104704	2020-07-27 00:48:28	2020-07-27	14	[{"id_menu":2,"count":1}]	13193	pick-up	0	14
104705	2020-07-27 00:49:13	2020-07-27	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	22062	delivery	5	31
104706	2020-07-27 00:56:17	2020-07-27	9	[{"id_menu":7,"count":1}]	40369	delivery	5	14
104707	2020-07-27 00:58:21	2020-07-27	12	[{"id_menu":1,"count":1}]	36873	delivery	5	17
104708	2020-07-27 01:01:58	2020-07-27	9	[{"id_menu":6,"count":1}]	16498	delivery	5	14
104709	2020-07-27 01:08:30	2020-07-27	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":2}]	40301	delivery	5	28
104710	2020-07-27 01:09:30	2020-07-27	12	[{"id_menu":1,"count":1}]	40280	delivery	5	17
104711	2020-07-27 01:10:19	2020-07-27	9	[{"id_menu":6,"count":3}]	35951	delivery	5	14
104712	2020-07-27 01:13:35	2020-07-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28712	pick-up	0	18
104713	2020-07-27 01:15:40	2020-07-27	12	[{"id_menu":1,"count":1}]	38370	delivery	5	17
104714	2020-07-27 01:26:39	2020-07-27	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	40344	delivery	5	25
104715	2020-07-27 01:34:53	2020-07-27	8	[{"id_menu":5,"count":1}]	32810	pick-up	0	8
104716	2020-07-27 01:36:44	2020-07-27	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4190	delivery	5	31
104717	2020-07-27 01:40:02	2020-07-27	12	[{"id_menu":3,"count":1}]	38642	pick-up	0	12
104718	2020-07-27 01:42:15	2020-07-27	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35643	delivery	5	35
104719	2020-07-27 01:45:42	2020-07-27	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	35720	delivery	5	27
104720	2020-07-27 01:45:56	2020-07-27	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	10854	delivery	5	23
104721	2020-07-27 01:46:23	2020-07-27	14	[{"id_menu":2,"count":2}]	25658	delivery	5	19
104722	2020-07-27 01:46:27	2020-07-27	12	[{"id_menu":1,"count":1}]	40282	delivery	5	17
104723	2020-07-27 01:47:53	2020-07-27	9	[{"id_menu":7,"count":1}]	40214	delivery	5	14
104724	2020-07-27 01:48:51	2020-07-27	12	[{"id_menu":3,"count":1}]	29881	delivery	5	17
104725	2020-07-27 01:49:44	2020-07-27	9	[{"id_menu":7,"count":1}]	3843	delivery	5	14
104726	2020-07-27 01:52:41	2020-07-27	9	[{"id_menu":6,"count":1}]	40442	delivery	5	14
104727	2020-07-27 01:53:36	2020-07-27	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	40250	delivery	5	40
104728	2020-07-27 01:55:20	2020-07-27	14	[{"id_menu":2,"count":1}]	8849	pick-up	0	14
104729	2020-07-27 01:56:36	2020-07-27	8	[{"id_menu":5,"count":1}]	14461	delivery	5	13
104730	2020-07-27 01:57:03	2020-07-27	9	[{"id_menu":7,"count":1}]	24759	delivery	5	14
104731	2020-07-27 01:57:19	2020-07-27	8	[{"id_menu":5,"count":1}]	40347	delivery	5	13
104732	2020-07-27 01:57:59	2020-07-27	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	19953	delivery	5	31
104733	2020-07-27 02:04:02	2020-07-27	9	[{"id_menu":6,"count":1}]	31969	delivery	5	14
104734	2020-07-27 02:04:53	2020-07-27	12	[{"id_menu":1,"count":1}]	3361	pick-up	0	12
104735	2020-07-27 02:06:02	2020-07-27	8	[{"id_menu":5,"count":1}]	7808	pick-up	0	8
104736	2020-07-27 02:06:18	2020-07-27	8	[{"id_menu":5,"count":1}]	40365	delivery	5	13
104737	2020-07-27 02:10:34	2020-07-27	17	[{"id_menu":4,"count":1}]	5789	delivery	5	22
104738	2020-07-27 02:10:44	2020-07-27	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3645	delivery	5	28
104739	2020-07-27 02:10:54	2020-07-27	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	40273	delivery	5	48
104740	2020-07-27 02:11:00	2020-07-27	12	[{"id_menu":1,"count":1}]	14862	delivery	5	17
104741	2020-07-27 02:12:37	2020-07-27	9	[{"id_menu":6,"count":1}]	40362	delivery	5	14
104742	2020-07-27 02:13:18	2020-07-27	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	31876	pick-up	0	35
104743	2020-07-27 02:14:02	2020-07-27	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":2}]	32936	pick-up	0	22
104744	2020-07-27 02:15:01	2020-07-27	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	36385	delivery	5	39
104745	2020-07-27 02:17:49	2020-07-27	8	[{"id_menu":5,"count":1}]	873	delivery	5	13
104746	2020-07-27 02:23:43	2020-07-27	9	[{"id_menu":7,"count":1}]	29365	delivery	5	14
104747	2020-07-27 02:29:05	2020-07-27	17	[{"id_menu":4,"count":1}]	38676	pick-up	0	17
104748	2020-07-27 02:32:54	2020-07-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	40426	delivery	5	22
104749	2020-07-27 02:35:44	2020-07-27	14	[{"id_menu":2,"count":1}]	40320	delivery	5	19
104750	2020-07-27 02:37:34	2020-07-27	9	[{"id_menu":6,"count":1}]	10480	delivery	5	14
104751	2020-07-27 02:44:52	2020-07-27	17	[{"id_menu":4,"count":1}]	16054	delivery	5	22
104752	2020-07-27 02:45:05	2020-07-27	9	[{"id_menu":7,"count":1}]	29094	delivery	5	14
104753	2020-07-27 02:45:53	2020-07-27	9	[{"id_menu":6,"count":1}]	10200	pick-up	0	9
104754	2020-07-27 02:56:07	2020-07-27	9	[{"id_menu":6,"count":2}]	2664	delivery	5	14
104755	2020-07-27 03:00:37	2020-07-27	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	40304	pick-up	0	30
104756	2020-07-27 03:02:02	2020-07-27	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	40251	delivery	5	25
104757	2020-07-27 03:04:35	2020-07-27	12	[{"id_menu":3,"count":2}]	40371	delivery	5	17
104758	2020-07-27 03:06:50	2020-07-27	12	[{"id_menu":1,"count":1}]	7603	delivery	5	17
104759	2020-07-27 03:13:04	2020-07-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	40323	delivery	5	22
104760	2020-07-27 03:13:05	2020-07-27	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	40404	delivery	5	31
104761	2020-07-27 03:13:07	2020-07-27	14	[{"id_menu":2,"count":1}]	15816	pick-up	0	14
104762	2020-07-27 03:22:10	2020-07-27	14	[{"id_menu":2,"count":1}]	40262	delivery	5	19
104763	2020-07-27 03:27:09	2020-07-27	9	[{"id_menu":7,"count":1}]	39861	delivery	5	14
104764	2020-07-27 03:28:33	2020-07-27	17	[{"id_menu":4,"count":1}]	24247	delivery	5	22
104765	2020-07-27 03:34:50	2020-07-27	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	19383	delivery	5	42
104766	2020-07-27 03:37:11	2020-07-27	17	[{"id_menu":4,"count":1}]	7330	delivery	5	22
104767	2020-07-27 03:41:25	2020-07-27	14	[{"id_menu":2,"count":1}]	40231	delivery	5	19
104768	2020-07-27 03:41:28	2020-07-27	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8204	delivery	5	45
104769	2020-07-27 03:44:17	2020-07-27	8	[{"id_menu":5,"count":1}]	13283	delivery	5	13
104770	2020-07-27 03:49:47	2020-07-27	9	[{"id_menu":7,"count":1}]	24392	delivery	5	14
104771	2020-07-27 03:50:38	2020-07-27	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	32539	delivery	5	40
104772	2020-07-27 03:55:07	2020-07-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	9475	pick-up	0	31
104773	2020-07-27 03:56:18	2020-07-27	9	[{"id_menu":6,"count":1}]	32244	delivery	5	14
104774	2020-07-27 03:57:05	2020-07-27	12	[{"id_menu":1,"count":1}]	22864	delivery	5	17
104775	2020-07-27 03:57:51	2020-07-27	12	[{"id_menu":1,"count":2}]	40193	delivery	5	17
104776	2020-07-27 04:02:56	2020-07-27	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	40366	delivery	5	36
104777	2020-07-27 04:09:48	2020-07-27	9	[{"id_menu":7,"count":1}]	38787	delivery	5	14
104778	2020-07-27 04:10:17	2020-07-27	9	[{"id_menu":6,"count":1}]	2790	delivery	5	14
104779	2020-07-27 04:14:15	2020-07-27	8	[{"id_menu":5,"count":1}]	39295	delivery	5	13
104780	2020-07-27 04:15:40	2020-07-27	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	35722	delivery	5	31
104781	2020-07-27 04:18:24	2020-07-27	9	[{"id_menu":6,"count":1}]	11422	delivery	5	14
104782	2020-07-27 04:20:58	2020-07-27	37	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	35807	delivery	5	42
104783	2020-07-27 04:35:36	2020-07-27	9	[{"id_menu":7,"count":1}]	14943	delivery	5	14
104784	2020-07-27 04:38:44	2020-07-27	8	[{"id_menu":5,"count":1}]	3704	delivery	5	13
104785	2020-07-27 04:41:11	2020-07-27	12	[{"id_menu":1,"count":1}]	3054	pick-up	0	12
104786	2020-07-27 04:51:54	2020-07-27	14	[{"id_menu":2,"count":1}]	2072	pick-up	0	14
104787	2020-07-27 04:57:34	2020-07-27	12	[{"id_menu":3,"count":1}]	6617	pick-up	0	12
104788	2020-07-27 04:59:13	2020-07-27	12	[{"id_menu":1,"count":1}]	40387	delivery	5	17
104789	2020-07-27 04:59:13	2020-07-27	9	[{"id_menu":6,"count":1}]	8612	delivery	5	14
104790	2020-07-27 05:09:15	2020-07-27	26	[{"id_menu":4,"count":3},{"id_menu":7,"count":1}]	6282	delivery	5	31
104791	2020-07-27 05:16:32	2020-07-27	14	[{"id_menu":2,"count":1}]	30464	delivery	5	19
104792	2020-07-27 05:19:47	2020-07-27	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	23118	delivery	5	40
104793	2020-07-27 05:25:31	2020-07-27	9	[{"id_menu":6,"count":1}]	40393	pick-up	0	9
104794	2020-07-27 05:26:11	2020-07-27	9	[{"id_menu":6,"count":1}]	27545	delivery	5	14
104795	2020-07-27 05:29:45	2020-07-27	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	34162	delivery	5	28
104796	2020-07-27 05:29:54	2020-07-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	33607	delivery	5	23
104797	2020-07-27 05:32:45	2020-07-27	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2237	pick-up	0	32
104798	2020-07-27 05:34:32	2020-07-27	12	[{"id_menu":1,"count":1}]	40385	delivery	5	17
104799	2020-07-27 05:34:46	2020-07-27	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	10596	pick-up	0	21
104800	2020-07-27 05:39:47	2020-07-27	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	14984	delivery	5	26
104801	2020-07-27 05:40:56	2020-07-27	9	[{"id_menu":7,"count":1}]	40328	delivery	5	14
104802	2020-07-27 05:47:47	2020-07-27	14	[{"id_menu":2,"count":1}]	21087	pick-up	0	14
104803	2020-07-27 05:49:52	2020-07-27	9	[{"id_menu":7,"count":1}]	13483	delivery	5	14
104804	2020-07-27 05:51:20	2020-07-27	12	[{"id_menu":3,"count":1}]	20970	pick-up	0	12
104805	2020-07-27 05:53:06	2020-07-27	9	[{"id_menu":7,"count":1}]	35171	delivery	5	14
104806	2020-07-27 05:53:39	2020-07-27	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	19391	pick-up	0	26
104807	2020-07-27 05:54:46	2020-07-27	14	[{"id_menu":2,"count":1}]	26580	pick-up	0	14
104808	2020-07-27 06:00:34	2020-07-27	9	[{"id_menu":7,"count":1}]	9603	pick-up	0	9
104809	2020-07-27 06:05:35	2020-07-27	12	[{"id_menu":3,"count":1}]	7963	pick-up	0	12
104810	2020-07-27 06:06:16	2020-07-27	14	[{"id_menu":2,"count":1}]	25494	delivery	5	19
104811	2020-07-27 06:06:22	2020-07-27	12	[{"id_menu":3,"count":1}]	40343	delivery	5	17
104812	2020-07-27 06:06:35	2020-07-27	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4060	delivery	5	51
104813	2020-07-27 06:14:29	2020-07-27	14	[{"id_menu":2,"count":1}]	24359	delivery	5	19
104814	2020-07-27 06:14:58	2020-07-27	9	[{"id_menu":6,"count":1}]	32762	delivery	5	14
104815	2020-07-27 06:18:59	2020-07-27	17	[{"id_menu":4,"count":1}]	40319	delivery	5	22
104816	2020-07-27 06:20:51	2020-07-27	17	[{"id_menu":4,"count":1}]	13537	pick-up	0	17
104817	2020-07-27 06:27:22	2020-07-27	8	[{"id_menu":5,"count":1}]	39522	delivery	5	13
104818	2020-07-27 06:27:29	2020-07-27	12	[{"id_menu":1,"count":1}]	29458	pick-up	0	12
104819	2020-07-27 06:28:03	2020-07-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23469	delivery	5	23
104820	2020-07-27 06:30:15	2020-07-27	17	[{"id_menu":4,"count":1}]	21119	delivery	5	22
104821	2020-07-27 06:43:12	2020-07-27	9	[{"id_menu":6,"count":2}]	40243	delivery	5	14
104822	2020-07-27 06:50:21	2020-07-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40306	pick-up	0	18
104823	2020-07-27 06:52:13	2020-07-27	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	26819	delivery	5	25
104824	2020-07-27 06:59:00	2020-07-27	8	[{"id_menu":5,"count":2}]	31232	delivery	5	13
104825	2020-07-27 07:04:00	2020-07-27	17	[{"id_menu":4,"count":1}]	13008	delivery	5	22
104826	2020-07-27 07:04:15	2020-07-27	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	33195	delivery	5	36
104827	2020-07-27 07:09:58	2020-07-27	9	[{"id_menu":7,"count":1}]	5478	pick-up	0	9
104828	2020-07-27 07:13:59	2020-07-27	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	40405	delivery	5	28
104829	2020-07-27 07:14:18	2020-07-27	9	[{"id_menu":7,"count":2}]	6238	delivery	5	14
104830	2020-07-27 07:14:44	2020-07-27	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	32739	delivery	5	34
104831	2020-07-27 07:15:17	2020-07-27	9	[{"id_menu":6,"count":2}]	22650	delivery	5	14
104832	2020-07-27 07:16:06	2020-07-27	12	[{"id_menu":3,"count":1}]	31350	delivery	5	17
104833	2020-07-27 07:17:32	2020-07-27	17	[{"id_menu":4,"count":1}]	15827	delivery	5	22
104834	2020-07-27 07:22:19	2020-07-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	40456	delivery	5	22
104835	2020-07-27 07:26:07	2020-07-27	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	40350	pick-up	0	39
104836	2020-07-27 07:27:01	2020-07-27	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	40238	delivery	5	56
104837	2020-07-27 07:28:17	2020-07-27	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40354	delivery	5	40
104838	2020-07-27 07:30:35	2020-07-27	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	40239	delivery	5	37
104839	2020-07-27 07:33:08	2020-07-27	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	40375	delivery	5	37
104840	2020-07-27 07:38:01	2020-07-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	30855	pick-up	0	31
104841	2020-07-27 07:43:37	2020-07-27	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	14104	delivery	5	26
104842	2020-07-27 07:43:51	2020-07-27	14	[{"id_menu":2,"count":1}]	18770	pick-up	0	14
104843	2020-07-27 07:46:02	2020-07-27	9	[{"id_menu":6,"count":1}]	20542	delivery	5	14
104844	2020-07-27 07:46:32	2020-07-27	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10420	delivery	5	36
104845	2020-07-27 07:49:09	2020-07-27	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5966	pick-up	0	25
104846	2020-07-27 07:49:58	2020-07-27	8	[{"id_menu":5,"count":1}]	7986	delivery	5	13
104847	2020-07-27 07:52:51	2020-07-27	8	[{"id_menu":5,"count":1}]	4260	pick-up	0	8
104848	2020-07-27 08:02:04	2020-07-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	8234	delivery	5	28
104849	2020-07-27 08:03:14	2020-07-27	14	[{"id_menu":2,"count":1}]	1674	pick-up	0	14
104850	2020-07-27 08:07:31	2020-07-27	8	[{"id_menu":5,"count":1}]	30552	delivery	5	13
104851	2020-07-27 08:07:36	2020-07-27	9	[{"id_menu":6,"count":1}]	40219	delivery	5	14
104852	2020-07-27 08:07:55	2020-07-27	17	[{"id_menu":4,"count":1}]	40444	delivery	5	22
104853	2020-07-27 08:15:52	2020-07-27	12	[{"id_menu":1,"count":1}]	34835	pick-up	0	12
104854	2020-07-27 08:17:22	2020-07-27	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	40217	delivery	5	28
104855	2020-07-27 08:21:30	2020-07-27	8	[{"id_menu":5,"count":1}]	30922	delivery	5	13
104856	2020-07-27 08:23:59	2020-07-27	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	30005	pick-up	0	21
104857	2020-07-27 08:25:37	2020-07-27	9	[{"id_menu":6,"count":1}]	25214	pick-up	0	9
104858	2020-07-27 08:29:22	2020-07-27	12	[{"id_menu":3,"count":1}]	35258	pick-up	0	12
104859	2020-07-27 08:33:01	2020-07-27	8	[{"id_menu":5,"count":2}]	40196	delivery	5	13
104860	2020-07-27 08:34:03	2020-07-27	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	32914	delivery	5	26
104861	2020-07-27 08:35:32	2020-07-27	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	40310	delivery	5	42
104862	2020-07-27 08:35:58	2020-07-27	12	[{"id_menu":1,"count":1}]	40221	delivery	5	17
104863	2020-07-27 08:38:37	2020-07-27	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	28044	delivery	5	34
104864	2020-07-27 08:38:40	2020-07-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	29398	delivery	5	22
104865	2020-07-27 08:41:13	2020-07-27	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	40467	delivery	5	25
104866	2020-07-27 08:48:03	2020-07-27	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	34700	delivery	5	31
104867	2020-07-27 08:49:41	2020-07-27	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	34890	delivery	5	28
104868	2020-07-27 08:54:47	2020-07-27	12	[{"id_menu":1,"count":1}]	40266	pick-up	0	12
104869	2020-07-27 08:59:13	2020-07-27	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7211	delivery	5	35
104870	2020-07-27 08:59:51	2020-07-27	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	40438	delivery	5	25
104871	2020-07-27 09:03:31	2020-07-27	17	[{"id_menu":4,"count":1}]	40406	delivery	5	22
104872	2020-07-27 09:05:39	2020-07-27	14	[{"id_menu":2,"count":1}]	40335	pick-up	0	14
104873	2020-07-27 09:07:00	2020-07-27	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	40326	delivery	5	42
104874	2020-07-27 09:09:24	2020-07-27	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	40434	delivery	5	30
104875	2020-07-27 09:10:52	2020-07-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	22629	delivery	5	28
104876	2020-07-27 09:12:51	2020-07-27	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	23065	delivery	5	42
104877	2020-07-27 09:14:56	2020-07-27	9	[{"id_menu":6,"count":1}]	9681	delivery	5	14
104878	2020-07-27 09:15:51	2020-07-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2552	pick-up	0	18
104879	2020-07-27 09:18:45	2020-07-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11560	delivery	5	23
104880	2020-07-27 09:23:47	2020-07-27	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23999	delivery	5	31
104881	2020-07-27 09:24:39	2020-07-27	17	[{"id_menu":4,"count":1}]	40436	delivery	5	22
104882	2020-07-27 09:29:20	2020-07-27	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2283	delivery	5	43
104883	2020-07-27 09:33:03	2020-07-27	9	[{"id_menu":6,"count":1}]	721	pick-up	0	9
104884	2020-07-27 09:34:38	2020-07-27	9	[{"id_menu":7,"count":1}]	7517	delivery	5	14
104885	2020-07-27 09:35:08	2020-07-27	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	33331	delivery	5	26
104886	2020-07-27 09:36:53	2020-07-27	8	[{"id_menu":5,"count":1}]	14088	pick-up	0	8
104887	2020-07-27 09:42:58	2020-07-27	17	[{"id_menu":4,"count":1}]	23733	pick-up	0	17
104888	2020-07-27 09:50:34	2020-07-27	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40275	delivery	5	31
104889	2020-07-27 09:50:39	2020-07-27	12	[{"id_menu":1,"count":1}]	40269	delivery	5	17
104890	2020-07-27 09:51:28	2020-07-27	8	[{"id_menu":5,"count":2}]	40381	delivery	5	13
104891	2020-07-27 09:52:20	2020-07-27	9	[{"id_menu":7,"count":1}]	21387	pick-up	0	9
104892	2020-07-27 09:56:10	2020-07-27	9	[{"id_menu":7,"count":1}]	7736	delivery	5	14
104893	2020-07-27 09:59:59	2020-07-27	12	[{"id_menu":3,"count":1}]	40321	delivery	5	17
104894	2020-07-27 10:00:14	2020-07-27	9	[{"id_menu":6,"count":3}]	37588	delivery	5	14
104895	2020-07-27 10:00:49	2020-07-27	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	10152	pick-up	0	38
104896	2020-07-27 10:08:52	2020-07-27	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	24250	delivery	5	34
104897	2020-07-27 10:21:57	2020-07-27	9	[{"id_menu":7,"count":1}]	13307	delivery	5	14
104898	2020-07-27 10:23:14	2020-07-27	8	[{"id_menu":5,"count":1}]	16217	delivery	5	13
104899	2020-07-27 10:27:19	2020-07-27	9	[{"id_menu":6,"count":1}]	7766	pick-up	0	9
104900	2020-07-27 10:30:32	2020-07-27	8	[{"id_menu":5,"count":1}]	40226	delivery	5	13
104901	2020-07-27 10:32:37	2020-07-27	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10993	delivery	5	31
104902	2020-07-27 10:32:39	2020-07-27	12	[{"id_menu":1,"count":2}]	40303	delivery	5	17
104903	2020-07-27 10:32:43	2020-07-27	12	[{"id_menu":3,"count":1}]	13196	delivery	5	17
104904	2020-07-27 10:33:49	2020-07-27	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40309	delivery	5	52
104905	2020-07-27 10:35:38	2020-07-27	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	40433	delivery	5	26
104906	2020-07-27 10:36:38	2020-07-27	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40446	delivery	5	35
104907	2020-07-27 10:38:11	2020-07-27	9	[{"id_menu":6,"count":1}]	654	pick-up	0	9
104908	2020-07-27 10:46:41	2020-07-27	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	11057	delivery	5	26
104909	2020-07-27 10:49:06	2020-07-27	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	18782	delivery	5	40
104910	2020-07-27 10:49:30	2020-07-27	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10425	pick-up	0	17
104911	2020-07-27 10:55:16	2020-07-27	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40342	delivery	5	35
104912	2020-07-27 11:00:44	2020-07-27	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	40397	delivery	5	22
104913	2020-07-27 11:06:21	2020-07-27	9	[{"id_menu":6,"count":1}]	40439	delivery	5	14
104914	2020-07-27 11:08:10	2020-07-27	9	[{"id_menu":7,"count":1}]	40292	delivery	5	14
104915	2020-07-27 11:08:15	2020-07-27	14	[{"id_menu":2,"count":1}]	20961	pick-up	0	14
104916	2020-07-27 11:11:43	2020-07-27	8	[{"id_menu":5,"count":1}]	7122	delivery	5	13
104917	2020-07-27 11:12:54	2020-07-27	12	[{"id_menu":1,"count":1}]	40300	delivery	5	17
104918	2020-07-27 11:23:29	2020-07-27	9	[{"id_menu":6,"count":1}]	11894	pick-up	0	9
104919	2020-07-27 11:25:52	2020-07-27	12	[{"id_menu":3,"count":1}]	5808	pick-up	0	12
104920	2020-07-27 11:35:42	2020-07-27	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6688	delivery	5	31
104921	2020-07-27 11:35:56	2020-07-27	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	16313	delivery	5	31
104922	2020-07-27 11:37:49	2020-07-27	9	[{"id_menu":7,"count":1}]	37874	delivery	5	14
104923	2020-07-27 11:39:38	2020-07-27	14	[{"id_menu":2,"count":1}]	21243	delivery	5	19
104924	2020-07-27 11:39:46	2020-07-27	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	21671	delivery	5	28
104925	2020-07-27 11:41:57	2020-07-27	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	11342	delivery	5	26
104926	2020-07-27 11:45:08	2020-07-27	14	[{"id_menu":2,"count":1}]	19845	pick-up	0	14
104927	2020-07-27 11:45:43	2020-07-27	9	[{"id_menu":7,"count":1}]	19212	pick-up	0	9
104928	2020-07-27 11:46:03	2020-07-27	12	[{"id_menu":1,"count":1}]	14963	delivery	5	17
104929	2020-07-27 11:51:28	2020-07-27	8	[{"id_menu":5,"count":1}]	5818	delivery	5	13
104930	2020-07-27 11:53:41	2020-07-27	9	[{"id_menu":6,"count":1}]	17150	pick-up	0	9
104931	2020-07-27 11:53:51	2020-07-27	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16438	delivery	5	31
104932	2020-07-27 11:56:08	2020-07-27	9	[{"id_menu":6,"count":1}]	40421	delivery	5	14
104933	2020-07-27 11:58:53	2020-07-27	17	[{"id_menu":4,"count":1}]	36605	delivery	5	22
104934	2020-07-27 11:59:19	2020-07-27	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	4150	delivery	5	22
104935	2020-07-27 12:04:01	2020-07-27	9	[{"id_menu":7,"count":1}]	3227	delivery	5	14
104936	2020-07-27 12:06:01	2020-07-27	12	[{"id_menu":3,"count":1}]	4710	delivery	5	17
104937	2020-07-27 12:09:32	2020-07-27	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14545	delivery	5	55
104938	2020-07-27 12:11:19	2020-07-27	8	[{"id_menu":5,"count":1}]	40412	delivery	5	13
104939	2020-07-27 12:12:22	2020-07-27	17	[{"id_menu":4,"count":1}]	36355	delivery	5	22
104940	2020-07-27 12:16:37	2020-07-27	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	18983	delivery	5	31
104941	2020-07-27 12:20:50	2020-07-27	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40222	delivery	5	37
104942	2020-07-27 12:25:28	2020-07-27	9	[{"id_menu":6,"count":1}]	40353	pick-up	0	9
104943	2020-07-27 12:27:18	2020-07-27	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3997	delivery	5	28
104944	2020-07-27 12:31:14	2020-07-27	12	[{"id_menu":1,"count":1}]	18698	delivery	5	17
104945	2020-07-27 12:32:36	2020-07-27	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	19428	delivery	5	27
104946	2020-07-27 12:35:53	2020-07-27	17	[{"id_menu":4,"count":1}]	19346	delivery	5	22
104947	2020-07-27 12:38:33	2020-07-27	14	[{"id_menu":2,"count":1}]	17777	pick-up	0	14
104948	2020-07-27 12:41:31	2020-07-27	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	14294	delivery	5	35
104949	2020-07-27 12:41:42	2020-07-27	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	40420	delivery	5	31
104950	2020-07-27 12:47:24	2020-07-27	17	[{"id_menu":4,"count":2}]	40289	pick-up	0	17
104951	2020-07-27 12:50:10	2020-07-27	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	40312	delivery	5	22
104952	2020-07-27 12:51:55	2020-07-27	9	[{"id_menu":7,"count":1}]	7383	delivery	5	14
104953	2020-07-27 12:54:45	2020-07-27	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	40325	delivery	5	51
104954	2020-07-27 12:59:45	2020-07-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	40411	delivery	5	28
104955	2020-07-27 13:01:03	2020-07-27	8	[{"id_menu":5,"count":1}]	39016	delivery	5	13
104956	2020-07-27 13:02:36	2020-07-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	8181	delivery	5	22
104957	2020-07-27 13:02:50	2020-07-27	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	5192	delivery	5	26
104958	2020-07-27 13:04:02	2020-07-27	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	38615	delivery	5	43
104959	2020-07-27 13:04:44	2020-07-27	14	[{"id_menu":2,"count":1}]	40257	delivery	5	19
104960	2020-07-27 13:05:21	2020-07-27	9	[{"id_menu":6,"count":1}]	40356	delivery	5	14
104961	2020-07-27 13:09:23	2020-07-27	14	[{"id_menu":2,"count":1}]	5447	delivery	5	19
104962	2020-07-27 13:14:52	2020-07-27	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	40329	delivery	5	34
104963	2020-07-27 13:17:51	2020-07-27	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	40283	delivery	5	37
104964	2020-07-27 13:23:52	2020-07-27	9	[{"id_menu":6,"count":1}]	27061	delivery	5	14
104965	2020-07-27 13:30:22	2020-07-27	9	[{"id_menu":6,"count":1}]	22414	delivery	5	14
104966	2020-07-27 13:32:20	2020-07-27	14	[{"id_menu":2,"count":1}]	30702	delivery	5	19
104967	2020-07-27 13:42:10	2020-07-27	9	[{"id_menu":7,"count":1}]	28800	delivery	5	14
104968	2020-07-27 13:42:19	2020-07-27	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	40357	delivery	5	30
104969	2020-07-27 13:43:16	2020-07-27	8	[{"id_menu":5,"count":1}]	25260	delivery	5	13
104970	2020-07-27 13:46:33	2020-07-27	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29302	delivery	5	22
104971	2020-07-27 13:47:03	2020-07-27	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	40227	delivery	5	31
104972	2020-07-27 13:48:01	2020-07-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	10045	delivery	5	28
104973	2020-07-27 13:51:39	2020-07-27	14	[{"id_menu":2,"count":1}]	40454	delivery	5	19
104974	2020-07-27 13:54:04	2020-07-27	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	27938	delivery	5	25
104975	2020-07-27 13:59:50	2020-07-27	9	[{"id_menu":6,"count":1}]	37992	delivery	5	14
104976	2020-07-27 14:00:35	2020-07-27	12	[{"id_menu":3,"count":1}]	452	pick-up	0	12
104977	2020-07-27 14:03:29	2020-07-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	31117	delivery	5	36
104978	2020-07-27 14:08:37	2020-07-27	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	16607	delivery	5	25
104979	2020-07-27 14:16:56	2020-07-27	14	[{"id_menu":2,"count":1}]	30864	pick-up	0	14
104980	2020-07-27 14:22:07	2020-07-27	9	[{"id_menu":7,"count":1}]	31170	delivery	5	14
104981	2020-07-27 14:22:09	2020-07-27	8	[{"id_menu":5,"count":1}]	40462	delivery	5	13
104982	2020-07-27 14:35:00	2020-07-27	12	[{"id_menu":3,"count":1}]	13826	delivery	5	17
104983	2020-07-27 14:35:31	2020-07-27	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	40346	delivery	5	36
104984	2020-07-27 14:42:41	2020-07-27	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4107	delivery	5	43
104985	2020-07-27 14:51:27	2020-07-27	12	[{"id_menu":1,"count":1}]	5454	delivery	5	17
104986	2020-07-27 14:53:38	2020-07-27	9	[{"id_menu":6,"count":1}]	15750	delivery	5	14
104987	2020-07-27 14:56:26	2020-07-27	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	8622	delivery	5	35
104988	2020-07-27 14:56:58	2020-07-27	9	[{"id_menu":6,"count":1}]	40414	delivery	5	14
104989	2020-07-27 15:00:12	2020-07-27	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	32551	delivery	5	26
104990	2020-07-27 15:01:09	2020-07-27	12	[{"id_menu":3,"count":1}]	2715	delivery	5	17
104991	2020-07-27 15:01:39	2020-07-27	17	[{"id_menu":4,"count":1}]	19028	delivery	5	22
104992	2020-07-27 15:13:59	2020-07-27	8	[{"id_menu":5,"count":1}]	40232	pick-up	0	8
104993	2020-07-27 15:20:36	2020-07-27	9	[{"id_menu":7,"count":1}]	40220	delivery	5	14
104994	2020-07-27 15:23:24	2020-07-27	14	[{"id_menu":2,"count":1}]	22862	delivery	5	19
104995	2020-07-27 15:23:28	2020-07-27	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	40359	delivery	5	31
104996	2020-07-27 15:25:22	2020-07-27	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	40424	delivery	5	31
104997	2020-07-27 15:27:08	2020-07-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40351	delivery	5	23
104998	2020-07-27 15:28:34	2020-07-27	14	[{"id_menu":2,"count":1}]	40286	delivery	5	19
104999	2020-07-27 15:30:04	2020-07-27	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	40368	delivery	5	34
105000	2020-07-27 15:32:27	2020-07-27	12	[{"id_menu":3,"count":1}]	28200	delivery	5	17
105001	2020-07-27 15:38:11	2020-07-27	9	[{"id_menu":6,"count":1}]	8090	delivery	5	14
105002	2020-07-27 15:39:53	2020-07-27	14	[{"id_menu":2,"count":1}]	40331	delivery	5	19
105003	2020-07-27 15:40:19	2020-07-27	8	[{"id_menu":5,"count":1}]	40440	delivery	5	13
105004	2020-07-27 15:41:59	2020-07-27	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	40352	delivery	5	25
105005	2020-07-27 15:43:39	2020-07-27	17	[{"id_menu":4,"count":1}]	24783	delivery	5	22
105006	2020-07-27 15:50:44	2020-07-27	12	[{"id_menu":3,"count":1}]	40295	delivery	5	17
105007	2020-07-27 15:51:52	2020-07-27	12	[{"id_menu":1,"count":1}]	40241	delivery	5	17
105008	2020-07-27 15:52:48	2020-07-27	9	[{"id_menu":7,"count":1}]	1597	delivery	5	14
105009	2020-07-27 15:55:00	2020-07-27	17	[{"id_menu":4,"count":1}]	6983	delivery	5	22
105010	2020-07-27 15:55:30	2020-07-27	9	[{"id_menu":7,"count":1}]	21846	delivery	5	14
105011	2020-07-27 15:56:04	2020-07-27	9	[{"id_menu":6,"count":1}]	31734	delivery	5	14
105012	2020-07-27 15:58:54	2020-07-27	9	[{"id_menu":6,"count":1}]	40363	delivery	5	14
105013	2020-07-27 16:06:34	2020-07-27	14	[{"id_menu":2,"count":1}]	40242	delivery	5	19
105014	2020-07-27 16:07:23	2020-07-27	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32328	delivery	5	48
105015	2020-07-27 16:07:54	2020-07-27	17	[{"id_menu":4,"count":1}]	12183	pick-up	0	17
105016	2020-07-27 16:09:14	2020-07-27	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	17793	delivery	5	23
105017	2020-07-27 16:10:56	2020-07-27	9	[{"id_menu":6,"count":1}]	9626	delivery	5	14
105018	2020-07-27 16:15:55	2020-07-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18297	delivery	5	23
105019	2020-07-27 16:20:39	2020-07-27	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	22622	delivery	5	40
105020	2020-07-27 16:23:06	2020-07-27	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	27567	delivery	5	25
105021	2020-07-27 16:23:35	2020-07-27	14	[{"id_menu":2,"count":1}]	6916	delivery	5	19
105022	2020-07-27 16:25:33	2020-07-27	14	[{"id_menu":2,"count":2}]	21104	pick-up	0	14
105023	2020-07-27 16:26:52	2020-07-27	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	15156	delivery	5	26
105024	2020-07-27 16:27:09	2020-07-27	9	[{"id_menu":6,"count":1}]	8744	delivery	5	14
105025	2020-07-27 16:27:35	2020-07-27	9	[{"id_menu":7,"count":1}]	40410	delivery	5	14
105026	2020-07-27 16:29:24	2020-07-27	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	932	delivery	5	31
105027	2020-07-27 16:34:06	2020-07-27	9	[{"id_menu":7,"count":1}]	30491	delivery	5	14
105028	2020-07-27 16:47:57	2020-07-27	12	[{"id_menu":3,"count":1}]	3459	pick-up	0	12
105029	2020-07-27 16:50:16	2020-07-27	8	[{"id_menu":5,"count":1}]	8132	delivery	5	13
105030	2020-07-27 16:55:04	2020-07-27	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3874	delivery	5	22
105031	2020-07-27 16:59:22	2020-07-27	14	[{"id_menu":2,"count":1}]	40348	delivery	5	19
105032	2020-07-27 17:03:13	2020-07-27	12	[{"id_menu":1,"count":1}]	12819	delivery	5	17
105033	2020-07-27 17:04:06	2020-07-27	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	19113	delivery	5	31
105034	2020-07-27 17:12:46	2020-07-27	14	[{"id_menu":2,"count":1}]	40317	delivery	5	19
105035	2020-07-27 17:15:16	2020-07-27	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	35439	delivery	5	31
105036	2020-07-27 17:30:58	2020-07-27	8	[{"id_menu":5,"count":1}]	5558	delivery	5	13
105037	2020-07-27 17:38:54	2020-07-27	9	[{"id_menu":6,"count":1}]	40400	delivery	5	14
105038	2020-07-27 17:40:06	2020-07-27	9	[{"id_menu":7,"count":1}]	30283	delivery	5	14
105039	2020-07-27 17:43:04	2020-07-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	40233	delivery	5	36
105040	2020-07-27 17:43:39	2020-07-27	12	[{"id_menu":3,"count":1}]	39354	delivery	5	17
105041	2020-07-27 17:44:16	2020-07-27	17	[{"id_menu":4,"count":1}]	40278	delivery	5	22
105042	2020-07-27 17:49:11	2020-07-27	9	[{"id_menu":6,"count":1}]	15319	delivery	5	14
105043	2020-07-27 17:49:24	2020-07-27	12	[{"id_menu":1,"count":1}]	40372	delivery	5	17
105044	2020-07-27 17:50:17	2020-07-27	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	32115	delivery	5	36
105045	2020-07-27 17:52:32	2020-07-27	14	[{"id_menu":2,"count":1}]	1759	pick-up	0	14
105046	2020-07-27 17:57:54	2020-07-27	12	[{"id_menu":3,"count":1}]	40268	delivery	5	17
105047	2020-07-27 17:58:50	2020-07-27	8	[{"id_menu":5,"count":1}]	40079	delivery	5	13
105048	2020-07-27 17:58:54	2020-07-27	9	[{"id_menu":6,"count":1}]	40265	delivery	5	14
105049	2020-07-27 18:05:30	2020-07-27	14	[{"id_menu":2,"count":1}]	233	delivery	5	19
105050	2020-07-27 18:14:35	2020-07-27	9	[{"id_menu":6,"count":1}]	40383	delivery	5	14
105051	2020-07-27 18:17:27	2020-07-27	9	[{"id_menu":7,"count":1}]	9304	delivery	5	14
105052	2020-07-27 18:18:17	2020-07-27	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	6499	delivery	5	45
105053	2020-07-27 18:18:51	2020-07-27	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	40409	delivery	5	26
105054	2020-07-27 18:29:16	2020-07-27	8	[{"id_menu":5,"count":1}]	40316	delivery	5	13
105055	2020-07-27 18:30:49	2020-07-27	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	23988	delivery	5	31
105056	2020-07-27 18:34:16	2020-07-27	17	[{"id_menu":4,"count":1}]	3830	pick-up	0	17
105057	2020-07-27 18:39:54	2020-07-27	12	[{"id_menu":3,"count":1}]	35100	delivery	5	17
105058	2020-07-27 18:40:21	2020-07-27	14	[{"id_menu":2,"count":2}]	14668	delivery	5	19
105059	2020-07-27 18:41:29	2020-07-27	17	[{"id_menu":4,"count":1}]	33732	pick-up	0	17
105060	2020-07-27 18:51:39	2020-07-27	12	[{"id_menu":1,"count":1}]	29226	pick-up	0	12
105061	2020-07-27 18:57:16	2020-07-27	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	14279	delivery	5	27
105062	2020-07-27 18:58:26	2020-07-27	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40448	delivery	5	40
105063	2020-07-27 19:03:28	2020-07-27	12	[{"id_menu":1,"count":1}]	10242	delivery	5	17
105064	2020-07-27 19:06:23	2020-07-27	17	[{"id_menu":4,"count":1}]	13731	pick-up	0	17
105065	2020-07-27 19:09:28	2020-07-27	9	[{"id_menu":7,"count":1}]	39900	delivery	5	14
105066	2020-07-27 19:12:54	2020-07-27	9	[{"id_menu":7,"count":1}]	1638	delivery	5	14
105067	2020-07-27 19:15:32	2020-07-27	9	[{"id_menu":7,"count":2}]	2409	delivery	5	14
105068	2020-07-27 19:24:30	2020-07-27	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	40465	delivery	5	48
105069	2020-07-27 19:30:03	2020-07-27	12	[{"id_menu":1,"count":1}]	39399	delivery	5	17
105070	2020-07-27 19:32:48	2020-07-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	17797	delivery	5	23
105071	2020-07-27 19:35:23	2020-07-27	9	[{"id_menu":6,"count":1}]	40378	pick-up	0	9
105072	2020-07-27 19:38:03	2020-07-27	14	[{"id_menu":2,"count":1}]	10466	delivery	5	19
105073	2020-07-27 19:40:55	2020-07-27	14	[{"id_menu":2,"count":1}]	33202	delivery	5	19
105074	2020-07-27 19:41:51	2020-07-27	12	[{"id_menu":1,"count":1}]	40425	delivery	5	17
105075	2020-07-27 19:45:41	2020-07-27	9	[{"id_menu":7,"count":1}]	23860	delivery	5	14
105076	2020-07-27 19:46:16	2020-07-27	8	[{"id_menu":5,"count":3}]	25825	delivery	5	13
105077	2020-07-27 19:53:03	2020-07-27	14	[{"id_menu":2,"count":1}]	10434	delivery	5	19
105078	2020-07-27 20:04:55	2020-07-27	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	6156	delivery	5	40
105079	2020-07-27 20:13:58	2020-07-27	12	[{"id_menu":1,"count":1}]	40230	delivery	5	17
105080	2020-07-27 20:18:04	2020-07-27	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5109	delivery	5	22
105081	2020-07-27 20:19:03	2020-07-27	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	31549	delivery	5	26
105082	2020-07-27 20:19:44	2020-07-27	14	[{"id_menu":2,"count":1}]	3736	delivery	5	19
105083	2020-07-27 20:22:39	2020-07-27	9	[{"id_menu":6,"count":1}]	15063	delivery	5	14
105084	2020-07-27 20:23:17	2020-07-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8180	pick-up	0	17
105085	2020-07-27 20:25:47	2020-07-27	12	[{"id_menu":3,"count":1}]	5097	delivery	5	17
105086	2020-07-27 20:27:44	2020-07-27	12	[{"id_menu":1,"count":1}]	40449	delivery	5	17
105087	2020-07-27 20:32:05	2020-07-27	17	[{"id_menu":4,"count":1}]	40463	delivery	5	22
105088	2020-07-27 20:35:35	2020-07-27	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14254	delivery	5	36
105089	2020-07-27 20:38:53	2020-07-27	8	[{"id_menu":5,"count":1}]	24725	pick-up	0	8
105090	2020-07-27 20:41:12	2020-07-27	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	28663	delivery	5	26
105091	2020-07-27 20:44:23	2020-07-27	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	40394	delivery	5	26
105092	2020-07-27 20:46:50	2020-07-27	17	[{"id_menu":4,"count":1}]	4585	pick-up	0	17
105093	2020-07-27 20:49:10	2020-07-27	17	[{"id_menu":4,"count":1}]	18981	delivery	5	22
105094	2020-07-27 21:00:44	2020-07-27	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32729	delivery	5	37
105095	2020-07-27 21:04:06	2020-07-27	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	25444	delivery	5	52
105096	2020-07-27 21:04:50	2020-07-27	9	[{"id_menu":6,"count":1}]	12138	pick-up	0	9
105097	2020-07-27 21:09:12	2020-07-27	9	[{"id_menu":7,"count":3}]	29470	delivery	5	14
105098	2020-07-27 21:09:13	2020-07-27	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	23758	delivery	5	26
105099	2020-07-27 21:12:33	2020-07-27	14	[{"id_menu":2,"count":1}]	17140	delivery	5	19
105100	2020-07-27 21:13:18	2020-07-27	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	40396	delivery	5	28
105101	2020-07-27 21:14:59	2020-07-27	17	[{"id_menu":4,"count":1}]	40235	pick-up	0	17
105102	2020-07-27 21:25:01	2020-07-27	9	[{"id_menu":6,"count":1}]	6207	delivery	5	14
105103	2020-07-27 21:34:07	2020-07-27	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	29283	pick-up	0	21
105104	2020-07-27 21:35:34	2020-07-27	12	[{"id_menu":3,"count":1}]	19144	delivery	5	17
105105	2020-07-27 21:37:48	2020-07-27	14	[{"id_menu":2,"count":1}]	7293	delivery	5	19
105106	2020-07-27 21:38:06	2020-07-27	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13621	delivery	5	31
105107	2020-07-27 21:41:23	2020-07-27	9	[{"id_menu":6,"count":1}]	29601	delivery	5	14
105108	2020-07-27 21:46:08	2020-07-27	8	[{"id_menu":5,"count":1}]	4139	pick-up	0	8
105109	2020-07-27 21:47:14	2020-07-27	9	[{"id_menu":7,"count":1}]	6219	delivery	5	14
105110	2020-07-27 21:53:21	2020-07-27	8	[{"id_menu":5,"count":2}]	1031	delivery	5	13
105111	2020-07-27 21:55:00	2020-07-27	14	[{"id_menu":2,"count":1}]	7200	delivery	5	19
105112	2020-07-27 21:56:31	2020-07-27	12	[{"id_menu":1,"count":1}]	5974	delivery	5	17
105113	2020-07-27 21:57:57	2020-07-27	14	[{"id_menu":2,"count":1}]	3502	delivery	5	19
105114	2020-07-27 22:02:50	2020-07-27	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	40260	delivery	5	31
105115	2020-07-27 22:02:55	2020-07-27	12	[{"id_menu":3,"count":1}]	27107	delivery	5	17
105116	2020-07-27 22:04:12	2020-07-27	8	[{"id_menu":5,"count":1}]	12530	delivery	5	13
105117	2020-07-27 22:07:15	2020-07-27	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	40294	delivery	5	45
105118	2020-07-27 22:12:59	2020-07-27	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2616	pick-up	0	26
105119	2020-07-27 22:13:06	2020-07-27	17	[{"id_menu":4,"count":2}]	4015	pick-up	0	17
105120	2020-07-27 22:13:52	2020-07-27	9	[{"id_menu":6,"count":1}]	40373	delivery	5	14
105121	2020-07-27 22:15:34	2020-07-27	17	[{"id_menu":4,"count":1}]	40293	delivery	5	22
105122	2020-07-27 22:17:24	2020-07-27	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	22125	delivery	5	31
105123	2020-07-27 22:26:33	2020-07-27	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	40330	delivery	5	45
105124	2020-07-27 22:27:27	2020-07-27	17	[{"id_menu":4,"count":1}]	12717	pick-up	0	17
105125	2020-07-27 22:32:59	2020-07-27	17	[{"id_menu":4,"count":1}]	35047	delivery	5	22
105126	2020-07-27 22:36:45	2020-07-27	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	30070	delivery	5	38
105127	2020-07-27 22:38:53	2020-07-27	17	[{"id_menu":4,"count":1}]	36620	delivery	5	22
105128	2020-07-27 22:39:06	2020-07-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39925	delivery	5	22
105129	2020-07-27 22:40:05	2020-07-27	17	[{"id_menu":4,"count":1}]	39119	pick-up	0	17
105130	2020-07-27 22:42:41	2020-07-27	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	40249	delivery	5	43
105131	2020-07-27 22:50:32	2020-07-27	14	[{"id_menu":2,"count":1}]	40374	delivery	5	19
105132	2020-07-27 22:52:26	2020-07-27	17	[{"id_menu":4,"count":1}]	40244	delivery	5	22
105133	2020-07-27 22:54:27	2020-07-27	12	[{"id_menu":1,"count":1}]	40441	delivery	5	17
105134	2020-07-27 22:59:29	2020-07-27	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14169	delivery	5	22
105135	2020-07-27 23:06:54	2020-07-27	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	40271	pick-up	0	17
105136	2020-07-27 23:09:51	2020-07-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11530	delivery	5	23
105137	2020-07-27 23:11:24	2020-07-27	17	[{"id_menu":4,"count":1}]	7253	delivery	5	22
105138	2020-07-27 23:14:09	2020-07-27	9	[{"id_menu":6,"count":1}]	40259	delivery	5	14
105139	2020-07-27 23:20:16	2020-07-27	9	[{"id_menu":7,"count":1}]	40252	delivery	5	14
105140	2020-07-27 23:23:12	2020-07-27	9	[{"id_menu":6,"count":1}]	19146	delivery	5	14
105141	2020-07-27 23:27:15	2020-07-27	17	[{"id_menu":4,"count":2}]	33282	delivery	5	22
105142	2020-07-27 23:35:07	2020-07-27	17	[{"id_menu":4,"count":1}]	26676	pick-up	0	17
105143	2020-07-27 23:37:32	2020-07-27	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	12012	delivery	5	26
105144	2020-07-27 23:39:15	2020-07-27	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	23276	delivery	5	30
105145	2020-07-27 23:40:12	2020-07-27	14	[{"id_menu":2,"count":1}]	31815	delivery	5	19
105146	2020-07-27 23:42:14	2020-07-27	9	[{"id_menu":6,"count":3}]	22410	delivery	5	14
105147	2020-07-27 23:43:09	2020-07-27	9	[{"id_menu":6,"count":1}]	40255	delivery	5	14
105148	2020-07-27 23:46:05	2020-07-27	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	6644	pick-up	0	22
105149	2020-07-27 23:46:55	2020-07-27	14	[{"id_menu":2,"count":1}]	33634	delivery	5	19
105150	2020-07-27 23:47:56	2020-07-27	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40401	delivery	5	37
105151	2020-07-27 23:48:13	2020-07-27	14	[{"id_menu":2,"count":1}]	40445	delivery	5	19
105152	2020-07-27 23:49:44	2020-07-27	14	[{"id_menu":2,"count":1}]	1800	pick-up	0	14
105153	2020-07-27 23:54:23	2020-07-27	9	[{"id_menu":6,"count":1}]	10717	pick-up	0	9
105154	2020-07-27 23:56:19	2020-07-27	14	[{"id_menu":2,"count":1}]	40364	pick-up	0	14
105155	2020-07-28 00:00:54	2020-07-28	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	29265	delivery	5	39
105156	2020-07-28 00:04:12	2020-07-28	9	[{"id_menu":6,"count":1}]	40524	delivery	5	14
105157	2020-07-28 00:08:23	2020-07-28	8	[{"id_menu":5,"count":1}]	11488	delivery	5	13
105158	2020-07-28 00:09:34	2020-07-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	38584	delivery	5	23
105159	2020-07-28 00:09:40	2020-07-28	14	[{"id_menu":2,"count":1}]	7566	pick-up	0	14
105160	2020-07-28 00:10:36	2020-07-28	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9804	delivery	5	52
105161	2020-07-28 00:13:35	2020-07-28	14	[{"id_menu":2,"count":1}]	2168	pick-up	0	14
105162	2020-07-28 00:13:57	2020-07-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	27410	delivery	5	23
105163	2020-07-28 00:18:59	2020-07-28	12	[{"id_menu":3,"count":1}]	3826	pick-up	0	12
105164	2020-07-28 00:20:27	2020-07-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	23602	pick-up	0	26
105165	2020-07-28 00:28:09	2020-07-28	9	[{"id_menu":6,"count":1}]	40553	delivery	5	14
105166	2020-07-28 00:31:54	2020-07-28	9	[{"id_menu":7,"count":1}]	16045	delivery	5	14
105167	2020-07-28 00:33:22	2020-07-28	9	[{"id_menu":6,"count":1}]	39073	delivery	5	14
105168	2020-07-28 00:33:27	2020-07-28	9	[{"id_menu":7,"count":1}]	11390	delivery	5	14
105169	2020-07-28 00:34:03	2020-07-28	14	[{"id_menu":2,"count":1}]	40674	delivery	5	19
105170	2020-07-28 00:37:49	2020-07-28	9	[{"id_menu":6,"count":1}]	27289	delivery	5	14
105171	2020-07-28 00:39:27	2020-07-28	9	[{"id_menu":7,"count":1}]	40680	delivery	5	14
105172	2020-07-28 00:41:29	2020-07-28	17	[{"id_menu":4,"count":1}]	24041	pick-up	0	17
105173	2020-07-28 00:43:03	2020-07-28	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40640	delivery	5	40
105174	2020-07-28 00:43:15	2020-07-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17351	pick-up	0	17
105175	2020-07-28 00:44:52	2020-07-28	9	[{"id_menu":6,"count":1}]	24629	delivery	5	14
105176	2020-07-28 00:50:50	2020-07-28	12	[{"id_menu":3,"count":1}]	40681	delivery	5	17
105177	2020-07-28 00:51:14	2020-07-28	9	[{"id_menu":6,"count":1}]	15614	delivery	5	14
105178	2020-07-28 00:53:02	2020-07-28	9	[{"id_menu":7,"count":1}]	40573	delivery	5	14
105179	2020-07-28 00:55:13	2020-07-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	40490	delivery	5	28
105180	2020-07-28 00:56:14	2020-07-28	9	[{"id_menu":7,"count":1}]	2594	pick-up	0	9
105181	2020-07-28 00:58:09	2020-07-28	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	24260	pick-up	0	26
105182	2020-07-28 00:58:24	2020-07-28	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	16550	delivery	5	25
105183	2020-07-28 00:59:42	2020-07-28	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12099	delivery	5	45
105184	2020-07-28 01:00:50	2020-07-28	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	20571	delivery	5	43
105185	2020-07-28 01:08:16	2020-07-28	9	[{"id_menu":6,"count":1}]	1438	pick-up	0	9
105186	2020-07-28 01:08:50	2020-07-28	9	[{"id_menu":7,"count":1}]	26018	delivery	5	14
105187	2020-07-28 01:11:55	2020-07-28	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	34688	delivery	5	53
105188	2020-07-28 01:20:14	2020-07-28	9	[{"id_menu":7,"count":1}]	40574	delivery	5	14
105189	2020-07-28 01:25:09	2020-07-28	17	[{"id_menu":4,"count":1}]	38404	pick-up	0	17
105190	2020-07-28 01:30:04	2020-07-28	17	[{"id_menu":4,"count":1}]	40633	delivery	5	22
105191	2020-07-28 01:30:19	2020-07-28	12	[{"id_menu":3,"count":1}]	30757	delivery	5	17
105192	2020-07-28 01:33:51	2020-07-28	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	40499	pick-up	0	21
105193	2020-07-28 01:34:00	2020-07-28	9	[{"id_menu":6,"count":3}]	40699	delivery	5	14
105194	2020-07-28 01:36:47	2020-07-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39973	delivery	5	22
105195	2020-07-28 01:38:01	2020-07-28	17	[{"id_menu":4,"count":1}]	37084	pick-up	0	17
105196	2020-07-28 01:39:38	2020-07-28	9	[{"id_menu":7,"count":1}]	40634	pick-up	0	9
105197	2020-07-28 01:43:28	2020-07-28	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":2}]	32130	delivery	5	31
105198	2020-07-28 01:47:02	2020-07-28	17	[{"id_menu":4,"count":1}]	40543	delivery	5	22
105199	2020-07-28 01:47:05	2020-07-28	12	[{"id_menu":3,"count":2}]	1039	delivery	5	17
105200	2020-07-28 01:47:49	2020-07-28	12	[{"id_menu":1,"count":1}]	2796	pick-up	0	12
105201	2020-07-28 01:50:50	2020-07-28	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32945	delivery	5	35
105202	2020-07-28 01:54:42	2020-07-28	12	[{"id_menu":1,"count":1}]	3989	delivery	5	17
105203	2020-07-28 01:55:23	2020-07-28	9	[{"id_menu":7,"count":1}]	34818	delivery	5	14
105204	2020-07-28 01:56:37	2020-07-28	12	[{"id_menu":3,"count":1}]	23689	delivery	5	17
105205	2020-07-28 02:00:16	2020-07-28	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	25594	delivery	5	27
105206	2020-07-28 02:01:21	2020-07-28	8	[{"id_menu":5,"count":1}]	40564	pick-up	0	8
105207	2020-07-28 02:06:21	2020-07-28	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1445	pick-up	0	31
105208	2020-07-28 02:15:26	2020-07-28	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	26033	delivery	5	26
105209	2020-07-28 02:18:23	2020-07-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	28982	delivery	5	31
105210	2020-07-28 02:19:52	2020-07-28	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	40479	delivery	5	34
105211	2020-07-28 02:20:06	2020-07-28	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	40538	delivery	5	30
105212	2020-07-28 02:21:04	2020-07-28	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	40721	delivery	5	44
105213	2020-07-28 02:21:12	2020-07-28	9	[{"id_menu":6,"count":1}]	29637	delivery	5	14
105214	2020-07-28 02:22:32	2020-07-28	12	[{"id_menu":1,"count":1}]	14531	pick-up	0	12
105215	2020-07-28 02:26:41	2020-07-28	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	26643	delivery	5	36
105216	2020-07-28 02:29:30	2020-07-28	14	[{"id_menu":2,"count":1}]	29296	delivery	5	19
105217	2020-07-28 02:47:59	2020-07-28	17	[{"id_menu":4,"count":1}]	14642	delivery	5	22
105218	2020-07-28 02:48:11	2020-07-28	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40482	delivery	5	54
105219	2020-07-28 02:49:56	2020-07-28	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	33129	delivery	5	36
105220	2020-07-28 02:55:33	2020-07-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	17154	delivery	5	22
105221	2020-07-28 02:57:59	2020-07-28	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	28174	delivery	5	40
105222	2020-07-28 02:59:05	2020-07-28	12	[{"id_menu":1,"count":1}]	1263	pick-up	0	12
105223	2020-07-28 02:59:21	2020-07-28	12	[{"id_menu":3,"count":1}]	40676	delivery	5	17
105224	2020-07-28 03:00:19	2020-07-28	17	[{"id_menu":4,"count":1}]	8463	pick-up	0	17
105225	2020-07-28 03:02:49	2020-07-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1944	pick-up	0	23
105226	2020-07-28 03:05:20	2020-07-28	9	[{"id_menu":7,"count":1}]	40608	delivery	5	14
105227	2020-07-28 03:14:22	2020-07-28	9	[{"id_menu":6,"count":1}]	36817	delivery	5	14
105228	2020-07-28 03:15:27	2020-07-28	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	17353	pick-up	0	21
105229	2020-07-28 03:18:43	2020-07-28	17	[{"id_menu":4,"count":1}]	37834	delivery	5	22
105230	2020-07-28 03:18:50	2020-07-28	9	[{"id_menu":7,"count":1}]	40410	delivery	5	14
105231	2020-07-28 03:18:57	2020-07-28	9	[{"id_menu":6,"count":1}]	6156	pick-up	0	9
105232	2020-07-28 03:24:41	2020-07-28	17	[{"id_menu":4,"count":1}]	22946	delivery	5	22
105233	2020-07-28 03:24:55	2020-07-28	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	30074	delivery	5	26
105234	2020-07-28 03:26:01	2020-07-28	8	[{"id_menu":5,"count":1}]	14734	delivery	5	13
105235	2020-07-28 03:26:28	2020-07-28	17	[{"id_menu":4,"count":1}]	32218	delivery	5	22
105236	2020-07-28 03:33:07	2020-07-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3629	delivery	5	28
105237	2020-07-28 03:33:20	2020-07-28	9	[{"id_menu":7,"count":2}]	19172	delivery	5	14
105238	2020-07-28 03:35:38	2020-07-28	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11505	delivery	5	57
105239	2020-07-28 03:37:30	2020-07-28	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	40598	delivery	5	28
105240	2020-07-28 03:38:12	2020-07-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40582	delivery	5	23
105241	2020-07-28 03:39:26	2020-07-28	9	[{"id_menu":6,"count":1}]	13613	pick-up	0	9
105242	2020-07-28 03:45:03	2020-07-28	9	[{"id_menu":6,"count":1}]	9783	delivery	5	14
105243	2020-07-28 03:48:34	2020-07-28	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	593	pick-up	0	40
105244	2020-07-28 03:49:34	2020-07-28	8	[{"id_menu":5,"count":1}]	5335	delivery	5	13
105245	2020-07-28 03:50:22	2020-07-28	12	[{"id_menu":3,"count":1}]	40628	delivery	5	17
105246	2020-07-28 03:51:20	2020-07-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	40619	delivery	5	22
105247	2020-07-28 03:52:58	2020-07-28	14	[{"id_menu":2,"count":2}]	40650	delivery	5	19
105248	2020-07-28 03:56:11	2020-07-28	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":2}]	40651	delivery	5	28
105249	2020-07-28 03:57:08	2020-07-28	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	11494	pick-up	0	21
105250	2020-07-28 03:57:16	2020-07-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	40496	delivery	5	31
105251	2020-07-28 03:58:36	2020-07-28	9	[{"id_menu":7,"count":1}]	40702	delivery	5	14
105252	2020-07-28 04:01:01	2020-07-28	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19759	delivery	5	37
105253	2020-07-28 04:01:18	2020-07-28	12	[{"id_menu":1,"count":1}]	5539	pick-up	0	12
105254	2020-07-28 04:01:55	2020-07-28	9	[{"id_menu":6,"count":1}]	40604	delivery	5	14
105255	2020-07-28 04:12:54	2020-07-28	12	[{"id_menu":1,"count":1}]	28078	delivery	5	17
105256	2020-07-28 04:19:52	2020-07-28	12	[{"id_menu":1,"count":1}]	40695	delivery	5	17
105257	2020-07-28 04:20:09	2020-07-28	8	[{"id_menu":5,"count":1}]	40518	delivery	5	13
105258	2020-07-28 04:21:21	2020-07-28	14	[{"id_menu":2,"count":1}]	40643	delivery	5	19
105259	2020-07-28 04:22:01	2020-07-28	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	40488	delivery	5	38
105260	2020-07-28 04:22:28	2020-07-28	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	40637	delivery	5	34
105261	2020-07-28 04:25:10	2020-07-28	12	[{"id_menu":1,"count":2}]	40627	delivery	5	17
105262	2020-07-28 04:31:35	2020-07-28	9	[{"id_menu":7,"count":1}]	40510	delivery	5	14
105263	2020-07-28 04:33:54	2020-07-28	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	22071	pick-up	0	31
105264	2020-07-28 04:35:24	2020-07-28	14	[{"id_menu":2,"count":1}]	2575	pick-up	0	14
105265	2020-07-28 04:37:29	2020-07-28	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	12001	delivery	5	31
105266	2020-07-28 04:42:25	2020-07-28	8	[{"id_menu":5,"count":1}]	3858	pick-up	0	8
105267	2020-07-28 04:51:17	2020-07-28	9	[{"id_menu":7,"count":1}]	18247	delivery	5	14
105268	2020-07-28 04:56:22	2020-07-28	8	[{"id_menu":5,"count":1}]	40673	delivery	5	13
105269	2020-07-28 04:57:28	2020-07-28	9	[{"id_menu":7,"count":1}]	24274	pick-up	0	9
105270	2020-07-28 04:57:29	2020-07-28	12	[{"id_menu":1,"count":1}]	28331	pick-up	0	12
105271	2020-07-28 04:57:31	2020-07-28	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	40559	delivery	5	26
105272	2020-07-28 04:57:43	2020-07-28	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	24807	delivery	5	27
105273	2020-07-28 05:06:52	2020-07-28	14	[{"id_menu":2,"count":1}]	20697	pick-up	0	14
105274	2020-07-28 05:07:57	2020-07-28	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	39327	delivery	5	26
105275	2020-07-28 05:11:34	2020-07-28	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	35374	delivery	5	29
105276	2020-07-28 05:13:48	2020-07-28	12	[{"id_menu":1,"count":1}]	19268	delivery	5	17
105277	2020-07-28 05:14:02	2020-07-28	9	[{"id_menu":7,"count":1}]	40548	delivery	5	14
105278	2020-07-28 05:15:11	2020-07-28	12	[{"id_menu":1,"count":1}]	16520	delivery	5	17
105279	2020-07-28 05:17:50	2020-07-28	8	[{"id_menu":5,"count":1}]	32926	delivery	5	13
105280	2020-07-28 05:19:47	2020-07-28	9	[{"id_menu":6,"count":1}]	24293	delivery	5	14
105281	2020-07-28 05:23:17	2020-07-28	12	[{"id_menu":1,"count":1}]	18770	delivery	5	17
105282	2020-07-28 05:28:07	2020-07-28	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	24609	pick-up	0	21
105283	2020-07-28 05:31:39	2020-07-28	17	[{"id_menu":4,"count":1}]	27777	pick-up	0	17
105284	2020-07-28 05:48:20	2020-07-28	8	[{"id_menu":5,"count":1}]	38898	delivery	5	13
105285	2020-07-28 05:49:13	2020-07-28	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	14851	pick-up	0	21
105286	2020-07-28 05:50:39	2020-07-28	14	[{"id_menu":2,"count":1}]	12895	delivery	5	19
105287	2020-07-28 05:57:02	2020-07-28	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	38996	delivery	5	31
105288	2020-07-28 05:59:47	2020-07-28	8	[{"id_menu":5,"count":1}]	34330	delivery	5	13
105289	2020-07-28 06:07:10	2020-07-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	33467	delivery	5	31
105290	2020-07-28 06:13:14	2020-07-28	8	[{"id_menu":5,"count":1}]	40642	delivery	5	13
105291	2020-07-28 06:13:15	2020-07-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	19706	delivery	5	31
105292	2020-07-28 06:14:02	2020-07-28	12	[{"id_menu":1,"count":1}]	35500	delivery	5	17
105293	2020-07-28 06:14:44	2020-07-28	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	8212	delivery	5	38
105294	2020-07-28 06:18:14	2020-07-28	9	[{"id_menu":6,"count":1}]	34291	delivery	5	14
105295	2020-07-28 06:27:01	2020-07-28	8	[{"id_menu":5,"count":1}]	17671	delivery	5	13
105296	2020-07-28 06:27:31	2020-07-28	14	[{"id_menu":2,"count":1}]	14788	delivery	5	19
105297	2020-07-28 06:31:59	2020-07-28	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	40545	delivery	5	34
105298	2020-07-28 06:36:18	2020-07-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36213	delivery	5	23
105299	2020-07-28 06:37:00	2020-07-28	17	[{"id_menu":4,"count":1}]	28516	delivery	5	22
105300	2020-07-28 06:37:23	2020-07-28	9	[{"id_menu":7,"count":2}]	17835	delivery	5	14
105301	2020-07-28 06:40:06	2020-07-28	14	[{"id_menu":2,"count":1}]	40718	delivery	5	19
105302	2020-07-28 06:40:25	2020-07-28	9	[{"id_menu":6,"count":1}]	36182	pick-up	0	9
105303	2020-07-28 06:41:13	2020-07-28	8	[{"id_menu":5,"count":1}]	3314	delivery	5	13
105304	2020-07-28 06:43:30	2020-07-28	9	[{"id_menu":6,"count":1}]	13713	delivery	5	14
105305	2020-07-28 06:50:45	2020-07-28	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	40568	delivery	5	37
105306	2020-07-28 06:51:20	2020-07-28	17	[{"id_menu":4,"count":1}]	27028	pick-up	0	17
105307	2020-07-28 06:51:47	2020-07-28	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	40639	delivery	5	26
105308	2020-07-28 06:54:09	2020-07-28	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	40641	pick-up	0	31
105309	2020-07-28 06:55:15	2020-07-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	40522	delivery	5	31
105310	2020-07-28 07:01:13	2020-07-28	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	40590	delivery	5	26
105311	2020-07-28 07:04:28	2020-07-28	9	[{"id_menu":6,"count":2}]	30743	delivery	5	14
105312	2020-07-28 07:05:14	2020-07-28	8	[{"id_menu":5,"count":1}]	17503	delivery	5	13
105313	2020-07-28 07:10:09	2020-07-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	40694	delivery	5	28
105314	2020-07-28 07:15:07	2020-07-28	9	[{"id_menu":6,"count":1}]	37142	delivery	5	14
105315	2020-07-28 07:24:38	2020-07-28	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	40567	delivery	5	39
105316	2020-07-28 07:25:23	2020-07-28	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":2}]	3806	delivery	5	30
105317	2020-07-28 07:26:36	2020-07-28	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	18898	delivery	5	45
105318	2020-07-28 07:29:48	2020-07-28	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	27095	delivery	5	26
105319	2020-07-28 07:33:36	2020-07-28	9	[{"id_menu":6,"count":1}]	40509	delivery	5	14
105320	2020-07-28 07:33:54	2020-07-28	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40684	delivery	5	31
105321	2020-07-28 07:38:10	2020-07-28	9	[{"id_menu":7,"count":1}]	10885	delivery	5	14
105322	2020-07-28 07:43:20	2020-07-28	12	[{"id_menu":3,"count":1}]	997	delivery	5	17
105323	2020-07-28 07:50:31	2020-07-28	12	[{"id_menu":3,"count":1}]	40583	delivery	5	17
105324	2020-07-28 07:53:58	2020-07-28	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	37451	pick-up	0	31
105325	2020-07-28 07:57:30	2020-07-28	12	[{"id_menu":1,"count":1}]	40507	delivery	5	17
105326	2020-07-28 07:58:11	2020-07-28	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	32212	delivery	5	30
105327	2020-07-28 07:58:39	2020-07-28	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	40623	pick-up	0	31
105328	2020-07-28 08:04:24	2020-07-28	12	[{"id_menu":1,"count":1}]	10336	delivery	5	17
105329	2020-07-28 08:09:56	2020-07-28	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	40622	delivery	5	36
105330	2020-07-28 08:10:45	2020-07-28	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":2}]	40655	delivery	5	22
105331	2020-07-28 08:12:49	2020-07-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	40589	delivery	5	31
105332	2020-07-28 08:13:57	2020-07-28	14	[{"id_menu":2,"count":1}]	26209	pick-up	0	14
105333	2020-07-28 08:16:28	2020-07-28	14	[{"id_menu":2,"count":1}]	40631	delivery	5	19
105334	2020-07-28 08:25:39	2020-07-28	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9071	delivery	5	34
105335	2020-07-28 08:27:44	2020-07-28	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	17412	delivery	5	26
105336	2020-07-28 08:29:59	2020-07-28	8	[{"id_menu":5,"count":1}]	2116	pick-up	0	8
105337	2020-07-28 08:43:17	2020-07-28	12	[{"id_menu":1,"count":1}]	627	pick-up	0	12
105338	2020-07-28 08:44:31	2020-07-28	9	[{"id_menu":7,"count":1}]	7615	pick-up	0	9
105339	2020-07-28 08:51:07	2020-07-28	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18090	delivery	5	36
105340	2020-07-28 08:56:21	2020-07-28	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	450	delivery	5	25
105341	2020-07-28 08:56:55	2020-07-28	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	40495	delivery	5	31
105342	2020-07-28 09:02:35	2020-07-28	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	22298	delivery	5	35
105343	2020-07-28 09:05:21	2020-07-28	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	40602	delivery	5	23
105344	2020-07-28 09:06:40	2020-07-28	12	[{"id_menu":1,"count":1}]	40571	delivery	5	17
105345	2020-07-28 09:07:16	2020-07-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	40700	delivery	5	31
105346	2020-07-28 09:08:57	2020-07-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	36081	delivery	5	22
105347	2020-07-28 09:10:05	2020-07-28	12	[{"id_menu":3,"count":1}]	13136	pick-up	0	12
105348	2020-07-28 09:10:21	2020-07-28	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14081	pick-up	0	30
105349	2020-07-28 09:10:30	2020-07-28	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13518	delivery	5	57
105350	2020-07-28 09:13:26	2020-07-28	17	[{"id_menu":4,"count":2}]	3362	pick-up	0	17
105351	2020-07-28 09:17:38	2020-07-28	17	[{"id_menu":4,"count":1}]	11183	delivery	5	22
105352	2020-07-28 09:19:45	2020-07-28	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	28720	delivery	5	26
105353	2020-07-28 09:23:40	2020-07-28	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	26677	delivery	5	36
105354	2020-07-28 09:27:31	2020-07-28	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	38738	delivery	5	40
105355	2020-07-28 09:35:50	2020-07-28	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":2}]	40505	delivery	5	26
105356	2020-07-28 09:36:24	2020-07-28	12	[{"id_menu":3,"count":1}]	26220	delivery	5	17
105357	2020-07-28 09:43:25	2020-07-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	40683	delivery	5	22
105358	2020-07-28 09:45:21	2020-07-28	12	[{"id_menu":3,"count":1}]	34788	delivery	5	17
105359	2020-07-28 09:46:43	2020-07-28	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	18355	delivery	5	38
105360	2020-07-28 09:47:32	2020-07-28	9	[{"id_menu":6,"count":1}]	28362	delivery	5	14
105361	2020-07-28 09:47:39	2020-07-28	17	[{"id_menu":4,"count":1}]	9782	delivery	5	22
105362	2020-07-28 09:51:51	2020-07-28	8	[{"id_menu":5,"count":1}]	2519	delivery	5	13
105363	2020-07-28 10:02:22	2020-07-28	12	[{"id_menu":3,"count":1}]	7058	pick-up	0	12
105364	2020-07-28 10:03:23	2020-07-28	12	[{"id_menu":1,"count":1}]	12827	delivery	5	17
105365	2020-07-28 10:03:27	2020-07-28	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	24975	delivery	5	25
105366	2020-07-28 10:07:25	2020-07-28	8	[{"id_menu":5,"count":1}]	197	pick-up	0	8
105367	2020-07-28 10:15:31	2020-07-28	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15654	delivery	5	45
105368	2020-07-28 10:17:23	2020-07-28	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	40618	delivery	5	36
105369	2020-07-28 10:17:52	2020-07-28	9	[{"id_menu":6,"count":1}]	38112	delivery	5	14
105370	2020-07-28 10:19:46	2020-07-28	9	[{"id_menu":6,"count":1}]	40470	delivery	5	14
105371	2020-07-28 10:23:17	2020-07-28	9	[{"id_menu":6,"count":1}]	40615	pick-up	0	9
105372	2020-07-28 10:27:43	2020-07-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	40519	delivery	5	28
105373	2020-07-28 10:38:42	2020-07-28	12	[{"id_menu":1,"count":1}]	14722	delivery	5	17
105374	2020-07-28 10:42:34	2020-07-28	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	34237	delivery	5	34
105375	2020-07-28 10:50:57	2020-07-28	9	[{"id_menu":7,"count":1}]	10435	delivery	5	14
105376	2020-07-28 10:53:52	2020-07-28	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	40477	delivery	5	34
105377	2020-07-28 10:54:33	2020-07-28	17	[{"id_menu":4,"count":1}]	40678	delivery	5	22
105378	2020-07-28 10:57:22	2020-07-28	14	[{"id_menu":2,"count":1}]	40670	delivery	5	19
105379	2020-07-28 11:10:06	2020-07-28	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	17685	pick-up	0	35
105380	2020-07-28 11:10:12	2020-07-28	8	[{"id_menu":5,"count":1}]	3195	delivery	5	13
105381	2020-07-28 11:10:17	2020-07-28	12	[{"id_menu":1,"count":1}]	30078	delivery	5	17
105382	2020-07-28 11:13:24	2020-07-28	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	40701	delivery	5	43
105383	2020-07-28 11:18:49	2020-07-28	38	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	40530	delivery	5	43
105384	2020-07-28 11:19:02	2020-07-28	17	[{"id_menu":4,"count":1}]	38399	delivery	5	22
105385	2020-07-28 11:20:37	2020-07-28	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	28367	delivery	5	28
105386	2020-07-28 11:24:48	2020-07-28	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	36504	delivery	5	25
105387	2020-07-28 11:27:58	2020-07-28	14	[{"id_menu":2,"count":1}]	24380	delivery	5	19
105388	2020-07-28 11:30:14	2020-07-28	8	[{"id_menu":5,"count":1}]	40534	delivery	5	13
105389	2020-07-28 11:30:47	2020-07-28	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	40599	delivery	5	29
105390	2020-07-28 11:33:02	2020-07-28	14	[{"id_menu":2,"count":1}]	40515	delivery	5	19
105391	2020-07-28 11:33:09	2020-07-28	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	40540	pick-up	0	24
105392	2020-07-28 11:40:02	2020-07-28	9	[{"id_menu":6,"count":1}]	40606	delivery	5	14
105393	2020-07-28 11:53:50	2020-07-28	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	34247	delivery	5	36
105394	2020-07-28 11:55:16	2020-07-28	9	[{"id_menu":6,"count":1}]	2816	pick-up	0	9
105395	2020-07-28 11:59:22	2020-07-28	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	29695	pick-up	0	22
105396	2020-07-28 12:00:41	2020-07-28	12	[{"id_menu":3,"count":1}]	26496	delivery	5	17
105397	2020-07-28 12:03:25	2020-07-28	9	[{"id_menu":7,"count":1}]	6407	delivery	5	14
105398	2020-07-28 12:04:19	2020-07-28	14	[{"id_menu":2,"count":1}]	3174	pick-up	0	14
105399	2020-07-28 12:05:57	2020-07-28	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	40692	delivery	5	26
105400	2020-07-28 12:06:28	2020-07-28	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7763	delivery	5	44
105401	2020-07-28 12:06:29	2020-07-28	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3312	delivery	5	55
105402	2020-07-28 12:08:33	2020-07-28	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	40656	delivery	5	31
105403	2020-07-28 12:14:33	2020-07-28	8	[{"id_menu":5,"count":1}]	9907	pick-up	0	8
105404	2020-07-28 12:19:29	2020-07-28	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	35574	pick-up	0	34
105405	2020-07-28 12:32:31	2020-07-28	17	[{"id_menu":4,"count":1}]	35168	pick-up	0	17
105406	2020-07-28 12:35:02	2020-07-28	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	40557	delivery	5	36
105407	2020-07-28 12:35:22	2020-07-28	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	34767	delivery	5	42
105408	2020-07-28 12:45:26	2020-07-28	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	40145	delivery	5	39
105409	2020-07-28 12:45:51	2020-07-28	12	[{"id_menu":3,"count":1}]	1521	pick-up	0	12
105410	2020-07-28 12:49:27	2020-07-28	9	[{"id_menu":6,"count":1}]	40594	delivery	5	14
105411	2020-07-28 12:49:58	2020-07-28	17	[{"id_menu":4,"count":1}]	6617	pick-up	0	17
105412	2020-07-28 12:50:55	2020-07-28	9	[{"id_menu":7,"count":1}]	37727	delivery	5	14
105413	2020-07-28 12:55:04	2020-07-28	12	[{"id_menu":3,"count":1}]	33533	delivery	5	17
105414	2020-07-28 12:56:02	2020-07-28	14	[{"id_menu":2,"count":1}]	32002	pick-up	0	14
105415	2020-07-28 12:56:25	2020-07-28	9	[{"id_menu":7,"count":1}]	11239	pick-up	0	9
105416	2020-07-28 12:59:27	2020-07-28	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6953	delivery	5	34
105417	2020-07-28 12:59:52	2020-07-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	40611	delivery	5	22
105418	2020-07-28 13:03:00	2020-07-28	9	[{"id_menu":6,"count":1}]	40577	delivery	5	14
105419	2020-07-28 13:05:01	2020-07-28	9	[{"id_menu":7,"count":1}]	40688	delivery	5	14
105420	2020-07-28 13:07:36	2020-07-28	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	14710	pick-up	0	35
105421	2020-07-28 13:09:39	2020-07-28	12	[{"id_menu":3,"count":1}]	28624	delivery	5	17
105422	2020-07-28 13:12:31	2020-07-28	12	[{"id_menu":3,"count":1}]	40625	delivery	5	17
105423	2020-07-28 13:15:45	2020-07-28	14	[{"id_menu":2,"count":1}]	6340	delivery	5	19
105424	2020-07-28 13:15:52	2020-07-28	9	[{"id_menu":6,"count":1}]	1260	delivery	5	14
105425	2020-07-28 13:17:47	2020-07-28	8	[{"id_menu":5,"count":1}]	17600	delivery	5	13
105426	2020-07-28 13:20:25	2020-07-28	8	[{"id_menu":5,"count":1}]	40124	delivery	5	13
105427	2020-07-28 13:22:13	2020-07-28	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	28607	delivery	5	39
105428	2020-07-28 13:26:32	2020-07-28	9	[{"id_menu":6,"count":1}]	14874	delivery	5	14
105429	2020-07-28 13:29:05	2020-07-28	9	[{"id_menu":6,"count":1}]	13547	pick-up	0	9
105430	2020-07-28 13:31:16	2020-07-28	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	40542	delivery	5	26
105431	2020-07-28 13:32:00	2020-07-28	14	[{"id_menu":2,"count":1}]	4170	pick-up	0	14
105432	2020-07-28 13:33:35	2020-07-28	8	[{"id_menu":5,"count":1}]	40723	delivery	5	13
105433	2020-07-28 13:34:34	2020-07-28	12	[{"id_menu":1,"count":1}]	40710	delivery	5	17
105434	2020-07-28 13:39:09	2020-07-28	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	40529	delivery	5	27
105435	2020-07-28 13:39:39	2020-07-28	9	[{"id_menu":7,"count":1}]	16686	delivery	5	14
105436	2020-07-28 13:42:33	2020-07-28	9	[{"id_menu":6,"count":1}]	37694	pick-up	0	9
105437	2020-07-28 13:45:39	2020-07-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	40716	delivery	5	31
105438	2020-07-28 13:49:57	2020-07-28	14	[{"id_menu":2,"count":1}]	26583	pick-up	0	14
105439	2020-07-28 13:51:25	2020-07-28	9	[{"id_menu":6,"count":1}]	40612	delivery	5	14
105440	2020-07-28 13:51:28	2020-07-28	17	[{"id_menu":4,"count":1}]	39979	delivery	5	22
105441	2020-07-28 13:52:24	2020-07-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	10554	delivery	5	28
105442	2020-07-28 13:53:37	2020-07-28	9	[{"id_menu":7,"count":1}]	36914	delivery	5	14
105443	2020-07-28 13:54:07	2020-07-28	12	[{"id_menu":3,"count":1}]	7327	delivery	5	17
105444	2020-07-28 14:01:27	2020-07-28	9	[{"id_menu":7,"count":1}]	26742	delivery	5	14
105445	2020-07-28 14:02:56	2020-07-28	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	40508	delivery	5	46
105446	2020-07-28 14:07:26	2020-07-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21747	delivery	5	22
105447	2020-07-28 14:09:32	2020-07-28	9	[{"id_menu":7,"count":1}]	23093	delivery	5	14
105448	2020-07-28 14:09:37	2020-07-28	9	[{"id_menu":7,"count":1}]	27181	delivery	5	14
105449	2020-07-28 14:10:51	2020-07-28	9	[{"id_menu":7,"count":1}]	40672	pick-up	0	9
105450	2020-07-28 14:12:29	2020-07-28	9	[{"id_menu":7,"count":1}]	34676	delivery	5	14
105451	2020-07-28 14:13:53	2020-07-28	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	32475	delivery	5	25
105452	2020-07-28 14:19:46	2020-07-28	12	[{"id_menu":3,"count":1}]	17777	pick-up	0	12
105453	2020-07-28 14:20:47	2020-07-28	9	[{"id_menu":6,"count":1}]	32146	delivery	5	14
105454	2020-07-28 14:27:22	2020-07-28	12	[{"id_menu":1,"count":1}]	7153	delivery	5	17
105455	2020-07-28 14:37:05	2020-07-28	9	[{"id_menu":7,"count":1}]	20349	delivery	5	14
105456	2020-07-28 14:37:46	2020-07-28	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2616	pick-up	0	21
105457	2020-07-28 14:44:36	2020-07-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12976	delivery	5	31
105458	2020-07-28 14:45:33	2020-07-28	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	14984	delivery	5	25
105459	2020-07-28 14:46:08	2020-07-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	40578	delivery	5	28
105460	2020-07-28 14:48:01	2020-07-28	12	[{"id_menu":1,"count":1}]	3926	pick-up	0	12
105461	2020-07-28 14:51:16	2020-07-28	12	[{"id_menu":1,"count":1}]	17133	delivery	5	17
105462	2020-07-28 14:54:28	2020-07-28	12	[{"id_menu":1,"count":1}]	40484	delivery	5	17
105463	2020-07-28 14:55:23	2020-07-28	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40665	delivery	5	35
105464	2020-07-28 14:55:40	2020-07-28	14	[{"id_menu":2,"count":1}]	40620	pick-up	0	14
105465	2020-07-28 14:57:01	2020-07-28	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4143	delivery	5	56
105466	2020-07-28 14:57:40	2020-07-28	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	40708	delivery	5	45
105467	2020-07-28 14:57:41	2020-07-28	17	[{"id_menu":4,"count":1}]	5293	pick-up	0	17
105468	2020-07-28 14:57:51	2020-07-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32306	delivery	5	22
105469	2020-07-28 14:59:49	2020-07-28	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	21009	delivery	5	36
105470	2020-07-28 15:03:57	2020-07-28	8	[{"id_menu":5,"count":1}]	18061	delivery	5	13
105471	2020-07-28 15:05:06	2020-07-28	9	[{"id_menu":7,"count":1}]	2640	delivery	5	14
105472	2020-07-28 15:06:06	2020-07-28	9	[{"id_menu":7,"count":1}]	15216	pick-up	0	9
105473	2020-07-28 15:25:58	2020-07-28	12	[{"id_menu":1,"count":1}]	5226	delivery	5	17
105474	2020-07-28 15:29:14	2020-07-28	9	[{"id_menu":6,"count":2}]	38966	delivery	5	14
105475	2020-07-28 15:32:27	2020-07-28	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	32	pick-up	0	21
105476	2020-07-28 15:32:34	2020-07-28	12	[{"id_menu":3,"count":1}]	4120	pick-up	0	12
105477	2020-07-28 15:33:22	2020-07-28	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40472	delivery	5	35
105478	2020-07-28 15:36:19	2020-07-28	9	[{"id_menu":7,"count":1}]	40591	pick-up	0	9
105479	2020-07-28 15:36:55	2020-07-28	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	36737	delivery	5	23
105480	2020-07-28 15:38:29	2020-07-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	36449	delivery	5	22
105481	2020-07-28 15:50:01	2020-07-28	14	[{"id_menu":2,"count":1}]	9125	delivery	5	19
105482	2020-07-28 15:52:35	2020-07-28	17	[{"id_menu":4,"count":1}]	14484	delivery	5	22
105483	2020-07-28 15:52:37	2020-07-28	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	21893	delivery	5	28
105484	2020-07-28 15:56:27	2020-07-28	17	[{"id_menu":4,"count":1}]	40483	delivery	5	22
105485	2020-07-28 15:57:09	2020-07-28	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	40714	delivery	5	40
105486	2020-07-28 15:58:03	2020-07-28	8	[{"id_menu":5,"count":1}]	18737	delivery	5	13
105487	2020-07-28 15:59:40	2020-07-28	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	40502	delivery	5	28
105488	2020-07-28 16:02:14	2020-07-28	17	[{"id_menu":4,"count":1}]	40584	delivery	5	22
105489	2020-07-28 16:02:41	2020-07-28	12	[{"id_menu":3,"count":1}]	35096	pick-up	0	12
105490	2020-07-28 16:02:55	2020-07-28	34	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	27483	delivery	5	39
105491	2020-07-28 16:03:19	2020-07-28	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	40709	delivery	5	34
105492	2020-07-28 16:03:55	2020-07-28	17	[{"id_menu":4,"count":1}]	40480	pick-up	0	17
105493	2020-07-28 16:07:48	2020-07-28	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	31611	delivery	5	27
105494	2020-07-28 16:10:33	2020-07-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16867	delivery	5	23
105495	2020-07-28 16:15:24	2020-07-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	40579	delivery	5	22
105496	2020-07-28 16:17:26	2020-07-28	14	[{"id_menu":2,"count":1}]	9692	pick-up	0	14
105497	2020-07-28 16:21:36	2020-07-28	8	[{"id_menu":5,"count":1}]	7611	delivery	5	13
105498	2020-07-28 16:21:42	2020-07-28	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	40552	delivery	5	36
105499	2020-07-28 16:22:33	2020-07-28	14	[{"id_menu":2,"count":1}]	11083	pick-up	0	14
105500	2020-07-28 16:22:45	2020-07-28	9	[{"id_menu":7,"count":1}]	40562	delivery	5	14
105501	2020-07-28 16:25:55	2020-07-28	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	23614	delivery	5	37
105502	2020-07-28 16:28:58	2020-07-28	14	[{"id_menu":2,"count":1}]	40485	delivery	5	19
105503	2020-07-28 16:35:38	2020-07-28	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	40531	delivery	5	44
105504	2020-07-28 16:35:42	2020-07-28	12	[{"id_menu":1,"count":1}]	27557	pick-up	0	12
105505	2020-07-28 16:39:16	2020-07-28	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	40570	delivery	5	37
105506	2020-07-28 16:39:49	2020-07-28	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	9298	delivery	5	36
105507	2020-07-28 16:40:01	2020-07-28	8	[{"id_menu":5,"count":1}]	40593	delivery	5	13
105508	2020-07-28 16:41:49	2020-07-28	8	[{"id_menu":5,"count":1}]	38984	delivery	5	13
105509	2020-07-28 16:42:12	2020-07-28	8	[{"id_menu":5,"count":1}]	17656	delivery	5	13
105510	2020-07-28 16:46:00	2020-07-28	12	[{"id_menu":1,"count":2}]	40469	delivery	5	17
105511	2020-07-28 16:49:00	2020-07-28	8	[{"id_menu":5,"count":2}]	15052	pick-up	0	8
105512	2020-07-28 16:52:43	2020-07-28	9	[{"id_menu":7,"count":1}]	20430	delivery	5	14
105513	2020-07-28 16:53:25	2020-07-28	14	[{"id_menu":2,"count":1}]	7835	pick-up	0	14
105514	2020-07-28 16:57:32	2020-07-28	9	[{"id_menu":6,"count":1}]	12898	delivery	5	14
105515	2020-07-28 17:02:14	2020-07-28	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	37532	delivery	5	29
105516	2020-07-28 17:11:15	2020-07-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20705	delivery	5	22
105517	2020-07-28 17:11:41	2020-07-28	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	27700	pick-up	0	21
105518	2020-07-28 17:23:26	2020-07-28	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	33758	pick-up	0	26
105519	2020-07-28 17:25:47	2020-07-28	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32419	delivery	5	31
105520	2020-07-28 17:25:50	2020-07-28	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	5442	delivery	5	26
105521	2020-07-28 17:26:11	2020-07-28	14	[{"id_menu":2,"count":1}]	40475	delivery	5	19
105522	2020-07-28 17:27:53	2020-07-28	12	[{"id_menu":1,"count":1}]	13477	pick-up	0	12
105523	2020-07-28 17:29:17	2020-07-28	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	40474	pick-up	0	21
105524	2020-07-28 17:32:38	2020-07-28	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	40537	delivery	5	43
105525	2020-07-28 17:40:45	2020-07-28	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	18260	delivery	5	40
105526	2020-07-28 17:42:22	2020-07-28	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	15577	delivery	5	40
105527	2020-07-28 17:45:21	2020-07-28	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	40712	delivery	5	42
105528	2020-07-28 17:52:33	2020-07-28	12	[{"id_menu":1,"count":1}]	31809	delivery	5	17
105529	2020-07-28 17:55:02	2020-07-28	14	[{"id_menu":2,"count":1}]	6918	delivery	5	19
105530	2020-07-28 17:55:27	2020-07-28	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	32692	delivery	5	34
105531	2020-07-28 17:56:55	2020-07-28	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15699	delivery	5	51
105532	2020-07-28 18:05:03	2020-07-28	9	[{"id_menu":7,"count":1}]	207	pick-up	0	9
105533	2020-07-28 18:05:44	2020-07-28	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4030	delivery	5	26
105534	2020-07-28 18:07:14	2020-07-28	12	[{"id_menu":3,"count":1}]	15226	delivery	5	17
105535	2020-07-28 18:07:20	2020-07-28	12	[{"id_menu":1,"count":1}]	24593	delivery	5	17
105536	2020-07-28 18:07:47	2020-07-28	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33100	pick-up	0	26
105537	2020-07-28 18:08:06	2020-07-28	17	[{"id_menu":4,"count":1}]	32471	delivery	5	22
105538	2020-07-28 18:16:15	2020-07-28	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	18746	pick-up	0	38
105539	2020-07-28 18:18:53	2020-07-28	9	[{"id_menu":7,"count":1}]	28428	delivery	5	14
105540	2020-07-28 18:23:43	2020-07-28	9	[{"id_menu":7,"count":1}]	6221	pick-up	0	9
105541	2020-07-28 18:29:18	2020-07-28	12	[{"id_menu":3,"count":1}]	40717	delivery	5	17
105542	2020-07-28 18:30:33	2020-07-28	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	32447	delivery	5	43
105543	2020-07-28 18:30:37	2020-07-28	17	[{"id_menu":4,"count":1}]	40629	pick-up	0	17
105544	2020-07-28 18:35:53	2020-07-28	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	13075	delivery	5	22
105545	2020-07-28 18:36:05	2020-07-28	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	40563	delivery	5	23
105546	2020-07-28 18:40:13	2020-07-28	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	26634	delivery	5	31
105547	2020-07-28 18:42:07	2020-07-28	9	[{"id_menu":7,"count":1}]	32494	delivery	5	14
105548	2020-07-28 18:42:11	2020-07-28	17	[{"id_menu":4,"count":1}]	32770	pick-up	0	17
105549	2020-07-28 18:43:50	2020-07-28	12	[{"id_menu":1,"count":1}]	40494	delivery	5	17
105550	2020-07-28 18:51:20	2020-07-28	14	[{"id_menu":2,"count":2}]	30392	pick-up	0	14
105551	2020-07-28 18:58:42	2020-07-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	40662	delivery	5	22
105552	2020-07-28 18:59:49	2020-07-28	12	[{"id_menu":3,"count":1}]	33211	delivery	5	17
105553	2020-07-28 19:07:30	2020-07-28	9	[{"id_menu":6,"count":1}]	2041	delivery	5	14
105554	2020-07-28 19:07:41	2020-07-28	14	[{"id_menu":2,"count":1}]	40587	delivery	5	19
105555	2020-07-28 19:07:50	2020-07-28	12	[{"id_menu":3,"count":1}]	7919	pick-up	0	12
105556	2020-07-28 19:11:56	2020-07-28	8	[{"id_menu":5,"count":1}]	23886	pick-up	0	8
105557	2020-07-28 19:17:26	2020-07-28	12	[{"id_menu":1,"count":1}]	13340	delivery	5	17
105558	2020-07-28 19:19:54	2020-07-28	8	[{"id_menu":5,"count":1}]	5676	delivery	5	13
105559	2020-07-28 19:19:56	2020-07-28	14	[{"id_menu":2,"count":1}]	2605	delivery	5	19
105560	2020-07-28 19:23:20	2020-07-28	12	[{"id_menu":1,"count":1}]	18980	pick-up	0	12
105561	2020-07-28 19:24:28	2020-07-28	8	[{"id_menu":5,"count":1}]	10620	delivery	5	13
105562	2020-07-28 19:25:05	2020-07-28	9	[{"id_menu":6,"count":2}]	3146	pick-up	0	9
105563	2020-07-28 19:28:43	2020-07-28	12	[{"id_menu":1,"count":1}]	40536	delivery	5	17
105564	2020-07-28 19:29:56	2020-07-28	8	[{"id_menu":5,"count":1}]	40705	delivery	5	13
105565	2020-07-28 19:32:55	2020-07-28	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15550	pick-up	0	31
105566	2020-07-28 19:34:57	2020-07-28	9	[{"id_menu":7,"count":1}]	28414	delivery	5	14
105567	2020-07-28 19:35:12	2020-07-28	14	[{"id_menu":2,"count":1}]	29852	pick-up	0	14
105568	2020-07-28 19:35:23	2020-07-28	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	40724	delivery	5	26
105569	2020-07-28 19:48:50	2020-07-28	17	[{"id_menu":4,"count":1}]	37568	delivery	5	22
105570	2020-07-28 19:49:09	2020-07-28	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	26459	pick-up	0	29
105571	2020-07-28 20:02:28	2020-07-28	9	[{"id_menu":7,"count":1}]	12896	delivery	5	14
105572	2020-07-28 20:02:29	2020-07-28	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22947	delivery	5	39
105573	2020-07-28 20:11:11	2020-07-28	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40533	delivery	5	35
105574	2020-07-28 20:13:21	2020-07-28	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	40682	delivery	5	25
105575	2020-07-28 20:15:37	2020-07-28	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11927	delivery	5	40
105576	2020-07-28 20:18:22	2020-07-28	9	[{"id_menu":6,"count":3}]	24985	delivery	5	14
105577	2020-07-28 20:22:39	2020-07-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12269	delivery	5	22
105578	2020-07-28 20:32:06	2020-07-28	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1562	pick-up	0	20
105579	2020-07-28 20:35:17	2020-07-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	40669	delivery	5	28
105580	2020-07-28 20:36:43	2020-07-28	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	7750	delivery	5	26
105581	2020-07-28 20:38:08	2020-07-28	14	[{"id_menu":2,"count":1}]	15519	delivery	5	19
105582	2020-07-28 20:38:57	2020-07-28	8	[{"id_menu":5,"count":1}]	31834	delivery	5	13
105583	2020-07-28 20:42:39	2020-07-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	40503	delivery	5	22
105584	2020-07-28 20:45:01	2020-07-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	40549	delivery	5	23
105585	2020-07-28 20:50:38	2020-07-28	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	40690	delivery	5	25
105586	2020-07-28 20:54:31	2020-07-28	12	[{"id_menu":1,"count":1}]	40647	delivery	5	17
105587	2020-07-28 20:55:53	2020-07-28	9	[{"id_menu":6,"count":1}]	25689	delivery	5	14
105588	2020-07-28 21:00:05	2020-07-28	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	5963	pick-up	0	26
105589	2020-07-28 21:02:21	2020-07-28	9	[{"id_menu":7,"count":1}]	33642	delivery	5	14
105590	2020-07-28 21:06:32	2020-07-28	12	[{"id_menu":3,"count":1}]	44	pick-up	0	12
105591	2020-07-28 21:10:02	2020-07-28	12	[{"id_menu":3,"count":1}]	40659	delivery	5	17
105592	2020-07-28 21:13:42	2020-07-28	17	[{"id_menu":4,"count":2}]	22779	delivery	5	22
105593	2020-07-28 21:15:20	2020-07-28	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	8692	delivery	5	26
105594	2020-07-28 21:17:12	2020-07-28	14	[{"id_menu":2,"count":1}]	38004	pick-up	0	14
105595	2020-07-28 21:17:34	2020-07-28	9	[{"id_menu":7,"count":1}]	40528	delivery	5	14
105596	2020-07-28 21:28:41	2020-07-28	12	[{"id_menu":1,"count":1}]	20215	delivery	5	17
105597	2020-07-28 21:30:04	2020-07-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	536	pick-up	0	17
105598	2020-07-28 21:30:58	2020-07-28	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	29795	delivery	5	39
105599	2020-07-28 21:31:29	2020-07-28	12	[{"id_menu":3,"count":1}]	40671	delivery	5	17
105600	2020-07-28 21:31:31	2020-07-28	17	[{"id_menu":4,"count":1}]	24810	delivery	5	22
105601	2020-07-28 21:32:00	2020-07-28	9	[{"id_menu":6,"count":1}]	7190	pick-up	0	9
105602	2020-07-28 21:33:06	2020-07-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	40704	delivery	5	22
105603	2020-07-28 21:40:07	2020-07-28	17	[{"id_menu":4,"count":1}]	40653	delivery	5	22
105604	2020-07-28 21:41:08	2020-07-28	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	38601	pick-up	0	29
105605	2020-07-28 21:54:43	2020-07-28	8	[{"id_menu":5,"count":1}]	32772	delivery	5	13
105606	2020-07-28 22:04:03	2020-07-28	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	26659	delivery	5	34
105607	2020-07-28 22:07:53	2020-07-28	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	40512	delivery	5	36
105608	2020-07-28 22:11:37	2020-07-28	14	[{"id_menu":2,"count":1}]	1526	pick-up	0	14
105609	2020-07-28 22:12:40	2020-07-28	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	23914	delivery	5	25
105610	2020-07-28 22:17:11	2020-07-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6342	delivery	5	31
105611	2020-07-28 22:20:52	2020-07-28	12	[{"id_menu":3,"count":1}]	40652	delivery	5	17
105612	2020-07-28 22:24:53	2020-07-28	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	19776	pick-up	0	26
105613	2020-07-28 22:26:17	2020-07-28	12	[{"id_menu":1,"count":1}]	24723	delivery	5	17
105614	2020-07-28 22:26:34	2020-07-28	12	[{"id_menu":3,"count":1}]	2139	pick-up	0	12
105615	2020-07-28 22:29:53	2020-07-28	9	[{"id_menu":7,"count":1}]	7955	delivery	5	14
105616	2020-07-28 22:36:02	2020-07-28	17	[{"id_menu":4,"count":1}]	40685	pick-up	0	17
105617	2020-07-28 22:36:32	2020-07-28	14	[{"id_menu":2,"count":1}]	24759	delivery	5	19
105618	2020-07-28 22:37:52	2020-07-28	17	[{"id_menu":4,"count":1}]	40621	delivery	5	22
105619	2020-07-28 22:38:08	2020-07-28	9	[{"id_menu":6,"count":1}]	40667	delivery	5	14
105620	2020-07-28 22:41:56	2020-07-28	17	[{"id_menu":4,"count":1}]	40580	delivery	5	22
105621	2020-07-28 22:42:10	2020-07-28	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	40322	pick-up	0	21
105622	2020-07-28 22:42:14	2020-07-28	12	[{"id_menu":1,"count":1}]	33220	pick-up	0	12
105623	2020-07-28 22:53:20	2020-07-28	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	25031	delivery	5	39
105624	2020-07-28 22:56:17	2020-07-28	14	[{"id_menu":2,"count":1}]	15831	delivery	5	19
105625	2020-07-28 22:58:00	2020-07-28	8	[{"id_menu":5,"count":1}]	634	pick-up	0	8
105626	2020-07-28 23:00:35	2020-07-28	9	[{"id_menu":7,"count":1}]	40626	delivery	5	14
105627	2020-07-28 23:02:26	2020-07-28	14	[{"id_menu":2,"count":1}]	40498	delivery	5	19
105628	2020-07-28 23:02:48	2020-07-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	11487	delivery	5	31
105629	2020-07-28 23:03:04	2020-07-28	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	40476	delivery	5	28
105630	2020-07-28 23:10:27	2020-07-28	17	[{"id_menu":4,"count":1}]	3382	delivery	5	22
105631	2020-07-28 23:11:24	2020-07-28	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	18822	delivery	5	31
105632	2020-07-28 23:12:22	2020-07-28	9	[{"id_menu":6,"count":1}]	40630	delivery	5	14
105633	2020-07-28 23:12:58	2020-07-28	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	37327	delivery	5	36
105634	2020-07-28 23:14:10	2020-07-28	9	[{"id_menu":7,"count":1}]	153	pick-up	0	9
105635	2020-07-28 23:16:57	2020-07-28	9	[{"id_menu":7,"count":1}]	40697	pick-up	0	9
105636	2020-07-28 23:26:23	2020-07-28	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	13722	delivery	5	28
105637	2020-07-28 23:26:37	2020-07-28	8	[{"id_menu":5,"count":1}]	40677	delivery	5	13
105638	2020-07-28 23:27:46	2020-07-28	17	[{"id_menu":4,"count":1}]	2932	pick-up	0	17
105639	2020-07-28 23:28:28	2020-07-28	8	[{"id_menu":5,"count":1}]	28579	delivery	5	13
105640	2020-07-28 23:29:39	2020-07-28	17	[{"id_menu":4,"count":1}]	25964	pick-up	0	17
105641	2020-07-28 23:32:55	2020-07-28	12	[{"id_menu":1,"count":1}]	26208	delivery	5	17
105642	2020-07-28 23:33:30	2020-07-28	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1896	pick-up	0	29
105643	2020-07-28 23:38:09	2020-07-28	9	[{"id_menu":6,"count":1}]	40715	delivery	5	14
105644	2020-07-28 23:40:41	2020-07-28	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	9899	delivery	5	43
105645	2020-07-28 23:41:48	2020-07-28	12	[{"id_menu":1,"count":1}]	40658	delivery	5	17
105646	2020-07-28 23:41:51	2020-07-28	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	30629	delivery	5	35
105647	2020-07-28 23:41:53	2020-07-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	10453	delivery	5	28
105648	2020-07-28 23:44:35	2020-07-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	40539	pick-up	0	17
105649	2020-07-28 23:46:44	2020-07-28	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29489	delivery	5	39
105650	2020-07-28 23:49:03	2020-07-28	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	25668	delivery	5	36
105651	2020-07-28 23:51:45	2020-07-28	9	[{"id_menu":7,"count":1}]	11755	delivery	5	14
105652	2020-07-28 23:55:58	2020-07-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	40663	delivery	5	31
105653	2020-07-28 23:56:06	2020-07-28	12	[{"id_menu":1,"count":1}]	40535	delivery	5	17
105654	2020-07-29 00:01:29	2020-07-29	9	[{"id_menu":6,"count":1}]	19909	delivery	5	14
105655	2020-07-29 00:08:07	2020-07-29	9	[{"id_menu":6,"count":1}]	40869	delivery	5	14
105656	2020-07-29 00:09:03	2020-07-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	40974	delivery	5	31
105657	2020-07-29 00:10:22	2020-07-29	8	[{"id_menu":5,"count":2}]	37360	pick-up	0	8
105658	2020-07-29 00:11:50	2020-07-29	8	[{"id_menu":5,"count":1}]	40789	delivery	5	13
105659	2020-07-29 00:14:15	2020-07-29	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	40936	delivery	5	43
105660	2020-07-29 00:14:58	2020-07-29	9	[{"id_menu":6,"count":1}]	3589	delivery	5	14
105661	2020-07-29 00:17:41	2020-07-29	9	[{"id_menu":6,"count":2}]	14982	pick-up	0	9
105662	2020-07-29 00:20:34	2020-07-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	38625	pick-up	0	23
105663	2020-07-29 00:23:07	2020-07-29	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15776	delivery	5	37
105664	2020-07-29 00:24:35	2020-07-29	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	29460	delivery	5	23
105665	2020-07-29 00:27:19	2020-07-29	9	[{"id_menu":6,"count":1}]	40904	delivery	5	14
105666	2020-07-29 00:28:52	2020-07-29	9	[{"id_menu":7,"count":1}]	5915	delivery	5	14
105667	2020-07-29 00:28:56	2020-07-29	14	[{"id_menu":2,"count":1}]	40882	delivery	5	19
105668	2020-07-29 00:29:15	2020-07-29	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	113	pick-up	0	25
105669	2020-07-29 00:34:38	2020-07-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	40754	delivery	5	27
105670	2020-07-29 00:35:10	2020-07-29	12	[{"id_menu":1,"count":1}]	38372	delivery	5	17
105671	2020-07-29 00:35:29	2020-07-29	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	40742	delivery	5	30
105672	2020-07-29 00:36:30	2020-07-29	14	[{"id_menu":2,"count":1}]	40863	delivery	5	19
105673	2020-07-29 00:37:46	2020-07-29	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	40883	delivery	5	34
105674	2020-07-29 00:38:53	2020-07-29	9	[{"id_menu":6,"count":1}]	13729	delivery	5	14
105675	2020-07-29 00:41:17	2020-07-29	8	[{"id_menu":5,"count":1}]	28712	delivery	5	13
105676	2020-07-29 00:43:45	2020-07-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	40856	delivery	5	31
105677	2020-07-29 00:45:23	2020-07-29	14	[{"id_menu":2,"count":1}]	12484	pick-up	0	14
105678	2020-07-29 00:45:27	2020-07-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2801	pick-up	0	17
105679	2020-07-29 00:49:27	2020-07-29	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	34911	delivery	5	23
105680	2020-07-29 00:50:53	2020-07-29	14	[{"id_menu":2,"count":1}]	38135	delivery	5	19
105681	2020-07-29 00:58:08	2020-07-29	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	27712	delivery	5	28
105682	2020-07-29 00:58:24	2020-07-29	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	3363	pick-up	0	26
105683	2020-07-29 01:00:53	2020-07-29	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	40934	delivery	5	31
105684	2020-07-29 01:02:41	2020-07-29	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	36550	delivery	5	23
105685	2020-07-29 01:07:25	2020-07-29	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	40771	delivery	5	39
105686	2020-07-29 01:09:06	2020-07-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	40908	delivery	5	28
105687	2020-07-29 01:09:50	2020-07-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4342	pick-up	0	23
105688	2020-07-29 01:10:10	2020-07-29	9	[{"id_menu":6,"count":1}]	40852	delivery	5	14
105689	2020-07-29 01:10:29	2020-07-29	17	[{"id_menu":4,"count":1}]	40777	delivery	5	22
105690	2020-07-29 01:12:29	2020-07-29	17	[{"id_menu":4,"count":1}]	19047	delivery	5	22
105691	2020-07-29 01:13:05	2020-07-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40902	delivery	5	23
105692	2020-07-29 01:16:03	2020-07-29	12	[{"id_menu":1,"count":1}]	6221	pick-up	0	12
105693	2020-07-29 01:18:12	2020-07-29	9	[{"id_menu":6,"count":1}]	32279	delivery	5	14
105694	2020-07-29 01:19:03	2020-07-29	12	[{"id_menu":1,"count":1}]	7025	delivery	5	17
105695	2020-07-29 01:21:25	2020-07-29	12	[{"id_menu":3,"count":1}]	40781	delivery	5	17
105696	2020-07-29 01:21:28	2020-07-29	17	[{"id_menu":4,"count":1}]	27711	delivery	5	22
105697	2020-07-29 01:21:36	2020-07-29	9	[{"id_menu":6,"count":1}]	21288	delivery	5	14
105698	2020-07-29 01:22:28	2020-07-29	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	40782	delivery	5	34
105699	2020-07-29 01:25:51	2020-07-29	9	[{"id_menu":7,"count":1}]	20723	delivery	5	14
105700	2020-07-29 01:26:36	2020-07-29	8	[{"id_menu":5,"count":1}]	11510	delivery	5	13
105701	2020-07-29 01:27:39	2020-07-29	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	31716	delivery	5	34
105702	2020-07-29 01:27:42	2020-07-29	9	[{"id_menu":6,"count":1}]	40973	delivery	5	14
105703	2020-07-29 01:28:18	2020-07-29	12	[{"id_menu":1,"count":1}]	40887	delivery	5	17
105704	2020-07-29 01:29:19	2020-07-29	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	352	pick-up	0	21
105705	2020-07-29 01:29:50	2020-07-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	40790	delivery	5	28
105706	2020-07-29 01:30:08	2020-07-29	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	21538	delivery	5	30
105707	2020-07-29 01:32:18	2020-07-29	17	[{"id_menu":4,"count":1}]	330	pick-up	0	17
105708	2020-07-29 01:34:56	2020-07-29	17	[{"id_menu":4,"count":1}]	18067	delivery	5	22
105709	2020-07-29 01:39:04	2020-07-29	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	26989	delivery	5	40
105710	2020-07-29 01:40:10	2020-07-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11555	delivery	5	31
105711	2020-07-29 01:41:52	2020-07-29	12	[{"id_menu":1,"count":1}]	40992	delivery	5	17
105712	2020-07-29 01:46:46	2020-07-29	9	[{"id_menu":7,"count":1}]	31026	delivery	5	14
105713	2020-07-29 01:46:59	2020-07-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	26911	pick-up	0	21
105714	2020-07-29 01:49:00	2020-07-29	9	[{"id_menu":6,"count":1}]	23039	delivery	5	14
105715	2020-07-29 01:52:14	2020-07-29	12	[{"id_menu":1,"count":1}]	40946	delivery	5	17
105716	2020-07-29 01:52:32	2020-07-29	12	[{"id_menu":3,"count":1}]	40926	delivery	5	17
105717	2020-07-29 01:54:42	2020-07-29	12	[{"id_menu":3,"count":1}]	22014	delivery	5	17
105718	2020-07-29 01:57:20	2020-07-29	14	[{"id_menu":2,"count":1}]	40917	pick-up	0	14
105719	2020-07-29 02:01:59	2020-07-29	8	[{"id_menu":5,"count":1}]	21387	pick-up	0	8
105720	2020-07-29 02:04:13	2020-07-29	9	[{"id_menu":7,"count":1}]	11189	pick-up	0	9
105721	2020-07-29 02:05:16	2020-07-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	40927	delivery	5	27
105722	2020-07-29 02:06:50	2020-07-29	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	17518	delivery	5	31
105723	2020-07-29 02:07:08	2020-07-29	8	[{"id_menu":5,"count":1}]	20811	delivery	5	13
105724	2020-07-29 02:11:10	2020-07-29	9	[{"id_menu":6,"count":1}]	16792	pick-up	0	9
105725	2020-07-29 02:12:35	2020-07-29	12	[{"id_menu":3,"count":1}]	1461	delivery	5	17
105726	2020-07-29 02:14:03	2020-07-29	14	[{"id_menu":2,"count":1}]	40841	delivery	5	19
105727	2020-07-29 02:15:37	2020-07-29	17	[{"id_menu":4,"count":1}]	31130	delivery	5	22
105728	2020-07-29 02:16:32	2020-07-29	9	[{"id_menu":7,"count":2}]	660	pick-up	0	9
105729	2020-07-29 02:18:03	2020-07-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12640	delivery	5	31
105730	2020-07-29 02:21:08	2020-07-29	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	40730	delivery	5	34
105731	2020-07-29 02:22:34	2020-07-29	17	[{"id_menu":4,"count":1}]	31931	delivery	5	22
105732	2020-07-29 02:23:22	2020-07-29	14	[{"id_menu":2,"count":1}]	40889	pick-up	0	14
105733	2020-07-29 02:24:11	2020-07-29	12	[{"id_menu":1,"count":1}]	5783	pick-up	0	12
105734	2020-07-29 02:25:40	2020-07-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	18959	delivery	5	31
105735	2020-07-29 02:28:30	2020-07-29	37	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	39872	pick-up	0	37
105736	2020-07-29 02:29:30	2020-07-29	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40885	delivery	5	37
105737	2020-07-29 02:31:30	2020-07-29	12	[{"id_menu":1,"count":1}]	18239	pick-up	0	12
105738	2020-07-29 02:34:27	2020-07-29	12	[{"id_menu":3,"count":1}]	12302	delivery	5	17
105739	2020-07-29 02:36:00	2020-07-29	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	38986	delivery	5	38
105740	2020-07-29 02:36:07	2020-07-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3185	delivery	5	27
105741	2020-07-29 02:38:17	2020-07-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	38612	pick-up	0	23
105742	2020-07-29 02:39:05	2020-07-29	12	[{"id_menu":3,"count":1}]	15565	pick-up	0	12
105743	2020-07-29 02:40:46	2020-07-29	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28737	delivery	5	35
105744	2020-07-29 02:41:27	2020-07-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	40911	delivery	5	36
105745	2020-07-29 02:42:13	2020-07-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	24455	delivery	5	31
105746	2020-07-29 02:42:24	2020-07-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20667	pick-up	0	18
105747	2020-07-29 02:43:51	2020-07-29	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21786	pick-up	0	38
105748	2020-07-29 02:44:29	2020-07-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	40937	delivery	5	22
105749	2020-07-29 02:47:10	2020-07-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":3}]	7623	delivery	5	22
105750	2020-07-29 02:51:41	2020-07-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	4116	delivery	5	27
105751	2020-07-29 02:53:54	2020-07-29	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	41012	pick-up	0	24
105752	2020-07-29 02:53:55	2020-07-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	41000	delivery	5	22
105753	2020-07-29 02:54:45	2020-07-29	17	[{"id_menu":4,"count":1}]	18000	delivery	5	22
105754	2020-07-29 02:56:29	2020-07-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	40942	delivery	5	27
105755	2020-07-29 02:57:09	2020-07-29	9	[{"id_menu":7,"count":1}]	32907	delivery	5	14
105756	2020-07-29 02:58:45	2020-07-29	8	[{"id_menu":5,"count":1}]	38498	pick-up	0	8
105757	2020-07-29 02:59:28	2020-07-29	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	40819	delivery	5	39
105758	2020-07-29 02:59:32	2020-07-29	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	8180	pick-up	0	20
105759	2020-07-29 03:00:51	2020-07-29	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	32785	delivery	5	39
105760	2020-07-29 03:03:32	2020-07-29	9	[{"id_menu":7,"count":1}]	2085	pick-up	0	9
105761	2020-07-29 03:03:52	2020-07-29	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	36161	delivery	5	40
105762	2020-07-29 03:04:28	2020-07-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14414	delivery	5	31
105763	2020-07-29 03:05:41	2020-07-29	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	40791	delivery	5	43
105764	2020-07-29 03:06:08	2020-07-29	9	[{"id_menu":7,"count":1}]	40873	delivery	5	14
105765	2020-07-29 03:10:44	2020-07-29	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	6858	pick-up	0	20
105766	2020-07-29 03:12:43	2020-07-29	17	[{"id_menu":4,"count":1}]	11764	pick-up	0	17
105767	2020-07-29 03:18:16	2020-07-29	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	2491	delivery	5	30
105768	2020-07-29 03:22:07	2020-07-29	17	[{"id_menu":4,"count":1}]	30505	pick-up	0	17
105769	2020-07-29 03:22:54	2020-07-29	14	[{"id_menu":2,"count":1}]	17353	pick-up	0	14
105770	2020-07-29 03:23:25	2020-07-29	9	[{"id_menu":7,"count":1}]	41	delivery	5	14
105771	2020-07-29 03:23:43	2020-07-29	9	[{"id_menu":6,"count":1}]	40810	delivery	5	14
105772	2020-07-29 03:26:37	2020-07-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15684	delivery	5	23
105773	2020-07-29 03:26:55	2020-07-29	9	[{"id_menu":7,"count":1}]	1598	delivery	5	14
105774	2020-07-29 03:27:41	2020-07-29	12	[{"id_menu":3,"count":1}]	18304	pick-up	0	12
105775	2020-07-29 03:31:08	2020-07-29	9	[{"id_menu":6,"count":1}]	15629	delivery	5	14
105971	2020-07-29 10:29:35	2020-07-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14578	pick-up	0	17
105776	2020-07-29 03:38:46	2020-07-29	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	40877	delivery	5	39
105777	2020-07-29 03:39:25	2020-07-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	23048	delivery	5	27
105778	2020-07-29 03:40:53	2020-07-29	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	40975	delivery	5	25
105779	2020-07-29 03:43:02	2020-07-29	14	[{"id_menu":2,"count":1}]	40984	delivery	5	19
105780	2020-07-29 03:47:17	2020-07-29	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11093	delivery	5	34
105781	2020-07-29 03:47:26	2020-07-29	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1447	delivery	5	26
105782	2020-07-29 03:48:11	2020-07-29	12	[{"id_menu":1,"count":1}]	8775	delivery	5	17
105783	2020-07-29 03:48:15	2020-07-29	9	[{"id_menu":7,"count":1}]	17909	delivery	5	14
105784	2020-07-29 03:49:57	2020-07-29	9	[{"id_menu":6,"count":1}]	5928	delivery	5	14
105785	2020-07-29 03:51:22	2020-07-29	41	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	40765	delivery	5	46
105786	2020-07-29 03:54:29	2020-07-29	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	13606	delivery	5	28
105787	2020-07-29 03:57:01	2020-07-29	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40980	delivery	5	49
105788	2020-07-29 03:57:17	2020-07-29	14	[{"id_menu":2,"count":1}]	35387	delivery	5	19
105789	2020-07-29 03:57:21	2020-07-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	24440	delivery	5	28
105790	2020-07-29 04:00:08	2020-07-29	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	40740	delivery	5	31
105791	2020-07-29 04:02:32	2020-07-29	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	40958	delivery	5	26
105792	2020-07-29 04:08:15	2020-07-29	12	[{"id_menu":3,"count":1}]	3241	pick-up	0	12
105793	2020-07-29 04:12:12	2020-07-29	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	40735	delivery	5	51
105794	2020-07-29 04:16:44	2020-07-29	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7007	delivery	5	30
105795	2020-07-29 04:18:20	2020-07-29	12	[{"id_menu":1,"count":1}]	40796	pick-up	0	12
105796	2020-07-29 04:21:31	2020-07-29	12	[{"id_menu":1,"count":1}]	32079	delivery	5	17
105797	2020-07-29 04:25:16	2020-07-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21461	delivery	5	23
105798	2020-07-29 04:28:25	2020-07-29	9	[{"id_menu":7,"count":1}]	12321	delivery	5	14
105799	2020-07-29 04:29:38	2020-07-29	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3361	pick-up	0	26
105800	2020-07-29 04:31:07	2020-07-29	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	40862	delivery	5	25
105801	2020-07-29 04:32:04	2020-07-29	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	12227	delivery	5	40
105802	2020-07-29 04:33:49	2020-07-29	17	[{"id_menu":4,"count":1}]	1005	delivery	5	22
105803	2020-07-29 04:34:50	2020-07-29	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	36029	pick-up	0	29
105804	2020-07-29 04:35:32	2020-07-29	17	[{"id_menu":4,"count":1}]	40933	delivery	5	22
105805	2020-07-29 04:38:27	2020-07-29	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	30535	delivery	5	30
105806	2020-07-29 04:38:56	2020-07-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	23096	delivery	5	28
105807	2020-07-29 04:39:26	2020-07-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	40746	delivery	5	23
105808	2020-07-29 04:41:47	2020-07-29	9	[{"id_menu":7,"count":1}]	4021	delivery	5	14
105809	2020-07-29 04:42:05	2020-07-29	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	27501	delivery	5	26
105810	2020-07-29 04:43:31	2020-07-29	14	[{"id_menu":2,"count":1}]	28479	delivery	5	19
105811	2020-07-29 04:43:31	2020-07-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	40751	delivery	5	22
105812	2020-07-29 04:46:45	2020-07-29	14	[{"id_menu":2,"count":1}]	18057	pick-up	0	14
105813	2020-07-29 04:47:32	2020-07-29	8	[{"id_menu":5,"count":1}]	22274	delivery	5	13
105814	2020-07-29 04:49:04	2020-07-29	12	[{"id_menu":1,"count":1}]	8023	delivery	5	17
105815	2020-07-29 04:50:19	2020-07-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	16580	delivery	5	28
105816	2020-07-29 04:53:23	2020-07-29	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	39717	delivery	5	28
105817	2020-07-29 04:55:31	2020-07-29	9	[{"id_menu":7,"count":1}]	40747	delivery	5	14
105818	2020-07-29 04:58:25	2020-07-29	17	[{"id_menu":4,"count":1}]	4804	pick-up	0	17
105819	2020-07-29 04:59:16	2020-07-29	9	[{"id_menu":7,"count":1}]	37200	delivery	5	14
105820	2020-07-29 05:01:57	2020-07-29	9	[{"id_menu":6,"count":1}]	5477	delivery	5	14
105821	2020-07-29 05:04:44	2020-07-29	12	[{"id_menu":3,"count":1}]	31006	pick-up	0	12
105822	2020-07-29 05:05:31	2020-07-29	12	[{"id_menu":3,"count":1}]	24597	pick-up	0	12
105823	2020-07-29 05:05:34	2020-07-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":3}]	6544	delivery	5	26
105824	2020-07-29 05:07:59	2020-07-29	9	[{"id_menu":7,"count":1}]	28538	delivery	5	14
105825	2020-07-29 05:08:31	2020-07-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	30747	delivery	5	26
105826	2020-07-29 05:08:36	2020-07-29	14	[{"id_menu":2,"count":1}]	40903	delivery	5	19
105827	2020-07-29 05:09:27	2020-07-29	9	[{"id_menu":6,"count":1}]	40874	delivery	5	14
105828	2020-07-29 05:10:09	2020-07-29	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31789	delivery	5	49
105829	2020-07-29 05:15:10	2020-07-29	9	[{"id_menu":7,"count":1}]	23497	delivery	5	14
105830	2020-07-29 05:17:40	2020-07-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	40978	delivery	5	27
105831	2020-07-29 05:19:52	2020-07-29	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	26767	delivery	5	34
105832	2020-07-29 05:20:15	2020-07-29	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	32524	delivery	5	39
105833	2020-07-29 05:24:49	2020-07-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	17465	delivery	5	22
105834	2020-07-29 05:26:19	2020-07-29	14	[{"id_menu":2,"count":1}]	16037	delivery	5	19
105835	2020-07-29 05:26:36	2020-07-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	40844	delivery	5	28
105836	2020-07-29 05:28:58	2020-07-29	8	[{"id_menu":5,"count":1}]	22207	pick-up	0	8
105837	2020-07-29 05:29:23	2020-07-29	14	[{"id_menu":2,"count":1}]	27257	pick-up	0	14
105838	2020-07-29 05:32:09	2020-07-29	17	[{"id_menu":4,"count":1}]	40827	delivery	5	22
105839	2020-07-29 05:32:45	2020-07-29	14	[{"id_menu":2,"count":1}]	24197	delivery	5	19
105840	2020-07-29 05:36:40	2020-07-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2185	pick-up	0	23
105841	2020-07-29 05:37:46	2020-07-29	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	23294	delivery	5	43
105842	2020-07-29 05:41:17	2020-07-29	9	[{"id_menu":6,"count":1}]	4501	pick-up	0	9
105843	2020-07-29 05:44:34	2020-07-29	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	15856	pick-up	0	31
105844	2020-07-29 05:45:07	2020-07-29	8	[{"id_menu":5,"count":1}]	15376	delivery	5	13
105845	2020-07-29 05:46:31	2020-07-29	8	[{"id_menu":5,"count":1}]	19399	delivery	5	13
105846	2020-07-29 05:49:51	2020-07-29	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	17695	pick-up	0	26
105847	2020-07-29 05:56:44	2020-07-29	9	[{"id_menu":6,"count":1}]	40833	delivery	5	14
105848	2020-07-29 05:57:15	2020-07-29	12	[{"id_menu":1,"count":1}]	40891	delivery	5	17
105849	2020-07-29 05:57:54	2020-07-29	14	[{"id_menu":2,"count":1}]	29912	delivery	5	19
105850	2020-07-29 05:58:41	2020-07-29	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4004	delivery	5	43
105851	2020-07-29 06:01:45	2020-07-29	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	40785	delivery	5	48
105852	2020-07-29 06:03:14	2020-07-29	12	[{"id_menu":1,"count":1}]	40995	delivery	5	17
105853	2020-07-29 06:04:08	2020-07-29	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	35440	delivery	5	25
105854	2020-07-29 06:04:10	2020-07-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	35343	delivery	5	31
105855	2020-07-29 06:04:20	2020-07-29	17	[{"id_menu":4,"count":1}]	2315	delivery	5	22
105856	2020-07-29 06:05:33	2020-07-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	17747	delivery	5	27
105857	2020-07-29 06:08:09	2020-07-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	40879	delivery	5	36
105858	2020-07-29 06:18:18	2020-07-29	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6589	delivery	5	30
105859	2020-07-29 06:19:02	2020-07-29	9	[{"id_menu":7,"count":2}]	1587	pick-up	0	9
105860	2020-07-29 06:19:54	2020-07-29	9	[{"id_menu":6,"count":1}]	40801	delivery	5	14
105861	2020-07-29 06:25:19	2020-07-29	12	[{"id_menu":1,"count":1}]	29744	delivery	5	17
105862	2020-07-29 06:29:27	2020-07-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4274	pick-up	0	22
105863	2020-07-29 06:31:57	2020-07-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	34245	pick-up	0	23
105864	2020-07-29 06:37:45	2020-07-29	14	[{"id_menu":2,"count":1}]	40774	delivery	5	19
105865	2020-07-29 06:44:58	2020-07-29	12	[{"id_menu":1,"count":1}]	40853	pick-up	0	12
105866	2020-07-29 06:46:17	2020-07-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15716	delivery	5	31
105867	2020-07-29 06:47:13	2020-07-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	40816	delivery	5	22
105868	2020-07-29 06:47:40	2020-07-29	12	[{"id_menu":3,"count":1}]	28357	pick-up	0	12
105869	2020-07-29 06:51:03	2020-07-29	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	25799	delivery	5	43
105870	2020-07-29 06:52:26	2020-07-29	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	32946	pick-up	0	20
105871	2020-07-29 06:52:50	2020-07-29	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1885	pick-up	0	29
105872	2020-07-29 06:55:14	2020-07-29	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	126	delivery	5	36
105873	2020-07-29 06:57:52	2020-07-29	12	[{"id_menu":1,"count":1}]	23309	delivery	5	17
105874	2020-07-29 06:58:14	2020-07-29	9	[{"id_menu":6,"count":1}]	35712	delivery	5	14
105875	2020-07-29 06:58:16	2020-07-29	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6260	delivery	5	40
105876	2020-07-29 07:02:40	2020-07-29	14	[{"id_menu":2,"count":1}]	26622	delivery	5	19
105877	2020-07-29 07:04:09	2020-07-29	12	[{"id_menu":1,"count":1}]	17715	delivery	5	17
105878	2020-07-29 07:04:53	2020-07-29	12	[{"id_menu":3,"count":1}]	40792	delivery	5	17
105879	2020-07-29 07:05:27	2020-07-29	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	33506	delivery	5	30
105880	2020-07-29 07:06:39	2020-07-29	9	[{"id_menu":6,"count":1}]	31866	delivery	5	14
105881	2020-07-29 07:10:51	2020-07-29	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	33010	delivery	5	37
105882	2020-07-29 07:11:44	2020-07-29	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7338	delivery	5	40
105883	2020-07-29 07:13:13	2020-07-29	12	[{"id_menu":3,"count":1}]	40880	delivery	5	17
105884	2020-07-29 07:13:25	2020-07-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	32385	delivery	5	28
105885	2020-07-29 07:15:56	2020-07-29	17	[{"id_menu":4,"count":1}]	38004	pick-up	0	17
105886	2020-07-29 07:18:09	2020-07-29	14	[{"id_menu":2,"count":1}]	38310	pick-up	0	14
105887	2020-07-29 07:18:13	2020-07-29	9	[{"id_menu":7,"count":1}]	33441	delivery	5	14
105888	2020-07-29 07:19:30	2020-07-29	12	[{"id_menu":3,"count":1}]	22594	delivery	5	17
105889	2020-07-29 07:23:51	2020-07-29	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	21502	delivery	5	31
105890	2020-07-29 07:33:13	2020-07-29	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	21612	pick-up	0	38
105891	2020-07-29 07:38:57	2020-07-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	18687	pick-up	0	23
105892	2020-07-29 07:39:04	2020-07-29	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	40965	delivery	5	31
105893	2020-07-29 07:40:25	2020-07-29	9	[{"id_menu":6,"count":1}]	4594	delivery	5	14
105894	2020-07-29 07:42:15	2020-07-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	40931	delivery	5	26
105895	2020-07-29 07:45:19	2020-07-29	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	6830	delivery	5	35
105896	2020-07-29 07:45:51	2020-07-29	9	[{"id_menu":6,"count":1}]	7086	pick-up	0	9
105897	2020-07-29 07:46:46	2020-07-29	17	[{"id_menu":4,"count":1}]	6089	pick-up	0	17
105898	2020-07-29 07:47:12	2020-07-29	8	[{"id_menu":5,"count":1}]	26874	delivery	5	13
105899	2020-07-29 07:56:15	2020-07-29	9	[{"id_menu":6,"count":1}]	36138	delivery	5	14
105900	2020-07-29 07:59:17	2020-07-29	14	[{"id_menu":2,"count":3}]	40963	pick-up	0	14
105901	2020-07-29 08:02:11	2020-07-29	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16615	delivery	5	43
105902	2020-07-29 08:02:46	2020-07-29	9	[{"id_menu":6,"count":1}]	40783	delivery	5	14
105903	2020-07-29 08:05:53	2020-07-29	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40867	delivery	5	43
105904	2020-07-29 08:06:11	2020-07-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	34124	delivery	5	31
105905	2020-07-29 08:09:44	2020-07-29	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40994	delivery	5	37
105906	2020-07-29 08:11:58	2020-07-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	35485	delivery	5	28
105907	2020-07-29 08:12:35	2020-07-29	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	12397	delivery	5	45
105908	2020-07-29 08:13:10	2020-07-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	14638	delivery	5	31
105909	2020-07-29 08:13:33	2020-07-29	14	[{"id_menu":2,"count":1}]	527	pick-up	0	14
105910	2020-07-29 08:15:10	2020-07-29	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	28876	pick-up	0	29
105911	2020-07-29 08:15:24	2020-07-29	14	[{"id_menu":2,"count":1}]	37888	delivery	5	19
105912	2020-07-29 08:19:17	2020-07-29	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":2}]	35218	delivery	5	22
105913	2020-07-29 08:21:54	2020-07-29	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29071	delivery	5	31
105914	2020-07-29 08:26:43	2020-07-29	9	[{"id_menu":7,"count":1}]	40828	delivery	5	14
105915	2020-07-29 08:27:23	2020-07-29	9	[{"id_menu":6,"count":1}]	40757	delivery	5	14
105916	2020-07-29 08:30:46	2020-07-29	8	[{"id_menu":5,"count":1}]	3088	pick-up	0	8
105917	2020-07-29 08:33:37	2020-07-29	17	[{"id_menu":4,"count":1}]	38270	delivery	5	22
105918	2020-07-29 08:33:58	2020-07-29	17	[{"id_menu":4,"count":2}]	40826	delivery	5	22
105919	2020-07-29 08:35:50	2020-07-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	701	pick-up	0	21
105920	2020-07-29 08:37:22	2020-07-29	8	[{"id_menu":5,"count":1}]	39111	delivery	5	13
105921	2020-07-29 08:38:17	2020-07-29	12	[{"id_menu":3,"count":1}]	40834	delivery	5	17
105922	2020-07-29 08:38:51	2020-07-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38218	delivery	5	23
105923	2020-07-29 08:39:39	2020-07-29	9	[{"id_menu":7,"count":1}]	3239	delivery	5	14
105924	2020-07-29 08:40:03	2020-07-29	9	[{"id_menu":7,"count":1}]	40939	delivery	5	14
105925	2020-07-29 08:46:56	2020-07-29	8	[{"id_menu":5,"count":1}]	40970	delivery	5	13
105926	2020-07-29 08:47:47	2020-07-29	12	[{"id_menu":1,"count":1}]	40232	pick-up	0	12
105927	2020-07-29 08:50:22	2020-07-29	14	[{"id_menu":2,"count":1}]	28225	pick-up	0	14
105928	2020-07-29 08:51:08	2020-07-29	14	[{"id_menu":2,"count":1}]	40835	delivery	5	19
105929	2020-07-29 08:51:59	2020-07-29	12	[{"id_menu":1,"count":1}]	40848	pick-up	0	12
105930	2020-07-29 08:56:48	2020-07-29	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	13375	delivery	5	43
105931	2020-07-29 08:58:34	2020-07-29	14	[{"id_menu":2,"count":1}]	2477	delivery	5	19
105932	2020-07-29 09:03:18	2020-07-29	9	[{"id_menu":7,"count":1}]	41005	delivery	5	14
105933	2020-07-29 09:03:40	2020-07-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	41004	pick-up	0	21
105934	2020-07-29 09:06:40	2020-07-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	14462	pick-up	0	23
105935	2020-07-29 09:07:39	2020-07-29	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40808	delivery	5	31
105936	2020-07-29 09:08:50	2020-07-29	9	[{"id_menu":6,"count":1}]	40899	pick-up	0	9
105937	2020-07-29 09:09:12	2020-07-29	14	[{"id_menu":2,"count":1}]	31780	pick-up	0	14
105938	2020-07-29 09:11:11	2020-07-29	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	40895	delivery	5	25
105939	2020-07-29 09:12:02	2020-07-29	17	[{"id_menu":4,"count":1}]	1677	pick-up	0	17
105940	2020-07-29 09:13:19	2020-07-29	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	40766	pick-up	0	29
105941	2020-07-29 09:13:45	2020-07-29	17	[{"id_menu":4,"count":1}]	10398	delivery	5	22
105942	2020-07-29 09:13:45	2020-07-29	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	40770	delivery	5	39
105943	2020-07-29 09:17:33	2020-07-29	8	[{"id_menu":5,"count":1}]	31587	delivery	5	13
105944	2020-07-29 09:19:48	2020-07-29	9	[{"id_menu":6,"count":2}]	33757	pick-up	0	9
105945	2020-07-29 09:23:08	2020-07-29	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	40829	delivery	5	43
105946	2020-07-29 09:23:55	2020-07-29	8	[{"id_menu":5,"count":1}]	34764	delivery	5	13
105947	2020-07-29 09:24:13	2020-07-29	9	[{"id_menu":7,"count":1}]	11735	delivery	5	14
105948	2020-07-29 09:26:43	2020-07-29	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21801	delivery	5	48
105949	2020-07-29 09:28:01	2020-07-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	41008	delivery	5	22
105950	2020-07-29 09:29:00	2020-07-29	8	[{"id_menu":5,"count":1}]	13441	delivery	5	13
105951	2020-07-29 09:30:23	2020-07-29	9	[{"id_menu":7,"count":1}]	40786	delivery	5	14
105952	2020-07-29 09:31:52	2020-07-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	10284	delivery	5	28
105953	2020-07-29 09:35:55	2020-07-29	8	[{"id_menu":5,"count":1}]	12450	delivery	5	13
105954	2020-07-29 09:38:19	2020-07-29	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	9925	delivery	5	34
105955	2020-07-29 09:43:09	2020-07-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8847	delivery	5	36
105956	2020-07-29 09:43:43	2020-07-29	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	40775	pick-up	0	21
105957	2020-07-29 09:45:59	2020-07-29	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	26472	delivery	5	38
105958	2020-07-29 09:48:51	2020-07-29	9	[{"id_menu":6,"count":1}]	40921	delivery	5	14
105959	2020-07-29 09:49:40	2020-07-29	9	[{"id_menu":6,"count":1}]	34022	delivery	5	14
105960	2020-07-29 09:50:46	2020-07-29	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	40812	delivery	5	34
105961	2020-07-29 09:52:24	2020-07-29	14	[{"id_menu":2,"count":1}]	33645	delivery	5	19
105962	2020-07-29 09:52:52	2020-07-29	17	[{"id_menu":4,"count":1}]	40884	delivery	5	22
105963	2020-07-29 09:56:52	2020-07-29	12	[{"id_menu":1,"count":1}]	2729	delivery	5	17
105964	2020-07-29 10:07:24	2020-07-29	9	[{"id_menu":7,"count":1}]	41010	delivery	5	14
105965	2020-07-29 10:10:43	2020-07-29	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	19527	delivery	5	45
105966	2020-07-29 10:15:48	2020-07-29	12	[{"id_menu":3,"count":1}]	37348	delivery	5	17
105967	2020-07-29 10:19:02	2020-07-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	40798	delivery	5	31
105968	2020-07-29 10:22:08	2020-07-29	12	[{"id_menu":3,"count":1}]	6101	pick-up	0	12
105969	2020-07-29 10:23:16	2020-07-29	12	[{"id_menu":3,"count":1}]	40893	delivery	5	17
105970	2020-07-29 10:24:13	2020-07-29	9	[{"id_menu":7,"count":1}]	29178	delivery	5	14
105972	2020-07-29 10:29:44	2020-07-29	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	37911	delivery	5	34
105973	2020-07-29 10:31:31	2020-07-29	14	[{"id_menu":2,"count":1}]	38032	delivery	5	19
105974	2020-07-29 10:32:21	2020-07-29	17	[{"id_menu":4,"count":1}]	20545	delivery	5	22
105975	2020-07-29 10:34:57	2020-07-29	8	[{"id_menu":5,"count":1}]	1280	pick-up	0	8
105976	2020-07-29 10:35:01	2020-07-29	8	[{"id_menu":5,"count":1}]	10801	delivery	5	13
105977	2020-07-29 10:35:05	2020-07-29	8	[{"id_menu":5,"count":2}]	20779	delivery	5	13
105978	2020-07-29 10:35:51	2020-07-29	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	40825	delivery	5	34
105979	2020-07-29 10:41:47	2020-07-29	17	[{"id_menu":4,"count":1}]	2272	pick-up	0	17
105980	2020-07-29 10:44:30	2020-07-29	23	[{"id_menu":2,"count":3},{"id_menu":6,"count":1}]	8195	delivery	5	28
105981	2020-07-29 10:46:36	2020-07-29	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	32215	delivery	5	27
105982	2020-07-29 10:47:14	2020-07-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13996	delivery	5	22
105983	2020-07-29 10:49:47	2020-07-29	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40905	delivery	5	31
105984	2020-07-29 10:50:20	2020-07-29	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	40930	delivery	5	34
105985	2020-07-29 10:50:28	2020-07-29	9	[{"id_menu":6,"count":1}]	12725	delivery	5	14
105986	2020-07-29 10:55:26	2020-07-29	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	40858	delivery	5	26
105987	2020-07-29 10:56:06	2020-07-29	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	36682	delivery	5	48
105988	2020-07-29 10:59:54	2020-07-29	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	12327	delivery	5	34
105989	2020-07-29 11:01:36	2020-07-29	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	33094	delivery	5	43
105990	2020-07-29 11:05:29	2020-07-29	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	743	pick-up	0	31
105991	2020-07-29 11:06:14	2020-07-29	9	[{"id_menu":7,"count":1}]	25907	delivery	5	14
105992	2020-07-29 11:07:08	2020-07-29	14	[{"id_menu":2,"count":1}]	41009	delivery	5	19
105993	2020-07-29 11:07:40	2020-07-29	9	[{"id_menu":6,"count":1}]	36728	delivery	5	14
105994	2020-07-29 11:08:45	2020-07-29	9	[{"id_menu":7,"count":1}]	4762	pick-up	0	9
105995	2020-07-29 11:09:17	2020-07-29	8	[{"id_menu":5,"count":1}]	40849	delivery	5	13
105996	2020-07-29 11:10:01	2020-07-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	23600	delivery	5	31
105997	2020-07-29 11:11:04	2020-07-29	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	40739	delivery	5	23
105998	2020-07-29 11:11:58	2020-07-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2863	pick-up	0	18
105999	2020-07-29 11:12:13	2020-07-29	14	[{"id_menu":2,"count":1}]	13893	pick-up	0	14
106000	2020-07-29 11:12:33	2020-07-29	12	[{"id_menu":3,"count":1}]	2458	pick-up	0	12
106001	2020-07-29 11:12:46	2020-07-29	17	[{"id_menu":4,"count":1}]	40918	delivery	5	22
106002	2020-07-29 11:13:23	2020-07-29	14	[{"id_menu":2,"count":1}]	39558	delivery	5	19
106003	2020-07-29 11:18:33	2020-07-29	12	[{"id_menu":3,"count":1}]	10601	delivery	5	17
106004	2020-07-29 11:19:50	2020-07-29	12	[{"id_menu":3,"count":1}]	37739	pick-up	0	12
106005	2020-07-29 11:20:51	2020-07-29	17	[{"id_menu":4,"count":1}]	26059	pick-up	0	17
106006	2020-07-29 11:22:52	2020-07-29	9	[{"id_menu":7,"count":1}]	16018	pick-up	0	9
106007	2020-07-29 11:31:19	2020-07-29	9	[{"id_menu":7,"count":1}]	29969	delivery	5	14
106008	2020-07-29 11:32:00	2020-07-29	14	[{"id_menu":2,"count":1}]	14425	pick-up	0	14
106009	2020-07-29 11:32:15	2020-07-29	17	[{"id_menu":4,"count":1}]	37590	delivery	5	22
106010	2020-07-29 11:33:39	2020-07-29	14	[{"id_menu":2,"count":1}]	37179	delivery	5	19
106011	2020-07-29 11:34:01	2020-07-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	25911	delivery	5	22
106012	2020-07-29 11:34:44	2020-07-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	40780	delivery	5	26
106013	2020-07-29 11:36:21	2020-07-29	17	[{"id_menu":4,"count":1}]	40861	delivery	5	22
106014	2020-07-29 11:36:51	2020-07-29	9	[{"id_menu":7,"count":1}]	6410	pick-up	0	9
106015	2020-07-29 11:41:20	2020-07-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	40768	delivery	5	26
106016	2020-07-29 11:41:40	2020-07-29	9	[{"id_menu":6,"count":1}]	6762	delivery	5	14
106017	2020-07-29 11:47:11	2020-07-29	12	[{"id_menu":3,"count":2}]	372	pick-up	0	12
106018	2020-07-29 11:47:26	2020-07-29	8	[{"id_menu":5,"count":1}]	40865	delivery	5	13
106019	2020-07-29 11:50:58	2020-07-29	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	33949	delivery	5	26
106020	2020-07-29 11:52:24	2020-07-29	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	972	delivery	5	31
106021	2020-07-29 11:54:11	2020-07-29	8	[{"id_menu":5,"count":1}]	34684	delivery	5	13
106022	2020-07-29 11:54:57	2020-07-29	14	[{"id_menu":2,"count":1}]	18989	delivery	5	19
106023	2020-07-29 11:56:43	2020-07-29	8	[{"id_menu":5,"count":1}]	41002	delivery	5	13
106024	2020-07-29 11:57:29	2020-07-29	17	[{"id_menu":4,"count":1}]	40083	delivery	5	22
106025	2020-07-29 11:57:47	2020-07-29	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":2}]	16239	delivery	5	27
106026	2020-07-29 11:59:39	2020-07-29	14	[{"id_menu":2,"count":1}]	32016	delivery	5	19
106027	2020-07-29 12:03:17	2020-07-29	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	11495	delivery	5	48
106028	2020-07-29 12:03:34	2020-07-29	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	40894	delivery	5	31
106029	2020-07-29 12:05:12	2020-07-29	14	[{"id_menu":2,"count":1}]	40806	delivery	5	19
106030	2020-07-29 12:05:28	2020-07-29	14	[{"id_menu":2,"count":1}]	286	pick-up	0	14
106031	2020-07-29 12:07:10	2020-07-29	12	[{"id_menu":1,"count":1}]	17908	delivery	5	17
106032	2020-07-29 12:08:06	2020-07-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	40859	delivery	5	36
106033	2020-07-29 12:11:05	2020-07-29	17	[{"id_menu":4,"count":1}]	12207	delivery	5	22
106034	2020-07-29 12:14:41	2020-07-29	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	12717	pick-up	0	29
106035	2020-07-29 12:14:42	2020-07-29	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10234	delivery	5	37
106036	2020-07-29 12:17:01	2020-07-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	15805	delivery	5	27
106037	2020-07-29 12:17:54	2020-07-29	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	40769	delivery	5	25
106038	2020-07-29 12:18:11	2020-07-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	40744	delivery	5	22
106039	2020-07-29 12:23:43	2020-07-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8246	delivery	5	36
106040	2020-07-29 12:25:19	2020-07-29	14	[{"id_menu":2,"count":1}]	11274	delivery	5	19
106041	2020-07-29 12:26:06	2020-07-29	12	[{"id_menu":1,"count":1}]	14714	pick-up	0	12
106042	2020-07-29 12:28:07	2020-07-29	8	[{"id_menu":5,"count":1}]	15174	delivery	5	13
106043	2020-07-29 12:28:48	2020-07-29	9	[{"id_menu":6,"count":1}]	40803	delivery	5	14
106044	2020-07-29 12:30:38	2020-07-29	9	[{"id_menu":6,"count":1}]	7107	delivery	5	14
106045	2020-07-29 12:30:52	2020-07-29	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10651	delivery	5	43
106046	2020-07-29 12:33:23	2020-07-29	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18858	delivery	5	48
106047	2020-07-29 12:35:48	2020-07-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	40779	delivery	5	31
106048	2020-07-29 12:35:55	2020-07-29	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	6566	delivery	5	40
106049	2020-07-29 12:37:17	2020-07-29	12	[{"id_menu":1,"count":1}]	2016	delivery	5	17
106050	2020-07-29 12:40:09	2020-07-29	12	[{"id_menu":3,"count":1}]	40799	delivery	5	17
106051	2020-07-29 12:43:09	2020-07-29	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9147	delivery	5	30
106052	2020-07-29 12:43:45	2020-07-29	8	[{"id_menu":5,"count":1}]	40935	delivery	5	13
106053	2020-07-29 12:50:30	2020-07-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	19914	pick-up	0	21
106054	2020-07-29 12:50:44	2020-07-29	12	[{"id_menu":3,"count":1}]	40818	pick-up	0	12
106055	2020-07-29 12:52:47	2020-07-29	9	[{"id_menu":6,"count":2}]	2783	pick-up	0	9
106056	2020-07-29 12:59:49	2020-07-29	14	[{"id_menu":2,"count":1}]	11992	pick-up	0	14
106057	2020-07-29 13:05:19	2020-07-29	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	4793	pick-up	0	20
106058	2020-07-29 13:06:11	2020-07-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3470	pick-up	0	23
106059	2020-07-29 13:06:59	2020-07-29	14	[{"id_menu":2,"count":1}]	40964	delivery	5	19
106060	2020-07-29 13:07:50	2020-07-29	9	[{"id_menu":6,"count":1}]	40843	delivery	5	14
106061	2020-07-29 13:08:16	2020-07-29	8	[{"id_menu":5,"count":1}]	19663	delivery	5	13
106062	2020-07-29 13:09:25	2020-07-29	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	40764	delivery	5	45
106063	2020-07-29 13:10:55	2020-07-29	8	[{"id_menu":5,"count":1}]	40940	delivery	5	13
106064	2020-07-29 13:11:45	2020-07-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	40967	pick-up	0	22
106065	2020-07-29 13:14:56	2020-07-29	9	[{"id_menu":7,"count":2}]	30767	delivery	5	14
106066	2020-07-29 13:18:59	2020-07-29	9	[{"id_menu":6,"count":1}]	40736	delivery	5	14
106067	2020-07-29 13:25:21	2020-07-29	12	[{"id_menu":1,"count":1}]	35720	delivery	5	17
106068	2020-07-29 13:32:26	2020-07-29	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	30991	delivery	5	45
106069	2020-07-29 13:37:24	2020-07-29	12	[{"id_menu":1,"count":1}]	12183	pick-up	0	12
106070	2020-07-29 13:38:39	2020-07-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	40820	delivery	5	22
106071	2020-07-29 13:39:48	2020-07-29	17	[{"id_menu":4,"count":1}]	40875	delivery	5	22
106072	2020-07-29 13:46:14	2020-07-29	8	[{"id_menu":5,"count":1}]	10501	delivery	5	13
106073	2020-07-29 13:47:12	2020-07-29	17	[{"id_menu":4,"count":1}]	40773	delivery	5	22
106074	2020-07-29 13:49:47	2020-07-29	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	40847	delivery	5	26
106075	2020-07-29 13:53:50	2020-07-29	12	[{"id_menu":1,"count":1}]	9358	pick-up	0	12
106076	2020-07-29 13:54:21	2020-07-29	14	[{"id_menu":2,"count":1}]	18918	delivery	5	19
106077	2020-07-29 13:55:38	2020-07-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16320	delivery	5	22
106078	2020-07-29 13:57:25	2020-07-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	33258	delivery	5	22
106079	2020-07-29 14:01:56	2020-07-29	12	[{"id_menu":3,"count":1}]	6643	pick-up	0	12
106080	2020-07-29 14:01:58	2020-07-29	17	[{"id_menu":4,"count":1}]	14631	delivery	5	22
106081	2020-07-29 14:03:42	2020-07-29	9	[{"id_menu":6,"count":1}]	1314	delivery	5	14
106082	2020-07-29 14:06:27	2020-07-29	17	[{"id_menu":4,"count":1}]	40759	delivery	5	22
106083	2020-07-29 14:07:19	2020-07-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40830	delivery	5	23
106084	2020-07-29 14:14:19	2020-07-29	14	[{"id_menu":2,"count":1}]	8406	delivery	5	19
106085	2020-07-29 14:17:13	2020-07-29	9	[{"id_menu":6,"count":1}]	21352	pick-up	0	9
106086	2020-07-29 14:17:30	2020-07-29	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14343	delivery	5	52
106087	2020-07-29 14:17:47	2020-07-29	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	40976	delivery	5	40
106088	2020-07-29 14:19:51	2020-07-29	12	[{"id_menu":1,"count":1}]	23128	delivery	5	17
106089	2020-07-29 14:20:13	2020-07-29	9	[{"id_menu":7,"count":1}]	32539	delivery	5	14
106090	2020-07-29 14:20:52	2020-07-29	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	14199	delivery	5	28
106091	2020-07-29 14:24:40	2020-07-29	14	[{"id_menu":2,"count":1}]	32054	delivery	5	19
106092	2020-07-29 14:25:38	2020-07-29	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40971	delivery	5	40
106093	2020-07-29 14:25:54	2020-07-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	37369	delivery	5	22
106094	2020-07-29 14:27:07	2020-07-29	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	40949	delivery	5	31
106095	2020-07-29 14:27:48	2020-07-29	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	40795	pick-up	0	29
106096	2020-07-29 14:28:46	2020-07-29	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6232	pick-up	0	31
106097	2020-07-29 14:29:25	2020-07-29	9	[{"id_menu":6,"count":1}]	19732	delivery	5	14
106098	2020-07-29 14:33:56	2020-07-29	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	40966	delivery	5	34
106099	2020-07-29 14:34:03	2020-07-29	9	[{"id_menu":7,"count":1}]	40836	delivery	5	14
106100	2020-07-29 14:37:01	2020-07-29	8	[{"id_menu":5,"count":1}]	40897	delivery	5	13
106101	2020-07-29 14:40:35	2020-07-29	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	40745	delivery	5	40
106102	2020-07-29 14:41:50	2020-07-29	12	[{"id_menu":3,"count":1}]	21269	delivery	5	17
106103	2020-07-29 14:45:39	2020-07-29	17	[{"id_menu":4,"count":1}]	26065	pick-up	0	17
106104	2020-07-29 14:47:30	2020-07-29	12	[{"id_menu":1,"count":1}]	35748	delivery	5	17
106105	2020-07-29 14:48:22	2020-07-29	14	[{"id_menu":2,"count":1}]	2623	pick-up	0	14
106106	2020-07-29 14:50:35	2020-07-29	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	40794	pick-up	0	38
106107	2020-07-29 14:50:43	2020-07-29	12	[{"id_menu":1,"count":1}]	9647	delivery	5	17
106108	2020-07-29 14:51:41	2020-07-29	8	[{"id_menu":5,"count":1}]	21239	pick-up	0	8
106109	2020-07-29 14:51:47	2020-07-29	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	40866	delivery	5	30
106110	2020-07-29 14:52:48	2020-07-29	8	[{"id_menu":5,"count":1}]	13424	delivery	5	13
106111	2020-07-29 14:58:29	2020-07-29	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39674	delivery	5	31
106112	2020-07-29 14:58:43	2020-07-29	17	[{"id_menu":4,"count":1}]	39952	delivery	5	22
106113	2020-07-29 15:00:06	2020-07-29	8	[{"id_menu":5,"count":2}]	40955	delivery	5	13
106114	2020-07-29 15:02:39	2020-07-29	12	[{"id_menu":3,"count":1}]	30974	delivery	5	17
106115	2020-07-29 15:05:28	2020-07-29	8	[{"id_menu":5,"count":1}]	40809	delivery	5	13
106116	2020-07-29 15:13:04	2020-07-29	9	[{"id_menu":7,"count":1}]	27770	delivery	5	14
106117	2020-07-29 15:15:47	2020-07-29	9	[{"id_menu":6,"count":1}]	12067	delivery	5	14
106118	2020-07-29 15:17:25	2020-07-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	40763	delivery	5	28
106119	2020-07-29 15:19:07	2020-07-29	14	[{"id_menu":2,"count":1}]	5812	delivery	5	19
106120	2020-07-29 15:19:45	2020-07-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	40956	delivery	5	31
106121	2020-07-29 15:20:19	2020-07-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	40756	delivery	5	31
106122	2020-07-29 15:23:42	2020-07-29	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	9420	pick-up	0	21
106123	2020-07-29 15:25:48	2020-07-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	40815	pick-up	0	23
106124	2020-07-29 15:25:57	2020-07-29	12	[{"id_menu":3,"count":1}]	31957	pick-up	0	12
106125	2020-07-29 15:27:04	2020-07-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10621	delivery	5	23
106126	2020-07-29 15:28:47	2020-07-29	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	40997	delivery	5	43
106127	2020-07-29 15:34:12	2020-07-29	17	[{"id_menu":4,"count":1}]	17003	delivery	5	22
106128	2020-07-29 15:34:30	2020-07-29	17	[{"id_menu":4,"count":1}]	13579	pick-up	0	17
106129	2020-07-29 15:35:27	2020-07-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	40741	delivery	5	27
106130	2020-07-29 15:35:42	2020-07-29	8	[{"id_menu":5,"count":1}]	20631	delivery	5	13
106131	2020-07-29 15:39:47	2020-07-29	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	20876	delivery	5	39
106132	2020-07-29 15:40:33	2020-07-29	9	[{"id_menu":6,"count":1}]	37493	delivery	5	14
106133	2020-07-29 15:42:58	2020-07-29	9	[{"id_menu":6,"count":1}]	25096	delivery	5	14
106134	2020-07-29 15:44:05	2020-07-29	17	[{"id_menu":4,"count":1}]	40944	delivery	5	22
106135	2020-07-29 15:44:21	2020-07-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	14325	delivery	5	31
106136	2020-07-29 15:45:18	2020-07-29	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	13928	delivery	5	25
106137	2020-07-29 15:53:32	2020-07-29	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	40960	delivery	5	34
106138	2020-07-29 15:53:44	2020-07-29	12	[{"id_menu":1,"count":2}]	5561	delivery	5	17
106139	2020-07-29 15:55:41	2020-07-29	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4921	pick-up	0	29
106140	2020-07-29 15:55:46	2020-07-29	9	[{"id_menu":6,"count":1}]	1326	pick-up	0	9
106141	2020-07-29 15:58:47	2020-07-29	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2320	pick-up	0	25
106142	2020-07-29 15:58:51	2020-07-29	9	[{"id_menu":6,"count":2}]	27059	delivery	5	14
106143	2020-07-29 16:02:09	2020-07-29	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	40981	delivery	5	34
106144	2020-07-29 16:04:12	2020-07-29	12	[{"id_menu":1,"count":1}]	29394	delivery	5	17
106145	2020-07-29 16:04:12	2020-07-29	14	[{"id_menu":2,"count":1}]	1094	pick-up	0	14
106146	2020-07-29 16:04:43	2020-07-29	9	[{"id_menu":7,"count":1}]	4416	pick-up	0	9
106147	2020-07-29 16:10:35	2020-07-29	17	[{"id_menu":4,"count":1}]	37482	delivery	5	22
106148	2020-07-29 16:10:56	2020-07-29	9	[{"id_menu":6,"count":1}]	40868	delivery	5	14
106149	2020-07-29 16:11:20	2020-07-29	17	[{"id_menu":4,"count":1}]	31374	pick-up	0	17
106150	2020-07-29 16:12:03	2020-07-29	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	40957	delivery	5	35
106151	2020-07-29 16:14:52	2020-07-29	12	[{"id_menu":3,"count":1}]	28185	delivery	5	17
106152	2020-07-29 16:17:08	2020-07-29	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	18001	delivery	5	43
106153	2020-07-29 16:17:43	2020-07-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	40837	delivery	5	28
106154	2020-07-29 16:20:02	2020-07-29	14	[{"id_menu":2,"count":1}]	40943	delivery	5	19
106155	2020-07-29 16:20:57	2020-07-29	17	[{"id_menu":4,"count":1}]	18170	pick-up	0	17
106156	2020-07-29 16:22:03	2020-07-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2651	delivery	5	27
106157	2020-07-29 16:22:12	2020-07-29	9	[{"id_menu":7,"count":1}]	36873	delivery	5	14
106158	2020-07-29 16:23:04	2020-07-29	12	[{"id_menu":3,"count":1}]	3864	delivery	5	17
106159	2020-07-29 16:24:10	2020-07-29	12	[{"id_menu":3,"count":1}]	1913	delivery	5	17
106160	2020-07-29 16:24:46	2020-07-29	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	3812	pick-up	0	21
106161	2020-07-29 16:24:52	2020-07-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5829	pick-up	0	26
106162	2020-07-29 16:25:25	2020-07-29	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	30056	delivery	5	40
106163	2020-07-29 16:26:51	2020-07-29	8	[{"id_menu":5,"count":1}]	20832	delivery	5	13
106164	2020-07-29 16:27:36	2020-07-29	14	[{"id_menu":2,"count":1}]	168	pick-up	0	14
106165	2020-07-29 16:30:43	2020-07-29	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	20579	delivery	5	43
106166	2020-07-29 16:32:09	2020-07-29	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	40996	delivery	5	34
106167	2020-07-29 16:32:29	2020-07-29	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31092	pick-up	0	30
106168	2020-07-29 16:33:49	2020-07-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	5741	delivery	5	26
106169	2020-07-29 16:35:01	2020-07-29	9	[{"id_menu":7,"count":2}]	23271	delivery	5	14
106170	2020-07-29 16:35:57	2020-07-29	17	[{"id_menu":4,"count":1}]	19245	delivery	5	22
106171	2020-07-29 16:38:15	2020-07-29	12	[{"id_menu":3,"count":1}]	338	pick-up	0	12
106172	2020-07-29 16:40:01	2020-07-29	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	40989	delivery	5	25
106173	2020-07-29 16:40:13	2020-07-29	9	[{"id_menu":6,"count":1}]	40898	delivery	5	14
106174	2020-07-29 16:40:42	2020-07-29	9	[{"id_menu":7,"count":1}]	22116	pick-up	0	9
106175	2020-07-29 16:41:30	2020-07-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14699	delivery	5	36
106176	2020-07-29 16:43:21	2020-07-29	8	[{"id_menu":5,"count":1}]	40928	delivery	5	13
106177	2020-07-29 16:45:14	2020-07-29	17	[{"id_menu":4,"count":1}]	28366	delivery	5	22
106178	2020-07-29 16:45:16	2020-07-29	8	[{"id_menu":5,"count":1}]	10106	pick-up	0	8
106179	2020-07-29 16:45:54	2020-07-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	40728	delivery	5	28
106180	2020-07-29 16:45:54	2020-07-29	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	33698	delivery	5	43
106181	2020-07-29 16:46:05	2020-07-29	9	[{"id_menu":7,"count":1}]	40737	delivery	5	14
106182	2020-07-29 16:48:01	2020-07-29	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	41011	delivery	5	31
106183	2020-07-29 16:49:06	2020-07-29	17	[{"id_menu":4,"count":1}]	2821	pick-up	0	17
106184	2020-07-29 16:49:17	2020-07-29	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	40925	delivery	5	29
106185	2020-07-29 16:52:43	2020-07-29	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	32285	delivery	5	23
106186	2020-07-29 16:53:25	2020-07-29	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	40688	delivery	5	26
106187	2020-07-29 16:53:37	2020-07-29	14	[{"id_menu":2,"count":1}]	26013	pick-up	0	14
106188	2020-07-29 16:57:34	2020-07-29	12	[{"id_menu":1,"count":1}]	35064	pick-up	0	12
106189	2020-07-29 16:59:01	2020-07-29	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":2}]	17094	delivery	5	36
106190	2020-07-29 17:05:43	2020-07-29	9	[{"id_menu":6,"count":1}]	40839	delivery	5	14
106191	2020-07-29 17:06:03	2020-07-29	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	6615	pick-up	0	24
106192	2020-07-29 17:07:02	2020-07-29	14	[{"id_menu":2,"count":2}]	24802	pick-up	0	14
106193	2020-07-29 17:09:13	2020-07-29	17	[{"id_menu":4,"count":1}]	7187	pick-up	0	17
106194	2020-07-29 17:12:20	2020-07-29	17	[{"id_menu":4,"count":1}]	40831	pick-up	0	17
106195	2020-07-29 17:12:58	2020-07-29	14	[{"id_menu":2,"count":1}]	33089	delivery	5	19
106196	2020-07-29 17:14:46	2020-07-29	8	[{"id_menu":5,"count":1}]	5349	delivery	5	13
106197	2020-07-29 17:16:36	2020-07-29	14	[{"id_menu":2,"count":2}]	21601	pick-up	0	14
106198	2020-07-29 17:20:59	2020-07-29	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	33344	delivery	5	31
106199	2020-07-29 17:23:16	2020-07-29	9	[{"id_menu":7,"count":2}]	3780	delivery	5	14
106200	2020-07-29 17:23:20	2020-07-29	9	[{"id_menu":7,"count":1}]	40941	delivery	5	14
106201	2020-07-29 17:24:24	2020-07-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	11991	delivery	5	28
106202	2020-07-29 17:24:27	2020-07-29	12	[{"id_menu":1,"count":1}]	40864	delivery	5	17
106203	2020-07-29 17:25:39	2020-07-29	14	[{"id_menu":2,"count":1}]	3875	pick-up	0	14
106204	2020-07-29 17:26:37	2020-07-29	21	[{"id_menu":3,"count":3},{"id_menu":6,"count":1}]	40823	delivery	5	26
106205	2020-07-29 17:29:11	2020-07-29	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	40909	delivery	5	38
106206	2020-07-29 17:35:12	2020-07-29	12	[{"id_menu":1,"count":1}]	644	pick-up	0	12
106207	2020-07-29 17:36:34	2020-07-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	32144	pick-up	0	23
106208	2020-07-29 17:41:30	2020-07-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	40906	delivery	5	26
106209	2020-07-29 17:43:37	2020-07-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	30275	pick-up	0	23
106210	2020-07-29 17:45:01	2020-07-29	14	[{"id_menu":2,"count":1}]	18445	delivery	5	19
106211	2020-07-29 17:49:40	2020-07-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	13994	delivery	5	26
106212	2020-07-29 17:58:35	2020-07-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	40961	delivery	5	23
106213	2020-07-29 17:58:36	2020-07-29	9	[{"id_menu":6,"count":1}]	13498	delivery	5	14
106214	2020-07-29 17:58:42	2020-07-29	8	[{"id_menu":5,"count":1}]	40947	delivery	5	13
106215	2020-07-29 17:59:44	2020-07-29	14	[{"id_menu":2,"count":1}]	40788	pick-up	0	14
106216	2020-07-29 18:02:28	2020-07-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8604	delivery	5	22
106217	2020-07-29 18:07:15	2020-07-29	9	[{"id_menu":7,"count":1}]	5654	delivery	5	14
106218	2020-07-29 18:09:12	2020-07-29	8	[{"id_menu":5,"count":1}]	32697	delivery	5	13
106219	2020-07-29 18:09:25	2020-07-29	14	[{"id_menu":2,"count":1}]	22188	pick-up	0	14
106220	2020-07-29 18:11:53	2020-07-29	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	31927	delivery	5	23
106221	2020-07-29 18:13:31	2020-07-29	9	[{"id_menu":7,"count":1}]	16537	delivery	5	14
106222	2020-07-29 18:15:47	2020-07-29	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	36142	delivery	5	40
106223	2020-07-29 18:17:38	2020-07-29	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	40870	delivery	5	23
106224	2020-07-29 18:18:46	2020-07-29	12	[{"id_menu":3,"count":1}]	24338	delivery	5	17
106225	2020-07-29 18:21:32	2020-07-29	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	40787	delivery	5	34
106226	2020-07-29 18:23:42	2020-07-29	9	[{"id_menu":7,"count":1}]	24779	delivery	5	14
106227	2020-07-29 18:24:14	2020-07-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":3}]	15093	delivery	5	23
106228	2020-07-29 18:24:26	2020-07-29	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	40872	delivery	5	39
106229	2020-07-29 18:24:36	2020-07-29	12	[{"id_menu":1,"count":1}]	31439	delivery	5	17
106230	2020-07-29 18:26:46	2020-07-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6443	delivery	5	31
106231	2020-07-29 18:27:31	2020-07-29	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	40991	delivery	5	45
106232	2020-07-29 18:27:35	2020-07-29	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	13946	delivery	5	44
106233	2020-07-29 18:28:57	2020-07-29	9	[{"id_menu":6,"count":2}]	3037	delivery	5	14
106234	2020-07-29 18:30:25	2020-07-29	9	[{"id_menu":7,"count":1}]	8831	delivery	5	14
106235	2020-07-29 18:37:58	2020-07-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	19854	delivery	5	31
106236	2020-07-29 18:38:37	2020-07-29	12	[{"id_menu":3,"count":1}]	15995	delivery	5	17
106237	2020-07-29 18:40:47	2020-07-29	9	[{"id_menu":7,"count":1}]	9377	delivery	5	14
106238	2020-07-29 18:42:31	2020-07-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41003	delivery	5	23
106239	2020-07-29 18:44:20	2020-07-29	9	[{"id_menu":6,"count":1}]	40832	delivery	5	14
106240	2020-07-29 18:47:12	2020-07-29	9	[{"id_menu":7,"count":1}]	40968	delivery	5	14
106241	2020-07-29 18:47:19	2020-07-29	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	11566	delivery	5	31
106242	2020-07-29 18:47:55	2020-07-29	12	[{"id_menu":1,"count":1}]	40916	delivery	5	17
106243	2020-07-29 18:48:13	2020-07-29	9	[{"id_menu":7,"count":2}]	942	pick-up	0	9
106244	2020-07-29 18:54:21	2020-07-29	8	[{"id_menu":5,"count":1}]	33769	delivery	5	13
106245	2020-07-29 18:56:30	2020-07-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":3}]	40990	delivery	5	31
106246	2020-07-29 18:57:56	2020-07-29	17	[{"id_menu":4,"count":1}]	17685	pick-up	0	17
106247	2020-07-29 18:58:18	2020-07-29	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	22500	delivery	5	34
106248	2020-07-29 19:03:08	2020-07-29	12	[{"id_menu":1,"count":1}]	14177	delivery	5	17
106249	2020-07-29 19:04:10	2020-07-29	9	[{"id_menu":7,"count":1}]	23633	delivery	5	14
106250	2020-07-29 19:05:11	2020-07-29	14	[{"id_menu":2,"count":1}]	13554	delivery	5	19
106251	2020-07-29 19:05:14	2020-07-29	9	[{"id_menu":6,"count":1}]	652	pick-up	0	9
106252	2020-07-29 19:08:41	2020-07-29	8	[{"id_menu":5,"count":1}]	25827	pick-up	0	8
106253	2020-07-29 19:09:21	2020-07-29	17	[{"id_menu":4,"count":1}]	40731	delivery	5	22
106254	2020-07-29 19:11:42	2020-07-29	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	26066	delivery	5	31
106255	2020-07-29 19:17:08	2020-07-29	17	[{"id_menu":4,"count":1}]	11199	delivery	5	22
106256	2020-07-29 19:21:11	2020-07-29	17	[{"id_menu":4,"count":1}]	16321	pick-up	0	17
106257	2020-07-29 19:22:55	2020-07-29	8	[{"id_menu":5,"count":1}]	16603	delivery	5	13
106258	2020-07-29 19:24:17	2020-07-29	12	[{"id_menu":1,"count":1}]	35091	delivery	5	17
106259	2020-07-29 19:25:57	2020-07-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3674	pick-up	0	26
106260	2020-07-29 19:31:02	2020-07-29	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2422	delivery	5	52
106261	2020-07-29 19:34:38	2020-07-29	12	[{"id_menu":3,"count":1}]	1659	delivery	5	17
106262	2020-07-29 19:37:19	2020-07-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1151	pick-up	0	26
106263	2020-07-29 19:38:53	2020-07-29	9	[{"id_menu":6,"count":1}]	59	delivery	5	14
106264	2020-07-29 19:41:32	2020-07-29	14	[{"id_menu":2,"count":1}]	18150	delivery	5	19
106265	2020-07-29 19:43:41	2020-07-29	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	15769	pick-up	0	26
106266	2020-07-29 19:43:57	2020-07-29	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7855	delivery	5	43
106267	2020-07-29 19:48:27	2020-07-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	31612	delivery	5	22
106268	2020-07-29 19:49:53	2020-07-29	9	[{"id_menu":6,"count":1}]	26580	pick-up	0	9
106269	2020-07-29 19:50:37	2020-07-29	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	40924	delivery	5	40
106270	2020-07-29 19:51:27	2020-07-29	9	[{"id_menu":6,"count":1}]	40854	delivery	5	14
106271	2020-07-29 19:52:59	2020-07-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	39928	delivery	5	31
106272	2020-07-29 19:57:28	2020-07-29	9	[{"id_menu":6,"count":1}]	40807	delivery	5	14
106273	2020-07-29 19:57:41	2020-07-29	17	[{"id_menu":4,"count":1}]	22052	delivery	5	22
106274	2020-07-29 19:57:48	2020-07-29	12	[{"id_menu":3,"count":1}]	40753	delivery	5	17
106275	2020-07-29 19:58:31	2020-07-29	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27060	delivery	5	31
106276	2020-07-29 19:59:09	2020-07-29	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40784	delivery	5	31
106277	2020-07-29 20:00:51	2020-07-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	40802	delivery	5	36
106278	2020-07-29 20:06:03	2020-07-29	17	[{"id_menu":4,"count":1}]	37372	delivery	5	22
106279	2020-07-29 20:06:26	2020-07-29	12	[{"id_menu":3,"count":1}]	31841	pick-up	0	12
106280	2020-07-29 20:07:44	2020-07-29	9	[{"id_menu":6,"count":1}]	1929	delivery	5	14
106281	2020-07-29 20:08:49	2020-07-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	40993	pick-up	0	23
106282	2020-07-29 20:09:02	2020-07-29	9	[{"id_menu":7,"count":1}]	31996	delivery	5	14
106283	2020-07-29 20:10:02	2020-07-29	8	[{"id_menu":5,"count":1}]	21910	delivery	5	13
106284	2020-07-29 20:13:33	2020-07-29	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28617	delivery	5	35
106285	2020-07-29 20:17:01	2020-07-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41001	delivery	5	23
106286	2020-07-29 20:18:14	2020-07-29	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	40977	delivery	5	43
106287	2020-07-29 20:19:11	2020-07-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	28090	delivery	5	28
106288	2020-07-29 20:21:55	2020-07-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	35397	pick-up	0	26
106289	2020-07-29 20:23:02	2020-07-29	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	40929	pick-up	0	52
106290	2020-07-29 20:23:09	2020-07-29	12	[{"id_menu":3,"count":1}]	40776	delivery	5	17
106291	2020-07-29 20:23:57	2020-07-29	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	41007	delivery	5	34
106292	2020-07-29 20:25:16	2020-07-29	8	[{"id_menu":5,"count":2}]	40890	delivery	5	13
106293	2020-07-29 20:28:04	2020-07-29	14	[{"id_menu":2,"count":1}]	31452	pick-up	0	14
106294	2020-07-29 20:28:16	2020-07-29	9	[{"id_menu":7,"count":1}]	4451	delivery	5	14
106295	2020-07-29 20:30:32	2020-07-29	14	[{"id_menu":2,"count":1}]	19868	pick-up	0	14
106296	2020-07-29 20:31:58	2020-07-29	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	22123	delivery	5	40
106297	2020-07-29 20:32:09	2020-07-29	8	[{"id_menu":5,"count":1}]	30330	pick-up	0	8
106298	2020-07-29 20:32:16	2020-07-29	14	[{"id_menu":2,"count":1}]	1269	pick-up	0	14
106299	2020-07-29 20:33:36	2020-07-29	8	[{"id_menu":5,"count":1}]	40838	delivery	5	13
106300	2020-07-29 20:35:39	2020-07-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	40951	delivery	5	36
106301	2020-07-29 20:37:53	2020-07-29	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	26643	delivery	5	39
106302	2020-07-29 20:38:51	2020-07-29	8	[{"id_menu":5,"count":1}]	40817	delivery	5	13
106303	2020-07-29 20:39:08	2020-07-29	8	[{"id_menu":5,"count":1}]	40892	delivery	5	13
106304	2020-07-29 20:40:45	2020-07-29	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	40986	delivery	5	36
106305	2020-07-29 20:42:52	2020-07-29	14	[{"id_menu":2,"count":2}]	9682	pick-up	0	14
106306	2020-07-29 20:49:00	2020-07-29	9	[{"id_menu":6,"count":1}]	40797	delivery	5	14
106307	2020-07-29 20:49:03	2020-07-29	17	[{"id_menu":4,"count":1}]	2961	delivery	5	22
106308	2020-07-29 20:49:44	2020-07-29	26	[{"id_menu":4,"count":3},{"id_menu":7,"count":1}]	40855	delivery	5	31
106309	2020-07-29 20:49:59	2020-07-29	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	32505	delivery	5	40
106310	2020-07-29 20:51:20	2020-07-29	12	[{"id_menu":1,"count":1}]	35804	pick-up	0	12
106311	2020-07-29 20:53:17	2020-07-29	9	[{"id_menu":7,"count":1}]	14207	delivery	5	14
106312	2020-07-29 20:53:44	2020-07-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	40919	delivery	5	28
106313	2020-07-29 20:58:26	2020-07-29	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	22515	pick-up	0	29
106314	2020-07-29 20:59:48	2020-07-29	17	[{"id_menu":4,"count":1}]	21892	delivery	5	22
106315	2020-07-29 21:00:47	2020-07-29	14	[{"id_menu":2,"count":1}]	1573	delivery	5	19
106316	2020-07-29 21:02:28	2020-07-29	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	12188	delivery	5	29
106317	2020-07-29 21:12:35	2020-07-29	17	[{"id_menu":4,"count":1}]	40845	delivery	5	22
106318	2020-07-29 21:12:49	2020-07-29	9	[{"id_menu":6,"count":1}]	28406	pick-up	0	9
106319	2020-07-29 21:16:38	2020-07-29	12	[{"id_menu":1,"count":1}]	1597	pick-up	0	12
106320	2020-07-29 21:16:52	2020-07-29	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	19946	delivery	5	34
106321	2020-07-29 21:18:16	2020-07-29	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21074	delivery	5	34
106322	2020-07-29 21:21:22	2020-07-29	8	[{"id_menu":5,"count":1}]	4851	delivery	5	13
106323	2020-07-29 21:24:56	2020-07-29	9	[{"id_menu":6,"count":1}]	6042	delivery	5	14
106324	2020-07-29 21:26:26	2020-07-29	14	[{"id_menu":2,"count":1}]	96	pick-up	0	14
106325	2020-07-29 21:26:41	2020-07-29	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	35684	delivery	5	44
106326	2020-07-29 21:29:35	2020-07-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	40962	delivery	5	23
106327	2020-07-29 21:29:44	2020-07-29	8	[{"id_menu":5,"count":1}]	3119	delivery	5	13
106328	2020-07-29 21:30:00	2020-07-29	9	[{"id_menu":7,"count":1}]	12131	delivery	5	14
106329	2020-07-29 21:30:29	2020-07-29	14	[{"id_menu":2,"count":1}]	39465	delivery	5	19
106330	2020-07-29 21:32:29	2020-07-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	20288	delivery	5	28
106331	2020-07-29 21:33:32	2020-07-29	8	[{"id_menu":5,"count":1}]	30771	pick-up	0	8
106332	2020-07-29 21:39:58	2020-07-29	9	[{"id_menu":7,"count":1}]	1840	delivery	5	14
106333	2020-07-29 21:41:20	2020-07-29	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	24194	pick-up	0	35
106334	2020-07-29 21:44:08	2020-07-29	14	[{"id_menu":2,"count":1}]	40800	delivery	5	19
106335	2020-07-29 21:46:17	2020-07-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	13012	delivery	5	27
106336	2020-07-29 21:46:37	2020-07-29	9	[{"id_menu":7,"count":1}]	2659	delivery	5	14
106337	2020-07-29 21:52:30	2020-07-29	55	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	40750	delivery	5	60
106338	2020-07-29 21:54:52	2020-07-29	8	[{"id_menu":5,"count":1}]	40805	delivery	5	13
106339	2020-07-29 21:55:25	2020-07-29	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	3436	delivery	5	25
106340	2020-07-29 21:55:44	2020-07-29	17	[{"id_menu":4,"count":1}]	8148	delivery	5	22
106341	2020-07-29 21:55:49	2020-07-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	40851	delivery	5	31
106342	2020-07-29 21:56:32	2020-07-29	14	[{"id_menu":2,"count":1}]	9201	delivery	5	19
106343	2020-07-29 21:57:22	2020-07-29	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	27287	delivery	5	25
106344	2020-07-29 21:58:06	2020-07-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	8528	delivery	5	31
106345	2020-07-29 21:58:17	2020-07-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	40857	delivery	5	26
106346	2020-07-29 21:58:43	2020-07-29	12	[{"id_menu":3,"count":1}]	15683	pick-up	0	12
106347	2020-07-29 22:00:03	2020-07-29	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	35758	delivery	5	40
106348	2020-07-29 22:02:47	2020-07-29	12	[{"id_menu":3,"count":1}]	22049	delivery	5	17
106349	2020-07-29 22:05:50	2020-07-29	14	[{"id_menu":2,"count":1}]	21172	delivery	5	19
106350	2020-07-29 22:06:05	2020-07-29	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	15400	pick-up	0	33
106351	2020-07-29 22:06:15	2020-07-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	40761	delivery	5	28
106352	2020-07-29 22:07:08	2020-07-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	40743	delivery	5	22
106353	2020-07-29 22:09:07	2020-07-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	40945	delivery	5	31
106354	2020-07-29 22:09:08	2020-07-29	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	7710	delivery	5	40
106355	2020-07-29 22:14:04	2020-07-29	9	[{"id_menu":7,"count":1}]	40824	delivery	5	14
106356	2020-07-29 22:14:17	2020-07-29	9	[{"id_menu":7,"count":1}]	27452	delivery	5	14
106357	2020-07-29 22:14:28	2020-07-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13053	delivery	5	31
106358	2020-07-29 22:14:50	2020-07-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	21698	delivery	5	36
106359	2020-07-29 22:18:55	2020-07-29	8	[{"id_menu":5,"count":1}]	40840	delivery	5	13
106360	2020-07-29 22:19:00	2020-07-29	8	[{"id_menu":5,"count":1}]	23692	delivery	5	13
106361	2020-07-29 22:19:44	2020-07-29	8	[{"id_menu":5,"count":1}]	28333	delivery	5	13
106362	2020-07-29 22:19:45	2020-07-29	12	[{"id_menu":3,"count":2}]	28001	delivery	5	17
106363	2020-07-29 22:20:44	2020-07-29	9	[{"id_menu":7,"count":1}]	20592	delivery	5	14
106364	2020-07-29 22:20:55	2020-07-29	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	2390	delivery	5	25
106365	2020-07-29 22:20:56	2020-07-29	9	[{"id_menu":7,"count":1}]	40850	delivery	5	14
106366	2020-07-29 22:23:18	2020-07-29	9	[{"id_menu":6,"count":1}]	14290	delivery	5	14
106367	2020-07-29 22:24:33	2020-07-29	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20459	delivery	5	35
106368	2020-07-29 22:30:38	2020-07-29	12	[{"id_menu":1,"count":1}]	19864	delivery	5	17
106369	2020-07-29 22:35:25	2020-07-29	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	9171	pick-up	0	20
106370	2020-07-29 22:36:29	2020-07-29	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	26028	delivery	5	43
106371	2020-07-29 22:37:40	2020-07-29	8	[{"id_menu":5,"count":1}]	21857	delivery	5	13
106372	2020-07-29 22:38:24	2020-07-29	12	[{"id_menu":1,"count":1}]	35690	delivery	5	17
106373	2020-07-29 22:39:19	2020-07-29	9	[{"id_menu":7,"count":2}]	24120	delivery	5	14
106374	2020-07-29 22:40:10	2020-07-29	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	40932	delivery	5	37
106375	2020-07-29 22:42:58	2020-07-29	12	[{"id_menu":3,"count":1}]	11331	delivery	5	17
106376	2020-07-29 22:49:22	2020-07-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	41013	pick-up	0	17
106377	2020-07-29 22:49:27	2020-07-29	9	[{"id_menu":6,"count":1}]	19337	delivery	5	14
106378	2020-07-29 22:49:39	2020-07-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39630	delivery	5	23
106379	2020-07-29 22:49:53	2020-07-29	8	[{"id_menu":5,"count":1}]	1673	pick-up	0	8
106380	2020-07-29 22:52:16	2020-07-29	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15209	delivery	5	39
106381	2020-07-29 23:00:28	2020-07-29	9	[{"id_menu":6,"count":1}]	22423	pick-up	0	9
106382	2020-07-29 23:08:06	2020-07-29	12	[{"id_menu":1,"count":2}]	40972	delivery	5	17
106383	2020-07-29 23:12:25	2020-07-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	40729	delivery	5	31
106384	2020-07-29 23:13:45	2020-07-29	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":2}]	40727	delivery	5	25
106385	2020-07-29 23:18:02	2020-07-29	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	40814	delivery	5	23
106386	2020-07-29 23:20:00	2020-07-29	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	9996	delivery	5	40
106387	2020-07-29 23:20:24	2020-07-29	9	[{"id_menu":7,"count":1}]	18475	delivery	5	14
106388	2020-07-29 23:23:20	2020-07-29	9	[{"id_menu":6,"count":1}]	15519	delivery	5	14
106389	2020-07-29 23:24:18	2020-07-29	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	40758	delivery	5	39
106390	2020-07-29 23:25:57	2020-07-29	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13555	pick-up	0	48
106391	2020-07-29 23:26:51	2020-07-29	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	40888	delivery	5	48
106392	2020-07-29 23:27:31	2020-07-29	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	13086	delivery	5	25
106393	2020-07-29 23:27:39	2020-07-29	14	[{"id_menu":2,"count":1}]	16406	pick-up	0	14
106394	2020-07-29 23:29:12	2020-07-29	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	34419	delivery	5	22
106395	2020-07-29 23:30:07	2020-07-29	9	[{"id_menu":6,"count":2}]	29685	pick-up	0	9
106396	2020-07-29 23:33:57	2020-07-29	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26345	delivery	5	35
106397	2020-07-29 23:34:29	2020-07-29	9	[{"id_menu":6,"count":1}]	39382	delivery	5	14
106398	2020-07-29 23:36:34	2020-07-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	40900	delivery	5	36
106399	2020-07-29 23:36:45	2020-07-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6015	delivery	5	36
106400	2020-07-29 23:38:08	2020-07-29	9	[{"id_menu":7,"count":2}]	32634	delivery	5	14
106401	2020-07-29 23:38:13	2020-07-29	12	[{"id_menu":1,"count":1}]	36123	delivery	5	17
106402	2020-07-29 23:39:56	2020-07-29	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	40821	delivery	5	30
106403	2020-07-29 23:42:19	2020-07-29	14	[{"id_menu":2,"count":1}]	40910	delivery	5	19
106404	2020-07-29 23:43:16	2020-07-29	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	35062	delivery	5	25
106405	2020-07-29 23:44:00	2020-07-29	12	[{"id_menu":3,"count":1}]	26780	delivery	5	17
106406	2020-07-29 23:46:54	2020-07-29	9	[{"id_menu":6,"count":1}]	36259	delivery	5	14
106407	2020-07-29 23:47:31	2020-07-29	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	735	delivery	5	49
106408	2020-07-29 23:49:21	2020-07-29	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	40755	delivery	5	40
106409	2020-07-29 23:50:37	2020-07-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	18684	delivery	5	31
106410	2020-07-29 23:50:54	2020-07-29	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28739	delivery	5	39
106411	2020-07-29 23:51:14	2020-07-29	17	[{"id_menu":4,"count":1}]	21155	delivery	5	22
106412	2020-07-29 23:52:49	2020-07-29	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	40901	pick-up	0	35
106413	2020-07-29 23:54:23	2020-07-29	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40914	delivery	5	37
106414	2020-07-29 23:55:59	2020-07-29	9	[{"id_menu":6,"count":1}]	40752	pick-up	0	9
106415	2020-07-29 23:57:24	2020-07-29	12	[{"id_menu":1,"count":1}]	40983	delivery	5	17
106416	2020-07-29 23:58:35	2020-07-29	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	29399	delivery	5	43
106417	2020-07-30 00:00:10	2020-07-30	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	2932	pick-up	0	26
106418	2020-07-30 00:08:30	2020-07-30	17	[{"id_menu":4,"count":1}]	846	delivery	5	22
106419	2020-07-30 00:09:25	2020-07-30	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	9374	delivery	5	26
106420	2020-07-30 00:11:57	2020-07-30	9	[{"id_menu":7,"count":1}]	11424	pick-up	0	9
106421	2020-07-30 00:12:10	2020-07-30	9	[{"id_menu":7,"count":3}]	41145	delivery	5	14
106422	2020-07-30 00:14:04	2020-07-30	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	1427	delivery	5	23
106423	2020-07-30 00:16:11	2020-07-30	14	[{"id_menu":2,"count":1}]	17515	delivery	5	19
106424	2020-07-30 00:16:54	2020-07-30	14	[{"id_menu":2,"count":1}]	10222	delivery	5	19
106425	2020-07-30 00:19:25	2020-07-30	8	[{"id_menu":5,"count":1}]	34052	pick-up	0	8
106426	2020-07-30 00:19:48	2020-07-30	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	5192	delivery	5	22
106427	2020-07-30 00:20:40	2020-07-30	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	41076	delivery	5	43
106428	2020-07-30 00:23:02	2020-07-30	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2367	pick-up	0	35
106429	2020-07-30 00:23:59	2020-07-30	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30528	delivery	5	37
106430	2020-07-30 00:25:08	2020-07-30	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	41190	delivery	5	34
106431	2020-07-30 00:29:26	2020-07-30	8	[{"id_menu":5,"count":1}]	24402	pick-up	0	8
106432	2020-07-30 00:36:14	2020-07-30	12	[{"id_menu":1,"count":1}]	41091	delivery	5	17
106433	2020-07-30 00:37:09	2020-07-30	14	[{"id_menu":2,"count":1}]	5945	pick-up	0	14
106434	2020-07-30 00:38:34	2020-07-30	9	[{"id_menu":6,"count":1}]	40799	delivery	5	14
106435	2020-07-30 00:39:09	2020-07-30	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17085	delivery	5	35
106436	2020-07-30 00:41:04	2020-07-30	12	[{"id_menu":1,"count":1}]	2080	delivery	5	17
106437	2020-07-30 00:41:36	2020-07-30	12	[{"id_menu":1,"count":1}]	21553	delivery	5	17
106438	2020-07-30 00:42:03	2020-07-30	9	[{"id_menu":6,"count":1}]	41087	delivery	5	14
106439	2020-07-30 00:44:16	2020-07-30	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31567	delivery	5	49
106440	2020-07-30 00:47:17	2020-07-30	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	28543	delivery	5	35
106441	2020-07-30 00:48:43	2020-07-30	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	41111	delivery	5	26
106442	2020-07-30 00:51:47	2020-07-30	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	41181	delivery	5	44
106443	2020-07-30 00:52:12	2020-07-30	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	29394	pick-up	0	25
106444	2020-07-30 00:52:42	2020-07-30	8	[{"id_menu":5,"count":1}]	35511	delivery	5	13
106445	2020-07-30 00:59:16	2020-07-30	17	[{"id_menu":4,"count":1}]	3948	pick-up	0	17
106446	2020-07-30 01:03:29	2020-07-30	9	[{"id_menu":6,"count":1}]	41254	delivery	5	14
106447	2020-07-30 01:04:49	2020-07-30	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	41165	delivery	5	45
106448	2020-07-30 01:06:05	2020-07-30	9	[{"id_menu":6,"count":1}]	38813	delivery	5	14
106449	2020-07-30 01:06:44	2020-07-30	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	14902	delivery	5	28
106450	2020-07-30 01:08:37	2020-07-30	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	41233	delivery	5	26
106451	2020-07-30 01:08:40	2020-07-30	9	[{"id_menu":7,"count":1}]	29635	delivery	5	14
106452	2020-07-30 01:13:25	2020-07-30	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	6897	delivery	5	22
106453	2020-07-30 01:15:25	2020-07-30	8	[{"id_menu":5,"count":1}]	23822	delivery	5	13
106454	2020-07-30 01:31:21	2020-07-30	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41187	delivery	5	40
106455	2020-07-30 01:36:06	2020-07-30	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	103	pick-up	0	31
106456	2020-07-30 01:36:36	2020-07-30	17	[{"id_menu":4,"count":1}]	31379	delivery	5	22
106457	2020-07-30 01:39:01	2020-07-30	9	[{"id_menu":6,"count":1}]	41210	delivery	5	14
106458	2020-07-30 01:41:25	2020-07-30	9	[{"id_menu":7,"count":1}]	1666	delivery	5	14
106459	2020-07-30 01:42:39	2020-07-30	12	[{"id_menu":3,"count":1}]	16344	delivery	5	17
106460	2020-07-30 01:44:51	2020-07-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1212	delivery	5	22
106461	2020-07-30 01:44:53	2020-07-30	32	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	41080	delivery	5	37
106462	2020-07-30 01:50:15	2020-07-30	8	[{"id_menu":5,"count":1}]	33843	pick-up	0	8
106463	2020-07-30 01:52:18	2020-07-30	8	[{"id_menu":5,"count":1}]	11394	pick-up	0	8
106464	2020-07-30 01:53:02	2020-07-30	14	[{"id_menu":2,"count":1}]	41174	delivery	5	19
106465	2020-07-30 01:56:52	2020-07-30	8	[{"id_menu":5,"count":1}]	29164	delivery	5	13
106466	2020-07-30 02:00:26	2020-07-30	14	[{"id_menu":2,"count":3}]	30067	delivery	5	19
106467	2020-07-30 02:06:06	2020-07-30	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15271	delivery	5	51
106468	2020-07-30 02:06:51	2020-07-30	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	41144	delivery	5	23
106469	2020-07-30 02:07:29	2020-07-30	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	31743	delivery	5	31
106470	2020-07-30 02:09:23	2020-07-30	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	41162	delivery	5	34
106471	2020-07-30 02:13:36	2020-07-30	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41108	delivery	5	52
106472	2020-07-30 02:14:06	2020-07-30	12	[{"id_menu":1,"count":1}]	24471	delivery	5	17
106473	2020-07-30 02:15:28	2020-07-30	12	[{"id_menu":3,"count":1}]	41100	delivery	5	17
106474	2020-07-30 02:17:55	2020-07-30	9	[{"id_menu":7,"count":1}]	6022	delivery	5	14
106475	2020-07-30 02:18:10	2020-07-30	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	41180	delivery	5	25
106476	2020-07-30 02:18:38	2020-07-30	9	[{"id_menu":6,"count":1}]	9749	pick-up	0	9
106477	2020-07-30 02:20:02	2020-07-30	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	41029	delivery	5	45
106478	2020-07-30 02:21:21	2020-07-30	14	[{"id_menu":2,"count":1}]	41036	delivery	5	19
106479	2020-07-30 02:21:53	2020-07-30	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	41075	pick-up	0	21
106480	2020-07-30 02:24:07	2020-07-30	9	[{"id_menu":6,"count":1}]	41024	delivery	5	14
106481	2020-07-30 02:26:07	2020-07-30	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	34706	delivery	5	28
106482	2020-07-30 02:26:14	2020-07-30	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	41223	delivery	5	26
106483	2020-07-30 02:27:04	2020-07-30	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	41176	pick-up	0	24
106484	2020-07-30 02:36:02	2020-07-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	41196	delivery	5	31
106485	2020-07-30 02:40:44	2020-07-30	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	41136	pick-up	0	21
106486	2020-07-30 02:41:01	2020-07-30	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	6276	delivery	5	30
106487	2020-07-30 02:42:48	2020-07-30	17	[{"id_menu":4,"count":1}]	35855	pick-up	0	17
106488	2020-07-30 02:43:30	2020-07-30	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	720	delivery	5	40
106489	2020-07-30 02:43:40	2020-07-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	39587	pick-up	0	22
106490	2020-07-30 02:48:21	2020-07-30	14	[{"id_menu":2,"count":1}]	41224	delivery	5	19
106491	2020-07-30 02:58:44	2020-07-30	9	[{"id_menu":6,"count":1}]	35727	delivery	5	14
106492	2020-07-30 03:02:08	2020-07-30	12	[{"id_menu":1,"count":1}]	634	pick-up	0	12
106493	2020-07-30 03:04:07	2020-07-30	9	[{"id_menu":6,"count":1}]	17758	delivery	5	14
106494	2020-07-30 03:08:39	2020-07-30	9	[{"id_menu":6,"count":1}]	12849	delivery	5	14
106495	2020-07-30 03:09:38	2020-07-30	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	28060	delivery	5	57
106496	2020-07-30 03:10:02	2020-07-30	9	[{"id_menu":7,"count":1}]	32726	delivery	5	14
106497	2020-07-30 03:10:44	2020-07-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	41156	pick-up	0	23
106498	2020-07-30 03:11:11	2020-07-30	14	[{"id_menu":2,"count":1}]	33256	delivery	5	19
106499	2020-07-30 03:11:36	2020-07-30	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	41129	delivery	5	22
106500	2020-07-30 03:12:16	2020-07-30	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	41183	delivery	5	36
106501	2020-07-30 03:13:03	2020-07-30	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2269	delivery	5	46
106502	2020-07-30 03:14:30	2020-07-30	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19889	delivery	5	36
106503	2020-07-30 03:14:34	2020-07-30	8	[{"id_menu":5,"count":1}]	41252	delivery	5	13
106504	2020-07-30 03:15:46	2020-07-30	9	[{"id_menu":6,"count":1}]	13084	delivery	5	14
106505	2020-07-30 03:17:35	2020-07-30	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	41033	delivery	5	43
106506	2020-07-30 03:18:06	2020-07-30	9	[{"id_menu":6,"count":1}]	41079	delivery	5	14
106507	2020-07-30 03:20:24	2020-07-30	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41256	delivery	5	54
106508	2020-07-30 03:21:25	2020-07-30	12	[{"id_menu":3,"count":1}]	35335	delivery	5	17
106509	2020-07-30 03:25:18	2020-07-30	9	[{"id_menu":7,"count":1}]	15750	delivery	5	14
106510	2020-07-30 03:27:08	2020-07-30	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	41175	delivery	5	39
106511	2020-07-30 03:36:14	2020-07-30	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	27452	delivery	5	34
106512	2020-07-30 03:41:02	2020-07-30	9	[{"id_menu":7,"count":1}]	41117	delivery	5	14
106513	2020-07-30 03:44:48	2020-07-30	14	[{"id_menu":2,"count":1}]	6996	pick-up	0	14
106514	2020-07-30 03:55:21	2020-07-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	22610	delivery	5	31
106515	2020-07-30 03:57:27	2020-07-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24452	pick-up	0	17
106516	2020-07-30 03:57:42	2020-07-30	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	38990	delivery	5	25
106517	2020-07-30 03:59:23	2020-07-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	25279	pick-up	0	23
106518	2020-07-30 04:00:20	2020-07-30	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	41267	delivery	5	28
106519	2020-07-30 04:03:30	2020-07-30	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	16019	delivery	5	56
106520	2020-07-30 04:05:32	2020-07-30	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	4393	pick-up	0	34
106521	2020-07-30 04:07:40	2020-07-30	17	[{"id_menu":4,"count":1}]	30839	pick-up	0	17
106522	2020-07-30 04:15:24	2020-07-30	12	[{"id_menu":1,"count":1}]	41148	delivery	5	17
106523	2020-07-30 04:18:25	2020-07-30	9	[{"id_menu":7,"count":1}]	35951	delivery	5	14
106524	2020-07-30 04:18:33	2020-07-30	8	[{"id_menu":5,"count":1}]	41243	delivery	5	13
106525	2020-07-30 04:19:01	2020-07-30	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	16850	delivery	5	56
106526	2020-07-30 04:19:03	2020-07-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	38955	delivery	5	27
106527	2020-07-30 04:19:51	2020-07-30	12	[{"id_menu":1,"count":1}]	22208	delivery	5	17
106528	2020-07-30 04:21:01	2020-07-30	14	[{"id_menu":2,"count":1}]	29787	delivery	5	19
106529	2020-07-30 04:23:52	2020-07-30	9	[{"id_menu":7,"count":1}]	38046	delivery	5	14
106530	2020-07-30 04:25:41	2020-07-30	14	[{"id_menu":2,"count":1}]	15701	pick-up	0	14
106531	2020-07-30 04:28:03	2020-07-30	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	29231	pick-up	0	31
106532	2020-07-30 04:29:04	2020-07-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	15491	delivery	5	23
106533	2020-07-30 04:29:04	2020-07-30	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	27102	delivery	5	30
106534	2020-07-30 04:36:02	2020-07-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1523	pick-up	0	22
106535	2020-07-30 04:37:56	2020-07-30	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	41209	delivery	5	22
106536	2020-07-30 04:43:12	2020-07-30	9	[{"id_menu":7,"count":2}]	35581	delivery	5	14
106537	2020-07-30 04:43:42	2020-07-30	9	[{"id_menu":6,"count":1}]	9483	pick-up	0	9
106538	2020-07-30 04:44:02	2020-07-30	17	[{"id_menu":4,"count":1}]	41018	pick-up	0	17
106539	2020-07-30 04:46:24	2020-07-30	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	14378	delivery	5	25
106540	2020-07-30 04:46:46	2020-07-30	17	[{"id_menu":4,"count":1}]	9923	delivery	5	22
106541	2020-07-30 04:52:44	2020-07-30	12	[{"id_menu":3,"count":1}]	20302	delivery	5	17
106542	2020-07-30 04:53:59	2020-07-30	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	29065	pick-up	0	29
106543	2020-07-30 04:59:03	2020-07-30	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39663	delivery	5	52
106544	2020-07-30 04:59:26	2020-07-30	9	[{"id_menu":6,"count":2}]	41264	delivery	5	14
106545	2020-07-30 05:01:43	2020-07-30	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	5044	delivery	5	34
106546	2020-07-30 05:07:29	2020-07-30	8	[{"id_menu":5,"count":1}]	41034	delivery	5	13
106547	2020-07-30 05:07:55	2020-07-30	9	[{"id_menu":6,"count":1}]	41212	delivery	5	14
106548	2020-07-30 05:08:17	2020-07-30	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":2}]	11933	delivery	5	26
106549	2020-07-30 05:12:07	2020-07-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	41137	delivery	5	28
106550	2020-07-30 05:14:33	2020-07-30	12	[{"id_menu":1,"count":1}]	34400	delivery	5	17
106551	2020-07-30 05:15:54	2020-07-30	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	14364	delivery	5	25
106552	2020-07-30 05:21:35	2020-07-30	9	[{"id_menu":6,"count":1}]	10499	delivery	5	14
106553	2020-07-30 05:22:45	2020-07-30	8	[{"id_menu":5,"count":1}]	9393	delivery	5	13
106554	2020-07-30 05:22:54	2020-07-30	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21562	delivery	5	35
106555	2020-07-30 05:25:02	2020-07-30	9	[{"id_menu":7,"count":1}]	14628	pick-up	0	9
106556	2020-07-30 05:31:14	2020-07-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41221	delivery	5	23
106557	2020-07-30 05:31:35	2020-07-30	9	[{"id_menu":6,"count":2}]	28617	delivery	5	14
106558	2020-07-30 05:32:51	2020-07-30	12	[{"id_menu":1,"count":1}]	20261	delivery	5	17
106559	2020-07-30 05:33:00	2020-07-30	9	[{"id_menu":6,"count":1}]	26520	delivery	5	14
106560	2020-07-30 05:33:05	2020-07-30	14	[{"id_menu":2,"count":1}]	18331	pick-up	0	14
106561	2020-07-30 05:33:16	2020-07-30	8	[{"id_menu":5,"count":1}]	20528	delivery	5	13
106562	2020-07-30 05:34:39	2020-07-30	17	[{"id_menu":4,"count":1}]	41143	delivery	5	22
106563	2020-07-30 05:36:51	2020-07-30	9	[{"id_menu":6,"count":1}]	12997	delivery	5	14
106564	2020-07-30 05:36:52	2020-07-30	12	[{"id_menu":1,"count":1}]	19833	pick-up	0	12
106565	2020-07-30 05:39:15	2020-07-30	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	26473	delivery	5	31
106566	2020-07-30 05:42:37	2020-07-30	9	[{"id_menu":7,"count":1}]	41121	delivery	5	14
106567	2020-07-30 05:43:51	2020-07-30	8	[{"id_menu":5,"count":1}]	27148	pick-up	0	8
106568	2020-07-30 05:48:05	2020-07-30	8	[{"id_menu":5,"count":1}]	41170	delivery	5	13
106569	2020-07-30 05:48:23	2020-07-30	12	[{"id_menu":1,"count":1}]	3522	delivery	5	17
106570	2020-07-30 05:48:40	2020-07-30	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	41131	delivery	5	45
106571	2020-07-30 05:50:03	2020-07-30	8	[{"id_menu":5,"count":1}]	11651	delivery	5	13
106572	2020-07-30 05:50:34	2020-07-30	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	37303	delivery	5	40
106573	2020-07-30 05:50:46	2020-07-30	9	[{"id_menu":6,"count":1}]	41141	delivery	5	14
106574	2020-07-30 05:52:25	2020-07-30	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	1334	pick-up	0	26
106575	2020-07-30 05:55:36	2020-07-30	12	[{"id_menu":3,"count":1}]	41164	delivery	5	17
106576	2020-07-30 05:56:18	2020-07-30	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	41159	delivery	5	40
106577	2020-07-30 05:56:45	2020-07-30	8	[{"id_menu":5,"count":1}]	4690	pick-up	0	8
106578	2020-07-30 05:59:44	2020-07-30	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	19729	pick-up	0	29
106579	2020-07-30 06:07:24	2020-07-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	41124	delivery	5	23
106580	2020-07-30 06:09:55	2020-07-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	21973	delivery	5	31
106581	2020-07-30 06:10:22	2020-07-30	12	[{"id_menu":3,"count":1}]	41237	delivery	5	17
106582	2020-07-30 06:10:52	2020-07-30	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36366	delivery	5	35
106583	2020-07-30 06:10:57	2020-07-30	14	[{"id_menu":2,"count":1}]	41157	pick-up	0	14
106584	2020-07-30 06:14:04	2020-07-30	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	41198	delivery	5	31
106585	2020-07-30 06:14:51	2020-07-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	19031	delivery	5	28
106586	2020-07-30 06:15:48	2020-07-30	17	[{"id_menu":4,"count":1}]	41222	delivery	5	22
106587	2020-07-30 06:21:01	2020-07-30	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24101	delivery	5	34
106588	2020-07-30 06:21:53	2020-07-30	17	[{"id_menu":4,"count":1}]	17955	delivery	5	22
106589	2020-07-30 06:22:14	2020-07-30	9	[{"id_menu":6,"count":1}]	4658	pick-up	0	9
106590	2020-07-30 06:26:15	2020-07-30	8	[{"id_menu":5,"count":1}]	40655	delivery	5	13
106591	2020-07-30 06:27:31	2020-07-30	9	[{"id_menu":6,"count":1}]	40459	pick-up	0	9
106592	2020-07-30 06:27:48	2020-07-30	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	18864	delivery	5	31
106593	2020-07-30 06:29:40	2020-07-30	12	[{"id_menu":1,"count":1}]	5711	delivery	5	17
106594	2020-07-30 06:29:52	2020-07-30	8	[{"id_menu":5,"count":1}]	1137	delivery	5	13
106595	2020-07-30 06:30:32	2020-07-30	17	[{"id_menu":4,"count":1}]	24751	delivery	5	22
106596	2020-07-30 06:32:59	2020-07-30	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	41232	delivery	5	39
106597	2020-07-30 06:36:02	2020-07-30	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3619	pick-up	0	29
106598	2020-07-30 06:40:55	2020-07-30	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	9021	delivery	5	29
106599	2020-07-30 06:40:57	2020-07-30	8	[{"id_menu":5,"count":1}]	13555	pick-up	0	8
106600	2020-07-30 06:42:44	2020-07-30	14	[{"id_menu":2,"count":1}]	26964	delivery	5	19
106601	2020-07-30 06:42:51	2020-07-30	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	36113	delivery	5	22
106602	2020-07-30 06:43:29	2020-07-30	9	[{"id_menu":6,"count":1}]	19552	delivery	5	14
106603	2020-07-30 06:47:37	2020-07-30	9	[{"id_menu":7,"count":1}]	26955	delivery	5	14
106604	2020-07-30 06:51:29	2020-07-30	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	36161	delivery	5	31
106605	2020-07-30 06:53:40	2020-07-30	12	[{"id_menu":3,"count":1}]	41205	delivery	5	17
106606	2020-07-30 06:54:24	2020-07-30	12	[{"id_menu":1,"count":1}]	10583	delivery	5	17
106607	2020-07-30 06:56:41	2020-07-30	9	[{"id_menu":6,"count":1}]	41019	delivery	5	14
106608	2020-07-30 06:57:22	2020-07-30	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	9163	delivery	5	34
106609	2020-07-30 06:59:29	2020-07-30	14	[{"id_menu":2,"count":1}]	3330	pick-up	0	14
106610	2020-07-30 07:00:57	2020-07-30	8	[{"id_menu":5,"count":1}]	26973	delivery	5	13
106611	2020-07-30 07:02:26	2020-07-30	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	41055	delivery	5	30
106612	2020-07-30 07:05:22	2020-07-30	17	[{"id_menu":4,"count":1}]	22772	delivery	5	22
106613	2020-07-30 07:10:23	2020-07-30	12	[{"id_menu":3,"count":1}]	19923	delivery	5	17
106614	2020-07-30 07:10:57	2020-07-30	31	[{"id_menu":2,"count":3},{"id_menu":4,"count":1}]	24031	delivery	5	36
106615	2020-07-30 07:14:51	2020-07-30	12	[{"id_menu":3,"count":2}]	41023	pick-up	0	12
106616	2020-07-30 07:16:43	2020-07-30	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	17064	delivery	5	26
106617	2020-07-30 07:18:17	2020-07-30	12	[{"id_menu":1,"count":1}]	3949	pick-up	0	12
106618	2020-07-30 07:20:22	2020-07-30	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31370	delivery	5	39
106619	2020-07-30 07:21:00	2020-07-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41226	delivery	5	23
106620	2020-07-30 07:21:41	2020-07-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3692	delivery	5	28
106621	2020-07-30 07:22:37	2020-07-30	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	20457	delivery	5	44
106622	2020-07-30 07:23:27	2020-07-30	9	[{"id_menu":7,"count":2}]	27161	pick-up	0	9
106623	2020-07-30 07:24:05	2020-07-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41154	delivery	5	23
106624	2020-07-30 07:27:49	2020-07-30	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	27082	delivery	5	34
106625	2020-07-30 07:28:43	2020-07-30	17	[{"id_menu":4,"count":1}]	5364	pick-up	0	17
106626	2020-07-30 07:37:55	2020-07-30	9	[{"id_menu":6,"count":2}]	32534	delivery	5	14
106627	2020-07-30 07:39:34	2020-07-30	9	[{"id_menu":6,"count":1}]	29861	delivery	5	14
106628	2020-07-30 07:40:52	2020-07-30	9	[{"id_menu":7,"count":1}]	39959	delivery	5	14
106629	2020-07-30 07:41:08	2020-07-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	22441	delivery	5	31
106630	2020-07-30 07:42:09	2020-07-30	9	[{"id_menu":7,"count":1}]	10477	pick-up	0	9
106631	2020-07-30 07:44:41	2020-07-30	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21003	delivery	5	49
106632	2020-07-30 07:46:16	2020-07-30	22	[{"id_menu":2,"count":3},{"id_menu":5,"count":1}]	41078	delivery	5	27
106633	2020-07-30 07:46:30	2020-07-30	14	[{"id_menu":2,"count":1}]	38778	delivery	5	19
106634	2020-07-30 07:47:10	2020-07-30	8	[{"id_menu":5,"count":1}]	41200	delivery	5	13
106635	2020-07-30 07:48:13	2020-07-30	14	[{"id_menu":2,"count":1}]	41179	pick-up	0	14
106636	2020-07-30 07:53:52	2020-07-30	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	15549	delivery	5	39
106637	2020-07-30 07:57:44	2020-07-30	9	[{"id_menu":7,"count":1}]	41099	delivery	5	14
106638	2020-07-30 07:58:48	2020-07-30	14	[{"id_menu":2,"count":1}]	31143	delivery	5	19
106639	2020-07-30 08:02:01	2020-07-30	9	[{"id_menu":7,"count":1}]	38081	pick-up	0	9
106640	2020-07-30 08:04:39	2020-07-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	21007	delivery	5	28
106641	2020-07-30 08:04:45	2020-07-30	17	[{"id_menu":4,"count":1}]	26508	delivery	5	22
106642	2020-07-30 08:04:49	2020-07-30	12	[{"id_menu":3,"count":1}]	41213	delivery	5	17
106643	2020-07-30 08:06:00	2020-07-30	9	[{"id_menu":7,"count":1}]	2776	pick-up	0	9
106644	2020-07-30 08:06:08	2020-07-30	12	[{"id_menu":3,"count":1}]	11878	delivery	5	17
106645	2020-07-30 08:06:19	2020-07-30	9	[{"id_menu":7,"count":1}]	25040	delivery	5	14
106646	2020-07-30 08:13:11	2020-07-30	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	28574	delivery	5	26
106647	2020-07-30 08:23:25	2020-07-30	9	[{"id_menu":6,"count":1}]	23647	delivery	5	14
106648	2020-07-30 08:25:53	2020-07-30	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	36615	pick-up	0	35
106649	2020-07-30 08:29:30	2020-07-30	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2591	pick-up	0	20
106650	2020-07-30 08:32:24	2020-07-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	14608	delivery	5	28
106651	2020-07-30 08:35:07	2020-07-30	9	[{"id_menu":7,"count":1}]	21163	delivery	5	14
106652	2020-07-30 08:39:29	2020-07-30	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41248	delivery	5	43
106653	2020-07-30 08:39:56	2020-07-30	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	41041	delivery	5	53
106654	2020-07-30 08:40:23	2020-07-30	12	[{"id_menu":1,"count":1}]	41168	delivery	5	17
106655	2020-07-30 08:41:26	2020-07-30	9	[{"id_menu":7,"count":1}]	41060	delivery	5	14
106656	2020-07-30 08:44:07	2020-07-30	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9494	delivery	5	31
106657	2020-07-30 08:45:56	2020-07-30	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41058	delivery	5	31
106658	2020-07-30 08:50:01	2020-07-30	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40431	delivery	5	31
106659	2020-07-30 08:50:10	2020-07-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	40192	delivery	5	28
106660	2020-07-30 08:50:45	2020-07-30	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	3900	pick-up	0	29
106661	2020-07-30 08:52:48	2020-07-30	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	41030	delivery	5	42
106662	2020-07-30 08:56:19	2020-07-30	29	[{"id_menu":3,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27970	delivery	5	34
106663	2020-07-30 09:00:02	2020-07-30	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	29233	delivery	5	26
106664	2020-07-30 09:01:41	2020-07-30	17	[{"id_menu":4,"count":1}]	41218	delivery	5	22
106665	2020-07-30 09:03:29	2020-07-30	12	[{"id_menu":1,"count":1}]	14780	delivery	5	17
106666	2020-07-30 09:05:37	2020-07-30	12	[{"id_menu":1,"count":1}]	41109	delivery	5	17
106667	2020-07-30 09:06:52	2020-07-30	9	[{"id_menu":6,"count":2}]	31315	delivery	5	14
106668	2020-07-30 09:10:02	2020-07-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	41064	delivery	5	27
106669	2020-07-30 09:13:26	2020-07-30	14	[{"id_menu":2,"count":1}]	41083	delivery	5	19
106670	2020-07-30 09:13:45	2020-07-30	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	38486	delivery	5	34
106671	2020-07-30 09:14:41	2020-07-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	41054	pick-up	0	18
106672	2020-07-30 09:15:23	2020-07-30	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	40710	delivery	5	25
106673	2020-07-30 09:19:15	2020-07-30	12	[{"id_menu":3,"count":1}]	41255	delivery	5	17
106674	2020-07-30 09:19:28	2020-07-30	9	[{"id_menu":7,"count":2}]	41265	delivery	5	14
106675	2020-07-30 09:20:20	2020-07-30	9	[{"id_menu":6,"count":1}]	41120	delivery	5	14
106676	2020-07-30 09:21:52	2020-07-30	9	[{"id_menu":6,"count":1}]	41073	delivery	5	14
106677	2020-07-30 09:24:43	2020-07-30	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	41206	delivery	5	25
106678	2020-07-30 09:27:40	2020-07-30	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	26256	delivery	5	25
106679	2020-07-30 09:31:10	2020-07-30	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	41169	delivery	5	26
106680	2020-07-30 09:31:58	2020-07-30	8	[{"id_menu":5,"count":1}]	28629	pick-up	0	8
106681	2020-07-30 09:35:53	2020-07-30	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	26768	delivery	5	48
106682	2020-07-30 09:39:57	2020-07-30	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	38804	delivery	5	31
106683	2020-07-30 09:40:13	2020-07-30	9	[{"id_menu":6,"count":1}]	13681	delivery	5	14
106684	2020-07-30 09:40:47	2020-07-30	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	41110	delivery	5	43
106685	2020-07-30 09:42:13	2020-07-30	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	41166	delivery	5	34
106686	2020-07-30 09:44:02	2020-07-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2552	pick-up	0	17
106687	2020-07-30 09:47:57	2020-07-30	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	41177	delivery	5	43
106688	2020-07-30 09:52:04	2020-07-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41062	delivery	5	23
106689	2020-07-30 09:55:31	2020-07-30	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18203	delivery	5	22
106690	2020-07-30 09:56:45	2020-07-30	8	[{"id_menu":5,"count":1}]	37893	delivery	5	13
106691	2020-07-30 09:59:21	2020-07-30	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	28799	delivery	5	27
106692	2020-07-30 10:01:03	2020-07-30	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	41105	delivery	5	40
106693	2020-07-30 10:01:16	2020-07-30	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13878	delivery	5	31
106694	2020-07-30 10:02:36	2020-07-30	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	41239	delivery	5	45
106695	2020-07-30 10:03:26	2020-07-30	12	[{"id_menu":3,"count":1}]	41066	delivery	5	17
106696	2020-07-30 10:04:16	2020-07-30	14	[{"id_menu":2,"count":1}]	20723	delivery	5	19
106697	2020-07-30 10:06:31	2020-07-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13888	delivery	5	31
106698	2020-07-30 10:11:15	2020-07-30	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6298	delivery	5	40
106699	2020-07-30 10:13:15	2020-07-30	17	[{"id_menu":4,"count":1}]	41220	delivery	5	22
106700	2020-07-30 10:16:13	2020-07-30	8	[{"id_menu":5,"count":1}]	25882	pick-up	0	8
106701	2020-07-30 10:17:45	2020-07-30	12	[{"id_menu":3,"count":1}]	2885	delivery	5	17
106702	2020-07-30 10:21:01	2020-07-30	12	[{"id_menu":3,"count":1}]	29945	delivery	5	17
106703	2020-07-30 10:21:45	2020-07-30	9	[{"id_menu":6,"count":1}]	41115	pick-up	0	9
106704	2020-07-30 10:28:27	2020-07-30	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	5039	delivery	5	29
106705	2020-07-30 10:32:36	2020-07-30	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	30385	delivery	5	57
106706	2020-07-30 10:33:31	2020-07-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	29585	delivery	5	26
106707	2020-07-30 10:33:38	2020-07-30	9	[{"id_menu":7,"count":1}]	24952	delivery	5	14
106708	2020-07-30 10:35:04	2020-07-30	9	[{"id_menu":7,"count":1}]	8443	delivery	5	14
106709	2020-07-30 10:35:19	2020-07-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":3}]	30399	delivery	5	26
106710	2020-07-30 10:37:54	2020-07-30	8	[{"id_menu":5,"count":1}]	41098	delivery	5	13
106711	2020-07-30 10:39:04	2020-07-30	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15511	delivery	5	22
106712	2020-07-30 10:43:12	2020-07-30	9	[{"id_menu":7,"count":2}]	13389	pick-up	0	9
106713	2020-07-30 10:46:16	2020-07-30	12	[{"id_menu":1,"count":1}]	41214	pick-up	0	12
106714	2020-07-30 10:46:53	2020-07-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	39654	delivery	5	31
106715	2020-07-30 10:49:26	2020-07-30	9	[{"id_menu":7,"count":1}]	9918	delivery	5	14
106716	2020-07-30 10:52:40	2020-07-30	14	[{"id_menu":2,"count":1}]	23724	pick-up	0	14
106717	2020-07-30 10:52:57	2020-07-30	12	[{"id_menu":1,"count":1}]	17288	delivery	5	17
106718	2020-07-30 10:53:16	2020-07-30	12	[{"id_menu":1,"count":1}]	8265	pick-up	0	12
106719	2020-07-30 10:53:39	2020-07-30	14	[{"id_menu":2,"count":1}]	184	delivery	5	19
106720	2020-07-30 10:54:40	2020-07-30	9	[{"id_menu":6,"count":1}]	41188	delivery	5	14
106721	2020-07-30 10:56:30	2020-07-30	14	[{"id_menu":2,"count":1}]	27519	delivery	5	19
106722	2020-07-30 10:58:05	2020-07-30	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	24493	delivery	5	25
106723	2020-07-30 10:58:44	2020-07-30	9	[{"id_menu":7,"count":1}]	41184	delivery	5	14
106724	2020-07-30 10:59:24	2020-07-30	9	[{"id_menu":6,"count":1}]	41186	delivery	5	14
106725	2020-07-30 11:01:03	2020-07-30	17	[{"id_menu":4,"count":1}]	21967	delivery	5	22
106726	2020-07-30 11:01:34	2020-07-30	9	[{"id_menu":6,"count":1}]	2608	pick-up	0	9
106727	2020-07-30 11:05:09	2020-07-30	12	[{"id_menu":3,"count":1}]	19987	delivery	5	17
106728	2020-07-30 11:11:32	2020-07-30	9	[{"id_menu":7,"count":1}]	41035	delivery	5	14
106729	2020-07-30 11:14:29	2020-07-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	39841	delivery	5	31
106730	2020-07-30 11:23:47	2020-07-30	8	[{"id_menu":5,"count":1}]	27849	delivery	5	13
106731	2020-07-30 11:23:59	2020-07-30	14	[{"id_menu":2,"count":1}]	13497	delivery	5	19
106732	2020-07-30 11:25:45	2020-07-30	12	[{"id_menu":1,"count":1}]	41051	delivery	5	17
106733	2020-07-30 11:26:18	2020-07-30	14	[{"id_menu":2,"count":1}]	2726	pick-up	0	14
106734	2020-07-30 11:30:09	2020-07-30	17	[{"id_menu":4,"count":1}]	41122	delivery	5	22
106735	2020-07-30 11:32:29	2020-07-30	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	41257	delivery	5	39
106736	2020-07-30 11:36:27	2020-07-30	9	[{"id_menu":7,"count":2}]	1911	delivery	5	14
106737	2020-07-30 11:40:17	2020-07-30	9	[{"id_menu":7,"count":1}]	27806	delivery	5	14
106738	2020-07-30 11:41:56	2020-07-30	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	124	pick-up	0	37
106739	2020-07-30 11:43:29	2020-07-30	9	[{"id_menu":7,"count":1}]	41139	delivery	5	14
106740	2020-07-30 11:47:09	2020-07-30	12	[{"id_menu":3,"count":1}]	4100	delivery	5	17
106741	2020-07-30 11:47:54	2020-07-30	12	[{"id_menu":3,"count":1}]	26861	delivery	5	17
106742	2020-07-30 11:50:06	2020-07-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	41191	delivery	5	26
106743	2020-07-30 11:51:24	2020-07-30	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	34704	delivery	5	42
106744	2020-07-30 11:52:08	2020-07-30	9	[{"id_menu":6,"count":2}]	16334	delivery	5	14
106745	2020-07-30 11:55:44	2020-07-30	14	[{"id_menu":2,"count":1}]	41202	delivery	5	19
106746	2020-07-30 12:00:10	2020-07-30	8	[{"id_menu":5,"count":1}]	41211	delivery	5	13
106747	2020-07-30 12:01:14	2020-07-30	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21912	delivery	5	34
106748	2020-07-30 12:01:51	2020-07-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19229	delivery	5	22
106749	2020-07-30 12:03:32	2020-07-30	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	12305	pick-up	0	35
106750	2020-07-30 12:05:58	2020-07-30	8	[{"id_menu":5,"count":1}]	38188	delivery	5	13
106751	2020-07-30 12:06:01	2020-07-30	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	41059	delivery	5	48
106752	2020-07-30 12:08:32	2020-07-30	14	[{"id_menu":2,"count":1}]	41050	delivery	5	19
106753	2020-07-30 12:08:36	2020-07-30	14	[{"id_menu":2,"count":1}]	41216	pick-up	0	14
106754	2020-07-30 12:10:41	2020-07-30	8	[{"id_menu":5,"count":1}]	41084	delivery	5	13
106755	2020-07-30 12:12:43	2020-07-30	12	[{"id_menu":3,"count":1}]	17742	delivery	5	17
106756	2020-07-30 12:18:29	2020-07-30	9	[{"id_menu":6,"count":1}]	10518	delivery	5	14
106757	2020-07-30 12:19:30	2020-07-30	12	[{"id_menu":1,"count":1}]	41217	delivery	5	17
106758	2020-07-30 12:20:03	2020-07-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	41016	delivery	5	28
106759	2020-07-30 12:20:56	2020-07-30	14	[{"id_menu":2,"count":1}]	41114	pick-up	0	14
106760	2020-07-30 12:21:37	2020-07-30	17	[{"id_menu":4,"count":1}]	41193	pick-up	0	17
106761	2020-07-30 12:26:19	2020-07-30	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	35098	delivery	5	25
106762	2020-07-30 12:27:19	2020-07-30	12	[{"id_menu":3,"count":1}]	15818	delivery	5	17
106763	2020-07-30 12:27:52	2020-07-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	41128	delivery	5	22
106764	2020-07-30 12:28:06	2020-07-30	17	[{"id_menu":4,"count":1}]	23378	delivery	5	22
106765	2020-07-30 12:32:03	2020-07-30	9	[{"id_menu":6,"count":1}]	3002	pick-up	0	9
106766	2020-07-30 12:33:17	2020-07-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41040	delivery	5	23
106767	2020-07-30 12:38:19	2020-07-30	14	[{"id_menu":2,"count":1}]	34106	delivery	5	19
106768	2020-07-30 12:41:03	2020-07-30	8	[{"id_menu":5,"count":1}]	41081	delivery	5	13
106769	2020-07-30 12:43:10	2020-07-30	9	[{"id_menu":7,"count":1}]	9358	pick-up	0	9
106770	2020-07-30 12:47:48	2020-07-30	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	41229	delivery	5	57
106771	2020-07-30 12:50:48	2020-07-30	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	12790	delivery	5	48
106772	2020-07-30 12:51:40	2020-07-30	9	[{"id_menu":6,"count":2}]	32933	delivery	5	14
106773	2020-07-30 12:52:38	2020-07-30	8	[{"id_menu":5,"count":1}]	18356	delivery	5	13
106774	2020-07-30 12:55:07	2020-07-30	8	[{"id_menu":5,"count":1}]	13879	delivery	5	13
106775	2020-07-30 12:58:01	2020-07-30	17	[{"id_menu":4,"count":1}]	32502	delivery	5	22
106776	2020-07-30 12:59:11	2020-07-30	14	[{"id_menu":2,"count":1}]	14524	pick-up	0	14
106777	2020-07-30 13:02:53	2020-07-30	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	6656	delivery	5	22
106778	2020-07-30 13:04:30	2020-07-30	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41061	delivery	5	31
106779	2020-07-30 13:05:16	2020-07-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	41182	delivery	5	22
106780	2020-07-30 13:06:01	2020-07-30	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	41044	delivery	5	26
106781	2020-07-30 13:08:21	2020-07-30	12	[{"id_menu":1,"count":1}]	41253	delivery	5	17
106782	2020-07-30 13:08:22	2020-07-30	17	[{"id_menu":4,"count":1}]	41246	delivery	5	22
106783	2020-07-30 13:09:51	2020-07-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	41094	delivery	5	27
106784	2020-07-30 13:10:21	2020-07-30	8	[{"id_menu":5,"count":1}]	35287	pick-up	0	8
106785	2020-07-30 13:10:23	2020-07-30	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	31480	delivery	5	36
106786	2020-07-30 13:13:54	2020-07-30	17	[{"id_menu":4,"count":1}]	40555	pick-up	0	17
106787	2020-07-30 13:14:07	2020-07-30	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	30408	delivery	5	42
106788	2020-07-30 13:15:48	2020-07-30	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16048	delivery	5	36
106789	2020-07-30 13:16:26	2020-07-30	8	[{"id_menu":5,"count":1}]	13613	pick-up	0	8
106790	2020-07-30 13:22:42	2020-07-30	17	[{"id_menu":4,"count":1}]	21996	delivery	5	22
106791	2020-07-30 13:31:13	2020-07-30	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2426	pick-up	0	30
106792	2020-07-30 13:31:40	2020-07-30	9	[{"id_menu":7,"count":1}]	41101	delivery	5	14
106793	2020-07-30 13:34:31	2020-07-30	14	[{"id_menu":2,"count":1}]	41155	delivery	5	19
106794	2020-07-30 13:34:57	2020-07-30	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	4636	delivery	5	36
106795	2020-07-30 13:34:59	2020-07-30	17	[{"id_menu":4,"count":1}]	2497	delivery	5	22
106796	2020-07-30 13:36:28	2020-07-30	9	[{"id_menu":7,"count":1}]	1453	delivery	5	14
106797	2020-07-30 13:38:05	2020-07-30	17	[{"id_menu":4,"count":1}]	3655	pick-up	0	17
106798	2020-07-30 13:40:47	2020-07-30	17	[{"id_menu":4,"count":1}]	19461	pick-up	0	17
106799	2020-07-30 13:42:08	2020-07-30	12	[{"id_menu":3,"count":1}]	41153	delivery	5	17
106800	2020-07-30 13:42:51	2020-07-30	9	[{"id_menu":6,"count":1}]	32344	delivery	5	14
106801	2020-07-30 13:50:05	2020-07-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41113	delivery	5	23
106802	2020-07-30 13:51:45	2020-07-30	9	[{"id_menu":6,"count":1}]	4575	delivery	5	14
106803	2020-07-30 13:55:30	2020-07-30	9	[{"id_menu":7,"count":1}]	17392	delivery	5	14
106804	2020-07-30 13:57:36	2020-07-30	9	[{"id_menu":6,"count":1}]	41049	delivery	5	14
106805	2020-07-30 13:57:48	2020-07-30	14	[{"id_menu":2,"count":1}]	34031	delivery	5	19
106806	2020-07-30 13:58:03	2020-07-30	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7293	delivery	5	34
106807	2020-07-30 13:58:09	2020-07-30	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11748	delivery	5	39
106808	2020-07-30 13:58:54	2020-07-30	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	28911	delivery	5	36
106809	2020-07-30 14:00:23	2020-07-30	9	[{"id_menu":6,"count":1}]	24302	pick-up	0	9
106810	2020-07-30 14:01:37	2020-07-30	14	[{"id_menu":2,"count":1}]	27502	delivery	5	19
106811	2020-07-30 14:03:50	2020-07-30	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	41095	delivery	5	34
106812	2020-07-30 14:07:26	2020-07-30	12	[{"id_menu":1,"count":1}]	886	pick-up	0	12
106813	2020-07-30 14:08:02	2020-07-30	8	[{"id_menu":5,"count":2}]	41204	delivery	5	13
106814	2020-07-30 14:11:43	2020-07-30	49	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	41032	delivery	5	54
106815	2020-07-30 14:22:37	2020-07-30	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	26186	delivery	5	34
106816	2020-07-30 14:23:49	2020-07-30	17	[{"id_menu":4,"count":1}]	5483	delivery	5	22
106817	2020-07-30 14:25:24	2020-07-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	12430	delivery	5	23
106818	2020-07-30 14:25:46	2020-07-30	14	[{"id_menu":2,"count":1}]	41147	delivery	5	19
106819	2020-07-30 14:26:10	2020-07-30	12	[{"id_menu":3,"count":1}]	10394	pick-up	0	12
106820	2020-07-30 14:28:16	2020-07-30	9	[{"id_menu":7,"count":1}]	17046	pick-up	0	9
106821	2020-07-30 14:30:01	2020-07-30	9	[{"id_menu":7,"count":1}]	12001	pick-up	0	9
106822	2020-07-30 14:37:37	2020-07-30	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	27558	delivery	5	26
106823	2020-07-30 14:38:18	2020-07-30	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	15199	delivery	5	26
106824	2020-07-30 14:38:32	2020-07-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	41107	delivery	5	28
106825	2020-07-30 14:42:09	2020-07-30	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	35563	delivery	5	26
106826	2020-07-30 14:46:29	2020-07-30	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	21805	delivery	5	44
106827	2020-07-30 14:47:55	2020-07-30	14	[{"id_menu":2,"count":1}]	21121	pick-up	0	14
106828	2020-07-30 14:47:58	2020-07-30	9	[{"id_menu":6,"count":1}]	41116	delivery	5	14
106829	2020-07-30 14:49:44	2020-07-30	9	[{"id_menu":6,"count":1}]	15764	pick-up	0	9
106830	2020-07-30 14:51:06	2020-07-30	9	[{"id_menu":7,"count":1}]	41140	delivery	5	14
106831	2020-07-30 14:51:34	2020-07-30	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	3015	delivery	5	48
106832	2020-07-30 14:52:20	2020-07-30	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	23345	delivery	5	39
106833	2020-07-30 14:58:32	2020-07-30	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	41106	delivery	5	36
106834	2020-07-30 15:01:40	2020-07-30	9	[{"id_menu":7,"count":1}]	24517	delivery	5	14
106835	2020-07-30 15:04:06	2020-07-30	12	[{"id_menu":3,"count":1}]	41047	delivery	5	17
106836	2020-07-30 15:05:02	2020-07-30	14	[{"id_menu":2,"count":2}]	6072	delivery	5	19
106837	2020-07-30 15:08:59	2020-07-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6235	pick-up	0	23
106838	2020-07-30 15:10:14	2020-07-30	9	[{"id_menu":6,"count":1}]	41025	delivery	5	14
106839	2020-07-30 15:15:17	2020-07-30	9	[{"id_menu":6,"count":1}]	41251	delivery	5	14
106840	2020-07-30 15:18:22	2020-07-30	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	29837	delivery	5	36
106841	2020-07-30 15:21:11	2020-07-30	8	[{"id_menu":5,"count":1}]	10080	delivery	5	13
106842	2020-07-30 15:22:56	2020-07-30	34	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	41070	delivery	5	39
106843	2020-07-30 15:24:21	2020-07-30	9	[{"id_menu":6,"count":2}]	2373	pick-up	0	9
106844	2020-07-30 15:25:21	2020-07-30	12	[{"id_menu":1,"count":1}]	23781	delivery	5	17
106845	2020-07-30 15:28:17	2020-07-30	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	37356	delivery	5	31
106846	2020-07-30 15:28:30	2020-07-30	9	[{"id_menu":6,"count":2}]	41118	delivery	5	14
106847	2020-07-30 15:28:52	2020-07-30	9	[{"id_menu":6,"count":1}]	4410	pick-up	0	9
106848	2020-07-30 15:30:35	2020-07-30	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	35655	delivery	5	25
106849	2020-07-30 15:32:06	2020-07-30	14	[{"id_menu":2,"count":1}]	24904	delivery	5	19
106850	2020-07-30 15:32:47	2020-07-30	9	[{"id_menu":6,"count":1}]	22869	delivery	5	14
106851	2020-07-30 15:33:46	2020-07-30	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	40232	pick-up	0	26
106852	2020-07-30 15:36:44	2020-07-30	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7476	delivery	5	40
106853	2020-07-30 15:38:35	2020-07-30	8	[{"id_menu":5,"count":1}]	12930	delivery	5	13
106854	2020-07-30 15:38:41	2020-07-30	9	[{"id_menu":6,"count":1}]	15422	delivery	5	14
106855	2020-07-30 15:40:14	2020-07-30	12	[{"id_menu":3,"count":1}]	5975	delivery	5	17
106856	2020-07-30 15:41:01	2020-07-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	41249	delivery	5	31
106857	2020-07-30 15:41:52	2020-07-30	12	[{"id_menu":3,"count":1}]	19496	delivery	5	17
106858	2020-07-30 15:42:44	2020-07-30	14	[{"id_menu":2,"count":2}]	29824	delivery	5	19
106859	2020-07-30 15:43:16	2020-07-30	9	[{"id_menu":7,"count":1}]	41263	delivery	5	14
106860	2020-07-30 15:44:14	2020-07-30	14	[{"id_menu":2,"count":1}]	1726	pick-up	0	14
106861	2020-07-30 15:46:01	2020-07-30	12	[{"id_menu":3,"count":1}]	14913	delivery	5	17
106862	2020-07-30 15:46:09	2020-07-30	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	25292	delivery	5	40
106863	2020-07-30 15:46:28	2020-07-30	9	[{"id_menu":7,"count":1}]	7378	delivery	5	14
106864	2020-07-30 15:46:29	2020-07-30	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	10144	delivery	5	29
106865	2020-07-30 15:46:30	2020-07-30	17	[{"id_menu":4,"count":1}]	18304	pick-up	0	17
106866	2020-07-30 15:48:55	2020-07-30	9	[{"id_menu":7,"count":1}]	7893	delivery	5	14
106867	2020-07-30 15:55:06	2020-07-30	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	41104	delivery	5	25
106868	2020-07-30 15:58:38	2020-07-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	6381	delivery	5	22
106869	2020-07-30 16:02:30	2020-07-30	9	[{"id_menu":6,"count":1}]	31028	delivery	5	14
106870	2020-07-30 16:03:51	2020-07-30	14	[{"id_menu":2,"count":1}]	1344	delivery	5	19
106871	2020-07-30 16:05:38	2020-07-30	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41236	delivery	5	35
106872	2020-07-30 16:08:49	2020-07-30	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17352	pick-up	0	17
106873	2020-07-30 16:09:44	2020-07-30	12	[{"id_menu":3,"count":1}]	7338	delivery	5	17
106874	2020-07-30 16:09:52	2020-07-30	9	[{"id_menu":6,"count":1}]	7140	delivery	5	14
106875	2020-07-30 16:12:30	2020-07-30	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18283	delivery	5	36
106876	2020-07-30 16:12:55	2020-07-30	9	[{"id_menu":7,"count":2}]	41160	pick-up	0	9
106877	2020-07-30 16:17:59	2020-07-30	9	[{"id_menu":7,"count":1}]	16676	delivery	5	14
106878	2020-07-30 16:19:51	2020-07-30	12	[{"id_menu":3,"count":1}]	27231	delivery	5	17
106879	2020-07-30 16:20:00	2020-07-30	8	[{"id_menu":5,"count":1}]	15788	delivery	5	13
106880	2020-07-30 16:20:26	2020-07-30	8	[{"id_menu":5,"count":1}]	3077	pick-up	0	8
106881	2020-07-30 16:24:07	2020-07-30	14	[{"id_menu":2,"count":1}]	12546	delivery	5	19
106882	2020-07-30 16:27:03	2020-07-30	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37916	delivery	5	52
106883	2020-07-30 16:30:36	2020-07-30	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	41261	delivery	5	22
106884	2020-07-30 16:31:27	2020-07-30	9	[{"id_menu":6,"count":1}]	13552	delivery	5	14
106885	2020-07-30 16:36:06	2020-07-30	14	[{"id_menu":2,"count":1}]	37620	delivery	5	19
106886	2020-07-30 16:39:26	2020-07-30	17	[{"id_menu":4,"count":1}]	41021	delivery	5	22
106887	2020-07-30 16:39:26	2020-07-30	9	[{"id_menu":7,"count":1}]	36788	delivery	5	14
106888	2020-07-30 16:40:08	2020-07-30	9	[{"id_menu":7,"count":1}]	41185	pick-up	0	9
106889	2020-07-30 16:43:35	2020-07-30	14	[{"id_menu":2,"count":1}]	1791	delivery	5	19
106890	2020-07-30 16:44:54	2020-07-30	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	41250	delivery	5	28
106891	2020-07-30 16:46:25	2020-07-30	12	[{"id_menu":1,"count":1}]	41063	delivery	5	17
106892	2020-07-30 16:49:03	2020-07-30	26	[{"id_menu":4,"count":3},{"id_menu":7,"count":1}]	41053	delivery	5	31
106893	2020-07-30 16:52:43	2020-07-30	9	[{"id_menu":7,"count":1}]	41119	delivery	5	14
106894	2020-07-30 16:55:18	2020-07-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10123	delivery	5	23
106895	2020-07-30 16:59:50	2020-07-30	14	[{"id_menu":2,"count":1}]	6342	pick-up	0	14
106896	2020-07-30 17:02:30	2020-07-30	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	41096	delivery	5	36
106897	2020-07-30 17:04:01	2020-07-30	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	41242	delivery	5	40
106898	2020-07-30 17:05:40	2020-07-30	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	25227	delivery	5	26
106899	2020-07-30 17:05:41	2020-07-30	12	[{"id_menu":1,"count":1}]	41240	pick-up	0	12
106900	2020-07-30 17:06:07	2020-07-30	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	41026	delivery	5	31
106901	2020-07-30 17:07:10	2020-07-30	9	[{"id_menu":6,"count":2}]	19054	delivery	5	14
106902	2020-07-30 17:07:16	2020-07-30	8	[{"id_menu":5,"count":1}]	41017	delivery	5	13
106903	2020-07-30 17:07:49	2020-07-30	9	[{"id_menu":7,"count":1}]	41037	delivery	5	14
106904	2020-07-30 17:08:26	2020-07-30	9	[{"id_menu":6,"count":1}]	24089	delivery	5	14
106905	2020-07-30 17:09:30	2020-07-30	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	12132	delivery	5	34
106906	2020-07-30 17:10:48	2020-07-30	9	[{"id_menu":7,"count":1}]	36098	delivery	5	14
106907	2020-07-30 17:10:51	2020-07-30	12	[{"id_menu":1,"count":1}]	4290	delivery	5	17
106908	2020-07-30 17:15:17	2020-07-30	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	2631	pick-up	0	31
106909	2020-07-30 17:16:30	2020-07-30	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	2731	pick-up	0	24
106910	2020-07-30 17:17:44	2020-07-30	9	[{"id_menu":6,"count":1}]	30647	delivery	5	14
106911	2020-07-30 17:19:58	2020-07-30	30	[{"id_menu":1,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19467	delivery	5	35
106912	2020-07-30 17:20:09	2020-07-30	8	[{"id_menu":5,"count":1}]	37671	delivery	5	13
106913	2020-07-30 17:22:18	2020-07-30	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1660	delivery	5	34
106914	2020-07-30 17:23:39	2020-07-30	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32117	delivery	5	51
106915	2020-07-30 17:23:56	2020-07-30	8	[{"id_menu":5,"count":1}]	15417	delivery	5	13
106916	2020-07-30 17:33:38	2020-07-30	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	41203	delivery	5	34
106917	2020-07-30 17:34:32	2020-07-30	17	[{"id_menu":4,"count":1}]	38554	delivery	5	22
106918	2020-07-30 17:34:34	2020-07-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	17862	delivery	5	23
106919	2020-07-30 17:35:46	2020-07-30	14	[{"id_menu":2,"count":1}]	41231	delivery	5	19
106920	2020-07-30 17:36:45	2020-07-30	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13761	delivery	5	54
106921	2020-07-30 17:40:40	2020-07-30	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	8355	delivery	5	26
106922	2020-07-30 17:41:06	2020-07-30	12	[{"id_menu":1,"count":1}]	8852	delivery	5	17
106923	2020-07-30 17:42:25	2020-07-30	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	748	delivery	5	25
106924	2020-07-30 17:43:04	2020-07-30	8	[{"id_menu":5,"count":2}]	41134	delivery	5	13
106925	2020-07-30 17:45:29	2020-07-30	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	18740	delivery	5	40
106926	2020-07-30 17:46:44	2020-07-30	12	[{"id_menu":1,"count":1}]	41149	delivery	5	17
106927	2020-07-30 17:48:32	2020-07-30	17	[{"id_menu":4,"count":1}]	40839	delivery	5	22
106928	2020-07-30 17:50:13	2020-07-30	14	[{"id_menu":2,"count":1}]	4470	pick-up	0	14
106929	2020-07-30 17:51:19	2020-07-30	9	[{"id_menu":7,"count":2}]	32188	delivery	5	14
106930	2020-07-30 17:53:36	2020-07-30	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	41074	delivery	5	26
106931	2020-07-30 17:53:41	2020-07-30	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	2752	delivery	5	28
106932	2020-07-30 17:55:20	2020-07-30	9	[{"id_menu":6,"count":1}]	41259	pick-up	0	9
106933	2020-07-30 17:56:23	2020-07-30	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	40131	delivery	5	39
106934	2020-07-30 17:57:28	2020-07-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	16456	delivery	5	27
106935	2020-07-30 17:58:20	2020-07-30	9	[{"id_menu":7,"count":1}]	41130	delivery	5	14
106936	2020-07-30 18:01:50	2020-07-30	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":2}]	41197	delivery	5	34
106937	2020-07-30 18:05:49	2020-07-30	9	[{"id_menu":7,"count":1}]	26622	delivery	5	14
106938	2020-07-30 18:07:12	2020-07-30	12	[{"id_menu":3,"count":1}]	41071	pick-up	0	12
106939	2020-07-30 18:09:44	2020-07-30	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36334	delivery	5	31
106940	2020-07-30 18:13:03	2020-07-30	9	[{"id_menu":6,"count":1}]	25101	delivery	5	14
106941	2020-07-30 18:18:07	2020-07-30	14	[{"id_menu":2,"count":2}]	9046	delivery	5	19
106942	2020-07-30 18:23:05	2020-07-30	12	[{"id_menu":1,"count":1}]	41112	delivery	5	17
106943	2020-07-30 18:24:18	2020-07-30	14	[{"id_menu":2,"count":1}]	41092	delivery	5	19
106944	2020-07-30 18:24:56	2020-07-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	41150	delivery	5	26
106945	2020-07-30 18:25:22	2020-07-30	8	[{"id_menu":5,"count":1}]	21242	delivery	5	13
106946	2020-07-30 18:26:03	2020-07-30	14	[{"id_menu":2,"count":1}]	15508	delivery	5	19
106947	2020-07-30 18:28:58	2020-07-30	17	[{"id_menu":4,"count":1}]	33828	pick-up	0	17
106948	2020-07-30 18:30:59	2020-07-30	14	[{"id_menu":2,"count":1}]	11148	delivery	5	19
106949	2020-07-30 18:32:34	2020-07-30	9	[{"id_menu":6,"count":1}]	16737	pick-up	0	9
106950	2020-07-30 18:36:27	2020-07-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	16275	delivery	5	28
106951	2020-07-30 18:38:14	2020-07-30	9	[{"id_menu":6,"count":1}]	41088	delivery	5	14
106952	2020-07-30 18:38:41	2020-07-30	12	[{"id_menu":1,"count":1}]	41158	delivery	5	17
106953	2020-07-30 18:39:03	2020-07-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	29747	delivery	5	26
106954	2020-07-30 18:42:05	2020-07-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	41167	delivery	5	28
106955	2020-07-30 18:44:05	2020-07-30	9	[{"id_menu":6,"count":1}]	1244	pick-up	0	9
106956	2020-07-30 18:46:07	2020-07-30	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5156	delivery	5	45
106957	2020-07-30 18:47:03	2020-07-30	14	[{"id_menu":2,"count":1}]	41228	delivery	5	19
106958	2020-07-30 18:49:14	2020-07-30	8	[{"id_menu":5,"count":1}]	41135	delivery	5	13
106959	2020-07-30 18:55:48	2020-07-30	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	22471	delivery	5	26
106960	2020-07-30 18:56:51	2020-07-30	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	23806	delivery	5	31
106961	2020-07-30 18:58:26	2020-07-30	14	[{"id_menu":2,"count":1}]	4434	delivery	5	19
106962	2020-07-30 18:59:27	2020-07-30	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9152	delivery	5	39
106963	2020-07-30 19:00:11	2020-07-30	9	[{"id_menu":7,"count":1}]	32747	delivery	5	14
106964	2020-07-30 19:00:15	2020-07-30	12	[{"id_menu":3,"count":1}]	16790	pick-up	0	12
106965	2020-07-30 19:03:33	2020-07-30	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	764	delivery	5	40
106966	2020-07-30 19:06:42	2020-07-30	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	26135	delivery	5	22
106967	2020-07-30 19:08:13	2020-07-30	12	[{"id_menu":3,"count":1}]	29990	pick-up	0	12
106968	2020-07-30 19:08:36	2020-07-30	9	[{"id_menu":7,"count":1}]	41069	delivery	5	14
106969	2020-07-30 19:10:28	2020-07-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	23692	delivery	5	31
106970	2020-07-30 19:15:26	2020-07-30	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41127	delivery	5	35
106971	2020-07-30 19:18:03	2020-07-30	12	[{"id_menu":1,"count":1}]	40611	pick-up	0	12
106972	2020-07-30 19:20:20	2020-07-30	14	[{"id_menu":2,"count":1}]	34824	pick-up	0	14
106973	2020-07-30 19:20:21	2020-07-30	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	9717	delivery	5	36
106974	2020-07-30 19:21:24	2020-07-30	8	[{"id_menu":5,"count":1}]	38768	delivery	5	13
106975	2020-07-30 19:22:54	2020-07-30	9	[{"id_menu":7,"count":1}]	3478	delivery	5	14
106976	2020-07-30 19:35:11	2020-07-30	12	[{"id_menu":1,"count":1}]	13495	pick-up	0	12
106977	2020-07-30 19:36:58	2020-07-30	8	[{"id_menu":5,"count":1}]	38155	pick-up	0	8
106978	2020-07-30 19:38:22	2020-07-30	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1452	delivery	5	34
106979	2020-07-30 19:40:19	2020-07-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	29351	delivery	5	26
106980	2020-07-30 19:40:28	2020-07-30	12	[{"id_menu":1,"count":1}]	6428	pick-up	0	12
106981	2020-07-30 19:40:46	2020-07-30	14	[{"id_menu":2,"count":1}]	14314	pick-up	0	14
106982	2020-07-30 19:42:26	2020-07-30	12	[{"id_menu":1,"count":2}]	15590	pick-up	0	12
106983	2020-07-30 19:44:24	2020-07-30	8	[{"id_menu":5,"count":1}]	2386	delivery	5	13
106984	2020-07-30 19:46:57	2020-07-30	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	14435	delivery	5	30
106985	2020-07-30 19:47:12	2020-07-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41067	delivery	5	23
106986	2020-07-30 19:48:13	2020-07-30	9	[{"id_menu":6,"count":1}]	41201	delivery	5	14
106987	2020-07-30 19:52:31	2020-07-30	9	[{"id_menu":7,"count":1}]	21246	delivery	5	14
106988	2020-07-30 19:53:21	2020-07-30	14	[{"id_menu":2,"count":1}]	5125	delivery	5	19
106989	2020-07-30 19:55:54	2020-07-30	8	[{"id_menu":5,"count":1}]	18190	delivery	5	13
106990	2020-07-30 19:56:05	2020-07-30	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	41072	delivery	5	43
106991	2020-07-30 19:56:44	2020-07-30	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	23411	pick-up	0	26
106992	2020-07-30 19:57:56	2020-07-30	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	28932	delivery	5	38
106993	2020-07-30 19:59:42	2020-07-30	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6221	pick-up	0	38
106994	2020-07-30 20:00:09	2020-07-30	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	41015	delivery	5	22
106995	2020-07-30 20:00:39	2020-07-30	12	[{"id_menu":3,"count":1}]	19042	pick-up	0	12
106996	2020-07-30 20:05:46	2020-07-30	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17421	delivery	5	39
106997	2020-07-30 20:12:06	2020-07-30	14	[{"id_menu":2,"count":1}]	41146	pick-up	0	14
106998	2020-07-30 20:14:45	2020-07-30	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	4170	pick-up	0	26
106999	2020-07-30 20:15:59	2020-07-30	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41245	delivery	5	37
107000	2020-07-30 20:23:23	2020-07-30	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4186	delivery	5	54
107001	2020-07-30 20:27:13	2020-07-30	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	23268	delivery	5	30
107002	2020-07-30 20:33:02	2020-07-30	9	[{"id_menu":7,"count":2}]	29576	delivery	5	14
107003	2020-07-30 20:37:48	2020-07-30	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	41068	delivery	5	57
107004	2020-07-30 20:38:36	2020-07-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	41093	delivery	5	28
107005	2020-07-30 20:39:23	2020-07-30	17	[{"id_menu":4,"count":1}]	41207	delivery	5	22
107006	2020-07-30 20:43:03	2020-07-30	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	16440	delivery	5	35
107007	2020-07-30 20:44:07	2020-07-30	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	31059	delivery	5	36
107008	2020-07-30 20:44:37	2020-07-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":3}]	7156	pick-up	0	26
107009	2020-07-30 20:45:42	2020-07-30	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	41082	delivery	5	23
107010	2020-07-30 20:46:57	2020-07-30	9	[{"id_menu":6,"count":1}]	41039	delivery	5	14
107011	2020-07-30 20:50:07	2020-07-30	9	[{"id_menu":7,"count":1}]	17828	delivery	5	14
107012	2020-07-30 20:50:25	2020-07-30	9	[{"id_menu":7,"count":2}]	39911	delivery	5	14
107013	2020-07-30 21:02:51	2020-07-30	17	[{"id_menu":4,"count":1}]	5207	delivery	5	22
107014	2020-07-30 21:03:07	2020-07-30	14	[{"id_menu":2,"count":1}]	41086	delivery	5	19
107015	2020-07-30 21:04:26	2020-07-30	14	[{"id_menu":2,"count":1}]	18567	delivery	5	19
107016	2020-07-30 21:07:46	2020-07-30	17	[{"id_menu":4,"count":1}]	26978	delivery	5	22
107017	2020-07-30 21:08:01	2020-07-30	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	40142	delivery	5	43
107018	2020-07-30 21:08:15	2020-07-30	17	[{"id_menu":4,"count":1}]	2085	pick-up	0	17
107019	2020-07-30 21:08:23	2020-07-30	9	[{"id_menu":6,"count":1}]	41230	delivery	5	14
107020	2020-07-30 21:11:37	2020-07-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	38707	delivery	5	31
107021	2020-07-30 21:13:50	2020-07-30	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	41151	delivery	5	30
107022	2020-07-30 21:15:22	2020-07-30	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21829	delivery	5	22
107023	2020-07-30 21:15:55	2020-07-30	12	[{"id_menu":1,"count":1}]	23930	pick-up	0	12
107024	2020-07-30 21:17:35	2020-07-30	12	[{"id_menu":1,"count":1}]	15477	delivery	5	17
107025	2020-07-30 21:18:47	2020-07-30	9	[{"id_menu":6,"count":1}]	29755	delivery	5	14
107026	2020-07-30 21:25:23	2020-07-30	17	[{"id_menu":4,"count":1}]	29341	delivery	5	22
107027	2020-07-30 21:28:26	2020-07-30	8	[{"id_menu":5,"count":1}]	41022	delivery	5	13
107028	2020-07-30 21:31:20	2020-07-30	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	11124	pick-up	0	20
107029	2020-07-30 21:32:54	2020-07-30	8	[{"id_menu":5,"count":1}]	29842	pick-up	0	8
107030	2020-07-30 21:33:04	2020-07-30	17	[{"id_menu":4,"count":1}]	41172	delivery	5	22
107031	2020-07-30 21:33:26	2020-07-30	14	[{"id_menu":2,"count":1}]	31261	pick-up	0	14
107032	2020-07-30 21:37:49	2020-07-30	14	[{"id_menu":2,"count":1}]	16483	pick-up	0	14
107033	2020-07-30 21:39:54	2020-07-30	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	41195	delivery	5	37
107034	2020-07-30 21:40:34	2020-07-30	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	35064	delivery	5	29
107035	2020-07-30 21:41:00	2020-07-30	12	[{"id_menu":1,"count":1}]	14539	delivery	5	17
107036	2020-07-30 21:41:23	2020-07-30	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":2}]	32887	delivery	5	31
107037	2020-07-30 21:46:55	2020-07-30	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19248	delivery	5	35
107038	2020-07-30 21:47:16	2020-07-30	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	41089	delivery	5	36
107039	2020-07-30 21:47:55	2020-07-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	41138	delivery	5	28
107040	2020-07-30 21:50:46	2020-07-30	14	[{"id_menu":2,"count":1}]	30751	pick-up	0	14
107041	2020-07-30 21:52:46	2020-07-30	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	41234	delivery	5	46
107042	2020-07-30 21:53:23	2020-07-30	17	[{"id_menu":4,"count":2}]	26565	pick-up	0	17
107043	2020-07-30 21:57:43	2020-07-30	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	352	pick-up	0	21
107044	2020-07-30 21:58:34	2020-07-30	14	[{"id_menu":2,"count":1}]	28081	delivery	5	19
107045	2020-07-30 22:01:36	2020-07-30	8	[{"id_menu":5,"count":1}]	14559	delivery	5	13
107046	2020-07-30 22:02:07	2020-07-30	8	[{"id_menu":5,"count":1}]	41194	pick-up	0	8
107047	2020-07-30 22:03:21	2020-07-30	8	[{"id_menu":5,"count":1}]	21175	delivery	5	13
107048	2020-07-30 22:04:38	2020-07-30	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	31055	delivery	5	34
107049	2020-07-30 22:07:54	2020-07-30	9	[{"id_menu":6,"count":1}]	41268	delivery	5	14
107050	2020-07-30 22:12:57	2020-07-30	17	[{"id_menu":4,"count":1}]	41097	delivery	5	22
107051	2020-07-30 22:14:57	2020-07-30	9	[{"id_menu":7,"count":1}]	11581	delivery	5	14
107052	2020-07-30 22:15:39	2020-07-30	8	[{"id_menu":5,"count":1}]	41065	delivery	5	13
107053	2020-07-30 22:18:11	2020-07-30	9	[{"id_menu":7,"count":1}]	41126	delivery	5	14
107054	2020-07-30 22:19:24	2020-07-30	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	38368	delivery	5	45
107055	2020-07-30 22:19:55	2020-07-30	14	[{"id_menu":2,"count":1}]	37994	delivery	5	19
107056	2020-07-30 22:20:48	2020-07-30	9	[{"id_menu":6,"count":1}]	27785	delivery	5	14
107057	2020-07-30 22:23:43	2020-07-30	9	[{"id_menu":6,"count":1}]	41215	delivery	5	14
107058	2020-07-30 22:27:08	2020-07-30	12	[{"id_menu":3,"count":1}]	14451	delivery	5	17
107059	2020-07-30 22:27:14	2020-07-30	12	[{"id_menu":3,"count":1}]	20964	pick-up	0	12
107060	2020-07-30 22:27:58	2020-07-30	14	[{"id_menu":2,"count":1}]	40572	delivery	5	19
107061	2020-07-30 22:28:34	2020-07-30	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35357	delivery	5	49
107062	2020-07-30 22:31:03	2020-07-30	9	[{"id_menu":7,"count":1}]	31810	delivery	5	14
107063	2020-07-30 22:33:53	2020-07-30	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18870	delivery	5	31
107064	2020-07-30 22:34:15	2020-07-30	8	[{"id_menu":5,"count":1}]	41085	delivery	5	13
107065	2020-07-30 22:38:38	2020-07-30	9	[{"id_menu":7,"count":1}]	6533	delivery	5	14
107066	2020-07-30 22:38:39	2020-07-30	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12894	delivery	5	34
107067	2020-07-30 22:39:12	2020-07-30	14	[{"id_menu":2,"count":1}]	3441	pick-up	0	14
107068	2020-07-30 22:39:14	2020-07-30	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	41235	delivery	5	31
107069	2020-07-30 22:39:19	2020-07-30	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	41189	delivery	5	23
107070	2020-07-30 22:42:34	2020-07-30	12	[{"id_menu":1,"count":1}]	5579	delivery	5	17
107071	2020-07-30 22:42:55	2020-07-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	33521	delivery	5	27
107072	2020-07-30 22:43:35	2020-07-30	9	[{"id_menu":7,"count":1}]	14382	delivery	5	14
107073	2020-07-30 22:43:52	2020-07-30	12	[{"id_menu":1,"count":1}]	30330	delivery	5	17
107074	2020-07-30 22:45:06	2020-07-30	14	[{"id_menu":2,"count":1}]	6152	delivery	5	19
107075	2020-07-30 22:49:06	2020-07-30	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37228	delivery	5	43
107076	2020-07-30 22:50:40	2020-07-30	12	[{"id_menu":3,"count":1}]	41225	pick-up	0	12
107077	2020-07-30 22:52:39	2020-07-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	41266	delivery	5	27
107078	2020-07-30 22:53:18	2020-07-30	17	[{"id_menu":4,"count":1}]	36244	pick-up	0	17
107079	2020-07-30 22:54:40	2020-07-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1293	delivery	5	23
107080	2020-07-30 22:55:39	2020-07-30	9	[{"id_menu":7,"count":1}]	41031	delivery	5	14
107081	2020-07-30 22:57:08	2020-07-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	41132	delivery	5	28
107082	2020-07-30 23:00:52	2020-07-30	14	[{"id_menu":2,"count":2}]	37933	delivery	5	19
107083	2020-07-30 23:02:36	2020-07-30	9	[{"id_menu":6,"count":1}]	11187	delivery	5	14
107084	2020-07-30 23:11:55	2020-07-30	12	[{"id_menu":3,"count":1}]	2200	pick-up	0	12
107085	2020-07-30 23:14:45	2020-07-30	9	[{"id_menu":7,"count":1}]	29450	pick-up	0	9
107086	2020-07-30 23:15:43	2020-07-30	9	[{"id_menu":6,"count":1}]	18241	delivery	5	14
107087	2020-07-30 23:18:18	2020-07-30	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	20573	delivery	5	39
107088	2020-07-30 23:19:49	2020-07-30	9	[{"id_menu":6,"count":1}]	8451	delivery	5	14
107089	2020-07-30 23:26:59	2020-07-30	9	[{"id_menu":7,"count":1}]	16584	delivery	5	14
107090	2020-07-30 23:35:21	2020-07-30	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	21731	delivery	5	22
107091	2020-07-30 23:41:20	2020-07-30	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	30763	delivery	5	22
107092	2020-07-30 23:43:17	2020-07-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	41178	delivery	5	28
107093	2020-07-30 23:44:50	2020-07-30	9	[{"id_menu":7,"count":1}]	34538	delivery	5	14
107094	2020-07-30 23:47:27	2020-07-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41028	delivery	5	23
107095	2020-07-30 23:49:30	2020-07-30	17	[{"id_menu":4,"count":1}]	41027	delivery	5	22
107096	2020-07-30 23:50:08	2020-07-30	14	[{"id_menu":2,"count":1}]	41244	delivery	5	19
107097	2020-07-30 23:50:24	2020-07-30	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41219	delivery	5	31
107098	2020-07-30 23:50:48	2020-07-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	41048	delivery	5	26
107099	2020-07-31 00:00:24	2020-07-31	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	30015	delivery	5	31
107100	2020-07-31 00:14:19	2020-07-31	9	[{"id_menu":6,"count":1}]	37907	delivery	5	14
107101	2020-07-31 00:14:20	2020-07-31	9	[{"id_menu":7,"count":1}]	35138	pick-up	0	9
107102	2020-07-31 00:15:32	2020-07-31	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	41446	delivery	5	31
107103	2020-07-31 00:18:34	2020-07-31	12	[{"id_menu":1,"count":1}]	41348	delivery	5	17
107104	2020-07-31 00:19:16	2020-07-31	9	[{"id_menu":6,"count":1}]	41317	delivery	5	14
107105	2020-07-31 00:19:45	2020-07-31	9	[{"id_menu":7,"count":1}]	2401	pick-up	0	9
107106	2020-07-31 00:20:47	2020-07-31	8	[{"id_menu":5,"count":1}]	41172	delivery	5	13
107107	2020-07-31 00:24:05	2020-07-31	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28499	delivery	5	22
107108	2020-07-31 00:29:59	2020-07-31	14	[{"id_menu":2,"count":1}]	31858	delivery	5	19
107109	2020-07-31 00:30:20	2020-07-31	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28844	pick-up	0	18
107110	2020-07-31 00:33:05	2020-07-31	9	[{"id_menu":7,"count":1}]	41325	delivery	5	14
107111	2020-07-31 00:39:48	2020-07-31	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	7437	delivery	5	26
107112	2020-07-31 00:40:46	2020-07-31	12	[{"id_menu":1,"count":1}]	41412	delivery	5	17
107113	2020-07-31 00:42:20	2020-07-31	12	[{"id_menu":1,"count":1}]	41361	delivery	5	17
107114	2020-07-31 00:43:44	2020-07-31	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13715	delivery	5	22
107115	2020-07-31 00:43:52	2020-07-31	8	[{"id_menu":5,"count":1}]	41279	delivery	5	13
107116	2020-07-31 00:45:31	2020-07-31	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	41498	delivery	5	31
107117	2020-07-31 00:47:31	2020-07-31	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	41470	delivery	5	42
107118	2020-07-31 00:51:17	2020-07-31	9	[{"id_menu":7,"count":1}]	8760	delivery	5	14
107119	2020-07-31 00:53:48	2020-07-31	9	[{"id_menu":7,"count":1}]	8929	delivery	5	14
107120	2020-07-31 00:54:57	2020-07-31	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	35231	delivery	5	23
107121	2020-07-31 00:59:09	2020-07-31	17	[{"id_menu":4,"count":1}]	14086	pick-up	0	17
107122	2020-07-31 01:02:42	2020-07-31	12	[{"id_menu":3,"count":1}]	10525	pick-up	0	12
107123	2020-07-31 01:04:13	2020-07-31	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	41489	pick-up	0	26
107124	2020-07-31 01:08:10	2020-07-31	8	[{"id_menu":5,"count":1}]	41392	delivery	5	13
107125	2020-07-31 01:10:26	2020-07-31	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	24541	delivery	5	57
107126	2020-07-31 01:11:08	2020-07-31	9	[{"id_menu":6,"count":1}]	36974	delivery	5	14
107127	2020-07-31 01:11:17	2020-07-31	8	[{"id_menu":5,"count":1}]	36323	delivery	5	13
107128	2020-07-31 01:11:33	2020-07-31	9	[{"id_menu":6,"count":1}]	16422	pick-up	0	9
107129	2020-07-31 01:11:34	2020-07-31	12	[{"id_menu":3,"count":1}]	22211	delivery	5	17
107130	2020-07-31 01:11:36	2020-07-31	9	[{"id_menu":6,"count":1}]	41455	delivery	5	14
107131	2020-07-31 01:12:21	2020-07-31	9	[{"id_menu":7,"count":1}]	3440	pick-up	0	9
107132	2020-07-31 01:12:43	2020-07-31	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	27208	delivery	5	30
107133	2020-07-31 01:12:46	2020-07-31	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	41282	delivery	5	34
107134	2020-07-31 01:16:24	2020-07-31	12	[{"id_menu":1,"count":1}]	6769	pick-up	0	12
107135	2020-07-31 01:16:40	2020-07-31	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	41269	delivery	5	40
107136	2020-07-31 01:16:52	2020-07-31	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	41376	delivery	5	34
107137	2020-07-31 01:17:43	2020-07-31	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	24184	delivery	5	22
107138	2020-07-31 01:18:06	2020-07-31	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	21959	delivery	5	31
107139	2020-07-31 01:18:52	2020-07-31	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	25649	delivery	5	26
107140	2020-07-31 01:22:46	2020-07-31	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	41389	delivery	5	26
107141	2020-07-31 01:23:49	2020-07-31	17	[{"id_menu":4,"count":1}]	41357	pick-up	0	17
107142	2020-07-31 01:23:49	2020-07-31	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17894	delivery	5	31
107143	2020-07-31 01:24:24	2020-07-31	9	[{"id_menu":6,"count":1}]	9621	delivery	5	14
107144	2020-07-31 01:26:33	2020-07-31	9	[{"id_menu":6,"count":1}]	10036	delivery	5	14
107145	2020-07-31 01:32:45	2020-07-31	14	[{"id_menu":2,"count":1}]	31082	delivery	5	19
107146	2020-07-31 01:36:22	2020-07-31	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	41429	delivery	5	25
107147	2020-07-31 01:36:59	2020-07-31	9	[{"id_menu":7,"count":1}]	35645	delivery	5	14
107148	2020-07-31 01:37:15	2020-07-31	9	[{"id_menu":6,"count":1}]	16245	pick-up	0	9
107149	2020-07-31 01:38:27	2020-07-31	14	[{"id_menu":2,"count":1}]	27	delivery	5	19
107150	2020-07-31 01:40:09	2020-07-31	9	[{"id_menu":6,"count":1}]	8754	delivery	5	14
107151	2020-07-31 01:42:41	2020-07-31	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	23298	delivery	5	38
107152	2020-07-31 01:43:19	2020-07-31	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	28491	delivery	5	26
107153	2020-07-31 01:44:08	2020-07-31	12	[{"id_menu":3,"count":1}]	17389	delivery	5	17
107154	2020-07-31 01:46:04	2020-07-31	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13982	delivery	5	22
107155	2020-07-31 01:46:20	2020-07-31	8	[{"id_menu":5,"count":1}]	22245	delivery	5	13
107156	2020-07-31 01:48:02	2020-07-31	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	8092	delivery	5	38
107157	2020-07-31 01:49:46	2020-07-31	9	[{"id_menu":7,"count":1}]	33228	delivery	5	14
107158	2020-07-31 01:53:07	2020-07-31	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	41451	delivery	5	31
107159	2020-07-31 01:57:11	2020-07-31	17	[{"id_menu":4,"count":1}]	41308	delivery	5	22
107160	2020-07-31 01:57:46	2020-07-31	8	[{"id_menu":5,"count":1}]	41301	delivery	5	13
107161	2020-07-31 01:58:17	2020-07-31	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41287	delivery	5	45
107162	2020-07-31 02:01:50	2020-07-31	9	[{"id_menu":7,"count":1}]	28255	delivery	5	14
107163	2020-07-31 02:04:10	2020-07-31	8	[{"id_menu":5,"count":1}]	13291	delivery	5	13
107164	2020-07-31 02:06:14	2020-07-31	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	41467	delivery	5	43
107165	2020-07-31 02:06:42	2020-07-31	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	36710	delivery	5	43
107166	2020-07-31 02:09:54	2020-07-31	12	[{"id_menu":3,"count":1}]	33798	pick-up	0	12
107167	2020-07-31 02:16:12	2020-07-31	14	[{"id_menu":2,"count":1}]	41472	delivery	5	19
107168	2020-07-31 02:16:40	2020-07-31	14	[{"id_menu":2,"count":1}]	41466	pick-up	0	14
107169	2020-07-31 02:17:12	2020-07-31	9	[{"id_menu":6,"count":1}]	20120	delivery	5	14
107170	2020-07-31 02:17:42	2020-07-31	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24877	delivery	5	22
107171	2020-07-31 02:18:40	2020-07-31	17	[{"id_menu":4,"count":1}]	1457	delivery	5	22
107172	2020-07-31 02:20:32	2020-07-31	9	[{"id_menu":6,"count":1}]	41291	delivery	5	14
107173	2020-07-31 02:21:17	2020-07-31	9	[{"id_menu":7,"count":1}]	27497	delivery	5	14
107174	2020-07-31 02:22:54	2020-07-31	12	[{"id_menu":3,"count":1}]	41506	delivery	5	17
107175	2020-07-31 02:28:11	2020-07-31	12	[{"id_menu":3,"count":1}]	10194	pick-up	0	12
107176	2020-07-31 02:29:03	2020-07-31	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	19970	delivery	5	25
107177	2020-07-31 02:30:03	2020-07-31	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	35885	delivery	5	26
107178	2020-07-31 02:32:45	2020-07-31	12	[{"id_menu":1,"count":1}]	3912	delivery	5	17
107179	2020-07-31 02:32:59	2020-07-31	12	[{"id_menu":3,"count":1}]	31074	delivery	5	17
107180	2020-07-31 02:33:55	2020-07-31	12	[{"id_menu":1,"count":1}]	1444	delivery	5	17
107181	2020-07-31 02:37:34	2020-07-31	12	[{"id_menu":3,"count":1}]	34133	pick-up	0	12
107182	2020-07-31 02:41:07	2020-07-31	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	31943	delivery	5	38
107183	2020-07-31 02:42:05	2020-07-31	9	[{"id_menu":7,"count":1}]	41296	pick-up	0	9
107184	2020-07-31 02:42:57	2020-07-31	17	[{"id_menu":4,"count":1}]	9348	pick-up	0	17
107185	2020-07-31 02:48:07	2020-07-31	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	21901	pick-up	0	23
107186	2020-07-31 02:49:27	2020-07-31	9	[{"id_menu":7,"count":1}]	40075	delivery	5	14
107187	2020-07-31 02:49:40	2020-07-31	12	[{"id_menu":1,"count":1}]	2385	pick-up	0	12
107188	2020-07-31 02:54:38	2020-07-31	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	30607	pick-up	0	26
107189	2020-07-31 02:55:10	2020-07-31	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	41403	delivery	5	23
107190	2020-07-31 02:55:20	2020-07-31	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	10336	delivery	5	37
107191	2020-07-31 02:58:54	2020-07-31	17	[{"id_menu":4,"count":1}]	41473	delivery	5	22
107192	2020-07-31 03:01:49	2020-07-31	9	[{"id_menu":6,"count":1}]	13911	delivery	5	14
107193	2020-07-31 03:06:12	2020-07-31	8	[{"id_menu":5,"count":1}]	15904	delivery	5	13
107194	2020-07-31 03:06:24	2020-07-31	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	41453	delivery	5	34
107195	2020-07-31 03:07:04	2020-07-31	9	[{"id_menu":6,"count":2}]	36864	delivery	5	14
107196	2020-07-31 03:10:48	2020-07-31	14	[{"id_menu":2,"count":1}]	39021	delivery	5	19
107197	2020-07-31 03:11:03	2020-07-31	12	[{"id_menu":1,"count":1}]	15743	delivery	5	17
107198	2020-07-31 03:11:08	2020-07-31	9	[{"id_menu":6,"count":1}]	12541	delivery	5	14
107199	2020-07-31 03:12:13	2020-07-31	12	[{"id_menu":1,"count":1}]	8679	pick-up	0	12
107200	2020-07-31 03:13:00	2020-07-31	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	41295	delivery	5	34
107201	2020-07-31 03:13:54	2020-07-31	8	[{"id_menu":5,"count":1}]	5822	delivery	5	13
107202	2020-07-31 03:14:22	2020-07-31	14	[{"id_menu":2,"count":2}]	1902	pick-up	0	14
107203	2020-07-31 03:15:38	2020-07-31	14	[{"id_menu":2,"count":1}]	41409	delivery	5	19
107204	2020-07-31 03:16:02	2020-07-31	9	[{"id_menu":6,"count":2}]	41415	delivery	5	14
107205	2020-07-31 03:19:04	2020-07-31	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	41359	delivery	5	27
107206	2020-07-31 03:21:56	2020-07-31	8	[{"id_menu":5,"count":1}]	9617	delivery	5	13
107207	2020-07-31 03:24:49	2020-07-31	29	[{"id_menu":3,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28488	delivery	5	34
107208	2020-07-31 03:35:05	2020-07-31	9	[{"id_menu":6,"count":1}]	41377	delivery	5	14
107209	2020-07-31 03:36:25	2020-07-31	9	[{"id_menu":6,"count":1}]	34868	delivery	5	14
107210	2020-07-31 03:46:00	2020-07-31	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10689	delivery	5	31
107211	2020-07-31 03:47:10	2020-07-31	9	[{"id_menu":6,"count":1}]	14591	delivery	5	14
107212	2020-07-31 03:47:53	2020-07-31	17	[{"id_menu":4,"count":1}]	7834	pick-up	0	17
107213	2020-07-31 03:49:43	2020-07-31	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	33203	delivery	5	28
107214	2020-07-31 03:53:52	2020-07-31	12	[{"id_menu":3,"count":1}]	29254	delivery	5	17
107215	2020-07-31 03:58:49	2020-07-31	9	[{"id_menu":7,"count":1}]	36919	delivery	5	14
107216	2020-07-31 03:59:13	2020-07-31	17	[{"id_menu":4,"count":1}]	41404	delivery	5	22
107217	2020-07-31 03:59:52	2020-07-31	14	[{"id_menu":2,"count":1}]	14969	delivery	5	19
107218	2020-07-31 04:01:57	2020-07-31	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	41399	delivery	5	34
107219	2020-07-31 04:02:57	2020-07-31	9	[{"id_menu":6,"count":1}]	41394	delivery	5	14
107220	2020-07-31 04:05:28	2020-07-31	9	[{"id_menu":7,"count":2}]	32003	delivery	5	14
107221	2020-07-31 04:05:36	2020-07-31	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	41485	delivery	5	31
107222	2020-07-31 04:12:59	2020-07-31	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	4983	delivery	5	23
107223	2020-07-31 04:13:52	2020-07-31	12	[{"id_menu":3,"count":1}]	41310	delivery	5	17
107224	2020-07-31 04:24:07	2020-07-31	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	17797	delivery	5	30
107225	2020-07-31 04:25:57	2020-07-31	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	27021	pick-up	0	25
107226	2020-07-31 04:27:10	2020-07-31	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	748	delivery	5	34
107227	2020-07-31 04:29:52	2020-07-31	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2166	delivery	5	26
107228	2020-07-31 04:30:02	2020-07-31	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	41283	delivery	5	26
107229	2020-07-31 04:30:19	2020-07-31	12	[{"id_menu":3,"count":1}]	27018	delivery	5	17
107230	2020-07-31 04:33:40	2020-07-31	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8770	delivery	5	43
107231	2020-07-31 04:34:27	2020-07-31	9	[{"id_menu":7,"count":1}]	4656	pick-up	0	9
107232	2020-07-31 04:39:39	2020-07-31	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	33775	delivery	5	45
107233	2020-07-31 04:40:59	2020-07-31	12	[{"id_menu":1,"count":1}]	25053	pick-up	0	12
107234	2020-07-31 04:43:23	2020-07-31	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	41503	delivery	5	34
107235	2020-07-31 04:45:54	2020-07-31	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":2}]	41334	delivery	5	22
107236	2020-07-31 04:49:39	2020-07-31	12	[{"id_menu":3,"count":1}]	33746	delivery	5	17
107237	2020-07-31 04:51:39	2020-07-31	9	[{"id_menu":7,"count":1}]	25658	delivery	5	14
107238	2020-07-31 04:53:35	2020-07-31	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	18085	delivery	5	34
107239	2020-07-31 04:53:52	2020-07-31	12	[{"id_menu":3,"count":1}]	8150	pick-up	0	12
107240	2020-07-31 04:54:10	2020-07-31	9	[{"id_menu":6,"count":1}]	2000	pick-up	0	9
107241	2020-07-31 04:55:26	2020-07-31	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19199	delivery	5	22
107242	2020-07-31 05:00:51	2020-07-31	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	41501	delivery	5	22
107243	2020-07-31 05:00:53	2020-07-31	8	[{"id_menu":5,"count":1}]	38815	pick-up	0	8
107244	2020-07-31 05:01:06	2020-07-31	9	[{"id_menu":6,"count":1}]	10442	delivery	5	14
107245	2020-07-31 05:03:03	2020-07-31	9	[{"id_menu":6,"count":1}]	41444	delivery	5	14
107246	2020-07-31 05:06:34	2020-07-31	9	[{"id_menu":6,"count":1}]	36049	delivery	5	14
107247	2020-07-31 05:07:14	2020-07-31	9	[{"id_menu":6,"count":1}]	12197	delivery	5	14
107248	2020-07-31 05:09:31	2020-07-31	8	[{"id_menu":5,"count":1}]	14438	delivery	5	13
107249	2020-07-31 05:09:39	2020-07-31	8	[{"id_menu":5,"count":1}]	35005	delivery	5	13
107250	2020-07-31 05:11:25	2020-07-31	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41378	delivery	5	43
107251	2020-07-31 05:19:57	2020-07-31	9	[{"id_menu":6,"count":1}]	35107	delivery	5	14
107252	2020-07-31 05:24:16	2020-07-31	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11006	delivery	5	45
107253	2020-07-31 05:26:27	2020-07-31	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	39006	delivery	5	30
107254	2020-07-31 05:26:40	2020-07-31	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23810	delivery	5	34
107255	2020-07-31 05:28:39	2020-07-31	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	27291	delivery	5	57
107256	2020-07-31 05:34:04	2020-07-31	14	[{"id_menu":2,"count":1}]	5149	pick-up	0	14
107257	2020-07-31 05:36:21	2020-07-31	12	[{"id_menu":3,"count":1}]	32648	delivery	5	17
107258	2020-07-31 05:43:10	2020-07-31	9	[{"id_menu":6,"count":1}]	2687	delivery	5	14
107259	2020-07-31 05:46:16	2020-07-31	14	[{"id_menu":2,"count":1}]	2736	delivery	5	19
107260	2020-07-31 05:46:38	2020-07-31	8	[{"id_menu":5,"count":1}]	1123	pick-up	0	8
107261	2020-07-31 05:46:56	2020-07-31	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3431	delivery	5	31
107262	2020-07-31 05:47:07	2020-07-31	12	[{"id_menu":3,"count":1}]	32693	delivery	5	17
107263	2020-07-31 05:48:02	2020-07-31	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	41408	delivery	5	40
107264	2020-07-31 05:49:02	2020-07-31	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	11992	pick-up	0	22
107265	2020-07-31 05:49:46	2020-07-31	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38871	delivery	5	35
107266	2020-07-31 05:52:52	2020-07-31	14	[{"id_menu":2,"count":1}]	10772	delivery	5	19
107267	2020-07-31 05:59:25	2020-07-31	14	[{"id_menu":2,"count":1}]	7611	delivery	5	19
107268	2020-07-31 05:59:37	2020-07-31	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21937	delivery	5	53
107269	2020-07-31 06:02:48	2020-07-31	8	[{"id_menu":5,"count":1}]	11200	delivery	5	13
107270	2020-07-31 06:05:40	2020-07-31	12	[{"id_menu":1,"count":1}]	4486	pick-up	0	12
107271	2020-07-31 06:07:22	2020-07-31	8	[{"id_menu":5,"count":1}]	41420	delivery	5	13
107272	2020-07-31 06:10:15	2020-07-31	12	[{"id_menu":3,"count":1}]	11198	pick-up	0	12
107273	2020-07-31 06:11:23	2020-07-31	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":3}]	41411	delivery	5	26
107274	2020-07-31 06:16:32	2020-07-31	14	[{"id_menu":2,"count":1}]	7835	pick-up	0	14
107275	2020-07-31 06:22:33	2020-07-31	8	[{"id_menu":5,"count":1}]	17085	delivery	5	13
107276	2020-07-31 06:28:40	2020-07-31	9	[{"id_menu":6,"count":1}]	41285	delivery	5	14
107277	2020-07-31 06:29:58	2020-07-31	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24935	pick-up	0	31
107278	2020-07-31 06:35:23	2020-07-31	12	[{"id_menu":1,"count":1}]	4081	pick-up	0	12
107279	2020-07-31 06:38:54	2020-07-31	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	41342	delivery	5	22
107280	2020-07-31 06:39:02	2020-07-31	12	[{"id_menu":1,"count":1}]	5762	delivery	5	17
107281	2020-07-31 06:39:38	2020-07-31	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	29929	delivery	5	36
107282	2020-07-31 06:40:41	2020-07-31	14	[{"id_menu":2,"count":1}]	17999	delivery	5	19
107283	2020-07-31 06:42:05	2020-07-31	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	24987	delivery	5	40
107284	2020-07-31 06:42:21	2020-07-31	12	[{"id_menu":3,"count":1}]	41309	delivery	5	17
107285	2020-07-31 06:42:45	2020-07-31	9	[{"id_menu":6,"count":1}]	19706	delivery	5	14
107286	2020-07-31 06:43:56	2020-07-31	9	[{"id_menu":6,"count":1}]	37732	delivery	5	14
107287	2020-07-31 06:48:04	2020-07-31	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3942	delivery	5	36
107288	2020-07-31 06:49:47	2020-07-31	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6442	delivery	5	28
107289	2020-07-31 06:50:47	2020-07-31	8	[{"id_menu":5,"count":1}]	10254	delivery	5	13
107290	2020-07-31 06:51:16	2020-07-31	9	[{"id_menu":6,"count":1}]	10976	delivery	5	14
107291	2020-07-31 06:54:36	2020-07-31	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	41365	delivery	5	45
107292	2020-07-31 06:58:11	2020-07-31	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	39556	delivery	5	26
107293	2020-07-31 06:58:20	2020-07-31	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	14759	delivery	5	34
107294	2020-07-31 06:58:46	2020-07-31	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	41277	delivery	5	48
107295	2020-07-31 07:03:54	2020-07-31	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	41356	delivery	5	40
107296	2020-07-31 07:04:32	2020-07-31	12	[{"id_menu":1,"count":1}]	41417	delivery	5	17
107297	2020-07-31 07:06:32	2020-07-31	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	37142	pick-up	0	23
107298	2020-07-31 07:18:59	2020-07-31	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	41419	pick-up	0	29
107299	2020-07-31 07:19:10	2020-07-31	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	27306	delivery	5	48
107300	2020-07-31 07:27:11	2020-07-31	14	[{"id_menu":2,"count":1}]	3788	pick-up	0	14
107301	2020-07-31 07:27:41	2020-07-31	8	[{"id_menu":5,"count":1}]	41319	delivery	5	13
107302	2020-07-31 07:28:05	2020-07-31	9	[{"id_menu":6,"count":1}]	16952	delivery	5	14
107303	2020-07-31 07:34:27	2020-07-31	12	[{"id_menu":1,"count":1}]	804	delivery	5	17
107304	2020-07-31 07:34:53	2020-07-31	12	[{"id_menu":3,"count":1}]	13298	pick-up	0	12
107305	2020-07-31 07:35:58	2020-07-31	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41430	delivery	5	23
107306	2020-07-31 07:39:24	2020-07-31	14	[{"id_menu":2,"count":1}]	5338	pick-up	0	14
107307	2020-07-31 07:40:48	2020-07-31	12	[{"id_menu":1,"count":1}]	41385	delivery	5	17
107308	2020-07-31 07:46:53	2020-07-31	9	[{"id_menu":7,"count":1}]	18883	delivery	5	14
107309	2020-07-31 07:49:29	2020-07-31	17	[{"id_menu":4,"count":1}]	41322	delivery	5	22
107310	2020-07-31 07:51:37	2020-07-31	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6751	delivery	5	36
107311	2020-07-31 08:00:01	2020-07-31	14	[{"id_menu":2,"count":2}]	2681	delivery	5	19
107312	2020-07-31 08:02:23	2020-07-31	12	[{"id_menu":3,"count":1}]	12057	delivery	5	17
107313	2020-07-31 08:03:58	2020-07-31	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23714	delivery	5	53
107314	2020-07-31 08:09:14	2020-07-31	9	[{"id_menu":7,"count":1}]	29777	delivery	5	14
107315	2020-07-31 08:11:47	2020-07-31	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	13045	delivery	5	37
107316	2020-07-31 08:12:25	2020-07-31	9	[{"id_menu":6,"count":1}]	11904	pick-up	0	9
107317	2020-07-31 08:13:02	2020-07-31	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	41381	delivery	5	28
107318	2020-07-31 08:15:38	2020-07-31	9	[{"id_menu":7,"count":1}]	36721	pick-up	0	9
107319	2020-07-31 08:15:59	2020-07-31	9	[{"id_menu":6,"count":1}]	18684	delivery	5	14
107320	2020-07-31 08:17:44	2020-07-31	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	41452	delivery	5	39
107321	2020-07-31 08:18:55	2020-07-31	14	[{"id_menu":2,"count":1}]	41402	pick-up	0	14
107322	2020-07-31 08:21:13	2020-07-31	14	[{"id_menu":2,"count":1}]	15434	pick-up	0	14
107323	2020-07-31 08:21:46	2020-07-31	12	[{"id_menu":1,"count":1}]	6018	delivery	5	17
107324	2020-07-31 08:24:50	2020-07-31	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	41372	delivery	5	42
107325	2020-07-31 08:26:24	2020-07-31	12	[{"id_menu":3,"count":1}]	41413	delivery	5	17
107326	2020-07-31 08:29:06	2020-07-31	12	[{"id_menu":3,"count":1}]	24913	pick-up	0	12
107327	2020-07-31 08:29:25	2020-07-31	17	[{"id_menu":4,"count":1}]	40592	delivery	5	22
107328	2020-07-31 08:33:15	2020-07-31	9	[{"id_menu":7,"count":1}]	29544	delivery	5	14
107329	2020-07-31 08:34:07	2020-07-31	12	[{"id_menu":3,"count":1}]	35806	delivery	5	17
107330	2020-07-31 08:34:54	2020-07-31	14	[{"id_menu":2,"count":1}]	41463	pick-up	0	14
107331	2020-07-31 08:36:48	2020-07-31	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	33185	delivery	5	25
107332	2020-07-31 08:38:01	2020-07-31	9	[{"id_menu":6,"count":1}]	3556	delivery	5	14
107333	2020-07-31 08:38:42	2020-07-31	12	[{"id_menu":1,"count":1}]	5758	delivery	5	17
107334	2020-07-31 08:40:16	2020-07-31	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	23554	delivery	5	37
107335	2020-07-31 08:42:06	2020-07-31	9	[{"id_menu":6,"count":1}]	19052	pick-up	0	9
107336	2020-07-31 08:42:17	2020-07-31	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	562	delivery	5	39
107337	2020-07-31 08:42:20	2020-07-31	9	[{"id_menu":6,"count":2}]	1263	pick-up	0	9
107338	2020-07-31 08:45:34	2020-07-31	9	[{"id_menu":6,"count":1}]	34111	delivery	5	14
107339	2020-07-31 08:47:50	2020-07-31	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	493	pick-up	0	26
107340	2020-07-31 08:51:21	2020-07-31	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	22262	delivery	5	31
107341	2020-07-31 08:53:09	2020-07-31	8	[{"id_menu":5,"count":1}]	14696	delivery	5	13
107342	2020-07-31 08:58:32	2020-07-31	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10896	delivery	5	31
107343	2020-07-31 09:01:59	2020-07-31	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	26359	delivery	5	31
107344	2020-07-31 09:06:47	2020-07-31	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	27057	delivery	5	30
107345	2020-07-31 09:08:10	2020-07-31	9	[{"id_menu":6,"count":2}]	23961	delivery	5	14
107346	2020-07-31 09:13:32	2020-07-31	8	[{"id_menu":5,"count":1}]	41305	delivery	5	13
107347	2020-07-31 09:13:57	2020-07-31	8	[{"id_menu":5,"count":1}]	41290	delivery	5	13
107348	2020-07-31 09:15:23	2020-07-31	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	40116	delivery	5	38
107349	2020-07-31 09:16:00	2020-07-31	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	41497	delivery	5	39
107350	2020-07-31 09:17:48	2020-07-31	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	41387	delivery	5	44
107351	2020-07-31 09:17:56	2020-07-31	17	[{"id_menu":4,"count":1}]	41434	delivery	5	22
107352	2020-07-31 09:19:15	2020-07-31	9	[{"id_menu":7,"count":1}]	15158	delivery	5	14
107353	2020-07-31 09:21:23	2020-07-31	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	16655	delivery	5	31
107354	2020-07-31 09:21:56	2020-07-31	12	[{"id_menu":1,"count":1}]	41494	delivery	5	17
107355	2020-07-31 09:25:11	2020-07-31	12	[{"id_menu":3,"count":1}]	29027	delivery	5	17
107356	2020-07-31 09:27:18	2020-07-31	9	[{"id_menu":6,"count":1}]	16914	delivery	5	14
107357	2020-07-31 09:27:51	2020-07-31	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9688	delivery	5	46
107358	2020-07-31 09:27:52	2020-07-31	12	[{"id_menu":3,"count":1}]	41437	delivery	5	17
107359	2020-07-31 09:29:44	2020-07-31	9	[{"id_menu":7,"count":1}]	29001	pick-up	0	9
107360	2020-07-31 09:31:47	2020-07-31	9	[{"id_menu":7,"count":3}]	13808	delivery	5	14
107361	2020-07-31 09:32:39	2020-07-31	9	[{"id_menu":6,"count":1}]	3135	delivery	5	14
107362	2020-07-31 09:35:09	2020-07-31	12	[{"id_menu":1,"count":1}]	10110	pick-up	0	12
107363	2020-07-31 09:35:43	2020-07-31	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	41487	delivery	5	40
107364	2020-07-31 09:41:43	2020-07-31	17	[{"id_menu":4,"count":1}]	2573	pick-up	0	17
107365	2020-07-31 09:43:04	2020-07-31	9	[{"id_menu":6,"count":1}]	38569	pick-up	0	9
107366	2020-07-31 09:45:04	2020-07-31	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	14775	delivery	5	27
107367	2020-07-31 09:45:21	2020-07-31	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	41315	delivery	5	26
107368	2020-07-31 09:45:32	2020-07-31	12	[{"id_menu":1,"count":1}]	41349	delivery	5	17
107369	2020-07-31 09:47:24	2020-07-31	9	[{"id_menu":6,"count":1}]	41476	delivery	5	14
107370	2020-07-31 09:48:06	2020-07-31	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	22363	delivery	5	31
107371	2020-07-31 09:48:19	2020-07-31	9	[{"id_menu":6,"count":1}]	38084	pick-up	0	9
107372	2020-07-31 09:48:48	2020-07-31	8	[{"id_menu":5,"count":1}]	11995	delivery	5	13
107373	2020-07-31 09:51:31	2020-07-31	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	12103	delivery	5	28
107374	2020-07-31 09:51:58	2020-07-31	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	27319	delivery	5	36
107375	2020-07-31 09:53:28	2020-07-31	9	[{"id_menu":6,"count":1}]	1528	pick-up	0	9
107376	2020-07-31 09:56:36	2020-07-31	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	41353	delivery	5	22
107377	2020-07-31 09:58:25	2020-07-31	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24263	delivery	5	37
107378	2020-07-31 10:00:28	2020-07-31	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	41274	pick-up	0	23
107379	2020-07-31 10:00:33	2020-07-31	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	4805	delivery	5	31
107380	2020-07-31 10:03:06	2020-07-31	8	[{"id_menu":5,"count":1}]	24118	delivery	5	13
107381	2020-07-31 10:10:36	2020-07-31	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	16910	delivery	5	37
107382	2020-07-31 10:18:53	2020-07-31	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	23113	delivery	5	27
107383	2020-07-31 10:19:43	2020-07-31	8	[{"id_menu":5,"count":1}]	39471	pick-up	0	8
107384	2020-07-31 10:27:02	2020-07-31	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	41448	delivery	5	36
107385	2020-07-31 10:30:23	2020-07-31	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41410	delivery	5	43
107386	2020-07-31 10:34:13	2020-07-31	12	[{"id_menu":1,"count":1}]	28333	delivery	5	17
107387	2020-07-31 10:37:53	2020-07-31	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	39944	delivery	5	28
107388	2020-07-31 10:38:52	2020-07-31	9	[{"id_menu":7,"count":1}]	41396	pick-up	0	9
107389	2020-07-31 10:38:59	2020-07-31	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	25877	delivery	5	31
107390	2020-07-31 10:44:43	2020-07-31	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	32444	delivery	5	31
107391	2020-07-31 10:45:53	2020-07-31	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2285	delivery	5	31
107392	2020-07-31 10:53:23	2020-07-31	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	41338	delivery	5	43
107393	2020-07-31 10:55:03	2020-07-31	14	[{"id_menu":2,"count":1}]	21628	delivery	5	19
107394	2020-07-31 10:55:55	2020-07-31	8	[{"id_menu":5,"count":1}]	12967	delivery	5	13
107395	2020-07-31 10:55:56	2020-07-31	12	[{"id_menu":1,"count":1}]	17614	delivery	5	17
107396	2020-07-31 11:02:04	2020-07-31	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31581	pick-up	0	18
107397	2020-07-31 11:02:15	2020-07-31	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	22691	pick-up	0	26
107398	2020-07-31 11:03:00	2020-07-31	9	[{"id_menu":7,"count":1}]	41504	delivery	5	14
107399	2020-07-31 11:04:05	2020-07-31	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3858	pick-up	0	25
107400	2020-07-31 11:04:46	2020-07-31	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	27908	delivery	5	31
107401	2020-07-31 11:09:04	2020-07-31	12	[{"id_menu":1,"count":1}]	27429	pick-up	0	12
107402	2020-07-31 11:09:39	2020-07-31	9	[{"id_menu":7,"count":1}]	18533	pick-up	0	9
107403	2020-07-31 11:11:15	2020-07-31	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":3}]	13881	delivery	5	23
107404	2020-07-31 11:12:14	2020-07-31	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	41395	delivery	5	26
107405	2020-07-31 11:17:04	2020-07-31	9	[{"id_menu":7,"count":1}]	41440	delivery	5	14
107406	2020-07-31 11:20:50	2020-07-31	12	[{"id_menu":1,"count":1}]	25431	delivery	5	17
107407	2020-07-31 11:23:12	2020-07-31	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	31510	delivery	5	26
107408	2020-07-31 11:24:12	2020-07-31	14	[{"id_menu":2,"count":1}]	33665	delivery	5	19
107409	2020-07-31 11:24:17	2020-07-31	8	[{"id_menu":5,"count":1}]	23853	delivery	5	13
107410	2020-07-31 11:33:43	2020-07-31	12	[{"id_menu":3,"count":1}]	16792	delivery	5	17
107411	2020-07-31 11:36:24	2020-07-31	8	[{"id_menu":5,"count":1}]	8109	pick-up	0	8
107412	2020-07-31 11:47:10	2020-07-31	12	[{"id_menu":3,"count":1}]	41490	delivery	5	17
107413	2020-07-31 11:50:14	2020-07-31	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	41416	delivery	5	43
107414	2020-07-31 11:51:03	2020-07-31	9	[{"id_menu":6,"count":1}]	24356	delivery	5	14
107415	2020-07-31 11:53:57	2020-07-31	8	[{"id_menu":5,"count":1}]	41358	delivery	5	13
107416	2020-07-31 11:55:01	2020-07-31	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	41374	delivery	5	38
107417	2020-07-31 11:55:08	2020-07-31	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":3}]	35682	delivery	5	31
107418	2020-07-31 11:56:25	2020-07-31	9	[{"id_menu":6,"count":1}]	14165	delivery	5	14
107419	2020-07-31 11:58:52	2020-07-31	9	[{"id_menu":7,"count":1}]	41294	delivery	5	14
107420	2020-07-31 12:01:06	2020-07-31	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28305	pick-up	0	17
107421	2020-07-31 12:01:37	2020-07-31	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	41329	delivery	5	40
107422	2020-07-31 12:05:23	2020-07-31	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	27085	delivery	5	31
107423	2020-07-31 12:05:32	2020-07-31	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12771	delivery	5	48
107424	2020-07-31 12:06:31	2020-07-31	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	41500	pick-up	0	31
107425	2020-07-31 12:09:02	2020-07-31	34	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	33943	pick-up	0	34
107426	2020-07-31 12:09:30	2020-07-31	12	[{"id_menu":1,"count":1}]	41370	delivery	5	17
107427	2020-07-31 12:13:12	2020-07-31	17	[{"id_menu":4,"count":1}]	16063	delivery	5	22
107428	2020-07-31 12:16:19	2020-07-31	14	[{"id_menu":2,"count":1}]	1352	pick-up	0	14
107429	2020-07-31 12:16:30	2020-07-31	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35660	delivery	5	54
107430	2020-07-31 12:20:32	2020-07-31	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	41293	delivery	5	44
107431	2020-07-31 12:23:26	2020-07-31	9	[{"id_menu":7,"count":1}]	29396	delivery	5	14
107432	2020-07-31 12:24:40	2020-07-31	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	24980	delivery	5	34
107433	2020-07-31 12:26:50	2020-07-31	9	[{"id_menu":6,"count":1}]	14096	delivery	5	14
107434	2020-07-31 12:26:54	2020-07-31	12	[{"id_menu":1,"count":1}]	13987	delivery	5	17
107435	2020-07-31 12:27:49	2020-07-31	12	[{"id_menu":3,"count":1}]	34246	delivery	5	17
107436	2020-07-31 12:28:25	2020-07-31	12	[{"id_menu":1,"count":1}]	21946	delivery	5	17
107437	2020-07-31 12:28:26	2020-07-31	14	[{"id_menu":2,"count":1}]	41469	delivery	5	19
107438	2020-07-31 12:30:02	2020-07-31	9	[{"id_menu":6,"count":1}]	29484	delivery	5	14
107439	2020-07-31 12:32:34	2020-07-31	9	[{"id_menu":7,"count":1}]	41431	delivery	5	14
107440	2020-07-31 12:33:01	2020-07-31	9	[{"id_menu":6,"count":1}]	11656	delivery	5	14
107441	2020-07-31 12:35:54	2020-07-31	12	[{"id_menu":3,"count":1}]	18472	delivery	5	17
107442	2020-07-31 12:37:57	2020-07-31	9	[{"id_menu":7,"count":2}]	1219	delivery	5	14
107443	2020-07-31 12:39:16	2020-07-31	12	[{"id_menu":1,"count":1}]	25238	delivery	5	17
107444	2020-07-31 12:43:13	2020-07-31	14	[{"id_menu":2,"count":1}]	6124	delivery	5	19
107445	2020-07-31 12:43:57	2020-07-31	14	[{"id_menu":2,"count":1}]	10679	pick-up	0	14
107446	2020-07-31 12:47:01	2020-07-31	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	11676	delivery	5	31
107447	2020-07-31 12:48:21	2020-07-31	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	38091	delivery	5	27
107448	2020-07-31 12:48:33	2020-07-31	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20229	delivery	5	31
107449	2020-07-31 12:48:40	2020-07-31	9	[{"id_menu":6,"count":1}]	41312	delivery	5	14
107450	2020-07-31 12:48:53	2020-07-31	9	[{"id_menu":7,"count":1}]	41425	delivery	5	14
107451	2020-07-31 12:49:04	2020-07-31	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	41393	delivery	5	31
107452	2020-07-31 12:51:03	2020-07-31	12	[{"id_menu":1,"count":1}]	41354	delivery	5	17
107453	2020-07-31 12:53:56	2020-07-31	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	31695	delivery	5	31
107454	2020-07-31 12:56:17	2020-07-31	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28618	delivery	5	46
107455	2020-07-31 12:58:04	2020-07-31	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	39902	pick-up	0	23
107456	2020-07-31 12:59:12	2020-07-31	8	[{"id_menu":5,"count":2}]	16307	delivery	5	13
107457	2020-07-31 13:03:00	2020-07-31	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	38866	delivery	5	23
107458	2020-07-31 13:13:40	2020-07-31	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	36271	delivery	5	34
107459	2020-07-31 13:14:53	2020-07-31	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	11766	delivery	5	28
107460	2020-07-31 13:15:16	2020-07-31	14	[{"id_menu":2,"count":1}]	39493	delivery	5	19
107461	2020-07-31 13:17:15	2020-07-31	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	19707	delivery	5	25
107462	2020-07-31 13:20:07	2020-07-31	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	25997	delivery	5	22
107463	2020-07-31 13:22:06	2020-07-31	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	41447	delivery	5	25
107464	2020-07-31 13:24:45	2020-07-31	9	[{"id_menu":7,"count":1}]	15779	delivery	5	14
107465	2020-07-31 13:29:34	2020-07-31	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8506	delivery	5	37
107466	2020-07-31 13:29:43	2020-07-31	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	24639	delivery	5	31
107467	2020-07-31 13:29:57	2020-07-31	17	[{"id_menu":4,"count":1}]	22194	pick-up	0	17
107468	2020-07-31 13:30:02	2020-07-31	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	9682	delivery	5	31
107469	2020-07-31 13:30:10	2020-07-31	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	41441	delivery	5	22
107470	2020-07-31 13:31:56	2020-07-31	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	41400	delivery	5	36
107471	2020-07-31 13:34:21	2020-07-31	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	41343	delivery	5	28
107472	2020-07-31 13:34:26	2020-07-31	9	[{"id_menu":6,"count":1}]	969	delivery	5	14
107473	2020-07-31 13:39:27	2020-07-31	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	41124	delivery	5	40
107474	2020-07-31 13:40:21	2020-07-31	12	[{"id_menu":3,"count":1}]	1208	pick-up	0	12
107475	2020-07-31 13:45:25	2020-07-31	17	[{"id_menu":4,"count":1}]	41362	delivery	5	22
107476	2020-07-31 13:45:42	2020-07-31	12	[{"id_menu":1,"count":1}]	33833	delivery	5	17
107477	2020-07-31 13:46:21	2020-07-31	14	[{"id_menu":2,"count":1}]	41373	pick-up	0	14
107478	2020-07-31 13:48:56	2020-07-31	17	[{"id_menu":4,"count":1}]	3839	delivery	5	22
107479	2020-07-31 13:48:59	2020-07-31	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	6596	delivery	5	40
107480	2020-07-31 13:50:04	2020-07-31	17	[{"id_menu":4,"count":1}]	34052	pick-up	0	17
107481	2020-07-31 13:50:48	2020-07-31	17	[{"id_menu":4,"count":1}]	6296	delivery	5	22
107482	2020-07-31 13:56:37	2020-07-31	14	[{"id_menu":2,"count":1}]	17695	delivery	5	19
107483	2020-07-31 14:00:10	2020-07-31	9	[{"id_menu":7,"count":1}]	41302	delivery	5	14
107484	2020-07-31 14:00:33	2020-07-31	8	[{"id_menu":5,"count":1}]	34147	delivery	5	13
107485	2020-07-31 14:00:58	2020-07-31	9	[{"id_menu":6,"count":2}]	19207	delivery	5	14
107486	2020-07-31 14:03:22	2020-07-31	9	[{"id_menu":7,"count":1}]	37321	delivery	5	14
107487	2020-07-31 14:04:05	2020-07-31	12	[{"id_menu":1,"count":1}]	39814	delivery	5	17
107488	2020-07-31 14:04:14	2020-07-31	12	[{"id_menu":3,"count":1}]	7206	pick-up	0	12
107489	2020-07-31 14:07:29	2020-07-31	12	[{"id_menu":1,"count":1}]	41330	delivery	5	17
107490	2020-07-31 14:09:26	2020-07-31	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	33916	delivery	5	23
107491	2020-07-31 14:10:34	2020-07-31	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	40065	delivery	5	29
107492	2020-07-31 14:18:20	2020-07-31	8	[{"id_menu":5,"count":1}]	6514	delivery	5	13
107493	2020-07-31 14:19:58	2020-07-31	12	[{"id_menu":1,"count":1}]	25123	delivery	5	17
107494	2020-07-31 14:20:09	2020-07-31	9	[{"id_menu":6,"count":1}]	2841	pick-up	0	9
107495	2020-07-31 14:23:44	2020-07-31	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24967	delivery	5	22
107496	2020-07-31 14:27:31	2020-07-31	12	[{"id_menu":1,"count":1}]	29326	delivery	5	17
107497	2020-07-31 14:31:43	2020-07-31	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	41499	delivery	5	31
107498	2020-07-31 14:31:54	2020-07-31	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20792	delivery	5	22
107499	2020-07-31 14:34:08	2020-07-31	9	[{"id_menu":6,"count":1}]	32057	delivery	5	14
107500	2020-07-31 14:34:30	2020-07-31	9	[{"id_menu":6,"count":3}]	14063	pick-up	0	9
107501	2020-07-31 14:34:35	2020-07-31	9	[{"id_menu":6,"count":1}]	41457	delivery	5	14
107502	2020-07-31 14:36:21	2020-07-31	14	[{"id_menu":2,"count":1}]	38630	delivery	5	19
107503	2020-07-31 14:42:11	2020-07-31	9	[{"id_menu":7,"count":1}]	41304	delivery	5	14
107504	2020-07-31 14:42:29	2020-07-31	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	41461	delivery	5	25
107505	2020-07-31 14:49:13	2020-07-31	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	9976	delivery	5	34
107506	2020-07-31 14:49:28	2020-07-31	9	[{"id_menu":7,"count":1}]	40358	delivery	5	14
107507	2020-07-31 14:51:21	2020-07-31	9	[{"id_menu":7,"count":1}]	41423	delivery	5	14
107508	2020-07-31 14:54:36	2020-07-31	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	21352	delivery	5	31
107509	2020-07-31 14:58:54	2020-07-31	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2451	delivery	5	37
107510	2020-07-31 14:59:36	2020-07-31	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	3680	pick-up	0	24
107511	2020-07-31 15:03:55	2020-07-31	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5483	pick-up	0	26
107512	2020-07-31 15:05:02	2020-07-31	9	[{"id_menu":7,"count":1}]	40185	delivery	5	14
107513	2020-07-31 15:11:09	2020-07-31	14	[{"id_menu":2,"count":1}]	7058	pick-up	0	14
107514	2020-07-31 15:14:18	2020-07-31	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	41333	delivery	5	28
107515	2020-07-31 15:15:46	2020-07-31	8	[{"id_menu":5,"count":1}]	41432	delivery	5	13
107516	2020-07-31 15:16:05	2020-07-31	9	[{"id_menu":6,"count":1}]	40322	pick-up	0	9
107517	2020-07-31 15:19:58	2020-07-31	9	[{"id_menu":7,"count":1}]	41464	delivery	5	14
107518	2020-07-31 15:20:18	2020-07-31	9	[{"id_menu":6,"count":1}]	4752	delivery	5	14
107519	2020-07-31 15:22:15	2020-07-31	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	41459	delivery	5	23
107520	2020-07-31 15:22:17	2020-07-31	9	[{"id_menu":7,"count":2}]	12842	delivery	5	14
107521	2020-07-31 15:23:11	2020-07-31	9	[{"id_menu":7,"count":1}]	40201	pick-up	0	9
107522	2020-07-31 15:24:26	2020-07-31	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	36375	delivery	5	26
107523	2020-07-31 15:25:39	2020-07-31	17	[{"id_menu":4,"count":1}]	41450	delivery	5	22
107524	2020-07-31 15:27:48	2020-07-31	9	[{"id_menu":6,"count":1}]	4460	delivery	5	14
107525	2020-07-31 15:28:11	2020-07-31	9	[{"id_menu":7,"count":1}]	41382	delivery	5	14
107526	2020-07-31 15:31:31	2020-07-31	9	[{"id_menu":6,"count":1}]	35902	delivery	5	14
107527	2020-07-31 15:41:11	2020-07-31	9	[{"id_menu":7,"count":1}]	18443	delivery	5	14
107528	2020-07-31 15:43:02	2020-07-31	8	[{"id_menu":5,"count":1}]	41468	delivery	5	13
107529	2020-07-31 15:43:34	2020-07-31	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	41360	delivery	5	34
107530	2020-07-31 15:45:46	2020-07-31	9	[{"id_menu":6,"count":1}]	41427	delivery	5	14
107531	2020-07-31 15:45:49	2020-07-31	9	[{"id_menu":7,"count":1}]	6259	delivery	5	14
107532	2020-07-31 15:49:24	2020-07-31	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18035	delivery	5	22
107533	2020-07-31 15:51:53	2020-07-31	9	[{"id_menu":7,"count":1}]	41474	delivery	5	14
107534	2020-07-31 15:52:16	2020-07-31	8	[{"id_menu":5,"count":1}]	5696	delivery	5	13
107535	2020-07-31 15:52:38	2020-07-31	8	[{"id_menu":5,"count":1}]	21061	delivery	5	13
107536	2020-07-31 15:52:55	2020-07-31	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15244	delivery	5	22
107537	2020-07-31 15:58:51	2020-07-31	14	[{"id_menu":2,"count":1}]	2339	delivery	5	19
107538	2020-07-31 15:59:54	2020-07-31	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	30647	delivery	5	25
107539	2020-07-31 16:02:15	2020-07-31	17	[{"id_menu":4,"count":1}]	41443	delivery	5	22
107540	2020-07-31 16:03:25	2020-07-31	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	12017	delivery	5	40
107541	2020-07-31 16:05:30	2020-07-31	14	[{"id_menu":2,"count":1}]	8966	delivery	5	19
107542	2020-07-31 16:08:31	2020-07-31	9	[{"id_menu":6,"count":1}]	29854	delivery	5	14
107543	2020-07-31 16:09:57	2020-07-31	9	[{"id_menu":6,"count":1}]	27982	delivery	5	14
107544	2020-07-31 16:11:47	2020-07-31	9	[{"id_menu":7,"count":1}]	39238	pick-up	0	9
107545	2020-07-31 16:13:15	2020-07-31	8	[{"id_menu":5,"count":1}]	41337	delivery	5	13
107546	2020-07-31 16:24:09	2020-07-31	9	[{"id_menu":6,"count":1}]	41289	delivery	5	14
107547	2020-07-31 16:24:42	2020-07-31	12	[{"id_menu":1,"count":1}]	7151	delivery	5	17
107548	2020-07-31 16:26:50	2020-07-31	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	41426	delivery	5	22
107549	2020-07-31 16:30:09	2020-07-31	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16239	delivery	5	40
107550	2020-07-31 16:30:30	2020-07-31	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	41435	delivery	5	43
107551	2020-07-31 16:31:03	2020-07-31	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	8212	delivery	5	26
107552	2020-07-31 16:31:09	2020-07-31	14	[{"id_menu":2,"count":1}]	41379	delivery	5	19
107553	2020-07-31 16:31:25	2020-07-31	9	[{"id_menu":6,"count":1}]	14038	pick-up	0	9
107554	2020-07-31 16:31:43	2020-07-31	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	31724	delivery	5	22
107555	2020-07-31 16:34:16	2020-07-31	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	22496	delivery	5	31
107556	2020-07-31 16:35:15	2020-07-31	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41278	delivery	5	23
107557	2020-07-31 16:45:19	2020-07-31	8	[{"id_menu":5,"count":1}]	41138	delivery	5	13
107558	2020-07-31 16:49:21	2020-07-31	12	[{"id_menu":3,"count":1}]	11878	delivery	5	17
107559	2020-07-31 16:53:03	2020-07-31	9	[{"id_menu":7,"count":1}]	41483	delivery	5	14
107560	2020-07-31 16:55:30	2020-07-31	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	17545	delivery	5	22
107561	2020-07-31 16:56:15	2020-07-31	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15386	delivery	5	36
107562	2020-07-31 17:00:46	2020-07-31	14	[{"id_menu":2,"count":1}]	41445	pick-up	0	14
107563	2020-07-31 17:01:41	2020-07-31	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	34745	delivery	5	36
107564	2020-07-31 17:02:18	2020-07-31	9	[{"id_menu":7,"count":1}]	541	pick-up	0	9
107565	2020-07-31 17:02:21	2020-07-31	9	[{"id_menu":6,"count":1}]	4851	delivery	5	14
107566	2020-07-31 17:03:17	2020-07-31	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	41388	delivery	5	36
107567	2020-07-31 17:03:45	2020-07-31	9	[{"id_menu":6,"count":1}]	41324	delivery	5	14
107568	2020-07-31 17:08:53	2020-07-31	12	[{"id_menu":3,"count":1}]	41281	delivery	5	17
107569	2020-07-31 17:13:19	2020-07-31	14	[{"id_menu":2,"count":1}]	11560	delivery	5	19
107570	2020-07-31 17:13:20	2020-07-31	12	[{"id_menu":1,"count":1}]	40630	delivery	5	17
107571	2020-07-31 17:15:58	2020-07-31	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	36405	delivery	5	43
107572	2020-07-31 17:18:59	2020-07-31	9	[{"id_menu":7,"count":1}]	19058	delivery	5	14
107573	2020-07-31 17:22:21	2020-07-31	8	[{"id_menu":5,"count":1}]	39966	delivery	5	13
107574	2020-07-31 17:24:47	2020-07-31	12	[{"id_menu":3,"count":1}]	35167	delivery	5	17
107575	2020-07-31 17:26:59	2020-07-31	9	[{"id_menu":6,"count":1}]	32154	delivery	5	14
107576	2020-07-31 17:30:32	2020-07-31	9	[{"id_menu":6,"count":1}]	37375	delivery	5	14
107577	2020-07-31 17:32:17	2020-07-31	9	[{"id_menu":7,"count":1}]	19727	delivery	5	14
107578	2020-07-31 17:32:25	2020-07-31	9	[{"id_menu":6,"count":1}]	41433	delivery	5	14
107579	2020-07-31 17:38:55	2020-07-31	14	[{"id_menu":2,"count":1}]	12849	delivery	5	19
107580	2020-07-31 17:48:48	2020-07-31	14	[{"id_menu":2,"count":1}]	41351	delivery	5	19
107581	2020-07-31 17:50:12	2020-07-31	9	[{"id_menu":6,"count":2}]	29695	delivery	5	14
107582	2020-07-31 17:51:41	2020-07-31	8	[{"id_menu":5,"count":1}]	4369	delivery	5	13
107583	2020-07-31 17:53:56	2020-07-31	8	[{"id_menu":5,"count":2}]	2398	pick-up	0	8
107584	2020-07-31 17:56:26	2020-07-31	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2590	pick-up	0	26
107585	2020-07-31 18:05:21	2020-07-31	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6173	pick-up	0	18
107586	2020-07-31 18:07:17	2020-07-31	49	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4183	delivery	5	54
107587	2020-07-31 18:09:12	2020-07-31	8	[{"id_menu":5,"count":1}]	32478	delivery	5	13
107588	2020-07-31 18:15:38	2020-07-31	9	[{"id_menu":7,"count":1}]	40063	delivery	5	14
107589	2020-07-31 18:17:27	2020-07-31	17	[{"id_menu":4,"count":1}]	2087	delivery	5	22
107590	2020-07-31 18:19:44	2020-07-31	12	[{"id_menu":3,"count":1}]	36982	delivery	5	17
107591	2020-07-31 18:22:10	2020-07-31	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	41332	delivery	5	28
107592	2020-07-31 18:26:09	2020-07-31	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	39737	delivery	5	22
107593	2020-07-31 18:27:07	2020-07-31	14	[{"id_menu":2,"count":1}]	41439	pick-up	0	14
107594	2020-07-31 18:28:35	2020-07-31	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	29527	delivery	5	25
107595	2020-07-31 18:31:22	2020-07-31	12	[{"id_menu":1,"count":1}]	25944	pick-up	0	12
107596	2020-07-31 18:36:12	2020-07-31	17	[{"id_menu":4,"count":1}]	22498	delivery	5	22
107597	2020-07-31 18:36:37	2020-07-31	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41436	delivery	5	40
107598	2020-07-31 18:38:27	2020-07-31	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	41270	pick-up	0	25
107599	2020-07-31 18:38:41	2020-07-31	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	39344	delivery	5	26
107600	2020-07-31 18:39:04	2020-07-31	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	41442	delivery	5	48
107601	2020-07-31 18:41:20	2020-07-31	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	41339	delivery	5	28
107602	2020-07-31 18:41:36	2020-07-31	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	20158	delivery	5	22
107603	2020-07-31 18:45:00	2020-07-31	9	[{"id_menu":6,"count":1}]	10200	pick-up	0	9
107604	2020-07-31 18:51:05	2020-07-31	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	41462	delivery	5	22
107605	2020-07-31 18:51:55	2020-07-31	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	6758	delivery	5	31
107606	2020-07-31 18:52:19	2020-07-31	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	7231	delivery	5	27
107607	2020-07-31 18:53:08	2020-07-31	8	[{"id_menu":5,"count":1}]	41505	delivery	5	13
107608	2020-07-31 18:54:41	2020-07-31	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	22056	delivery	5	23
107609	2020-07-31 18:55:57	2020-07-31	17	[{"id_menu":4,"count":1}]	41273	delivery	5	22
107610	2020-07-31 19:02:58	2020-07-31	12	[{"id_menu":1,"count":1}]	38602	delivery	5	17
107611	2020-07-31 19:04:44	2020-07-31	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	20338	pick-up	0	21
107612	2020-07-31 19:05:35	2020-07-31	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5808	pick-up	0	18
107613	2020-07-31 19:05:45	2020-07-31	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11409	delivery	5	43
107614	2020-07-31 19:06:20	2020-07-31	9	[{"id_menu":6,"count":1}]	4265	delivery	5	14
107615	2020-07-31 19:06:37	2020-07-31	9	[{"id_menu":6,"count":1}]	28281	delivery	5	14
107616	2020-07-31 19:09:32	2020-07-31	12	[{"id_menu":3,"count":1}]	41384	delivery	5	17
107617	2020-07-31 19:12:47	2020-07-31	12	[{"id_menu":1,"count":1}]	27452	delivery	5	17
107618	2020-07-31 19:13:12	2020-07-31	9	[{"id_menu":7,"count":2}]	36129	delivery	5	14
107619	2020-07-31 19:14:01	2020-07-31	14	[{"id_menu":2,"count":1}]	31374	pick-up	0	14
107620	2020-07-31 19:17:16	2020-07-31	12	[{"id_menu":3,"count":1}]	27651	delivery	5	17
107621	2020-07-31 19:19:28	2020-07-31	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	30167	delivery	5	28
107622	2020-07-31 19:23:29	2020-07-31	9	[{"id_menu":6,"count":1}]	41369	delivery	5	14
107623	2020-07-31 19:24:15	2020-07-31	9	[{"id_menu":6,"count":1}]	41321	delivery	5	14
107624	2020-07-31 19:24:46	2020-07-31	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	39418	delivery	5	28
107625	2020-07-31 19:29:38	2020-07-31	14	[{"id_menu":2,"count":1}]	38095	delivery	5	19
107626	2020-07-31 19:30:42	2020-07-31	17	[{"id_menu":4,"count":1}]	7297	delivery	5	22
107627	2020-07-31 19:31:57	2020-07-31	14	[{"id_menu":2,"count":1}]	41344	delivery	5	19
107628	2020-07-31 19:34:16	2020-07-31	9	[{"id_menu":7,"count":1}]	8486	delivery	5	14
107629	2020-07-31 19:35:04	2020-07-31	8	[{"id_menu":5,"count":1}]	9202	pick-up	0	8
107630	2020-07-31 19:40:03	2020-07-31	9	[{"id_menu":7,"count":1}]	3996	delivery	5	14
107631	2020-07-31 19:42:00	2020-07-31	12	[{"id_menu":1,"count":1}]	41386	pick-up	0	12
107632	2020-07-31 19:43:39	2020-07-31	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	19750	delivery	5	34
107633	2020-07-31 19:44:09	2020-07-31	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":3}]	11046	delivery	5	26
107634	2020-07-31 19:48:27	2020-07-31	8	[{"id_menu":5,"count":1}]	41454	delivery	5	13
107635	2020-07-31 19:52:15	2020-07-31	9	[{"id_menu":7,"count":1}]	17940	delivery	5	14
107636	2020-07-31 19:52:58	2020-07-31	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	41380	pick-up	0	48
107637	2020-07-31 20:05:34	2020-07-31	9	[{"id_menu":6,"count":1}]	41347	delivery	5	14
107638	2020-07-31 20:06:17	2020-07-31	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9711	delivery	5	22
107639	2020-07-31 20:22:11	2020-07-31	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	15626	delivery	5	36
107640	2020-07-31 20:23:53	2020-07-31	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	27777	pick-up	0	26
107641	2020-07-31 20:24:25	2020-07-31	12	[{"id_menu":1,"count":1}]	2295	pick-up	0	12
107642	2020-07-31 20:27:01	2020-07-31	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	34309	delivery	5	38
107643	2020-07-31 20:28:35	2020-07-31	9	[{"id_menu":7,"count":1}]	30540	pick-up	0	9
107644	2020-07-31 20:40:29	2020-07-31	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	41418	delivery	5	39
107645	2020-07-31 20:45:11	2020-07-31	12	[{"id_menu":1,"count":1}]	6097	pick-up	0	12
107646	2020-07-31 20:45:19	2020-07-31	14	[{"id_menu":2,"count":1}]	39034	pick-up	0	14
107647	2020-07-31 20:45:26	2020-07-31	9	[{"id_menu":6,"count":1}]	26338	delivery	5	14
107648	2020-07-31 20:45:48	2020-07-31	12	[{"id_menu":3,"count":1}]	33841	delivery	5	17
107649	2020-07-31 20:47:12	2020-07-31	12	[{"id_menu":1,"count":1}]	2252	pick-up	0	12
107650	2020-07-31 20:50:02	2020-07-31	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	34707	delivery	5	25
107651	2020-07-31 20:55:52	2020-07-31	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	22341	delivery	5	30
107652	2020-07-31 20:55:55	2020-07-31	9	[{"id_menu":6,"count":1}]	41477	delivery	5	14
107653	2020-07-31 20:56:19	2020-07-31	12	[{"id_menu":1,"count":1}]	41492	delivery	5	17
107654	2020-07-31 20:56:40	2020-07-31	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31365	delivery	5	43
107655	2020-07-31 20:59:56	2020-07-31	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29328	delivery	5	23
107656	2020-07-31 21:03:08	2020-07-31	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2552	pick-up	0	21
107657	2020-07-31 21:04:05	2020-07-31	14	[{"id_menu":2,"count":1}]	6239	delivery	5	19
107658	2020-07-31 21:05:46	2020-07-31	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	41478	delivery	5	28
107659	2020-07-31 21:05:52	2020-07-31	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	41479	delivery	5	40
107660	2020-07-31 21:10:07	2020-07-31	8	[{"id_menu":5,"count":1}]	26267	delivery	5	13
107661	2020-07-31 21:12:59	2020-07-31	9	[{"id_menu":7,"count":1}]	18222	pick-up	0	9
107662	2020-07-31 21:13:27	2020-07-31	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5508	pick-up	0	40
107663	2020-07-31 21:15:58	2020-07-31	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	25125	delivery	5	28
107664	2020-07-31 21:19:53	2020-07-31	14	[{"id_menu":2,"count":1}]	29458	delivery	5	19
107665	2020-07-31 21:21:17	2020-07-31	9	[{"id_menu":6,"count":1}]	13888	pick-up	0	9
107666	2020-07-31 21:28:25	2020-07-31	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	24996	delivery	5	43
107667	2020-07-31 21:29:11	2020-07-31	8	[{"id_menu":5,"count":1}]	29448	delivery	5	13
107668	2020-07-31 21:31:25	2020-07-31	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	24210	delivery	5	31
107669	2020-07-31 21:31:48	2020-07-31	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	41486	delivery	5	26
107670	2020-07-31 21:34:03	2020-07-31	9	[{"id_menu":7,"count":1}]	29187	pick-up	0	9
107671	2020-07-31 21:35:07	2020-07-31	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	28537	delivery	5	22
107672	2020-07-31 21:44:09	2020-07-31	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	39946	delivery	5	25
107673	2020-07-31 21:45:24	2020-07-31	17	[{"id_menu":4,"count":1}]	2332	delivery	5	22
107674	2020-07-31 21:48:07	2020-07-31	14	[{"id_menu":2,"count":1}]	3774	delivery	5	19
107675	2020-07-31 21:53:30	2020-07-31	9	[{"id_menu":7,"count":1}]	41320	delivery	5	14
107676	2020-07-31 21:54:24	2020-07-31	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	12578	pick-up	0	34
107677	2020-07-31 21:54:51	2020-07-31	9	[{"id_menu":7,"count":1}]	38102	delivery	5	14
107678	2020-07-31 21:57:57	2020-07-31	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	35492	delivery	5	30
107679	2020-07-31 21:58:25	2020-07-31	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	24343	delivery	5	28
107680	2020-07-31 21:59:23	2020-07-31	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	41493	delivery	5	51
107681	2020-07-31 22:03:07	2020-07-31	12	[{"id_menu":3,"count":1}]	41428	delivery	5	17
107682	2020-07-31 22:08:34	2020-07-31	14	[{"id_menu":2,"count":1}]	5248	delivery	5	19
107683	2020-07-31 22:12:40	2020-07-31	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	41272	delivery	5	31
107684	2020-07-31 22:17:27	2020-07-31	9	[{"id_menu":7,"count":1}]	9140	delivery	5	14
107685	2020-07-31 22:19:56	2020-07-31	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	11407	pick-up	0	41
107686	2020-07-31 22:20:39	2020-07-31	8	[{"id_menu":5,"count":1}]	1729	pick-up	0	8
107687	2020-07-31 22:26:24	2020-07-31	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	41341	delivery	5	36
107688	2020-07-31 22:26:39	2020-07-31	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":3}]	41318	delivery	5	30
107689	2020-07-31 22:27:46	2020-07-31	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	41299	delivery	5	40
107690	2020-07-31 22:28:56	2020-07-31	17	[{"id_menu":4,"count":1}]	41421	delivery	5	22
107691	2020-07-31 22:29:37	2020-07-31	12	[{"id_menu":1,"count":1}]	41298	pick-up	0	12
107692	2020-07-31 22:34:15	2020-07-31	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27492	delivery	5	46
107693	2020-07-31 22:34:35	2020-07-31	8	[{"id_menu":5,"count":1}]	27858	delivery	5	13
107694	2020-07-31 22:35:07	2020-07-31	12	[{"id_menu":3,"count":1}]	29102	delivery	5	17
107695	2020-07-31 22:38:08	2020-07-31	14	[{"id_menu":2,"count":1}]	34999	delivery	5	19
107696	2020-07-31 22:38:09	2020-07-31	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	41300	delivery	5	26
107697	2020-07-31 22:42:27	2020-07-31	12	[{"id_menu":3,"count":2}]	24603	pick-up	0	12
107698	2020-07-31 22:42:46	2020-07-31	14	[{"id_menu":2,"count":1}]	21553	pick-up	0	14
107699	2020-07-31 22:44:20	2020-07-31	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13637	delivery	5	40
107700	2020-07-31 22:44:54	2020-07-31	9	[{"id_menu":6,"count":1}]	7931	delivery	5	14
107701	2020-07-31 22:47:04	2020-07-31	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	28249	delivery	5	22
107702	2020-07-31 22:59:17	2020-07-31	8	[{"id_menu":5,"count":1}]	39422	delivery	5	13
107703	2020-07-31 23:03:07	2020-07-31	8	[{"id_menu":5,"count":1}]	26686	delivery	5	13
107704	2020-07-31 23:07:12	2020-07-31	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14473	delivery	5	35
107705	2020-07-31 23:09:52	2020-07-31	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	27332	pick-up	0	26
107706	2020-07-31 23:11:03	2020-07-31	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	41326	delivery	5	40
107707	2020-07-31 23:12:44	2020-07-31	8	[{"id_menu":5,"count":1}]	11495	pick-up	0	8
107708	2020-07-31 23:12:48	2020-07-31	9	[{"id_menu":6,"count":1}]	8648	delivery	5	14
107709	2020-07-31 23:13:30	2020-07-31	12	[{"id_menu":3,"count":1}]	7186	delivery	5	17
107710	2020-07-31 23:14:16	2020-07-31	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23579	delivery	5	35
107711	2020-07-31 23:17:22	2020-07-31	12	[{"id_menu":3,"count":1}]	40374	pick-up	0	12
107712	2020-07-31 23:21:56	2020-07-31	9	[{"id_menu":7,"count":1}]	28750	delivery	5	14
107713	2020-07-31 23:23:10	2020-07-31	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	32332	delivery	5	31
107714	2020-07-31 23:27:48	2020-07-31	17	[{"id_menu":4,"count":1}]	8295	delivery	5	22
107715	2020-07-31 23:29:49	2020-07-31	8	[{"id_menu":5,"count":1}]	38939	delivery	5	13
107716	2020-07-31 23:32:19	2020-07-31	17	[{"id_menu":4,"count":1}]	41286	delivery	5	22
107717	2020-07-31 23:32:49	2020-07-31	8	[{"id_menu":5,"count":1}]	41424	delivery	5	13
107718	2020-07-31 23:36:38	2020-07-31	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	41323	delivery	5	26
107719	2020-07-31 23:37:58	2020-07-31	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	13874	pick-up	0	26
107720	2020-07-31 23:38:33	2020-07-31	14	[{"id_menu":2,"count":1}]	10292	delivery	5	19
107721	2020-07-31 23:39:31	2020-07-31	14	[{"id_menu":2,"count":1}]	41363	delivery	5	19
107722	2020-07-31 23:43:01	2020-07-31	8	[{"id_menu":5,"count":1}]	27480	delivery	5	13
107723	2020-07-31 23:47:27	2020-07-31	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	13790	delivery	5	34
107724	2020-07-31 23:48:01	2020-07-31	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	30476	delivery	5	26
107725	2020-07-31 23:51:51	2020-07-31	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28912	delivery	5	34
107726	2020-07-31 23:53:38	2020-07-31	17	[{"id_menu":4,"count":1}]	13404	delivery	5	22
107727	2020-07-31 23:57:29	2020-07-31	9	[{"id_menu":7,"count":1}]	41364	delivery	5	14
107728	2020-08-01 00:00:07	2020-08-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18090	delivery	5	22
107729	2020-08-01 00:03:18	2020-08-01	8	[{"id_menu":5,"count":1}]	5753	delivery	5	13
107730	2020-08-01 00:03:39	2020-08-01	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	10435	delivery	5	39
107731	2020-08-01 00:08:12	2020-08-01	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	614	delivery	5	43
107732	2020-08-01 00:09:13	2020-08-01	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4943	pick-up	0	29
107733	2020-08-01 00:09:34	2020-08-01	12	[{"id_menu":1,"count":1}]	6325	delivery	5	17
107734	2020-08-01 00:12:57	2020-08-01	9	[{"id_menu":7,"count":1}]	14165	delivery	5	14
107735	2020-08-01 00:15:59	2020-08-01	9	[{"id_menu":7,"count":1}]	41596	delivery	5	14
107736	2020-08-01 00:17:55	2020-08-01	14	[{"id_menu":2,"count":1}]	41636	delivery	5	19
107737	2020-08-01 00:18:59	2020-08-01	12	[{"id_menu":3,"count":1}]	41517	pick-up	0	12
107738	2020-08-01 00:21:24	2020-08-01	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	19358	delivery	5	38
107739	2020-08-01 00:25:23	2020-08-01	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	33750	delivery	5	40
107740	2020-08-01 00:28:16	2020-08-01	9	[{"id_menu":7,"count":1}]	33135	delivery	5	14
107741	2020-08-01 00:28:56	2020-08-01	14	[{"id_menu":2,"count":1}]	18348	pick-up	0	14
107742	2020-08-01 00:30:58	2020-08-01	9	[{"id_menu":6,"count":1}]	41541	delivery	5	14
107743	2020-08-01 00:33:14	2020-08-01	9	[{"id_menu":7,"count":1}]	22260	delivery	5	14
107744	2020-08-01 00:36:09	2020-08-01	9	[{"id_menu":7,"count":2}]	18192	delivery	5	14
107745	2020-08-01 00:36:40	2020-08-01	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	41667	delivery	5	34
107746	2020-08-01 00:43:37	2020-08-01	9	[{"id_menu":6,"count":1}]	12780	delivery	5	14
107747	2020-08-01 00:45:40	2020-08-01	12	[{"id_menu":3,"count":1}]	41639	delivery	5	17
107748	2020-08-01 00:46:28	2020-08-01	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	31117	delivery	5	35
107749	2020-08-01 00:47:56	2020-08-01	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	5447	pick-up	0	18
107750	2020-08-01 00:55:55	2020-08-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	41672	delivery	5	36
107751	2020-08-01 00:57:22	2020-08-01	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	41508	delivery	5	45
107752	2020-08-01 00:58:49	2020-08-01	8	[{"id_menu":5,"count":1}]	401	pick-up	0	8
107753	2020-08-01 00:59:10	2020-08-01	12	[{"id_menu":3,"count":2}]	41641	delivery	5	17
107754	2020-08-01 01:00:09	2020-08-01	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8065	pick-up	0	37
107755	2020-08-01 01:02:24	2020-08-01	12	[{"id_menu":1,"count":1}]	23567	pick-up	0	12
107756	2020-08-01 01:04:24	2020-08-01	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	6308	delivery	5	26
107757	2020-08-01 01:04:25	2020-08-01	24	[{"id_menu":1,"count":3},{"id_menu":3,"count":1}]	17934	delivery	5	29
107758	2020-08-01 01:07:04	2020-08-01	9	[{"id_menu":7,"count":1}]	41671	delivery	5	14
107759	2020-08-01 01:10:53	2020-08-01	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	39006	delivery	5	25
107760	2020-08-01 01:11:54	2020-08-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31981	delivery	5	22
107761	2020-08-01 01:13:04	2020-08-01	9	[{"id_menu":7,"count":1}]	6820	delivery	5	14
107762	2020-08-01 01:14:44	2020-08-01	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	41568	delivery	5	26
107763	2020-08-01 01:15:40	2020-08-01	9	[{"id_menu":7,"count":1}]	41603	delivery	5	14
107764	2020-08-01 01:17:23	2020-08-01	14	[{"id_menu":2,"count":1}]	40625	delivery	5	19
107765	2020-08-01 01:20:51	2020-08-01	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":2}]	24082	pick-up	0	29
107766	2020-08-01 01:22:36	2020-08-01	9	[{"id_menu":7,"count":1}]	16096	delivery	5	14
107767	2020-08-01 01:23:24	2020-08-01	12	[{"id_menu":1,"count":1}]	4869	pick-up	0	12
107768	2020-08-01 01:30:16	2020-08-01	9	[{"id_menu":7,"count":1}]	12700	delivery	5	14
107769	2020-08-01 01:32:02	2020-08-01	14	[{"id_menu":2,"count":1}]	3385	pick-up	0	14
107770	2020-08-01 01:33:05	2020-08-01	9	[{"id_menu":7,"count":2}]	23939	pick-up	0	9
107771	2020-08-01 01:33:53	2020-08-01	12	[{"id_menu":1,"count":1}]	37271	delivery	5	17
107772	2020-08-01 01:34:48	2020-08-01	39	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7122	delivery	5	44
107773	2020-08-01 01:35:59	2020-08-01	8	[{"id_menu":5,"count":1}]	21805	delivery	5	13
107774	2020-08-01 01:36:59	2020-08-01	12	[{"id_menu":3,"count":1}]	41663	pick-up	0	12
107775	2020-08-01 01:37:56	2020-08-01	9	[{"id_menu":6,"count":1}]	41525	delivery	5	14
107776	2020-08-01 01:37:59	2020-08-01	8	[{"id_menu":5,"count":1}]	14463	delivery	5	13
107777	2020-08-01 01:38:03	2020-08-01	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	35581	delivery	5	40
107778	2020-08-01 01:39:27	2020-08-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	17620	delivery	5	36
107779	2020-08-01 01:42:05	2020-08-01	9	[{"id_menu":6,"count":1}]	41681	pick-up	0	9
107780	2020-08-01 01:46:05	2020-08-01	29	[{"id_menu":3,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	26383	delivery	5	34
107781	2020-08-01 01:47:33	2020-08-01	9	[{"id_menu":6,"count":1}]	41555	delivery	5	14
107782	2020-08-01 01:47:44	2020-08-01	9	[{"id_menu":7,"count":1}]	4589	delivery	5	14
107783	2020-08-01 01:48:08	2020-08-01	8	[{"id_menu":5,"count":1}]	8951	delivery	5	13
107784	2020-08-01 01:51:32	2020-08-01	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	26163	delivery	5	26
107785	2020-08-01 01:52:36	2020-08-01	17	[{"id_menu":4,"count":1}]	5409	pick-up	0	17
107786	2020-08-01 01:53:17	2020-08-01	12	[{"id_menu":1,"count":1}]	41654	delivery	5	17
107787	2020-08-01 01:58:06	2020-08-01	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	36632	delivery	5	23
107788	2020-08-01 01:58:49	2020-08-01	9	[{"id_menu":6,"count":1}]	19129	delivery	5	14
107789	2020-08-01 01:58:51	2020-08-01	9	[{"id_menu":6,"count":1}]	34437	delivery	5	14
107790	2020-08-01 02:06:27	2020-08-01	12	[{"id_menu":3,"count":1}]	25964	pick-up	0	12
107791	2020-08-01 02:06:27	2020-08-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	17308	delivery	5	23
107792	2020-08-01 02:07:16	2020-08-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5515	delivery	5	28
107793	2020-08-01 02:09:52	2020-08-01	9	[{"id_menu":6,"count":1}]	14711	delivery	5	14
107794	2020-08-01 02:11:17	2020-08-01	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	33261	delivery	5	40
107795	2020-08-01 02:12:01	2020-08-01	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2668	pick-up	0	22
107796	2020-08-01 02:13:22	2020-08-01	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	28411	delivery	5	29
107797	2020-08-01 02:13:49	2020-08-01	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	41557	delivery	5	31
107798	2020-08-01 02:21:08	2020-08-01	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11202	delivery	5	51
107799	2020-08-01 02:23:30	2020-08-01	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	2780	delivery	5	26
107800	2020-08-01 02:24:21	2020-08-01	8	[{"id_menu":5,"count":1}]	7189	pick-up	0	8
107801	2020-08-01 02:24:26	2020-08-01	49	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	41704	delivery	5	54
107802	2020-08-01 02:25:20	2020-08-01	14	[{"id_menu":2,"count":1}]	1924	delivery	5	19
107803	2020-08-01 02:26:51	2020-08-01	12	[{"id_menu":3,"count":1}]	41610	delivery	5	17
107804	2020-08-01 02:27:11	2020-08-01	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20377	delivery	5	31
107805	2020-08-01 02:28:42	2020-08-01	14	[{"id_menu":2,"count":1}]	41660	delivery	5	19
107806	2020-08-01 02:31:52	2020-08-01	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	41616	pick-up	0	38
107807	2020-08-01 02:35:00	2020-08-01	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	19637	pick-up	0	26
107808	2020-08-01 02:35:19	2020-08-01	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	27938	delivery	5	39
107809	2020-08-01 02:36:02	2020-08-01	8	[{"id_menu":5,"count":1}]	41487	delivery	5	13
107810	2020-08-01 02:38:54	2020-08-01	14	[{"id_menu":2,"count":1}]	19868	pick-up	0	14
107811	2020-08-01 02:39:46	2020-08-01	8	[{"id_menu":5,"count":1}]	41690	pick-up	0	8
107812	2020-08-01 02:46:08	2020-08-01	9	[{"id_menu":7,"count":1}]	41661	delivery	5	14
107813	2020-08-01 02:47:07	2020-08-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	25190	pick-up	0	23
107814	2020-08-01 02:53:02	2020-08-01	9	[{"id_menu":7,"count":1}]	41706	pick-up	0	9
107815	2020-08-01 02:57:08	2020-08-01	9	[{"id_menu":6,"count":1}]	34795	pick-up	0	9
107816	2020-08-01 03:00:26	2020-08-01	12	[{"id_menu":1,"count":1}]	30480	delivery	5	17
107817	2020-08-01 03:00:45	2020-08-01	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	13968	delivery	5	43
107818	2020-08-01 03:02:25	2020-08-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1549	pick-up	0	26
107819	2020-08-01 03:05:39	2020-08-01	9	[{"id_menu":7,"count":1}]	41631	delivery	5	14
107820	2020-08-01 03:10:01	2020-08-01	8	[{"id_menu":5,"count":1}]	1592	delivery	5	13
107821	2020-08-01 03:12:19	2020-08-01	9	[{"id_menu":7,"count":1}]	33489	delivery	5	14
107822	2020-08-01 03:12:32	2020-08-01	8	[{"id_menu":5,"count":1}]	41561	delivery	5	13
107823	2020-08-01 03:13:01	2020-08-01	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39024	delivery	5	53
107824	2020-08-01 03:16:05	2020-08-01	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	38469	pick-up	0	21
107825	2020-08-01 03:16:39	2020-08-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	25788	delivery	5	26
107826	2020-08-01 03:18:22	2020-08-01	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	37013	delivery	5	27
107827	2020-08-01 03:18:28	2020-08-01	9	[{"id_menu":6,"count":1}]	257	pick-up	0	9
107828	2020-08-01 03:18:54	2020-08-01	12	[{"id_menu":3,"count":1}]	29623	delivery	5	17
107829	2020-08-01 03:20:37	2020-08-01	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	20330	pick-up	0	21
107830	2020-08-01 03:21:57	2020-08-01	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7338	delivery	5	36
107831	2020-08-01 03:22:10	2020-08-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18390	delivery	5	22
107832	2020-08-01 03:24:00	2020-08-01	9	[{"id_menu":6,"count":1}]	8251	delivery	5	14
107833	2020-08-01 03:30:07	2020-08-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	18386	delivery	5	28
107834	2020-08-01 03:30:43	2020-08-01	12	[{"id_menu":1,"count":1}]	16914	pick-up	0	12
107835	2020-08-01 03:33:39	2020-08-01	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	11438	delivery	5	40
107836	2020-08-01 03:35:07	2020-08-01	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	32288	delivery	5	39
107837	2020-08-01 03:36:47	2020-08-01	12	[{"id_menu":1,"count":1}]	30591	pick-up	0	12
107838	2020-08-01 03:39:23	2020-08-01	17	[{"id_menu":5,"count":3},{"id_menu":6,"count":1}]	41559	delivery	5	22
107839	2020-08-01 03:41:38	2020-08-01	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	39095	delivery	5	34
107840	2020-08-01 03:42:24	2020-08-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	34682	delivery	5	22
107841	2020-08-01 03:44:07	2020-08-01	12	[{"id_menu":3,"count":1}]	7603	pick-up	0	12
107842	2020-08-01 03:44:48	2020-08-01	8	[{"id_menu":5,"count":1}]	3153	pick-up	0	8
107843	2020-08-01 03:46:40	2020-08-01	8	[{"id_menu":5,"count":1}]	11407	delivery	5	13
107844	2020-08-01 03:47:15	2020-08-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	41574	delivery	5	28
107845	2020-08-01 03:48:00	2020-08-01	9	[{"id_menu":7,"count":1}]	12705	delivery	5	14
107846	2020-08-01 03:53:29	2020-08-01	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	41585	delivery	5	25
107847	2020-08-01 03:55:27	2020-08-01	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18530	pick-up	0	29
107848	2020-08-01 04:04:54	2020-08-01	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	37097	pick-up	0	25
107849	2020-08-01 04:06:15	2020-08-01	17	[{"id_menu":4,"count":1}]	38854	delivery	5	22
107850	2020-08-01 04:08:05	2020-08-01	9	[{"id_menu":7,"count":1}]	41545	delivery	5	14
107851	2020-08-01 04:09:34	2020-08-01	12	[{"id_menu":1,"count":1}]	41674	delivery	5	17
107852	2020-08-01 04:14:45	2020-08-01	12	[{"id_menu":3,"count":1}]	9565	delivery	5	17
107853	2020-08-01 04:19:24	2020-08-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	21600	pick-up	0	31
107854	2020-08-01 04:19:27	2020-08-01	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":3}]	1517	pick-up	0	26
107855	2020-08-01 04:19:35	2020-08-01	17	[{"id_menu":4,"count":1}]	13994	delivery	5	22
107856	2020-08-01 04:20:55	2020-08-01	9	[{"id_menu":6,"count":1}]	41527	delivery	5	14
107857	2020-08-01 04:23:04	2020-08-01	14	[{"id_menu":2,"count":1}]	8239	delivery	5	19
107858	2020-08-01 04:24:00	2020-08-01	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41514	delivery	5	37
107859	2020-08-01 04:25:19	2020-08-01	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39825	delivery	5	36
107860	2020-08-01 04:28:25	2020-08-01	9	[{"id_menu":6,"count":1}]	41653	delivery	5	14
107861	2020-08-01 04:29:46	2020-08-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5512	delivery	5	22
107862	2020-08-01 04:32:36	2020-08-01	14	[{"id_menu":2,"count":1}]	41578	delivery	5	19
107863	2020-08-01 04:34:41	2020-08-01	9	[{"id_menu":7,"count":1}]	41562	delivery	5	14
107864	2020-08-01 04:35:21	2020-08-01	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	20646	delivery	5	26
107865	2020-08-01 04:38:07	2020-08-01	12	[{"id_menu":1,"count":1}]	41658	delivery	5	17
107866	2020-08-01 04:38:27	2020-08-01	17	[{"id_menu":4,"count":1}]	20442	delivery	5	22
107867	2020-08-01 04:40:45	2020-08-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6173	delivery	5	28
107868	2020-08-01 04:41:01	2020-08-01	8	[{"id_menu":5,"count":1}]	18049	pick-up	0	8
107869	2020-08-01 04:41:10	2020-08-01	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	9295	pick-up	0	40
107870	2020-08-01 04:48:30	2020-08-01	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	31172	delivery	5	27
107871	2020-08-01 04:48:31	2020-08-01	17	[{"id_menu":4,"count":1}]	13391	delivery	5	22
107872	2020-08-01 04:50:49	2020-08-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":3}]	24594	delivery	5	26
107873	2020-08-01 04:52:03	2020-08-01	9	[{"id_menu":6,"count":1}]	20957	delivery	5	14
107874	2020-08-01 04:52:55	2020-08-01	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	39357	delivery	5	30
107875	2020-08-01 04:54:54	2020-08-01	8	[{"id_menu":5,"count":1}]	13940	pick-up	0	8
107876	2020-08-01 05:01:31	2020-08-01	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	24395	delivery	5	31
107877	2020-08-01 05:04:57	2020-08-01	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	38673	delivery	5	23
107878	2020-08-01 05:05:43	2020-08-01	17	[{"id_menu":4,"count":1}]	17009	delivery	5	22
107879	2020-08-01 05:06:24	2020-08-01	12	[{"id_menu":1,"count":1}]	10283	pick-up	0	12
107880	2020-08-01 05:08:11	2020-08-01	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	41532	delivery	5	26
107881	2020-08-01 05:12:04	2020-08-01	8	[{"id_menu":5,"count":2}]	28947	delivery	5	13
107882	2020-08-01 05:12:56	2020-08-01	9	[{"id_menu":7,"count":1}]	22614	delivery	5	14
107883	2020-08-01 05:13:02	2020-08-01	12	[{"id_menu":1,"count":1}]	2370	pick-up	0	12
107884	2020-08-01 05:19:24	2020-08-01	17	[{"id_menu":4,"count":1}]	11604	delivery	5	22
107885	2020-08-01 05:22:29	2020-08-01	9	[{"id_menu":7,"count":1}]	36303	delivery	5	14
107886	2020-08-01 05:22:47	2020-08-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29777	delivery	5	23
107887	2020-08-01 05:24:01	2020-08-01	14	[{"id_menu":2,"count":1}]	18643	pick-up	0	14
107888	2020-08-01 05:27:52	2020-08-01	9	[{"id_menu":7,"count":1}]	41570	delivery	5	14
107889	2020-08-01 05:29:18	2020-08-01	12	[{"id_menu":1,"count":1}]	34676	delivery	5	17
107890	2020-08-01 05:29:38	2020-08-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3052	delivery	5	28
107891	2020-08-01 05:30:05	2020-08-01	8	[{"id_menu":5,"count":1}]	37774	delivery	5	13
107892	2020-08-01 05:36:46	2020-08-01	9	[{"id_menu":7,"count":1}]	1875	delivery	5	14
107893	2020-08-01 05:36:49	2020-08-01	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41668	delivery	5	31
107894	2020-08-01 05:41:36	2020-08-01	9	[{"id_menu":6,"count":1}]	20021	pick-up	0	9
107895	2020-08-01 05:43:53	2020-08-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32144	delivery	5	23
107896	2020-08-01 05:44:40	2020-08-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	41556	delivery	5	26
107897	2020-08-01 05:48:49	2020-08-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	21507	delivery	5	31
107898	2020-08-01 05:49:17	2020-08-01	14	[{"id_menu":2,"count":1}]	24684	pick-up	0	14
107899	2020-08-01 05:49:52	2020-08-01	17	[{"id_menu":4,"count":1}]	41538	delivery	5	22
107900	2020-08-01 05:51:23	2020-08-01	14	[{"id_menu":2,"count":1}]	29276	delivery	5	19
107901	2020-08-01 05:55:53	2020-08-01	12	[{"id_menu":3,"count":1}]	489	pick-up	0	12
107902	2020-08-01 05:58:19	2020-08-01	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8729	delivery	5	51
107903	2020-08-01 05:58:20	2020-08-01	12	[{"id_menu":1,"count":1}]	31442	pick-up	0	12
107904	2020-08-01 06:00:29	2020-08-01	12	[{"id_menu":1,"count":1}]	35494	delivery	5	17
107905	2020-08-01 06:02:21	2020-08-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	41621	pick-up	0	31
107906	2020-08-01 06:03:34	2020-08-01	9	[{"id_menu":6,"count":1}]	40944	delivery	5	14
107907	2020-08-01 06:04:29	2020-08-01	14	[{"id_menu":2,"count":1}]	19374	delivery	5	19
107908	2020-08-01 06:05:37	2020-08-01	9	[{"id_menu":6,"count":1}]	39359	delivery	5	14
107909	2020-08-01 06:10:50	2020-08-01	12	[{"id_menu":1,"count":1}]	5371	delivery	5	17
107910	2020-08-01 06:13:19	2020-08-01	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10527	delivery	5	37
107911	2020-08-01 06:16:59	2020-08-01	12	[{"id_menu":3,"count":1}]	41664	delivery	5	17
107912	2020-08-01 06:17:42	2020-08-01	9	[{"id_menu":6,"count":1}]	41597	delivery	5	14
107913	2020-08-01 06:21:43	2020-08-01	9	[{"id_menu":6,"count":1}]	41613	delivery	5	14
107914	2020-08-01 06:22:42	2020-08-01	14	[{"id_menu":2,"count":1}]	29879	delivery	5	19
107915	2020-08-01 06:25:09	2020-08-01	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1591	delivery	5	31
107916	2020-08-01 06:28:22	2020-08-01	14	[{"id_menu":2,"count":1}]	26252	pick-up	0	14
107917	2020-08-01 06:30:03	2020-08-01	12	[{"id_menu":1,"count":1}]	28964	delivery	5	17
107918	2020-08-01 06:30:45	2020-08-01	12	[{"id_menu":1,"count":1}]	2413	delivery	5	17
107919	2020-08-01 06:32:51	2020-08-01	9	[{"id_menu":6,"count":1}]	7888	delivery	5	14
107920	2020-08-01 06:34:12	2020-08-01	8	[{"id_menu":5,"count":1}]	41584	delivery	5	13
107921	2020-08-01 06:37:38	2020-08-01	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	41620	delivery	5	26
107922	2020-08-01 06:38:21	2020-08-01	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	4992	pick-up	0	26
107923	2020-08-01 06:38:55	2020-08-01	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	41601	delivery	5	34
107924	2020-08-01 06:39:19	2020-08-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	41680	delivery	5	31
107925	2020-08-01 06:39:37	2020-08-01	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	29844	delivery	5	40
107926	2020-08-01 06:40:07	2020-08-01	9	[{"id_menu":7,"count":1}]	7934	pick-up	0	9
107927	2020-08-01 06:42:44	2020-08-01	12	[{"id_menu":3,"count":1}]	18538	delivery	5	17
107928	2020-08-01 06:44:23	2020-08-01	9	[{"id_menu":7,"count":1}]	38004	pick-up	0	9
107929	2020-08-01 06:45:15	2020-08-01	8	[{"id_menu":5,"count":1}]	31760	delivery	5	13
107930	2020-08-01 06:46:05	2020-08-01	9	[{"id_menu":6,"count":1}]	28679	delivery	5	14
107931	2020-08-01 06:46:15	2020-08-01	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3949	pick-up	0	35
107932	2020-08-01 06:49:22	2020-08-01	14	[{"id_menu":2,"count":1}]	41571	pick-up	0	14
107933	2020-08-01 06:53:28	2020-08-01	17	[{"id_menu":4,"count":1}]	1727	pick-up	0	17
107934	2020-08-01 06:54:39	2020-08-01	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	8229	pick-up	0	23
107935	2020-08-01 06:54:51	2020-08-01	14	[{"id_menu":2,"count":1}]	799	delivery	5	19
107936	2020-08-01 06:55:51	2020-08-01	12	[{"id_menu":1,"count":1}]	113	pick-up	0	12
107937	2020-08-01 06:59:04	2020-08-01	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	41662	delivery	5	30
107938	2020-08-01 06:59:45	2020-08-01	9	[{"id_menu":7,"count":1}]	41647	delivery	5	14
107939	2020-08-01 07:03:20	2020-08-01	9	[{"id_menu":7,"count":1}]	31542	delivery	5	14
107940	2020-08-01 07:05:16	2020-08-01	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8860	pick-up	0	26
107941	2020-08-01 07:05:23	2020-08-01	14	[{"id_menu":2,"count":1}]	41536	delivery	5	19
107942	2020-08-01 07:05:46	2020-08-01	9	[{"id_menu":7,"count":1}]	8747	delivery	5	14
107943	2020-08-01 07:07:24	2020-08-01	17	[{"id_menu":4,"count":2}]	3611	delivery	5	22
107944	2020-08-01 07:09:24	2020-08-01	17	[{"id_menu":4,"count":1}]	863	delivery	5	22
107945	2020-08-01 07:12:58	2020-08-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38897	pick-up	0	18
107946	2020-08-01 07:13:05	2020-08-01	14	[{"id_menu":2,"count":1}]	41707	pick-up	0	14
107947	2020-08-01 07:16:12	2020-08-01	12	[{"id_menu":3,"count":1}]	24621	delivery	5	17
107948	2020-08-01 07:16:38	2020-08-01	17	[{"id_menu":4,"count":1}]	41711	pick-up	0	17
107949	2020-08-01 07:20:12	2020-08-01	12	[{"id_menu":1,"count":1}]	41534	delivery	5	17
107950	2020-08-01 07:21:49	2020-08-01	17	[{"id_menu":4,"count":1}]	32533	delivery	5	22
107951	2020-08-01 07:23:29	2020-08-01	12	[{"id_menu":3,"count":1}]	35579	delivery	5	17
107952	2020-08-01 07:24:02	2020-08-01	17	[{"id_menu":4,"count":1}]	5346	delivery	5	22
107953	2020-08-01 07:26:42	2020-08-01	9	[{"id_menu":7,"count":1}]	13643	pick-up	0	9
107954	2020-08-01 07:27:49	2020-08-01	22	[{"id_menu":2,"count":3},{"id_menu":5,"count":1}]	31056	pick-up	0	22
107955	2020-08-01 07:28:04	2020-08-01	17	[{"id_menu":4,"count":1}]	15662	pick-up	0	17
107956	2020-08-01 07:29:31	2020-08-01	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	41594	delivery	5	31
107957	2020-08-01 07:32:31	2020-08-01	17	[{"id_menu":4,"count":1}]	37456	delivery	5	22
107958	2020-08-01 07:34:15	2020-08-01	17	[{"id_menu":4,"count":1}]	34312	delivery	5	22
107959	2020-08-01 07:34:50	2020-08-01	14	[{"id_menu":2,"count":1}]	1713	pick-up	0	14
107960	2020-08-01 07:38:40	2020-08-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	11961	delivery	5	23
107961	2020-08-01 07:38:42	2020-08-01	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	4142	delivery	5	43
107962	2020-08-01 07:41:25	2020-08-01	9	[{"id_menu":7,"count":1}]	15563	delivery	5	14
107963	2020-08-01 07:42:15	2020-08-01	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	41523	delivery	5	31
107964	2020-08-01 07:44:43	2020-08-01	12	[{"id_menu":3,"count":1}]	19929	delivery	5	17
107965	2020-08-01 07:47:54	2020-08-01	9	[{"id_menu":7,"count":1}]	36870	delivery	5	14
107966	2020-08-01 07:49:53	2020-08-01	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	13928	delivery	5	44
107967	2020-08-01 07:52:52	2020-08-01	14	[{"id_menu":2,"count":1}]	1126	pick-up	0	14
107968	2020-08-01 07:55:48	2020-08-01	9	[{"id_menu":7,"count":1}]	41700	pick-up	0	9
107969	2020-08-01 07:56:02	2020-08-01	9	[{"id_menu":6,"count":1}]	31724	delivery	5	14
107970	2020-08-01 07:56:20	2020-08-01	12	[{"id_menu":1,"count":2}]	28916	delivery	5	17
107971	2020-08-01 08:00:27	2020-08-01	8	[{"id_menu":5,"count":1}]	11009	delivery	5	13
107972	2020-08-01 08:00:41	2020-08-01	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	35806	delivery	5	26
107973	2020-08-01 08:01:42	2020-08-01	9	[{"id_menu":6,"count":1}]	21961	pick-up	0	9
107974	2020-08-01 08:02:47	2020-08-01	12	[{"id_menu":3,"count":1}]	5665	pick-up	0	12
107975	2020-08-01 08:03:10	2020-08-01	17	[{"id_menu":4,"count":1}]	41510	delivery	5	22
107976	2020-08-01 08:03:53	2020-08-01	9	[{"id_menu":6,"count":1}]	20891	delivery	5	14
107977	2020-08-01 08:05:02	2020-08-01	17	[{"id_menu":4,"count":2}]	24006	delivery	5	22
107978	2020-08-01 08:05:23	2020-08-01	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	39891	delivery	5	43
107979	2020-08-01 08:08:00	2020-08-01	9	[{"id_menu":7,"count":1}]	29945	delivery	5	14
107980	2020-08-01 08:09:51	2020-08-01	12	[{"id_menu":3,"count":1}]	8454	pick-up	0	12
107981	2020-08-01 08:13:00	2020-08-01	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21760	delivery	5	36
107982	2020-08-01 08:13:24	2020-08-01	14	[{"id_menu":2,"count":1}]	40321	pick-up	0	14
107983	2020-08-01 08:14:21	2020-08-01	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	22364	delivery	5	43
107984	2020-08-01 08:15:25	2020-08-01	17	[{"id_menu":4,"count":1}]	5402	pick-up	0	17
107985	2020-08-01 08:18:13	2020-08-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":3}]	25722	delivery	5	26
107986	2020-08-01 08:18:34	2020-08-01	9	[{"id_menu":6,"count":1}]	39670	delivery	5	14
107987	2020-08-01 08:18:42	2020-08-01	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	41685	delivery	5	34
107988	2020-08-01 08:19:07	2020-08-01	8	[{"id_menu":5,"count":1}]	11642	delivery	5	13
107989	2020-08-01 08:20:26	2020-08-01	9	[{"id_menu":6,"count":1}]	22643	pick-up	0	9
107990	2020-08-01 08:21:34	2020-08-01	14	[{"id_menu":2,"count":1}]	34106	pick-up	0	14
107991	2020-08-01 08:23:07	2020-08-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6007	delivery	5	36
107992	2020-08-01 08:24:55	2020-08-01	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7809	delivery	5	30
107993	2020-08-01 08:26:21	2020-08-01	8	[{"id_menu":5,"count":1}]	41666	delivery	5	13
107994	2020-08-01 08:26:52	2020-08-01	9	[{"id_menu":6,"count":1}]	36162	delivery	5	14
107995	2020-08-01 08:28:15	2020-08-01	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	39527	delivery	5	45
107996	2020-08-01 08:29:34	2020-08-01	14	[{"id_menu":2,"count":1}]	5090	pick-up	0	14
107997	2020-08-01 08:31:15	2020-08-01	14	[{"id_menu":2,"count":1}]	29862	delivery	5	19
107998	2020-08-01 08:31:19	2020-08-01	12	[{"id_menu":1,"count":1}]	9449	delivery	5	17
107999	2020-08-01 08:31:55	2020-08-01	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	37213	delivery	5	40
108000	2020-08-01 08:35:01	2020-08-01	9	[{"id_menu":6,"count":1}]	4463	pick-up	0	9
108001	2020-08-01 08:37:02	2020-08-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	41665	delivery	5	28
108002	2020-08-01 08:37:14	2020-08-01	9	[{"id_menu":7,"count":1}]	9155	delivery	5	14
108003	2020-08-01 08:38:19	2020-08-01	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	41581	delivery	5	28
108004	2020-08-01 08:39:47	2020-08-01	12	[{"id_menu":1,"count":1}]	38245	pick-up	0	12
108005	2020-08-01 08:40:02	2020-08-01	8	[{"id_menu":5,"count":1}]	38209	delivery	5	13
108006	2020-08-01 08:40:13	2020-08-01	14	[{"id_menu":2,"count":1}]	1754	pick-up	0	14
108007	2020-08-01 08:47:47	2020-08-01	14	[{"id_menu":2,"count":1}]	39719	pick-up	0	14
108008	2020-08-01 08:50:11	2020-08-01	8	[{"id_menu":5,"count":1}]	9994	delivery	5	13
108009	2020-08-01 08:53:06	2020-08-01	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	18491	delivery	5	31
108010	2020-08-01 08:54:58	2020-08-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1814	delivery	5	22
108011	2020-08-01 08:59:26	2020-08-01	8	[{"id_menu":5,"count":1}]	37948	delivery	5	13
108012	2020-08-01 09:00:40	2020-08-01	17	[{"id_menu":4,"count":1}]	2529	delivery	5	22
108013	2020-08-01 09:02:25	2020-08-01	17	[{"id_menu":4,"count":1}]	19711	pick-up	0	17
108014	2020-08-01 09:02:37	2020-08-01	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	41626	pick-up	0	20
108015	2020-08-01 09:04:45	2020-08-01	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	41526	delivery	5	34
108016	2020-08-01 09:06:00	2020-08-01	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	17502	pick-up	0	26
108017	2020-08-01 09:08:14	2020-08-01	9	[{"id_menu":7,"count":1}]	11146	pick-up	0	9
108018	2020-08-01 09:08:15	2020-08-01	9	[{"id_menu":6,"count":1}]	33933	delivery	5	14
108019	2020-08-01 09:09:07	2020-08-01	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	15653	pick-up	0	26
108020	2020-08-01 09:09:38	2020-08-01	9	[{"id_menu":7,"count":1}]	23350	delivery	5	14
108021	2020-08-01 09:11:41	2020-08-01	9	[{"id_menu":6,"count":1}]	40426	delivery	5	14
108022	2020-08-01 09:12:30	2020-08-01	9	[{"id_menu":7,"count":1}]	34766	delivery	5	14
108023	2020-08-01 09:13:08	2020-08-01	9	[{"id_menu":7,"count":1}]	24325	pick-up	0	9
108024	2020-08-01 09:13:56	2020-08-01	8	[{"id_menu":5,"count":1}]	38196	delivery	5	13
108025	2020-08-01 09:16:09	2020-08-01	9	[{"id_menu":7,"count":1}]	39442	pick-up	0	9
108026	2020-08-01 09:18:18	2020-08-01	17	[{"id_menu":4,"count":1}]	20736	delivery	5	22
108027	2020-08-01 09:19:10	2020-08-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	28074	pick-up	0	26
108028	2020-08-01 09:22:35	2020-08-01	9	[{"id_menu":7,"count":1}]	34618	delivery	5	14
108029	2020-08-01 09:23:20	2020-08-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	32912	delivery	5	28
108030	2020-08-01 09:25:13	2020-08-01	9	[{"id_menu":6,"count":1}]	30569	delivery	5	14
108031	2020-08-01 09:25:18	2020-08-01	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	13141	delivery	5	25
108032	2020-08-01 09:26:20	2020-08-01	12	[{"id_menu":1,"count":1}]	28913	delivery	5	17
108033	2020-08-01 09:36:26	2020-08-01	9	[{"id_menu":7,"count":1}]	3389	pick-up	0	9
108034	2020-08-01 09:37:58	2020-08-01	8	[{"id_menu":5,"count":1}]	13668	delivery	5	13
108035	2020-08-01 09:39:19	2020-08-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	17329	delivery	5	28
108036	2020-08-01 09:39:27	2020-08-01	17	[{"id_menu":4,"count":1}]	26618	pick-up	0	17
108037	2020-08-01 09:42:43	2020-08-01	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	32060	delivery	5	39
108038	2020-08-01 09:43:05	2020-08-01	12	[{"id_menu":1,"count":1}]	30526	delivery	5	17
108039	2020-08-01 09:43:19	2020-08-01	9	[{"id_menu":6,"count":1}]	41677	delivery	5	14
108040	2020-08-01 09:44:57	2020-08-01	12	[{"id_menu":3,"count":1}]	41692	delivery	5	17
108041	2020-08-01 09:47:26	2020-08-01	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14237	delivery	5	31
108042	2020-08-01 09:54:22	2020-08-01	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":3}]	5889	delivery	5	34
108043	2020-08-01 10:04:39	2020-08-01	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	12397	delivery	5	43
108044	2020-08-01 10:04:55	2020-08-01	9	[{"id_menu":7,"count":1}]	6800	delivery	5	14
108045	2020-08-01 10:06:37	2020-08-01	9	[{"id_menu":7,"count":2}]	37852	delivery	5	14
108046	2020-08-01 10:08:36	2020-08-01	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":2}]	30384	delivery	5	28
108047	2020-08-01 10:12:21	2020-08-01	9	[{"id_menu":6,"count":1}]	30391	pick-up	0	9
108048	2020-08-01 10:14:04	2020-08-01	12	[{"id_menu":3,"count":1}]	28116	delivery	5	17
108049	2020-08-01 10:16:11	2020-08-01	12	[{"id_menu":1,"count":1}]	2054	pick-up	0	12
108050	2020-08-01 10:17:33	2020-08-01	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	41696	delivery	5	37
108051	2020-08-01 10:17:58	2020-08-01	14	[{"id_menu":2,"count":1}]	1693	pick-up	0	14
108052	2020-08-01 10:18:30	2020-08-01	14	[{"id_menu":2,"count":1}]	41691	delivery	5	19
108053	2020-08-01 10:18:32	2020-08-01	9	[{"id_menu":6,"count":1}]	27793	pick-up	0	9
108054	2020-08-01 10:22:36	2020-08-01	12	[{"id_menu":3,"count":1}]	25885	pick-up	0	12
108055	2020-08-01 10:22:41	2020-08-01	17	[{"id_menu":4,"count":1}]	35722	delivery	5	22
108056	2020-08-01 10:23:08	2020-08-01	8	[{"id_menu":5,"count":1}]	41531	delivery	5	13
108057	2020-08-01 10:23:17	2020-08-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21855	delivery	5	22
108058	2020-08-01 10:23:42	2020-08-01	12	[{"id_menu":1,"count":1}]	41670	delivery	5	17
108059	2020-08-01 10:26:40	2020-08-01	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	27544	delivery	5	26
108060	2020-08-01 10:28:56	2020-08-01	14	[{"id_menu":2,"count":1}]	38486	delivery	5	19
108061	2020-08-01 10:30:07	2020-08-01	9	[{"id_menu":6,"count":1}]	41652	delivery	5	14
108062	2020-08-01 10:30:32	2020-08-01	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	17808	delivery	5	30
108063	2020-08-01 10:32:25	2020-08-01	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	270	delivery	5	31
108064	2020-08-01 10:33:25	2020-08-01	12	[{"id_menu":1,"count":1}]	24943	pick-up	0	12
108065	2020-08-01 10:37:19	2020-08-01	9	[{"id_menu":6,"count":1}]	19657	delivery	5	14
108066	2020-08-01 10:47:12	2020-08-01	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	28553	delivery	5	29
108067	2020-08-01 10:47:54	2020-08-01	9	[{"id_menu":6,"count":1}]	5961	pick-up	0	9
108068	2020-08-01 10:49:23	2020-08-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	32067	pick-up	0	31
108069	2020-08-01 10:55:21	2020-08-01	9	[{"id_menu":6,"count":1}]	27000	delivery	5	14
108070	2020-08-01 10:55:30	2020-08-01	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	23698	delivery	5	23
108071	2020-08-01 10:57:50	2020-08-01	9	[{"id_menu":6,"count":1}]	23933	delivery	5	14
108072	2020-08-01 10:59:17	2020-08-01	9	[{"id_menu":6,"count":1}]	2563	delivery	5	14
108073	2020-08-01 11:08:13	2020-08-01	17	[{"id_menu":4,"count":1}]	41633	pick-up	0	17
108074	2020-08-01 11:10:43	2020-08-01	9	[{"id_menu":6,"count":1}]	3069	pick-up	0	9
108075	2020-08-01 11:12:30	2020-08-01	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	41619	delivery	5	31
108076	2020-08-01 11:17:49	2020-08-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	11998	delivery	5	26
108077	2020-08-01 11:18:46	2020-08-01	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	8365	delivery	5	31
108078	2020-08-01 11:18:54	2020-08-01	14	[{"id_menu":2,"count":1}]	806	pick-up	0	14
108079	2020-08-01 11:19:00	2020-08-01	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	41549	delivery	5	34
108080	2020-08-01 11:19:02	2020-08-01	9	[{"id_menu":6,"count":1}]	36813	delivery	5	14
108081	2020-08-01 11:20:30	2020-08-01	8	[{"id_menu":5,"count":1}]	36918	delivery	5	13
108082	2020-08-01 11:21:38	2020-08-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	34507	delivery	5	22
108083	2020-08-01 11:22:19	2020-08-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	7387	delivery	5	28
108084	2020-08-01 11:23:18	2020-08-01	14	[{"id_menu":2,"count":1}]	9907	pick-up	0	14
108085	2020-08-01 11:24:01	2020-08-01	9	[{"id_menu":6,"count":1}]	41580	delivery	5	14
108086	2020-08-01 11:26:18	2020-08-01	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9003	delivery	5	36
108087	2020-08-01 11:28:53	2020-08-01	12	[{"id_menu":1,"count":1}]	14391	pick-up	0	12
108088	2020-08-01 11:29:52	2020-08-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	41565	delivery	5	31
108089	2020-08-01 11:30:09	2020-08-01	17	[{"id_menu":4,"count":1}]	41533	delivery	5	22
108090	2020-08-01 11:32:47	2020-08-01	9	[{"id_menu":6,"count":1}]	18048	delivery	5	14
108091	2020-08-01 11:32:51	2020-08-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	16810	pick-up	0	21
108092	2020-08-01 11:34:46	2020-08-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	41625	delivery	5	28
108093	2020-08-01 11:34:53	2020-08-01	9	[{"id_menu":7,"count":1}]	29204	delivery	5	14
108094	2020-08-01 11:44:42	2020-08-01	12	[{"id_menu":1,"count":1}]	27976	delivery	5	17
108095	2020-08-01 11:46:04	2020-08-01	9	[{"id_menu":7,"count":1}]	1529	pick-up	0	9
108096	2020-08-01 11:46:11	2020-08-01	12	[{"id_menu":1,"count":1}]	13424	delivery	5	17
108097	2020-08-01 11:46:30	2020-08-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	41598	delivery	5	22
108098	2020-08-01 11:48:09	2020-08-01	8	[{"id_menu":5,"count":1}]	4217	delivery	5	13
108099	2020-08-01 11:49:00	2020-08-01	9	[{"id_menu":6,"count":1}]	9072	delivery	5	14
108100	2020-08-01 11:51:41	2020-08-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	41518	delivery	5	22
108101	2020-08-01 11:53:45	2020-08-01	8	[{"id_menu":5,"count":1}]	23902	delivery	5	13
108102	2020-08-01 11:53:55	2020-08-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41588	delivery	5	23
108103	2020-08-01 11:55:34	2020-08-01	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19803	pick-up	0	34
108104	2020-08-01 11:56:53	2020-08-01	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	38777	delivery	5	34
108105	2020-08-01 12:00:02	2020-08-01	8	[{"id_menu":5,"count":1}]	24018	pick-up	0	8
108106	2020-08-01 12:00:42	2020-08-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7886	delivery	5	28
108107	2020-08-01 12:01:14	2020-08-01	17	[{"id_menu":4,"count":1}]	18089	pick-up	0	17
108108	2020-08-01 12:03:31	2020-08-01	9	[{"id_menu":7,"count":1}]	10354	delivery	5	14
108109	2020-08-01 12:04:21	2020-08-01	8	[{"id_menu":5,"count":1}]	41535	delivery	5	13
108110	2020-08-01 12:06:48	2020-08-01	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	13179	delivery	5	35
108111	2020-08-01 12:07:38	2020-08-01	9	[{"id_menu":7,"count":1}]	520	pick-up	0	9
108112	2020-08-01 12:10:01	2020-08-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	41675	delivery	5	22
108113	2020-08-01 12:10:18	2020-08-01	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	31975	delivery	5	27
108114	2020-08-01 12:10:39	2020-08-01	9	[{"id_menu":6,"count":1}]	31265	delivery	5	14
108115	2020-08-01 12:12:24	2020-08-01	14	[{"id_menu":2,"count":1}]	25149	delivery	5	19
108116	2020-08-01 12:12:58	2020-08-01	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5309	delivery	5	34
108117	2020-08-01 12:15:57	2020-08-01	17	[{"id_menu":4,"count":1}]	5503	delivery	5	22
108118	2020-08-01 12:18:18	2020-08-01	9	[{"id_menu":7,"count":1}]	29616	delivery	5	14
108119	2020-08-01 12:18:41	2020-08-01	12	[{"id_menu":3,"count":1}]	41649	delivery	5	17
108120	2020-08-01 12:18:50	2020-08-01	8	[{"id_menu":5,"count":1}]	41648	delivery	5	13
108121	2020-08-01 12:20:06	2020-08-01	9	[{"id_menu":7,"count":1}]	150	delivery	5	14
108122	2020-08-01 12:21:01	2020-08-01	9	[{"id_menu":7,"count":1}]	41701	delivery	5	14
108123	2020-08-01 12:22:39	2020-08-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	2052	delivery	5	31
108124	2020-08-01 12:24:27	2020-08-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24573	delivery	5	22
108125	2020-08-01 12:24:40	2020-08-01	12	[{"id_menu":1,"count":1}]	19151	delivery	5	17
108126	2020-08-01 12:27:00	2020-08-01	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	17929	delivery	5	34
108127	2020-08-01 12:28:41	2020-08-01	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	41529	delivery	5	45
108128	2020-08-01 12:29:32	2020-08-01	9	[{"id_menu":6,"count":1}]	32517	delivery	5	14
108129	2020-08-01 12:29:58	2020-08-01	12	[{"id_menu":3,"count":1}]	1992	pick-up	0	12
108130	2020-08-01 12:31:38	2020-08-01	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	25532	pick-up	0	26
108131	2020-08-01 12:31:53	2020-08-01	8	[{"id_menu":5,"count":1}]	10729	delivery	5	13
108132	2020-08-01 12:32:02	2020-08-01	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	41699	delivery	5	53
108133	2020-08-01 12:33:38	2020-08-01	17	[{"id_menu":4,"count":1}]	25279	delivery	5	22
108134	2020-08-01 12:36:25	2020-08-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	41632	delivery	5	28
108135	2020-08-01 12:36:32	2020-08-01	9	[{"id_menu":6,"count":1}]	41600	delivery	5	14
108136	2020-08-01 12:43:08	2020-08-01	9	[{"id_menu":6,"count":1}]	9034	delivery	5	14
108137	2020-08-01 12:47:50	2020-08-01	30	[{"id_menu":3,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29099	delivery	5	35
108138	2020-08-01 12:51:24	2020-08-01	14	[{"id_menu":2,"count":1}]	41582	delivery	5	19
108139	2020-08-01 12:52:28	2020-08-01	12	[{"id_menu":1,"count":1}]	11225	pick-up	0	12
108140	2020-08-01 12:53:13	2020-08-01	14	[{"id_menu":2,"count":1}]	32491	delivery	5	19
108141	2020-08-01 12:55:38	2020-08-01	9	[{"id_menu":7,"count":1}]	41577	delivery	5	14
108142	2020-08-01 12:57:48	2020-08-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	41659	delivery	5	31
108143	2020-08-01 12:58:16	2020-08-01	17	[{"id_menu":4,"count":1}]	2119	pick-up	0	17
108144	2020-08-01 13:06:18	2020-08-01	9	[{"id_menu":6,"count":1}]	15284	delivery	5	14
108145	2020-08-01 13:08:41	2020-08-01	14	[{"id_menu":2,"count":1}]	41682	delivery	5	19
108146	2020-08-01 13:10:39	2020-08-01	12	[{"id_menu":3,"count":4}]	23146	delivery	5	17
108147	2020-08-01 13:11:15	2020-08-01	8	[{"id_menu":5,"count":1}]	41606	pick-up	0	8
108148	2020-08-01 13:13:55	2020-08-01	12	[{"id_menu":1,"count":1}]	12303	delivery	5	17
108149	2020-08-01 13:16:51	2020-08-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":3}]	41547	delivery	5	28
108150	2020-08-01 13:17:07	2020-08-01	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	41713	delivery	5	44
108151	2020-08-01 13:17:17	2020-08-01	12	[{"id_menu":1,"count":1}]	21121	pick-up	0	12
108152	2020-08-01 13:17:41	2020-08-01	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23467	delivery	5	31
108153	2020-08-01 13:21:11	2020-08-01	9	[{"id_menu":7,"count":1}]	18888	delivery	5	14
108154	2020-08-01 13:25:39	2020-08-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	36421	delivery	5	22
108155	2020-08-01 13:29:57	2020-08-01	9	[{"id_menu":6,"count":1}]	9690	delivery	5	14
108156	2020-08-01 13:30:28	2020-08-01	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	701	pick-up	0	21
108157	2020-08-01 13:31:15	2020-08-01	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15890	delivery	5	36
108158	2020-08-01 13:34:39	2020-08-01	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	38387	delivery	5	40
108159	2020-08-01 13:36:15	2020-08-01	9	[{"id_menu":6,"count":3}]	33543	delivery	5	14
108160	2020-08-01 13:37:02	2020-08-01	8	[{"id_menu":5,"count":1}]	28078	delivery	5	13
108161	2020-08-01 13:37:32	2020-08-01	14	[{"id_menu":2,"count":1}]	41684	delivery	5	19
108162	2020-08-01 13:41:02	2020-08-01	12	[{"id_menu":1,"count":1}]	33153	pick-up	0	12
108163	2020-08-01 13:41:18	2020-08-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16367	delivery	5	23
108164	2020-08-01 13:46:47	2020-08-01	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	41628	delivery	5	57
108165	2020-08-01 13:48:31	2020-08-01	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	27567	delivery	5	34
108166	2020-08-01 13:50:31	2020-08-01	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	32571	delivery	5	35
108167	2020-08-01 13:50:39	2020-08-01	8	[{"id_menu":5,"count":1}]	41583	delivery	5	13
108168	2020-08-01 13:52:38	2020-08-01	14	[{"id_menu":2,"count":1}]	27070	pick-up	0	14
108169	2020-08-01 13:52:51	2020-08-01	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	41693	delivery	5	28
108170	2020-08-01 13:54:03	2020-08-01	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	28584	delivery	5	26
108171	2020-08-01 13:55:37	2020-08-01	14	[{"id_menu":2,"count":1}]	29052	delivery	5	19
108172	2020-08-01 14:00:16	2020-08-01	17	[{"id_menu":4,"count":1}]	41586	delivery	5	22
108173	2020-08-01 14:04:07	2020-08-01	12	[{"id_menu":1,"count":1}]	20196	delivery	5	17
108174	2020-08-01 14:11:16	2020-08-01	9	[{"id_menu":6,"count":1}]	19372	delivery	5	14
108175	2020-08-01 14:11:56	2020-08-01	14	[{"id_menu":2,"count":1}]	12963	delivery	5	19
108176	2020-08-01 14:19:04	2020-08-01	34	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	41522	pick-up	0	34
108177	2020-08-01 14:21:39	2020-08-01	17	[{"id_menu":4,"count":1}]	41637	delivery	5	22
108178	2020-08-01 14:22:20	2020-08-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	31212	delivery	5	22
108179	2020-08-01 14:22:32	2020-08-01	9	[{"id_menu":7,"count":1}]	41712	delivery	5	14
108180	2020-08-01 14:22:54	2020-08-01	9	[{"id_menu":7,"count":1}]	14384	delivery	5	14
108181	2020-08-01 14:23:49	2020-08-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	32687	delivery	5	26
108182	2020-08-01 14:25:23	2020-08-01	12	[{"id_menu":1,"count":1}]	18021	delivery	5	17
108183	2020-08-01 14:28:21	2020-08-01	9	[{"id_menu":6,"count":1}]	41605	delivery	5	14
108184	2020-08-01 14:32:15	2020-08-01	9	[{"id_menu":7,"count":1}]	19480	delivery	5	14
108185	2020-08-01 14:35:32	2020-08-01	8	[{"id_menu":5,"count":1}]	28600	delivery	5	13
108186	2020-08-01 14:38:17	2020-08-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	32520	delivery	5	26
108187	2020-08-01 14:38:59	2020-08-01	14	[{"id_menu":2,"count":1}]	41564	delivery	5	19
108188	2020-08-01 14:39:55	2020-08-01	17	[{"id_menu":4,"count":1}]	743	delivery	5	22
108189	2020-08-01 14:40:56	2020-08-01	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	21008	delivery	5	31
108190	2020-08-01 14:41:33	2020-08-01	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	41573	delivery	5	39
108191	2020-08-01 14:44:12	2020-08-01	17	[{"id_menu":4,"count":1}]	32328	delivery	5	22
108192	2020-08-01 14:44:24	2020-08-01	14	[{"id_menu":2,"count":1}]	20594	delivery	5	19
108193	2020-08-01 14:45:06	2020-08-01	12	[{"id_menu":1,"count":1}]	5233	delivery	5	17
108194	2020-08-01 14:47:29	2020-08-01	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	3012	pick-up	0	26
108195	2020-08-01 14:49:11	2020-08-01	14	[{"id_menu":2,"count":1}]	41679	pick-up	0	14
108196	2020-08-01 14:49:52	2020-08-01	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11840	delivery	5	34
108197	2020-08-01 14:53:23	2020-08-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	8035	delivery	5	36
108198	2020-08-01 14:55:30	2020-08-01	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	41650	delivery	5	43
108199	2020-08-01 14:58:45	2020-08-01	17	[{"id_menu":4,"count":1}]	1445	delivery	5	22
108200	2020-08-01 14:59:01	2020-08-01	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41645	delivery	5	35
108201	2020-08-01 14:59:08	2020-08-01	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	41587	delivery	5	30
108202	2020-08-01 15:00:12	2020-08-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":3}]	12018	delivery	5	28
108203	2020-08-01 15:00:15	2020-08-01	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	34423	delivery	5	48
108204	2020-08-01 15:02:07	2020-08-01	8	[{"id_menu":5,"count":1}]	39699	delivery	5	13
108205	2020-08-01 15:02:15	2020-08-01	17	[{"id_menu":4,"count":1}]	18839	pick-up	0	17
108206	2020-08-01 15:02:47	2020-08-01	14	[{"id_menu":2,"count":1}]	41687	delivery	5	19
108207	2020-08-01 15:03:05	2020-08-01	14	[{"id_menu":2,"count":1}]	29881	pick-up	0	14
108208	2020-08-01 15:05:47	2020-08-01	12	[{"id_menu":3,"count":1}]	38316	pick-up	0	12
108209	2020-08-01 15:09:04	2020-08-01	9	[{"id_menu":6,"count":1}]	19363	delivery	5	14
108210	2020-08-01 15:17:06	2020-08-01	9	[{"id_menu":7,"count":1}]	41576	delivery	5	14
108211	2020-08-01 15:17:26	2020-08-01	8	[{"id_menu":5,"count":1}]	6276	delivery	5	13
108212	2020-08-01 15:17:34	2020-08-01	14	[{"id_menu":2,"count":1}]	5019	pick-up	0	14
108213	2020-08-01 15:19:52	2020-08-01	12	[{"id_menu":3,"count":1}]	2420	pick-up	0	12
108214	2020-08-01 15:20:32	2020-08-01	9	[{"id_menu":6,"count":1}]	1021	pick-up	0	9
108215	2020-08-01 15:21:14	2020-08-01	17	[{"id_menu":4,"count":1}]	21934	delivery	5	22
108216	2020-08-01 15:22:47	2020-08-01	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	35910	delivery	5	27
108217	2020-08-01 15:22:59	2020-08-01	9	[{"id_menu":6,"count":1}]	17582	delivery	5	14
108218	2020-08-01 15:25:03	2020-08-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	22197	delivery	5	28
108219	2020-08-01 15:29:24	2020-08-01	9	[{"id_menu":6,"count":1}]	41643	pick-up	0	9
108220	2020-08-01 15:31:37	2020-08-01	9	[{"id_menu":7,"count":1}]	31509	delivery	5	14
108221	2020-08-01 15:33:39	2020-08-01	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29695	delivery	5	34
108222	2020-08-01 15:36:27	2020-08-01	14	[{"id_menu":2,"count":1}]	41546	pick-up	0	14
108223	2020-08-01 15:37:42	2020-08-01	17	[{"id_menu":4,"count":1}]	16829	pick-up	0	17
108224	2020-08-01 15:38:01	2020-08-01	17	[{"id_menu":4,"count":1}]	17592	pick-up	0	17
108225	2020-08-01 15:38:24	2020-08-01	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6895	delivery	5	36
108226	2020-08-01 15:38:30	2020-08-01	9	[{"id_menu":6,"count":1}]	12707	delivery	5	14
108227	2020-08-01 15:40:01	2020-08-01	9	[{"id_menu":6,"count":1}]	41551	delivery	5	14
108228	2020-08-01 15:40:40	2020-08-01	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10679	pick-up	0	25
108229	2020-08-01 15:41:40	2020-08-01	12	[{"id_menu":1,"count":1}]	33560	delivery	5	17
108230	2020-08-01 15:41:52	2020-08-01	8	[{"id_menu":5,"count":1}]	1781	pick-up	0	8
108231	2020-08-01 15:42:28	2020-08-01	12	[{"id_menu":1,"count":1}]	19821	delivery	5	17
108232	2020-08-01 15:46:10	2020-08-01	14	[{"id_menu":2,"count":1}]	41604	delivery	5	19
108233	2020-08-01 15:46:13	2020-08-01	12	[{"id_menu":3,"count":1}]	1412	delivery	5	17
108234	2020-08-01 15:46:33	2020-08-01	12	[{"id_menu":3,"count":1}]	27098	delivery	5	17
108235	2020-08-01 15:50:14	2020-08-01	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	41524	delivery	5	36
108236	2020-08-01 15:52:22	2020-08-01	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	15182	delivery	5	38
108237	2020-08-01 15:54:13	2020-08-01	9	[{"id_menu":6,"count":1}]	10807	delivery	5	14
108238	2020-08-01 15:56:01	2020-08-01	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	41519	delivery	5	42
108239	2020-08-01 15:59:55	2020-08-01	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	27680	delivery	5	36
108240	2020-08-01 16:02:33	2020-08-01	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	41553	delivery	5	22
108241	2020-08-01 16:04:37	2020-08-01	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	33076	delivery	5	34
108242	2020-08-01 16:06:51	2020-08-01	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	32802	delivery	5	23
108243	2020-08-01 16:07:39	2020-08-01	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	13005	delivery	5	31
108244	2020-08-01 16:07:59	2020-08-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14357	delivery	5	23
108245	2020-08-01 16:11:10	2020-08-01	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4822	delivery	5	45
108246	2020-08-01 16:11:10	2020-08-01	9	[{"id_menu":6,"count":1}]	41644	delivery	5	14
108247	2020-08-01 16:11:41	2020-08-01	8	[{"id_menu":5,"count":1}]	154	pick-up	0	8
108248	2020-08-01 16:13:20	2020-08-01	9	[{"id_menu":7,"count":1}]	41703	delivery	5	14
108249	2020-08-01 16:15:34	2020-08-01	17	[{"id_menu":4,"count":1}]	29854	delivery	5	22
108250	2020-08-01 16:15:52	2020-08-01	8	[{"id_menu":5,"count":1}]	41563	delivery	5	13
108251	2020-08-01 16:16:39	2020-08-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":3}]	41569	delivery	5	22
108252	2020-08-01 16:18:16	2020-08-01	8	[{"id_menu":5,"count":1}]	2919	delivery	5	13
108253	2020-08-01 16:19:28	2020-08-01	9	[{"id_menu":7,"count":1}]	13558	pick-up	0	9
108254	2020-08-01 16:21:02	2020-08-01	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	25181	delivery	5	37
108255	2020-08-01 16:24:01	2020-08-01	17	[{"id_menu":4,"count":1}]	24000	pick-up	0	17
108256	2020-08-01 16:26:52	2020-08-01	8	[{"id_menu":5,"count":1}]	18936	delivery	5	13
108257	2020-08-01 16:27:01	2020-08-01	12	[{"id_menu":1,"count":1}]	10872	delivery	5	17
108258	2020-08-01 16:28:56	2020-08-01	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	12031	delivery	5	26
108259	2020-08-01 16:30:58	2020-08-01	9	[{"id_menu":7,"count":1}]	13532	delivery	5	14
108260	2020-08-01 16:31:44	2020-08-01	12	[{"id_menu":3,"count":1}]	21009	pick-up	0	12
108261	2020-08-01 16:32:41	2020-08-01	12	[{"id_menu":1,"count":1}]	994	pick-up	0	12
108262	2020-08-01 16:35:44	2020-08-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	41715	delivery	5	22
108263	2020-08-01 16:36:32	2020-08-01	9	[{"id_menu":6,"count":1}]	13111	delivery	5	14
108264	2020-08-01 16:37:39	2020-08-01	17	[{"id_menu":4,"count":1}]	22788	delivery	5	22
108265	2020-08-01 16:38:33	2020-08-01	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	30074	delivery	5	45
108266	2020-08-01 16:40:51	2020-08-01	12	[{"id_menu":1,"count":1}]	31523	delivery	5	17
108267	2020-08-01 16:41:34	2020-08-01	9	[{"id_menu":6,"count":1}]	22762	delivery	5	14
108268	2020-08-01 16:44:31	2020-08-01	14	[{"id_menu":2,"count":2}]	24271	delivery	5	19
108269	2020-08-01 16:46:19	2020-08-01	12	[{"id_menu":1,"count":1}]	17255	pick-up	0	12
108270	2020-08-01 16:47:28	2020-08-01	9	[{"id_menu":6,"count":1}]	22808	delivery	5	14
108271	2020-08-01 16:48:48	2020-08-01	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	9107	pick-up	0	41
108272	2020-08-01 16:51:24	2020-08-01	9	[{"id_menu":7,"count":1}]	41595	delivery	5	14
108273	2020-08-01 16:52:48	2020-08-01	9	[{"id_menu":7,"count":1}]	41300	pick-up	0	9
108274	2020-08-01 16:52:54	2020-08-01	9	[{"id_menu":6,"count":1}]	6292	pick-up	0	9
108275	2020-08-01 16:57:23	2020-08-01	17	[{"id_menu":4,"count":1}]	22510	delivery	5	22
108276	2020-08-01 17:00:10	2020-08-01	9	[{"id_menu":7,"count":1}]	8109	pick-up	0	9
108277	2020-08-01 17:01:27	2020-08-01	9	[{"id_menu":6,"count":1}]	41623	delivery	5	14
108278	2020-08-01 17:05:09	2020-08-01	9	[{"id_menu":7,"count":1}]	18107	delivery	5	14
108279	2020-08-01 17:05:38	2020-08-01	14	[{"id_menu":2,"count":2}]	20095	delivery	5	19
108280	2020-08-01 17:05:47	2020-08-01	14	[{"id_menu":2,"count":1}]	41635	pick-up	0	14
108281	2020-08-01 17:06:12	2020-08-01	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	6630	delivery	5	31
108282	2020-08-01 17:09:09	2020-08-01	8	[{"id_menu":5,"count":1}]	41656	delivery	5	13
108283	2020-08-01 17:10:29	2020-08-01	12	[{"id_menu":1,"count":1}]	41602	delivery	5	17
108284	2020-08-01 17:12:09	2020-08-01	9	[{"id_menu":7,"count":1}]	356	delivery	5	14
108285	2020-08-01 17:15:10	2020-08-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	13760	delivery	5	36
108286	2020-08-01 17:15:36	2020-08-01	8	[{"id_menu":5,"count":1}]	12758	delivery	5	13
108287	2020-08-01 17:17:10	2020-08-01	8	[{"id_menu":5,"count":1}]	22226	pick-up	0	8
108288	2020-08-01 17:17:57	2020-08-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	26839	pick-up	0	31
108289	2020-08-01 17:20:15	2020-08-01	14	[{"id_menu":2,"count":1}]	38836	delivery	5	19
108290	2020-08-01 17:23:19	2020-08-01	9	[{"id_menu":7,"count":1}]	41611	delivery	5	14
108291	2020-08-01 17:23:24	2020-08-01	17	[{"id_menu":4,"count":1}]	27919	delivery	5	22
108292	2020-08-01 17:24:05	2020-08-01	8	[{"id_menu":5,"count":1}]	41673	delivery	5	13
108293	2020-08-01 17:25:17	2020-08-01	12	[{"id_menu":3,"count":1}]	1685	pick-up	0	12
108294	2020-08-01 17:31:57	2020-08-01	8	[{"id_menu":5,"count":1}]	41579	delivery	5	13
108295	2020-08-01 17:31:58	2020-08-01	14	[{"id_menu":2,"count":1}]	7782	pick-up	0	14
108296	2020-08-01 17:34:59	2020-08-01	17	[{"id_menu":4,"count":1}]	28025	delivery	5	22
108297	2020-08-01 17:37:37	2020-08-01	14	[{"id_menu":2,"count":1}]	32542	delivery	5	19
108298	2020-08-01 17:38:43	2020-08-01	8	[{"id_menu":5,"count":1}]	6222	delivery	5	13
108299	2020-08-01 17:43:47	2020-08-01	17	[{"id_menu":4,"count":1}]	21770	pick-up	0	17
108300	2020-08-01 17:46:54	2020-08-01	9	[{"id_menu":7,"count":2}]	42	pick-up	0	9
108301	2020-08-01 17:47:26	2020-08-01	9	[{"id_menu":7,"count":2}]	12615	delivery	5	14
108302	2020-08-01 17:48:53	2020-08-01	9	[{"id_menu":6,"count":1}]	41642	pick-up	0	9
108303	2020-08-01 17:51:13	2020-08-01	14	[{"id_menu":2,"count":1}]	41702	delivery	5	19
108304	2020-08-01 17:52:12	2020-08-01	12	[{"id_menu":1,"count":1}]	5427	pick-up	0	12
108305	2020-08-01 17:55:34	2020-08-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5205	delivery	5	23
108306	2020-08-01 18:00:35	2020-08-01	14	[{"id_menu":2,"count":1}]	28838	delivery	5	19
108307	2020-08-01 18:00:48	2020-08-01	17	[{"id_menu":4,"count":1}]	41589	delivery	5	22
108308	2020-08-01 18:00:49	2020-08-01	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16834	delivery	5	54
108309	2020-08-01 18:03:30	2020-08-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	26281	delivery	5	28
108310	2020-08-01 18:04:47	2020-08-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	28396	delivery	5	28
108311	2020-08-01 18:05:15	2020-08-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	33683	delivery	5	23
108312	2020-08-01 18:07:12	2020-08-01	8	[{"id_menu":5,"count":1}]	35141	delivery	5	13
108313	2020-08-01 18:10:36	2020-08-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	15767	pick-up	0	31
108314	2020-08-01 18:10:49	2020-08-01	17	[{"id_menu":4,"count":1}]	1990	pick-up	0	17
108315	2020-08-01 18:12:53	2020-08-01	14	[{"id_menu":2,"count":1}]	41630	delivery	5	19
108316	2020-08-01 18:15:28	2020-08-01	17	[{"id_menu":4,"count":1}]	28012	delivery	5	22
108317	2020-08-01 18:16:39	2020-08-01	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	41686	delivery	5	31
108318	2020-08-01 18:18:48	2020-08-01	12	[{"id_menu":1,"count":1}]	31710	pick-up	0	12
108319	2020-08-01 18:19:33	2020-08-01	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	5919	delivery	5	40
108320	2020-08-01 18:20:31	2020-08-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	29504	delivery	5	31
108321	2020-08-01 18:21:30	2020-08-01	9	[{"id_menu":6,"count":1}]	31286	delivery	5	14
108322	2020-08-01 18:21:39	2020-08-01	8	[{"id_menu":5,"count":1}]	4022	delivery	5	13
108323	2020-08-01 18:22:48	2020-08-01	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10456	delivery	5	57
108324	2020-08-01 18:25:45	2020-08-01	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15679	delivery	5	34
108325	2020-08-01 18:26:17	2020-08-01	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	30498	delivery	5	23
108326	2020-08-01 18:26:31	2020-08-01	9	[{"id_menu":6,"count":1}]	41714	delivery	5	14
108327	2020-08-01 18:27:17	2020-08-01	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16222	pick-up	0	31
108328	2020-08-01 18:27:50	2020-08-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15405	pick-up	0	26
108329	2020-08-01 18:29:14	2020-08-01	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	41521	delivery	5	31
108330	2020-08-01 18:29:27	2020-08-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	41544	delivery	5	22
108331	2020-08-01 18:36:56	2020-08-01	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	41669	delivery	5	40
108332	2020-08-01 18:36:59	2020-08-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1801	pick-up	0	23
108333	2020-08-01 18:37:03	2020-08-01	9	[{"id_menu":6,"count":2}]	41622	delivery	5	14
108334	2020-08-01 18:37:11	2020-08-01	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12181	delivery	5	43
108335	2020-08-01 18:39:44	2020-08-01	9	[{"id_menu":6,"count":1}]	1921	pick-up	0	9
108336	2020-08-01 18:41:15	2020-08-01	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	40499	pick-up	0	26
108337	2020-08-01 18:44:46	2020-08-01	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	36708	delivery	5	43
108338	2020-08-01 18:45:01	2020-08-01	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	11263	delivery	5	27
108339	2020-08-01 18:45:39	2020-08-01	9	[{"id_menu":6,"count":1}]	41683	delivery	5	14
108340	2020-08-01 18:45:45	2020-08-01	14	[{"id_menu":2,"count":1}]	7572	pick-up	0	14
108341	2020-08-01 18:47:48	2020-08-01	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	40039	delivery	5	39
108342	2020-08-01 18:48:33	2020-08-01	9	[{"id_menu":7,"count":1}]	39931	pick-up	0	9
108343	2020-08-01 18:50:04	2020-08-01	9	[{"id_menu":6,"count":1}]	41676	pick-up	0	9
108344	2020-08-01 18:52:29	2020-08-01	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1085	pick-up	0	29
108345	2020-08-01 18:54:06	2020-08-01	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	41593	delivery	5	40
108346	2020-08-01 18:55:02	2020-08-01	14	[{"id_menu":2,"count":1}]	40232	delivery	5	19
108347	2020-08-01 18:59:16	2020-08-01	17	[{"id_menu":4,"count":1}]	1582	pick-up	0	17
108348	2020-08-01 19:05:10	2020-08-01	12	[{"id_menu":1,"count":1}]	39280	delivery	5	17
108349	2020-08-01 19:06:12	2020-08-01	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8848	delivery	5	31
108350	2020-08-01 19:06:21	2020-08-01	9	[{"id_menu":6,"count":1}]	1434	pick-up	0	9
108351	2020-08-01 19:06:52	2020-08-01	9	[{"id_menu":6,"count":1}]	12052	delivery	5	14
108352	2020-08-01 19:07:59	2020-08-01	9	[{"id_menu":7,"count":1}]	5160	pick-up	0	9
108353	2020-08-01 19:08:52	2020-08-01	17	[{"id_menu":4,"count":1}]	41567	delivery	5	22
108354	2020-08-01 19:10:39	2020-08-01	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31835	delivery	5	48
108355	2020-08-01 19:11:37	2020-08-01	9	[{"id_menu":6,"count":1}]	41537	delivery	5	14
108356	2020-08-01 19:11:58	2020-08-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	41507	pick-up	0	26
108357	2020-08-01 19:15:46	2020-08-01	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	41515	delivery	5	34
108358	2020-08-01 19:17:36	2020-08-01	17	[{"id_menu":4,"count":1}]	954	pick-up	0	17
108359	2020-08-01 19:18:12	2020-08-01	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	41599	delivery	5	34
108360	2020-08-01 19:18:46	2020-08-01	9	[{"id_menu":7,"count":1}]	32380	delivery	5	14
108361	2020-08-01 19:19:06	2020-08-01	9	[{"id_menu":6,"count":1}]	32128	delivery	5	14
108362	2020-08-01 19:19:32	2020-08-01	14	[{"id_menu":2,"count":1}]	41688	pick-up	0	14
108363	2020-08-01 19:22:13	2020-08-01	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	41708	delivery	5	25
108364	2020-08-01 19:22:41	2020-08-01	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	41694	delivery	5	39
108365	2020-08-01 19:25:11	2020-08-01	9	[{"id_menu":6,"count":1}]	15077	delivery	5	14
108366	2020-08-01 19:26:23	2020-08-01	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3119	delivery	5	39
108367	2020-08-01 19:26:47	2020-08-01	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	41618	delivery	5	26
108368	2020-08-01 19:27:00	2020-08-01	17	[{"id_menu":4,"count":1}]	15457	delivery	5	22
108369	2020-08-01 19:31:17	2020-08-01	17	[{"id_menu":4,"count":1}]	38302	delivery	5	22
108370	2020-08-01 19:34:10	2020-08-01	12	[{"id_menu":1,"count":1}]	21975	pick-up	0	12
108371	2020-08-01 19:34:31	2020-08-01	30	[{"id_menu":1,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41614	delivery	5	35
108372	2020-08-01 19:35:44	2020-08-01	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	8620	pick-up	0	26
108373	2020-08-01 19:37:46	2020-08-01	9	[{"id_menu":7,"count":1}]	41592	delivery	5	14
108374	2020-08-01 19:42:44	2020-08-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	41558	delivery	5	22
108375	2020-08-01 19:43:17	2020-08-01	14	[{"id_menu":2,"count":1}]	18245	delivery	5	19
108376	2020-08-01 19:43:18	2020-08-01	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13300	delivery	5	54
108377	2020-08-01 19:44:54	2020-08-01	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	41542	delivery	5	40
108378	2020-08-01 19:50:33	2020-08-01	8	[{"id_menu":5,"count":2}]	41689	delivery	5	13
108379	2020-08-01 19:51:21	2020-08-01	12	[{"id_menu":3,"count":1}]	1902	pick-up	0	12
108380	2020-08-01 19:52:09	2020-08-01	9	[{"id_menu":7,"count":1}]	19307	delivery	5	14
108381	2020-08-01 19:53:57	2020-08-01	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	14331	delivery	5	40
108382	2020-08-01 19:54:55	2020-08-01	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21081	delivery	5	45
108383	2020-08-01 20:02:04	2020-08-01	9	[{"id_menu":6,"count":1}]	32437	delivery	5	14
108384	2020-08-01 20:02:53	2020-08-01	9	[{"id_menu":7,"count":1}]	17910	delivery	5	14
108385	2020-08-01 20:04:05	2020-08-01	9	[{"id_menu":7,"count":1}]	16065	delivery	5	14
108386	2020-08-01 20:06:54	2020-08-01	14	[{"id_menu":2,"count":1}]	23437	delivery	5	19
108387	2020-08-01 20:11:18	2020-08-01	14	[{"id_menu":2,"count":1}]	15630	pick-up	0	14
108388	2020-08-01 20:12:23	2020-08-01	9	[{"id_menu":6,"count":1}]	31837	delivery	5	14
108389	2020-08-01 20:12:36	2020-08-01	9	[{"id_menu":6,"count":1}]	41512	delivery	5	14
108390	2020-08-01 20:12:54	2020-08-01	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	41530	delivery	5	22
108391	2020-08-01 20:19:04	2020-08-01	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	41638	delivery	5	57
108392	2020-08-01 20:19:39	2020-08-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	19506	pick-up	0	21
108393	2020-08-01 20:19:58	2020-08-01	12	[{"id_menu":3,"count":1}]	2897	pick-up	0	12
108394	2020-08-01 20:22:35	2020-08-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	20631	delivery	5	28
108395	2020-08-01 20:22:44	2020-08-01	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8010	delivery	5	45
108396	2020-08-01 20:22:51	2020-08-01	17	[{"id_menu":4,"count":1}]	14558	pick-up	0	17
108397	2020-08-01 20:23:22	2020-08-01	9	[{"id_menu":6,"count":1}]	6234	delivery	5	14
108398	2020-08-01 20:23:41	2020-08-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	35254	delivery	5	36
108399	2020-08-01 20:24:25	2020-08-01	8	[{"id_menu":5,"count":1}]	19800	delivery	5	13
108400	2020-08-01 20:27:02	2020-08-01	9	[{"id_menu":7,"count":1}]	31271	delivery	5	14
108401	2020-08-01 20:28:06	2020-08-01	12	[{"id_menu":3,"count":2}]	5350	pick-up	0	12
108402	2020-08-01 20:32:58	2020-08-01	8	[{"id_menu":5,"count":1}]	7468	delivery	5	13
108403	2020-08-01 20:33:14	2020-08-01	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7202	delivery	5	35
108404	2020-08-01 20:33:39	2020-08-01	12	[{"id_menu":1,"count":1}]	2956	pick-up	0	12
108405	2020-08-01 20:35:19	2020-08-01	9	[{"id_menu":7,"count":1}]	4929	pick-up	0	9
108406	2020-08-01 20:35:57	2020-08-01	9	[{"id_menu":7,"count":1}]	3327	pick-up	0	9
108407	2020-08-01 20:39:53	2020-08-01	12	[{"id_menu":1,"count":1}]	28717	delivery	5	17
108408	2020-08-01 20:40:04	2020-08-01	39	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	41710	delivery	5	44
108409	2020-08-01 20:43:53	2020-08-01	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	25454	delivery	5	26
108410	2020-08-01 20:43:55	2020-08-01	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	41590	delivery	5	31
108411	2020-08-01 20:45:57	2020-08-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18101	delivery	5	23
108412	2020-08-01 20:46:47	2020-08-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	25942	delivery	5	31
108413	2020-08-01 20:49:01	2020-08-01	14	[{"id_menu":2,"count":2}]	34685	delivery	5	19
108414	2020-08-01 20:51:29	2020-08-01	12	[{"id_menu":1,"count":1}]	41550	delivery	5	17
108415	2020-08-01 20:51:40	2020-08-01	14	[{"id_menu":2,"count":1}]	41629	delivery	5	19
108416	2020-08-01 20:55:42	2020-08-01	9	[{"id_menu":6,"count":1}]	41572	delivery	5	14
108417	2020-08-01 20:56:53	2020-08-01	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	35084	delivery	5	43
108418	2020-08-01 20:56:58	2020-08-01	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	41655	delivery	5	30
108419	2020-08-01 20:57:02	2020-08-01	12	[{"id_menu":3,"count":1}]	41609	delivery	5	17
108420	2020-08-01 20:58:47	2020-08-01	8	[{"id_menu":5,"count":1}]	2008	pick-up	0	8
108421	2020-08-01 20:59:12	2020-08-01	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	38451	delivery	5	30
108422	2020-08-01 21:02:19	2020-08-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	30841	delivery	5	26
108423	2020-08-01 21:03:39	2020-08-01	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	34517	pick-up	0	39
108424	2020-08-01 21:05:51	2020-08-01	9	[{"id_menu":7,"count":1}]	6087	delivery	5	14
108425	2020-08-01 21:06:06	2020-08-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	41554	delivery	5	28
108426	2020-08-01 21:14:24	2020-08-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	41697	delivery	5	28
108427	2020-08-01 21:14:35	2020-08-01	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	41627	delivery	5	27
108428	2020-08-01 21:15:05	2020-08-01	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	7591	delivery	5	26
108429	2020-08-01 21:16:16	2020-08-01	14	[{"id_menu":2,"count":2}]	7119	pick-up	0	14
108430	2020-08-01 21:20:29	2020-08-01	9	[{"id_menu":6,"count":1}]	41640	pick-up	0	9
108431	2020-08-01 21:21:49	2020-08-01	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	26062	delivery	5	40
108432	2020-08-01 21:24:24	2020-08-01	9	[{"id_menu":6,"count":1}]	7407	pick-up	0	9
108433	2020-08-01 21:26:23	2020-08-01	9	[{"id_menu":6,"count":1}]	3453	delivery	5	14
108434	2020-08-01 21:31:16	2020-08-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19399	delivery	5	22
108435	2020-08-01 21:31:49	2020-08-01	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	12068	delivery	5	43
108436	2020-08-01 21:32:42	2020-08-01	12	[{"id_menu":1,"count":1}]	41591	delivery	5	17
108437	2020-08-01 21:32:58	2020-08-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21705	delivery	5	22
108438	2020-08-01 21:36:27	2020-08-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7595	delivery	5	28
108439	2020-08-01 21:38:26	2020-08-01	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	41509	delivery	5	48
108440	2020-08-01 21:40:12	2020-08-01	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22511	delivery	5	31
108441	2020-08-01 21:43:51	2020-08-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	22131	pick-up	0	23
108442	2020-08-01 21:45:53	2020-08-01	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	14243	delivery	5	42
108443	2020-08-01 21:48:41	2020-08-01	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26808	delivery	5	37
108444	2020-08-01 21:50:32	2020-08-01	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7951	delivery	5	36
108445	2020-08-01 21:51:40	2020-08-01	12	[{"id_menu":1,"count":1}]	19893	delivery	5	17
108446	2020-08-01 21:53:18	2020-08-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	948	delivery	5	23
108447	2020-08-01 21:57:13	2020-08-01	12	[{"id_menu":1,"count":1}]	2007	delivery	5	17
108448	2020-08-01 22:01:07	2020-08-01	9	[{"id_menu":6,"count":1}]	41575	delivery	5	14
108449	2020-08-01 22:02:08	2020-08-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	13580	delivery	5	26
108450	2020-08-01 22:02:52	2020-08-01	17	[{"id_menu":4,"count":1}]	31963	delivery	5	22
108451	2020-08-01 22:03:52	2020-08-01	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	36854	delivery	5	36
108452	2020-08-01 22:04:32	2020-08-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41705	delivery	5	23
108453	2020-08-01 22:05:06	2020-08-01	12	[{"id_menu":1,"count":1}]	36718	pick-up	0	12
108454	2020-08-01 22:06:39	2020-08-01	14	[{"id_menu":2,"count":1}]	35842	delivery	5	19
108455	2020-08-01 22:06:43	2020-08-01	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17996	delivery	5	45
108456	2020-08-01 22:07:22	2020-08-01	9	[{"id_menu":7,"count":1}]	28955	delivery	5	14
108457	2020-08-01 22:07:55	2020-08-01	14	[{"id_menu":2,"count":1}]	25914	delivery	5	19
108458	2020-08-01 22:14:05	2020-08-01	12	[{"id_menu":1,"count":1}]	41516	delivery	5	17
108459	2020-08-01 22:14:16	2020-08-01	17	[{"id_menu":4,"count":1}]	41528	delivery	5	22
108460	2020-08-01 22:15:39	2020-08-01	9	[{"id_menu":7,"count":1}]	5380	delivery	5	14
108461	2020-08-01 22:16:03	2020-08-01	17	[{"id_menu":4,"count":1}]	491	pick-up	0	17
108462	2020-08-01 22:17:38	2020-08-01	12	[{"id_menu":1,"count":1}]	41678	delivery	5	17
108463	2020-08-01 22:19:05	2020-08-01	12	[{"id_menu":1,"count":1}]	12685	delivery	5	17
108464	2020-08-01 22:22:04	2020-08-01	14	[{"id_menu":2,"count":1}]	14679	pick-up	0	14
108465	2020-08-01 22:24:09	2020-08-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	36794	pick-up	0	17
108466	2020-08-01 22:25:24	2020-08-01	8	[{"id_menu":5,"count":1}]	41617	delivery	5	13
108467	2020-08-01 22:27:49	2020-08-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9682	pick-up	0	18
108468	2020-08-01 22:29:55	2020-08-01	9	[{"id_menu":7,"count":1}]	41513	delivery	5	14
108469	2020-08-01 22:32:43	2020-08-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	23184	delivery	5	28
108470	2020-08-01 22:37:57	2020-08-01	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	6749	delivery	5	34
108471	2020-08-01 22:38:14	2020-08-01	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27026	delivery	5	31
108472	2020-08-01 22:38:30	2020-08-01	46	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1657	pick-up	0	46
108473	2020-08-01 22:40:58	2020-08-01	12	[{"id_menu":3,"count":1}]	11287	pick-up	0	12
108474	2020-08-01 22:42:58	2020-08-01	12	[{"id_menu":1,"count":1}]	15791	pick-up	0	12
108475	2020-08-01 22:45:08	2020-08-01	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	17121	delivery	5	40
108476	2020-08-01 22:45:09	2020-08-01	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	41560	delivery	5	43
108477	2020-08-01 22:45:49	2020-08-01	12	[{"id_menu":1,"count":1}]	4042	pick-up	0	12
108478	2020-08-01 22:46:02	2020-08-01	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4644	pick-up	0	25
108479	2020-08-01 22:46:25	2020-08-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	41646	delivery	5	28
108480	2020-08-01 22:48:11	2020-08-01	14	[{"id_menu":2,"count":1}]	874	delivery	5	19
108481	2020-08-01 22:51:05	2020-08-01	12	[{"id_menu":3,"count":1}]	41695	delivery	5	17
108482	2020-08-01 22:55:22	2020-08-01	14	[{"id_menu":2,"count":1}]	41511	delivery	5	19
108483	2020-08-01 22:56:16	2020-08-01	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	27239	delivery	5	34
108484	2020-08-01 22:56:42	2020-08-01	12	[{"id_menu":1,"count":1}]	40042	delivery	5	17
108485	2020-08-01 22:57:21	2020-08-01	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	41624	pick-up	0	26
108486	2020-08-01 22:59:56	2020-08-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	20524	delivery	5	26
108487	2020-08-01 23:04:33	2020-08-01	17	[{"id_menu":4,"count":1}]	41552	delivery	5	22
108488	2020-08-01 23:05:45	2020-08-01	14	[{"id_menu":2,"count":1}]	37886	delivery	5	19
108489	2020-08-01 23:05:48	2020-08-01	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	90	delivery	5	31
108490	2020-08-01 23:06:21	2020-08-01	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	41548	pick-up	0	29
108491	2020-08-01 23:07:09	2020-08-01	9	[{"id_menu":6,"count":1}]	20117	delivery	5	14
108492	2020-08-01 23:07:15	2020-08-01	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	34631	delivery	5	22
108493	2020-08-01 23:08:20	2020-08-01	9	[{"id_menu":6,"count":2}]	27257	pick-up	0	9
108494	2020-08-01 23:08:50	2020-08-01	9	[{"id_menu":6,"count":1}]	5471	delivery	5	14
108495	2020-08-01 23:08:51	2020-08-01	12	[{"id_menu":1,"count":1}]	40616	delivery	5	17
108496	2020-08-01 23:14:09	2020-08-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10305	delivery	5	23
108497	2020-08-01 23:14:34	2020-08-01	8	[{"id_menu":5,"count":1}]	11197	delivery	5	13
108498	2020-08-01 23:15:28	2020-08-01	9	[{"id_menu":6,"count":1}]	41543	delivery	5	14
108499	2020-08-01 23:15:51	2020-08-01	12	[{"id_menu":3,"count":1}]	41607	delivery	5	17
108500	2020-08-01 23:16:16	2020-08-01	9	[{"id_menu":6,"count":1}]	33917	delivery	5	14
108501	2020-08-01 23:18:36	2020-08-01	9	[{"id_menu":6,"count":1}]	41709	delivery	5	14
108502	2020-08-01 23:19:42	2020-08-01	9	[{"id_menu":6,"count":1}]	12358	delivery	5	14
108503	2020-08-01 23:23:17	2020-08-01	12	[{"id_menu":3,"count":1}]	41634	delivery	5	17
108504	2020-08-01 23:26:42	2020-08-01	8	[{"id_menu":5,"count":1}]	9647	delivery	5	13
108505	2020-08-01 23:29:20	2020-08-01	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17268	delivery	5	31
108506	2020-08-01 23:31:33	2020-08-01	14	[{"id_menu":2,"count":1}]	41698	delivery	5	19
108507	2020-08-01 23:37:32	2020-08-01	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	41608	delivery	5	36
108508	2020-08-01 23:39:56	2020-08-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11933	delivery	5	23
108509	2020-08-01 23:42:26	2020-08-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	41240	delivery	5	28
108510	2020-08-01 23:44:59	2020-08-01	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	6037	delivery	5	26
108511	2020-08-01 23:45:14	2020-08-01	8	[{"id_menu":5,"count":1}]	17206	delivery	5	13
108512	2020-08-01 23:45:46	2020-08-01	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	6480	delivery	5	26
108513	2020-08-01 23:46:00	2020-08-01	8	[{"id_menu":5,"count":1}]	27258	delivery	5	13
108514	2020-08-01 23:46:11	2020-08-01	9	[{"id_menu":6,"count":1}]	8743	pick-up	0	9
108515	2020-08-01 23:51:49	2020-08-01	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	41540	delivery	5	43
108516	2020-08-01 23:53:22	2020-08-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	23835	delivery	5	31
108517	2020-08-01 23:57:18	2020-08-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	41615	delivery	5	28
108518	2020-08-01 23:58:25	2020-08-01	14	[{"id_menu":2,"count":1}]	15769	pick-up	0	14
108519	2020-08-01 23:58:49	2020-08-01	9	[{"id_menu":7,"count":1}]	30933	delivery	5	14
108520	2020-08-01 23:59:33	2020-08-01	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	41651	delivery	5	34
108521	2020-08-02 00:01:33	2020-08-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20534	delivery	5	22
108522	2020-08-02 00:03:45	2020-08-02	9	[{"id_menu":7,"count":1}]	40762	delivery	5	14
108523	2020-08-02 00:04:20	2020-08-02	17	[{"id_menu":4,"count":1}]	20910	pick-up	0	17
108524	2020-08-02 00:07:16	2020-08-02	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	41939	pick-up	0	29
108525	2020-08-02 00:12:05	2020-08-02	17	[{"id_menu":4,"count":1}]	41883	delivery	5	22
108526	2020-08-02 00:12:28	2020-08-02	9	[{"id_menu":7,"count":1}]	41852	delivery	5	14
108527	2020-08-02 00:14:17	2020-08-02	9	[{"id_menu":6,"count":1}]	41799	delivery	5	14
108528	2020-08-02 00:15:07	2020-08-02	8	[{"id_menu":5,"count":1}]	4388	delivery	5	13
108529	2020-08-02 00:16:20	2020-08-02	9	[{"id_menu":7,"count":1}]	41807	delivery	5	14
108530	2020-08-02 00:16:33	2020-08-02	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	41875	delivery	5	36
108531	2020-08-02 00:20:03	2020-08-02	14	[{"id_menu":2,"count":1}]	23927	delivery	5	19
108532	2020-08-02 00:22:15	2020-08-02	9	[{"id_menu":6,"count":1}]	26742	delivery	5	14
108533	2020-08-02 00:26:25	2020-08-02	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	40583	delivery	5	26
108534	2020-08-02 00:27:01	2020-08-02	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	18245	delivery	5	26
108535	2020-08-02 00:27:05	2020-08-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17341	delivery	5	22
108536	2020-08-02 00:27:45	2020-08-02	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	20440	delivery	5	27
108537	2020-08-02 00:28:35	2020-08-02	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	40611	delivery	5	26
108538	2020-08-02 00:33:52	2020-08-02	9	[{"id_menu":7,"count":1}]	9783	delivery	5	14
108539	2020-08-02 00:34:10	2020-08-02	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	19603	delivery	5	27
108540	2020-08-02 00:36:26	2020-08-02	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	40066	delivery	5	34
108541	2020-08-02 00:40:14	2020-08-02	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	41794	delivery	5	22
108542	2020-08-02 00:41:25	2020-08-02	12	[{"id_menu":3,"count":1}]	10882	pick-up	0	12
108543	2020-08-02 00:41:56	2020-08-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	28151	delivery	5	31
108544	2020-08-02 00:43:12	2020-08-02	14	[{"id_menu":2,"count":1}]	17447	pick-up	0	14
108545	2020-08-02 00:45:54	2020-08-02	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	41974	delivery	5	28
108546	2020-08-02 00:47:45	2020-08-02	14	[{"id_menu":2,"count":2}]	41898	delivery	5	19
108547	2020-08-02 00:48:14	2020-08-02	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	41764	delivery	5	28
108548	2020-08-02 00:48:42	2020-08-02	17	[{"id_menu":4,"count":1}]	14086	delivery	5	22
108549	2020-08-02 00:50:00	2020-08-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":3}]	25044	delivery	5	23
108550	2020-08-02 00:52:00	2020-08-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1362	delivery	5	31
108551	2020-08-02 00:52:39	2020-08-02	12	[{"id_menu":1,"count":2}]	29224	delivery	5	17
108552	2020-08-02 00:57:09	2020-08-02	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	29189	delivery	5	28
108553	2020-08-02 00:57:19	2020-08-02	17	[{"id_menu":4,"count":1}]	23602	pick-up	0	17
108554	2020-08-02 00:57:34	2020-08-02	9	[{"id_menu":7,"count":1}]	41836	delivery	5	14
108555	2020-08-02 00:57:42	2020-08-02	12	[{"id_menu":1,"count":1}]	20965	delivery	5	17
108556	2020-08-02 00:58:50	2020-08-02	14	[{"id_menu":2,"count":1}]	25324	pick-up	0	14
108557	2020-08-02 01:03:07	2020-08-02	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	19303	delivery	5	26
108558	2020-08-02 01:04:11	2020-08-02	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	729	pick-up	0	21
108559	2020-08-02 01:06:46	2020-08-02	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	4347	delivery	5	28
108560	2020-08-02 01:09:13	2020-08-02	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	34034	delivery	5	34
108561	2020-08-02 01:09:19	2020-08-02	8	[{"id_menu":5,"count":1}]	10611	delivery	5	13
108562	2020-08-02 01:09:28	2020-08-02	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	38569	pick-up	0	23
108563	2020-08-02 01:10:13	2020-08-02	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	41726	delivery	5	31
108564	2020-08-02 01:13:42	2020-08-02	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	31002	delivery	5	28
108565	2020-08-02 01:14:07	2020-08-02	9	[{"id_menu":7,"count":1}]	27757	delivery	5	14
108566	2020-08-02 01:16:52	2020-08-02	14	[{"id_menu":2,"count":1}]	23621	delivery	5	19
108567	2020-08-02 01:18:05	2020-08-02	9	[{"id_menu":7,"count":1}]	16127	delivery	5	14
108568	2020-08-02 01:19:13	2020-08-02	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	41956	delivery	5	42
108569	2020-08-02 01:20:54	2020-08-02	14	[{"id_menu":2,"count":1}]	41752	delivery	5	19
108570	2020-08-02 01:23:47	2020-08-02	12	[{"id_menu":3,"count":1}]	32054	delivery	5	17
108571	2020-08-02 01:24:37	2020-08-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	38157	delivery	5	31
108572	2020-08-02 01:25:26	2020-08-02	12	[{"id_menu":1,"count":1}]	16926	pick-up	0	12
108573	2020-08-02 01:30:34	2020-08-02	12	[{"id_menu":1,"count":1}]	17678	delivery	5	17
108574	2020-08-02 01:31:54	2020-08-02	9	[{"id_menu":6,"count":1}]	41946	delivery	5	14
108575	2020-08-02 01:32:12	2020-08-02	12	[{"id_menu":3,"count":1}]	41824	pick-up	0	12
108576	2020-08-02 01:34:35	2020-08-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15930	delivery	5	23
108577	2020-08-02 01:35:28	2020-08-02	12	[{"id_menu":1,"count":1}]	41822	delivery	5	17
108578	2020-08-02 01:38:24	2020-08-02	14	[{"id_menu":2,"count":1}]	41785	delivery	5	19
108579	2020-08-02 01:39:53	2020-08-02	9	[{"id_menu":6,"count":1}]	23061	delivery	5	14
108580	2020-08-02 01:40:26	2020-08-02	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	36330	delivery	5	37
108581	2020-08-02 01:41:00	2020-08-02	9	[{"id_menu":7,"count":2}]	3583	delivery	5	14
108582	2020-08-02 01:42:26	2020-08-02	17	[{"id_menu":4,"count":1}]	34653	delivery	5	22
108583	2020-08-02 01:43:49	2020-08-02	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4147	pick-up	0	23
108584	2020-08-02 01:48:18	2020-08-02	9	[{"id_menu":7,"count":1}]	41741	pick-up	0	9
108585	2020-08-02 01:48:27	2020-08-02	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18468	delivery	5	34
108586	2020-08-02 01:49:56	2020-08-02	9	[{"id_menu":7,"count":3}]	871	delivery	5	14
108587	2020-08-02 01:50:45	2020-08-02	8	[{"id_menu":5,"count":1}]	2536	pick-up	0	8
108588	2020-08-02 01:51:33	2020-08-02	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	3823	delivery	5	45
108589	2020-08-02 01:54:20	2020-08-02	9	[{"id_menu":7,"count":1}]	21334	delivery	5	14
108590	2020-08-02 01:55:55	2020-08-02	9	[{"id_menu":7,"count":1}]	19868	delivery	5	14
108591	2020-08-02 01:58:04	2020-08-02	8	[{"id_menu":5,"count":1}]	7089	delivery	5	13
108592	2020-08-02 01:59:37	2020-08-02	12	[{"id_menu":3,"count":1}]	41844	delivery	5	17
108593	2020-08-02 02:01:00	2020-08-02	9	[{"id_menu":7,"count":1}]	41725	delivery	5	14
108594	2020-08-02 02:05:03	2020-08-02	9	[{"id_menu":6,"count":1}]	17817	delivery	5	14
108595	2020-08-02 02:05:58	2020-08-02	12	[{"id_menu":3,"count":1}]	8734	delivery	5	17
108596	2020-08-02 02:06:26	2020-08-02	9	[{"id_menu":6,"count":1}]	41904	delivery	5	14
108597	2020-08-02 02:07:55	2020-08-02	12	[{"id_menu":1,"count":1}]	8378	delivery	5	17
108598	2020-08-02 02:08:42	2020-08-02	14	[{"id_menu":2,"count":1}]	41895	delivery	5	19
108599	2020-08-02 02:11:10	2020-08-02	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	29345	delivery	5	40
108600	2020-08-02 02:11:26	2020-08-02	17	[{"id_menu":4,"count":1}]	1473	pick-up	0	17
108601	2020-08-02 02:12:58	2020-08-02	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	27147	delivery	5	39
108602	2020-08-02 02:15:58	2020-08-02	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15481	delivery	5	43
108603	2020-08-02 02:17:43	2020-08-02	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5746	delivery	5	31
108604	2020-08-02 02:21:42	2020-08-02	9	[{"id_menu":7,"count":1}]	10032	delivery	5	14
108605	2020-08-02 02:23:06	2020-08-02	12	[{"id_menu":3,"count":1}]	41825	delivery	5	17
108606	2020-08-02 02:23:37	2020-08-02	9	[{"id_menu":6,"count":1}]	41762	pick-up	0	9
108607	2020-08-02 02:25:38	2020-08-02	8	[{"id_menu":5,"count":1}]	17019	delivery	5	13
108608	2020-08-02 02:25:55	2020-08-02	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	12282	delivery	5	28
108609	2020-08-02 02:27:18	2020-08-02	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	41815	delivery	5	40
108610	2020-08-02 02:27:44	2020-08-02	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6410	pick-up	0	35
108611	2020-08-02 02:27:54	2020-08-02	17	[{"id_menu":4,"count":1}]	32610	delivery	5	22
108612	2020-08-02 02:32:32	2020-08-02	14	[{"id_menu":2,"count":1}]	41746	pick-up	0	14
108613	2020-08-02 02:32:47	2020-08-02	14	[{"id_menu":2,"count":1}]	41872	delivery	5	19
108614	2020-08-02 02:32:49	2020-08-02	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17460	pick-up	0	17
108615	2020-08-02 02:34:40	2020-08-02	12	[{"id_menu":3,"count":1}]	16893	delivery	5	17
108616	2020-08-02 02:35:30	2020-08-02	9	[{"id_menu":7,"count":1}]	41722	delivery	5	14
108617	2020-08-02 02:35:52	2020-08-02	12	[{"id_menu":3,"count":1}]	31476	delivery	5	17
108618	2020-08-02 02:41:57	2020-08-02	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	8644	delivery	5	25
108619	2020-08-02 02:44:16	2020-08-02	17	[{"id_menu":4,"count":1}]	41918	delivery	5	22
108620	2020-08-02 02:48:12	2020-08-02	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	41964	pick-up	0	31
108621	2020-08-02 02:50:14	2020-08-02	8	[{"id_menu":5,"count":1}]	41957	delivery	5	13
108622	2020-08-02 02:51:37	2020-08-02	9	[{"id_menu":7,"count":1}]	12274	pick-up	0	9
108623	2020-08-02 02:51:56	2020-08-02	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32824	delivery	5	36
108624	2020-08-02 02:53:37	2020-08-02	14	[{"id_menu":2,"count":1}]	19690	delivery	5	19
108625	2020-08-02 02:54:13	2020-08-02	14	[{"id_menu":2,"count":1}]	41602	delivery	5	19
108626	2020-08-02 02:56:10	2020-08-02	9	[{"id_menu":6,"count":1}]	4305	delivery	5	14
108627	2020-08-02 02:57:04	2020-08-02	9	[{"id_menu":6,"count":1}]	26985	pick-up	0	9
108628	2020-08-02 02:57:26	2020-08-02	12	[{"id_menu":1,"count":1}]	41745	delivery	5	17
108629	2020-08-02 03:00:14	2020-08-02	17	[{"id_menu":4,"count":1}]	41983	delivery	5	22
108630	2020-08-02 03:01:07	2020-08-02	9	[{"id_menu":7,"count":1}]	41774	delivery	5	14
108631	2020-08-02 03:03:00	2020-08-02	14	[{"id_menu":2,"count":1}]	41800	delivery	5	19
108632	2020-08-02 03:05:00	2020-08-02	12	[{"id_menu":1,"count":1}]	41864	delivery	5	17
108633	2020-08-02 03:05:14	2020-08-02	9	[{"id_menu":7,"count":1}]	5783	pick-up	0	9
108634	2020-08-02 03:05:37	2020-08-02	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15323	delivery	5	39
108635	2020-08-02 03:08:06	2020-08-02	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	8045	delivery	5	31
108636	2020-08-02 03:10:13	2020-08-02	9	[{"id_menu":7,"count":1}]	4887	delivery	5	14
108637	2020-08-02 03:12:54	2020-08-02	9	[{"id_menu":6,"count":1}]	2689	delivery	5	14
108638	2020-08-02 03:16:18	2020-08-02	17	[{"id_menu":4,"count":1}]	10442	delivery	5	22
108639	2020-08-02 03:17:14	2020-08-02	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	41940	delivery	5	52
108640	2020-08-02 03:17:52	2020-08-02	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	41863	pick-up	0	21
108641	2020-08-02 03:18:28	2020-08-02	9	[{"id_menu":6,"count":1}]	35001	delivery	5	14
108642	2020-08-02 03:21:32	2020-08-02	17	[{"id_menu":4,"count":1}]	5144	pick-up	0	17
108643	2020-08-02 03:22:12	2020-08-02	9	[{"id_menu":6,"count":1}]	41759	delivery	5	14
108644	2020-08-02 03:28:20	2020-08-02	17	[{"id_menu":4,"count":1}]	41729	delivery	5	22
108645	2020-08-02 03:34:02	2020-08-02	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	30917	delivery	5	38
108646	2020-08-02 03:36:02	2020-08-02	9	[{"id_menu":7,"count":1}]	41738	delivery	5	14
108647	2020-08-02 03:36:06	2020-08-02	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	13279	delivery	5	26
108648	2020-08-02 03:37:49	2020-08-02	9	[{"id_menu":6,"count":1}]	41927	delivery	5	14
108649	2020-08-02 03:38:44	2020-08-02	8	[{"id_menu":5,"count":1}]	25887	delivery	5	13
108650	2020-08-02 03:40:26	2020-08-02	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16749	delivery	5	48
108651	2020-08-02 03:42:32	2020-08-02	14	[{"id_menu":2,"count":1}]	41788	delivery	5	19
108652	2020-08-02 03:48:50	2020-08-02	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	41749	delivery	5	43
108653	2020-08-02 03:52:49	2020-08-02	8	[{"id_menu":5,"count":1}]	1882	pick-up	0	8
108654	2020-08-02 03:53:13	2020-08-02	14	[{"id_menu":2,"count":1}]	41923	delivery	5	19
108655	2020-08-02 03:53:47	2020-08-02	12	[{"id_menu":1,"count":1}]	41804	delivery	5	17
108656	2020-08-02 03:54:44	2020-08-02	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	18311	delivery	5	43
108657	2020-08-02 03:55:10	2020-08-02	8	[{"id_menu":5,"count":1}]	5707	delivery	5	13
108658	2020-08-02 03:55:46	2020-08-02	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":3}]	41897	delivery	5	22
108659	2020-08-02 03:58:11	2020-08-02	8	[{"id_menu":5,"count":1}]	36549	delivery	5	13
108660	2020-08-02 03:58:12	2020-08-02	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	41755	delivery	5	39
108661	2020-08-02 03:58:50	2020-08-02	9	[{"id_menu":7,"count":1}]	41758	delivery	5	14
108662	2020-08-02 03:59:21	2020-08-02	17	[{"id_menu":4,"count":1}]	23470	delivery	5	22
108663	2020-08-02 04:01:33	2020-08-02	12	[{"id_menu":3,"count":1}]	41969	pick-up	0	12
108664	2020-08-02 04:02:29	2020-08-02	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	41843	delivery	5	26
108665	2020-08-02 04:05:02	2020-08-02	9	[{"id_menu":7,"count":1}]	41817	delivery	5	14
108666	2020-08-02 04:05:48	2020-08-02	9	[{"id_menu":7,"count":2}]	20729	delivery	5	14
108667	2020-08-02 04:07:59	2020-08-02	9	[{"id_menu":6,"count":1}]	36074	delivery	5	14
108668	2020-08-02 04:09:33	2020-08-02	14	[{"id_menu":2,"count":1}]	41936	delivery	5	19
108669	2020-08-02 04:10:53	2020-08-02	9	[{"id_menu":7,"count":2}]	41912	delivery	5	14
108670	2020-08-02 04:12:22	2020-08-02	12	[{"id_menu":1,"count":1}]	22698	delivery	5	17
108671	2020-08-02 04:12:26	2020-08-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	19572	delivery	5	31
108672	2020-08-02 04:16:36	2020-08-02	8	[{"id_menu":5,"count":1}]	18222	pick-up	0	8
108673	2020-08-02 04:17:49	2020-08-02	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	17005	delivery	5	26
108674	2020-08-02 04:22:04	2020-08-02	9	[{"id_menu":7,"count":2}]	41737	delivery	5	14
108675	2020-08-02 04:25:28	2020-08-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	41720	pick-up	0	23
108676	2020-08-02 04:25:34	2020-08-02	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	33533	delivery	5	27
108677	2020-08-02 04:25:45	2020-08-02	9	[{"id_menu":6,"count":1}]	15002	delivery	5	14
108678	2020-08-02 04:26:53	2020-08-02	12	[{"id_menu":3,"count":1}]	11010	pick-up	0	12
108679	2020-08-02 04:30:50	2020-08-02	9	[{"id_menu":7,"count":1}]	41819	delivery	5	14
108680	2020-08-02 04:31:02	2020-08-02	12	[{"id_menu":1,"count":1}]	37270	delivery	5	17
108681	2020-08-02 04:32:04	2020-08-02	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16194	delivery	5	55
108682	2020-08-02 04:33:00	2020-08-02	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	39464	delivery	5	40
108683	2020-08-02 04:37:21	2020-08-02	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	41775	delivery	5	26
108684	2020-08-02 04:41:40	2020-08-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	29004	delivery	5	23
108685	2020-08-02 04:45:16	2020-08-02	8	[{"id_menu":5,"count":1}]	41893	delivery	5	13
108686	2020-08-02 04:46:20	2020-08-02	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	29339	delivery	5	26
108687	2020-08-02 04:46:36	2020-08-02	17	[{"id_menu":4,"count":1}]	5932	delivery	5	22
108688	2020-08-02 04:47:18	2020-08-02	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	19892	delivery	5	27
108689	2020-08-02 04:47:37	2020-08-02	12	[{"id_menu":1,"count":1}]	15794	pick-up	0	12
108690	2020-08-02 04:48:42	2020-08-02	17	[{"id_menu":4,"count":1}]	36802	delivery	5	22
108691	2020-08-02 04:48:53	2020-08-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":3}]	41778	delivery	5	31
108692	2020-08-02 04:49:21	2020-08-02	17	[{"id_menu":4,"count":1}]	8303	pick-up	0	17
108693	2020-08-02 04:49:41	2020-08-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22595	delivery	5	23
108694	2020-08-02 04:50:25	2020-08-02	14	[{"id_menu":2,"count":1}]	41769	pick-up	0	14
108695	2020-08-02 04:51:02	2020-08-02	8	[{"id_menu":5,"count":1}]	32838	pick-up	0	8
108696	2020-08-02 04:55:20	2020-08-02	34	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	41976	delivery	5	39
108697	2020-08-02 04:57:03	2020-08-02	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9065	pick-up	0	25
108698	2020-08-02 04:57:20	2020-08-02	8	[{"id_menu":5,"count":1}]	3314	pick-up	0	8
108699	2020-08-02 05:00:39	2020-08-02	12	[{"id_menu":1,"count":1}]	41813	delivery	5	17
108700	2020-08-02 05:02:09	2020-08-02	9	[{"id_menu":7,"count":1}]	35566	pick-up	0	9
108701	2020-08-02 05:06:33	2020-08-02	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1269	pick-up	0	21
108702	2020-08-02 05:07:31	2020-08-02	14	[{"id_menu":2,"count":1}]	23571	pick-up	0	14
108703	2020-08-02 05:08:05	2020-08-02	17	[{"id_menu":4,"count":1}]	8657	pick-up	0	17
108704	2020-08-02 05:09:25	2020-08-02	12	[{"id_menu":1,"count":1}]	7133	delivery	5	17
108705	2020-08-02 05:12:53	2020-08-02	17	[{"id_menu":4,"count":1}]	15695	pick-up	0	17
108706	2020-08-02 05:13:05	2020-08-02	9	[{"id_menu":6,"count":1}]	41878	delivery	5	14
108707	2020-08-02 05:13:22	2020-08-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13370	pick-up	0	18
108708	2020-08-02 05:14:45	2020-08-02	12	[{"id_menu":1,"count":1}]	227	pick-up	0	12
108709	2020-08-02 05:16:10	2020-08-02	9	[{"id_menu":7,"count":1}]	20498	delivery	5	14
108710	2020-08-02 05:20:27	2020-08-02	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	41791	delivery	5	39
108711	2020-08-02 05:21:37	2020-08-02	14	[{"id_menu":2,"count":1}]	970	pick-up	0	14
108712	2020-08-02 05:22:01	2020-08-02	9	[{"id_menu":6,"count":1}]	38017	pick-up	0	9
108713	2020-08-02 05:23:04	2020-08-02	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	41829	delivery	5	26
108714	2020-08-02 05:24:30	2020-08-02	9	[{"id_menu":7,"count":1}]	35424	pick-up	0	9
108715	2020-08-02 05:26:10	2020-08-02	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	41891	delivery	5	34
108716	2020-08-02 05:26:16	2020-08-02	12	[{"id_menu":3,"count":1}]	12695	pick-up	0	12
108717	2020-08-02 05:26:47	2020-08-02	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	40517	delivery	5	22
108718	2020-08-02 05:27:01	2020-08-02	9	[{"id_menu":7,"count":1}]	41887	pick-up	0	9
108719	2020-08-02 05:27:47	2020-08-02	14	[{"id_menu":2,"count":1}]	27672	delivery	5	19
108720	2020-08-02 05:28:15	2020-08-02	12	[{"id_menu":3,"count":1}]	11894	delivery	5	17
108721	2020-08-02 05:29:09	2020-08-02	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	41910	delivery	5	22
108722	2020-08-02 05:29:12	2020-08-02	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	38062	delivery	5	25
108723	2020-08-02 05:29:52	2020-08-02	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	28362	delivery	5	22
108724	2020-08-02 05:33:31	2020-08-02	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	35158	delivery	5	48
108725	2020-08-02 05:34:12	2020-08-02	9	[{"id_menu":7,"count":1}]	32103	delivery	5	14
108726	2020-08-02 05:37:44	2020-08-02	12	[{"id_menu":1,"count":1}]	274	pick-up	0	12
108727	2020-08-02 05:38:18	2020-08-02	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	41942	delivery	5	22
108728	2020-08-02 05:38:51	2020-08-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15873	pick-up	0	17
108729	2020-08-02 05:39:01	2020-08-02	9	[{"id_menu":6,"count":1}]	34198	delivery	5	14
108730	2020-08-02 05:41:11	2020-08-02	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	33891	delivery	5	28
108731	2020-08-02 05:42:27	2020-08-02	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	41874	delivery	5	40
108732	2020-08-02 05:43:56	2020-08-02	12	[{"id_menu":1,"count":1}]	41571	pick-up	0	12
108733	2020-08-02 05:47:37	2020-08-02	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	41902	delivery	5	23
108734	2020-08-02 05:48:47	2020-08-02	12	[{"id_menu":1,"count":1}]	4995	delivery	5	17
108735	2020-08-02 05:48:48	2020-08-02	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	36182	pick-up	0	46
108736	2020-08-02 05:50:44	2020-08-02	17	[{"id_menu":4,"count":1}]	778	pick-up	0	17
108737	2020-08-02 05:50:55	2020-08-02	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":2}]	999	delivery	5	31
108738	2020-08-02 05:51:23	2020-08-02	12	[{"id_menu":3,"count":1}]	40100	delivery	5	17
108739	2020-08-02 05:51:54	2020-08-02	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	41922	delivery	5	40
108740	2020-08-02 05:53:38	2020-08-02	12	[{"id_menu":1,"count":1}]	35388	delivery	5	17
108741	2020-08-02 05:53:49	2020-08-02	8	[{"id_menu":5,"count":1}]	41861	delivery	5	13
108742	2020-08-02 05:55:35	2020-08-02	9	[{"id_menu":6,"count":1}]	25915	pick-up	0	9
108743	2020-08-02 05:56:06	2020-08-02	12	[{"id_menu":3,"count":1}]	5223	pick-up	0	12
108744	2020-08-02 05:56:32	2020-08-02	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	41975	delivery	5	39
108745	2020-08-02 05:58:15	2020-08-02	9	[{"id_menu":6,"count":1}]	36630	delivery	5	14
108746	2020-08-02 06:04:04	2020-08-02	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	20218	delivery	5	44
108747	2020-08-02 06:04:28	2020-08-02	12	[{"id_menu":1,"count":1}]	25985	delivery	5	17
108748	2020-08-02 06:05:25	2020-08-02	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	40476	delivery	5	28
108749	2020-08-02 06:05:41	2020-08-02	9	[{"id_menu":6,"count":1}]	17470	delivery	5	14
108750	2020-08-02 06:05:55	2020-08-02	9	[{"id_menu":6,"count":1}]	10744	delivery	5	14
108751	2020-08-02 06:05:57	2020-08-02	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	16709	delivery	5	31
108752	2020-08-02 06:09:38	2020-08-02	9	[{"id_menu":7,"count":1}]	13287	delivery	5	14
108753	2020-08-02 06:09:57	2020-08-02	14	[{"id_menu":2,"count":1}]	6459	delivery	5	19
108754	2020-08-02 06:12:30	2020-08-02	34	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	41860	pick-up	0	34
108755	2020-08-02 06:14:50	2020-08-02	9	[{"id_menu":6,"count":1}]	24164	delivery	5	14
108756	2020-08-02 06:16:51	2020-08-02	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23506	delivery	5	45
108757	2020-08-02 06:19:49	2020-08-02	14	[{"id_menu":2,"count":1}]	25220	delivery	5	19
108758	2020-08-02 06:21:51	2020-08-02	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	41727	delivery	5	56
108759	2020-08-02 06:22:36	2020-08-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13656	pick-up	0	17
108760	2020-08-02 06:26:01	2020-08-02	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	41928	delivery	5	26
108761	2020-08-02 06:26:07	2020-08-02	14	[{"id_menu":2,"count":1}]	19893	pick-up	0	14
108762	2020-08-02 06:27:38	2020-08-02	9	[{"id_menu":6,"count":1}]	21069	delivery	5	14
108763	2020-08-02 06:27:52	2020-08-02	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	40139	pick-up	0	26
108764	2020-08-02 06:27:57	2020-08-02	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	26065	pick-up	0	22
108765	2020-08-02 06:28:36	2020-08-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41811	delivery	5	23
108766	2020-08-02 06:29:05	2020-08-02	8	[{"id_menu":5,"count":1}]	41982	delivery	5	13
108767	2020-08-02 06:29:05	2020-08-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	820	pick-up	0	23
108768	2020-08-02 06:29:29	2020-08-02	9	[{"id_menu":7,"count":2}]	41831	delivery	5	14
108769	2020-08-02 06:29:51	2020-08-02	9	[{"id_menu":7,"count":2}]	10514	delivery	5	14
108770	2020-08-02 06:31:54	2020-08-02	14	[{"id_menu":2,"count":1}]	10067	pick-up	0	14
108771	2020-08-02 06:32:30	2020-08-02	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	33324	delivery	5	26
108772	2020-08-02 06:32:49	2020-08-02	8	[{"id_menu":5,"count":1}]	26525	delivery	5	13
108773	2020-08-02 06:33:16	2020-08-02	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	34232	delivery	5	22
108774	2020-08-02 06:33:48	2020-08-02	9	[{"id_menu":6,"count":1}]	20162	delivery	5	14
108775	2020-08-02 06:34:49	2020-08-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15954	delivery	5	31
108776	2020-08-02 06:37:14	2020-08-02	14	[{"id_menu":2,"count":1}]	41877	delivery	5	19
108777	2020-08-02 06:37:51	2020-08-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8792	delivery	5	23
108778	2020-08-02 06:40:30	2020-08-02	17	[{"id_menu":4,"count":1}]	41756	delivery	5	22
108779	2020-08-02 06:45:33	2020-08-02	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14475	delivery	5	35
108780	2020-08-02 06:47:16	2020-08-02	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	4892	delivery	5	28
108781	2020-08-02 06:47:27	2020-08-02	8	[{"id_menu":5,"count":1}]	28854	delivery	5	13
108782	2020-08-02 06:47:35	2020-08-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	34208	pick-up	0	17
108783	2020-08-02 06:48:58	2020-08-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17434	delivery	5	23
108784	2020-08-02 06:49:02	2020-08-02	9	[{"id_menu":7,"count":1}]	14146	pick-up	0	9
108785	2020-08-02 06:52:22	2020-08-02	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6182	pick-up	0	38
108786	2020-08-02 06:56:06	2020-08-02	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	41973	delivery	5	43
108787	2020-08-02 06:57:42	2020-08-02	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	22238	delivery	5	36
108788	2020-08-02 06:58:38	2020-08-02	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41917	delivery	5	31
108789	2020-08-02 06:59:06	2020-08-02	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":2}]	41780	delivery	5	28
108790	2020-08-02 06:59:57	2020-08-02	17	[{"id_menu":4,"count":1}]	14559	pick-up	0	17
108791	2020-08-02 07:00:19	2020-08-02	12	[{"id_menu":3,"count":1}]	41866	delivery	5	17
108792	2020-08-02 07:00:44	2020-08-02	9	[{"id_menu":7,"count":1}]	40201	pick-up	0	9
108793	2020-08-02 07:02:08	2020-08-02	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	456	pick-up	0	20
108794	2020-08-02 07:02:23	2020-08-02	8	[{"id_menu":5,"count":1}]	30608	delivery	5	13
108795	2020-08-02 07:06:09	2020-08-02	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	21130	pick-up	0	29
108796	2020-08-02 07:06:36	2020-08-02	17	[{"id_menu":4,"count":1}]	9017	pick-up	0	17
108797	2020-08-02 07:08:01	2020-08-02	8	[{"id_menu":5,"count":1}]	16346	delivery	5	13
108798	2020-08-02 07:09:26	2020-08-02	8	[{"id_menu":5,"count":1}]	10200	pick-up	0	8
108799	2020-08-02 07:13:26	2020-08-02	8	[{"id_menu":5,"count":1}]	41834	delivery	5	13
108800	2020-08-02 07:15:31	2020-08-02	9	[{"id_menu":6,"count":1}]	41805	delivery	5	14
108801	2020-08-02 07:16:41	2020-08-02	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	41721	delivery	5	22
108802	2020-08-02 07:20:11	2020-08-02	8	[{"id_menu":5,"count":1}]	377	pick-up	0	8
108803	2020-08-02 07:20:39	2020-08-02	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	33547	delivery	5	23
108804	2020-08-02 07:23:39	2020-08-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	25299	delivery	5	28
108805	2020-08-02 07:25:21	2020-08-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	29851	delivery	5	28
108806	2020-08-02 07:26:58	2020-08-02	9	[{"id_menu":6,"count":2}]	1581	pick-up	0	9
108807	2020-08-02 07:27:58	2020-08-02	9	[{"id_menu":7,"count":1}]	11827	delivery	5	14
108808	2020-08-02 07:30:39	2020-08-02	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	18400	delivery	5	28
108809	2020-08-02 07:31:30	2020-08-02	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	41856	delivery	5	34
108810	2020-08-02 07:32:27	2020-08-02	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	41723	delivery	5	43
108811	2020-08-02 07:32:29	2020-08-02	9	[{"id_menu":7,"count":1}]	17805	delivery	5	14
108812	2020-08-02 07:35:52	2020-08-02	9	[{"id_menu":7,"count":1}]	5649	delivery	5	14
108813	2020-08-02 07:38:06	2020-08-02	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	17809	delivery	5	30
108814	2020-08-02 07:38:09	2020-08-02	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25255	delivery	5	36
108815	2020-08-02 07:38:55	2020-08-02	9	[{"id_menu":6,"count":1}]	41854	delivery	5	14
108816	2020-08-02 07:39:41	2020-08-02	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	25799	delivery	5	40
108817	2020-08-02 07:39:45	2020-08-02	12	[{"id_menu":1,"count":1}]	38673	delivery	5	17
108818	2020-08-02 07:39:59	2020-08-02	12	[{"id_menu":1,"count":2}]	4495	delivery	5	17
108819	2020-08-02 07:40:21	2020-08-02	12	[{"id_menu":1,"count":1}]	41835	delivery	5	17
108820	2020-08-02 07:42:41	2020-08-02	9	[{"id_menu":7,"count":1}]	5324	delivery	5	14
108821	2020-08-02 07:46:44	2020-08-02	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41739	delivery	5	40
108822	2020-08-02 07:50:41	2020-08-02	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	30864	pick-up	0	21
108823	2020-08-02 07:52:01	2020-08-02	12	[{"id_menu":3,"count":1}]	41818	delivery	5	17
108824	2020-08-02 07:53:05	2020-08-02	17	[{"id_menu":4,"count":1}]	32803	delivery	5	22
108825	2020-08-02 07:54:24	2020-08-02	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	7151	delivery	5	34
108826	2020-08-02 07:55:12	2020-08-02	14	[{"id_menu":2,"count":1}]	3467	delivery	5	19
108827	2020-08-02 07:55:53	2020-08-02	9	[{"id_menu":6,"count":1}]	41955	delivery	5	14
108828	2020-08-02 07:59:42	2020-08-02	9	[{"id_menu":6,"count":2}]	41873	delivery	5	14
108829	2020-08-02 08:01:27	2020-08-02	9	[{"id_menu":7,"count":1}]	8700	pick-up	0	9
108830	2020-08-02 08:02:24	2020-08-02	8	[{"id_menu":5,"count":2}]	41972	delivery	5	13
108831	2020-08-02 08:04:12	2020-08-02	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	41894	delivery	5	22
108832	2020-08-02 08:04:17	2020-08-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	658	delivery	5	28
108833	2020-08-02 08:04:18	2020-08-02	55	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	41734	delivery	5	60
108834	2020-08-02 08:04:52	2020-08-02	12	[{"id_menu":3,"count":1}]	41925	delivery	5	17
108835	2020-08-02 08:06:27	2020-08-02	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	41921	delivery	5	28
108836	2020-08-02 08:09:20	2020-08-02	9	[{"id_menu":7,"count":1}]	33272	delivery	5	14
108837	2020-08-02 08:10:24	2020-08-02	9	[{"id_menu":7,"count":1}]	41765	pick-up	0	9
108838	2020-08-02 08:11:03	2020-08-02	9	[{"id_menu":7,"count":1}]	26926	pick-up	0	9
108839	2020-08-02 08:11:49	2020-08-02	9	[{"id_menu":6,"count":1}]	38055	delivery	5	14
108840	2020-08-02 08:14:09	2020-08-02	9	[{"id_menu":7,"count":1}]	21032	delivery	5	14
108841	2020-08-02 08:20:22	2020-08-02	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	41802	delivery	5	40
108842	2020-08-02 08:20:49	2020-08-02	12	[{"id_menu":1,"count":1}]	41681	delivery	5	17
108843	2020-08-02 08:21:22	2020-08-02	9	[{"id_menu":6,"count":1}]	33998	delivery	5	14
108844	2020-08-02 08:22:05	2020-08-02	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	41757	delivery	5	28
108845	2020-08-02 08:25:18	2020-08-02	14	[{"id_menu":2,"count":1}]	16813	pick-up	0	14
108846	2020-08-02 08:25:50	2020-08-02	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	30534	pick-up	0	29
108847	2020-08-02 08:26:48	2020-08-02	14	[{"id_menu":2,"count":2}]	17321	pick-up	0	14
108848	2020-08-02 08:26:49	2020-08-02	17	[{"id_menu":4,"count":1}]	3666	delivery	5	22
108849	2020-08-02 08:28:03	2020-08-02	12	[{"id_menu":1,"count":1}]	41838	delivery	5	17
108850	2020-08-02 08:30:54	2020-08-02	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	41908	delivery	5	31
108851	2020-08-02 08:31:14	2020-08-02	12	[{"id_menu":1,"count":1}]	41932	delivery	5	17
108852	2020-08-02 08:31:37	2020-08-02	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15639	delivery	5	31
108853	2020-08-02 08:35:41	2020-08-02	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	5685	delivery	5	31
108854	2020-08-02 08:37:52	2020-08-02	8	[{"id_menu":5,"count":1}]	41851	delivery	5	13
108855	2020-08-02 08:38:36	2020-08-02	12	[{"id_menu":3,"count":1}]	41920	pick-up	0	12
108856	2020-08-02 08:39:00	2020-08-02	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13084	delivery	5	36
108857	2020-08-02 08:39:33	2020-08-02	17	[{"id_menu":4,"count":1}]	41719	delivery	5	22
108858	2020-08-02 08:40:02	2020-08-02	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	40511	delivery	5	57
108859	2020-08-02 08:40:20	2020-08-02	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41979	delivery	5	37
108860	2020-08-02 08:43:06	2020-08-02	9	[{"id_menu":7,"count":1}]	8004	pick-up	0	9
108861	2020-08-02 08:46:45	2020-08-02	9	[{"id_menu":7,"count":1}]	35223	delivery	5	14
108862	2020-08-02 08:52:12	2020-08-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30155	delivery	5	23
108863	2020-08-02 08:52:18	2020-08-02	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	41306	delivery	5	25
108864	2020-08-02 08:52:43	2020-08-02	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41933	delivery	5	31
108865	2020-08-02 08:54:08	2020-08-02	12	[{"id_menu":1,"count":1}]	29181	delivery	5	17
108866	2020-08-02 08:54:49	2020-08-02	8	[{"id_menu":5,"count":1}]	15535	pick-up	0	8
108867	2020-08-02 08:55:01	2020-08-02	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	41924	delivery	5	43
108868	2020-08-02 08:56:47	2020-08-02	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2089	delivery	5	35
108869	2020-08-02 08:56:53	2020-08-02	8	[{"id_menu":5,"count":1}]	8884	delivery	5	13
108870	2020-08-02 08:58:00	2020-08-02	8	[{"id_menu":5,"count":1}]	13903	delivery	5	13
108871	2020-08-02 09:00:02	2020-08-02	12	[{"id_menu":3,"count":1}]	26381	delivery	5	17
108872	2020-08-02 09:01:41	2020-08-02	9	[{"id_menu":7,"count":1}]	628	delivery	5	14
108873	2020-08-02 09:08:48	2020-08-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	31882	delivery	5	23
108874	2020-08-02 09:10:25	2020-08-02	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	1243	delivery	5	34
108875	2020-08-02 09:10:44	2020-08-02	9	[{"id_menu":6,"count":1}]	13465	delivery	5	14
108876	2020-08-02 09:11:19	2020-08-02	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	5311	pick-up	0	21
108877	2020-08-02 09:12:51	2020-08-02	12	[{"id_menu":3,"count":2}]	8475	delivery	5	17
108878	2020-08-02 09:13:02	2020-08-02	9	[{"id_menu":7,"count":1}]	41809	delivery	5	14
108879	2020-08-02 09:14:00	2020-08-02	12	[{"id_menu":1,"count":1}]	9695	delivery	5	17
108880	2020-08-02 09:14:50	2020-08-02	9	[{"id_menu":7,"count":1}]	41833	delivery	5	14
108881	2020-08-02 09:18:04	2020-08-02	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1101	delivery	5	31
108882	2020-08-02 09:19:25	2020-08-02	9	[{"id_menu":7,"count":1}]	41862	delivery	5	14
108883	2020-08-02 09:22:23	2020-08-02	9	[{"id_menu":7,"count":1}]	25532	pick-up	0	9
108884	2020-08-02 09:29:14	2020-08-02	9	[{"id_menu":6,"count":1}]	4731	delivery	5	14
108885	2020-08-02 09:29:34	2020-08-02	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	41865	delivery	5	28
108886	2020-08-02 09:30:37	2020-08-02	8	[{"id_menu":5,"count":1}]	8755	pick-up	0	8
108887	2020-08-02 09:30:48	2020-08-02	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	25053	delivery	5	26
108888	2020-08-02 09:32:44	2020-08-02	12	[{"id_menu":3,"count":1}]	8866	delivery	5	17
108889	2020-08-02 09:33:12	2020-08-02	12	[{"id_menu":3,"count":1}]	41849	delivery	5	17
108890	2020-08-02 09:36:57	2020-08-02	9	[{"id_menu":6,"count":1}]	41954	delivery	5	14
108891	2020-08-02 09:37:39	2020-08-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1383	pick-up	0	26
108892	2020-08-02 09:40:29	2020-08-02	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	41816	delivery	5	39
108893	2020-08-02 09:41:42	2020-08-02	8	[{"id_menu":5,"count":1}]	20693	delivery	5	13
108894	2020-08-02 09:41:58	2020-08-02	8	[{"id_menu":5,"count":1}]	40779	delivery	5	13
108895	2020-08-02 09:43:06	2020-08-02	9	[{"id_menu":7,"count":1}]	301	delivery	5	14
108896	2020-08-02 09:43:23	2020-08-02	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36805	delivery	5	37
108897	2020-08-02 09:44:07	2020-08-02	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	41869	delivery	5	39
108898	2020-08-02 09:45:18	2020-08-02	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16193	delivery	5	34
108899	2020-08-02 09:45:28	2020-08-02	14	[{"id_menu":2,"count":2}]	41832	delivery	5	19
108900	2020-08-02 09:46:33	2020-08-02	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	19940	delivery	5	40
108901	2020-08-02 09:47:02	2020-08-02	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	10283	pick-up	0	26
108902	2020-08-02 09:51:17	2020-08-02	9	[{"id_menu":7,"count":1}]	41944	delivery	5	14
108903	2020-08-02 09:52:03	2020-08-02	9	[{"id_menu":7,"count":1}]	8355	pick-up	0	9
108904	2020-08-02 09:53:30	2020-08-02	14	[{"id_menu":2,"count":1}]	41806	delivery	5	19
108905	2020-08-02 09:54:00	2020-08-02	12	[{"id_menu":1,"count":1}]	7476	delivery	5	17
108906	2020-08-02 09:57:28	2020-08-02	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	26596	delivery	5	26
108907	2020-08-02 10:00:01	2020-08-02	9	[{"id_menu":6,"count":1}]	41803	delivery	5	14
108908	2020-08-02 10:02:34	2020-08-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27283	pick-up	0	18
108909	2020-08-02 10:04:41	2020-08-02	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	41937	delivery	5	57
108910	2020-08-02 10:05:09	2020-08-02	9	[{"id_menu":7,"count":1}]	41931	delivery	5	14
108911	2020-08-02 10:07:08	2020-08-02	9	[{"id_menu":6,"count":1}]	41882	delivery	5	14
108912	2020-08-02 10:08:46	2020-08-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1676	delivery	5	23
108913	2020-08-02 10:09:43	2020-08-02	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	5729	delivery	5	27
108914	2020-08-02 10:09:49	2020-08-02	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	41793	delivery	5	23
108915	2020-08-02 10:10:26	2020-08-02	14	[{"id_menu":2,"count":1}]	23661	pick-up	0	14
108916	2020-08-02 10:13:39	2020-08-02	12	[{"id_menu":3,"count":1}]	3189	pick-up	0	12
108917	2020-08-02 10:19:02	2020-08-02	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3976	pick-up	0	31
108918	2020-08-02 10:21:32	2020-08-02	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41899	delivery	5	31
108919	2020-08-02 10:24:30	2020-08-02	8	[{"id_menu":5,"count":1}]	5894	delivery	5	13
108920	2020-08-02 10:27:43	2020-08-02	8	[{"id_menu":5,"count":1}]	41970	delivery	5	13
108921	2020-08-02 10:27:43	2020-08-02	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35663	delivery	5	49
108922	2020-08-02 10:30:57	2020-08-02	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8307	delivery	5	30
108923	2020-08-02 10:32:29	2020-08-02	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	18878	delivery	5	25
108924	2020-08-02 10:32:49	2020-08-02	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	41907	delivery	5	34
108925	2020-08-02 10:32:58	2020-08-02	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	41886	delivery	5	27
108926	2020-08-02 10:34:17	2020-08-02	12	[{"id_menu":3,"count":1}]	41789	delivery	5	17
108927	2020-08-02 10:34:22	2020-08-02	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	41941	delivery	5	31
108928	2020-08-02 10:35:11	2020-08-02	8	[{"id_menu":5,"count":1}]	41787	delivery	5	13
108929	2020-08-02 10:35:59	2020-08-02	12	[{"id_menu":3,"count":1}]	31457	delivery	5	17
108930	2020-08-02 10:37:16	2020-08-02	9	[{"id_menu":6,"count":1}]	7058	pick-up	0	9
108931	2020-08-02 10:37:29	2020-08-02	17	[{"id_menu":4,"count":1}]	2439	delivery	5	22
108932	2020-08-02 10:37:51	2020-08-02	8	[{"id_menu":5,"count":1}]	16627	pick-up	0	8
108933	2020-08-02 10:43:55	2020-08-02	12	[{"id_menu":1,"count":1}]	2672	pick-up	0	12
108934	2020-08-02 10:44:59	2020-08-02	12	[{"id_menu":3,"count":1}]	41915	delivery	5	17
108935	2020-08-02 10:45:46	2020-08-02	9	[{"id_menu":7,"count":1}]	39670	delivery	5	14
108936	2020-08-02 10:46:09	2020-08-02	9	[{"id_menu":6,"count":1}]	35669	delivery	5	14
108937	2020-08-02 10:46:44	2020-08-02	9	[{"id_menu":7,"count":1}]	23508	delivery	5	14
108938	2020-08-02 10:48:36	2020-08-02	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	13651	delivery	5	34
108939	2020-08-02 10:50:01	2020-08-02	9	[{"id_menu":6,"count":1}]	21874	pick-up	0	9
108940	2020-08-02 10:50:03	2020-08-02	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6065	delivery	5	31
108941	2020-08-02 10:50:13	2020-08-02	8	[{"id_menu":5,"count":1}]	41777	pick-up	0	8
108942	2020-08-02 10:51:40	2020-08-02	12	[{"id_menu":3,"count":1}]	11946	pick-up	0	12
108943	2020-08-02 10:51:55	2020-08-02	12	[{"id_menu":1,"count":1}]	9494	delivery	5	17
108944	2020-08-02 10:52:13	2020-08-02	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	29134	pick-up	0	29
108945	2020-08-02 10:53:08	2020-08-02	17	[{"id_menu":4,"count":1}]	41859	delivery	5	22
108946	2020-08-02 10:54:25	2020-08-02	17	[{"id_menu":4,"count":1}]	26290	delivery	5	22
108947	2020-08-02 10:54:47	2020-08-02	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	41888	delivery	5	34
108948	2020-08-02 10:55:05	2020-08-02	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	18209	delivery	5	31
108949	2020-08-02 10:56:01	2020-08-02	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	24684	pick-up	0	35
108950	2020-08-02 10:57:47	2020-08-02	9	[{"id_menu":7,"count":1}]	19506	pick-up	0	9
108951	2020-08-02 10:58:02	2020-08-02	9	[{"id_menu":7,"count":1}]	13474	delivery	5	14
108952	2020-08-02 11:01:16	2020-08-02	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13319	pick-up	0	31
108953	2020-08-02 11:01:17	2020-08-02	9	[{"id_menu":7,"count":1}]	11517	delivery	5	14
108954	2020-08-02 11:02:51	2020-08-02	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	41977	delivery	5	57
108955	2020-08-02 11:03:08	2020-08-02	14	[{"id_menu":2,"count":1}]	41958	delivery	5	19
108956	2020-08-02 11:03:34	2020-08-02	8	[{"id_menu":5,"count":1}]	2989	pick-up	0	8
108957	2020-08-02 11:03:47	2020-08-02	12	[{"id_menu":3,"count":1}]	41870	delivery	5	17
108958	2020-08-02 11:06:56	2020-08-02	9	[{"id_menu":7,"count":1}]	17032	delivery	5	14
108959	2020-08-02 11:07:15	2020-08-02	8	[{"id_menu":5,"count":1}]	24838	delivery	5	13
108960	2020-08-02 11:09:00	2020-08-02	12	[{"id_menu":1,"count":1}]	10099	delivery	5	17
108961	2020-08-02 11:09:02	2020-08-02	9	[{"id_menu":6,"count":1}]	41801	delivery	5	14
108962	2020-08-02 11:09:53	2020-08-02	9	[{"id_menu":6,"count":1}]	25901	delivery	5	14
108963	2020-08-02 11:10:01	2020-08-02	8	[{"id_menu":5,"count":1}]	17046	delivery	5	13
108964	2020-08-02 11:10:35	2020-08-02	8	[{"id_menu":5,"count":2}]	41830	delivery	5	13
108965	2020-08-02 11:11:50	2020-08-02	9	[{"id_menu":6,"count":1}]	41823	delivery	5	14
108966	2020-08-02 11:18:00	2020-08-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	41712	delivery	5	22
108967	2020-08-02 11:18:18	2020-08-02	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	41827	delivery	5	36
108968	2020-08-02 11:19:08	2020-08-02	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	34463	delivery	5	31
108969	2020-08-02 11:19:47	2020-08-02	12	[{"id_menu":1,"count":1}]	13477	pick-up	0	12
108970	2020-08-02 11:22:34	2020-08-02	9	[{"id_menu":6,"count":1}]	1415	pick-up	0	9
108971	2020-08-02 11:23:42	2020-08-02	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	41732	delivery	5	22
108972	2020-08-02 11:24:14	2020-08-02	14	[{"id_menu":2,"count":1}]	32936	pick-up	0	14
108973	2020-08-02 11:25:12	2020-08-02	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	4205	delivery	5	26
108974	2020-08-02 11:27:47	2020-08-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	11709	delivery	5	28
108975	2020-08-02 11:31:12	2020-08-02	9	[{"id_menu":6,"count":1}]	27189	delivery	5	14
108976	2020-08-02 11:31:21	2020-08-02	8	[{"id_menu":5,"count":1}]	5957	delivery	5	13
108977	2020-08-02 11:31:54	2020-08-02	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2274	pick-up	0	48
108978	2020-08-02 11:32:40	2020-08-02	14	[{"id_menu":2,"count":1}]	28054	delivery	5	19
108979	2020-08-02 11:33:19	2020-08-02	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1462	delivery	5	36
108980	2020-08-02 11:33:50	2020-08-02	9	[{"id_menu":7,"count":1}]	25420	delivery	5	14
108981	2020-08-02 11:34:39	2020-08-02	12	[{"id_menu":1,"count":1}]	24950	pick-up	0	12
108982	2020-08-02 11:36:02	2020-08-02	8	[{"id_menu":5,"count":2}]	24639	delivery	5	13
108983	2020-08-02 11:37:05	2020-08-02	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	23427	delivery	5	31
108984	2020-08-02 11:38:41	2020-08-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	24047	delivery	5	28
108985	2020-08-02 11:39:46	2020-08-02	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	29881	pick-up	0	20
108986	2020-08-02 11:42:53	2020-08-02	14	[{"id_menu":2,"count":1}]	17964	delivery	5	19
108987	2020-08-02 11:44:58	2020-08-02	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	14495	delivery	5	34
108988	2020-08-02 11:47:13	2020-08-02	17	[{"id_menu":4,"count":1}]	12183	pick-up	0	17
108989	2020-08-02 11:47:25	2020-08-02	12	[{"id_menu":3,"count":1}]	41858	delivery	5	17
108990	2020-08-02 11:48:01	2020-08-02	9	[{"id_menu":6,"count":1}]	3584	delivery	5	14
108991	2020-08-02 11:48:38	2020-08-02	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41763	delivery	5	45
108992	2020-08-02 11:49:34	2020-08-02	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	41857	delivery	5	39
108993	2020-08-02 11:50:40	2020-08-02	9	[{"id_menu":7,"count":1}]	35420	delivery	5	14
108994	2020-08-02 11:51:17	2020-08-02	8	[{"id_menu":5,"count":1}]	2616	pick-up	0	8
108995	2020-08-02 11:51:26	2020-08-02	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18007	delivery	5	46
108996	2020-08-02 11:58:36	2020-08-02	9	[{"id_menu":6,"count":1}]	21690	delivery	5	14
108997	2020-08-02 12:01:09	2020-08-02	8	[{"id_menu":5,"count":1}]	32458	pick-up	0	8
108998	2020-08-02 12:02:39	2020-08-02	12	[{"id_menu":3,"count":1}]	389	delivery	5	17
108999	2020-08-02 12:06:47	2020-08-02	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	18682	delivery	5	45
109000	2020-08-02 12:08:06	2020-08-02	8	[{"id_menu":5,"count":1}]	19386	delivery	5	13
109001	2020-08-02 12:08:13	2020-08-02	9	[{"id_menu":6,"count":1}]	1297	delivery	5	14
109002	2020-08-02 12:10:05	2020-08-02	9	[{"id_menu":6,"count":1}]	25623	delivery	5	14
109003	2020-08-02 12:12:16	2020-08-02	12	[{"id_menu":1,"count":1}]	34311	delivery	5	17
109004	2020-08-02 12:12:29	2020-08-02	8	[{"id_menu":5,"count":1}]	27660	delivery	5	13
109005	2020-08-02 12:12:54	2020-08-02	17	[{"id_menu":4,"count":1}]	35266	pick-up	0	17
109006	2020-08-02 12:14:30	2020-08-02	9	[{"id_menu":6,"count":1}]	41876	pick-up	0	9
109007	2020-08-02 12:16:32	2020-08-02	12	[{"id_menu":3,"count":1}]	6496	delivery	5	17
109008	2020-08-02 12:17:48	2020-08-02	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	41855	delivery	5	36
109009	2020-08-02 12:18:15	2020-08-02	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	5141	pick-up	0	24
109010	2020-08-02 12:19:56	2020-08-02	14	[{"id_menu":2,"count":1}]	13953	delivery	5	19
109011	2020-08-02 12:21:23	2020-08-02	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	19313	pick-up	0	31
109012	2020-08-02 12:21:33	2020-08-02	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	41743	delivery	5	26
109013	2020-08-02 12:23:02	2020-08-02	9	[{"id_menu":7,"count":1}]	38606	delivery	5	14
109014	2020-08-02 12:23:54	2020-08-02	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	26382	delivery	5	51
109015	2020-08-02 12:23:59	2020-08-02	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4223	pick-up	0	29
109016	2020-08-02 12:25:29	2020-08-02	14	[{"id_menu":2,"count":1}]	33220	pick-up	0	14
109017	2020-08-02 12:25:45	2020-08-02	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	31631	delivery	5	22
109018	2020-08-02 12:26:44	2020-08-02	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1255	pick-up	0	21
109019	2020-08-02 12:29:11	2020-08-02	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2056	pick-up	0	26
109020	2020-08-02 12:30:54	2020-08-02	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	1700	pick-up	0	21
109021	2020-08-02 12:31:16	2020-08-02	9	[{"id_menu":6,"count":1}]	4758	pick-up	0	9
109022	2020-08-02 12:42:47	2020-08-02	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	28446	pick-up	0	29
109023	2020-08-02 12:43:39	2020-08-02	12	[{"id_menu":1,"count":3}]	32208	delivery	5	17
109024	2020-08-02 12:51:33	2020-08-02	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	37142	pick-up	0	29
109025	2020-08-02 12:54:36	2020-08-02	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	29693	delivery	5	45
109026	2020-08-02 12:57:43	2020-08-02	17	[{"id_menu":4,"count":1}]	23931	pick-up	0	17
109027	2020-08-02 12:57:52	2020-08-02	9	[{"id_menu":6,"count":1}]	41251	delivery	5	14
109028	2020-08-02 12:59:53	2020-08-02	17	[{"id_menu":4,"count":1}]	21596	delivery	5	22
109029	2020-08-02 13:01:57	2020-08-02	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	41736	delivery	5	26
109030	2020-08-02 13:04:23	2020-08-02	8	[{"id_menu":5,"count":1}]	2854	delivery	5	13
109031	2020-08-02 13:04:39	2020-08-02	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	41929	delivery	5	28
109032	2020-08-02 13:05:51	2020-08-02	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	14984	delivery	5	43
109033	2020-08-02 13:10:13	2020-08-02	17	[{"id_menu":4,"count":1}]	40862	delivery	5	22
109034	2020-08-02 13:10:55	2020-08-02	8	[{"id_menu":5,"count":1}]	40098	delivery	5	13
109035	2020-08-02 13:14:16	2020-08-02	17	[{"id_menu":4,"count":1}]	581	delivery	5	22
109036	2020-08-02 13:19:33	2020-08-02	9	[{"id_menu":7,"count":1}]	41846	delivery	5	14
109037	2020-08-02 13:20:37	2020-08-02	9	[{"id_menu":6,"count":1}]	17503	delivery	5	14
109038	2020-08-02 13:21:35	2020-08-02	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	13000	delivery	5	27
109039	2020-08-02 13:22:58	2020-08-02	8	[{"id_menu":5,"count":1}]	7519	delivery	5	13
109040	2020-08-02 13:24:05	2020-08-02	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6028	delivery	5	31
109041	2020-08-02 13:24:16	2020-08-02	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	684	pick-up	0	31
109042	2020-08-02 13:24:55	2020-08-02	9	[{"id_menu":6,"count":1}]	38729	delivery	5	14
109043	2020-08-02 13:26:04	2020-08-02	14	[{"id_menu":2,"count":1}]	41948	delivery	5	19
109044	2020-08-02 13:26:37	2020-08-02	9	[{"id_menu":6,"count":2}]	41911	delivery	5	14
109045	2020-08-02 13:27:26	2020-08-02	12	[{"id_menu":3,"count":1}]	1203	pick-up	0	12
109046	2020-08-02 13:28:40	2020-08-02	14	[{"id_menu":2,"count":1}]	41890	delivery	5	19
109047	2020-08-02 13:30:51	2020-08-02	14	[{"id_menu":2,"count":1}]	2980	delivery	5	19
109048	2020-08-02 13:31:20	2020-08-02	9	[{"id_menu":6,"count":2}]	6415	pick-up	0	9
109049	2020-08-02 13:31:22	2020-08-02	12	[{"id_menu":1,"count":1}]	41624	pick-up	0	12
109050	2020-08-02 13:32:08	2020-08-02	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	29697	delivery	5	36
109051	2020-08-02 13:32:28	2020-08-02	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41733	delivery	5	52
109052	2020-08-02 13:33:55	2020-08-02	12	[{"id_menu":3,"count":1}]	31235	delivery	5	17
109053	2020-08-02 13:36:13	2020-08-02	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11206	delivery	5	31
109054	2020-08-02 13:37:16	2020-08-02	9	[{"id_menu":6,"count":1}]	10106	delivery	5	14
109055	2020-08-02 13:37:33	2020-08-02	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	8146	delivery	5	31
109056	2020-08-02 13:38:40	2020-08-02	9	[{"id_menu":7,"count":1}]	9391	delivery	5	14
109057	2020-08-02 13:42:47	2020-08-02	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	11613	delivery	5	26
109058	2020-08-02 13:43:08	2020-08-02	12	[{"id_menu":1,"count":1}]	41884	delivery	5	17
109059	2020-08-02 13:44:47	2020-08-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	41934	delivery	5	31
109060	2020-08-02 13:45:12	2020-08-02	9	[{"id_menu":6,"count":1}]	33345	delivery	5	14
109061	2020-08-02 13:45:35	2020-08-02	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	30597	delivery	5	31
109062	2020-08-02 13:47:58	2020-08-02	39	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	41760	delivery	5	44
109063	2020-08-02 13:49:06	2020-08-02	9	[{"id_menu":6,"count":1}]	9191	pick-up	0	9
109064	2020-08-02 13:49:51	2020-08-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":3}]	12517	delivery	5	31
109065	2020-08-02 13:50:01	2020-08-02	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	41820	delivery	5	43
109066	2020-08-02 13:51:54	2020-08-02	9	[{"id_menu":7,"count":1}]	33059	delivery	5	14
109067	2020-08-02 13:52:09	2020-08-02	8	[{"id_menu":5,"count":1}]	41781	delivery	5	13
109068	2020-08-02 13:52:10	2020-08-02	14	[{"id_menu":2,"count":1}]	41945	delivery	5	19
109069	2020-08-02 13:52:12	2020-08-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28405	delivery	5	22
109070	2020-08-02 13:52:56	2020-08-02	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	41735	delivery	5	31
109071	2020-08-02 13:54:46	2020-08-02	14	[{"id_menu":2,"count":1}]	6565	pick-up	0	14
109072	2020-08-02 13:55:06	2020-08-02	8	[{"id_menu":5,"count":1}]	2413	pick-up	0	8
109073	2020-08-02 13:55:39	2020-08-02	14	[{"id_menu":2,"count":1}]	260	pick-up	0	14
109074	2020-08-02 13:57:03	2020-08-02	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	13320	delivery	5	26
109075	2020-08-02 13:57:42	2020-08-02	12	[{"id_menu":3,"count":1}]	25571	pick-up	0	12
109076	2020-08-02 13:59:34	2020-08-02	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	29231	pick-up	0	21
109077	2020-08-02 13:59:43	2020-08-02	9	[{"id_menu":7,"count":1}]	1720	pick-up	0	9
109078	2020-08-02 14:02:20	2020-08-02	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	19968	delivery	5	56
109079	2020-08-02 14:06:40	2020-08-02	17	[{"id_menu":4,"count":1}]	11266	delivery	5	22
109080	2020-08-02 14:07:02	2020-08-02	12	[{"id_menu":1,"count":1}]	34644	delivery	5	17
109081	2020-08-02 14:07:43	2020-08-02	9	[{"id_menu":7,"count":2}]	41868	delivery	5	14
109082	2020-08-02 14:08:06	2020-08-02	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19827	pick-up	0	17
109083	2020-08-02 14:09:33	2020-08-02	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	41776	delivery	5	39
109084	2020-08-02 14:12:49	2020-08-02	12	[{"id_menu":3,"count":1}]	21636	delivery	5	17
109085	2020-08-02 14:16:14	2020-08-02	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	41796	delivery	5	22
109086	2020-08-02 14:16:26	2020-08-02	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	22210	delivery	5	36
109087	2020-08-02 14:17:57	2020-08-02	29	[{"id_menu":3,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15188	delivery	5	34
109088	2020-08-02 14:19:03	2020-08-02	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	27124	delivery	5	28
109089	2020-08-02 14:27:55	2020-08-02	14	[{"id_menu":2,"count":1}]	41881	delivery	5	19
109090	2020-08-02 14:30:41	2020-08-02	14	[{"id_menu":2,"count":1}]	35838	delivery	5	19
109091	2020-08-02 14:31:48	2020-08-02	14	[{"id_menu":2,"count":1}]	33575	delivery	5	19
109092	2020-08-02 14:39:42	2020-08-02	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	41792	delivery	5	39
109093	2020-08-02 14:44:48	2020-08-02	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7451	delivery	5	39
109094	2020-08-02 14:46:03	2020-08-02	14	[{"id_menu":2,"count":1}]	15082	pick-up	0	14
109095	2020-08-02 14:47:24	2020-08-02	8	[{"id_menu":5,"count":1}]	15304	delivery	5	13
109096	2020-08-02 14:50:24	2020-08-02	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":3}]	27539	delivery	5	26
109097	2020-08-02 14:51:28	2020-08-02	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3048	delivery	5	28
109098	2020-08-02 14:52:06	2020-08-02	9	[{"id_menu":6,"count":2}]	27397	delivery	5	14
109099	2020-08-02 14:52:17	2020-08-02	9	[{"id_menu":6,"count":1}]	39740	delivery	5	14
109100	2020-08-02 14:54:44	2020-08-02	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41909	delivery	5	52
109101	2020-08-02 14:56:59	2020-08-02	17	[{"id_menu":4,"count":1}]	13497	pick-up	0	17
109102	2020-08-02 14:57:45	2020-08-02	14	[{"id_menu":2,"count":1}]	25390	delivery	5	19
109103	2020-08-02 14:58:34	2020-08-02	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	1355	delivery	5	45
109104	2020-08-02 15:00:57	2020-08-02	12	[{"id_menu":3,"count":1}]	39024	delivery	5	17
109105	2020-08-02 15:01:08	2020-08-02	14	[{"id_menu":2,"count":1}]	41871	delivery	5	19
109106	2020-08-02 15:01:15	2020-08-02	17	[{"id_menu":4,"count":1}]	5387	pick-up	0	17
109107	2020-08-02 15:06:58	2020-08-02	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	21623	delivery	5	31
109108	2020-08-02 15:07:11	2020-08-02	12	[{"id_menu":1,"count":1}]	7574	delivery	5	17
109109	2020-08-02 15:07:35	2020-08-02	9	[{"id_menu":6,"count":1}]	37068	delivery	5	14
109110	2020-08-02 15:07:44	2020-08-02	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9166	delivery	5	34
109111	2020-08-02 15:09:43	2020-08-02	12	[{"id_menu":1,"count":1}]	26024	delivery	5	17
109112	2020-08-02 15:09:55	2020-08-02	14	[{"id_menu":2,"count":1}]	6876	delivery	5	19
109113	2020-08-02 15:10:29	2020-08-02	9	[{"id_menu":7,"count":1}]	41953	delivery	5	14
109114	2020-08-02 15:10:49	2020-08-02	17	[{"id_menu":4,"count":1}]	21615	delivery	5	22
109115	2020-08-02 15:11:44	2020-08-02	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	17038	delivery	5	35
109116	2020-08-02 15:12:01	2020-08-02	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	41744	delivery	5	26
109117	2020-08-02 15:12:05	2020-08-02	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	41968	delivery	5	37
109118	2020-08-02 15:18:10	2020-08-02	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	3160	delivery	5	31
109119	2020-08-02 15:19:52	2020-08-02	17	[{"id_menu":4,"count":1}]	11241	delivery	5	22
109120	2020-08-02 15:23:06	2020-08-02	9	[{"id_menu":6,"count":1}]	41747	pick-up	0	9
109121	2020-08-02 15:24:22	2020-08-02	9	[{"id_menu":6,"count":1}]	31947	delivery	5	14
109122	2020-08-02 15:27:44	2020-08-02	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	36612	delivery	5	36
109123	2020-08-02 15:27:56	2020-08-02	9	[{"id_menu":7,"count":2}]	23278	delivery	5	14
109124	2020-08-02 15:28:05	2020-08-02	9	[{"id_menu":6,"count":1}]	13120	pick-up	0	9
109125	2020-08-02 15:28:17	2020-08-02	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	37041	delivery	5	26
109126	2020-08-02 15:28:54	2020-08-02	8	[{"id_menu":5,"count":1}]	19442	pick-up	0	8
109127	2020-08-02 15:30:26	2020-08-02	9	[{"id_menu":7,"count":2}]	25986	delivery	5	14
109128	2020-08-02 15:31:00	2020-08-02	12	[{"id_menu":3,"count":1}]	817	pick-up	0	12
109129	2020-08-02 15:31:01	2020-08-02	9	[{"id_menu":6,"count":1}]	40944	delivery	5	14
109130	2020-08-02 15:31:54	2020-08-02	8	[{"id_menu":5,"count":1}]	5232	pick-up	0	8
109131	2020-08-02 15:33:35	2020-08-02	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	33938	delivery	5	37
109132	2020-08-02 15:34:24	2020-08-02	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	41980	delivery	5	28
109133	2020-08-02 15:35:39	2020-08-02	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2627	pick-up	0	23
109134	2020-08-02 15:39:38	2020-08-02	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	41847	delivery	5	27
109135	2020-08-02 15:40:47	2020-08-02	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	33452	delivery	5	25
109136	2020-08-02 15:41:22	2020-08-02	9	[{"id_menu":6,"count":1}]	17540	pick-up	0	9
109137	2020-08-02 15:42:34	2020-08-02	12	[{"id_menu":3,"count":1}]	3151	pick-up	0	12
109138	2020-08-02 15:43:09	2020-08-02	17	[{"id_menu":4,"count":3}]	39429	delivery	5	22
109139	2020-08-02 15:43:35	2020-08-02	9	[{"id_menu":6,"count":1}]	17245	pick-up	0	9
109140	2020-08-02 15:44:33	2020-08-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24676	pick-up	0	17
109141	2020-08-02 15:44:56	2020-08-02	12	[{"id_menu":3,"count":1}]	8952	delivery	5	17
109142	2020-08-02 15:46:48	2020-08-02	12	[{"id_menu":1,"count":1}]	16867	delivery	5	17
109143	2020-08-02 15:49:11	2020-08-02	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	41889	delivery	5	36
109144	2020-08-02 15:52:09	2020-08-02	9	[{"id_menu":6,"count":1}]	20430	delivery	5	14
109145	2020-08-02 15:54:48	2020-08-02	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	41761	delivery	5	40
109146	2020-08-02 15:59:07	2020-08-02	17	[{"id_menu":4,"count":1}]	41812	delivery	5	22
109147	2020-08-02 16:00:59	2020-08-02	8	[{"id_menu":5,"count":1}]	16570	delivery	5	13
109148	2020-08-02 16:03:10	2020-08-02	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	34252	delivery	5	30
109149	2020-08-02 16:04:40	2020-08-02	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10016	delivery	5	47
109150	2020-08-02 16:05:32	2020-08-02	9	[{"id_menu":6,"count":1}]	13667	delivery	5	14
109151	2020-08-02 16:05:41	2020-08-02	8	[{"id_menu":5,"count":1}]	41344	delivery	5	13
109152	2020-08-02 16:06:01	2020-08-02	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	41771	delivery	5	39
109153	2020-08-02 16:08:48	2020-08-02	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	41810	delivery	5	34
109154	2020-08-02 16:09:09	2020-08-02	12	[{"id_menu":3,"count":1}]	41943	delivery	5	17
109155	2020-08-02 16:11:28	2020-08-02	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	41965	delivery	5	31
109156	2020-08-02 16:16:15	2020-08-02	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	26090	delivery	5	22
109157	2020-08-02 16:16:38	2020-08-02	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	6201	delivery	5	40
109158	2020-08-02 16:17:24	2020-08-02	17	[{"id_menu":4,"count":1}]	22328	delivery	5	22
109159	2020-08-02 16:18:58	2020-08-02	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1879	pick-up	0	20
109160	2020-08-02 16:21:52	2020-08-02	12	[{"id_menu":3,"count":1}]	39996	pick-up	0	12
109161	2020-08-02 16:22:11	2020-08-02	12	[{"id_menu":3,"count":1}]	41731	delivery	5	17
109162	2020-08-02 16:24:39	2020-08-02	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	30659	delivery	5	26
109163	2020-08-02 16:26:13	2020-08-02	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	5097	delivery	5	25
109164	2020-08-02 16:26:44	2020-08-02	12	[{"id_menu":1,"count":1}]	30474	delivery	5	17
109165	2020-08-02 16:27:19	2020-08-02	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	39118	delivery	5	38
109166	2020-08-02 16:27:27	2020-08-02	9	[{"id_menu":6,"count":1}]	11732	delivery	5	14
109167	2020-08-02 16:28:19	2020-08-02	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	8651	delivery	5	26
109168	2020-08-02 16:28:28	2020-08-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	41967	delivery	5	31
109169	2020-08-02 16:28:54	2020-08-02	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	21031	delivery	5	31
109170	2020-08-02 16:30:33	2020-08-02	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	20080	delivery	5	39
109171	2020-08-02 16:34:52	2020-08-02	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	9011	delivery	5	31
109172	2020-08-02 16:38:25	2020-08-02	9	[{"id_menu":7,"count":1}]	41742	delivery	5	14
109173	2020-08-02 16:38:40	2020-08-02	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	41900	pick-up	0	21
109174	2020-08-02 16:39:08	2020-08-02	9	[{"id_menu":7,"count":1}]	40816	delivery	5	14
109175	2020-08-02 16:41:04	2020-08-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18716	delivery	5	23
109176	2020-08-02 16:42:50	2020-08-02	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	25502	delivery	5	43
109177	2020-08-02 16:44:05	2020-08-02	9	[{"id_menu":6,"count":1}]	30247	delivery	5	14
109178	2020-08-02 16:45:26	2020-08-02	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	7415	pick-up	0	21
109179	2020-08-02 16:50:47	2020-08-02	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	25202	delivery	5	34
109180	2020-08-02 16:53:16	2020-08-02	8	[{"id_menu":5,"count":1}]	41841	delivery	5	13
109181	2020-08-02 16:53:20	2020-08-02	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41930	delivery	5	54
109182	2020-08-02 16:55:02	2020-08-02	9	[{"id_menu":6,"count":1}]	29528	delivery	5	14
109183	2020-08-02 16:59:39	2020-08-02	9	[{"id_menu":6,"count":1}]	41837	delivery	5	14
109184	2020-08-02 17:00:21	2020-08-02	12	[{"id_menu":1,"count":1}]	41892	pick-up	0	12
109185	2020-08-02 17:01:51	2020-08-02	14	[{"id_menu":2,"count":1}]	31570	pick-up	0	14
109186	2020-08-02 17:04:24	2020-08-02	14	[{"id_menu":2,"count":1}]	41949	delivery	5	19
109187	2020-08-02 17:10:42	2020-08-02	8	[{"id_menu":5,"count":1}]	19582	delivery	5	13
109188	2020-08-02 17:13:05	2020-08-02	14	[{"id_menu":2,"count":1}]	10785	delivery	5	19
109189	2020-08-02 17:15:11	2020-08-02	9	[{"id_menu":7,"count":1}]	41947	delivery	5	14
109190	2020-08-02 17:15:42	2020-08-02	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	34075	delivery	5	45
109191	2020-08-02 17:16:39	2020-08-02	9	[{"id_menu":6,"count":1}]	8169	pick-up	0	9
109192	2020-08-02 17:17:54	2020-08-02	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19720	delivery	5	35
109193	2020-08-02 17:18:17	2020-08-02	8	[{"id_menu":5,"count":1}]	4072	pick-up	0	8
109194	2020-08-02 17:18:59	2020-08-02	9	[{"id_menu":6,"count":1}]	25468	delivery	5	14
109195	2020-08-02 17:19:04	2020-08-02	9	[{"id_menu":7,"count":1}]	13507	delivery	5	14
109196	2020-08-02 17:22:30	2020-08-02	12	[{"id_menu":1,"count":1}]	35722	pick-up	0	12
109197	2020-08-02 17:22:35	2020-08-02	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	41717	delivery	5	52
109198	2020-08-02 17:25:07	2020-08-02	9	[{"id_menu":7,"count":1}]	25865	delivery	5	14
109199	2020-08-02 17:26:14	2020-08-02	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	41905	delivery	5	23
109200	2020-08-02 17:28:11	2020-08-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3102	pick-up	0	23
109201	2020-08-02 17:28:17	2020-08-02	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	7098	pick-up	0	38
109202	2020-08-02 17:30:26	2020-08-02	17	[{"id_menu":4,"count":1}]	37796	delivery	5	22
109203	2020-08-02 17:31:18	2020-08-02	12	[{"id_menu":3,"count":1}]	76	pick-up	0	12
109204	2020-08-02 17:31:27	2020-08-02	9	[{"id_menu":7,"count":1}]	2761	delivery	5	14
109205	2020-08-02 17:31:32	2020-08-02	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	37597	delivery	5	52
109206	2020-08-02 17:34:10	2020-08-02	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1335	pick-up	0	29
109207	2020-08-02 17:34:26	2020-08-02	17	[{"id_menu":4,"count":1}]	18602	pick-up	0	17
109208	2020-08-02 17:35:18	2020-08-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2928	delivery	5	28
109209	2020-08-02 17:40:43	2020-08-02	17	[{"id_menu":4,"count":1}]	41951	pick-up	0	17
109210	2020-08-02 17:41:22	2020-08-02	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13040	delivery	5	45
109211	2020-08-02 17:44:14	2020-08-02	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	6708	pick-up	0	26
109212	2020-08-02 17:45:07	2020-08-02	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	13660	delivery	5	25
109213	2020-08-02 17:45:20	2020-08-02	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	31037	delivery	5	31
109214	2020-08-02 17:50:42	2020-08-02	9	[{"id_menu":7,"count":1}]	3066	delivery	5	14
109215	2020-08-02 17:51:33	2020-08-02	9	[{"id_menu":7,"count":1}]	41753	delivery	5	14
109216	2020-08-02 17:54:34	2020-08-02	14	[{"id_menu":2,"count":1}]	40570	delivery	5	19
109217	2020-08-02 17:59:04	2020-08-02	8	[{"id_menu":5,"count":1}]	41798	delivery	5	13
109218	2020-08-02 17:59:10	2020-08-02	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1952	delivery	5	27
109219	2020-08-02 17:59:44	2020-08-02	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	17226	delivery	5	26
109220	2020-08-02 18:02:33	2020-08-02	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	1293	delivery	5	28
109221	2020-08-02 18:02:58	2020-08-02	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	28225	pick-up	0	31
109222	2020-08-02 18:04:18	2020-08-02	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	41978	delivery	5	27
109223	2020-08-02 18:05:05	2020-08-02	9	[{"id_menu":7,"count":3}]	41896	delivery	5	14
109224	2020-08-02 18:07:10	2020-08-02	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	38872	delivery	5	26
109225	2020-08-02 18:07:24	2020-08-02	12	[{"id_menu":3,"count":1}]	27651	delivery	5	17
109226	2020-08-02 18:08:38	2020-08-02	8	[{"id_menu":5,"count":1}]	18353	pick-up	0	8
109227	2020-08-02 18:08:45	2020-08-02	8	[{"id_menu":5,"count":1}]	10613	delivery	5	13
109228	2020-08-02 18:09:54	2020-08-02	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	25079	delivery	5	31
109229	2020-08-02 18:09:55	2020-08-02	9	[{"id_menu":7,"count":1}]	22478	delivery	5	14
109230	2020-08-02 18:09:56	2020-08-02	9	[{"id_menu":7,"count":1}]	16621	delivery	5	14
109231	2020-08-02 18:10:27	2020-08-02	17	[{"id_menu":4,"count":1}]	33107	delivery	5	22
109232	2020-08-02 18:17:42	2020-08-02	9	[{"id_menu":6,"count":1}]	41938	delivery	5	14
109233	2020-08-02 18:21:01	2020-08-02	17	[{"id_menu":4,"count":1}]	25664	delivery	5	22
109234	2020-08-02 18:22:50	2020-08-02	14	[{"id_menu":2,"count":1}]	20333	delivery	5	19
109235	2020-08-02 18:24:40	2020-08-02	9	[{"id_menu":7,"count":1}]	41790	delivery	5	14
109236	2020-08-02 18:25:10	2020-08-02	14	[{"id_menu":2,"count":1}]	30106	delivery	5	19
109237	2020-08-02 18:25:45	2020-08-02	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	29678	pick-up	0	22
109238	2020-08-02 18:26:55	2020-08-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39323	delivery	5	23
109239	2020-08-02 18:30:37	2020-08-02	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	7582	delivery	5	29
109240	2020-08-02 18:32:13	2020-08-02	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	41919	delivery	5	26
109241	2020-08-02 18:33:21	2020-08-02	8	[{"id_menu":5,"count":1}]	2651	delivery	5	13
109242	2020-08-02 18:37:15	2020-08-02	14	[{"id_menu":2,"count":1}]	22320	pick-up	0	14
109243	2020-08-02 18:38:09	2020-08-02	9	[{"id_menu":6,"count":1}]	41903	delivery	5	14
109244	2020-08-02 18:40:33	2020-08-02	8	[{"id_menu":5,"count":1}]	41782	delivery	5	13
109245	2020-08-02 18:40:55	2020-08-02	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29898	delivery	5	36
109246	2020-08-02 18:41:00	2020-08-02	12	[{"id_menu":3,"count":1}]	30878	delivery	5	17
109247	2020-08-02 18:42:09	2020-08-02	9	[{"id_menu":6,"count":1}]	35818	delivery	5	14
109248	2020-08-02 18:43:04	2020-08-02	17	[{"id_menu":4,"count":1}]	9847	pick-up	0	17
109249	2020-08-02 18:43:28	2020-08-02	9	[{"id_menu":7,"count":1}]	35012	delivery	5	14
109250	2020-08-02 18:47:14	2020-08-02	17	[{"id_menu":4,"count":2}]	41779	delivery	5	22
109251	2020-08-02 18:48:10	2020-08-02	8	[{"id_menu":5,"count":1}]	41795	delivery	5	13
109252	2020-08-02 18:48:55	2020-08-02	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3434	delivery	5	31
109253	2020-08-02 18:50:48	2020-08-02	9	[{"id_menu":7,"count":1}]	8397	delivery	5	14
109254	2020-08-02 18:52:13	2020-08-02	9	[{"id_menu":7,"count":1}]	41839	delivery	5	14
109255	2020-08-02 18:55:44	2020-08-02	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	35763	delivery	5	27
109256	2020-08-02 18:57:06	2020-08-02	12	[{"id_menu":1,"count":1}]	41797	pick-up	0	12
109257	2020-08-02 18:57:42	2020-08-02	14	[{"id_menu":2,"count":1}]	15961	pick-up	0	14
109258	2020-08-02 18:58:52	2020-08-02	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	37473	delivery	5	44
109259	2020-08-02 18:58:57	2020-08-02	12	[{"id_menu":1,"count":1}]	41826	delivery	5	17
109260	2020-08-02 18:59:59	2020-08-02	14	[{"id_menu":2,"count":1}]	41786	delivery	5	19
109261	2020-08-02 19:05:43	2020-08-02	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3148	delivery	5	36
109262	2020-08-02 19:07:14	2020-08-02	8	[{"id_menu":5,"count":1}]	3901	delivery	5	13
109263	2020-08-02 19:09:02	2020-08-02	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	18643	pick-up	0	50
109264	2020-08-02 19:11:31	2020-08-02	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	26163	delivery	5	34
109265	2020-08-02 19:17:56	2020-08-02	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	41754	delivery	5	34
109266	2020-08-02 19:18:04	2020-08-02	9	[{"id_menu":6,"count":1}]	41906	delivery	5	14
109267	2020-08-02 19:19:06	2020-08-02	9	[{"id_menu":6,"count":1}]	41850	delivery	5	14
109268	2020-08-02 19:19:49	2020-08-02	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16870	delivery	5	36
109269	2020-08-02 19:21:22	2020-08-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28442	pick-up	0	17
109270	2020-08-02 19:22:44	2020-08-02	8	[{"id_menu":5,"count":1}]	22531	delivery	5	13
109271	2020-08-02 19:31:37	2020-08-02	9	[{"id_menu":6,"count":1}]	695	pick-up	0	9
109272	2020-08-02 19:38:14	2020-08-02	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	26393	pick-up	0	29
109273	2020-08-02 19:39:12	2020-08-02	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":3}]	41728	delivery	5	26
109274	2020-08-02 19:40:00	2020-08-02	12	[{"id_menu":1,"count":1}]	41984	delivery	5	17
109275	2020-08-02 19:42:43	2020-08-02	9	[{"id_menu":6,"count":1}]	4594	delivery	5	14
109276	2020-08-02 19:46:23	2020-08-02	9	[{"id_menu":7,"count":1}]	19894	pick-up	0	9
109277	2020-08-02 19:51:19	2020-08-02	14	[{"id_menu":2,"count":1}]	215	pick-up	0	14
109278	2020-08-02 19:52:41	2020-08-02	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10489	delivery	5	35
109279	2020-08-02 19:52:42	2020-08-02	9	[{"id_menu":6,"count":1}]	1779	pick-up	0	9
109280	2020-08-02 19:53:10	2020-08-02	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	41840	delivery	5	28
109281	2020-08-02 19:53:12	2020-08-02	9	[{"id_menu":7,"count":1}]	27092	delivery	5	14
109282	2020-08-02 19:53:56	2020-08-02	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	23362	delivery	5	31
109283	2020-08-02 19:54:12	2020-08-02	14	[{"id_menu":2,"count":1}]	41914	delivery	5	19
109284	2020-08-02 19:55:35	2020-08-02	9	[{"id_menu":7,"count":1}]	13371	delivery	5	14
109285	2020-08-02 19:56:04	2020-08-02	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1774	pick-up	0	23
109286	2020-08-02 19:56:58	2020-08-02	8	[{"id_menu":5,"count":1}]	14756	delivery	5	13
109287	2020-08-02 20:00:03	2020-08-02	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	41751	delivery	5	35
109288	2020-08-02 20:01:15	2020-08-02	9	[{"id_menu":7,"count":1}]	41950	delivery	5	14
109289	2020-08-02 20:01:56	2020-08-02	9	[{"id_menu":7,"count":1}]	5325	delivery	5	14
109290	2020-08-02 20:02:37	2020-08-02	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41730	delivery	5	48
109291	2020-08-02 20:02:50	2020-08-02	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	35910	delivery	5	26
109292	2020-08-02 20:03:44	2020-08-02	14	[{"id_menu":2,"count":1}]	14010	pick-up	0	14
109293	2020-08-02 20:06:25	2020-08-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	41146	pick-up	0	23
109294	2020-08-02 20:12:03	2020-08-02	9	[{"id_menu":7,"count":1}]	10867	pick-up	0	9
109295	2020-08-02 20:14:35	2020-08-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41740	delivery	5	23
109296	2020-08-02 20:15:21	2020-08-02	9	[{"id_menu":6,"count":1}]	41784	delivery	5	14
109297	2020-08-02 20:15:49	2020-08-02	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	41808	delivery	5	30
109298	2020-08-02 20:16:02	2020-08-02	12	[{"id_menu":3,"count":1}]	27331	delivery	5	17
109299	2020-08-02 20:17:44	2020-08-02	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	16957	pick-up	0	21
109300	2020-08-02 20:17:59	2020-08-02	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	24575	delivery	5	31
109301	2020-08-02 20:18:38	2020-08-02	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	27960	delivery	5	31
109302	2020-08-02 20:18:53	2020-08-02	9	[{"id_menu":6,"count":1}]	41913	delivery	5	14
109303	2020-08-02 20:21:03	2020-08-02	17	[{"id_menu":4,"count":1}]	3895	delivery	5	22
109304	2020-08-02 20:23:12	2020-08-02	17	[{"id_menu":4,"count":1}]	465	pick-up	0	17
109305	2020-08-02 20:25:06	2020-08-02	12	[{"id_menu":3,"count":1}]	30747	delivery	5	17
109306	2020-08-02 20:25:07	2020-08-02	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	437	delivery	5	35
109307	2020-08-02 20:25:53	2020-08-02	12	[{"id_menu":1,"count":1}]	2025	delivery	5	17
109308	2020-08-02 20:31:17	2020-08-02	9	[{"id_menu":7,"count":1}]	41853	delivery	5	14
109309	2020-08-02 20:32:55	2020-08-02	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	27589	pick-up	0	38
109310	2020-08-02 20:33:06	2020-08-02	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8410	delivery	5	40
109311	2020-08-02 20:36:44	2020-08-02	14	[{"id_menu":2,"count":2}]	3023	delivery	5	19
109312	2020-08-02 20:39:01	2020-08-02	9	[{"id_menu":6,"count":1}]	16257	delivery	5	14
109313	2020-08-02 20:41:50	2020-08-02	12	[{"id_menu":1,"count":1}]	14764	delivery	5	17
109314	2020-08-02 20:44:25	2020-08-02	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	41848	pick-up	0	23
109315	2020-08-02 20:44:38	2020-08-02	9	[{"id_menu":6,"count":1}]	6159	delivery	5	14
109316	2020-08-02 20:45:01	2020-08-02	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	22311	delivery	5	34
109317	2020-08-02 20:46:31	2020-08-02	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	36949	delivery	5	27
109318	2020-08-02 20:47:03	2020-08-02	14	[{"id_menu":2,"count":1}]	41821	delivery	5	19
109319	2020-08-02 20:49:15	2020-08-02	14	[{"id_menu":2,"count":1}]	1076	pick-up	0	14
109320	2020-08-02 20:52:34	2020-08-02	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	6015	delivery	5	45
109321	2020-08-02 20:53:08	2020-08-02	9	[{"id_menu":7,"count":1}]	41901	delivery	5	14
109322	2020-08-02 20:53:48	2020-08-02	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	18129	delivery	5	42
109323	2020-08-02 20:53:52	2020-08-02	12	[{"id_menu":3,"count":1}]	41926	pick-up	0	12
109324	2020-08-02 20:54:43	2020-08-02	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	41773	delivery	5	43
109325	2020-08-02 20:56:50	2020-08-02	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18838	delivery	5	36
109326	2020-08-02 20:57:27	2020-08-02	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	10850	pick-up	0	34
109327	2020-08-02 21:00:38	2020-08-02	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	41203	delivery	5	39
109328	2020-08-02 21:01:32	2020-08-02	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23193	delivery	5	35
109329	2020-08-02 21:01:41	2020-08-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	15777	delivery	5	28
109330	2020-08-02 21:02:02	2020-08-02	9	[{"id_menu":6,"count":1}]	39671	delivery	5	14
109331	2020-08-02 21:03:38	2020-08-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7431	delivery	5	23
109332	2020-08-02 21:06:41	2020-08-02	9	[{"id_menu":7,"count":1}]	18591	delivery	5	14
109333	2020-08-02 21:06:59	2020-08-02	12	[{"id_menu":1,"count":1}]	41767	delivery	5	17
109334	2020-08-02 21:07:55	2020-08-02	8	[{"id_menu":5,"count":1}]	38367	pick-up	0	8
109335	2020-08-02 21:10:13	2020-08-02	8	[{"id_menu":5,"count":1}]	19549	delivery	5	13
109336	2020-08-02 21:13:32	2020-08-02	8	[{"id_menu":5,"count":1}]	41828	delivery	5	13
109337	2020-08-02 21:14:09	2020-08-02	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	31661	pick-up	0	22
109338	2020-08-02 21:16:08	2020-08-02	12	[{"id_menu":1,"count":1}]	41962	delivery	5	17
109339	2020-08-02 21:17:17	2020-08-02	14	[{"id_menu":2,"count":1}]	4935	delivery	5	19
109340	2020-08-02 21:17:42	2020-08-02	9	[{"id_menu":6,"count":2}]	41768	pick-up	0	9
109341	2020-08-02 21:21:29	2020-08-02	14	[{"id_menu":2,"count":1}]	40180	delivery	5	19
109342	2020-08-02 21:23:23	2020-08-02	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37014	delivery	5	35
109343	2020-08-02 21:24:47	2020-08-02	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	41963	delivery	5	22
109344	2020-08-02 21:25:58	2020-08-02	9	[{"id_menu":6,"count":1}]	7253	delivery	5	14
109345	2020-08-02 21:26:28	2020-08-02	8	[{"id_menu":5,"count":1}]	20095	delivery	5	13
109346	2020-08-02 21:30:10	2020-08-02	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	18322	delivery	5	40
109347	2020-08-02 21:30:38	2020-08-02	14	[{"id_menu":2,"count":1}]	41007	delivery	5	19
109348	2020-08-02 21:31:19	2020-08-02	14	[{"id_menu":2,"count":1}]	9682	delivery	5	19
109349	2020-08-02 21:33:51	2020-08-02	17	[{"id_menu":4,"count":1}]	3640	pick-up	0	17
109350	2020-08-02 21:36:05	2020-08-02	12	[{"id_menu":1,"count":1}]	7229	delivery	5	17
109351	2020-08-02 21:36:20	2020-08-02	9	[{"id_menu":6,"count":1}]	17444	delivery	5	14
109352	2020-08-02 21:37:11	2020-08-02	17	[{"id_menu":4,"count":1}]	41814	delivery	5	22
109353	2020-08-02 21:42:01	2020-08-02	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	38950	delivery	5	26
109354	2020-08-02 21:43:45	2020-08-02	9	[{"id_menu":6,"count":1}]	15036	delivery	5	14
109355	2020-08-02 21:44:05	2020-08-02	9	[{"id_menu":6,"count":1}]	41961	delivery	5	14
109356	2020-08-02 21:44:23	2020-08-02	12	[{"id_menu":1,"count":1}]	14149	delivery	5	17
109357	2020-08-02 21:44:45	2020-08-02	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	41960	delivery	5	43
109358	2020-08-02 21:49:36	2020-08-02	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	39432	delivery	5	28
109359	2020-08-02 21:53:38	2020-08-02	9	[{"id_menu":6,"count":1}]	39515	delivery	5	14
109360	2020-08-02 21:53:58	2020-08-02	12	[{"id_menu":3,"count":1}]	1513	pick-up	0	12
109361	2020-08-02 22:00:24	2020-08-02	14	[{"id_menu":2,"count":2}]	10357	delivery	5	19
109362	2020-08-02 22:00:44	2020-08-02	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	41885	delivery	5	25
109363	2020-08-02 22:02:56	2020-08-02	9	[{"id_menu":6,"count":1}]	11758	delivery	5	14
109364	2020-08-02 22:03:33	2020-08-02	17	[{"id_menu":4,"count":1}]	18546	delivery	5	22
109365	2020-08-02 22:03:40	2020-08-02	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	21377	delivery	5	42
109366	2020-08-02 22:06:55	2020-08-02	17	[{"id_menu":4,"count":2}]	41770	delivery	5	22
109367	2020-08-02 22:07:40	2020-08-02	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	34253	delivery	5	43
109368	2020-08-02 22:08:18	2020-08-02	9	[{"id_menu":7,"count":1}]	36412	delivery	5	14
109369	2020-08-02 22:09:06	2020-08-02	14	[{"id_menu":2,"count":1}]	41985	delivery	5	19
109370	2020-08-02 22:11:09	2020-08-02	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	30311	delivery	5	48
109371	2020-08-02 22:12:51	2020-08-02	14	[{"id_menu":2,"count":2}]	30301	pick-up	0	14
109372	2020-08-02 22:14:41	2020-08-02	9	[{"id_menu":6,"count":1}]	29800	pick-up	0	9
109373	2020-08-02 22:14:59	2020-08-02	8	[{"id_menu":5,"count":1}]	9854	pick-up	0	8
109374	2020-08-02 22:18:42	2020-08-02	17	[{"id_menu":4,"count":1}]	1244	delivery	5	22
109375	2020-08-02 22:19:01	2020-08-02	12	[{"id_menu":3,"count":1}]	1991	pick-up	0	12
109376	2020-08-02 22:21:02	2020-08-02	14	[{"id_menu":2,"count":1}]	26208	delivery	5	19
109377	2020-08-02 22:22:15	2020-08-02	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	23378	delivery	5	57
109378	2020-08-02 22:22:15	2020-08-02	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9297	delivery	5	30
109379	2020-08-02 22:22:21	2020-08-02	12	[{"id_menu":1,"count":1}]	11295	delivery	5	17
109380	2020-08-02 22:23:40	2020-08-02	9	[{"id_menu":7,"count":1}]	18512	delivery	5	14
109381	2020-08-02 22:25:02	2020-08-02	9	[{"id_menu":7,"count":1}]	14618	delivery	5	14
109382	2020-08-02 22:27:50	2020-08-02	17	[{"id_menu":4,"count":1}]	41037	delivery	5	22
109383	2020-08-02 22:29:36	2020-08-02	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	41981	delivery	5	30
109384	2020-08-02 22:30:59	2020-08-02	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	11096	delivery	5	42
109385	2020-08-02 22:31:04	2020-08-02	12	[{"id_menu":3,"count":1}]	41986	delivery	5	17
109386	2020-08-02 22:33:02	2020-08-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	32734	pick-up	0	23
109387	2020-08-02 22:35:02	2020-08-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7833	delivery	5	22
109388	2020-08-02 22:43:10	2020-08-02	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	26901	delivery	5	45
109389	2020-08-02 22:45:00	2020-08-02	9	[{"id_menu":7,"count":1}]	12610	delivery	5	14
109390	2020-08-02 22:45:04	2020-08-02	8	[{"id_menu":5,"count":1}]	41845	delivery	5	13
109391	2020-08-02 22:45:40	2020-08-02	9	[{"id_menu":7,"count":1}]	28579	delivery	5	14
109392	2020-08-02 22:45:48	2020-08-02	14	[{"id_menu":2,"count":1}]	26099	pick-up	0	14
109393	2020-08-02 22:47:44	2020-08-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41959	delivery	5	23
109394	2020-08-02 22:51:05	2020-08-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	41750	delivery	5	22
109395	2020-08-02 22:51:32	2020-08-02	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29856	delivery	5	31
109396	2020-08-02 22:51:35	2020-08-02	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	6009	delivery	5	43
109397	2020-08-02 22:54:44	2020-08-02	9	[{"id_menu":7,"count":1}]	16084	delivery	5	14
109398	2020-08-02 22:55:05	2020-08-02	9	[{"id_menu":6,"count":1}]	41772	delivery	5	14
109399	2020-08-02 22:56:22	2020-08-02	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	14427	pick-up	0	26
109400	2020-08-02 22:56:23	2020-08-02	9	[{"id_menu":6,"count":1}]	41952	pick-up	0	9
109401	2020-08-02 22:56:51	2020-08-02	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	29618	delivery	5	44
109402	2020-08-02 22:59:15	2020-08-02	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	9995	delivery	5	36
109403	2020-08-02 22:59:43	2020-08-02	9	[{"id_menu":6,"count":1}]	12210	pick-up	0	9
109404	2020-08-02 23:03:10	2020-08-02	9	[{"id_menu":7,"count":1}]	26666	delivery	5	14
109405	2020-08-02 23:04:56	2020-08-02	9	[{"id_menu":6,"count":1}]	29710	delivery	5	14
109406	2020-08-02 23:06:02	2020-08-02	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	16791	delivery	5	42
109407	2020-08-02 23:06:03	2020-08-02	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	41783	delivery	5	31
109408	2020-08-02 23:06:08	2020-08-02	17	[{"id_menu":4,"count":1}]	41842	pick-up	0	17
109409	2020-08-02 23:07:32	2020-08-02	12	[{"id_menu":3,"count":1}]	24752	delivery	5	17
109410	2020-08-02 23:07:57	2020-08-02	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	232	pick-up	0	21
109411	2020-08-02 23:09:21	2020-08-02	9	[{"id_menu":6,"count":1}]	1656	pick-up	0	9
109412	2020-08-02 23:12:27	2020-08-02	9	[{"id_menu":7,"count":1}]	2935	pick-up	0	9
109413	2020-08-02 23:18:01	2020-08-02	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	41867	delivery	5	23
109414	2020-08-02 23:19:40	2020-08-02	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	22973	delivery	5	31
109415	2020-08-02 23:20:10	2020-08-02	12	[{"id_menu":1,"count":1}]	5189	pick-up	0	12
109416	2020-08-02 23:22:24	2020-08-02	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	21501	delivery	5	30
109417	2020-08-02 23:24:43	2020-08-02	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	41880	delivery	5	40
109418	2020-08-02 23:25:00	2020-08-02	14	[{"id_menu":2,"count":1}]	41718	pick-up	0	14
109419	2020-08-02 23:25:15	2020-08-02	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22813	delivery	5	35
109420	2020-08-02 23:26:10	2020-08-02	9	[{"id_menu":7,"count":1}]	11961	delivery	5	14
109421	2020-08-02 23:31:18	2020-08-02	12	[{"id_menu":1,"count":1}]	8165	delivery	5	17
109422	2020-08-02 23:32:06	2020-08-02	9	[{"id_menu":7,"count":1}]	2594	pick-up	0	9
109423	2020-08-02 23:32:14	2020-08-02	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	41966	delivery	5	30
109424	2020-08-02 23:32:48	2020-08-02	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22487	delivery	5	43
109425	2020-08-02 23:33:33	2020-08-02	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	25430	delivery	5	31
109426	2020-08-02 23:35:34	2020-08-02	9	[{"id_menu":6,"count":1}]	24375	pick-up	0	9
109427	2020-08-02 23:35:49	2020-08-02	17	[{"id_menu":4,"count":1}]	6104	delivery	5	22
109428	2020-08-02 23:36:15	2020-08-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	41879	delivery	5	28
109429	2020-08-02 23:37:48	2020-08-02	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	41724	delivery	5	22
109430	2020-08-02 23:38:45	2020-08-02	14	[{"id_menu":2,"count":1}]	30891	delivery	5	19
109431	2020-08-02 23:42:41	2020-08-02	12	[{"id_menu":1,"count":1}]	2472	pick-up	0	12
109432	2020-08-02 23:43:03	2020-08-02	14	[{"id_menu":2,"count":1}]	1559	pick-up	0	14
109433	2020-08-02 23:45:07	2020-08-02	12	[{"id_menu":1,"count":1}]	5314	delivery	5	17
109434	2020-08-02 23:46:11	2020-08-02	8	[{"id_menu":5,"count":1}]	29132	delivery	5	13
109435	2020-08-02 23:50:37	2020-08-02	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	32455	delivery	5	31
109436	2020-08-02 23:51:31	2020-08-02	9	[{"id_menu":7,"count":2}]	41935	delivery	5	14
109437	2020-08-02 23:53:11	2020-08-02	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	14937	delivery	5	26
109438	2020-08-02 23:53:17	2020-08-02	14	[{"id_menu":2,"count":1}]	41916	delivery	5	19
109439	2020-08-02 23:53:20	2020-08-02	14	[{"id_menu":2,"count":1}]	41748	delivery	5	19
109440	2020-08-02 23:58:12	2020-08-02	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	27082	pick-up	0	23
109441	2020-08-02 23:59:40	2020-08-02	14	[{"id_menu":2,"count":1}]	24069	delivery	5	19
109442	2020-08-03 00:03:14	2020-08-03	12	[{"id_menu":3,"count":1}]	3199	delivery	5	17
109443	2020-08-03 00:06:55	2020-08-03	9	[{"id_menu":7,"count":1}]	27784	delivery	5	14
109444	2020-08-03 00:08:39	2020-08-03	9	[{"id_menu":6,"count":1}]	6591	pick-up	0	9
109445	2020-08-03 00:11:46	2020-08-03	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16755	delivery	5	37
109446	2020-08-03 00:12:18	2020-08-03	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5485	delivery	5	35
109447	2020-08-03 00:13:26	2020-08-03	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	12905	pick-up	0	37
109448	2020-08-03 00:17:24	2020-08-03	14	[{"id_menu":2,"count":1}]	42149	delivery	5	19
109449	2020-08-03 00:25:21	2020-08-03	8	[{"id_menu":5,"count":1}]	42153	delivery	5	13
109450	2020-08-03 00:29:17	2020-08-03	9	[{"id_menu":6,"count":1}]	42015	delivery	5	14
109451	2020-08-03 00:29:48	2020-08-03	17	[{"id_menu":4,"count":1}]	42158	pick-up	0	17
109452	2020-08-03 00:39:19	2020-08-03	9	[{"id_menu":6,"count":1}]	42214	delivery	5	14
109453	2020-08-03 00:43:55	2020-08-03	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	38421	delivery	5	26
109454	2020-08-03 00:44:15	2020-08-03	14	[{"id_menu":2,"count":2}]	40056	delivery	5	19
109455	2020-08-03 00:47:30	2020-08-03	12	[{"id_menu":1,"count":1}]	16839	delivery	5	17
109456	2020-08-03 00:54:28	2020-08-03	9	[{"id_menu":7,"count":2}]	42232	delivery	5	14
109457	2020-08-03 00:56:05	2020-08-03	9	[{"id_menu":6,"count":1}]	8716	pick-up	0	9
109458	2020-08-03 00:59:59	2020-08-03	8	[{"id_menu":5,"count":2}]	7247	pick-up	0	8
109459	2020-08-03 01:01:35	2020-08-03	9	[{"id_menu":6,"count":1}]	11774	pick-up	0	9
109460	2020-08-03 01:15:26	2020-08-03	8	[{"id_menu":5,"count":1}]	24538	delivery	5	13
109461	2020-08-03 01:17:25	2020-08-03	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	31856	delivery	5	27
109462	2020-08-03 01:17:32	2020-08-03	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	42108	delivery	5	34
109463	2020-08-03 01:18:31	2020-08-03	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	42216	delivery	5	39
109464	2020-08-03 01:21:09	2020-08-03	12	[{"id_menu":3,"count":1}]	32886	delivery	5	17
109465	2020-08-03 01:23:12	2020-08-03	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	42051	delivery	5	40
109466	2020-08-03 01:24:38	2020-08-03	8	[{"id_menu":5,"count":1}]	7080	pick-up	0	8
109467	2020-08-03 01:26:56	2020-08-03	17	[{"id_menu":4,"count":1}]	8097	delivery	5	22
109468	2020-08-03 01:28:00	2020-08-03	9	[{"id_menu":7,"count":1}]	12936	delivery	5	14
109469	2020-08-03 01:29:16	2020-08-03	14	[{"id_menu":2,"count":1}]	20379	pick-up	0	14
109470	2020-08-03 01:29:31	2020-08-03	14	[{"id_menu":2,"count":1}]	1266	pick-up	0	14
109471	2020-08-03 01:30:55	2020-08-03	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	42102	delivery	5	26
109472	2020-08-03 01:31:18	2020-08-03	8	[{"id_menu":5,"count":1}]	34302	delivery	5	13
109473	2020-08-03 01:36:23	2020-08-03	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	2855	pick-up	0	24
109474	2020-08-03 01:40:47	2020-08-03	9	[{"id_menu":7,"count":1}]	32657	delivery	5	14
109475	2020-08-03 01:53:39	2020-08-03	9	[{"id_menu":7,"count":1}]	18596	delivery	5	14
109476	2020-08-03 01:54:20	2020-08-03	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	42187	pick-up	0	38
109477	2020-08-03 01:54:36	2020-08-03	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	42011	delivery	5	45
109478	2020-08-03 01:57:01	2020-08-03	9	[{"id_menu":7,"count":1}]	2277	delivery	5	14
109479	2020-08-03 01:57:19	2020-08-03	34	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	27783	delivery	5	39
109480	2020-08-03 01:59:01	2020-08-03	14	[{"id_menu":2,"count":1}]	31378	delivery	5	19
109481	2020-08-03 01:59:12	2020-08-03	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	5707	delivery	5	22
109482	2020-08-03 02:00:44	2020-08-03	14	[{"id_menu":2,"count":1}]	28854	delivery	5	19
109483	2020-08-03 02:03:37	2020-08-03	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20957	delivery	5	39
109484	2020-08-03 02:05:32	2020-08-03	12	[{"id_menu":3,"count":1}]	6111	pick-up	0	12
109485	2020-08-03 02:09:04	2020-08-03	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	42207	delivery	5	39
109486	2020-08-03 02:11:35	2020-08-03	12	[{"id_menu":1,"count":1}]	39512	delivery	5	17
109487	2020-08-03 02:15:04	2020-08-03	17	[{"id_menu":4,"count":1}]	13498	delivery	5	22
109488	2020-08-03 02:17:24	2020-08-03	8	[{"id_menu":5,"count":1}]	13171	delivery	5	13
109489	2020-08-03 02:18:36	2020-08-03	8	[{"id_menu":5,"count":1}]	24774	pick-up	0	8
109490	2020-08-03 02:19:15	2020-08-03	12	[{"id_menu":1,"count":1}]	19554	pick-up	0	12
109491	2020-08-03 02:21:49	2020-08-03	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	24221	delivery	5	29
109492	2020-08-03 02:22:12	2020-08-03	14	[{"id_menu":2,"count":1}]	28532	pick-up	0	14
109493	2020-08-03 02:25:43	2020-08-03	12	[{"id_menu":1,"count":1}]	42136	delivery	5	17
109494	2020-08-03 02:32:22	2020-08-03	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26343	delivery	5	35
109495	2020-08-03 02:38:26	2020-08-03	14	[{"id_menu":2,"count":1}]	42097	delivery	5	19
109496	2020-08-03 02:40:19	2020-08-03	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	14982	pick-up	0	21
109497	2020-08-03 02:40:31	2020-08-03	14	[{"id_menu":2,"count":1}]	32674	pick-up	0	14
109498	2020-08-03 02:47:19	2020-08-03	12	[{"id_menu":1,"count":1}]	1559	pick-up	0	12
109499	2020-08-03 02:47:26	2020-08-03	9	[{"id_menu":7,"count":1}]	42002	delivery	5	14
109500	2020-08-03 02:50:54	2020-08-03	14	[{"id_menu":2,"count":1}]	31431	delivery	5	19
109501	2020-08-03 02:57:51	2020-08-03	14	[{"id_menu":2,"count":1}]	24690	delivery	5	19
109502	2020-08-03 02:59:52	2020-08-03	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28780	delivery	5	54
109503	2020-08-03 03:00:03	2020-08-03	9	[{"id_menu":6,"count":1}]	19666	delivery	5	14
109504	2020-08-03 03:00:56	2020-08-03	17	[{"id_menu":4,"count":1}]	3126	pick-up	0	17
109505	2020-08-03 03:01:30	2020-08-03	8	[{"id_menu":5,"count":1}]	8460	delivery	5	13
109506	2020-08-03 03:02:37	2020-08-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	42117	delivery	5	31
109507	2020-08-03 03:02:38	2020-08-03	12	[{"id_menu":1,"count":1}]	42194	pick-up	0	12
109508	2020-08-03 03:03:31	2020-08-03	14	[{"id_menu":2,"count":1}]	1201	pick-up	0	14
109509	2020-08-03 03:05:18	2020-08-03	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	42221	delivery	5	22
109510	2020-08-03 03:06:33	2020-08-03	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5994	delivery	5	31
109511	2020-08-03 03:11:02	2020-08-03	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	23668	delivery	5	26
109512	2020-08-03 03:11:59	2020-08-03	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	42179	delivery	5	40
109513	2020-08-03 03:12:34	2020-08-03	8	[{"id_menu":5,"count":1}]	5082	delivery	5	13
109514	2020-08-03 03:13:59	2020-08-03	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	42162	delivery	5	26
109515	2020-08-03 03:14:53	2020-08-03	12	[{"id_menu":3,"count":1}]	16065	delivery	5	17
109516	2020-08-03 03:16:15	2020-08-03	9	[{"id_menu":6,"count":1}]	19209	delivery	5	14
109517	2020-08-03 03:18:24	2020-08-03	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	41992	delivery	5	31
109518	2020-08-03 03:20:27	2020-08-03	9	[{"id_menu":6,"count":1}]	42244	delivery	5	14
109519	2020-08-03 03:23:19	2020-08-03	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	38771	pick-up	0	40
109520	2020-08-03 03:23:44	2020-08-03	12	[{"id_menu":1,"count":1}]	11866	delivery	5	17
109521	2020-08-03 03:24:36	2020-08-03	17	[{"id_menu":4,"count":1}]	27777	pick-up	0	17
109522	2020-08-03 03:28:34	2020-08-03	12	[{"id_menu":1,"count":1}]	7205	pick-up	0	12
109523	2020-08-03 03:29:28	2020-08-03	9	[{"id_menu":6,"count":1}]	42237	delivery	5	14
109524	2020-08-03 03:31:17	2020-08-03	9	[{"id_menu":7,"count":1}]	39840	delivery	5	14
109525	2020-08-03 03:35:56	2020-08-03	14	[{"id_menu":2,"count":1}]	37271	pick-up	0	14
109526	2020-08-03 03:38:09	2020-08-03	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	32820	delivery	5	42
109527	2020-08-03 03:40:45	2020-08-03	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	42000	delivery	5	27
109528	2020-08-03 03:46:47	2020-08-03	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2778	delivery	5	34
109529	2020-08-03 03:47:51	2020-08-03	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	19498	delivery	5	23
109530	2020-08-03 04:01:43	2020-08-03	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	34640	delivery	5	23
109531	2020-08-03 04:01:51	2020-08-03	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":2}]	7304	pick-up	0	23
109532	2020-08-03 04:05:48	2020-08-03	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	42192	delivery	5	40
109533	2020-08-03 04:07:27	2020-08-03	17	[{"id_menu":4,"count":1}]	21	pick-up	0	17
109534	2020-08-03 04:07:31	2020-08-03	14	[{"id_menu":2,"count":1}]	22369	delivery	5	19
109535	2020-08-03 04:07:36	2020-08-03	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	41997	delivery	5	27
109536	2020-08-03 04:08:36	2020-08-03	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	35055	pick-up	0	17
109537	2020-08-03 04:08:42	2020-08-03	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	30769	pick-up	0	29
109538	2020-08-03 04:08:56	2020-08-03	8	[{"id_menu":5,"count":1}]	26024	delivery	5	13
109539	2020-08-03 04:16:12	2020-08-03	9	[{"id_menu":6,"count":1}]	32184	pick-up	0	9
109540	2020-08-03 04:17:04	2020-08-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	31243	delivery	5	28
109541	2020-08-03 04:25:19	2020-08-03	12	[{"id_menu":3,"count":1}]	42169	delivery	5	17
109542	2020-08-03 04:25:55	2020-08-03	12	[{"id_menu":1,"count":1}]	42009	pick-up	0	12
109543	2020-08-03 04:26:33	2020-08-03	9	[{"id_menu":7,"count":1}]	15504	delivery	5	14
109544	2020-08-03 04:28:15	2020-08-03	12	[{"id_menu":3,"count":1}]	30770	pick-up	0	12
109545	2020-08-03 04:34:28	2020-08-03	14	[{"id_menu":2,"count":1}]	42210	delivery	5	19
109546	2020-08-03 04:34:47	2020-08-03	12	[{"id_menu":1,"count":1}]	30623	pick-up	0	12
109547	2020-08-03 04:35:43	2020-08-03	9	[{"id_menu":6,"count":1}]	8702	delivery	5	14
109548	2020-08-03 04:35:48	2020-08-03	9	[{"id_menu":7,"count":1}]	42036	delivery	5	14
109549	2020-08-03 04:42:27	2020-08-03	9	[{"id_menu":7,"count":1}]	20271	delivery	5	14
109550	2020-08-03 04:43:56	2020-08-03	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	37323	delivery	5	34
109551	2020-08-03 04:45:54	2020-08-03	9	[{"id_menu":7,"count":1}]	37606	delivery	5	14
109552	2020-08-03 04:49:31	2020-08-03	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	42172	delivery	5	22
109553	2020-08-03 04:49:34	2020-08-03	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	13881	delivery	5	23
109554	2020-08-03 04:53:08	2020-08-03	8	[{"id_menu":5,"count":1}]	34644	delivery	5	13
109555	2020-08-03 04:54:33	2020-08-03	14	[{"id_menu":2,"count":1}]	13115	delivery	5	19
109556	2020-08-03 04:56:35	2020-08-03	12	[{"id_menu":3,"count":1}]	18316	delivery	5	17
109557	2020-08-03 04:58:09	2020-08-03	12	[{"id_menu":3,"count":1}]	42041	delivery	5	17
109558	2020-08-03 04:59:39	2020-08-03	17	[{"id_menu":4,"count":1}]	42010	delivery	5	22
109559	2020-08-03 05:00:45	2020-08-03	12	[{"id_menu":3,"count":1}]	42202	delivery	5	17
109560	2020-08-03 05:01:13	2020-08-03	9	[{"id_menu":7,"count":1}]	37398	delivery	5	14
109561	2020-08-03 05:02:18	2020-08-03	14	[{"id_menu":2,"count":1}]	32133	pick-up	0	14
109562	2020-08-03 05:04:12	2020-08-03	14	[{"id_menu":2,"count":2}]	42060	delivery	5	19
109563	2020-08-03 05:05:55	2020-08-03	17	[{"id_menu":4,"count":2}]	42234	pick-up	0	17
109564	2020-08-03 05:06:10	2020-08-03	12	[{"id_menu":3,"count":1}]	28480	delivery	5	17
109565	2020-08-03 05:07:05	2020-08-03	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	9907	pick-up	0	21
109566	2020-08-03 05:13:21	2020-08-03	9	[{"id_menu":6,"count":1}]	42103	pick-up	0	9
109567	2020-08-03 05:17:58	2020-08-03	17	[{"id_menu":4,"count":1}]	1834	pick-up	0	17
109568	2020-08-03 05:18:33	2020-08-03	9	[{"id_menu":7,"count":1}]	35572	delivery	5	14
109569	2020-08-03 05:20:48	2020-08-03	8	[{"id_menu":5,"count":1}]	42239	delivery	5	13
109570	2020-08-03 05:22:32	2020-08-03	9	[{"id_menu":7,"count":1}]	26632	delivery	5	14
109571	2020-08-03 05:24:02	2020-08-03	9	[{"id_menu":6,"count":2}]	14711	delivery	5	14
109572	2020-08-03 05:27:28	2020-08-03	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	42118	delivery	5	22
109573	2020-08-03 05:31:13	2020-08-03	17	[{"id_menu":4,"count":1}]	25044	delivery	5	22
109574	2020-08-03 05:31:29	2020-08-03	14	[{"id_menu":2,"count":1}]	21340	delivery	5	19
109575	2020-08-03 05:37:39	2020-08-03	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	18133	pick-up	0	21
109576	2020-08-03 05:38:10	2020-08-03	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	14138	delivery	5	22
109577	2020-08-03 05:41:27	2020-08-03	12	[{"id_menu":1,"count":1}]	3447	delivery	5	17
109578	2020-08-03 05:50:03	2020-08-03	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	10892	delivery	5	26
109579	2020-08-03 06:02:07	2020-08-03	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2387	pick-up	0	26
109580	2020-08-03 06:10:01	2020-08-03	8	[{"id_menu":5,"count":1}]	19349	delivery	5	13
109581	2020-08-03 06:11:54	2020-08-03	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	35511	pick-up	0	24
109582	2020-08-03 06:12:57	2020-08-03	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	37244	delivery	5	27
109583	2020-08-03 06:12:57	2020-08-03	9	[{"id_menu":7,"count":1}]	12238	delivery	5	14
109584	2020-08-03 06:13:03	2020-08-03	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	42223	delivery	5	22
109585	2020-08-03 06:25:10	2020-08-03	9	[{"id_menu":6,"count":1}]	42116	delivery	5	14
109586	2020-08-03 06:26:36	2020-08-03	9	[{"id_menu":6,"count":1}]	42245	delivery	5	14
109587	2020-08-03 06:27:10	2020-08-03	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	709	delivery	5	34
109588	2020-08-03 06:30:31	2020-08-03	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	34368	pick-up	0	23
109589	2020-08-03 06:31:13	2020-08-03	12	[{"id_menu":3,"count":1}]	310	pick-up	0	12
109590	2020-08-03 06:33:15	2020-08-03	8	[{"id_menu":5,"count":1}]	40397	delivery	5	13
109591	2020-08-03 06:33:19	2020-08-03	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	8112	delivery	5	25
109592	2020-08-03 06:36:11	2020-08-03	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	13272	delivery	5	40
109593	2020-08-03 06:37:52	2020-08-03	17	[{"id_menu":4,"count":1}]	42066	delivery	5	22
109594	2020-08-03 06:40:32	2020-08-03	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	24766	delivery	5	26
109595	2020-08-03 06:44:00	2020-08-03	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	17211	delivery	5	42
109596	2020-08-03 06:45:52	2020-08-03	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	42141	delivery	5	31
109597	2020-08-03 06:49:44	2020-08-03	9	[{"id_menu":7,"count":1}]	42039	delivery	5	14
109598	2020-08-03 06:50:02	2020-08-03	9	[{"id_menu":7,"count":1}]	12571	delivery	5	14
109599	2020-08-03 06:53:32	2020-08-03	12	[{"id_menu":3,"count":1}]	32902	delivery	5	17
109600	2020-08-03 06:53:58	2020-08-03	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15407	delivery	5	35
109601	2020-08-03 06:56:56	2020-08-03	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	42021	delivery	5	30
109602	2020-08-03 06:58:47	2020-08-03	17	[{"id_menu":4,"count":1}]	41990	pick-up	0	17
109603	2020-08-03 06:58:50	2020-08-03	12	[{"id_menu":3,"count":1}]	42126	delivery	5	17
109604	2020-08-03 06:59:57	2020-08-03	12	[{"id_menu":1,"count":1}]	42093	pick-up	0	12
109605	2020-08-03 07:00:59	2020-08-03	17	[{"id_menu":4,"count":1}]	17145	delivery	5	22
109606	2020-08-03 07:03:07	2020-08-03	17	[{"id_menu":4,"count":1}]	42125	delivery	5	22
109607	2020-08-03 07:07:19	2020-08-03	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23350	delivery	5	22
109608	2020-08-03 07:07:28	2020-08-03	12	[{"id_menu":3,"count":1}]	42012	delivery	5	17
109609	2020-08-03 07:18:23	2020-08-03	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	25840	delivery	5	48
109610	2020-08-03 07:25:23	2020-08-03	9	[{"id_menu":6,"count":1}]	42151	delivery	5	14
109611	2020-08-03 07:33:54	2020-08-03	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	42159	delivery	5	26
109612	2020-08-03 07:36:56	2020-08-03	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	42231	delivery	5	29
109613	2020-08-03 07:37:39	2020-08-03	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	42176	delivery	5	28
109614	2020-08-03 07:38:24	2020-08-03	14	[{"id_menu":2,"count":1}]	42122	delivery	5	19
109615	2020-08-03 07:40:02	2020-08-03	9	[{"id_menu":6,"count":1}]	42032	delivery	5	14
109616	2020-08-03 07:42:13	2020-08-03	12	[{"id_menu":1,"count":1}]	6769	delivery	5	17
109617	2020-08-03 07:42:45	2020-08-03	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3799	pick-up	0	17
109618	2020-08-03 07:43:11	2020-08-03	17	[{"id_menu":4,"count":1}]	6250	pick-up	0	17
109619	2020-08-03 07:47:13	2020-08-03	12	[{"id_menu":1,"count":1}]	32530	delivery	5	17
109620	2020-08-03 07:47:35	2020-08-03	9	[{"id_menu":7,"count":1}]	28072	delivery	5	14
109621	2020-08-03 07:48:47	2020-08-03	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	26247	delivery	5	39
109622	2020-08-03 07:50:50	2020-08-03	9	[{"id_menu":6,"count":1}]	8180	pick-up	0	9
109623	2020-08-03 07:54:50	2020-08-03	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12650	delivery	5	53
109624	2020-08-03 07:56:01	2020-08-03	14	[{"id_menu":2,"count":1}]	32839	delivery	5	19
109625	2020-08-03 07:58:29	2020-08-03	9	[{"id_menu":6,"count":1}]	35974	delivery	5	14
109626	2020-08-03 08:01:35	2020-08-03	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	42138	delivery	5	23
109627	2020-08-03 08:03:39	2020-08-03	17	[{"id_menu":4,"count":1}]	23531	pick-up	0	17
109628	2020-08-03 08:10:27	2020-08-03	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	42065	delivery	5	35
109629	2020-08-03 08:13:39	2020-08-03	12	[{"id_menu":3,"count":1}]	22804	pick-up	0	12
109630	2020-08-03 08:20:47	2020-08-03	8	[{"id_menu":5,"count":1}]	34945	pick-up	0	8
109631	2020-08-03 08:21:31	2020-08-03	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	11254	delivery	5	40
109632	2020-08-03 08:24:31	2020-08-03	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4042	pick-up	0	29
109633	2020-08-03 08:27:43	2020-08-03	46	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	8410	delivery	5	51
109634	2020-08-03 08:29:37	2020-08-03	8	[{"id_menu":5,"count":1}]	42035	delivery	5	13
109635	2020-08-03 08:31:25	2020-08-03	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	15017	delivery	5	34
109636	2020-08-03 08:38:06	2020-08-03	17	[{"id_menu":4,"count":1}]	28932	delivery	5	22
109637	2020-08-03 08:38:59	2020-08-03	8	[{"id_menu":5,"count":1}]	24026	delivery	5	13
109638	2020-08-03 08:39:35	2020-08-03	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	18283	delivery	5	23
109639	2020-08-03 08:39:57	2020-08-03	14	[{"id_menu":2,"count":1}]	21938	delivery	5	19
109640	2020-08-03 08:40:02	2020-08-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	42142	delivery	5	28
109641	2020-08-03 08:41:26	2020-08-03	9	[{"id_menu":6,"count":1}]	8596	delivery	5	14
109642	2020-08-03 08:52:12	2020-08-03	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6730	delivery	5	30
109643	2020-08-03 08:53:24	2020-08-03	9	[{"id_menu":7,"count":1}]	16583	delivery	5	14
109644	2020-08-03 08:56:24	2020-08-03	17	[{"id_menu":4,"count":1}]	18519	delivery	5	22
109645	2020-08-03 08:59:17	2020-08-03	9	[{"id_menu":6,"count":1}]	27106	delivery	5	14
109646	2020-08-03 08:59:22	2020-08-03	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	24853	pick-up	0	32
109647	2020-08-03 08:59:58	2020-08-03	8	[{"id_menu":5,"count":1}]	27232	delivery	5	13
109648	2020-08-03 09:02:47	2020-08-03	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15302	delivery	5	34
109649	2020-08-03 09:09:27	2020-08-03	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	12540	pick-up	0	33
109650	2020-08-03 09:13:45	2020-08-03	9	[{"id_menu":6,"count":1}]	42209	delivery	5	14
109651	2020-08-03 09:17:01	2020-08-03	9	[{"id_menu":6,"count":1}]	42203	delivery	5	14
109652	2020-08-03 09:19:29	2020-08-03	12	[{"id_menu":3,"count":1}]	42062	delivery	5	17
109653	2020-08-03 09:23:29	2020-08-03	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	42104	delivery	5	36
109654	2020-08-03 09:28:03	2020-08-03	9	[{"id_menu":6,"count":2}]	19844	delivery	5	14
109655	2020-08-03 09:30:15	2020-08-03	17	[{"id_menu":4,"count":1}]	38316	delivery	5	22
109656	2020-08-03 09:31:56	2020-08-03	12	[{"id_menu":3,"count":1}]	21256	pick-up	0	12
109657	2020-08-03 09:32:45	2020-08-03	9	[{"id_menu":7,"count":1}]	42163	delivery	5	14
109658	2020-08-03 09:41:21	2020-08-03	9	[{"id_menu":7,"count":1}]	9391	delivery	5	14
109659	2020-08-03 09:46:27	2020-08-03	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	40617	delivery	5	26
109660	2020-08-03 09:49:13	2020-08-03	12	[{"id_menu":1,"count":1}]	33732	pick-up	0	12
109661	2020-08-03 09:49:43	2020-08-03	12	[{"id_menu":1,"count":1}]	34281	delivery	5	17
109662	2020-08-03 09:50:18	2020-08-03	9	[{"id_menu":7,"count":1}]	4074	delivery	5	14
109663	2020-08-03 09:54:17	2020-08-03	9	[{"id_menu":7,"count":1}]	42059	delivery	5	14
109664	2020-08-03 09:56:18	2020-08-03	14	[{"id_menu":2,"count":2}]	13940	delivery	5	19
109665	2020-08-03 09:59:17	2020-08-03	12	[{"id_menu":1,"count":1}]	27370	delivery	5	17
109666	2020-08-03 10:00:16	2020-08-03	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	42131	delivery	5	31
109667	2020-08-03 10:00:39	2020-08-03	17	[{"id_menu":4,"count":1}]	4841	pick-up	0	17
109668	2020-08-03 10:02:38	2020-08-03	14	[{"id_menu":2,"count":1}]	42088	delivery	5	19
109669	2020-08-03 10:06:09	2020-08-03	9	[{"id_menu":6,"count":1}]	742	pick-up	0	9
109670	2020-08-03 10:07:46	2020-08-03	9	[{"id_menu":7,"count":1}]	42183	delivery	5	14
109671	2020-08-03 10:14:29	2020-08-03	9	[{"id_menu":7,"count":1}]	42130	delivery	5	14
109672	2020-08-03 10:18:06	2020-08-03	17	[{"id_menu":4,"count":1}]	15538	delivery	5	22
109673	2020-08-03 10:20:15	2020-08-03	8	[{"id_menu":5,"count":1}]	13551	delivery	5	13
109674	2020-08-03 10:21:26	2020-08-03	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	37954	delivery	5	28
109675	2020-08-03 10:21:29	2020-08-03	12	[{"id_menu":3,"count":1}]	4810	pick-up	0	12
109676	2020-08-03 10:24:59	2020-08-03	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	42147	delivery	5	35
109677	2020-08-03 10:27:58	2020-08-03	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	26307	delivery	5	22
109678	2020-08-03 10:40:42	2020-08-03	9	[{"id_menu":6,"count":1}]	35008	delivery	5	14
109679	2020-08-03 10:41:25	2020-08-03	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16901	delivery	5	22
109680	2020-08-03 10:43:47	2020-08-03	9	[{"id_menu":7,"count":2}]	42161	delivery	5	14
109681	2020-08-03 10:46:08	2020-08-03	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	31480	delivery	5	38
109682	2020-08-03 10:47:49	2020-08-03	14	[{"id_menu":2,"count":1}]	9040	pick-up	0	14
109683	2020-08-03 10:51:13	2020-08-03	9	[{"id_menu":6,"count":1}]	3293	delivery	5	14
109684	2020-08-03 10:53:13	2020-08-03	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5983	delivery	5	34
109685	2020-08-03 10:53:30	2020-08-03	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	33683	delivery	5	30
109686	2020-08-03 10:56:36	2020-08-03	17	[{"id_menu":4,"count":1}]	31618	pick-up	0	17
109687	2020-08-03 11:01:03	2020-08-03	9	[{"id_menu":6,"count":1}]	22752	delivery	5	14
109688	2020-08-03 11:05:15	2020-08-03	9	[{"id_menu":7,"count":1}]	5172	delivery	5	14
109689	2020-08-03 11:06:20	2020-08-03	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	31940	delivery	5	31
109690	2020-08-03 11:06:50	2020-08-03	9	[{"id_menu":6,"count":1}]	18737	delivery	5	14
109691	2020-08-03 11:07:33	2020-08-03	12	[{"id_menu":1,"count":1}]	15964	delivery	5	17
109692	2020-08-03 11:10:20	2020-08-03	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	5976	delivery	5	23
109693	2020-08-03 11:15:36	2020-08-03	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28316	pick-up	0	17
109694	2020-08-03 11:16:04	2020-08-03	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	21671	delivery	5	43
109695	2020-08-03 11:27:07	2020-08-03	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4207	pick-up	0	41
109696	2020-08-03 11:27:23	2020-08-03	17	[{"id_menu":4,"count":1}]	33607	delivery	5	22
109697	2020-08-03 11:27:41	2020-08-03	9	[{"id_menu":7,"count":1}]	22638	delivery	5	14
109698	2020-08-03 11:29:49	2020-08-03	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	8651	delivery	5	37
109699	2020-08-03 11:33:47	2020-08-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	42180	delivery	5	28
109700	2020-08-03 11:34:21	2020-08-03	17	[{"id_menu":4,"count":1}]	38880	delivery	5	22
109701	2020-08-03 11:37:06	2020-08-03	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	39103	delivery	5	27
109702	2020-08-03 11:39:57	2020-08-03	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	25239	delivery	5	48
109703	2020-08-03 11:42:36	2020-08-03	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	41294	delivery	5	31
109704	2020-08-03 11:43:57	2020-08-03	12	[{"id_menu":1,"count":1}]	27446	delivery	5	17
109705	2020-08-03 11:44:15	2020-08-03	8	[{"id_menu":5,"count":1}]	26589	delivery	5	13
109706	2020-08-03 12:00:06	2020-08-03	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	17327	delivery	5	36
109707	2020-08-03 12:01:46	2020-08-03	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	17872	delivery	5	26
109708	2020-08-03 12:02:25	2020-08-03	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	42073	delivery	5	25
109709	2020-08-03 12:02:39	2020-08-03	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4100	delivery	5	48
109710	2020-08-03 12:07:30	2020-08-03	9	[{"id_menu":6,"count":1}]	42034	delivery	5	14
109711	2020-08-03 12:14:18	2020-08-03	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	42064	delivery	5	26
109712	2020-08-03 12:14:41	2020-08-03	12	[{"id_menu":3,"count":1}]	24902	delivery	5	17
109713	2020-08-03 12:16:24	2020-08-03	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19939	delivery	5	22
109714	2020-08-03 12:17:11	2020-08-03	14	[{"id_menu":2,"count":1}]	42154	delivery	5	19
109715	2020-08-03 12:30:52	2020-08-03	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	33900	delivery	5	31
109716	2020-08-03 12:33:11	2020-08-03	9	[{"id_menu":6,"count":1}]	20257	delivery	5	14
109717	2020-08-03 12:36:58	2020-08-03	14	[{"id_menu":2,"count":1}]	32503	delivery	5	19
109718	2020-08-03 12:37:22	2020-08-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	30416	delivery	5	28
109719	2020-08-03 12:39:45	2020-08-03	12	[{"id_menu":3,"count":1}]	22900	delivery	5	17
109720	2020-08-03 12:42:41	2020-08-03	17	[{"id_menu":4,"count":1}]	42112	delivery	5	22
109721	2020-08-03 12:53:26	2020-08-03	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	21282	delivery	5	45
109722	2020-08-03 13:01:37	2020-08-03	17	[{"id_menu":4,"count":1}]	7428	delivery	5	22
109723	2020-08-03 13:03:48	2020-08-03	9	[{"id_menu":6,"count":1}]	23185	pick-up	0	9
109724	2020-08-03 13:04:10	2020-08-03	8	[{"id_menu":5,"count":1}]	42005	delivery	5	13
109725	2020-08-03 13:08:02	2020-08-03	17	[{"id_menu":4,"count":1}]	3755	pick-up	0	17
109726	2020-08-03 13:10:44	2020-08-03	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	42067	delivery	5	23
109727	2020-08-03 13:11:01	2020-08-03	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	37485	delivery	5	53
109728	2020-08-03 13:11:42	2020-08-03	8	[{"id_menu":5,"count":1}]	42061	delivery	5	13
109729	2020-08-03 13:15:30	2020-08-03	14	[{"id_menu":2,"count":1}]	18634	delivery	5	19
109730	2020-08-03 13:15:40	2020-08-03	14	[{"id_menu":2,"count":1}]	42166	delivery	5	19
109731	2020-08-03 13:16:27	2020-08-03	12	[{"id_menu":1,"count":1}]	29084	pick-up	0	12
109732	2020-08-03 13:17:21	2020-08-03	14	[{"id_menu":2,"count":1}]	7330	delivery	5	19
109733	2020-08-03 13:17:33	2020-08-03	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	41022	delivery	5	44
109734	2020-08-03 13:19:14	2020-08-03	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	12211	delivery	5	48
109735	2020-08-03 13:20:13	2020-08-03	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	22858	delivery	5	31
109736	2020-08-03 13:20:57	2020-08-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	42212	delivery	5	31
109737	2020-08-03 13:23:50	2020-08-03	12	[{"id_menu":3,"count":1}]	1835	delivery	5	17
109738	2020-08-03 13:27:23	2020-08-03	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	42043	delivery	5	37
109739	2020-08-03 13:28:39	2020-08-03	12	[{"id_menu":3,"count":1}]	13713	delivery	5	17
109740	2020-08-03 13:32:07	2020-08-03	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	42106	delivery	5	27
109806	2020-08-03 16:36:31	2020-08-03	9	[{"id_menu":6,"count":1}]	4054	pick-up	0	9
109741	2020-08-03 13:32:34	2020-08-03	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	41993	delivery	5	42
109742	2020-08-03 13:36:12	2020-08-03	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30413	delivery	5	37
109743	2020-08-03 13:37:08	2020-08-03	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	35167	delivery	5	31
109744	2020-08-03 13:38:22	2020-08-03	8	[{"id_menu":5,"count":1}]	35213	delivery	5	13
109745	2020-08-03 13:45:00	2020-08-03	9	[{"id_menu":6,"count":2}]	14379	delivery	5	14
109746	2020-08-03 14:00:12	2020-08-03	17	[{"id_menu":4,"count":3}]	24587	delivery	5	22
109747	2020-08-03 14:00:17	2020-08-03	8	[{"id_menu":5,"count":1}]	3659	delivery	5	13
109748	2020-08-03 14:00:40	2020-08-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	42184	delivery	5	31
109749	2020-08-03 14:05:22	2020-08-03	12	[{"id_menu":3,"count":1}]	36666	delivery	5	17
109750	2020-08-03 14:07:01	2020-08-03	9	[{"id_menu":6,"count":1}]	34253	delivery	5	14
109751	2020-08-03 14:10:23	2020-08-03	29	[{"id_menu":3,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16908	delivery	5	34
109752	2020-08-03 14:12:45	2020-08-03	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4589	delivery	5	28
109753	2020-08-03 14:15:15	2020-08-03	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	31719	delivery	5	26
109754	2020-08-03 14:17:28	2020-08-03	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33339	delivery	5	37
109755	2020-08-03 14:17:51	2020-08-03	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2819	delivery	5	35
109756	2020-08-03 14:18:35	2020-08-03	9	[{"id_menu":6,"count":1}]	42107	delivery	5	14
109757	2020-08-03 14:19:50	2020-08-03	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11225	delivery	5	23
109758	2020-08-03 14:26:46	2020-08-03	12	[{"id_menu":1,"count":1}]	7022	delivery	5	17
109759	2020-08-03 14:29:04	2020-08-03	9	[{"id_menu":6,"count":1}]	27459	pick-up	0	9
109760	2020-08-03 14:31:28	2020-08-03	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	42199	delivery	5	34
109761	2020-08-03 14:36:35	2020-08-03	9	[{"id_menu":7,"count":1}]	1536	delivery	5	14
109762	2020-08-03 14:40:23	2020-08-03	14	[{"id_menu":2,"count":1}]	8046	pick-up	0	14
109763	2020-08-03 14:48:10	2020-08-03	12	[{"id_menu":3,"count":1}]	10661	delivery	5	17
109764	2020-08-03 14:48:24	2020-08-03	17	[{"id_menu":4,"count":1}]	42028	delivery	5	22
109765	2020-08-03 14:54:31	2020-08-03	8	[{"id_menu":5,"count":2}]	26977	delivery	5	13
109766	2020-08-03 14:57:15	2020-08-03	9	[{"id_menu":7,"count":1}]	18496	delivery	5	14
109767	2020-08-03 14:57:55	2020-08-03	9	[{"id_menu":6,"count":1}]	20549	delivery	5	14
109768	2020-08-03 15:04:30	2020-08-03	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	18901	delivery	5	26
109769	2020-08-03 15:07:40	2020-08-03	12	[{"id_menu":1,"count":2}]	23183	pick-up	0	12
109770	2020-08-03 15:13:47	2020-08-03	34	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	40204	delivery	5	39
109771	2020-08-03 15:13:57	2020-08-03	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	30512	delivery	5	23
109772	2020-08-03 15:17:17	2020-08-03	12	[{"id_menu":1,"count":1}]	29990	pick-up	0	12
109773	2020-08-03 15:18:53	2020-08-03	8	[{"id_menu":5,"count":1}]	890	delivery	5	13
109774	2020-08-03 15:19:38	2020-08-03	9	[{"id_menu":6,"count":1}]	34188	pick-up	0	9
109775	2020-08-03 15:21:33	2020-08-03	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	25107	delivery	5	39
109776	2020-08-03 15:26:34	2020-08-03	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6678	delivery	5	34
109777	2020-08-03 15:26:54	2020-08-03	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	42056	delivery	5	54
109778	2020-08-03 15:28:01	2020-08-03	8	[{"id_menu":5,"count":1}]	42026	delivery	5	13
109779	2020-08-03 15:29:58	2020-08-03	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4039	pick-up	0	31
109780	2020-08-03 15:31:00	2020-08-03	9	[{"id_menu":6,"count":1}]	37882	delivery	5	14
109781	2020-08-03 15:37:05	2020-08-03	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	8019	pick-up	0	21
109782	2020-08-03 15:40:15	2020-08-03	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	42200	delivery	5	31
109783	2020-08-03 15:40:29	2020-08-03	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16850	delivery	5	23
109784	2020-08-03 15:40:58	2020-08-03	9	[{"id_menu":6,"count":1}]	2339	pick-up	0	9
109785	2020-08-03 15:48:49	2020-08-03	9	[{"id_menu":6,"count":1}]	19321	delivery	5	14
109786	2020-08-03 15:50:26	2020-08-03	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21770	delivery	5	22
109787	2020-08-03 15:53:58	2020-08-03	14	[{"id_menu":2,"count":1}]	33023	delivery	5	19
109788	2020-08-03 15:55:23	2020-08-03	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	17594	pick-up	0	26
109789	2020-08-03 15:57:29	2020-08-03	8	[{"id_menu":5,"count":1}]	29795	delivery	5	13
109790	2020-08-03 16:02:07	2020-08-03	9	[{"id_menu":7,"count":1}]	40924	delivery	5	14
109791	2020-08-03 16:02:45	2020-08-03	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	16568	pick-up	0	21
109792	2020-08-03 16:09:08	2020-08-03	12	[{"id_menu":3,"count":1}]	5926	pick-up	0	12
109793	2020-08-03 16:09:09	2020-08-03	9	[{"id_menu":7,"count":1}]	17460	delivery	5	14
109794	2020-08-03 16:11:55	2020-08-03	14	[{"id_menu":2,"count":1}]	16459	delivery	5	19
109795	2020-08-03 16:12:50	2020-08-03	9	[{"id_menu":7,"count":1}]	42152	delivery	5	14
109796	2020-08-03 16:15:50	2020-08-03	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6547	delivery	5	22
109797	2020-08-03 16:22:30	2020-08-03	9	[{"id_menu":6,"count":1}]	42114	delivery	5	14
109798	2020-08-03 16:22:40	2020-08-03	14	[{"id_menu":2,"count":2}]	42025	delivery	5	19
109799	2020-08-03 16:25:58	2020-08-03	12	[{"id_menu":3,"count":1}]	36165	delivery	5	17
109800	2020-08-03 16:26:30	2020-08-03	9	[{"id_menu":6,"count":1}]	28404	delivery	5	14
109801	2020-08-03 16:30:08	2020-08-03	12	[{"id_menu":1,"count":1}]	13325	pick-up	0	12
109802	2020-08-03 16:31:40	2020-08-03	17	[{"id_menu":4,"count":1}]	42123	delivery	5	22
109803	2020-08-03 16:31:51	2020-08-03	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20128	delivery	5	35
109804	2020-08-03 16:31:51	2020-08-03	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	30891	delivery	5	26
109805	2020-08-03 16:33:51	2020-08-03	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	39377	delivery	5	34
109807	2020-08-03 16:40:59	2020-08-03	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12151	delivery	5	34
109808	2020-08-03 16:43:16	2020-08-03	8	[{"id_menu":5,"count":1}]	40312	delivery	5	13
109809	2020-08-03 16:47:22	2020-08-03	9	[{"id_menu":6,"count":1}]	37522	delivery	5	14
109810	2020-08-03 16:47:43	2020-08-03	14	[{"id_menu":2,"count":1}]	38006	delivery	5	19
109811	2020-08-03 16:55:17	2020-08-03	9	[{"id_menu":7,"count":1}]	42182	delivery	5	14
109812	2020-08-03 16:58:46	2020-08-03	14	[{"id_menu":2,"count":1}]	42168	delivery	5	19
109813	2020-08-03 17:00:25	2020-08-03	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	26750	delivery	5	34
109814	2020-08-03 17:03:30	2020-08-03	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	41991	delivery	5	45
109815	2020-08-03 17:05:49	2020-08-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	42204	delivery	5	28
109816	2020-08-03 17:10:22	2020-08-03	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3509	pick-up	0	31
109817	2020-08-03 17:10:50	2020-08-03	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	33021	delivery	5	26
109818	2020-08-03 17:15:12	2020-08-03	12	[{"id_menu":3,"count":1}]	24996	pick-up	0	12
109819	2020-08-03 17:18:14	2020-08-03	8	[{"id_menu":5,"count":1}]	19315	delivery	5	13
109820	2020-08-03 17:22:31	2020-08-03	12	[{"id_menu":1,"count":1}]	3474	delivery	5	17
109821	2020-08-03 17:24:02	2020-08-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":3}]	42155	delivery	5	31
109822	2020-08-03 17:27:41	2020-08-03	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3997	delivery	5	48
109823	2020-08-03 17:33:21	2020-08-03	14	[{"id_menu":2,"count":1}]	8025	pick-up	0	14
109824	2020-08-03 17:33:53	2020-08-03	12	[{"id_menu":1,"count":1}]	1529	pick-up	0	12
109825	2020-08-03 17:35:02	2020-08-03	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13066	delivery	5	22
109826	2020-08-03 17:35:59	2020-08-03	14	[{"id_menu":2,"count":1}]	42211	pick-up	0	14
109827	2020-08-03 17:37:23	2020-08-03	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	37819	delivery	5	40
109828	2020-08-03 17:37:50	2020-08-03	9	[{"id_menu":7,"count":1}]	274	pick-up	0	9
109829	2020-08-03 17:38:31	2020-08-03	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	42029	delivery	5	31
109830	2020-08-03 17:39:19	2020-08-03	12	[{"id_menu":1,"count":1}]	42113	delivery	5	17
109831	2020-08-03 17:39:37	2020-08-03	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	19159	pick-up	0	31
109832	2020-08-03 17:42:59	2020-08-03	9	[{"id_menu":7,"count":1}]	626	delivery	5	14
109833	2020-08-03 17:45:06	2020-08-03	17	[{"id_menu":4,"count":1}]	17710	delivery	5	22
109834	2020-08-03 17:46:32	2020-08-03	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7211	delivery	5	43
109835	2020-08-03 17:49:03	2020-08-03	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	29581	delivery	5	26
109836	2020-08-03 17:49:38	2020-08-03	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22210	delivery	5	43
109837	2020-08-03 17:52:10	2020-08-03	9	[{"id_menu":6,"count":1}]	1931	pick-up	0	9
109838	2020-08-03 17:55:45	2020-08-03	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27432	delivery	5	37
109839	2020-08-03 17:56:47	2020-08-03	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	42089	delivery	5	43
109840	2020-08-03 17:58:41	2020-08-03	12	[{"id_menu":3,"count":1}]	2651	pick-up	0	12
109841	2020-08-03 18:01:45	2020-08-03	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	37179	delivery	5	30
109842	2020-08-03 18:04:21	2020-08-03	9	[{"id_menu":6,"count":1}]	27235	delivery	5	14
109843	2020-08-03 18:12:03	2020-08-03	17	[{"id_menu":4,"count":1}]	27645	pick-up	0	17
109844	2020-08-03 18:15:05	2020-08-03	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	42144	delivery	5	30
109845	2020-08-03 18:16:42	2020-08-03	17	[{"id_menu":4,"count":1}]	6039	pick-up	0	17
109846	2020-08-03 18:19:18	2020-08-03	12	[{"id_menu":3,"count":1}]	5465	pick-up	0	12
109847	2020-08-03 18:21:45	2020-08-03	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	41995	delivery	5	30
109848	2020-08-03 18:29:53	2020-08-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	42085	pick-up	0	23
109849	2020-08-03 18:32:51	2020-08-03	21	[{"id_menu":1,"count":3},{"id_menu":6,"count":1}]	33673	delivery	5	26
109850	2020-08-03 18:34:06	2020-08-03	8	[{"id_menu":5,"count":1}]	20931	delivery	5	13
109851	2020-08-03 18:38:22	2020-08-03	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	42006	delivery	5	39
109852	2020-08-03 18:46:04	2020-08-03	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	42020	delivery	5	27
109853	2020-08-03 18:46:32	2020-08-03	17	[{"id_menu":4,"count":1}]	857	delivery	5	22
109854	2020-08-03 18:48:07	2020-08-03	8	[{"id_menu":5,"count":1}]	25188	delivery	5	13
109855	2020-08-03 18:49:35	2020-08-03	12	[{"id_menu":1,"count":1}]	23490	delivery	5	17
109856	2020-08-03 18:49:37	2020-08-03	12	[{"id_menu":3,"count":1}]	7582	pick-up	0	12
109857	2020-08-03 18:49:52	2020-08-03	9	[{"id_menu":7,"count":1}]	40085	pick-up	0	9
109858	2020-08-03 18:56:50	2020-08-03	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	42083	delivery	5	26
109859	2020-08-03 18:56:54	2020-08-03	14	[{"id_menu":2,"count":1}]	42110	delivery	5	19
109860	2020-08-03 18:59:19	2020-08-03	12	[{"id_menu":3,"count":1}]	42198	delivery	5	17
109861	2020-08-03 19:14:50	2020-08-03	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	39495	delivery	5	48
109862	2020-08-03 19:16:41	2020-08-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	74	delivery	5	31
109863	2020-08-03 19:18:08	2020-08-03	12	[{"id_menu":3,"count":1}]	12474	pick-up	0	12
109864	2020-08-03 19:26:21	2020-08-03	12	[{"id_menu":3,"count":1}]	8585	delivery	5	17
109865	2020-08-03 19:26:22	2020-08-03	9	[{"id_menu":7,"count":1}]	26311	pick-up	0	9
109866	2020-08-03 19:29:55	2020-08-03	9	[{"id_menu":6,"count":1}]	19300	pick-up	0	9
109867	2020-08-03 19:31:38	2020-08-03	14	[{"id_menu":2,"count":1}]	42135	delivery	5	19
109868	2020-08-03 19:32:57	2020-08-03	9	[{"id_menu":6,"count":1}]	24858	delivery	5	14
109869	2020-08-03 19:35:00	2020-08-03	9	[{"id_menu":6,"count":1}]	8543	pick-up	0	9
109870	2020-08-03 19:35:50	2020-08-03	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	34678	delivery	5	44
109871	2020-08-03 19:39:38	2020-08-03	17	[{"id_menu":4,"count":1}]	19129	pick-up	0	17
109872	2020-08-03 19:39:44	2020-08-03	9	[{"id_menu":6,"count":1}]	15237	delivery	5	14
109873	2020-08-03 19:43:34	2020-08-03	17	[{"id_menu":4,"count":1}]	4242	pick-up	0	17
109874	2020-08-03 19:44:09	2020-08-03	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	42058	delivery	5	26
109875	2020-08-03 19:49:19	2020-08-03	14	[{"id_menu":2,"count":1}]	23601	delivery	5	19
109876	2020-08-03 19:49:58	2020-08-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	23947	pick-up	0	26
109877	2020-08-03 19:50:06	2020-08-03	8	[{"id_menu":5,"count":1}]	31076	pick-up	0	8
109878	2020-08-03 19:53:28	2020-08-03	12	[{"id_menu":3,"count":2}]	13727	delivery	5	17
109879	2020-08-03 19:53:57	2020-08-03	9	[{"id_menu":7,"count":1}]	6648	delivery	5	14
109880	2020-08-03 19:55:03	2020-08-03	9	[{"id_menu":7,"count":1}]	2522	pick-up	0	9
109881	2020-08-03 19:58:28	2020-08-03	8	[{"id_menu":5,"count":1}]	29695	pick-up	0	8
109882	2020-08-03 20:10:18	2020-08-03	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	19684	pick-up	0	20
109883	2020-08-03 20:19:41	2020-08-03	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8500	delivery	5	34
109884	2020-08-03 20:21:41	2020-08-03	14	[{"id_menu":2,"count":1}]	5266	delivery	5	19
109885	2020-08-03 20:24:10	2020-08-03	9	[{"id_menu":7,"count":1}]	22614	pick-up	0	9
109886	2020-08-03 20:25:17	2020-08-03	14	[{"id_menu":2,"count":1}]	42080	pick-up	0	14
109887	2020-08-03 20:33:43	2020-08-03	9	[{"id_menu":6,"count":1}]	12638	delivery	5	14
109888	2020-08-03 20:35:12	2020-08-03	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	33556	delivery	5	36
109889	2020-08-03 20:42:24	2020-08-03	12	[{"id_menu":3,"count":1}]	18860	delivery	5	17
109890	2020-08-03 20:42:25	2020-08-03	12	[{"id_menu":1,"count":1}]	2573	pick-up	0	12
109891	2020-08-03 20:43:07	2020-08-03	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	18019	delivery	5	31
109892	2020-08-03 20:48:37	2020-08-03	8	[{"id_menu":5,"count":1}]	42017	delivery	5	13
109893	2020-08-03 20:50:39	2020-08-03	9	[{"id_menu":6,"count":1}]	31193	delivery	5	14
109894	2020-08-03 20:52:17	2020-08-03	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4807	delivery	5	23
109895	2020-08-03 20:55:54	2020-08-03	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	20780	pick-up	0	31
109896	2020-08-03 20:56:13	2020-08-03	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	16518	delivery	5	22
109897	2020-08-03 20:59:00	2020-08-03	12	[{"id_menu":1,"count":1}]	9525	delivery	5	17
109898	2020-08-03 21:00:19	2020-08-03	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	950	pick-up	0	26
109899	2020-08-03 21:01:01	2020-08-03	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12951	pick-up	0	17
109900	2020-08-03 21:05:12	2020-08-03	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	37364	delivery	5	31
109901	2020-08-03 21:07:04	2020-08-03	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	28892	delivery	5	43
109902	2020-08-03 21:08:25	2020-08-03	9	[{"id_menu":6,"count":1}]	38080	delivery	5	14
109903	2020-08-03 21:09:37	2020-08-03	9	[{"id_menu":6,"count":1}]	2101	pick-up	0	9
109904	2020-08-03 21:11:59	2020-08-03	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	17435	delivery	5	26
109905	2020-08-03 21:12:19	2020-08-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	42063	delivery	5	31
109906	2020-08-03 21:22:28	2020-08-03	17	[{"id_menu":4,"count":1}]	42079	delivery	5	22
109907	2020-08-03 21:26:55	2020-08-03	8	[{"id_menu":5,"count":1}]	39195	delivery	5	13
109908	2020-08-03 21:30:02	2020-08-03	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	42186	delivery	5	27
109909	2020-08-03 21:30:25	2020-08-03	14	[{"id_menu":2,"count":1}]	38090	delivery	5	19
109910	2020-08-03 21:32:58	2020-08-03	12	[{"id_menu":3,"count":1}]	4128	delivery	5	17
109911	2020-08-03 21:40:14	2020-08-03	12	[{"id_menu":1,"count":1}]	23721	delivery	5	17
109912	2020-08-03 21:48:01	2020-08-03	9	[{"id_menu":7,"count":1}]	28633	delivery	5	14
109913	2020-08-03 21:49:33	2020-08-03	9	[{"id_menu":6,"count":1}]	34239	delivery	5	14
109914	2020-08-03 21:53:19	2020-08-03	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	38993	delivery	5	26
109915	2020-08-03 21:53:33	2020-08-03	8	[{"id_menu":5,"count":1}]	41989	delivery	5	13
109916	2020-08-03 21:53:42	2020-08-03	9	[{"id_menu":7,"count":1}]	40585	delivery	5	14
109917	2020-08-03 21:57:20	2020-08-03	9	[{"id_menu":6,"count":1}]	6150	delivery	5	14
109918	2020-08-03 22:01:42	2020-08-03	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8298	pick-up	0	17
109919	2020-08-03 22:09:41	2020-08-03	9	[{"id_menu":6,"count":1}]	42090	delivery	5	14
109920	2020-08-03 22:10:59	2020-08-03	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19995	delivery	5	22
109921	2020-08-03 22:11:11	2020-08-03	14	[{"id_menu":2,"count":1}]	26370	pick-up	0	14
109922	2020-08-03 22:12:12	2020-08-03	9	[{"id_menu":6,"count":1}]	41647	delivery	5	14
109923	2020-08-03 22:12:44	2020-08-03	9	[{"id_menu":7,"count":1}]	28271	delivery	5	14
109924	2020-08-03 22:12:52	2020-08-03	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	42178	delivery	5	44
109925	2020-08-03 22:15:45	2020-08-03	12	[{"id_menu":1,"count":1}]	15614	delivery	5	17
109926	2020-08-03 22:17:01	2020-08-03	9	[{"id_menu":6,"count":1}]	39077	delivery	5	14
109927	2020-08-03 22:17:28	2020-08-03	17	[{"id_menu":4,"count":1}]	31659	delivery	5	22
109928	2020-08-03 22:19:25	2020-08-03	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	42069	delivery	5	34
109929	2020-08-03 22:24:07	2020-08-03	8	[{"id_menu":5,"count":1}]	14876	delivery	5	13
109930	2020-08-03 22:25:05	2020-08-03	12	[{"id_menu":3,"count":1}]	19240	delivery	5	17
109931	2020-08-03 22:25:41	2020-08-03	8	[{"id_menu":5,"count":1}]	31183	delivery	5	13
109932	2020-08-03 22:28:07	2020-08-03	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	39570	delivery	5	36
109933	2020-08-03 22:32:00	2020-08-03	8	[{"id_menu":5,"count":1}]	17430	pick-up	0	8
109934	2020-08-03 22:34:47	2020-08-03	9	[{"id_menu":7,"count":1}]	42027	delivery	5	14
109935	2020-08-03 22:35:13	2020-08-03	9	[{"id_menu":6,"count":1}]	23273	delivery	5	14
109936	2020-08-03 22:37:07	2020-08-03	12	[{"id_menu":3,"count":1}]	11574	pick-up	0	12
109937	2020-08-03 22:39:21	2020-08-03	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15265	delivery	5	23
109938	2020-08-03 22:39:26	2020-08-03	14	[{"id_menu":2,"count":1}]	12268	delivery	5	19
109939	2020-08-03 22:43:12	2020-08-03	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10518	delivery	5	31
109940	2020-08-03 22:45:46	2020-08-03	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4451	pick-up	0	31
109941	2020-08-03 22:48:50	2020-08-03	14	[{"id_menu":2,"count":1}]	35528	delivery	5	19
109942	2020-08-03 22:51:50	2020-08-03	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	16539	pick-up	0	23
109943	2020-08-03 22:58:57	2020-08-03	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41996	delivery	5	31
109944	2020-08-03 23:03:47	2020-08-03	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	19464	delivery	5	45
109945	2020-08-03 23:06:42	2020-08-03	17	[{"id_menu":4,"count":1}]	9603	delivery	5	22
109946	2020-08-03 23:10:39	2020-08-03	9	[{"id_menu":7,"count":1}]	10871	delivery	5	14
109947	2020-08-03 23:10:39	2020-08-03	9	[{"id_menu":7,"count":1}]	17412	delivery	5	14
109948	2020-08-03 23:11:33	2020-08-03	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13767	pick-up	0	31
109949	2020-08-03 23:22:29	2020-08-03	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	42228	delivery	5	36
109950	2020-08-03 23:28:16	2020-08-03	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	42055	delivery	5	35
109951	2020-08-03 23:34:01	2020-08-03	9	[{"id_menu":7,"count":1}]	42224	delivery	5	14
109952	2020-08-03 23:35:31	2020-08-03	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	42042	delivery	5	40
109953	2020-08-03 23:39:00	2020-08-03	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	42023	pick-up	0	26
109954	2020-08-03 23:43:10	2020-08-03	9	[{"id_menu":6,"count":1}]	42071	delivery	5	14
109955	2020-08-03 23:44:10	2020-08-03	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	15187	pick-up	0	30
109956	2020-08-03 23:46:58	2020-08-03	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15119	delivery	5	31
109957	2020-08-03 23:59:35	2020-08-03	9	[{"id_menu":7,"count":1}]	18197	delivery	5	14
109958	2020-08-04 00:04:55	2020-08-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	25315	delivery	5	28
109959	2020-08-04 00:04:59	2020-08-04	8	[{"id_menu":5,"count":1}]	37799	delivery	5	13
109960	2020-08-04 00:14:34	2020-08-04	9	[{"id_menu":7,"count":1}]	33435	delivery	5	14
109961	2020-08-04 00:16:41	2020-08-04	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	42443	delivery	5	25
109962	2020-08-04 00:17:24	2020-08-04	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23614	delivery	5	23
109963	2020-08-04 00:19:45	2020-08-04	17	[{"id_menu":4,"count":1}]	15267	pick-up	0	17
109964	2020-08-04 00:20:33	2020-08-04	9	[{"id_menu":7,"count":1}]	1495	delivery	5	14
109965	2020-08-04 00:21:25	2020-08-04	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	18901	delivery	5	26
109966	2020-08-04 00:29:27	2020-08-04	9	[{"id_menu":6,"count":1}]	3785	pick-up	0	9
109967	2020-08-04 00:32:43	2020-08-04	12	[{"id_menu":1,"count":1}]	4498	delivery	5	17
109968	2020-08-04 00:34:47	2020-08-04	12	[{"id_menu":3,"count":1}]	27015	pick-up	0	12
109969	2020-08-04 00:35:28	2020-08-04	9	[{"id_menu":7,"count":1}]	25735	pick-up	0	9
109970	2020-08-04 00:36:24	2020-08-04	12	[{"id_menu":1,"count":1}]	4577	delivery	5	17
109971	2020-08-04 00:39:38	2020-08-04	9	[{"id_menu":6,"count":1}]	42429	delivery	5	14
109972	2020-08-04 00:44:39	2020-08-04	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	19602	delivery	5	27
109973	2020-08-04 00:47:05	2020-08-04	14	[{"id_menu":2,"count":1}]	42296	delivery	5	19
109974	2020-08-04 00:48:01	2020-08-04	9	[{"id_menu":6,"count":1}]	37115	delivery	5	14
109975	2020-08-04 00:49:28	2020-08-04	12	[{"id_menu":3,"count":1}]	24375	delivery	5	17
109976	2020-08-04 00:52:12	2020-08-04	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	29854	delivery	5	48
109977	2020-08-04 00:55:20	2020-08-04	8	[{"id_menu":5,"count":1}]	11550	delivery	5	13
109978	2020-08-04 01:00:42	2020-08-04	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	32146	delivery	5	42
109979	2020-08-04 01:01:13	2020-08-04	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	22796	delivery	5	40
109980	2020-08-04 01:02:57	2020-08-04	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	18427	delivery	5	57
109981	2020-08-04 01:04:45	2020-08-04	8	[{"id_menu":5,"count":1}]	42415	delivery	5	13
109982	2020-08-04 01:07:55	2020-08-04	9	[{"id_menu":6,"count":1}]	42360	pick-up	0	9
109983	2020-08-04 01:11:12	2020-08-04	14	[{"id_menu":2,"count":1}]	42333	delivery	5	19
109984	2020-08-04 01:11:45	2020-08-04	17	[{"id_menu":4,"count":2}]	13400	pick-up	0	17
109985	2020-08-04 01:12:15	2020-08-04	9	[{"id_menu":7,"count":1}]	37863	delivery	5	14
109986	2020-08-04 01:12:19	2020-08-04	12	[{"id_menu":1,"count":1}]	42037	delivery	5	17
109987	2020-08-04 01:16:49	2020-08-04	9	[{"id_menu":6,"count":1}]	20307	delivery	5	14
109988	2020-08-04 01:21:32	2020-08-04	14	[{"id_menu":2,"count":1}]	42439	delivery	5	19
109989	2020-08-04 01:23:10	2020-08-04	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25108	delivery	5	34
109990	2020-08-04 01:25:34	2020-08-04	9	[{"id_menu":6,"count":1}]	36944	delivery	5	14
109991	2020-08-04 01:27:42	2020-08-04	9	[{"id_menu":7,"count":3}]	26311	pick-up	0	9
109992	2020-08-04 01:30:59	2020-08-04	9	[{"id_menu":6,"count":1}]	42375	delivery	5	14
109993	2020-08-04 01:31:14	2020-08-04	9	[{"id_menu":7,"count":1}]	29169	delivery	5	14
109994	2020-08-04 01:31:42	2020-08-04	14	[{"id_menu":2,"count":1}]	11507	delivery	5	19
109995	2020-08-04 01:32:06	2020-08-04	14	[{"id_menu":2,"count":1}]	42342	delivery	5	19
109996	2020-08-04 01:32:27	2020-08-04	9	[{"id_menu":7,"count":1}]	1656	delivery	5	14
109997	2020-08-04 01:43:42	2020-08-04	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	42340	delivery	5	31
109998	2020-08-04 01:43:49	2020-08-04	9	[{"id_menu":6,"count":1}]	42368	delivery	5	14
109999	2020-08-04 01:45:22	2020-08-04	9	[{"id_menu":7,"count":1}]	8139	delivery	5	14
110000	2020-08-04 01:47:30	2020-08-04	8	[{"id_menu":5,"count":1}]	42445	delivery	5	13
110001	2020-08-04 01:47:47	2020-08-04	12	[{"id_menu":3,"count":1}]	37644	pick-up	0	12
110002	2020-08-04 01:48:27	2020-08-04	12	[{"id_menu":1,"count":1}]	22149	delivery	5	17
110003	2020-08-04 01:53:28	2020-08-04	12	[{"id_menu":3,"count":1}]	32884	delivery	5	17
110004	2020-08-04 01:56:31	2020-08-04	17	[{"id_menu":4,"count":1}]	42364	delivery	5	22
110005	2020-08-04 02:07:34	2020-08-04	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37177	delivery	5	23
110006	2020-08-04 02:08:03	2020-08-04	12	[{"id_menu":3,"count":1}]	39931	delivery	5	17
110007	2020-08-04 02:08:10	2020-08-04	9	[{"id_menu":6,"count":1}]	22483	delivery	5	14
110008	2020-08-04 02:13:23	2020-08-04	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":3}]	42358	delivery	5	34
110009	2020-08-04 02:18:08	2020-08-04	17	[{"id_menu":4,"count":1}]	41072	delivery	5	22
110010	2020-08-04 02:19:55	2020-08-04	17	[{"id_menu":4,"count":1}]	15284	delivery	5	22
110011	2020-08-04 02:20:50	2020-08-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	37531	pick-up	0	23
110012	2020-08-04 02:21:02	2020-08-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	12174	delivery	5	28
110013	2020-08-04 02:22:44	2020-08-04	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	30596	delivery	5	36
110014	2020-08-04 02:23:25	2020-08-04	12	[{"id_menu":1,"count":1}]	11973	delivery	5	17
110015	2020-08-04 02:24:07	2020-08-04	12	[{"id_menu":1,"count":1}]	34930	delivery	5	17
110016	2020-08-04 02:26:05	2020-08-04	12	[{"id_menu":3,"count":1}]	13028	pick-up	0	12
110017	2020-08-04 02:27:49	2020-08-04	14	[{"id_menu":2,"count":1}]	42337	pick-up	0	14
110018	2020-08-04 02:29:35	2020-08-04	12	[{"id_menu":3,"count":1}]	35842	delivery	5	17
110019	2020-08-04 02:31:34	2020-08-04	12	[{"id_menu":3,"count":1}]	7733	delivery	5	17
110020	2020-08-04 02:37:42	2020-08-04	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	36922	delivery	5	34
110021	2020-08-04 02:38:00	2020-08-04	9	[{"id_menu":7,"count":1}]	37673	delivery	5	14
110022	2020-08-04 02:38:56	2020-08-04	17	[{"id_menu":4,"count":1}]	36767	pick-up	0	17
110023	2020-08-04 02:40:21	2020-08-04	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	42377	delivery	5	22
110024	2020-08-04 02:40:37	2020-08-04	9	[{"id_menu":7,"count":1}]	26429	delivery	5	14
110025	2020-08-04 02:40:39	2020-08-04	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	42309	delivery	5	23
110026	2020-08-04 02:43:12	2020-08-04	12	[{"id_menu":3,"count":1}]	2355	delivery	5	17
110027	2020-08-04 02:46:22	2020-08-04	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	29340	delivery	5	43
110028	2020-08-04 02:47:55	2020-08-04	17	[{"id_menu":4,"count":1}]	26494	delivery	5	22
110029	2020-08-04 02:50:37	2020-08-04	9	[{"id_menu":7,"count":1}]	3896	pick-up	0	9
110030	2020-08-04 02:50:44	2020-08-04	8	[{"id_menu":5,"count":1}]	2776	pick-up	0	8
110031	2020-08-04 02:53:07	2020-08-04	14	[{"id_menu":2,"count":1}]	3883	delivery	5	19
110032	2020-08-04 02:55:17	2020-08-04	12	[{"id_menu":3,"count":1}]	25679	pick-up	0	12
110033	2020-08-04 02:58:55	2020-08-04	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	42355	delivery	5	25
110034	2020-08-04 03:05:36	2020-08-04	14	[{"id_menu":2,"count":1}]	41214	pick-up	0	14
110035	2020-08-04 03:12:40	2020-08-04	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	19825	delivery	5	26
110036	2020-08-04 03:15:00	2020-08-04	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5743	delivery	5	34
110037	2020-08-04 03:16:01	2020-08-04	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	22264	delivery	5	23
110038	2020-08-04 03:16:36	2020-08-04	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	14709	delivery	5	25
110039	2020-08-04 03:20:49	2020-08-04	9	[{"id_menu":6,"count":1}]	42441	delivery	5	14
110040	2020-08-04 03:20:58	2020-08-04	14	[{"id_menu":2,"count":1}]	42361	delivery	5	19
110041	2020-08-04 03:21:13	2020-08-04	9	[{"id_menu":7,"count":1}]	241	delivery	5	14
110042	2020-08-04 03:22:28	2020-08-04	9	[{"id_menu":7,"count":1}]	42448	delivery	5	14
110043	2020-08-04 03:24:50	2020-08-04	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27790	delivery	5	22
110044	2020-08-04 03:29:24	2020-08-04	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	143	pick-up	0	26
110045	2020-08-04 03:31:01	2020-08-04	12	[{"id_menu":3,"count":1}]	42369	delivery	5	17
110046	2020-08-04 03:39:05	2020-08-04	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	11586	delivery	5	26
110047	2020-08-04 03:41:36	2020-08-04	9	[{"id_menu":6,"count":1}]	42272	pick-up	0	9
110048	2020-08-04 03:44:14	2020-08-04	9	[{"id_menu":7,"count":1}]	17461	delivery	5	14
110049	2020-08-04 03:45:50	2020-08-04	17	[{"id_menu":4,"count":1}]	4280	delivery	5	22
110050	2020-08-04 03:46:14	2020-08-04	43	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	42302	delivery	5	48
110051	2020-08-04 03:48:46	2020-08-04	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	32378	delivery	5	31
110052	2020-08-04 03:54:08	2020-08-04	14	[{"id_menu":2,"count":1}]	32237	delivery	5	19
110053	2020-08-04 03:54:55	2020-08-04	12	[{"id_menu":3,"count":1}]	20883	pick-up	0	12
110054	2020-08-04 03:56:16	2020-08-04	14	[{"id_menu":2,"count":1}]	42418	delivery	5	19
110055	2020-08-04 03:56:59	2020-08-04	12	[{"id_menu":3,"count":1}]	16528	delivery	5	17
110056	2020-08-04 03:57:39	2020-08-04	9	[{"id_menu":7,"count":1}]	32079	pick-up	0	9
110057	2020-08-04 03:59:18	2020-08-04	12	[{"id_menu":1,"count":1}]	30772	pick-up	0	12
110058	2020-08-04 04:02:31	2020-08-04	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4733	delivery	5	37
110059	2020-08-04 04:03:49	2020-08-04	9	[{"id_menu":6,"count":1}]	16309	pick-up	0	9
110060	2020-08-04 04:10:29	2020-08-04	14	[{"id_menu":2,"count":1}]	7931	delivery	5	19
110061	2020-08-04 04:10:57	2020-08-04	14	[{"id_menu":2,"count":1}]	40054	delivery	5	19
110062	2020-08-04 04:11:27	2020-08-04	17	[{"id_menu":4,"count":1}]	42399	delivery	5	22
110063	2020-08-04 04:11:30	2020-08-04	8	[{"id_menu":5,"count":1}]	39640	delivery	5	13
110064	2020-08-04 04:14:08	2020-08-04	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	18797	delivery	5	57
110065	2020-08-04 04:19:24	2020-08-04	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	42379	delivery	5	29
110066	2020-08-04 04:19:57	2020-08-04	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	40236	delivery	5	22
110067	2020-08-04 04:20:46	2020-08-04	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	42363	delivery	5	26
110068	2020-08-04 04:22:46	2020-08-04	12	[{"id_menu":1,"count":1}]	29099	delivery	5	17
110069	2020-08-04 04:25:20	2020-08-04	9	[{"id_menu":6,"count":1}]	42394	delivery	5	14
110070	2020-08-04 04:29:31	2020-08-04	8	[{"id_menu":5,"count":1}]	4337	delivery	5	13
110071	2020-08-04 04:30:56	2020-08-04	9	[{"id_menu":6,"count":1}]	17784	pick-up	0	9
110072	2020-08-04 04:32:11	2020-08-04	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	42297	delivery	5	31
110073	2020-08-04 04:32:26	2020-08-04	9	[{"id_menu":7,"count":1}]	29769	delivery	5	14
110074	2020-08-04 04:33:27	2020-08-04	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3343	delivery	5	30
110075	2020-08-04 04:35:25	2020-08-04	8	[{"id_menu":5,"count":1}]	42277	delivery	5	13
110076	2020-08-04 04:38:08	2020-08-04	8	[{"id_menu":5,"count":1}]	29125	delivery	5	13
110077	2020-08-04 04:41:36	2020-08-04	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	41926	pick-up	0	29
110078	2020-08-04 04:43:32	2020-08-04	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	42356	delivery	5	34
110079	2020-08-04 04:46:42	2020-08-04	12	[{"id_menu":3,"count":1}]	29466	delivery	5	17
110080	2020-08-04 04:53:24	2020-08-04	8	[{"id_menu":5,"count":1}]	36043	delivery	5	13
110081	2020-08-04 04:56:03	2020-08-04	9	[{"id_menu":6,"count":1}]	10471	delivery	5	14
110082	2020-08-04 04:58:58	2020-08-04	9	[{"id_menu":7,"count":1}]	42286	delivery	5	14
110083	2020-08-04 05:00:06	2020-08-04	9	[{"id_menu":7,"count":1}]	42381	delivery	5	14
110084	2020-08-04 05:01:33	2020-08-04	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	11454	delivery	5	25
110085	2020-08-04 05:04:01	2020-08-04	14	[{"id_menu":2,"count":1}]	10287	pick-up	0	14
110086	2020-08-04 05:06:30	2020-08-04	8	[{"id_menu":5,"count":1}]	1309	pick-up	0	8
110087	2020-08-04 05:11:18	2020-08-04	12	[{"id_menu":1,"count":1}]	40790	delivery	5	17
110088	2020-08-04 05:12:44	2020-08-04	12	[{"id_menu":1,"count":1}]	31115	delivery	5	17
110089	2020-08-04 05:12:47	2020-08-04	9	[{"id_menu":7,"count":1}]	2425	pick-up	0	9
110090	2020-08-04 05:13:47	2020-08-04	8	[{"id_menu":5,"count":1}]	10783	pick-up	0	8
110091	2020-08-04 05:15:21	2020-08-04	14	[{"id_menu":2,"count":1}]	17582	pick-up	0	14
110092	2020-08-04 05:15:29	2020-08-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	42421	delivery	5	28
110093	2020-08-04 05:18:49	2020-08-04	8	[{"id_menu":5,"count":1}]	42295	delivery	5	13
110094	2020-08-04 05:18:56	2020-08-04	17	[{"id_menu":4,"count":1}]	8574	pick-up	0	17
110095	2020-08-04 05:24:43	2020-08-04	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	412	pick-up	0	23
110096	2020-08-04 05:25:18	2020-08-04	14	[{"id_menu":2,"count":1}]	9244	pick-up	0	14
110097	2020-08-04 05:26:29	2020-08-04	9	[{"id_menu":6,"count":1}]	39662	pick-up	0	9
110098	2020-08-04 05:27:46	2020-08-04	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	9542	delivery	5	31
110099	2020-08-04 05:28:52	2020-08-04	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	7825	delivery	5	31
110100	2020-08-04 05:38:41	2020-08-04	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	42269	delivery	5	26
110101	2020-08-04 05:41:11	2020-08-04	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	21930	delivery	5	27
110102	2020-08-04 05:57:54	2020-08-04	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	24524	delivery	5	26
110103	2020-08-04 05:59:27	2020-08-04	12	[{"id_menu":3,"count":1}]	23312	pick-up	0	12
110104	2020-08-04 06:00:48	2020-08-04	9	[{"id_menu":7,"count":1}]	42402	delivery	5	14
110105	2020-08-04 06:05:39	2020-08-04	12	[{"id_menu":1,"count":1}]	42349	delivery	5	17
110106	2020-08-04 06:08:26	2020-08-04	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	17667	delivery	5	31
110107	2020-08-04 06:09:32	2020-08-04	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	9298	delivery	5	43
110108	2020-08-04 06:10:39	2020-08-04	8	[{"id_menu":5,"count":1}]	42253	delivery	5	13
110109	2020-08-04 06:14:28	2020-08-04	9	[{"id_menu":7,"count":1}]	41445	pick-up	0	9
110110	2020-08-04 06:18:56	2020-08-04	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15820	delivery	5	36
110111	2020-08-04 06:18:59	2020-08-04	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19036	delivery	5	35
110112	2020-08-04 06:19:10	2020-08-04	14	[{"id_menu":2,"count":1}]	32770	pick-up	0	14
110113	2020-08-04 06:25:55	2020-08-04	14	[{"id_menu":2,"count":1}]	31130	pick-up	0	14
110114	2020-08-04 06:28:01	2020-08-04	9	[{"id_menu":7,"count":1}]	42407	delivery	5	14
110115	2020-08-04 06:31:52	2020-08-04	17	[{"id_menu":4,"count":1}]	19040	delivery	5	22
110116	2020-08-04 06:33:53	2020-08-04	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	42263	delivery	5	31
110117	2020-08-04 06:34:45	2020-08-04	8	[{"id_menu":5,"count":1}]	11287	pick-up	0	8
110118	2020-08-04 06:36:02	2020-08-04	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25658	delivery	5	37
110119	2020-08-04 06:36:53	2020-08-04	9	[{"id_menu":7,"count":1}]	5961	pick-up	0	9
110120	2020-08-04 06:38:39	2020-08-04	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	32360	delivery	5	40
110121	2020-08-04 06:41:25	2020-08-04	9	[{"id_menu":6,"count":1}]	25141	pick-up	0	9
110122	2020-08-04 06:45:34	2020-08-04	12	[{"id_menu":1,"count":1}]	21386	pick-up	0	12
110123	2020-08-04 06:47:31	2020-08-04	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	3877	pick-up	0	24
110124	2020-08-04 06:53:20	2020-08-04	17	[{"id_menu":4,"count":1}]	23225	pick-up	0	17
110125	2020-08-04 06:58:11	2020-08-04	14	[{"id_menu":2,"count":1}]	23663	delivery	5	19
110126	2020-08-04 07:04:50	2020-08-04	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	42400	delivery	5	31
110127	2020-08-04 07:06:33	2020-08-04	9	[{"id_menu":6,"count":1}]	38071	delivery	5	14
110128	2020-08-04 07:07:12	2020-08-04	9	[{"id_menu":7,"count":1}]	16904	delivery	5	14
110129	2020-08-04 07:12:56	2020-08-04	9	[{"id_menu":6,"count":1}]	42268	pick-up	0	9
110130	2020-08-04 07:14:02	2020-08-04	9	[{"id_menu":6,"count":2}]	10973	delivery	5	14
110131	2020-08-04 07:14:35	2020-08-04	12	[{"id_menu":3,"count":1}]	42365	delivery	5	17
110132	2020-08-04 07:17:13	2020-08-04	9	[{"id_menu":7,"count":2}]	34827	delivery	5	14
110133	2020-08-04 07:18:07	2020-08-04	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	38045	delivery	5	25
110134	2020-08-04 07:18:34	2020-08-04	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	42376	delivery	5	36
110135	2020-08-04 07:22:57	2020-08-04	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12231	delivery	5	31
110136	2020-08-04 07:23:48	2020-08-04	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	42411	delivery	5	36
110137	2020-08-04 07:23:57	2020-08-04	14	[{"id_menu":2,"count":1}]	6326	delivery	5	19
110138	2020-08-04 07:31:13	2020-08-04	9	[{"id_menu":6,"count":1}]	38358	delivery	5	14
110139	2020-08-04 07:33:20	2020-08-04	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7338	delivery	5	37
110140	2020-08-04 07:34:10	2020-08-04	14	[{"id_menu":2,"count":1}]	408	pick-up	0	14
110141	2020-08-04 07:38:19	2020-08-04	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28651	delivery	5	22
110142	2020-08-04 07:38:51	2020-08-04	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	26071	delivery	5	45
110143	2020-08-04 07:39:15	2020-08-04	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	42370	delivery	5	25
110144	2020-08-04 07:39:56	2020-08-04	8	[{"id_menu":5,"count":1}]	39103	pick-up	0	8
110145	2020-08-04 07:41:30	2020-08-04	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	13634	delivery	5	39
110146	2020-08-04 07:43:52	2020-08-04	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	42280	delivery	5	28
110147	2020-08-04 07:47:36	2020-08-04	9	[{"id_menu":6,"count":1}]	15976	pick-up	0	9
110148	2020-08-04 07:48:32	2020-08-04	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	11380	pick-up	0	24
110149	2020-08-04 07:48:39	2020-08-04	12	[{"id_menu":3,"count":1}]	13166	pick-up	0	12
110150	2020-08-04 07:49:32	2020-08-04	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14399	delivery	5	22
110151	2020-08-04 07:54:39	2020-08-04	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	31835	delivery	5	51
110152	2020-08-04 07:58:26	2020-08-04	9	[{"id_menu":7,"count":1}]	42292	delivery	5	14
110153	2020-08-04 07:58:56	2020-08-04	9	[{"id_menu":6,"count":1}]	32704	delivery	5	14
110154	2020-08-04 07:59:22	2020-08-04	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	42414	delivery	5	25
110155	2020-08-04 08:01:13	2020-08-04	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	5082	pick-up	0	22
110156	2020-08-04 08:02:47	2020-08-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	14263	delivery	5	28
110157	2020-08-04 08:06:08	2020-08-04	17	[{"id_menu":4,"count":1}]	14708	delivery	5	22
110158	2020-08-04 08:11:54	2020-08-04	17	[{"id_menu":4,"count":1}]	20702	delivery	5	22
110159	2020-08-04 08:17:26	2020-08-04	14	[{"id_menu":2,"count":1}]	13984	pick-up	0	14
110160	2020-08-04 08:28:23	2020-08-04	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	7378	delivery	5	31
110161	2020-08-04 08:35:55	2020-08-04	17	[{"id_menu":4,"count":1}]	13082	delivery	5	22
110162	2020-08-04 08:39:08	2020-08-04	8	[{"id_menu":5,"count":1}]	4889	pick-up	0	8
110163	2020-08-04 08:41:32	2020-08-04	9	[{"id_menu":6,"count":1}]	35992	delivery	5	14
110164	2020-08-04 08:44:18	2020-08-04	14	[{"id_menu":2,"count":1}]	24537	delivery	5	19
110165	2020-08-04 08:45:50	2020-08-04	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	9627	pick-up	0	17
110166	2020-08-04 08:49:46	2020-08-04	17	[{"id_menu":4,"count":1}]	29412	delivery	5	22
110167	2020-08-04 08:50:56	2020-08-04	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	15858	delivery	5	22
110168	2020-08-04 08:52:29	2020-08-04	9	[{"id_menu":6,"count":1}]	19674	delivery	5	14
110169	2020-08-04 08:57:33	2020-08-04	9	[{"id_menu":7,"count":1}]	14534	delivery	5	14
110170	2020-08-04 08:57:46	2020-08-04	9	[{"id_menu":6,"count":1}]	32042	delivery	5	14
110171	2020-08-04 08:58:54	2020-08-04	9	[{"id_menu":6,"count":1}]	7983	pick-up	0	9
110172	2020-08-04 08:59:14	2020-08-04	12	[{"id_menu":3,"count":2}]	38484	pick-up	0	12
110173	2020-08-04 08:59:45	2020-08-04	43	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	42374	delivery	5	48
110174	2020-08-04 09:00:07	2020-08-04	14	[{"id_menu":2,"count":1}]	8242	delivery	5	19
110175	2020-08-04 09:01:24	2020-08-04	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	42248	delivery	5	34
110176	2020-08-04 09:01:24	2020-08-04	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	42413	delivery	5	31
110177	2020-08-04 09:03:17	2020-08-04	8	[{"id_menu":5,"count":1}]	2083	delivery	5	13
110178	2020-08-04 09:07:37	2020-08-04	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	15686	pick-up	0	34
110179	2020-08-04 09:09:28	2020-08-04	9	[{"id_menu":6,"count":1}]	19372	delivery	5	14
110180	2020-08-04 09:10:15	2020-08-04	9	[{"id_menu":6,"count":1}]	17459	delivery	5	14
110181	2020-08-04 09:13:21	2020-08-04	17	[{"id_menu":4,"count":1}]	28912	delivery	5	22
110182	2020-08-04 09:14:35	2020-08-04	9	[{"id_menu":7,"count":1}]	10706	pick-up	0	9
110183	2020-08-04 09:16:19	2020-08-04	14	[{"id_menu":2,"count":1}]	22801	delivery	5	19
110184	2020-08-04 09:18:51	2020-08-04	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	41451	delivery	5	39
110185	2020-08-04 09:19:09	2020-08-04	9	[{"id_menu":6,"count":3}]	14696	delivery	5	14
110186	2020-08-04 09:20:11	2020-08-04	17	[{"id_menu":4,"count":1}]	21686	pick-up	0	17
110187	2020-08-04 09:22:49	2020-08-04	9	[{"id_menu":6,"count":2}]	42317	delivery	5	14
110188	2020-08-04 09:24:39	2020-08-04	8	[{"id_menu":5,"count":1}]	25973	delivery	5	13
110189	2020-08-04 09:30:15	2020-08-04	17	[{"id_menu":4,"count":1}]	38271	delivery	5	22
110190	2020-08-04 09:46:27	2020-08-04	17	[{"id_menu":4,"count":1}]	42419	delivery	5	22
110191	2020-08-04 09:47:35	2020-08-04	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	8090	delivery	5	34
110192	2020-08-04 09:47:54	2020-08-04	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	39512	delivery	5	23
110193	2020-08-04 09:56:11	2020-08-04	12	[{"id_menu":1,"count":1}]	23699	delivery	5	17
110194	2020-08-04 09:57:43	2020-08-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	27590	pick-up	0	23
110195	2020-08-04 09:58:47	2020-08-04	9	[{"id_menu":6,"count":1}]	7444	delivery	5	14
110196	2020-08-04 10:01:10	2020-08-04	9	[{"id_menu":6,"count":1}]	3440	delivery	5	14
110197	2020-08-04 10:02:34	2020-08-04	9	[{"id_menu":7,"count":1}]	16100	delivery	5	14
110198	2020-08-04 10:04:25	2020-08-04	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	42339	delivery	5	23
110199	2020-08-04 10:05:32	2020-08-04	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	822	delivery	5	38
110200	2020-08-04 10:09:43	2020-08-04	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38175	delivery	5	40
110201	2020-08-04 10:12:09	2020-08-04	9	[{"id_menu":7,"count":1}]	42393	delivery	5	14
110202	2020-08-04 10:13:32	2020-08-04	9	[{"id_menu":6,"count":1}]	18646	delivery	5	14
110203	2020-08-04 10:16:24	2020-08-04	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17151	delivery	5	34
110204	2020-08-04 10:16:29	2020-08-04	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	17390	delivery	5	40
110205	2020-08-04 10:19:42	2020-08-04	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	42266	pick-up	0	37
110206	2020-08-04 10:20:26	2020-08-04	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	42247	delivery	5	34
110207	2020-08-04 10:21:37	2020-08-04	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	32300	delivery	5	26
110208	2020-08-04 10:28:03	2020-08-04	14	[{"id_menu":2,"count":1}]	2827	pick-up	0	14
110209	2020-08-04 10:28:58	2020-08-04	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5079	delivery	5	28
110210	2020-08-04 10:29:50	2020-08-04	9	[{"id_menu":7,"count":1}]	23099	delivery	5	14
110211	2020-08-04 10:30:40	2020-08-04	12	[{"id_menu":1,"count":1}]	2758	pick-up	0	12
110212	2020-08-04 10:31:20	2020-08-04	12	[{"id_menu":1,"count":1}]	3523	pick-up	0	12
110213	2020-08-04 10:31:36	2020-08-04	17	[{"id_menu":4,"count":1}]	5365	delivery	5	22
110214	2020-08-04 10:35:41	2020-08-04	8	[{"id_menu":5,"count":1}]	42455	delivery	5	13
110215	2020-08-04 10:37:24	2020-08-04	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	38495	delivery	5	25
110216	2020-08-04 10:41:12	2020-08-04	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	42261	delivery	5	22
110217	2020-08-04 10:41:50	2020-08-04	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	20633	delivery	5	37
110218	2020-08-04 10:42:43	2020-08-04	8	[{"id_menu":5,"count":1}]	33273	delivery	5	13
110219	2020-08-04 10:42:46	2020-08-04	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	42293	delivery	5	40
110220	2020-08-04 10:44:13	2020-08-04	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	25656	delivery	5	28
110221	2020-08-04 10:44:54	2020-08-04	17	[{"id_menu":4,"count":1}]	30876	pick-up	0	17
110222	2020-08-04 10:48:48	2020-08-04	17	[{"id_menu":4,"count":1}]	15120	pick-up	0	17
110223	2020-08-04 10:50:08	2020-08-04	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	42435	delivery	5	22
110224	2020-08-04 10:51:05	2020-08-04	9	[{"id_menu":6,"count":1}]	42299	delivery	5	14
110225	2020-08-04 10:57:39	2020-08-04	17	[{"id_menu":4,"count":1}]	8718	delivery	5	22
110226	2020-08-04 10:59:25	2020-08-04	9	[{"id_menu":6,"count":1}]	42260	delivery	5	14
110227	2020-08-04 11:01:32	2020-08-04	9	[{"id_menu":7,"count":1}]	15906	delivery	5	14
110228	2020-08-04 11:10:40	2020-08-04	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	42334	delivery	5	26
110229	2020-08-04 11:13:37	2020-08-04	9	[{"id_menu":6,"count":1}]	11812	delivery	5	14
110230	2020-08-04 11:21:21	2020-08-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	29042	delivery	5	28
110231	2020-08-04 11:23:37	2020-08-04	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	42436	delivery	5	40
110232	2020-08-04 11:23:51	2020-08-04	17	[{"id_menu":4,"count":1}]	38730	delivery	5	22
110233	2020-08-04 11:30:43	2020-08-04	9	[{"id_menu":6,"count":1}]	42382	delivery	5	14
110234	2020-08-04 11:32:00	2020-08-04	9	[{"id_menu":6,"count":1}]	2071	delivery	5	14
110235	2020-08-04 11:32:41	2020-08-04	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	42283	delivery	5	36
110236	2020-08-04 11:40:02	2020-08-04	9	[{"id_menu":6,"count":1}]	31091	delivery	5	14
110237	2020-08-04 11:41:12	2020-08-04	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	26402	delivery	5	36
110238	2020-08-04 11:45:51	2020-08-04	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17223	delivery	5	34
110239	2020-08-04 11:46:05	2020-08-04	12	[{"id_menu":1,"count":1}]	32442	delivery	5	17
110240	2020-08-04 11:47:13	2020-08-04	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	42320	delivery	5	23
110241	2020-08-04 11:47:37	2020-08-04	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41053	delivery	5	31
110242	2020-08-04 11:48:12	2020-08-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	9150	delivery	5	28
110243	2020-08-04 11:53:22	2020-08-04	14	[{"id_menu":2,"count":1}]	547	pick-up	0	14
110244	2020-08-04 11:57:44	2020-08-04	17	[{"id_menu":4,"count":1}]	24534	pick-up	0	17
110245	2020-08-04 12:04:21	2020-08-04	9	[{"id_menu":7,"count":1}]	14291	delivery	5	14
110246	2020-08-04 12:08:33	2020-08-04	12	[{"id_menu":1,"count":1}]	42354	delivery	5	17
110247	2020-08-04 12:10:10	2020-08-04	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8381	delivery	5	44
110248	2020-08-04 12:11:39	2020-08-04	12	[{"id_menu":1,"count":1}]	42330	delivery	5	17
110249	2020-08-04 12:12:41	2020-08-04	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38907	delivery	5	37
110250	2020-08-04 12:15:23	2020-08-04	9	[{"id_menu":6,"count":1}]	42396	delivery	5	14
110251	2020-08-04 12:21:43	2020-08-04	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	42274	delivery	5	25
110252	2020-08-04 12:23:28	2020-08-04	9	[{"id_menu":6,"count":1}]	18950	pick-up	0	9
110253	2020-08-04 12:24:31	2020-08-04	12	[{"id_menu":1,"count":1}]	42434	delivery	5	17
110254	2020-08-04 12:26:48	2020-08-04	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3002	pick-up	0	22
110255	2020-08-04 12:28:01	2020-08-04	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	14328	pick-up	0	29
110256	2020-08-04 12:30:37	2020-08-04	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9043	pick-up	0	35
110257	2020-08-04 12:33:27	2020-08-04	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	32285	delivery	5	31
110258	2020-08-04 12:36:23	2020-08-04	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":2}]	42257	delivery	5	28
110259	2020-08-04 12:43:28	2020-08-04	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	42422	delivery	5	31
110260	2020-08-04 12:45:12	2020-08-04	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	32078	delivery	5	26
110261	2020-08-04 12:47:12	2020-08-04	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	42409	delivery	5	31
110262	2020-08-04 12:53:50	2020-08-04	12	[{"id_menu":1,"count":1}]	21798	pick-up	0	12
110263	2020-08-04 12:54:08	2020-08-04	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	14657	delivery	5	28
110264	2020-08-04 13:01:08	2020-08-04	9	[{"id_menu":7,"count":2}]	42323	delivery	5	14
110265	2020-08-04 13:01:19	2020-08-04	17	[{"id_menu":4,"count":2}]	31664	pick-up	0	17
110266	2020-08-04 13:02:04	2020-08-04	9	[{"id_menu":7,"count":1}]	42319	delivery	5	14
110267	2020-08-04 13:03:49	2020-08-04	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	26468	delivery	5	22
110268	2020-08-04 13:05:13	2020-08-04	9	[{"id_menu":7,"count":1}]	42392	delivery	5	14
110269	2020-08-04 13:09:13	2020-08-04	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	20955	delivery	5	34
110270	2020-08-04 13:10:37	2020-08-04	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6369	pick-up	0	17
110271	2020-08-04 13:11:03	2020-08-04	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4514	delivery	5	43
110272	2020-08-04 13:11:13	2020-08-04	9	[{"id_menu":7,"count":3}]	18281	delivery	5	14
110273	2020-08-04 13:16:34	2020-08-04	14	[{"id_menu":2,"count":1}]	9995	pick-up	0	14
110274	2020-08-04 13:22:20	2020-08-04	9	[{"id_menu":6,"count":2}]	26455	delivery	5	14
110275	2020-08-04 13:24:40	2020-08-04	17	[{"id_menu":4,"count":1}]	10553	pick-up	0	17
110276	2020-08-04 13:27:14	2020-08-04	17	[{"id_menu":4,"count":1}]	32697	delivery	5	22
110277	2020-08-04 13:28:42	2020-08-04	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20970	pick-up	0	29
110278	2020-08-04 13:30:19	2020-08-04	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17094	delivery	5	22
110279	2020-08-04 13:31:07	2020-08-04	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12132	delivery	5	57
110280	2020-08-04 13:33:29	2020-08-04	12	[{"id_menu":1,"count":1}]	2152	pick-up	0	12
110281	2020-08-04 13:33:56	2020-08-04	9	[{"id_menu":6,"count":1}]	10170	delivery	5	14
110282	2020-08-04 13:34:34	2020-08-04	14	[{"id_menu":2,"count":1}]	351	delivery	5	19
110283	2020-08-04 13:41:45	2020-08-04	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	38582	delivery	5	39
110284	2020-08-04 13:45:21	2020-08-04	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	41772	pick-up	0	21
110285	2020-08-04 13:47:56	2020-08-04	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	42412	delivery	5	26
110286	2020-08-04 13:48:24	2020-08-04	12	[{"id_menu":3,"count":1}]	991	pick-up	0	12
110287	2020-08-04 13:50:25	2020-08-04	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1715	delivery	5	34
110288	2020-08-04 13:53:17	2020-08-04	8	[{"id_menu":5,"count":1}]	31264	delivery	5	13
110289	2020-08-04 13:53:40	2020-08-04	14	[{"id_menu":2,"count":1}]	14088	pick-up	0	14
110290	2020-08-04 13:54:56	2020-08-04	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	18935	delivery	5	26
110291	2020-08-04 13:56:04	2020-08-04	14	[{"id_menu":2,"count":1}]	42398	delivery	5	19
110292	2020-08-04 14:17:15	2020-08-04	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	31117	delivery	5	48
110293	2020-08-04 14:17:57	2020-08-04	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10767	pick-up	0	25
110294	2020-08-04 14:19:47	2020-08-04	12	[{"id_menu":3,"count":1}]	36888	delivery	5	17
110295	2020-08-04 14:23:50	2020-08-04	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	33667	pick-up	0	31
110296	2020-08-04 14:25:13	2020-08-04	14	[{"id_menu":2,"count":1}]	24668	pick-up	0	14
110297	2020-08-04 14:29:05	2020-08-04	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	42324	delivery	5	26
110298	2020-08-04 14:30:08	2020-08-04	17	[{"id_menu":4,"count":1}]	18557	pick-up	0	17
110299	2020-08-04 14:40:11	2020-08-04	12	[{"id_menu":3,"count":2}]	40555	pick-up	0	12
110300	2020-08-04 14:41:49	2020-08-04	17	[{"id_menu":4,"count":1}]	16211	delivery	5	22
110301	2020-08-04 14:43:33	2020-08-04	9	[{"id_menu":7,"count":1}]	19280	delivery	5	14
110302	2020-08-04 14:44:29	2020-08-04	9	[{"id_menu":6,"count":1}]	42252	delivery	5	14
110303	2020-08-04 14:44:40	2020-08-04	12	[{"id_menu":1,"count":1}]	1754	pick-up	0	12
110304	2020-08-04 14:47:51	2020-08-04	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	42373	delivery	5	36
110305	2020-08-04 14:53:28	2020-08-04	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	612	pick-up	0	23
110306	2020-08-04 14:53:48	2020-08-04	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	40062	delivery	5	31
110307	2020-08-04 14:54:50	2020-08-04	9	[{"id_menu":6,"count":1}]	27199	delivery	5	14
110308	2020-08-04 15:01:30	2020-08-04	17	[{"id_menu":4,"count":1}]	5668	delivery	5	22
110309	2020-08-04 15:04:18	2020-08-04	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15821	delivery	5	40
110310	2020-08-04 15:13:47	2020-08-04	12	[{"id_menu":3,"count":1}]	813	pick-up	0	12
110311	2020-08-04 15:18:32	2020-08-04	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	42444	delivery	5	31
110312	2020-08-04 15:20:08	2020-08-04	9	[{"id_menu":7,"count":1}]	37260	delivery	5	14
110313	2020-08-04 15:21:09	2020-08-04	14	[{"id_menu":2,"count":1}]	11329	pick-up	0	14
110314	2020-08-04 15:21:22	2020-08-04	9	[{"id_menu":7,"count":2}]	42408	delivery	5	14
110315	2020-08-04 15:25:57	2020-08-04	8	[{"id_menu":5,"count":1}]	23654	delivery	5	13
110316	2020-08-04 15:26:24	2020-08-04	17	[{"id_menu":4,"count":1}]	5540	delivery	5	22
110317	2020-08-04 15:26:32	2020-08-04	9	[{"id_menu":6,"count":1}]	42275	delivery	5	14
110318	2020-08-04 15:27:05	2020-08-04	14	[{"id_menu":2,"count":1}]	34778	delivery	5	19
110319	2020-08-04 15:30:58	2020-08-04	9	[{"id_menu":6,"count":2}]	27042	delivery	5	14
110320	2020-08-04 15:32:22	2020-08-04	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	41880	delivery	5	48
110321	2020-08-04 15:34:14	2020-08-04	12	[{"id_menu":1,"count":1}]	12962	pick-up	0	12
110322	2020-08-04 15:43:44	2020-08-04	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16172	delivery	5	43
110323	2020-08-04 15:47:30	2020-08-04	14	[{"id_menu":2,"count":1}]	12934	delivery	5	19
110324	2020-08-04 15:48:27	2020-08-04	14	[{"id_menu":2,"count":1}]	39883	delivery	5	19
110325	2020-08-04 15:48:46	2020-08-04	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	42442	delivery	5	31
110326	2020-08-04 15:49:21	2020-08-04	8	[{"id_menu":5,"count":1}]	39938	delivery	5	13
110327	2020-08-04 15:52:06	2020-08-04	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	20136	pick-up	0	22
110328	2020-08-04 15:53:12	2020-08-04	9	[{"id_menu":6,"count":1}]	39760	pick-up	0	9
110329	2020-08-04 15:55:58	2020-08-04	12	[{"id_menu":3,"count":1}]	37730	pick-up	0	12
110330	2020-08-04 16:00:36	2020-08-04	12	[{"id_menu":1,"count":1}]	2783	delivery	5	17
110331	2020-08-04 16:01:08	2020-08-04	17	[{"id_menu":4,"count":1}]	28580	delivery	5	22
110332	2020-08-04 16:03:09	2020-08-04	14	[{"id_menu":2,"count":1}]	35565	pick-up	0	14
110333	2020-08-04 16:03:31	2020-08-04	12	[{"id_menu":1,"count":1}]	16674	pick-up	0	12
110334	2020-08-04 16:05:19	2020-08-04	9	[{"id_menu":6,"count":1}]	27271	delivery	5	14
110335	2020-08-04 16:06:38	2020-08-04	9	[{"id_menu":7,"count":1}]	7705	delivery	5	14
110336	2020-08-04 16:06:57	2020-08-04	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	591	delivery	5	23
110337	2020-08-04 16:07:37	2020-08-04	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	14344	delivery	5	31
110338	2020-08-04 16:08:09	2020-08-04	9	[{"id_menu":6,"count":1}]	3754	pick-up	0	9
110339	2020-08-04 16:09:53	2020-08-04	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	13101	delivery	5	28
110340	2020-08-04 16:10:38	2020-08-04	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	40193	delivery	5	26
110341	2020-08-04 16:12:00	2020-08-04	9	[{"id_menu":7,"count":1}]	3392	delivery	5	14
110342	2020-08-04 16:12:29	2020-08-04	12	[{"id_menu":1,"count":1}]	15791	pick-up	0	12
110343	2020-08-04 16:14:18	2020-08-04	12	[{"id_menu":1,"count":1}]	31552	delivery	5	17
110344	2020-08-04 16:14:22	2020-08-04	8	[{"id_menu":5,"count":1}]	13841	delivery	5	13
110345	2020-08-04 16:16:43	2020-08-04	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	42250	delivery	5	31
110346	2020-08-04 16:18:31	2020-08-04	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	37817	delivery	5	43
110347	2020-08-04 16:18:34	2020-08-04	12	[{"id_menu":3,"count":1}]	21483	delivery	5	17
110348	2020-08-04 16:18:39	2020-08-04	9	[{"id_menu":7,"count":1}]	1820	delivery	5	14
110349	2020-08-04 16:19:34	2020-08-04	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	42327	delivery	5	31
110350	2020-08-04 16:20:37	2020-08-04	29	[{"id_menu":3,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31951	delivery	5	34
110351	2020-08-04 16:21:37	2020-08-04	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	4344	delivery	5	22
110352	2020-08-04 16:23:37	2020-08-04	12	[{"id_menu":1,"count":1}]	41774	delivery	5	17
110353	2020-08-04 16:28:53	2020-08-04	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	42417	delivery	5	31
110354	2020-08-04 16:32:58	2020-08-04	9	[{"id_menu":7,"count":1}]	170	pick-up	0	9
110355	2020-08-04 16:33:40	2020-08-04	9	[{"id_menu":7,"count":1}]	8884	delivery	5	14
110356	2020-08-04 16:36:05	2020-08-04	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	27241	delivery	5	26
110357	2020-08-04 16:37:54	2020-08-04	14	[{"id_menu":2,"count":1}]	14314	pick-up	0	14
110358	2020-08-04 16:38:15	2020-08-04	8	[{"id_menu":5,"count":1}]	41295	delivery	5	13
110359	2020-08-04 16:38:26	2020-08-04	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11148	delivery	5	22
110360	2020-08-04 16:41:16	2020-08-04	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	42271	delivery	5	31
110361	2020-08-04 16:45:00	2020-08-04	14	[{"id_menu":2,"count":1}]	23500	pick-up	0	14
110362	2020-08-04 16:45:24	2020-08-04	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":2}]	42281	delivery	5	31
110363	2020-08-04 16:55:52	2020-08-04	17	[{"id_menu":4,"count":1}]	42149	delivery	5	22
110364	2020-08-04 16:57:11	2020-08-04	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	13907	delivery	5	25
110365	2020-08-04 16:59:12	2020-08-04	9	[{"id_menu":7,"count":1}]	42308	delivery	5	14
110366	2020-08-04 17:01:06	2020-08-04	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1406	delivery	5	57
110367	2020-08-04 17:01:21	2020-08-04	12	[{"id_menu":3,"count":1}]	27873	delivery	5	17
110368	2020-08-04 17:06:06	2020-08-04	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	42321	delivery	5	23
110369	2020-08-04 17:10:55	2020-08-04	14	[{"id_menu":2,"count":1}]	2988	delivery	5	19
110370	2020-08-04 17:15:21	2020-08-04	9	[{"id_menu":7,"count":1}]	5094	pick-up	0	9
110371	2020-08-04 17:18:09	2020-08-04	9	[{"id_menu":7,"count":1}]	35812	pick-up	0	9
110372	2020-08-04 17:21:18	2020-08-04	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	42255	delivery	5	31
110373	2020-08-04 17:22:09	2020-08-04	9	[{"id_menu":6,"count":1}]	22412	delivery	5	14
110374	2020-08-04 17:25:22	2020-08-04	14	[{"id_menu":2,"count":1}]	7685	delivery	5	19
110375	2020-08-04 17:25:30	2020-08-04	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6168	delivery	5	45
110376	2020-08-04 17:26:27	2020-08-04	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23462	delivery	5	51
110377	2020-08-04 17:29:13	2020-08-04	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3160	delivery	5	27
110378	2020-08-04 17:30:05	2020-08-04	9	[{"id_menu":6,"count":1}]	38239	pick-up	0	9
110379	2020-08-04 17:30:09	2020-08-04	8	[{"id_menu":5,"count":1}]	8274	delivery	5	13
110380	2020-08-04 17:30:31	2020-08-04	9	[{"id_menu":6,"count":1}]	42405	delivery	5	14
110381	2020-08-04 17:40:03	2020-08-04	14	[{"id_menu":2,"count":1}]	30256	pick-up	0	14
110382	2020-08-04 17:43:25	2020-08-04	8	[{"id_menu":5,"count":1}]	42304	delivery	5	13
110383	2020-08-04 17:49:01	2020-08-04	9	[{"id_menu":6,"count":1}]	1068	delivery	5	14
110384	2020-08-04 17:49:32	2020-08-04	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4628	delivery	5	31
110385	2020-08-04 17:50:49	2020-08-04	8	[{"id_menu":5,"count":1}]	8160	delivery	5	13
110386	2020-08-04 17:54:14	2020-08-04	9	[{"id_menu":6,"count":3}]	42251	delivery	5	14
110387	2020-08-04 17:54:38	2020-08-04	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	42389	delivery	5	39
110388	2020-08-04 17:57:13	2020-08-04	9	[{"id_menu":6,"count":1}]	13324	pick-up	0	9
110389	2020-08-04 17:58:39	2020-08-04	14	[{"id_menu":2,"count":1}]	40574	delivery	5	19
110390	2020-08-04 17:59:44	2020-08-04	9	[{"id_menu":6,"count":2}]	27908	delivery	5	14
110391	2020-08-04 18:04:15	2020-08-04	17	[{"id_menu":4,"count":1}]	38185	delivery	5	22
110392	2020-08-04 18:04:17	2020-08-04	8	[{"id_menu":5,"count":1}]	28288	delivery	5	13
110393	2020-08-04 18:05:11	2020-08-04	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	5527	delivery	5	29
110394	2020-08-04 18:20:25	2020-08-04	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	15617	delivery	5	22
110395	2020-08-04 18:21:07	2020-08-04	9	[{"id_menu":6,"count":1}]	14605	delivery	5	14
110396	2020-08-04 18:22:59	2020-08-04	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	42256	pick-up	0	43
110397	2020-08-04 18:25:04	2020-08-04	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	9867	delivery	5	28
110398	2020-08-04 18:26:28	2020-08-04	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	36458	pick-up	0	18
110399	2020-08-04 18:28:50	2020-08-04	9	[{"id_menu":7,"count":1}]	19132	delivery	5	14
110400	2020-08-04 18:34:38	2020-08-04	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	28932	delivery	5	25
110401	2020-08-04 18:37:07	2020-08-04	12	[{"id_menu":1,"count":1}]	19514	pick-up	0	12
110402	2020-08-04 18:38:46	2020-08-04	9	[{"id_menu":6,"count":1}]	29800	pick-up	0	9
110403	2020-08-04 18:42:30	2020-08-04	8	[{"id_menu":5,"count":1}]	42416	delivery	5	13
110404	2020-08-04 18:44:34	2020-08-04	9	[{"id_menu":6,"count":1}]	31207	delivery	5	14
110405	2020-08-04 18:51:52	2020-08-04	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	42378	delivery	5	30
110406	2020-08-04 18:54:16	2020-08-04	9	[{"id_menu":7,"count":1}]	517	delivery	5	14
110407	2020-08-04 18:57:09	2020-08-04	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	42259	delivery	5	36
110408	2020-08-04 19:01:48	2020-08-04	9	[{"id_menu":7,"count":1}]	8638	delivery	5	14
110409	2020-08-04 19:02:30	2020-08-04	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21283	delivery	5	36
110410	2020-08-04 19:05:04	2020-08-04	9	[{"id_menu":7,"count":2}]	42279	delivery	5	14
110411	2020-08-04 19:09:41	2020-08-04	14	[{"id_menu":2,"count":1}]	669	pick-up	0	14
110412	2020-08-04 19:14:36	2020-08-04	12	[{"id_menu":1,"count":1}]	6166	delivery	5	17
110413	2020-08-04 19:14:49	2020-08-04	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	19004	delivery	5	28
110414	2020-08-04 19:18:14	2020-08-04	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	5354	pick-up	0	24
110415	2020-08-04 19:19:32	2020-08-04	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	42265	pick-up	0	23
110416	2020-08-04 19:20:01	2020-08-04	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	41376	delivery	5	26
110417	2020-08-04 19:29:34	2020-08-04	17	[{"id_menu":4,"count":1}]	20108	delivery	5	22
110418	2020-08-04 19:30:36	2020-08-04	9	[{"id_menu":6,"count":1}]	42366	pick-up	0	9
110419	2020-08-04 19:32:57	2020-08-04	12	[{"id_menu":1,"count":1}]	19868	pick-up	0	12
110420	2020-08-04 19:33:20	2020-08-04	8	[{"id_menu":5,"count":1}]	35083	delivery	5	13
110421	2020-08-04 19:33:54	2020-08-04	9	[{"id_menu":7,"count":1}]	37968	delivery	5	14
110422	2020-08-04 19:34:19	2020-08-04	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28456	pick-up	0	38
110423	2020-08-04 19:37:17	2020-08-04	9	[{"id_menu":7,"count":1}]	35324	delivery	5	14
110424	2020-08-04 19:38:19	2020-08-04	9	[{"id_menu":6,"count":1}]	42311	delivery	5	14
110425	2020-08-04 19:41:51	2020-08-04	9	[{"id_menu":6,"count":1}]	15320	delivery	5	14
110426	2020-08-04 19:43:34	2020-08-04	8	[{"id_menu":5,"count":1}]	15804	delivery	5	13
110427	2020-08-04 19:44:45	2020-08-04	9	[{"id_menu":7,"count":1}]	42362	delivery	5	14
110428	2020-08-04 19:46:43	2020-08-04	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18227	pick-up	0	18
110429	2020-08-04 19:48:38	2020-08-04	14	[{"id_menu":2,"count":1}]	42452	delivery	5	19
110430	2020-08-04 19:51:07	2020-08-04	12	[{"id_menu":1,"count":1}]	12291	delivery	5	17
110431	2020-08-04 19:51:28	2020-08-04	12	[{"id_menu":3,"count":1}]	11042	delivery	5	17
110432	2020-08-04 19:52:16	2020-08-04	12	[{"id_menu":3,"count":1}]	22197	delivery	5	17
110433	2020-08-04 19:57:59	2020-08-04	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	6846	delivery	5	26
110434	2020-08-04 19:59:26	2020-08-04	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	38433	delivery	5	26
110435	2020-08-04 20:00:50	2020-08-04	9	[{"id_menu":7,"count":1}]	42353	delivery	5	14
110436	2020-08-04 20:03:53	2020-08-04	9	[{"id_menu":7,"count":2}]	41722	delivery	5	14
110437	2020-08-04 20:04:44	2020-08-04	9	[{"id_menu":6,"count":1}]	42332	delivery	5	14
110438	2020-08-04 20:08:54	2020-08-04	14	[{"id_menu":2,"count":1}]	34488	delivery	5	19
110439	2020-08-04 20:11:02	2020-08-04	12	[{"id_menu":1,"count":1}]	2840	pick-up	0	12
110440	2020-08-04 20:12:10	2020-08-04	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	22848	delivery	5	22
110441	2020-08-04 20:13:51	2020-08-04	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	20243	delivery	5	34
110442	2020-08-04 20:18:27	2020-08-04	8	[{"id_menu":5,"count":1}]	42314	delivery	5	13
110443	2020-08-04 20:30:27	2020-08-04	8	[{"id_menu":5,"count":1}]	14005	delivery	5	13
110444	2020-08-04 20:32:20	2020-08-04	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	21725	delivery	5	26
110445	2020-08-04 20:32:49	2020-08-04	9	[{"id_menu":6,"count":1}]	27347	delivery	5	14
110446	2020-08-04 20:33:39	2020-08-04	17	[{"id_menu":4,"count":1}]	16972	pick-up	0	17
110447	2020-08-04 20:35:33	2020-08-04	17	[{"id_menu":4,"count":1}]	24407	pick-up	0	17
110448	2020-08-04 20:36:32	2020-08-04	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6608	pick-up	0	26
110449	2020-08-04 20:38:05	2020-08-04	9	[{"id_menu":7,"count":1}]	42249	delivery	5	14
110450	2020-08-04 20:39:57	2020-08-04	12	[{"id_menu":3,"count":1}]	2711	pick-up	0	12
110451	2020-08-04 20:40:15	2020-08-04	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8628	delivery	5	31
110452	2020-08-04 20:40:53	2020-08-04	12	[{"id_menu":3,"count":1}]	9607	delivery	5	17
110453	2020-08-04 20:42:39	2020-08-04	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	42347	delivery	5	22
110454	2020-08-04 20:44:21	2020-08-04	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	754	delivery	5	26
110455	2020-08-04 20:48:43	2020-08-04	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	42270	delivery	5	48
110456	2020-08-04 20:55:13	2020-08-04	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	6233	delivery	5	23
110457	2020-08-04 21:00:55	2020-08-04	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	42338	delivery	5	34
110458	2020-08-04 21:01:48	2020-08-04	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	42310	delivery	5	36
110459	2020-08-04 21:03:56	2020-08-04	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	42246	delivery	5	39
110460	2020-08-04 21:06:39	2020-08-04	14	[{"id_menu":2,"count":1}]	38017	delivery	5	19
110461	2020-08-04 21:09:21	2020-08-04	9	[{"id_menu":7,"count":1}]	29339	delivery	5	14
110462	2020-08-04 21:09:35	2020-08-04	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	42254	delivery	5	31
110463	2020-08-04 21:12:30	2020-08-04	9	[{"id_menu":7,"count":1}]	6645	delivery	5	14
110464	2020-08-04 21:14:54	2020-08-04	14	[{"id_menu":2,"count":1}]	3621	delivery	5	19
110465	2020-08-04 21:17:04	2020-08-04	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	42367	delivery	5	31
110466	2020-08-04 21:22:40	2020-08-04	14	[{"id_menu":2,"count":1}]	32105	delivery	5	19
110467	2020-08-04 21:27:11	2020-08-04	17	[{"id_menu":4,"count":1}]	16849	delivery	5	22
110468	2020-08-04 21:28:47	2020-08-04	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	42384	delivery	5	26
110469	2020-08-04 21:31:33	2020-08-04	14	[{"id_menu":2,"count":1}]	30639	delivery	5	19
110470	2020-08-04 21:31:40	2020-08-04	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	16246	pick-up	0	37
110471	2020-08-04 21:32:32	2020-08-04	8	[{"id_menu":5,"count":1}]	3931	pick-up	0	8
110472	2020-08-04 21:39:40	2020-08-04	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	17881	delivery	5	42
110473	2020-08-04 21:39:41	2020-08-04	12	[{"id_menu":3,"count":1}]	17861	pick-up	0	12
110474	2020-08-04 21:40:13	2020-08-04	12	[{"id_menu":1,"count":1}]	33744	delivery	5	17
110475	2020-08-04 21:43:29	2020-08-04	12	[{"id_menu":1,"count":1}]	42427	pick-up	0	12
110476	2020-08-04 21:43:30	2020-08-04	12	[{"id_menu":1,"count":1}]	40517	delivery	5	17
110477	2020-08-04 21:45:32	2020-08-04	9	[{"id_menu":7,"count":1}]	28284	delivery	5	14
110478	2020-08-04 21:51:06	2020-08-04	17	[{"id_menu":4,"count":1}]	12502	pick-up	0	17
110479	2020-08-04 21:51:40	2020-08-04	17	[{"id_menu":4,"count":1}]	18445	pick-up	0	17
110480	2020-08-04 21:53:14	2020-08-04	9	[{"id_menu":7,"count":1}]	4694	delivery	5	14
110481	2020-08-04 21:54:32	2020-08-04	9	[{"id_menu":6,"count":2}]	42290	pick-up	0	9
110482	2020-08-04 21:59:07	2020-08-04	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11039	delivery	5	23
110483	2020-08-04 22:08:17	2020-08-04	14	[{"id_menu":2,"count":1}]	21508	pick-up	0	14
110484	2020-08-04 22:11:38	2020-08-04	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	20998	delivery	5	28
110485	2020-08-04 22:11:42	2020-08-04	8	[{"id_menu":5,"count":1}]	24805	delivery	5	13
110486	2020-08-04 22:15:03	2020-08-04	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	42430	delivery	5	28
110487	2020-08-04 22:15:13	2020-08-04	9	[{"id_menu":7,"count":1}]	17897	delivery	5	14
110488	2020-08-04 22:15:17	2020-08-04	9	[{"id_menu":6,"count":1}]	5277	pick-up	0	9
110489	2020-08-04 22:19:04	2020-08-04	17	[{"id_menu":4,"count":1}]	1003	delivery	5	22
110490	2020-08-04 22:19:09	2020-08-04	8	[{"id_menu":5,"count":1}]	3823	delivery	5	13
110491	2020-08-04 22:22:42	2020-08-04	12	[{"id_menu":3,"count":1}]	41828	delivery	5	17
110492	2020-08-04 22:22:44	2020-08-04	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	26492	delivery	5	28
110493	2020-08-04 22:25:34	2020-08-04	8	[{"id_menu":5,"count":3}]	32466	delivery	5	13
110494	2020-08-04 22:26:29	2020-08-04	12	[{"id_menu":3,"count":1}]	15207	pick-up	0	12
110495	2020-08-04 22:27:27	2020-08-04	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	42425	delivery	5	36
110496	2020-08-04 22:32:09	2020-08-04	9	[{"id_menu":6,"count":1}]	1130	pick-up	0	9
110497	2020-08-04 22:34:26	2020-08-04	55	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	42287	delivery	5	60
110498	2020-08-04 22:39:56	2020-08-04	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	37873	delivery	5	26
110499	2020-08-04 22:40:18	2020-08-04	8	[{"id_menu":5,"count":1}]	27599	delivery	5	13
110500	2020-08-04 22:49:10	2020-08-04	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11221	delivery	5	31
110501	2020-08-04 22:49:28	2020-08-04	9	[{"id_menu":6,"count":1}]	491	pick-up	0	9
110502	2020-08-04 22:50:08	2020-08-04	12	[{"id_menu":3,"count":1}]	20304	delivery	5	17
110503	2020-08-04 22:53:17	2020-08-04	12	[{"id_menu":1,"count":1}]	11040	pick-up	0	12
110504	2020-08-04 22:54:08	2020-08-04	14	[{"id_menu":2,"count":1}]	123	pick-up	0	14
110505	2020-08-04 22:56:29	2020-08-04	17	[{"id_menu":4,"count":1}]	6975	pick-up	0	17
110506	2020-08-04 23:08:55	2020-08-04	14	[{"id_menu":2,"count":1}]	24226	delivery	5	19
110507	2020-08-04 23:11:03	2020-08-04	8	[{"id_menu":5,"count":1}]	38159	delivery	5	13
110508	2020-08-04 23:11:11	2020-08-04	26	[{"id_menu":2,"count":3},{"id_menu":3,"count":1}]	42312	delivery	5	31
110509	2020-08-04 23:11:53	2020-08-04	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2615	pick-up	0	38
110510	2020-08-04 23:12:56	2020-08-04	17	[{"id_menu":4,"count":1}]	12602	pick-up	0	17
110511	2020-08-04 23:22:46	2020-08-04	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	14290	pick-up	0	26
110512	2020-08-04 23:23:24	2020-08-04	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	20511	delivery	5	30
110513	2020-08-04 23:33:54	2020-08-04	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	42092	delivery	5	45
110514	2020-08-04 23:39:14	2020-08-04	9	[{"id_menu":7,"count":1}]	15117	delivery	5	14
110515	2020-08-04 23:42:28	2020-08-04	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	26940	pick-up	0	23
110516	2020-08-04 23:42:44	2020-08-04	17	[{"id_menu":4,"count":2}]	1822	delivery	5	22
110517	2020-08-04 23:46:29	2020-08-04	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	6831	delivery	5	26
110518	2020-08-04 23:47:04	2020-08-04	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	42371	delivery	5	31
110519	2020-08-04 23:48:49	2020-08-04	9	[{"id_menu":6,"count":1}]	34697	delivery	5	14
110520	2020-08-04 23:52:52	2020-08-04	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	313	pick-up	0	29
110521	2020-08-04 23:53:27	2020-08-04	12	[{"id_menu":1,"count":1}]	5537	delivery	5	17
110522	2020-08-05 00:00:10	2020-08-05	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	16829	delivery	5	34
110523	2020-08-05 00:04:02	2020-08-05	17	[{"id_menu":4,"count":1}]	11649	pick-up	0	17
110524	2020-08-05 00:04:02	2020-08-05	12	[{"id_menu":3,"count":1}]	38897	pick-up	0	12
110525	2020-08-05 00:05:37	2020-08-05	12	[{"id_menu":1,"count":1}]	24920	delivery	5	17
110526	2020-08-05 00:07:29	2020-08-05	17	[{"id_menu":4,"count":1}]	36051	delivery	5	22
110527	2020-08-05 00:08:16	2020-08-05	9	[{"id_menu":7,"count":1}]	21185	delivery	5	14
110528	2020-08-05 00:08:50	2020-08-05	12	[{"id_menu":1,"count":1}]	18556	delivery	5	17
110529	2020-08-05 00:12:20	2020-08-05	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	29509	pick-up	0	31
110530	2020-08-05 00:12:55	2020-08-05	8	[{"id_menu":5,"count":1}]	35975	delivery	5	13
110531	2020-08-05 00:18:38	2020-08-05	8	[{"id_menu":5,"count":1}]	6672	pick-up	0	8
110532	2020-08-05 00:24:11	2020-08-05	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	24434	pick-up	0	21
110533	2020-08-05 00:24:22	2020-08-05	12	[{"id_menu":3,"count":1}]	25001	delivery	5	17
110534	2020-08-05 00:25:16	2020-08-05	12	[{"id_menu":3,"count":1}]	42477	delivery	5	17
110535	2020-08-05 00:28:49	2020-08-05	9	[{"id_menu":7,"count":1}]	14673	pick-up	0	9
110536	2020-08-05 00:29:15	2020-08-05	14	[{"id_menu":2,"count":1}]	42647	delivery	5	19
110537	2020-08-05 00:31:52	2020-08-05	14	[{"id_menu":2,"count":1}]	28430	delivery	5	19
110538	2020-08-05 00:32:19	2020-08-05	8	[{"id_menu":5,"count":1}]	27449	delivery	5	13
110539	2020-08-05 00:33:06	2020-08-05	9	[{"id_menu":6,"count":1}]	42615	delivery	5	14
110540	2020-08-05 00:33:12	2020-08-05	8	[{"id_menu":5,"count":1}]	32815	delivery	5	13
110541	2020-08-05 00:35:19	2020-08-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34667	delivery	5	23
110542	2020-08-05 00:40:01	2020-08-05	9	[{"id_menu":6,"count":1}]	42550	delivery	5	14
110543	2020-08-05 00:41:25	2020-08-05	17	[{"id_menu":4,"count":1}]	17239	pick-up	0	17
110544	2020-08-05 00:42:42	2020-08-05	14	[{"id_menu":2,"count":2}]	38876	delivery	5	19
110545	2020-08-05 00:49:26	2020-08-05	9	[{"id_menu":6,"count":1}]	27828	delivery	5	14
110546	2020-08-05 00:51:42	2020-08-05	9	[{"id_menu":7,"count":1}]	42601	delivery	5	14
110547	2020-08-05 00:55:57	2020-08-05	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	991	pick-up	0	34
110548	2020-08-05 00:56:26	2020-08-05	9	[{"id_menu":6,"count":1}]	36782	delivery	5	14
110549	2020-08-05 00:57:08	2020-08-05	12	[{"id_menu":1,"count":1}]	34378	delivery	5	17
110550	2020-08-05 00:59:08	2020-08-05	9	[{"id_menu":7,"count":1}]	20885	delivery	5	14
110551	2020-08-05 01:01:02	2020-08-05	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5325	delivery	5	30
110552	2020-08-05 01:01:54	2020-08-05	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	12195	delivery	5	26
110553	2020-08-05 01:04:12	2020-08-05	9	[{"id_menu":6,"count":1}]	42591	delivery	5	14
110554	2020-08-05 01:09:28	2020-08-05	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	42502	delivery	5	30
110555	2020-08-05 01:10:13	2020-08-05	12	[{"id_menu":3,"count":1}]	42460	delivery	5	17
110556	2020-08-05 01:10:43	2020-08-05	12	[{"id_menu":3,"count":1}]	42666	delivery	5	17
110557	2020-08-05 01:12:49	2020-08-05	12	[{"id_menu":1,"count":1}]	42470	delivery	5	17
110558	2020-08-05 01:21:29	2020-08-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	42487	delivery	5	31
110559	2020-08-05 01:23:14	2020-08-05	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	299	delivery	5	31
110560	2020-08-05 01:25:02	2020-08-05	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	25069	delivery	5	22
110561	2020-08-05 01:31:31	2020-08-05	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6195	delivery	5	31
110562	2020-08-05 01:31:40	2020-08-05	12	[{"id_menu":3,"count":1}]	9833	delivery	5	17
110563	2020-08-05 01:34:06	2020-08-05	8	[{"id_menu":5,"count":1}]	29387	delivery	5	13
110564	2020-08-05 01:34:24	2020-08-05	9	[{"id_menu":6,"count":1}]	42542	delivery	5	14
110565	2020-08-05 01:35:34	2020-08-05	17	[{"id_menu":4,"count":1}]	3993	delivery	5	22
110566	2020-08-05 01:36:06	2020-08-05	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	42464	delivery	5	43
110567	2020-08-05 01:36:50	2020-08-05	9	[{"id_menu":7,"count":1}]	5192	delivery	5	14
110568	2020-08-05 01:38:33	2020-08-05	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	19380	delivery	5	40
110569	2020-08-05 01:39:01	2020-08-05	9	[{"id_menu":7,"count":1}]	2068	pick-up	0	9
110570	2020-08-05 01:39:52	2020-08-05	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	22639	delivery	5	29
110571	2020-08-05 01:41:14	2020-08-05	9	[{"id_menu":6,"count":1}]	42617	delivery	5	14
110572	2020-08-05 01:41:46	2020-08-05	12	[{"id_menu":3,"count":1}]	42516	delivery	5	17
110573	2020-08-05 01:44:48	2020-08-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6671	pick-up	0	23
110574	2020-08-05 01:50:51	2020-08-05	30	[{"id_menu":1,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33020	delivery	5	35
110575	2020-08-05 01:51:59	2020-08-05	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	6987	pick-up	0	29
110576	2020-08-05 01:54:07	2020-08-05	14	[{"id_menu":2,"count":1}]	33631	delivery	5	19
110577	2020-08-05 01:59:20	2020-08-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5817	delivery	5	23
110578	2020-08-05 02:01:30	2020-08-05	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	31208	delivery	5	22
110579	2020-08-05 02:03:13	2020-08-05	9	[{"id_menu":6,"count":1}]	41615	delivery	5	14
110580	2020-08-05 02:06:02	2020-08-05	12	[{"id_menu":3,"count":1}]	9759	delivery	5	17
110581	2020-08-05 02:12:48	2020-08-05	12	[{"id_menu":3,"count":1}]	42473	delivery	5	17
110582	2020-08-05 02:12:52	2020-08-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	42673	delivery	5	23
110583	2020-08-05 02:14:32	2020-08-05	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	19323	delivery	5	40
110584	2020-08-05 02:14:49	2020-08-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	29422	delivery	5	28
110585	2020-08-05 02:18:50	2020-08-05	12	[{"id_menu":1,"count":1}]	17112	delivery	5	17
110586	2020-08-05 02:19:41	2020-08-05	17	[{"id_menu":4,"count":1}]	19247	delivery	5	22
110587	2020-08-05 02:21:24	2020-08-05	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	24803	delivery	5	26
110588	2020-08-05 02:21:39	2020-08-05	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	42458	delivery	5	34
110589	2020-08-05 02:22:58	2020-08-05	9	[{"id_menu":7,"count":1}]	38569	pick-up	0	9
110590	2020-08-05 02:23:10	2020-08-05	9	[{"id_menu":7,"count":1}]	35126	delivery	5	14
110591	2020-08-05 02:25:15	2020-08-05	14	[{"id_menu":2,"count":2}]	42515	pick-up	0	14
110592	2020-08-05 02:27:25	2020-08-05	9	[{"id_menu":6,"count":1}]	42565	delivery	5	14
110593	2020-08-05 02:28:11	2020-08-05	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	42645	delivery	5	43
110594	2020-08-05 02:29:19	2020-08-05	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	12274	pick-up	0	22
110595	2020-08-05 02:29:41	2020-08-05	9	[{"id_menu":6,"count":1}]	10820	delivery	5	14
110596	2020-08-05 02:30:56	2020-08-05	9	[{"id_menu":7,"count":1}]	270	pick-up	0	9
110597	2020-08-05 02:31:29	2020-08-05	9	[{"id_menu":7,"count":2}]	42648	delivery	5	14
110598	2020-08-05 02:37:06	2020-08-05	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	40333	delivery	5	51
110599	2020-08-05 02:37:14	2020-08-05	14	[{"id_menu":2,"count":1}]	6755	delivery	5	19
110600	2020-08-05 02:38:54	2020-08-05	14	[{"id_menu":2,"count":1}]	39031	delivery	5	19
110601	2020-08-05 02:45:58	2020-08-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3863	delivery	5	23
110602	2020-08-05 02:46:23	2020-08-05	8	[{"id_menu":5,"count":1}]	729	pick-up	0	8
110603	2020-08-05 02:52:36	2020-08-05	9	[{"id_menu":6,"count":4}]	42467	delivery	5	14
110604	2020-08-05 02:53:47	2020-08-05	8	[{"id_menu":5,"count":1}]	11563	delivery	5	13
110605	2020-08-05 02:54:38	2020-08-05	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	36347	delivery	5	26
110606	2020-08-05 02:54:51	2020-08-05	9	[{"id_menu":7,"count":1}]	28035	delivery	5	14
110607	2020-08-05 02:56:57	2020-08-05	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13327	delivery	5	37
110608	2020-08-05 02:57:58	2020-08-05	9	[{"id_menu":7,"count":1}]	7288	delivery	5	14
110609	2020-08-05 03:02:16	2020-08-05	12	[{"id_menu":3,"count":1}]	34685	pick-up	0	12
110610	2020-08-05 03:11:37	2020-08-05	9	[{"id_menu":6,"count":1}]	36113	delivery	5	14
110611	2020-08-05 03:14:14	2020-08-05	17	[{"id_menu":4,"count":1}]	32331	pick-up	0	17
110612	2020-08-05 03:18:05	2020-08-05	8	[{"id_menu":5,"count":1}]	9295	delivery	5	13
110613	2020-08-05 03:19:55	2020-08-05	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	42612	delivery	5	49
110614	2020-08-05 03:21:47	2020-08-05	14	[{"id_menu":2,"count":1}]	5966	pick-up	0	14
110615	2020-08-05 03:23:09	2020-08-05	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	13791	delivery	5	31
110616	2020-08-05 03:24:30	2020-08-05	17	[{"id_menu":4,"count":1}]	7342	delivery	5	22
110617	2020-08-05 03:29:24	2020-08-05	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	42321	delivery	5	25
110618	2020-08-05 03:30:15	2020-08-05	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	21786	pick-up	0	21
110619	2020-08-05 03:30:25	2020-08-05	12	[{"id_menu":3,"count":1}]	9053	pick-up	0	12
110620	2020-08-05 03:30:39	2020-08-05	9	[{"id_menu":7,"count":1}]	26801	delivery	5	14
110621	2020-08-05 03:34:22	2020-08-05	9	[{"id_menu":7,"count":1}]	24353	delivery	5	14
110622	2020-08-05 03:38:24	2020-08-05	14	[{"id_menu":2,"count":1}]	39705	pick-up	0	14
110623	2020-08-05 03:41:24	2020-08-05	17	[{"id_menu":4,"count":1}]	33037	pick-up	0	17
110624	2020-08-05 03:47:40	2020-08-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	42657	delivery	5	28
110625	2020-08-05 03:49:13	2020-08-05	9	[{"id_menu":7,"count":1}]	11393	delivery	5	14
110626	2020-08-05 03:50:11	2020-08-05	8	[{"id_menu":5,"count":1}]	19015	delivery	5	13
110627	2020-08-05 03:54:19	2020-08-05	14	[{"id_menu":2,"count":1}]	42630	delivery	5	19
110628	2020-08-05 03:55:39	2020-08-05	17	[{"id_menu":4,"count":1}]	42623	delivery	5	22
110629	2020-08-05 03:56:07	2020-08-05	9	[{"id_menu":7,"count":1}]	42588	delivery	5	14
110630	2020-08-05 03:56:26	2020-08-05	8	[{"id_menu":5,"count":1}]	42483	delivery	5	13
110631	2020-08-05 03:57:42	2020-08-05	9	[{"id_menu":7,"count":1}]	18133	pick-up	0	9
110632	2020-08-05 04:06:40	2020-08-05	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	27018	delivery	5	43
110633	2020-08-05 04:07:48	2020-08-05	9	[{"id_menu":7,"count":1}]	34163	delivery	5	14
110634	2020-08-05 04:10:35	2020-08-05	17	[{"id_menu":4,"count":1}]	18908	delivery	5	22
110635	2020-08-05 04:14:03	2020-08-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1715	pick-up	0	26
110636	2020-08-05 04:15:38	2020-08-05	17	[{"id_menu":4,"count":1}]	41975	delivery	5	22
110637	2020-08-05 04:15:49	2020-08-05	9	[{"id_menu":7,"count":1}]	42631	delivery	5	14
110638	2020-08-05 04:15:55	2020-08-05	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	22778	delivery	5	38
110639	2020-08-05 04:21:20	2020-08-05	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	34992	delivery	5	48
110640	2020-08-05 04:23:53	2020-08-05	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	42521	delivery	5	22
110641	2020-08-05 04:26:28	2020-08-05	12	[{"id_menu":1,"count":1}]	1687	pick-up	0	12
110642	2020-08-05 04:26:47	2020-08-05	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	13987	delivery	5	40
110643	2020-08-05 04:27:08	2020-08-05	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	42465	delivery	5	45
110644	2020-08-05 04:29:43	2020-08-05	14	[{"id_menu":2,"count":1}]	30062	delivery	5	19
110645	2020-08-05 04:31:53	2020-08-05	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	42525	delivery	5	31
110646	2020-08-05 04:32:19	2020-08-05	12	[{"id_menu":3,"count":1}]	42606	delivery	5	17
110647	2020-08-05 04:36:16	2020-08-05	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	34641	delivery	5	31
110648	2020-08-05 04:40:38	2020-08-05	14	[{"id_menu":2,"count":1}]	10727	pick-up	0	14
110649	2020-08-05 04:41:14	2020-08-05	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	33183	delivery	5	25
110650	2020-08-05 04:42:10	2020-08-05	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	10434	delivery	5	31
110651	2020-08-05 04:42:47	2020-08-05	9	[{"id_menu":6,"count":1}]	18392	delivery	5	14
110652	2020-08-05 04:44:18	2020-08-05	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32010	delivery	5	37
110653	2020-08-05 04:44:31	2020-08-05	12	[{"id_menu":1,"count":1}]	303	delivery	5	17
110654	2020-08-05 04:44:43	2020-08-05	14	[{"id_menu":2,"count":1}]	39183	pick-up	0	14
110655	2020-08-05 04:52:46	2020-08-05	9	[{"id_menu":7,"count":1}]	13117	delivery	5	14
110656	2020-08-05 04:53:07	2020-08-05	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	28225	pick-up	0	20
110657	2020-08-05 04:53:14	2020-08-05	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11658	delivery	5	22
110658	2020-08-05 04:55:16	2020-08-05	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":2}]	30534	pick-up	0	23
110659	2020-08-05 04:55:52	2020-08-05	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	14867	delivery	5	29
110660	2020-08-05 04:57:58	2020-08-05	9	[{"id_menu":7,"count":2}]	42482	delivery	5	14
110661	2020-08-05 04:59:23	2020-08-05	12	[{"id_menu":1,"count":1}]	8372	delivery	5	17
110662	2020-08-05 05:00:56	2020-08-05	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	42675	delivery	5	44
110663	2020-08-05 05:06:27	2020-08-05	17	[{"id_menu":4,"count":1}]	31401	delivery	5	22
110664	2020-08-05 05:08:10	2020-08-05	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	8029	delivery	5	26
110665	2020-08-05 05:10:48	2020-08-05	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	972	delivery	5	34
110666	2020-08-05 05:13:21	2020-08-05	17	[{"id_menu":4,"count":1}]	119	pick-up	0	17
110667	2020-08-05 05:14:37	2020-08-05	17	[{"id_menu":4,"count":1}]	18654	delivery	5	22
110668	2020-08-05 05:16:16	2020-08-05	12	[{"id_menu":1,"count":1}]	19293	delivery	5	17
110669	2020-08-05 05:17:01	2020-08-05	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	298	delivery	5	31
110670	2020-08-05 05:21:54	2020-08-05	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3534	delivery	5	27
110671	2020-08-05 05:22:24	2020-08-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	42589	delivery	5	31
110672	2020-08-05 05:25:10	2020-08-05	12	[{"id_menu":1,"count":1}]	17641	pick-up	0	12
110673	2020-08-05 05:25:11	2020-08-05	8	[{"id_menu":5,"count":2}]	42656	delivery	5	13
110674	2020-08-05 05:32:51	2020-08-05	9	[{"id_menu":6,"count":1}]	33452	delivery	5	14
110675	2020-08-05 05:33:28	2020-08-05	9	[{"id_menu":6,"count":1}]	42603	delivery	5	14
110676	2020-08-05 05:35:43	2020-08-05	12	[{"id_menu":3,"count":1}]	34321	delivery	5	17
110677	2020-08-05 05:36:29	2020-08-05	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31091	delivery	5	35
110678	2020-08-05 05:36:54	2020-08-05	8	[{"id_menu":5,"count":1}]	42577	pick-up	0	8
110679	2020-08-05 05:37:32	2020-08-05	9	[{"id_menu":6,"count":1}]	2072	pick-up	0	9
110680	2020-08-05 05:38:48	2020-08-05	8	[{"id_menu":5,"count":2}]	42556	delivery	5	13
110681	2020-08-05 05:39:07	2020-08-05	8	[{"id_menu":5,"count":1}]	34005	delivery	5	13
110682	2020-08-05 05:40:14	2020-08-05	9	[{"id_menu":7,"count":1}]	42504	delivery	5	14
110683	2020-08-05 05:40:23	2020-08-05	14	[{"id_menu":2,"count":1}]	39048	delivery	5	19
110684	2020-08-05 05:42:14	2020-08-05	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	7861	delivery	5	25
110685	2020-08-05 05:43:15	2020-08-05	8	[{"id_menu":5,"count":2}]	18966	delivery	5	13
110686	2020-08-05 05:44:25	2020-08-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26290	delivery	5	23
110687	2020-08-05 05:45:05	2020-08-05	14	[{"id_menu":2,"count":1}]	7706	pick-up	0	14
110688	2020-08-05 05:48:18	2020-08-05	9	[{"id_menu":7,"count":1}]	42295	delivery	5	14
110689	2020-08-05 05:48:46	2020-08-05	9	[{"id_menu":7,"count":1}]	19052	delivery	5	14
110690	2020-08-05 05:50:12	2020-08-05	9	[{"id_menu":6,"count":1}]	2857	pick-up	0	9
110691	2020-08-05 05:50:28	2020-08-05	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	4227	delivery	5	36
110692	2020-08-05 05:51:03	2020-08-05	12	[{"id_menu":1,"count":1}]	30812	delivery	5	17
110693	2020-08-05 05:53:58	2020-08-05	12	[{"id_menu":3,"count":1}]	42622	delivery	5	17
110694	2020-08-05 05:57:10	2020-08-05	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	42457	delivery	5	26
110695	2020-08-05 06:00:31	2020-08-05	8	[{"id_menu":5,"count":1}]	42672	pick-up	0	8
110696	2020-08-05 06:00:57	2020-08-05	12	[{"id_menu":3,"count":1}]	16904	delivery	5	17
110697	2020-08-05 06:01:43	2020-08-05	14	[{"id_menu":2,"count":1}]	18450	delivery	5	19
110698	2020-08-05 06:04:46	2020-08-05	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	12676	delivery	5	31
110699	2020-08-05 06:05:41	2020-08-05	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3652	pick-up	0	38
110700	2020-08-05 06:09:18	2020-08-05	9	[{"id_menu":7,"count":1}]	42567	delivery	5	14
110701	2020-08-05 06:09:24	2020-08-05	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	23217	pick-up	0	26
110702	2020-08-05 06:12:32	2020-08-05	14	[{"id_menu":2,"count":1}]	3012	pick-up	0	14
110703	2020-08-05 06:13:13	2020-08-05	9	[{"id_menu":7,"count":1}]	22425	delivery	5	14
110704	2020-08-05 06:13:38	2020-08-05	8	[{"id_menu":5,"count":1}]	42661	delivery	5	13
110705	2020-08-05 06:16:42	2020-08-05	12	[{"id_menu":3,"count":1}]	381	pick-up	0	12
110706	2020-08-05 06:17:02	2020-08-05	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27764	delivery	5	36
110707	2020-08-05 06:18:45	2020-08-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	18567	delivery	5	22
110708	2020-08-05 06:18:54	2020-08-05	12	[{"id_menu":1,"count":1}]	18888	delivery	5	17
110709	2020-08-05 06:20:42	2020-08-05	8	[{"id_menu":5,"count":2}]	42524	delivery	5	13
110710	2020-08-05 06:21:06	2020-08-05	14	[{"id_menu":2,"count":1}]	42650	delivery	5	19
110711	2020-08-05 06:23:42	2020-08-05	12	[{"id_menu":1,"count":1}]	42658	delivery	5	17
110712	2020-08-05 06:29:12	2020-08-05	14	[{"id_menu":2,"count":1}]	20327	delivery	5	19
110713	2020-08-05 06:32:08	2020-08-05	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	10392	delivery	5	25
110714	2020-08-05 06:35:34	2020-08-05	9	[{"id_menu":7,"count":1}]	42534	delivery	5	14
110715	2020-08-05 06:42:23	2020-08-05	8	[{"id_menu":5,"count":1}]	24936	delivery	5	13
110716	2020-08-05 06:42:35	2020-08-05	9	[{"id_menu":6,"count":1}]	11431	delivery	5	14
110717	2020-08-05 06:43:17	2020-08-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	31140	delivery	5	31
110718	2020-08-05 06:43:24	2020-08-05	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	42481	pick-up	0	21
110719	2020-08-05 06:47:48	2020-08-05	8	[{"id_menu":5,"count":1}]	42497	delivery	5	13
110720	2020-08-05 06:51:58	2020-08-05	9	[{"id_menu":6,"count":1}]	9297	delivery	5	14
110721	2020-08-05 06:52:10	2020-08-05	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	16983	delivery	5	43
110722	2020-08-05 06:53:34	2020-08-05	9	[{"id_menu":6,"count":1}]	42600	delivery	5	14
110723	2020-08-05 06:55:18	2020-08-05	8	[{"id_menu":5,"count":1}]	2277	delivery	5	13
110724	2020-08-05 06:55:51	2020-08-05	12	[{"id_menu":3,"count":1}]	31065	delivery	5	17
110725	2020-08-05 06:56:38	2020-08-05	12	[{"id_menu":1,"count":1}]	701	delivery	5	17
110726	2020-08-05 06:57:47	2020-08-05	8	[{"id_menu":5,"count":1}]	42644	delivery	5	13
110727	2020-08-05 06:57:57	2020-08-05	9	[{"id_menu":7,"count":1}]	33929	delivery	5	14
110728	2020-08-05 06:58:53	2020-08-05	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	21922	delivery	5	43
110729	2020-08-05 07:01:51	2020-08-05	12	[{"id_menu":1,"count":1}]	35816	delivery	5	17
110730	2020-08-05 07:05:53	2020-08-05	9	[{"id_menu":7,"count":1}]	41952	pick-up	0	9
110731	2020-08-05 07:06:06	2020-08-05	12	[{"id_menu":1,"count":1}]	9234	delivery	5	17
110732	2020-08-05 07:08:57	2020-08-05	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	42536	delivery	5	36
110733	2020-08-05 07:10:44	2020-08-05	8	[{"id_menu":5,"count":1}]	42659	delivery	5	13
110734	2020-08-05 07:12:22	2020-08-05	9	[{"id_menu":6,"count":1}]	42523	delivery	5	14
110735	2020-08-05 07:12:36	2020-08-05	17	[{"id_menu":4,"count":1}]	42593	pick-up	0	17
110736	2020-08-05 07:14:18	2020-08-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	37162	delivery	5	28
110737	2020-08-05 07:14:44	2020-08-05	9	[{"id_menu":7,"count":1}]	42594	delivery	5	14
110738	2020-08-05 07:16:16	2020-08-05	9	[{"id_menu":6,"count":1}]	30549	delivery	5	14
110739	2020-08-05 07:16:22	2020-08-05	12	[{"id_menu":3,"count":1}]	15923	delivery	5	17
110740	2020-08-05 07:20:01	2020-08-05	17	[{"id_menu":4,"count":1}]	40393	pick-up	0	17
110741	2020-08-05 07:23:57	2020-08-05	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2729	delivery	5	48
110742	2020-08-05 07:30:06	2020-08-05	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	42633	delivery	5	36
110743	2020-08-05 07:30:17	2020-08-05	12	[{"id_menu":3,"count":1}]	42676	pick-up	0	12
110744	2020-08-05 07:32:26	2020-08-05	9	[{"id_menu":6,"count":4}]	8726	delivery	5	14
110745	2020-08-05 07:34:23	2020-08-05	12	[{"id_menu":3,"count":1}]	39925	delivery	5	17
110746	2020-08-05 07:35:46	2020-08-05	9	[{"id_menu":6,"count":1}]	5783	pick-up	0	9
110747	2020-08-05 07:35:50	2020-08-05	9	[{"id_menu":6,"count":1}]	40883	delivery	5	14
110748	2020-08-05 07:39:01	2020-08-05	8	[{"id_menu":5,"count":1}]	2866	pick-up	0	8
110749	2020-08-05 07:39:39	2020-08-05	8	[{"id_menu":5,"count":1}]	7003	delivery	5	13
110750	2020-08-05 07:39:52	2020-08-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	42518	delivery	5	31
110751	2020-08-05 07:46:39	2020-08-05	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	38339	delivery	5	27
110752	2020-08-05 07:47:27	2020-08-05	12	[{"id_menu":1,"count":1}]	21334	pick-up	0	12
110753	2020-08-05 07:52:52	2020-08-05	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	21390	pick-up	0	52
110754	2020-08-05 07:53:20	2020-08-05	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	42669	delivery	5	27
110755	2020-08-05 07:56:09	2020-08-05	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5658	delivery	5	35
110756	2020-08-05 07:57:06	2020-08-05	9	[{"id_menu":7,"count":1}]	23061	delivery	5	14
110757	2020-08-05 07:59:50	2020-08-05	12	[{"id_menu":3,"count":1}]	32224	delivery	5	17
110758	2020-08-05 08:00:58	2020-08-05	9	[{"id_menu":6,"count":1}]	31748	delivery	5	14
110759	2020-08-05 08:03:22	2020-08-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	27993	delivery	5	28
110760	2020-08-05 08:04:03	2020-08-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7699	delivery	5	31
110761	2020-08-05 08:06:45	2020-08-05	9	[{"id_menu":6,"count":1}]	42490	delivery	5	14
110762	2020-08-05 08:10:14	2020-08-05	12	[{"id_menu":1,"count":1}]	7631	pick-up	0	12
110763	2020-08-05 08:10:51	2020-08-05	9	[{"id_menu":6,"count":1}]	42496	delivery	5	14
110764	2020-08-05 08:12:34	2020-08-05	12	[{"id_menu":3,"count":1}]	42671	delivery	5	17
110765	2020-08-05 08:12:58	2020-08-05	9	[{"id_menu":7,"count":1}]	42667	pick-up	0	9
110766	2020-08-05 08:15:05	2020-08-05	12	[{"id_menu":1,"count":1}]	38851	pick-up	0	12
110767	2020-08-05 08:16:37	2020-08-05	9	[{"id_menu":7,"count":1}]	30623	pick-up	0	9
110768	2020-08-05 08:17:24	2020-08-05	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	42604	delivery	5	40
110769	2020-08-05 08:18:17	2020-08-05	9	[{"id_menu":7,"count":1}]	27655	delivery	5	14
110770	2020-08-05 08:20:46	2020-08-05	8	[{"id_menu":5,"count":1}]	42568	delivery	5	13
110771	2020-08-05 08:21:12	2020-08-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	10755	pick-up	0	23
110772	2020-08-05 08:24:06	2020-08-05	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	42506	delivery	5	40
110773	2020-08-05 08:27:34	2020-08-05	9	[{"id_menu":7,"count":1}]	24587	delivery	5	14
110774	2020-08-05 08:27:37	2020-08-05	14	[{"id_menu":2,"count":1}]	37681	delivery	5	19
110775	2020-08-05 08:42:02	2020-08-05	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	42459	pick-up	0	17
110776	2020-08-05 08:49:40	2020-08-05	9	[{"id_menu":7,"count":1}]	11464	delivery	5	14
110777	2020-08-05 08:50:08	2020-08-05	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	42642	delivery	5	35
110778	2020-08-05 08:50:13	2020-08-05	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	12019	pick-up	0	22
110779	2020-08-05 08:54:40	2020-08-05	8	[{"id_menu":5,"count":1}]	27861	delivery	5	13
110780	2020-08-05 08:56:24	2020-08-05	9	[{"id_menu":6,"count":2}]	42636	delivery	5	14
110781	2020-08-05 09:05:56	2020-08-05	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	42488	delivery	5	34
110782	2020-08-05 09:07:15	2020-08-05	17	[{"id_menu":4,"count":2}]	42581	delivery	5	22
110783	2020-08-05 09:10:13	2020-08-05	14	[{"id_menu":2,"count":1}]	3651	pick-up	0	14
110784	2020-08-05 09:12:11	2020-08-05	12	[{"id_menu":3,"count":1}]	42499	pick-up	0	12
110785	2020-08-05 09:14:00	2020-08-05	8	[{"id_menu":5,"count":1}]	42554	delivery	5	13
110786	2020-08-05 09:22:33	2020-08-05	9	[{"id_menu":6,"count":1}]	27194	delivery	5	14
110787	2020-08-05 09:25:00	2020-08-05	8	[{"id_menu":5,"count":1}]	42590	delivery	5	13
110788	2020-08-05 09:35:12	2020-08-05	9	[{"id_menu":6,"count":1}]	23937	delivery	5	14
110789	2020-08-05 09:36:36	2020-08-05	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	6596	delivery	5	39
110790	2020-08-05 09:38:06	2020-08-05	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13371	delivery	5	43
110791	2020-08-05 09:38:50	2020-08-05	9	[{"id_menu":7,"count":2}]	42634	delivery	5	14
110792	2020-08-05 09:42:42	2020-08-05	9	[{"id_menu":7,"count":1}]	32288	delivery	5	14
110793	2020-08-05 09:43:33	2020-08-05	9	[{"id_menu":7,"count":1}]	3478	delivery	5	14
110794	2020-08-05 09:44:26	2020-08-05	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	42629	delivery	5	35
110795	2020-08-05 09:45:53	2020-08-05	14	[{"id_menu":2,"count":1}]	11887	pick-up	0	14
110796	2020-08-05 09:46:04	2020-08-05	9	[{"id_menu":6,"count":1}]	30657	delivery	5	14
110797	2020-08-05 09:46:28	2020-08-05	12	[{"id_menu":1,"count":1}]	42478	pick-up	0	12
110798	2020-08-05 09:46:59	2020-08-05	14	[{"id_menu":2,"count":1}]	40672	delivery	5	19
110799	2020-08-05 09:47:11	2020-08-05	17	[{"id_menu":4,"count":1}]	7655	delivery	5	22
110800	2020-08-05 09:47:37	2020-08-05	9	[{"id_menu":6,"count":1}]	12282	delivery	5	14
110801	2020-08-05 09:48:03	2020-08-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39624	delivery	5	22
110802	2020-08-05 09:55:54	2020-08-05	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	34426	delivery	5	48
110803	2020-08-05 09:55:55	2020-08-05	8	[{"id_menu":5,"count":1}]	12367	pick-up	0	8
110804	2020-08-05 09:58:02	2020-08-05	12	[{"id_menu":1,"count":1}]	21601	delivery	5	17
110805	2020-08-05 09:58:51	2020-08-05	14	[{"id_menu":2,"count":1}]	2320	pick-up	0	14
110806	2020-08-05 09:58:59	2020-08-05	17	[{"id_menu":4,"count":1}]	5958	pick-up	0	17
110807	2020-08-05 10:00:01	2020-08-05	9	[{"id_menu":7,"count":1}]	12040	delivery	5	14
110808	2020-08-05 10:01:57	2020-08-05	12	[{"id_menu":1,"count":1}]	42580	delivery	5	17
110809	2020-08-05 10:10:09	2020-08-05	12	[{"id_menu":3,"count":1}]	42632	delivery	5	17
110810	2020-08-05 10:10:25	2020-08-05	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	948	delivery	5	26
110811	2020-08-05 10:10:35	2020-08-05	9	[{"id_menu":7,"count":1}]	14630	delivery	5	14
110812	2020-08-05 10:11:14	2020-08-05	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20729	delivery	5	35
110813	2020-08-05 10:13:05	2020-08-05	12	[{"id_menu":1,"count":1}]	30553	delivery	5	17
110814	2020-08-05 10:16:35	2020-08-05	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	42528	delivery	5	37
110815	2020-08-05 10:18:58	2020-08-05	12	[{"id_menu":1,"count":1}]	42501	delivery	5	17
110816	2020-08-05 10:29:12	2020-08-05	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	18479	delivery	5	26
110817	2020-08-05 10:29:23	2020-08-05	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	26350	delivery	5	30
110818	2020-08-05 10:29:34	2020-08-05	8	[{"id_menu":5,"count":1}]	15975	delivery	5	13
110819	2020-08-05 10:32:57	2020-08-05	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	19955	delivery	5	39
110820	2020-08-05 10:33:04	2020-08-05	8	[{"id_menu":5,"count":1}]	12681	delivery	5	13
110821	2020-08-05 10:37:28	2020-08-05	9	[{"id_menu":7,"count":1}]	19287	pick-up	0	9
110822	2020-08-05 10:38:10	2020-08-05	12	[{"id_menu":1,"count":1}]	11244	pick-up	0	12
110823	2020-08-05 10:38:13	2020-08-05	12	[{"id_menu":1,"count":1}]	42469	delivery	5	17
110824	2020-08-05 10:38:16	2020-08-05	9	[{"id_menu":6,"count":1}]	15949	delivery	5	14
110825	2020-08-05 10:38:43	2020-08-05	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	42592	delivery	5	31
110826	2020-08-05 10:39:11	2020-08-05	14	[{"id_menu":2,"count":1}]	17277	pick-up	0	14
110827	2020-08-05 10:40:15	2020-08-05	12	[{"id_menu":3,"count":1}]	42543	delivery	5	17
110828	2020-08-05 10:40:17	2020-08-05	12	[{"id_menu":3,"count":1}]	34747	pick-up	0	12
110829	2020-08-05 10:42:45	2020-08-05	9	[{"id_menu":7,"count":1}]	41467	delivery	5	14
110830	2020-08-05 10:46:06	2020-08-05	17	[{"id_menu":4,"count":1}]	40435	pick-up	0	17
110831	2020-08-05 10:48:03	2020-08-05	9	[{"id_menu":7,"count":1}]	7590	pick-up	0	9
110832	2020-08-05 10:54:14	2020-08-05	14	[{"id_menu":2,"count":1}]	7608	delivery	5	19
110833	2020-08-05 10:55:43	2020-08-05	17	[{"id_menu":4,"count":1}]	15194	pick-up	0	17
110834	2020-08-05 10:57:02	2020-08-05	8	[{"id_menu":5,"count":1}]	3961	pick-up	0	8
110835	2020-08-05 10:58:10	2020-08-05	14	[{"id_menu":2,"count":1}]	22417	pick-up	0	14
110836	2020-08-05 11:01:43	2020-08-05	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	42573	delivery	5	28
110837	2020-08-05 11:01:45	2020-08-05	17	[{"id_menu":4,"count":1}]	11961	delivery	5	22
110838	2020-08-05 11:01:59	2020-08-05	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	42535	delivery	5	31
110839	2020-08-05 11:02:50	2020-08-05	17	[{"id_menu":4,"count":1}]	34055	delivery	5	22
110840	2020-08-05 11:05:17	2020-08-05	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	42586	delivery	5	37
110841	2020-08-05 11:09:33	2020-08-05	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	42480	delivery	5	36
110842	2020-08-05 11:11:37	2020-08-05	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6499	delivery	5	36
110843	2020-08-05 11:11:53	2020-08-05	9	[{"id_menu":6,"count":1}]	33234	delivery	5	14
110844	2020-08-05 11:18:57	2020-08-05	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	24508	delivery	5	42
110845	2020-08-05 11:20:56	2020-08-05	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	42655	delivery	5	23
110846	2020-08-05 11:21:21	2020-08-05	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	2282	pick-up	0	43
110847	2020-08-05 11:21:37	2020-08-05	17	[{"id_menu":4,"count":1}]	32697	delivery	5	22
110848	2020-08-05 11:25:37	2020-08-05	12	[{"id_menu":3,"count":1}]	42533	delivery	5	17
110849	2020-08-05 11:26:20	2020-08-05	14	[{"id_menu":2,"count":2}]	1881	pick-up	0	14
110850	2020-08-05 11:27:58	2020-08-05	12	[{"id_menu":1,"count":1}]	1058	pick-up	0	12
110851	2020-08-05 11:30:57	2020-08-05	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	42570	delivery	5	36
110852	2020-08-05 11:31:45	2020-08-05	9	[{"id_menu":6,"count":1}]	22602	delivery	5	14
110853	2020-08-05 11:33:21	2020-08-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9907	pick-up	0	18
110854	2020-08-05 11:37:35	2020-08-05	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	42564	delivery	5	26
110855	2020-08-05 11:39:54	2020-08-05	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	42552	delivery	5	31
110856	2020-08-05 11:40:12	2020-08-05	12	[{"id_menu":3,"count":1}]	42472	pick-up	0	12
110857	2020-08-05 11:43:06	2020-08-05	14	[{"id_menu":2,"count":1}]	34242	delivery	5	19
110858	2020-08-05 11:45:02	2020-08-05	9	[{"id_menu":6,"count":1}]	38262	delivery	5	14
110859	2020-08-05 11:45:02	2020-08-05	12	[{"id_menu":1,"count":1}]	42575	delivery	5	17
110860	2020-08-05 11:45:35	2020-08-05	9	[{"id_menu":6,"count":1}]	14707	delivery	5	14
110861	2020-08-05 11:47:27	2020-08-05	12	[{"id_menu":1,"count":1}]	3420	pick-up	0	12
110862	2020-08-05 11:47:37	2020-08-05	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	42654	delivery	5	25
110863	2020-08-05 11:49:26	2020-08-05	12	[{"id_menu":3,"count":1}]	35747	delivery	5	17
110864	2020-08-05 11:49:28	2020-08-05	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	42540	delivery	5	49
110865	2020-08-05 11:51:47	2020-08-05	9	[{"id_menu":7,"count":1}]	11789	delivery	5	14
110866	2020-08-05 11:53:02	2020-08-05	8	[{"id_menu":5,"count":1}]	38267	pick-up	0	8
110867	2020-08-05 11:54:25	2020-08-05	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	10296	delivery	5	22
110868	2020-08-05 11:58:06	2020-08-05	9	[{"id_menu":7,"count":1}]	33669	delivery	5	14
110869	2020-08-05 11:59:19	2020-08-05	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	20907	delivery	5	34
110870	2020-08-05 12:00:54	2020-08-05	12	[{"id_menu":1,"count":1}]	33251	pick-up	0	12
110871	2020-08-05 12:01:40	2020-08-05	17	[{"id_menu":4,"count":1}]	42572	delivery	5	22
110872	2020-08-05 12:05:46	2020-08-05	9	[{"id_menu":6,"count":1}]	30470	delivery	5	14
110873	2020-08-05 12:05:49	2020-08-05	14	[{"id_menu":2,"count":1}]	17330	delivery	5	19
110874	2020-08-05 12:06:31	2020-08-05	17	[{"id_menu":4,"count":1}]	40085	pick-up	0	17
110875	2020-08-05 12:11:18	2020-08-05	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	31997	delivery	5	40
110876	2020-08-05 12:11:52	2020-08-05	9	[{"id_menu":7,"count":1}]	7167	delivery	5	14
110877	2020-08-05 12:12:42	2020-08-05	9	[{"id_menu":6,"count":1}]	21984	delivery	5	14
110878	2020-08-05 12:18:01	2020-08-05	12	[{"id_menu":1,"count":1}]	38522	delivery	5	17
110879	2020-08-05 12:19:41	2020-08-05	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	34175	delivery	5	30
110880	2020-08-05 12:21:28	2020-08-05	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	655	pick-up	0	21
110881	2020-08-05 12:22:14	2020-08-05	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":3}]	27122	delivery	5	26
110882	2020-08-05 12:24:20	2020-08-05	14	[{"id_menu":2,"count":1}]	24041	pick-up	0	14
110883	2020-08-05 12:24:48	2020-08-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	42509	delivery	5	28
110884	2020-08-05 12:27:18	2020-08-05	12	[{"id_menu":3,"count":1}]	19072	pick-up	0	12
110885	2020-08-05 12:27:36	2020-08-05	9	[{"id_menu":6,"count":1}]	3321	delivery	5	14
110886	2020-08-05 12:29:13	2020-08-05	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	10679	pick-up	0	29
110887	2020-08-05 12:31:00	2020-08-05	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1080	pick-up	0	35
110888	2020-08-05 12:32:00	2020-08-05	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	16346	delivery	5	40
110889	2020-08-05 12:32:46	2020-08-05	12	[{"id_menu":1,"count":1}]	15529	delivery	5	17
110890	2020-08-05 12:34:09	2020-08-05	9	[{"id_menu":6,"count":1}]	5690	delivery	5	14
110891	2020-08-05 12:34:11	2020-08-05	12	[{"id_menu":3,"count":1}]	17925	delivery	5	17
110892	2020-08-05 12:35:34	2020-08-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	12935	delivery	5	28
110893	2020-08-05 12:37:23	2020-08-05	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	13380	delivery	5	26
110894	2020-08-05 12:37:45	2020-08-05	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	19845	pick-up	0	26
110895	2020-08-05 12:37:57	2020-08-05	17	[{"id_menu":4,"count":1}]	42494	delivery	5	22
110896	2020-08-05 12:41:30	2020-08-05	8	[{"id_menu":5,"count":2}]	6801	delivery	5	13
110897	2020-08-05 12:58:06	2020-08-05	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4596	delivery	5	34
110898	2020-08-05 12:58:57	2020-08-05	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	5158	delivery	5	22
110899	2020-08-05 12:59:04	2020-08-05	8	[{"id_menu":5,"count":1}]	6911	delivery	5	13
110900	2020-08-05 13:03:04	2020-08-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6326	delivery	5	28
110901	2020-08-05 13:12:46	2020-08-05	9	[{"id_menu":7,"count":1}]	2926	pick-up	0	9
110902	2020-08-05 13:13:48	2020-08-05	14	[{"id_menu":2,"count":1}]	42514	delivery	5	19
110903	2020-08-05 13:14:30	2020-08-05	12	[{"id_menu":1,"count":2}]	18304	delivery	5	17
110904	2020-08-05 13:15:09	2020-08-05	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	14641	pick-up	0	31
110905	2020-08-05 13:16:18	2020-08-05	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	42519	delivery	5	43
110906	2020-08-05 13:17:03	2020-08-05	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	35685	delivery	5	45
110907	2020-08-05 13:17:39	2020-08-05	14	[{"id_menu":2,"count":1}]	28065	delivery	5	19
110908	2020-08-05 13:19:43	2020-08-05	9	[{"id_menu":7,"count":1}]	42602	delivery	5	14
110909	2020-08-05 13:20:51	2020-08-05	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23829	delivery	5	22
110910	2020-08-05 13:22:14	2020-08-05	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	15516	delivery	5	28
110911	2020-08-05 13:22:18	2020-08-05	14	[{"id_menu":2,"count":1}]	24547	pick-up	0	14
110912	2020-08-05 13:23:19	2020-08-05	9	[{"id_menu":7,"count":1}]	42500	pick-up	0	9
110913	2020-08-05 13:23:27	2020-08-05	12	[{"id_menu":3,"count":1}]	40856	delivery	5	17
110914	2020-08-05 13:24:00	2020-08-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5492	delivery	5	22
110915	2020-08-05 13:24:01	2020-08-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6514	delivery	5	31
110916	2020-08-05 13:25:53	2020-08-05	12	[{"id_menu":3,"count":1}]	32343	delivery	5	17
110917	2020-08-05 13:26:43	2020-08-05	14	[{"id_menu":2,"count":1}]	42555	delivery	5	19
110918	2020-08-05 13:28:21	2020-08-05	9	[{"id_menu":7,"count":1}]	17037	pick-up	0	9
110919	2020-08-05 13:31:50	2020-08-05	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	42526	delivery	5	31
110920	2020-08-05 13:33:37	2020-08-05	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23673	delivery	5	37
110921	2020-08-05 13:37:05	2020-08-05	17	[{"id_menu":4,"count":1}]	42463	pick-up	0	17
110922	2020-08-05 13:42:13	2020-08-05	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	12573	delivery	5	42
110923	2020-08-05 13:43:28	2020-08-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	12796	delivery	5	28
110924	2020-08-05 13:45:43	2020-08-05	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18153	delivery	5	34
110925	2020-08-05 13:49:20	2020-08-05	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	13531	delivery	5	30
110926	2020-08-05 13:49:33	2020-08-05	9	[{"id_menu":6,"count":1}]	42665	delivery	5	14
110927	2020-08-05 13:50:35	2020-08-05	12	[{"id_menu":3,"count":1}]	2065	pick-up	0	12
110928	2020-08-05 13:52:31	2020-08-05	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	11932	delivery	5	34
110929	2020-08-05 13:54:35	2020-08-05	12	[{"id_menu":1,"count":1}]	17995	pick-up	0	12
110930	2020-08-05 13:55:07	2020-08-05	14	[{"id_menu":2,"count":1}]	35325	pick-up	0	14
110931	2020-08-05 13:58:21	2020-08-05	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":3}]	35869	delivery	5	25
110932	2020-08-05 13:59:05	2020-08-05	17	[{"id_menu":4,"count":1}]	15068	pick-up	0	17
110933	2020-08-05 13:59:32	2020-08-05	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28749	delivery	5	39
110934	2020-08-05 14:04:07	2020-08-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	42493	delivery	5	22
110935	2020-08-05 14:04:35	2020-08-05	9	[{"id_menu":6,"count":1}]	13407	delivery	5	14
110936	2020-08-05 14:06:28	2020-08-05	9	[{"id_menu":7,"count":1}]	19507	delivery	5	14
110937	2020-08-05 14:08:59	2020-08-05	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	30617	delivery	5	57
110938	2020-08-05 14:09:21	2020-08-05	14	[{"id_menu":2,"count":1}]	36728	delivery	5	19
110939	2020-08-05 14:12:21	2020-08-05	17	[{"id_menu":4,"count":1}]	2256	pick-up	0	17
110940	2020-08-05 14:14:22	2020-08-05	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	42625	delivery	5	34
110941	2020-08-05 14:14:46	2020-08-05	8	[{"id_menu":5,"count":1}]	24402	pick-up	0	8
110942	2020-08-05 14:15:39	2020-08-05	12	[{"id_menu":3,"count":1}]	310	pick-up	0	12
110943	2020-08-05 14:15:44	2020-08-05	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	8647	pick-up	0	21
110944	2020-08-05 14:16:07	2020-08-05	34	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	32341	delivery	5	39
110945	2020-08-05 14:17:47	2020-08-05	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17	pick-up	0	40
110946	2020-08-05 14:26:47	2020-08-05	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	13115	delivery	5	27
110947	2020-08-05 14:27:03	2020-08-05	9	[{"id_menu":7,"count":1}]	42474	delivery	5	14
110948	2020-08-05 14:29:04	2020-08-05	9	[{"id_menu":6,"count":1}]	9562	pick-up	0	9
110949	2020-08-05 14:29:45	2020-08-05	17	[{"id_menu":4,"count":1}]	19	delivery	5	22
110950	2020-08-05 14:34:18	2020-08-05	8	[{"id_menu":5,"count":1}]	42649	delivery	5	13
110951	2020-08-05 14:36:04	2020-08-05	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	42597	pick-up	0	22
110952	2020-08-05 14:38:08	2020-08-05	9	[{"id_menu":6,"count":1}]	40944	delivery	5	14
110953	2020-08-05 14:38:46	2020-08-05	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	12286	delivery	5	38
110954	2020-08-05 14:38:56	2020-08-05	9	[{"id_menu":6,"count":1}]	15052	delivery	5	14
110955	2020-08-05 14:40:00	2020-08-05	17	[{"id_menu":4,"count":1}]	42491	delivery	5	22
110956	2020-08-05 14:40:02	2020-08-05	9	[{"id_menu":7,"count":1}]	26361	delivery	5	14
110957	2020-08-05 14:43:47	2020-08-05	9	[{"id_menu":6,"count":1}]	11732	pick-up	0	9
110958	2020-08-05 14:43:56	2020-08-05	14	[{"id_menu":2,"count":1}]	35779	delivery	5	19
110959	2020-08-05 14:50:27	2020-08-05	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1963	pick-up	0	31
110960	2020-08-05 14:51:54	2020-08-05	9	[{"id_menu":7,"count":1}]	13275	pick-up	0	9
110961	2020-08-05 14:52:47	2020-08-05	9	[{"id_menu":6,"count":1}]	9753	delivery	5	14
110962	2020-08-05 14:54:35	2020-08-05	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	20877	delivery	5	31
110963	2020-08-05 14:58:12	2020-08-05	8	[{"id_menu":5,"count":1}]	42208	delivery	5	13
110964	2020-08-05 15:00:03	2020-08-05	9	[{"id_menu":7,"count":1}]	12220	delivery	5	14
110965	2020-08-05 15:01:08	2020-08-05	17	[{"id_menu":4,"count":1}]	20832	delivery	5	22
110966	2020-08-05 15:01:17	2020-08-05	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	19583	delivery	5	30
110967	2020-08-05 15:03:09	2020-08-05	8	[{"id_menu":5,"count":1}]	21	pick-up	0	8
110968	2020-08-05 15:04:16	2020-08-05	17	[{"id_menu":4,"count":1}]	42664	delivery	5	22
110969	2020-08-05 15:05:28	2020-08-05	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	40341	delivery	5	34
110970	2020-08-05 15:05:37	2020-08-05	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	8946	delivery	5	31
110971	2020-08-05 15:06:18	2020-08-05	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	42492	delivery	5	22
110972	2020-08-05 15:07:12	2020-08-05	14	[{"id_menu":2,"count":1}]	42660	pick-up	0	14
110973	2020-08-05 15:08:48	2020-08-05	9	[{"id_menu":7,"count":1}]	42537	delivery	5	14
110974	2020-08-05 15:08:58	2020-08-05	17	[{"id_menu":4,"count":1}]	13060	delivery	5	22
110975	2020-08-05 15:10:13	2020-08-05	14	[{"id_menu":2,"count":1}]	20754	pick-up	0	14
110976	2020-08-05 15:10:26	2020-08-05	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	466	delivery	5	36
110977	2020-08-05 15:15:25	2020-08-05	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	42585	pick-up	0	23
110978	2020-08-05 15:20:27	2020-08-05	9	[{"id_menu":6,"count":1}]	1289	pick-up	0	9
110979	2020-08-05 15:21:06	2020-08-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	33604	delivery	5	28
110980	2020-08-05 15:22:42	2020-08-05	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	20329	delivery	5	28
110981	2020-08-05 15:22:44	2020-08-05	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	35759	delivery	5	31
110982	2020-08-05 15:26:38	2020-08-05	12	[{"id_menu":1,"count":1}]	27555	delivery	5	17
110983	2020-08-05 15:27:31	2020-08-05	9	[{"id_menu":7,"count":1}]	16074	delivery	5	14
110984	2020-08-05 15:27:59	2020-08-05	9	[{"id_menu":7,"count":1}]	34304	delivery	5	14
110985	2020-08-05 15:28:20	2020-08-05	17	[{"id_menu":4,"count":1}]	27882	delivery	5	22
110986	2020-08-05 15:28:55	2020-08-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	20723	delivery	5	28
110987	2020-08-05 15:29:07	2020-08-05	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	42495	delivery	5	49
110988	2020-08-05 15:30:33	2020-08-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	28808	delivery	5	31
110989	2020-08-05 15:30:45	2020-08-05	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15159	delivery	5	36
110990	2020-08-05 15:31:37	2020-08-05	14	[{"id_menu":2,"count":1}]	32368	delivery	5	19
110991	2020-08-05 15:33:09	2020-08-05	8	[{"id_menu":5,"count":1}]	29306	delivery	5	13
110992	2020-08-05 15:34:28	2020-08-05	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	42559	delivery	5	48
110993	2020-08-05 15:35:23	2020-08-05	12	[{"id_menu":1,"count":1}]	35410	delivery	5	17
110994	2020-08-05 15:38:08	2020-08-05	14	[{"id_menu":2,"count":1}]	42640	delivery	5	19
110995	2020-08-05 15:38:19	2020-08-05	9	[{"id_menu":6,"count":1}]	2235	pick-up	0	9
110996	2020-08-05 15:38:58	2020-08-05	9	[{"id_menu":6,"count":1}]	41053	delivery	5	14
110997	2020-08-05 15:41:00	2020-08-05	8	[{"id_menu":5,"count":1}]	41195	delivery	5	13
110998	2020-08-05 15:46:20	2020-08-05	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	10796	delivery	5	28
110999	2020-08-05 15:47:15	2020-08-05	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	29664	delivery	5	34
111000	2020-08-05 15:49:02	2020-08-05	8	[{"id_menu":5,"count":1}]	33767	delivery	5	13
111001	2020-08-05 15:50:43	2020-08-05	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	222	delivery	5	34
111002	2020-08-05 15:53:44	2020-08-05	12	[{"id_menu":1,"count":1}]	4798	pick-up	0	12
111003	2020-08-05 15:58:02	2020-08-05	17	[{"id_menu":4,"count":1}]	21855	delivery	5	22
111004	2020-08-05 16:02:59	2020-08-05	8	[{"id_menu":5,"count":1}]	42635	delivery	5	13
111005	2020-08-05 16:04:19	2020-08-05	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	42562	delivery	5	46
111006	2020-08-05 16:05:24	2020-08-05	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2843	delivery	5	26
111007	2020-08-05 16:08:53	2020-08-05	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	6322	delivery	5	42
111008	2020-08-05 16:11:27	2020-08-05	17	[{"id_menu":4,"count":1}]	3898	delivery	5	22
111009	2020-08-05 16:13:17	2020-08-05	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	13697	pick-up	0	26
111010	2020-08-05 16:14:36	2020-08-05	17	[{"id_menu":4,"count":1}]	39352	pick-up	0	17
111011	2020-08-05 16:16:58	2020-08-05	8	[{"id_menu":5,"count":1}]	5717	delivery	5	13
111012	2020-08-05 16:18:31	2020-08-05	12	[{"id_menu":1,"count":1}]	42512	delivery	5	17
111013	2020-08-05 16:19:29	2020-08-05	9	[{"id_menu":7,"count":2}]	42608	delivery	5	14
111014	2020-08-05 16:23:41	2020-08-05	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	42505	delivery	5	28
111015	2020-08-05 16:24:33	2020-08-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7623	delivery	5	22
111016	2020-08-05 16:24:36	2020-08-05	14	[{"id_menu":2,"count":1}]	36236	delivery	5	19
111017	2020-08-05 16:24:38	2020-08-05	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	42574	delivery	5	35
111018	2020-08-05 16:26:40	2020-08-05	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	3332	pick-up	0	20
111019	2020-08-05 16:26:56	2020-08-05	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	18417	delivery	5	26
111020	2020-08-05 16:27:03	2020-08-05	8	[{"id_menu":5,"count":1}]	28609	delivery	5	13
111021	2020-08-05 16:27:13	2020-08-05	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	41561	delivery	5	43
111022	2020-08-05 16:27:14	2020-08-05	12	[{"id_menu":1,"count":1}]	38498	pick-up	0	12
111023	2020-08-05 16:35:47	2020-08-05	12	[{"id_menu":1,"count":1}]	15417	delivery	5	17
111024	2020-08-05 16:36:58	2020-08-05	9	[{"id_menu":6,"count":1}]	34488	pick-up	0	9
111025	2020-08-05 16:42:14	2020-08-05	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":2}]	42627	delivery	5	26
111026	2020-08-05 16:43:37	2020-08-05	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19217	delivery	5	35
111027	2020-08-05 16:46:09	2020-08-05	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	42595	delivery	5	37
111028	2020-08-05 16:46:26	2020-08-05	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11815	delivery	5	45
111029	2020-08-05 16:47:46	2020-08-05	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	18526	pick-up	0	23
111030	2020-08-05 16:52:26	2020-08-05	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	14731	delivery	5	31
111031	2020-08-05 16:53:22	2020-08-05	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	4885	delivery	5	45
111032	2020-08-05 16:54:04	2020-08-05	17	[{"id_menu":4,"count":1}]	10007	pick-up	0	17
111033	2020-08-05 16:54:54	2020-08-05	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	42551	delivery	5	26
111034	2020-08-05 16:56:03	2020-08-05	14	[{"id_menu":2,"count":1}]	15908	delivery	5	19
111035	2020-08-05 17:00:24	2020-08-05	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	35627	delivery	5	37
111036	2020-08-05 17:00:53	2020-08-05	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	42641	delivery	5	45
111037	2020-08-05 17:00:57	2020-08-05	17	[{"id_menu":4,"count":1}]	3148	delivery	5	22
111038	2020-08-05 17:02:26	2020-08-05	9	[{"id_menu":7,"count":1}]	17868	delivery	5	14
111039	2020-08-05 17:04:22	2020-08-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	42476	delivery	5	22
111040	2020-08-05 17:10:42	2020-08-05	9	[{"id_menu":7,"count":1}]	42584	pick-up	0	9
111041	2020-08-05 17:11:30	2020-08-05	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	203	delivery	5	36
111042	2020-08-05 17:12:49	2020-08-05	9	[{"id_menu":7,"count":1}]	29945	delivery	5	14
111043	2020-08-05 17:20:58	2020-08-05	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	42611	delivery	5	31
111044	2020-08-05 17:21:26	2020-08-05	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	8149	delivery	5	26
111045	2020-08-05 17:24:22	2020-08-05	9	[{"id_menu":6,"count":1}]	37837	delivery	5	14
111046	2020-08-05 17:24:42	2020-08-05	12	[{"id_menu":3,"count":2}]	42461	delivery	5	17
111047	2020-08-05 17:30:53	2020-08-05	8	[{"id_menu":5,"count":1}]	3730	delivery	5	13
111048	2020-08-05 17:32:39	2020-08-05	12	[{"id_menu":1,"count":1}]	2528	pick-up	0	12
111049	2020-08-05 17:33:50	2020-08-05	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	26943	delivery	5	22
111050	2020-08-05 17:34:28	2020-08-05	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	41176	delivery	5	31
111051	2020-08-05 17:35:39	2020-08-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	42599	delivery	5	23
111052	2020-08-05 17:35:59	2020-08-05	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	36714	delivery	5	28
111053	2020-08-05 17:38:43	2020-08-05	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	9793	delivery	5	34
111054	2020-08-05 17:38:59	2020-08-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3968	pick-up	0	26
111055	2020-08-05 17:41:11	2020-08-05	9	[{"id_menu":7,"count":1}]	3222	pick-up	0	9
111056	2020-08-05 17:41:58	2020-08-05	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	42569	delivery	5	34
111057	2020-08-05 17:43:33	2020-08-05	12	[{"id_menu":3,"count":1}]	42674	delivery	5	17
111058	2020-08-05 17:45:02	2020-08-05	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	42485	delivery	5	45
111059	2020-08-05 17:48:26	2020-08-05	8	[{"id_menu":5,"count":1}]	17350	delivery	5	13
111060	2020-08-05 17:50:52	2020-08-05	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	42662	delivery	5	54
111061	2020-08-05 17:53:51	2020-08-05	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	42511	delivery	5	45
111062	2020-08-05 17:55:02	2020-08-05	14	[{"id_menu":2,"count":1}]	9251	delivery	5	19
111063	2020-08-05 17:55:13	2020-08-05	9	[{"id_menu":6,"count":1}]	40896	delivery	5	14
111064	2020-08-05 17:56:19	2020-08-05	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	36077	delivery	5	55
111065	2020-08-05 17:57:09	2020-08-05	9	[{"id_menu":7,"count":1}]	25071	delivery	5	14
111066	2020-08-05 17:59:39	2020-08-05	9	[{"id_menu":7,"count":1}]	8024	delivery	5	14
111067	2020-08-05 18:01:51	2020-08-05	9	[{"id_menu":6,"count":1}]	13995	delivery	5	14
111068	2020-08-05 18:04:14	2020-08-05	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	9337	pick-up	0	20
111069	2020-08-05 18:05:01	2020-08-05	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	42596	delivery	5	22
111070	2020-08-05 18:05:24	2020-08-05	8	[{"id_menu":5,"count":1}]	5440	delivery	5	13
111071	2020-08-05 18:07:42	2020-08-05	9	[{"id_menu":6,"count":1}]	12978	delivery	5	14
111072	2020-08-05 18:08:24	2020-08-05	17	[{"id_menu":4,"count":1}]	42484	delivery	5	22
111073	2020-08-05 18:10:43	2020-08-05	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	42489	delivery	5	51
111074	2020-08-05 18:10:59	2020-08-05	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	15614	delivery	5	43
111075	2020-08-05 18:11:01	2020-08-05	9	[{"id_menu":7,"count":1}]	42614	delivery	5	14
111076	2020-08-05 18:15:01	2020-08-05	9	[{"id_menu":7,"count":2}]	6709	delivery	5	14
111077	2020-08-05 18:20:29	2020-08-05	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	36832	delivery	5	26
111078	2020-08-05 18:22:10	2020-08-05	12	[{"id_menu":3,"count":1}]	29243	pick-up	0	12
111079	2020-08-05 18:23:06	2020-08-05	14	[{"id_menu":2,"count":1}]	28183	delivery	5	19
111080	2020-08-05 18:24:10	2020-08-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	27080	delivery	5	28
111081	2020-08-05 18:26:42	2020-08-05	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6664	delivery	5	45
111082	2020-08-05 18:27:12	2020-08-05	17	[{"id_menu":4,"count":1}]	2740	delivery	5	22
111083	2020-08-05 18:27:12	2020-08-05	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	40591	pick-up	0	21
111084	2020-08-05 18:32:16	2020-08-05	12	[{"id_menu":3,"count":1}]	489	pick-up	0	12
111085	2020-08-05 18:32:25	2020-08-05	17	[{"id_menu":4,"count":1}]	925	pick-up	0	17
111086	2020-08-05 18:37:10	2020-08-05	8	[{"id_menu":5,"count":1}]	42468	delivery	5	13
111087	2020-08-05 18:38:03	2020-08-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	40509	delivery	5	22
111088	2020-08-05 18:38:04	2020-08-05	8	[{"id_menu":5,"count":1}]	42462	delivery	5	13
111089	2020-08-05 18:43:43	2020-08-05	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	39397	pick-up	0	26
111090	2020-08-05 18:46:19	2020-08-05	14	[{"id_menu":2,"count":1}]	691	pick-up	0	14
111091	2020-08-05 18:47:04	2020-08-05	8	[{"id_menu":5,"count":1}]	17896	delivery	5	13
111092	2020-08-05 18:49:12	2020-08-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15539	delivery	5	31
111093	2020-08-05 18:49:53	2020-08-05	17	[{"id_menu":4,"count":1}]	2044	delivery	5	22
111094	2020-08-05 18:52:26	2020-08-05	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	30330	pick-up	0	26
111095	2020-08-05 18:54:01	2020-08-05	9	[{"id_menu":7,"count":1}]	42579	delivery	5	14
111096	2020-08-05 18:55:39	2020-08-05	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20876	delivery	5	35
111097	2020-08-05 18:57:30	2020-08-05	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	25577	pick-up	0	24
111098	2020-08-05 18:59:06	2020-08-05	9	[{"id_menu":7,"count":1}]	42639	delivery	5	14
111099	2020-08-05 18:59:36	2020-08-05	9	[{"id_menu":7,"count":1}]	12845	delivery	5	14
111100	2020-08-05 19:00:33	2020-08-05	14	[{"id_menu":2,"count":1}]	24802	delivery	5	19
111101	2020-08-05 19:04:07	2020-08-05	8	[{"id_menu":5,"count":1}]	14061	delivery	5	13
111102	2020-08-05 19:05:50	2020-08-05	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	22338	delivery	5	26
111103	2020-08-05 19:13:23	2020-08-05	9	[{"id_menu":6,"count":1}]	2245	delivery	5	14
111104	2020-08-05 19:18:56	2020-08-05	9	[{"id_menu":7,"count":1}]	20418	pick-up	0	9
111105	2020-08-05 19:19:13	2020-08-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	6894	delivery	5	31
111106	2020-08-05 19:19:30	2020-08-05	14	[{"id_menu":2,"count":1}]	11314	pick-up	0	14
111107	2020-08-05 19:22:16	2020-08-05	8	[{"id_menu":5,"count":1}]	42507	delivery	5	13
111108	2020-08-05 19:28:01	2020-08-05	9	[{"id_menu":6,"count":1}]	1072	pick-up	0	9
111109	2020-08-05 19:35:29	2020-08-05	9	[{"id_menu":7,"count":2}]	42546	delivery	5	14
111110	2020-08-05 19:36:39	2020-08-05	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1166	delivery	5	31
111111	2020-08-05 19:42:15	2020-08-05	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	42520	delivery	5	43
111112	2020-08-05 19:51:19	2020-08-05	9	[{"id_menu":7,"count":1}]	19328	delivery	5	14
111113	2020-08-05 19:52:03	2020-08-05	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2538	delivery	5	36
111114	2020-08-05 19:52:15	2020-08-05	9	[{"id_menu":6,"count":1}]	36938	pick-up	0	9
111115	2020-08-05 19:55:49	2020-08-05	9	[{"id_menu":6,"count":1}]	34252	pick-up	0	9
111116	2020-08-05 19:57:55	2020-08-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	17861	pick-up	0	26
111117	2020-08-05 19:58:35	2020-08-05	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	29856	delivery	5	45
111118	2020-08-05 19:58:56	2020-08-05	8	[{"id_menu":5,"count":1}]	17633	delivery	5	13
111119	2020-08-05 19:59:35	2020-08-05	14	[{"id_menu":2,"count":1}]	11749	delivery	5	19
111120	2020-08-05 20:02:25	2020-08-05	14	[{"id_menu":2,"count":1}]	2596	delivery	5	19
111121	2020-08-05 20:04:35	2020-08-05	9	[{"id_menu":6,"count":1}]	42578	delivery	5	14
111122	2020-08-05 20:05:53	2020-08-05	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	9470	delivery	5	26
111123	2020-08-05 20:05:56	2020-08-05	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	31044	pick-up	0	25
111124	2020-08-05 20:08:58	2020-08-05	8	[{"id_menu":5,"count":1}]	30541	pick-up	0	8
111125	2020-08-05 20:10:11	2020-08-05	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37627	delivery	5	35
111126	2020-08-05 20:11:41	2020-08-05	8	[{"id_menu":5,"count":1}]	20126	delivery	5	13
111127	2020-08-05 20:12:32	2020-08-05	9	[{"id_menu":6,"count":1}]	6873	delivery	5	14
111128	2020-08-05 20:13:45	2020-08-05	9	[{"id_menu":7,"count":1}]	42619	delivery	5	14
111129	2020-08-05 20:15:02	2020-08-05	17	[{"id_menu":4,"count":1}]	42513	pick-up	0	17
111130	2020-08-05 20:15:15	2020-08-05	14	[{"id_menu":2,"count":1}]	28280	delivery	5	19
111131	2020-08-05 20:21:32	2020-08-05	9	[{"id_menu":7,"count":1}]	30256	pick-up	0	9
111132	2020-08-05 20:22:07	2020-08-05	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	21434	delivery	5	36
111133	2020-08-05 20:24:52	2020-08-05	8	[{"id_menu":5,"count":1}]	2559	delivery	5	13
111134	2020-08-05 20:26:13	2020-08-05	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2585	pick-up	0	21
111135	2020-08-05 20:27:08	2020-08-05	8	[{"id_menu":5,"count":1}]	33805	delivery	5	13
111136	2020-08-05 20:28:39	2020-08-05	9	[{"id_menu":6,"count":1}]	42605	delivery	5	14
111137	2020-08-05 20:29:41	2020-08-05	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	29065	delivery	5	27
111138	2020-08-05 20:30:28	2020-08-05	9	[{"id_menu":6,"count":1}]	42637	delivery	5	14
111139	2020-08-05 20:33:40	2020-08-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1488	delivery	5	28
111140	2020-08-05 20:33:53	2020-08-05	17	[{"id_menu":4,"count":1}]	42538	delivery	5	22
111141	2020-08-05 20:37:42	2020-08-05	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	10935	pick-up	0	17
111142	2020-08-05 20:40:11	2020-08-05	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	30279	delivery	5	36
111143	2020-08-05 20:42:22	2020-08-05	14	[{"id_menu":2,"count":1}]	42517	delivery	5	19
111144	2020-08-05 20:44:35	2020-08-05	9	[{"id_menu":7,"count":1}]	21487	delivery	5	14
111212	2020-08-05 22:29:55	2020-08-05	9	[{"id_menu":6,"count":1}]	10206	delivery	5	14
111145	2020-08-05 20:44:44	2020-08-05	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5768	delivery	5	37
111146	2020-08-05 20:46:00	2020-08-05	9	[{"id_menu":7,"count":1}]	6134	delivery	5	14
111147	2020-08-05 20:47:26	2020-08-05	17	[{"id_menu":4,"count":1}]	12907	delivery	5	22
111148	2020-08-05 20:48:14	2020-08-05	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	20185	delivery	5	27
111149	2020-08-05 20:55:54	2020-08-05	17	[{"id_menu":4,"count":1}]	13679	delivery	5	22
111150	2020-08-05 20:57:22	2020-08-05	17	[{"id_menu":4,"count":1}]	17372	pick-up	0	17
111151	2020-08-05 21:00:31	2020-08-05	9	[{"id_menu":6,"count":1}]	21940	delivery	5	14
111152	2020-08-05 21:01:33	2020-08-05	17	[{"id_menu":4,"count":1}]	22408	delivery	5	22
111153	2020-08-05 21:05:49	2020-08-05	17	[{"id_menu":4,"count":1}]	6439	pick-up	0	17
111154	2020-08-05 21:06:14	2020-08-05	17	[{"id_menu":4,"count":2}]	2187	delivery	5	22
111155	2020-08-05 21:06:54	2020-08-05	12	[{"id_menu":1,"count":1}]	5306	delivery	5	17
111156	2020-08-05 21:06:59	2020-08-05	8	[{"id_menu":5,"count":1}]	14700	delivery	5	13
111157	2020-08-05 21:10:04	2020-08-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39976	delivery	5	23
111158	2020-08-05 21:10:10	2020-08-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	23110	delivery	5	28
111159	2020-08-05 21:13:42	2020-08-05	9	[{"id_menu":6,"count":1}]	18713	delivery	5	14
111160	2020-08-05 21:15:31	2020-08-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	42558	delivery	5	22
111161	2020-08-05 21:18:44	2020-08-05	8	[{"id_menu":5,"count":1}]	42498	delivery	5	13
111162	2020-08-05 21:23:22	2020-08-05	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	22863	delivery	5	28
111163	2020-08-05 21:23:32	2020-08-05	17	[{"id_menu":4,"count":1}]	6498	delivery	5	22
111164	2020-08-05 21:27:17	2020-08-05	9	[{"id_menu":7,"count":1}]	4766	delivery	5	14
111165	2020-08-05 21:29:41	2020-08-05	12	[{"id_menu":1,"count":1}]	32468	delivery	5	17
111166	2020-08-05 21:29:41	2020-08-05	12	[{"id_menu":3,"count":1}]	39627	delivery	5	17
111167	2020-08-05 21:31:26	2020-08-05	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	42527	delivery	5	31
111168	2020-08-05 21:31:27	2020-08-05	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39271	delivery	5	48
111169	2020-08-05 21:32:40	2020-08-05	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1293	delivery	5	40
111170	2020-08-05 21:33:09	2020-08-05	8	[{"id_menu":5,"count":1}]	17351	pick-up	0	8
111171	2020-08-05 21:33:49	2020-08-05	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19911	pick-up	0	29
111172	2020-08-05 21:35:47	2020-08-05	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	30697	pick-up	0	40
111173	2020-08-05 21:36:31	2020-08-05	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6055	delivery	5	43
111174	2020-08-05 21:38:41	2020-08-05	9	[{"id_menu":7,"count":1}]	1976	pick-up	0	9
111175	2020-08-05 21:42:32	2020-08-05	17	[{"id_menu":4,"count":1}]	42646	delivery	5	22
111176	2020-08-05 21:43:05	2020-08-05	9	[{"id_menu":6,"count":2}]	16825	pick-up	0	9
111177	2020-08-05 21:43:15	2020-08-05	17	[{"id_menu":4,"count":1}]	10553	pick-up	0	17
111178	2020-08-05 21:47:13	2020-08-05	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	42651	delivery	5	22
111179	2020-08-05 21:48:18	2020-08-05	12	[{"id_menu":3,"count":1}]	2768	delivery	5	17
111180	2020-08-05 21:48:20	2020-08-05	17	[{"id_menu":4,"count":1}]	27378	pick-up	0	17
111181	2020-08-05 21:50:50	2020-08-05	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	8175	delivery	5	25
111182	2020-08-05 21:50:58	2020-08-05	9	[{"id_menu":6,"count":1}]	9976	delivery	5	14
111183	2020-08-05 21:52:09	2020-08-05	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	996	delivery	5	36
111184	2020-08-05 21:53:18	2020-08-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	34039	delivery	5	28
111185	2020-08-05 21:53:37	2020-08-05	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	37673	pick-up	0	29
111186	2020-08-05 21:55:04	2020-08-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	970	pick-up	0	17
111187	2020-08-05 21:56:43	2020-08-05	12	[{"id_menu":3,"count":1}]	1506	pick-up	0	12
111188	2020-08-05 21:57:27	2020-08-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2089	delivery	5	28
111189	2020-08-05 22:01:00	2020-08-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	42475	delivery	5	22
111190	2020-08-05 22:01:49	2020-08-05	14	[{"id_menu":2,"count":1}]	9891	delivery	5	19
111191	2020-08-05 22:01:51	2020-08-05	14	[{"id_menu":2,"count":1}]	9099	delivery	5	19
111192	2020-08-05 22:06:34	2020-08-05	9	[{"id_menu":6,"count":1}]	31382	delivery	5	14
111193	2020-08-05 22:07:32	2020-08-05	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	31726	pick-up	0	47
111194	2020-08-05 22:07:37	2020-08-05	17	[{"id_menu":4,"count":1}]	8747	pick-up	0	17
111195	2020-08-05 22:08:03	2020-08-05	12	[{"id_menu":1,"count":1}]	42508	pick-up	0	12
111196	2020-08-05 22:10:11	2020-08-05	8	[{"id_menu":5,"count":1}]	2894	pick-up	0	8
111197	2020-08-05 22:11:14	2020-08-05	12	[{"id_menu":3,"count":1}]	42561	delivery	5	17
111198	2020-08-05 22:12:27	2020-08-05	8	[{"id_menu":5,"count":1}]	42486	delivery	5	13
111199	2020-08-05 22:12:56	2020-08-05	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	42607	delivery	5	26
111200	2020-08-05 22:14:23	2020-08-05	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	18914	delivery	5	40
111201	2020-08-05 22:14:45	2020-08-05	9	[{"id_menu":6,"count":1}]	41198	delivery	5	14
111202	2020-08-05 22:15:04	2020-08-05	9	[{"id_menu":7,"count":1}]	42466	delivery	5	14
111203	2020-08-05 22:16:43	2020-08-05	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	7425	delivery	5	26
111204	2020-08-05 22:18:25	2020-08-05	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	754	pick-up	0	17
111205	2020-08-05 22:20:10	2020-08-05	9	[{"id_menu":7,"count":1}]	1995	delivery	5	14
111206	2020-08-05 22:22:17	2020-08-05	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8990	delivery	5	34
111207	2020-08-05 22:23:49	2020-08-05	8	[{"id_menu":5,"count":1}]	19979	delivery	5	13
111208	2020-08-05 22:27:09	2020-08-05	14	[{"id_menu":2,"count":1}]	30455	pick-up	0	14
111209	2020-08-05 22:27:47	2020-08-05	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	42638	delivery	5	30
111210	2020-08-05 22:28:56	2020-08-05	17	[{"id_menu":4,"count":1}]	19270	delivery	5	22
111211	2020-08-05 22:29:13	2020-08-05	8	[{"id_menu":5,"count":1}]	42626	delivery	5	13
111213	2020-08-05 22:34:09	2020-08-05	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7604	delivery	5	34
111214	2020-08-05 22:35:15	2020-08-05	9	[{"id_menu":6,"count":1}]	5629	delivery	5	14
111215	2020-08-05 22:36:31	2020-08-05	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4212	delivery	5	22
111216	2020-08-05 22:36:58	2020-08-05	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	42582	delivery	5	28
111217	2020-08-05 22:41:31	2020-08-05	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	30460	delivery	5	40
111218	2020-08-05 22:43:53	2020-08-05	8	[{"id_menu":5,"count":1}]	4093	delivery	5	13
111219	2020-08-05 22:43:55	2020-08-05	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	40401	delivery	5	39
111220	2020-08-05 22:44:34	2020-08-05	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	36729	pick-up	0	29
111221	2020-08-05 22:45:55	2020-08-05	8	[{"id_menu":5,"count":1}]	2761	delivery	5	13
111222	2020-08-05 22:47:04	2020-08-05	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	42566	delivery	5	22
111223	2020-08-05 22:53:19	2020-08-05	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	26520	delivery	5	53
111224	2020-08-05 22:54:50	2020-08-05	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4904	pick-up	0	26
111225	2020-08-05 22:55:22	2020-08-05	17	[{"id_menu":4,"count":1}]	41937	delivery	5	22
111226	2020-08-05 22:57:20	2020-08-05	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	17051	delivery	5	40
111227	2020-08-05 22:57:25	2020-08-05	9	[{"id_menu":6,"count":1}]	32884	delivery	5	14
111228	2020-08-05 22:59:46	2020-08-05	14	[{"id_menu":2,"count":1}]	12143	delivery	5	19
111229	2020-08-05 23:03:01	2020-08-05	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1093	pick-up	0	32
111230	2020-08-05 23:09:03	2020-08-05	9	[{"id_menu":7,"count":2}]	42653	pick-up	0	9
111231	2020-08-05 23:11:00	2020-08-05	14	[{"id_menu":2,"count":1}]	5731	delivery	5	19
111232	2020-08-05 23:11:14	2020-08-05	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	42529	delivery	5	29
111233	2020-08-05 23:15:22	2020-08-05	9	[{"id_menu":6,"count":1}]	30361	pick-up	0	9
111234	2020-08-05 23:18:21	2020-08-05	12	[{"id_menu":3,"count":1}]	424	pick-up	0	12
111235	2020-08-05 23:18:32	2020-08-05	17	[{"id_menu":4,"count":1}]	42576	delivery	5	22
111236	2020-08-05 23:19:57	2020-08-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	10244	delivery	5	23
111237	2020-08-05 23:23:08	2020-08-05	12	[{"id_menu":3,"count":1}]	34564	delivery	5	17
111238	2020-08-05 23:24:05	2020-08-05	9	[{"id_menu":6,"count":1}]	18840	delivery	5	14
111239	2020-08-05 23:24:06	2020-08-05	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	10442	delivery	5	34
111240	2020-08-05 23:24:54	2020-08-05	9	[{"id_menu":7,"count":2}]	3268	pick-up	0	9
111241	2020-08-05 23:25:11	2020-08-05	9	[{"id_menu":7,"count":1}]	42643	delivery	5	14
111242	2020-08-05 23:26:02	2020-08-05	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":3}]	31300	delivery	5	31
111243	2020-08-05 23:26:08	2020-08-05	14	[{"id_menu":2,"count":1}]	4516	pick-up	0	14
111244	2020-08-05 23:30:58	2020-08-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":3}]	13801	delivery	5	23
111245	2020-08-05 23:31:25	2020-08-05	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	38822	delivery	5	43
111246	2020-08-05 23:49:08	2020-08-05	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	36148	pick-up	0	37
111247	2020-08-05 23:49:11	2020-08-05	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2656	pick-up	0	26
111248	2020-08-05 23:49:18	2020-08-05	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36010	pick-up	0	18
111249	2020-08-05 23:51:23	2020-08-05	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	42530	delivery	5	26
111250	2020-08-05 23:51:42	2020-08-05	17	[{"id_menu":4,"count":1}]	14537	delivery	5	22
111251	2020-08-05 23:54:49	2020-08-05	9	[{"id_menu":7,"count":1}]	31829	delivery	5	14
111252	2020-08-06 00:01:53	2020-08-06	9	[{"id_menu":6,"count":1}]	23922	delivery	5	14
111253	2020-08-06 00:03:29	2020-08-06	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	10205	pick-up	0	23
111254	2020-08-06 00:04:06	2020-08-06	43	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	40170	delivery	5	48
111255	2020-08-06 00:04:36	2020-08-06	12	[{"id_menu":1,"count":1}]	42882	delivery	5	17
111256	2020-08-06 00:05:29	2020-08-06	12	[{"id_menu":1,"count":1}]	17363	delivery	5	17
111257	2020-08-06 00:06:21	2020-08-06	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	32175	delivery	5	45
111258	2020-08-06 00:06:30	2020-08-06	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	11960	delivery	5	26
111259	2020-08-06 00:07:33	2020-08-06	14	[{"id_menu":2,"count":1}]	40860	delivery	5	19
111260	2020-08-06 00:09:25	2020-08-06	12	[{"id_menu":1,"count":1}]	42854	pick-up	0	12
111261	2020-08-06 00:10:28	2020-08-06	12	[{"id_menu":3,"count":1}]	39151	delivery	5	17
111262	2020-08-06 00:13:47	2020-08-06	9	[{"id_menu":7,"count":1}]	30327	delivery	5	14
111263	2020-08-06 00:14:36	2020-08-06	8	[{"id_menu":5,"count":1}]	42858	delivery	5	13
111264	2020-08-06 00:18:50	2020-08-06	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	19432	delivery	5	36
111265	2020-08-06 00:21:30	2020-08-06	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	16304	delivery	5	28
111266	2020-08-06 00:22:33	2020-08-06	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24570	delivery	5	22
111267	2020-08-06 00:24:36	2020-08-06	17	[{"id_menu":4,"count":1}]	31986	delivery	5	22
111268	2020-08-06 00:24:51	2020-08-06	17	[{"id_menu":4,"count":1}]	42791	delivery	5	22
111269	2020-08-06 00:25:36	2020-08-06	12	[{"id_menu":3,"count":1}]	39575	delivery	5	17
111270	2020-08-06 00:25:38	2020-08-06	9	[{"id_menu":6,"count":1}]	19282	delivery	5	14
111271	2020-08-06 00:25:44	2020-08-06	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	29527	delivery	5	31
111272	2020-08-06 00:26:13	2020-08-06	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7779	delivery	5	43
111273	2020-08-06 00:26:17	2020-08-06	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	42807	delivery	5	22
111274	2020-08-06 00:26:36	2020-08-06	17	[{"id_menu":4,"count":1}]	41136	pick-up	0	17
111275	2020-08-06 00:28:12	2020-08-06	14	[{"id_menu":2,"count":1}]	32144	pick-up	0	14
111276	2020-08-06 00:30:08	2020-08-06	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	39654	delivery	5	34
111344	2020-08-06 03:10:48	2020-08-06	9	[{"id_menu":6,"count":1}]	37736	delivery	5	14
111277	2020-08-06 00:34:51	2020-08-06	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25051	delivery	5	52
111278	2020-08-06 00:38:04	2020-08-06	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	18432	delivery	5	42
111279	2020-08-06 00:38:55	2020-08-06	9	[{"id_menu":6,"count":1}]	42732	delivery	5	14
111280	2020-08-06 00:39:16	2020-08-06	12	[{"id_menu":1,"count":1}]	21893	delivery	5	17
111281	2020-08-06 00:47:50	2020-08-06	14	[{"id_menu":2,"count":1}]	19674	delivery	5	19
111282	2020-08-06 00:50:00	2020-08-06	14	[{"id_menu":2,"count":1}]	5729	delivery	5	19
111283	2020-08-06 00:50:07	2020-08-06	8	[{"id_menu":5,"count":1}]	1256	delivery	5	13
111284	2020-08-06 00:52:04	2020-08-06	14	[{"id_menu":2,"count":1}]	21387	pick-up	0	14
111285	2020-08-06 00:52:43	2020-08-06	8	[{"id_menu":5,"count":1}]	42700	delivery	5	13
111286	2020-08-06 00:57:14	2020-08-06	14	[{"id_menu":2,"count":1}]	35925	delivery	5	19
111287	2020-08-06 01:00:52	2020-08-06	9	[{"id_menu":6,"count":1}]	42724	delivery	5	14
111288	2020-08-06 01:02:09	2020-08-06	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	42772	pick-up	0	26
111289	2020-08-06 01:02:28	2020-08-06	9	[{"id_menu":7,"count":1}]	42690	delivery	5	14
111290	2020-08-06 01:04:26	2020-08-06	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	5808	pick-up	0	26
111291	2020-08-06 01:08:23	2020-08-06	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	23271	delivery	5	26
111292	2020-08-06 01:10:48	2020-08-06	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7629	delivery	5	45
111293	2020-08-06 01:13:19	2020-08-06	8	[{"id_menu":5,"count":1}]	30329	pick-up	0	8
111294	2020-08-06 01:13:30	2020-08-06	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	9303	pick-up	0	23
111295	2020-08-06 01:13:56	2020-08-06	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	42775	delivery	5	30
111296	2020-08-06 01:18:54	2020-08-06	17	[{"id_menu":4,"count":1}]	3802	pick-up	0	17
111297	2020-08-06 01:18:57	2020-08-06	8	[{"id_menu":5,"count":1}]	2662	pick-up	0	8
111298	2020-08-06 01:19:42	2020-08-06	9	[{"id_menu":6,"count":1}]	42859	delivery	5	14
111299	2020-08-06 01:35:48	2020-08-06	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3565	delivery	5	40
111300	2020-08-06 01:37:10	2020-08-06	9	[{"id_menu":7,"count":1}]	42851	delivery	5	14
111301	2020-08-06 01:37:52	2020-08-06	9	[{"id_menu":6,"count":3}]	42795	delivery	5	14
111302	2020-08-06 01:42:00	2020-08-06	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	14267	delivery	5	26
111303	2020-08-06 01:42:59	2020-08-06	9	[{"id_menu":7,"count":2}]	42820	delivery	5	14
111304	2020-08-06 01:51:13	2020-08-06	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	5483	delivery	5	28
111305	2020-08-06 01:51:20	2020-08-06	17	[{"id_menu":4,"count":1}]	42271	delivery	5	22
111306	2020-08-06 01:53:33	2020-08-06	14	[{"id_menu":2,"count":1}]	34346	pick-up	0	14
111307	2020-08-06 01:55:48	2020-08-06	17	[{"id_menu":4,"count":1}]	11189	delivery	5	22
111308	2020-08-06 01:56:41	2020-08-06	14	[{"id_menu":2,"count":1}]	42809	pick-up	0	14
111309	2020-08-06 01:57:27	2020-08-06	12	[{"id_menu":1,"count":1}]	33614	pick-up	0	12
111310	2020-08-06 01:58:35	2020-08-06	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	33269	delivery	5	23
111311	2020-08-06 02:01:40	2020-08-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	37123	delivery	5	28
111312	2020-08-06 02:05:45	2020-08-06	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	25355	delivery	5	40
111313	2020-08-06 02:09:02	2020-08-06	12	[{"id_menu":1,"count":1}]	31694	delivery	5	17
111314	2020-08-06 02:09:45	2020-08-06	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	8900	pick-up	0	29
111315	2020-08-06 02:17:49	2020-08-06	9	[{"id_menu":7,"count":1}]	33946	delivery	5	14
111316	2020-08-06 02:20:09	2020-08-06	9	[{"id_menu":7,"count":1}]	25474	delivery	5	14
111317	2020-08-06 02:22:23	2020-08-06	14	[{"id_menu":2,"count":1}]	42922	delivery	5	19
111318	2020-08-06 02:28:30	2020-08-06	9	[{"id_menu":6,"count":1}]	42785	delivery	5	14
111319	2020-08-06 02:29:17	2020-08-06	9	[{"id_menu":7,"count":1}]	42079	pick-up	0	9
111320	2020-08-06 02:29:56	2020-08-06	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32766	delivery	5	23
111321	2020-08-06 02:30:10	2020-08-06	14	[{"id_menu":2,"count":1}]	42901	delivery	5	19
111322	2020-08-06 02:31:13	2020-08-06	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	42687	delivery	5	36
111323	2020-08-06 02:35:15	2020-08-06	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	42750	delivery	5	23
111324	2020-08-06 02:35:48	2020-08-06	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	26341	delivery	5	26
111325	2020-08-06 02:35:57	2020-08-06	9	[{"id_menu":7,"count":1}]	14073	delivery	5	14
111326	2020-08-06 02:37:32	2020-08-06	12	[{"id_menu":3,"count":1}]	7854	pick-up	0	12
111327	2020-08-06 02:40:09	2020-08-06	9	[{"id_menu":6,"count":1}]	26261	delivery	5	14
111328	2020-08-06 02:41:03	2020-08-06	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	37320	delivery	5	27
111329	2020-08-06 02:44:16	2020-08-06	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	32298	delivery	5	34
111330	2020-08-06 02:45:47	2020-08-06	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	36754	delivery	5	34
111331	2020-08-06 02:47:29	2020-08-06	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	42697	delivery	5	31
111332	2020-08-06 02:54:41	2020-08-06	14	[{"id_menu":2,"count":1}]	42692	delivery	5	19
111333	2020-08-06 02:54:41	2020-08-06	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	38895	delivery	5	30
111334	2020-08-06 02:55:26	2020-08-06	8	[{"id_menu":5,"count":1}]	32913	delivery	5	13
111335	2020-08-06 02:55:57	2020-08-06	17	[{"id_menu":4,"count":1}]	42870	delivery	5	22
111336	2020-08-06 02:56:32	2020-08-06	9	[{"id_menu":6,"count":1}]	9934	delivery	5	14
111337	2020-08-06 02:58:15	2020-08-06	9	[{"id_menu":6,"count":1}]	11124	pick-up	0	9
111338	2020-08-06 02:59:36	2020-08-06	12	[{"id_menu":1,"count":2}]	16335	pick-up	0	12
111339	2020-08-06 03:04:01	2020-08-06	12	[{"id_menu":3,"count":1}]	38569	delivery	5	17
111340	2020-08-06 03:04:51	2020-08-06	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	42899	delivery	5	45
111341	2020-08-06 03:05:36	2020-08-06	9	[{"id_menu":6,"count":1}]	11840	delivery	5	14
111342	2020-08-06 03:07:37	2020-08-06	14	[{"id_menu":2,"count":1}]	19143	delivery	5	19
111343	2020-08-06 03:10:06	2020-08-06	14	[{"id_menu":2,"count":1}]	42707	pick-up	0	14
111345	2020-08-06 03:16:41	2020-08-06	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	2857	pick-up	0	34
111346	2020-08-06 03:18:07	2020-08-06	12	[{"id_menu":3,"count":1}]	28624	delivery	5	17
111347	2020-08-06 03:18:13	2020-08-06	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	42889	delivery	5	43
111348	2020-08-06 03:18:35	2020-08-06	9	[{"id_menu":7,"count":1}]	15524	delivery	5	14
111349	2020-08-06 03:20:15	2020-08-06	12	[{"id_menu":1,"count":1}]	42802	delivery	5	17
111350	2020-08-06 03:23:50	2020-08-06	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	15284	delivery	5	26
111351	2020-08-06 03:27:57	2020-08-06	14	[{"id_menu":2,"count":1}]	26192	delivery	5	19
111352	2020-08-06 03:31:39	2020-08-06	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	38336	delivery	5	31
111353	2020-08-06 03:34:27	2020-08-06	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	41722	delivery	5	40
111354	2020-08-06 03:36:19	2020-08-06	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	42840	delivery	5	34
111355	2020-08-06 03:40:51	2020-08-06	8	[{"id_menu":5,"count":1}]	13769	delivery	5	13
111356	2020-08-06 03:41:56	2020-08-06	14	[{"id_menu":2,"count":1}]	42708	delivery	5	19
111357	2020-08-06 03:43:41	2020-08-06	9	[{"id_menu":7,"count":1}]	21389	pick-up	0	9
111358	2020-08-06 03:45:29	2020-08-06	9	[{"id_menu":6,"count":1}]	34328	pick-up	0	9
111359	2020-08-06 03:45:46	2020-08-06	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3350	delivery	5	43
111360	2020-08-06 03:48:57	2020-08-06	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	637	delivery	5	22
111361	2020-08-06 03:49:46	2020-08-06	17	[{"id_menu":4,"count":1}]	561	pick-up	0	17
111362	2020-08-06 03:50:57	2020-08-06	8	[{"id_menu":5,"count":1}]	25019	pick-up	0	8
111363	2020-08-06 03:52:10	2020-08-06	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16578	delivery	5	34
111364	2020-08-06 03:52:20	2020-08-06	9	[{"id_menu":7,"count":1}]	42857	delivery	5	14
111365	2020-08-06 04:00:46	2020-08-06	12	[{"id_menu":1,"count":1}]	42860	delivery	5	17
111366	2020-08-06 04:01:45	2020-08-06	14	[{"id_menu":2,"count":1}]	3027	pick-up	0	14
111367	2020-08-06 04:03:30	2020-08-06	14	[{"id_menu":2,"count":1}]	3318	delivery	5	19
111368	2020-08-06 04:04:22	2020-08-06	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	42883	delivery	5	34
111369	2020-08-06 04:04:40	2020-08-06	17	[{"id_menu":4,"count":1}]	42839	delivery	5	22
111370	2020-08-06 04:05:51	2020-08-06	14	[{"id_menu":2,"count":1}]	42719	pick-up	0	14
111371	2020-08-06 04:06:05	2020-08-06	9	[{"id_menu":7,"count":1}]	25951	delivery	5	14
111372	2020-08-06 04:07:25	2020-08-06	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5914	delivery	5	43
111373	2020-08-06 04:08:13	2020-08-06	12	[{"id_menu":1,"count":1}]	2989	delivery	5	17
111374	2020-08-06 04:08:34	2020-08-06	9	[{"id_menu":6,"count":1}]	22769	delivery	5	14
111375	2020-08-06 04:09:38	2020-08-06	14	[{"id_menu":2,"count":1}]	42801	pick-up	0	14
111376	2020-08-06 04:21:09	2020-08-06	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	34507	delivery	5	22
111377	2020-08-06 04:21:18	2020-08-06	9	[{"id_menu":7,"count":1}]	17100	delivery	5	14
111378	2020-08-06 04:23:59	2020-08-06	8	[{"id_menu":5,"count":1}]	42913	delivery	5	13
111379	2020-08-06 04:26:06	2020-08-06	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	6331	pick-up	0	21
111380	2020-08-06 04:26:22	2020-08-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1557	pick-up	0	23
111381	2020-08-06 04:34:41	2020-08-06	8	[{"id_menu":5,"count":1}]	42734	delivery	5	13
111382	2020-08-06 04:39:20	2020-08-06	14	[{"id_menu":2,"count":1}]	42747	delivery	5	19
111383	2020-08-06 04:42:03	2020-08-06	17	[{"id_menu":4,"count":1}]	20329	delivery	5	22
111384	2020-08-06 04:44:07	2020-08-06	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	42776	delivery	5	25
111385	2020-08-06 04:53:48	2020-08-06	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	26464	delivery	5	36
111386	2020-08-06 04:54:20	2020-08-06	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3500	delivery	5	39
111387	2020-08-06 04:54:38	2020-08-06	12	[{"id_menu":1,"count":1}]	5082	pick-up	0	12
111388	2020-08-06 04:57:50	2020-08-06	9	[{"id_menu":7,"count":1}]	42897	delivery	5	14
111389	2020-08-06 05:05:48	2020-08-06	14	[{"id_menu":2,"count":2}]	18024	delivery	5	19
111390	2020-08-06 05:09:15	2020-08-06	8	[{"id_menu":5,"count":1}]	42720	delivery	5	13
111391	2020-08-06 05:11:52	2020-08-06	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	42824	delivery	5	22
111392	2020-08-06 05:13:41	2020-08-06	9	[{"id_menu":7,"count":1}]	15869	pick-up	0	9
111393	2020-08-06 05:14:16	2020-08-06	9	[{"id_menu":7,"count":1}]	33656	delivery	5	14
111394	2020-08-06 05:15:20	2020-08-06	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	42891	delivery	5	34
111395	2020-08-06 05:16:15	2020-08-06	12	[{"id_menu":3,"count":1}]	3539	pick-up	0	12
111396	2020-08-06 05:17:45	2020-08-06	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8126	delivery	5	52
111397	2020-08-06 05:18:18	2020-08-06	14	[{"id_menu":2,"count":1}]	15769	pick-up	0	14
111398	2020-08-06 05:19:30	2020-08-06	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	32939	pick-up	0	31
111399	2020-08-06 05:21:40	2020-08-06	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	22219	delivery	5	43
111400	2020-08-06 05:22:25	2020-08-06	8	[{"id_menu":5,"count":1}]	31583	pick-up	0	8
111401	2020-08-06 05:23:07	2020-08-06	12	[{"id_menu":1,"count":1}]	42756	delivery	5	17
111402	2020-08-06 05:23:35	2020-08-06	17	[{"id_menu":4,"count":1}]	6157	pick-up	0	17
111403	2020-08-06 05:27:18	2020-08-06	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	24780	delivery	5	36
111404	2020-08-06 05:28:48	2020-08-06	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7034	pick-up	0	23
111405	2020-08-06 05:29:12	2020-08-06	9	[{"id_menu":6,"count":1}]	42918	delivery	5	14
111406	2020-08-06 05:29:46	2020-08-06	9	[{"id_menu":6,"count":2}]	33420	delivery	5	14
111407	2020-08-06 05:30:28	2020-08-06	8	[{"id_menu":5,"count":1}]	29646	delivery	5	13
111408	2020-08-06 05:31:32	2020-08-06	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12172	delivery	5	31
111409	2020-08-06 05:32:41	2020-08-06	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	17518	delivery	5	22
111410	2020-08-06 05:35:30	2020-08-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	42852	delivery	5	28
111411	2020-08-06 05:36:01	2020-08-06	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	21684	delivery	5	31
111412	2020-08-06 05:39:20	2020-08-06	9	[{"id_menu":7,"count":1}]	42725	delivery	5	14
111413	2020-08-06 05:40:23	2020-08-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	16231	delivery	5	28
111414	2020-08-06 05:41:49	2020-08-06	9	[{"id_menu":6,"count":1}]	42727	delivery	5	14
111415	2020-08-06 05:43:25	2020-08-06	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	39411	delivery	5	22
111416	2020-08-06 05:46:16	2020-08-06	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	26927	delivery	5	26
111417	2020-08-06 05:46:26	2020-08-06	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	42886	delivery	5	27
111418	2020-08-06 05:47:14	2020-08-06	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	42916	delivery	5	28
111419	2020-08-06 05:49:29	2020-08-06	9	[{"id_menu":6,"count":1}]	23349	pick-up	0	9
111420	2020-08-06 05:50:00	2020-08-06	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	42896	delivery	5	31
111421	2020-08-06 05:50:19	2020-08-06	8	[{"id_menu":5,"count":1}]	20899	delivery	5	13
111422	2020-08-06 05:58:54	2020-08-06	8	[{"id_menu":5,"count":1}]	26644	pick-up	0	8
111423	2020-08-06 05:58:57	2020-08-06	14	[{"id_menu":2,"count":1}]	42721	delivery	5	19
111424	2020-08-06 06:02:45	2020-08-06	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	36734	delivery	5	26
111425	2020-08-06 06:06:51	2020-08-06	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28320	delivery	5	51
111426	2020-08-06 06:09:15	2020-08-06	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	40046	delivery	5	38
111427	2020-08-06 06:10:10	2020-08-06	8	[{"id_menu":5,"count":1}]	7736	delivery	5	13
111428	2020-08-06 06:10:37	2020-08-06	9	[{"id_menu":6,"count":2}]	42751	delivery	5	14
111429	2020-08-06 06:11:46	2020-08-06	9	[{"id_menu":6,"count":1}]	27212	delivery	5	14
111430	2020-08-06 06:15:20	2020-08-06	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	39621	pick-up	0	22
111431	2020-08-06 06:19:40	2020-08-06	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	14362	pick-up	0	23
111432	2020-08-06 06:23:49	2020-08-06	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5780	pick-up	0	26
111433	2020-08-06 06:24:20	2020-08-06	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	30219	delivery	5	26
111434	2020-08-06 06:25:07	2020-08-06	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	4262	delivery	5	29
111435	2020-08-06 06:27:15	2020-08-06	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	9147	delivery	5	36
111436	2020-08-06 06:27:25	2020-08-06	9	[{"id_menu":6,"count":1}]	42805	delivery	5	14
111437	2020-08-06 06:29:07	2020-08-06	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	42777	delivery	5	26
111438	2020-08-06 06:29:56	2020-08-06	9	[{"id_menu":7,"count":1}]	23588	pick-up	0	9
111439	2020-08-06 06:31:59	2020-08-06	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	26747	delivery	5	34
111440	2020-08-06 06:32:54	2020-08-06	9	[{"id_menu":7,"count":1}]	42691	delivery	5	14
111441	2020-08-06 06:33:51	2020-08-06	12	[{"id_menu":1,"count":1}]	42730	delivery	5	17
111442	2020-08-06 06:36:30	2020-08-06	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	42866	delivery	5	53
111443	2020-08-06 06:37:40	2020-08-06	12	[{"id_menu":3,"count":1}]	30119	delivery	5	17
111444	2020-08-06 06:40:18	2020-08-06	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	37694	pick-up	0	21
111445	2020-08-06 06:42:18	2020-08-06	8	[{"id_menu":5,"count":1}]	27304	pick-up	0	8
111446	2020-08-06 06:45:28	2020-08-06	12	[{"id_menu":3,"count":1}]	36457	delivery	5	17
111447	2020-08-06 06:46:23	2020-08-06	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	31592	delivery	5	34
111448	2020-08-06 06:47:28	2020-08-06	9	[{"id_menu":7,"count":1}]	40265	delivery	5	14
111449	2020-08-06 06:47:29	2020-08-06	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	30302	delivery	5	26
111450	2020-08-06 06:49:46	2020-08-06	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	29903	delivery	5	35
111451	2020-08-06 06:50:13	2020-08-06	30	[{"id_menu":1,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	42680	delivery	5	35
111452	2020-08-06 06:51:06	2020-08-06	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":2}]	42696	delivery	5	31
111453	2020-08-06 06:51:37	2020-08-06	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	25846	delivery	5	43
111454	2020-08-06 06:55:26	2020-08-06	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18911	delivery	5	54
111455	2020-08-06 06:56:31	2020-08-06	46	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	19246	delivery	5	51
111456	2020-08-06 06:58:04	2020-08-06	14	[{"id_menu":2,"count":1}]	17800	delivery	5	19
111457	2020-08-06 06:59:25	2020-08-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	26967	pick-up	0	23
111458	2020-08-06 07:03:01	2020-08-06	17	[{"id_menu":4,"count":1}]	14970	pick-up	0	17
111459	2020-08-06 07:04:09	2020-08-06	9	[{"id_menu":7,"count":2}]	42869	delivery	5	14
111460	2020-08-06 07:04:36	2020-08-06	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31062	pick-up	0	18
111461	2020-08-06 07:04:41	2020-08-06	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	34859	delivery	5	22
111462	2020-08-06 07:06:41	2020-08-06	17	[{"id_menu":4,"count":1}]	16330	pick-up	0	17
111463	2020-08-06 07:07:05	2020-08-06	9	[{"id_menu":6,"count":2}]	42803	delivery	5	14
111464	2020-08-06 07:08:57	2020-08-06	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	26894	delivery	5	34
111465	2020-08-06 07:10:35	2020-08-06	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	28039	delivery	5	23
111466	2020-08-06 07:10:40	2020-08-06	9	[{"id_menu":7,"count":1}]	34445	delivery	5	14
111467	2020-08-06 07:15:12	2020-08-06	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":3}]	3679	delivery	5	26
111468	2020-08-06 07:17:26	2020-08-06	12	[{"id_menu":3,"count":1}]	40848	pick-up	0	12
111469	2020-08-06 07:20:53	2020-08-06	9	[{"id_menu":7,"count":3}]	27938	delivery	5	14
111470	2020-08-06 07:21:26	2020-08-06	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3072	delivery	5	31
111471	2020-08-06 07:22:35	2020-08-06	8	[{"id_menu":5,"count":1}]	42821	delivery	5	13
111472	2020-08-06 07:25:49	2020-08-06	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	42822	delivery	5	25
111473	2020-08-06 07:26:59	2020-08-06	9	[{"id_menu":7,"count":1}]	25868	delivery	5	14
111474	2020-08-06 07:27:20	2020-08-06	8	[{"id_menu":5,"count":1}]	24868	pick-up	0	8
111475	2020-08-06 07:31:12	2020-08-06	12	[{"id_menu":3,"count":1}]	42735	delivery	5	17
111476	2020-08-06 07:36:26	2020-08-06	17	[{"id_menu":4,"count":1}]	30834	delivery	5	22
111477	2020-08-06 07:44:03	2020-08-06	14	[{"id_menu":2,"count":1}]	15701	pick-up	0	14
111478	2020-08-06 07:44:08	2020-08-06	8	[{"id_menu":5,"count":1}]	12843	delivery	5	13
111479	2020-08-06 07:46:35	2020-08-06	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	15645	pick-up	0	31
111480	2020-08-06 07:47:08	2020-08-06	12	[{"id_menu":3,"count":1}]	42779	delivery	5	17
111481	2020-08-06 07:49:31	2020-08-06	12	[{"id_menu":1,"count":1}]	26930	delivery	5	17
111482	2020-08-06 07:51:13	2020-08-06	9	[{"id_menu":6,"count":1}]	26597	delivery	5	14
111483	2020-08-06 07:55:52	2020-08-06	9	[{"id_menu":7,"count":1}]	11045	delivery	5	14
111484	2020-08-06 07:55:54	2020-08-06	12	[{"id_menu":1,"count":1}]	4414	pick-up	0	12
111485	2020-08-06 07:57:36	2020-08-06	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17268	delivery	5	43
111486	2020-08-06 07:57:52	2020-08-06	9	[{"id_menu":7,"count":1}]	4161	pick-up	0	9
111487	2020-08-06 07:57:53	2020-08-06	17	[{"id_menu":4,"count":1}]	37078	delivery	5	22
111488	2020-08-06 07:58:29	2020-08-06	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	42138	delivery	5	48
111489	2020-08-06 08:00:28	2020-08-06	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15535	delivery	5	45
111490	2020-08-06 08:05:49	2020-08-06	9	[{"id_menu":7,"count":1}]	355	pick-up	0	9
111491	2020-08-06 08:06:04	2020-08-06	12	[{"id_menu":1,"count":2}]	42766	pick-up	0	12
111492	2020-08-06 08:08:15	2020-08-06	9	[{"id_menu":6,"count":2}]	2907	pick-up	0	9
111493	2020-08-06 08:08:25	2020-08-06	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	42717	delivery	5	37
111494	2020-08-06 08:08:48	2020-08-06	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	37258	delivery	5	40
111495	2020-08-06 08:10:21	2020-08-06	17	[{"id_menu":4,"count":1}]	25808	delivery	5	22
111496	2020-08-06 08:12:37	2020-08-06	17	[{"id_menu":4,"count":1}]	12935	delivery	5	22
111497	2020-08-06 08:12:53	2020-08-06	8	[{"id_menu":5,"count":1}]	38698	delivery	5	13
111498	2020-08-06 08:13:23	2020-08-06	14	[{"id_menu":2,"count":1}]	5257	pick-up	0	14
111499	2020-08-06 08:17:50	2020-08-06	14	[{"id_menu":2,"count":1}]	4021	pick-up	0	14
111500	2020-08-06 08:18:31	2020-08-06	17	[{"id_menu":4,"count":2}]	42716	delivery	5	22
111501	2020-08-06 08:19:38	2020-08-06	9	[{"id_menu":6,"count":1}]	32155	delivery	5	14
111502	2020-08-06 08:22:03	2020-08-06	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	24980	pick-up	0	23
111503	2020-08-06 08:25:18	2020-08-06	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7330	pick-up	0	26
111504	2020-08-06 08:28:21	2020-08-06	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	40148	delivery	5	30
111505	2020-08-06 08:28:25	2020-08-06	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	40906	delivery	5	28
111506	2020-08-06 08:28:55	2020-08-06	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	9175	delivery	5	35
111507	2020-08-06 08:38:20	2020-08-06	9	[{"id_menu":6,"count":2}]	17805	pick-up	0	9
111508	2020-08-06 08:39:02	2020-08-06	8	[{"id_menu":5,"count":2}]	28545	delivery	5	13
111509	2020-08-06 08:39:08	2020-08-06	9	[{"id_menu":7,"count":1}]	13702	delivery	5	14
111510	2020-08-06 08:46:12	2020-08-06	8	[{"id_menu":5,"count":1}]	23848	delivery	5	13
111511	2020-08-06 08:47:30	2020-08-06	12	[{"id_menu":3,"count":1}]	2228	delivery	5	17
111512	2020-08-06 08:48:17	2020-08-06	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	33304	pick-up	0	38
111513	2020-08-06 08:48:57	2020-08-06	17	[{"id_menu":4,"count":1}]	6182	pick-up	0	17
111514	2020-08-06 08:51:17	2020-08-06	9	[{"id_menu":6,"count":1}]	4451	pick-up	0	9
111515	2020-08-06 08:51:38	2020-08-06	9	[{"id_menu":7,"count":1}]	1012	pick-up	0	9
111516	2020-08-06 08:54:58	2020-08-06	12	[{"id_menu":1,"count":1}]	26452	pick-up	0	12
111517	2020-08-06 08:54:58	2020-08-06	12	[{"id_menu":1,"count":1}]	41720	pick-up	0	12
111518	2020-08-06 08:59:57	2020-08-06	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	42709	delivery	5	38
111519	2020-08-06 09:05:15	2020-08-06	8	[{"id_menu":5,"count":1}]	13661	delivery	5	13
111520	2020-08-06 09:05:55	2020-08-06	17	[{"id_menu":4,"count":2}]	23525	delivery	5	22
111521	2020-08-06 09:05:56	2020-08-06	9	[{"id_menu":7,"count":1}]	35777	delivery	5	14
111522	2020-08-06 09:07:14	2020-08-06	17	[{"id_menu":4,"count":1}]	10209	pick-up	0	17
111523	2020-08-06 09:08:11	2020-08-06	14	[{"id_menu":2,"count":1}]	135	pick-up	0	14
111524	2020-08-06 09:11:51	2020-08-06	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	38475	delivery	5	48
111525	2020-08-06 09:13:53	2020-08-06	14	[{"id_menu":2,"count":1}]	42728	delivery	5	19
111526	2020-08-06 09:16:33	2020-08-06	9	[{"id_menu":6,"count":1}]	13246	delivery	5	14
111527	2020-08-06 09:17:58	2020-08-06	9	[{"id_menu":6,"count":1}]	24365	delivery	5	14
111528	2020-08-06 09:22:45	2020-08-06	12	[{"id_menu":1,"count":1}]	1337	delivery	5	17
111529	2020-08-06 09:25:09	2020-08-06	9	[{"id_menu":7,"count":1}]	31183	delivery	5	14
111530	2020-08-06 09:28:51	2020-08-06	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	42849	delivery	5	26
111531	2020-08-06 09:28:52	2020-08-06	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	42841	pick-up	0	32
111532	2020-08-06 09:29:03	2020-08-06	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	42684	delivery	5	25
111533	2020-08-06 09:34:28	2020-08-06	12	[{"id_menu":3,"count":1}]	42500	pick-up	0	12
111534	2020-08-06 09:37:05	2020-08-06	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	37886	delivery	5	51
111535	2020-08-06 09:37:45	2020-08-06	32	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	42771	delivery	5	37
111536	2020-08-06 09:39:23	2020-08-06	9	[{"id_menu":7,"count":1}]	37097	delivery	5	14
111537	2020-08-06 09:41:59	2020-08-06	12	[{"id_menu":1,"count":1}]	14947	pick-up	0	12
111538	2020-08-06 09:43:21	2020-08-06	14	[{"id_menu":2,"count":1}]	15350	delivery	5	19
111539	2020-08-06 09:50:07	2020-08-06	14	[{"id_menu":2,"count":1}]	35897	delivery	5	19
111540	2020-08-06 09:50:10	2020-08-06	12	[{"id_menu":1,"count":1}]	8651	delivery	5	17
111541	2020-08-06 09:54:55	2020-08-06	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	16834	delivery	5	28
111542	2020-08-06 09:55:08	2020-08-06	9	[{"id_menu":6,"count":1}]	42769	delivery	5	14
111543	2020-08-06 10:00:13	2020-08-06	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	42799	delivery	5	34
111544	2020-08-06 10:00:50	2020-08-06	9	[{"id_menu":6,"count":1}]	42919	delivery	5	14
111545	2020-08-06 10:02:54	2020-08-06	12	[{"id_menu":1,"count":1}]	7626	pick-up	0	12
111546	2020-08-06 10:02:56	2020-08-06	12	[{"id_menu":3,"count":1}]	1060	pick-up	0	12
111547	2020-08-06 10:03:15	2020-08-06	9	[{"id_menu":7,"count":1}]	42818	delivery	5	14
111548	2020-08-06 10:08:12	2020-08-06	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	24176	delivery	5	57
111549	2020-08-06 10:09:56	2020-08-06	9	[{"id_menu":7,"count":1}]	28727	delivery	5	14
111550	2020-08-06 10:10:38	2020-08-06	8	[{"id_menu":5,"count":1}]	29193	delivery	5	13
111551	2020-08-06 10:12:59	2020-08-06	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12702	pick-up	0	26
111552	2020-08-06 10:13:23	2020-08-06	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	42826	delivery	5	31
111553	2020-08-06 10:14:24	2020-08-06	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21875	delivery	5	36
111554	2020-08-06 10:15:25	2020-08-06	14	[{"id_menu":2,"count":1}]	42856	delivery	5	19
111555	2020-08-06 10:16:12	2020-08-06	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	3173	delivery	5	25
111556	2020-08-06 10:16:14	2020-08-06	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8294	delivery	5	40
111557	2020-08-06 10:16:40	2020-08-06	9	[{"id_menu":7,"count":1}]	13858	pick-up	0	9
111558	2020-08-06 10:21:33	2020-08-06	17	[{"id_menu":4,"count":1}]	42880	delivery	5	22
111559	2020-08-06 10:24:01	2020-08-06	9	[{"id_menu":6,"count":1}]	11921	delivery	5	14
111560	2020-08-06 10:30:39	2020-08-06	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	42842	delivery	5	49
111561	2020-08-06 10:31:14	2020-08-06	12	[{"id_menu":1,"count":1}]	22214	pick-up	0	12
111562	2020-08-06 10:32:41	2020-08-06	17	[{"id_menu":4,"count":1}]	15628	delivery	5	22
111563	2020-08-06 10:32:44	2020-08-06	12	[{"id_menu":3,"count":1}]	26445	pick-up	0	12
111564	2020-08-06 10:37:55	2020-08-06	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	34867	delivery	5	31
111565	2020-08-06 10:39:32	2020-08-06	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	42909	delivery	5	43
111566	2020-08-06 10:40:06	2020-08-06	8	[{"id_menu":5,"count":1}]	42764	pick-up	0	8
111567	2020-08-06 10:41:54	2020-08-06	9	[{"id_menu":7,"count":1}]	42793	delivery	5	14
111568	2020-08-06 10:43:46	2020-08-06	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	42808	delivery	5	31
111569	2020-08-06 10:44:41	2020-08-06	12	[{"id_menu":1,"count":1}]	10350	delivery	5	17
111570	2020-08-06 10:45:28	2020-08-06	9	[{"id_menu":7,"count":1}]	42879	delivery	5	14
111571	2020-08-06 10:46:47	2020-08-06	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	42911	delivery	5	57
111572	2020-08-06 10:48:41	2020-08-06	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	35867	delivery	5	28
111573	2020-08-06 10:49:18	2020-08-06	17	[{"id_menu":4,"count":1}]	24603	pick-up	0	17
111574	2020-08-06 10:55:48	2020-08-06	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	42722	delivery	5	22
111575	2020-08-06 10:57:37	2020-08-06	12	[{"id_menu":3,"count":1}]	13199	pick-up	0	12
111576	2020-08-06 10:58:12	2020-08-06	9	[{"id_menu":7,"count":1}]	21967	delivery	5	14
111577	2020-08-06 10:59:12	2020-08-06	9	[{"id_menu":7,"count":1}]	15648	delivery	5	14
111578	2020-08-06 10:59:34	2020-08-06	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":2}]	2556	pick-up	0	26
111579	2020-08-06 11:03:36	2020-08-06	9	[{"id_menu":6,"count":1}]	29966	delivery	5	14
111580	2020-08-06 11:04:32	2020-08-06	17	[{"id_menu":4,"count":1}]	35784	pick-up	0	17
111581	2020-08-06 11:05:01	2020-08-06	9	[{"id_menu":6,"count":1}]	14306	delivery	5	14
111582	2020-08-06 11:05:59	2020-08-06	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	688	delivery	5	30
111583	2020-08-06 11:06:18	2020-08-06	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	11715	pick-up	0	21
111584	2020-08-06 11:08:01	2020-08-06	17	[{"id_menu":4,"count":1}]	38755	delivery	5	22
111585	2020-08-06 11:11:16	2020-08-06	9	[{"id_menu":7,"count":1}]	42884	delivery	5	14
111586	2020-08-06 11:12:28	2020-08-06	9	[{"id_menu":7,"count":2}]	42868	delivery	5	14
111587	2020-08-06 11:15:18	2020-08-06	9	[{"id_menu":6,"count":1}]	19889	delivery	5	14
111588	2020-08-06 11:15:24	2020-08-06	12	[{"id_menu":1,"count":1}]	25087	delivery	5	17
111589	2020-08-06 11:19:07	2020-08-06	12	[{"id_menu":1,"count":1}]	4870	pick-up	0	12
111590	2020-08-06 11:20:38	2020-08-06	9	[{"id_menu":6,"count":1}]	13568	delivery	5	14
111591	2020-08-06 11:20:44	2020-08-06	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	22383	pick-up	0	34
111592	2020-08-06 11:21:46	2020-08-06	9	[{"id_menu":6,"count":1}]	42683	delivery	5	14
111593	2020-08-06 11:22:05	2020-08-06	9	[{"id_menu":6,"count":2}]	21469	delivery	5	14
111594	2020-08-06 11:22:39	2020-08-06	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	7636	delivery	5	34
111595	2020-08-06 11:23:46	2020-08-06	12	[{"id_menu":3,"count":1}]	42845	delivery	5	17
111596	2020-08-06 11:27:47	2020-08-06	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	42902	delivery	5	42
111597	2020-08-06 11:27:51	2020-08-06	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	42843	delivery	5	28
111598	2020-08-06 11:29:32	2020-08-06	12	[{"id_menu":1,"count":1}]	42763	delivery	5	17
111599	2020-08-06 11:30:42	2020-08-06	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	42705	delivery	5	25
111600	2020-08-06 11:31:20	2020-08-06	17	[{"id_menu":4,"count":1}]	37882	delivery	5	22
111601	2020-08-06 11:37:08	2020-08-06	12	[{"id_menu":3,"count":1}]	25166	delivery	5	17
111602	2020-08-06 11:41:03	2020-08-06	14	[{"id_menu":2,"count":1}]	37944	delivery	5	19
111603	2020-08-06 11:41:13	2020-08-06	14	[{"id_menu":2,"count":1}]	4771	pick-up	0	14
111604	2020-08-06 11:41:45	2020-08-06	9	[{"id_menu":7,"count":1}]	42685	delivery	5	14
111605	2020-08-06 11:41:55	2020-08-06	12	[{"id_menu":3,"count":1}]	11711	delivery	5	17
111606	2020-08-06 11:42:43	2020-08-06	12	[{"id_menu":3,"count":1}]	16308	pick-up	0	12
111607	2020-08-06 11:42:58	2020-08-06	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	42672	delivery	5	27
111608	2020-08-06 11:44:36	2020-08-06	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	19637	delivery	5	31
111609	2020-08-06 11:44:36	2020-08-06	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	31716	delivery	5	37
111610	2020-08-06 11:44:47	2020-08-06	12	[{"id_menu":1,"count":1}]	23650	delivery	5	17
111611	2020-08-06 11:47:45	2020-08-06	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	12578	delivery	5	31
111612	2020-08-06 11:49:49	2020-08-06	8	[{"id_menu":5,"count":1}]	39193	delivery	5	13
111613	2020-08-06 11:51:31	2020-08-06	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16542	delivery	5	23
111614	2020-08-06 11:52:07	2020-08-06	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":2}]	42701	delivery	5	22
111615	2020-08-06 11:53:25	2020-08-06	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	42745	delivery	5	22
111616	2020-08-06 11:54:55	2020-08-06	9	[{"id_menu":6,"count":1}]	42837	delivery	5	14
111617	2020-08-06 12:03:57	2020-08-06	17	[{"id_menu":4,"count":1}]	41729	pick-up	0	17
111618	2020-08-06 12:04:09	2020-08-06	12	[{"id_menu":1,"count":1}]	26693	delivery	5	17
111619	2020-08-06 12:04:38	2020-08-06	17	[{"id_menu":4,"count":1}]	37933	pick-up	0	17
111620	2020-08-06 12:08:52	2020-08-06	12	[{"id_menu":1,"count":1}]	5426	delivery	5	17
111621	2020-08-06 12:09:28	2020-08-06	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	42892	delivery	5	36
111622	2020-08-06 12:13:14	2020-08-06	9	[{"id_menu":7,"count":1}]	4130	pick-up	0	9
111623	2020-08-06 12:15:01	2020-08-06	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	35106	pick-up	0	26
111624	2020-08-06 12:17:32	2020-08-06	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	33942	delivery	5	22
111625	2020-08-06 12:17:45	2020-08-06	9	[{"id_menu":6,"count":2}]	42736	delivery	5	14
111626	2020-08-06 12:18:46	2020-08-06	9	[{"id_menu":7,"count":1}]	42768	delivery	5	14
111627	2020-08-06 12:20:05	2020-08-06	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	42832	delivery	5	53
111628	2020-08-06 12:21:13	2020-08-06	12	[{"id_menu":3,"count":1}]	34320	delivery	5	17
111629	2020-08-06 12:21:55	2020-08-06	8	[{"id_menu":5,"count":1}]	16282	pick-up	0	8
111630	2020-08-06 12:22:58	2020-08-06	24	[{"id_menu":1,"count":3},{"id_menu":3,"count":1}]	33015	pick-up	0	24
111631	2020-08-06 12:23:21	2020-08-06	9	[{"id_menu":7,"count":1}]	7660	delivery	5	14
111632	2020-08-06 12:24:03	2020-08-06	9	[{"id_menu":7,"count":1}]	24003	delivery	5	14
111633	2020-08-06 12:25:36	2020-08-06	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	31014	delivery	5	43
111634	2020-08-06 12:26:04	2020-08-06	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1865	pick-up	0	25
111635	2020-08-06 12:27:56	2020-08-06	17	[{"id_menu":4,"count":2}]	36813	delivery	5	22
111636	2020-08-06 12:28:21	2020-08-06	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	662	pick-up	0	31
111637	2020-08-06 12:28:33	2020-08-06	9	[{"id_menu":6,"count":1}]	42907	delivery	5	14
111638	2020-08-06 12:29:44	2020-08-06	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	42814	delivery	5	22
111639	2020-08-06 12:31:45	2020-08-06	9	[{"id_menu":6,"count":1}]	42698	delivery	5	14
111640	2020-08-06 12:31:52	2020-08-06	14	[{"id_menu":2,"count":1}]	16026	delivery	5	19
111641	2020-08-06 12:33:05	2020-08-06	9	[{"id_menu":7,"count":2}]	22549	delivery	5	14
111642	2020-08-06 12:33:58	2020-08-06	12	[{"id_menu":1,"count":1}]	42677	delivery	5	17
111643	2020-08-06 12:36:16	2020-08-06	12	[{"id_menu":3,"count":1}]	11287	pick-up	0	12
111644	2020-08-06 12:39:25	2020-08-06	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	33717	delivery	5	43
111645	2020-08-06 12:40:19	2020-08-06	9	[{"id_menu":6,"count":1}]	42893	delivery	5	14
111646	2020-08-06 12:40:36	2020-08-06	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2287	delivery	5	38
111647	2020-08-06 12:43:17	2020-08-06	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	31098	delivery	5	43
111648	2020-08-06 12:43:28	2020-08-06	17	[{"id_menu":4,"count":1}]	42778	delivery	5	22
111649	2020-08-06 12:45:48	2020-08-06	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3931	pick-up	0	26
111650	2020-08-06 12:46:07	2020-08-06	8	[{"id_menu":5,"count":1}]	30891	delivery	5	13
111651	2020-08-06 12:46:29	2020-08-06	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	29960	pick-up	0	21
111652	2020-08-06 12:46:45	2020-08-06	8	[{"id_menu":5,"count":1}]	351	pick-up	0	8
111653	2020-08-06 12:47:02	2020-08-06	9	[{"id_menu":7,"count":1}]	27020	delivery	5	14
111654	2020-08-06 12:48:51	2020-08-06	12	[{"id_menu":1,"count":1}]	12184	pick-up	0	12
111655	2020-08-06 12:48:53	2020-08-06	9	[{"id_menu":7,"count":1}]	31862	delivery	5	14
111656	2020-08-06 12:49:49	2020-08-06	8	[{"id_menu":5,"count":1}]	28158	pick-up	0	8
111657	2020-08-06 12:52:13	2020-08-06	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	42810	delivery	5	51
111658	2020-08-06 12:55:05	2020-08-06	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	39930	delivery	5	27
111659	2020-08-06 12:58:30	2020-08-06	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8574	pick-up	0	37
111660	2020-08-06 12:59:21	2020-08-06	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35733	delivery	5	35
111661	2020-08-06 12:59:31	2020-08-06	8	[{"id_menu":5,"count":1}]	8729	delivery	5	13
111662	2020-08-06 13:02:18	2020-08-06	8	[{"id_menu":5,"count":1}]	35997	delivery	5	13
111663	2020-08-06 13:03:37	2020-08-06	8	[{"id_menu":5,"count":1}]	42800	delivery	5	13
111664	2020-08-06 13:04:47	2020-08-06	17	[{"id_menu":4,"count":1}]	19091	delivery	5	22
111665	2020-08-06 13:04:49	2020-08-06	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	42710	delivery	5	30
111666	2020-08-06 13:12:08	2020-08-06	14	[{"id_menu":2,"count":1}]	28095	delivery	5	19
111667	2020-08-06 13:12:25	2020-08-06	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	23767	delivery	5	30
111668	2020-08-06 13:14:33	2020-08-06	14	[{"id_menu":2,"count":1}]	36664	delivery	5	19
111669	2020-08-06 13:17:51	2020-08-06	8	[{"id_menu":5,"count":1}]	18259	delivery	5	13
111670	2020-08-06 13:18:10	2020-08-06	14	[{"id_menu":2,"count":1}]	20805	pick-up	0	14
111671	2020-08-06 13:18:43	2020-08-06	9	[{"id_menu":6,"count":1}]	42757	delivery	5	14
111672	2020-08-06 13:20:08	2020-08-06	8	[{"id_menu":5,"count":1}]	42828	delivery	5	13
111673	2020-08-06 13:20:17	2020-08-06	14	[{"id_menu":2,"count":1}]	10452	pick-up	0	14
111674	2020-08-06 13:20:19	2020-08-06	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	12676	delivery	5	34
111675	2020-08-06 13:26:20	2020-08-06	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	24062	delivery	5	28
111676	2020-08-06 13:30:03	2020-08-06	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	42811	delivery	5	34
111677	2020-08-06 13:31:08	2020-08-06	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1314	pick-up	0	21
111678	2020-08-06 13:38:10	2020-08-06	8	[{"id_menu":5,"count":1}]	11615	delivery	5	13
111679	2020-08-06 13:38:55	2020-08-06	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	33701	delivery	5	26
111680	2020-08-06 13:39:43	2020-08-06	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2408	delivery	5	28
111681	2020-08-06 13:47:39	2020-08-06	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	42838	delivery	5	34
111682	2020-08-06 13:48:17	2020-08-06	12	[{"id_menu":3,"count":1}]	10589	delivery	5	17
111683	2020-08-06 13:49:43	2020-08-06	9	[{"id_menu":7,"count":1}]	5233	delivery	5	14
111684	2020-08-06 13:53:18	2020-08-06	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	28058	delivery	5	43
111685	2020-08-06 13:54:17	2020-08-06	12	[{"id_menu":1,"count":1}]	13739	delivery	5	17
111686	2020-08-06 13:54:43	2020-08-06	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	42871	delivery	5	34
111687	2020-08-06 13:56:17	2020-08-06	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	626	delivery	5	30
111688	2020-08-06 13:56:41	2020-08-06	9	[{"id_menu":7,"count":1}]	7527	pick-up	0	9
111689	2020-08-06 13:57:36	2020-08-06	9	[{"id_menu":6,"count":1}]	17956	pick-up	0	9
111690	2020-08-06 14:01:12	2020-08-06	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	4719	delivery	5	43
111691	2020-08-06 14:01:33	2020-08-06	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	23573	delivery	5	31
111692	2020-08-06 14:02:26	2020-08-06	17	[{"id_menu":4,"count":1}]	37077	delivery	5	22
111693	2020-08-06 14:04:18	2020-08-06	9	[{"id_menu":7,"count":1}]	5050	pick-up	0	9
111694	2020-08-06 14:06:37	2020-08-06	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28827	pick-up	0	18
111695	2020-08-06 14:09:55	2020-08-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2771	pick-up	0	23
111696	2020-08-06 14:10:48	2020-08-06	8	[{"id_menu":5,"count":1}]	2746	delivery	5	13
111697	2020-08-06 14:12:49	2020-08-06	9	[{"id_menu":7,"count":1}]	42817	delivery	5	14
111698	2020-08-06 14:18:17	2020-08-06	9	[{"id_menu":6,"count":1}]	2264	pick-up	0	9
111699	2020-08-06 14:19:26	2020-08-06	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	10740	delivery	5	31
111700	2020-08-06 14:20:34	2020-08-06	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	42738	delivery	5	31
111701	2020-08-06 14:22:15	2020-08-06	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	13939	pick-up	0	35
111702	2020-08-06 14:24:14	2020-08-06	9	[{"id_menu":7,"count":1}]	13499	delivery	5	14
111703	2020-08-06 14:24:59	2020-08-06	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28632	delivery	5	34
111704	2020-08-06 14:25:39	2020-08-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	13520	delivery	5	28
111705	2020-08-06 14:26:36	2020-08-06	14	[{"id_menu":2,"count":1}]	42829	delivery	5	19
111706	2020-08-06 14:28:06	2020-08-06	9	[{"id_menu":6,"count":1}]	6270	delivery	5	14
111707	2020-08-06 14:28:20	2020-08-06	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	16170	delivery	5	29
111708	2020-08-06 14:29:58	2020-08-06	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	13913	delivery	5	25
111709	2020-08-06 14:30:45	2020-08-06	9	[{"id_menu":7,"count":1}]	42773	delivery	5	14
111710	2020-08-06 14:33:08	2020-08-06	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":3}]	37181	delivery	5	30
111711	2020-08-06 14:33:10	2020-08-06	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16032	delivery	5	34
111712	2020-08-06 14:34:08	2020-08-06	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	42836	delivery	5	26
111713	2020-08-06 14:34:15	2020-08-06	17	[{"id_menu":4,"count":1}]	1993	pick-up	0	17
111714	2020-08-06 14:34:55	2020-08-06	8	[{"id_menu":5,"count":1}]	2279	pick-up	0	8
111715	2020-08-06 14:34:56	2020-08-06	9	[{"id_menu":7,"count":1}]	30364	delivery	5	14
111716	2020-08-06 14:36:19	2020-08-06	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2902	delivery	5	31
111717	2020-08-06 14:39:38	2020-08-06	9	[{"id_menu":7,"count":1}]	42758	delivery	5	14
111718	2020-08-06 14:49:52	2020-08-06	9	[{"id_menu":7,"count":1}]	22890	delivery	5	14
111719	2020-08-06 14:50:30	2020-08-06	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	32716	delivery	5	25
111720	2020-08-06 14:51:04	2020-08-06	8	[{"id_menu":5,"count":1}]	42407	delivery	5	13
111721	2020-08-06 14:52:07	2020-08-06	8	[{"id_menu":5,"count":1}]	18475	delivery	5	13
111722	2020-08-06 14:57:17	2020-08-06	14	[{"id_menu":2,"count":1}]	42706	delivery	5	19
111723	2020-08-06 15:02:35	2020-08-06	12	[{"id_menu":1,"count":1}]	41086	delivery	5	17
111724	2020-08-06 15:03:13	2020-08-06	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	42835	delivery	5	28
111725	2020-08-06 15:09:26	2020-08-06	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	6197	delivery	5	27
111726	2020-08-06 15:10:02	2020-08-06	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	24667	delivery	5	35
111727	2020-08-06 15:14:31	2020-08-06	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14292	delivery	5	31
111728	2020-08-06 15:14:33	2020-08-06	12	[{"id_menu":1,"count":1}]	2078	pick-up	0	12
111729	2020-08-06 15:15:33	2020-08-06	17	[{"id_menu":4,"count":1}]	42885	delivery	5	22
111730	2020-08-06 15:17:35	2020-08-06	9	[{"id_menu":7,"count":1}]	31176	delivery	5	14
111731	2020-08-06 15:18:56	2020-08-06	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	42686	delivery	5	48
111732	2020-08-06 15:19:28	2020-08-06	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10645	delivery	5	31
111733	2020-08-06 15:19:33	2020-08-06	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	42876	delivery	5	29
111734	2020-08-06 15:20:04	2020-08-06	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	42780	delivery	5	37
111735	2020-08-06 15:21:50	2020-08-06	9	[{"id_menu":7,"count":1}]	25602	delivery	5	14
111736	2020-08-06 15:24:17	2020-08-06	8	[{"id_menu":5,"count":1}]	5738	pick-up	0	8
111737	2020-08-06 15:24:37	2020-08-06	12	[{"id_menu":1,"count":1}]	33579	delivery	5	17
111738	2020-08-06 15:25:50	2020-08-06	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	42704	delivery	5	31
111739	2020-08-06 15:28:18	2020-08-06	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	18495	delivery	5	26
111740	2020-08-06 15:31:23	2020-08-06	9	[{"id_menu":7,"count":1}]	42718	delivery	5	14
111741	2020-08-06 15:36:12	2020-08-06	9	[{"id_menu":6,"count":1}]	39612	delivery	5	14
111742	2020-08-06 15:36:17	2020-08-06	9	[{"id_menu":6,"count":1}]	14069	delivery	5	14
111743	2020-08-06 15:37:30	2020-08-06	9	[{"id_menu":6,"count":1}]	42770	pick-up	0	9
111744	2020-08-06 15:37:38	2020-08-06	14	[{"id_menu":2,"count":1}]	10321	delivery	5	19
111745	2020-08-06 15:38:52	2020-08-06	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16915	delivery	5	43
111746	2020-08-06 15:41:14	2020-08-06	9	[{"id_menu":7,"count":1}]	22062	delivery	5	14
111747	2020-08-06 15:41:30	2020-08-06	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	15401	delivery	5	39
111748	2020-08-06 15:42:29	2020-08-06	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	42744	delivery	5	34
111749	2020-08-06 15:45:13	2020-08-06	14	[{"id_menu":2,"count":1}]	42904	delivery	5	19
111750	2020-08-06 15:47:54	2020-08-06	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15510	delivery	5	22
111751	2020-08-06 15:49:35	2020-08-06	17	[{"id_menu":4,"count":1}]	42914	delivery	5	22
111752	2020-08-06 15:50:42	2020-08-06	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	28204	delivery	5	26
111753	2020-08-06 15:51:16	2020-08-06	14	[{"id_menu":2,"count":1}]	3012	pick-up	0	14
111754	2020-08-06 15:51:17	2020-08-06	12	[{"id_menu":1,"count":1}]	39564	delivery	5	17
111755	2020-08-06 15:51:54	2020-08-06	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	42784	delivery	5	39
111756	2020-08-06 15:52:22	2020-08-06	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	42905	pick-up	0	40
111757	2020-08-06 15:55:32	2020-08-06	26	[{"id_menu":4,"count":3},{"id_menu":7,"count":1}]	28600	delivery	5	31
111758	2020-08-06 15:56:37	2020-08-06	14	[{"id_menu":2,"count":1}]	42774	delivery	5	19
111759	2020-08-06 15:59:46	2020-08-06	9	[{"id_menu":6,"count":1}]	42917	delivery	5	14
111760	2020-08-06 16:00:28	2020-08-06	9	[{"id_menu":6,"count":1}]	42830	delivery	5	14
111761	2020-08-06 16:03:41	2020-08-06	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	42872	delivery	5	31
111762	2020-08-06 16:04:04	2020-08-06	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13613	pick-up	0	26
111763	2020-08-06 16:06:04	2020-08-06	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	19408	delivery	5	26
111764	2020-08-06 16:06:58	2020-08-06	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	42865	delivery	5	23
111765	2020-08-06 16:09:00	2020-08-06	8	[{"id_menu":5,"count":1}]	42847	delivery	5	13
111766	2020-08-06 16:10:45	2020-08-06	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22871	delivery	5	35
111767	2020-08-06 16:11:58	2020-08-06	14	[{"id_menu":2,"count":1}]	5520	pick-up	0	14
111768	2020-08-06 16:12:47	2020-08-06	14	[{"id_menu":2,"count":1}]	42729	delivery	5	19
111769	2020-08-06 16:13:15	2020-08-06	12	[{"id_menu":1,"count":1}]	42694	pick-up	0	12
111770	2020-08-06 16:13:21	2020-08-06	9	[{"id_menu":6,"count":1}]	30751	pick-up	0	9
111771	2020-08-06 16:14:43	2020-08-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	17171	delivery	5	28
111772	2020-08-06 16:16:06	2020-08-06	8	[{"id_menu":5,"count":1}]	1280	pick-up	0	8
111773	2020-08-06 16:17:04	2020-08-06	12	[{"id_menu":3,"count":1}]	42714	delivery	5	17
111774	2020-08-06 16:18:00	2020-08-06	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	38176	delivery	5	34
111775	2020-08-06 16:18:41	2020-08-06	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	33025	delivery	5	43
111776	2020-08-06 16:24:31	2020-08-06	9	[{"id_menu":6,"count":1}]	11703	delivery	5	14
111777	2020-08-06 16:29:40	2020-08-06	9	[{"id_menu":6,"count":1}]	32936	pick-up	0	9
111778	2020-08-06 16:31:30	2020-08-06	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	4162	delivery	5	25
111779	2020-08-06 16:33:36	2020-08-06	12	[{"id_menu":1,"count":1}]	4688	pick-up	0	12
111780	2020-08-06 16:33:43	2020-08-06	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	7211	delivery	5	46
111781	2020-08-06 16:36:24	2020-08-06	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	16027	delivery	5	22
111782	2020-08-06 16:42:30	2020-08-06	12	[{"id_menu":3,"count":1}]	5947	delivery	5	17
111783	2020-08-06 16:45:24	2020-08-06	17	[{"id_menu":4,"count":1}]	42861	delivery	5	22
111784	2020-08-06 16:49:12	2020-08-06	17	[{"id_menu":4,"count":1}]	19170	delivery	5	22
111785	2020-08-06 16:50:07	2020-08-06	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	41749	delivery	5	42
111786	2020-08-06 16:52:47	2020-08-06	14	[{"id_menu":2,"count":1}]	3332	pick-up	0	14
111787	2020-08-06 16:53:31	2020-08-06	9	[{"id_menu":6,"count":1}]	11479	delivery	5	14
111788	2020-08-06 16:54:01	2020-08-06	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	42787	delivery	5	23
111789	2020-08-06 16:55:23	2020-08-06	12	[{"id_menu":3,"count":1}]	9857	pick-up	0	12
111790	2020-08-06 16:56:26	2020-08-06	9	[{"id_menu":6,"count":1}]	17822	delivery	5	14
111791	2020-08-06 16:57:21	2020-08-06	17	[{"id_menu":4,"count":1}]	42682	delivery	5	22
111792	2020-08-06 17:03:14	2020-08-06	14	[{"id_menu":2,"count":1}]	42844	delivery	5	19
111793	2020-08-06 17:03:25	2020-08-06	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	22881	delivery	5	29
111794	2020-08-06 17:05:13	2020-08-06	30	[{"id_menu":1,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25499	delivery	5	35
111795	2020-08-06 17:06:04	2020-08-06	8	[{"id_menu":5,"count":1}]	3212	delivery	5	13
111796	2020-08-06 17:06:15	2020-08-06	9	[{"id_menu":6,"count":1}]	35691	delivery	5	14
111797	2020-08-06 17:07:56	2020-08-06	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	14727	delivery	5	34
111798	2020-08-06 17:12:14	2020-08-06	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":3}]	32839	delivery	5	28
111799	2020-08-06 17:15:03	2020-08-06	12	[{"id_menu":1,"count":1}]	42908	pick-up	0	12
111800	2020-08-06 17:18:30	2020-08-06	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	37215	delivery	5	34
111801	2020-08-06 17:19:03	2020-08-06	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	26316	delivery	5	57
111802	2020-08-06 17:19:22	2020-08-06	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	22363	delivery	5	45
111803	2020-08-06 17:19:23	2020-08-06	12	[{"id_menu":3,"count":1}]	42746	delivery	5	17
111804	2020-08-06 17:19:26	2020-08-06	12	[{"id_menu":1,"count":1}]	42742	delivery	5	17
111805	2020-08-06 17:21:33	2020-08-06	12	[{"id_menu":1,"count":1}]	34430	delivery	5	17
111806	2020-08-06 17:22:11	2020-08-06	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	11283	delivery	5	25
111807	2020-08-06 17:26:14	2020-08-06	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	13758	delivery	5	40
111808	2020-08-06 17:28:04	2020-08-06	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	20392	delivery	5	27
111809	2020-08-06 17:34:02	2020-08-06	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	18075	delivery	5	31
111810	2020-08-06 17:35:04	2020-08-06	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	37325	delivery	5	22
111811	2020-08-06 17:36:48	2020-08-06	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	38383	delivery	5	40
111812	2020-08-06 17:37:38	2020-08-06	12	[{"id_menu":3,"count":1}]	14729	delivery	5	17
111813	2020-08-06 17:38:19	2020-08-06	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	38898	delivery	5	31
111814	2020-08-06 17:39:52	2020-08-06	17	[{"id_menu":4,"count":1}]	17435	delivery	5	22
111815	2020-08-06 17:40:19	2020-08-06	17	[{"id_menu":4,"count":1}]	6565	delivery	5	22
111816	2020-08-06 17:40:24	2020-08-06	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	8288	delivery	5	40
111817	2020-08-06 17:42:50	2020-08-06	12	[{"id_menu":1,"count":1}]	42833	delivery	5	17
111818	2020-08-06 17:43:30	2020-08-06	14	[{"id_menu":2,"count":1}]	42900	pick-up	0	14
111819	2020-08-06 17:48:27	2020-08-06	9	[{"id_menu":7,"count":1}]	42874	delivery	5	14
111820	2020-08-06 17:55:20	2020-08-06	12	[{"id_menu":3,"count":1}]	21786	pick-up	0	12
111821	2020-08-06 17:55:32	2020-08-06	9	[{"id_menu":6,"count":1}]	42794	delivery	5	14
111822	2020-08-06 17:57:05	2020-08-06	12	[{"id_menu":1,"count":1}]	36243	pick-up	0	12
111823	2020-08-06 17:58:27	2020-08-06	8	[{"id_menu":5,"count":1}]	2289	delivery	5	13
111824	2020-08-06 17:58:33	2020-08-06	9	[{"id_menu":7,"count":1}]	2951	delivery	5	14
111825	2020-08-06 18:01:10	2020-08-06	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	17687	delivery	5	25
111826	2020-08-06 18:05:03	2020-08-06	8	[{"id_menu":5,"count":1}]	38634	delivery	5	13
111827	2020-08-06 18:08:43	2020-08-06	9	[{"id_menu":6,"count":1}]	42920	delivery	5	14
111828	2020-08-06 18:11:02	2020-08-06	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	42890	delivery	5	22
111829	2020-08-06 18:11:37	2020-08-06	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	23424	delivery	5	30
111830	2020-08-06 18:13:47	2020-08-06	17	[{"id_menu":4,"count":1}]	42689	delivery	5	22
111831	2020-08-06 18:16:33	2020-08-06	12	[{"id_menu":1,"count":1}]	42816	delivery	5	17
111832	2020-08-06 18:19:38	2020-08-06	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	42695	delivery	5	26
111833	2020-08-06 18:22:40	2020-08-06	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	3238	delivery	5	31
111834	2020-08-06 18:26:11	2020-08-06	9	[{"id_menu":7,"count":2}]	12773	delivery	5	14
111835	2020-08-06 18:26:26	2020-08-06	12	[{"id_menu":3,"count":1}]	19005	pick-up	0	12
111836	2020-08-06 18:26:30	2020-08-06	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	41268	delivery	5	31
111837	2020-08-06 18:35:33	2020-08-06	14	[{"id_menu":2,"count":2}]	33333	delivery	5	19
111838	2020-08-06 18:36:00	2020-08-06	17	[{"id_menu":4,"count":1}]	39105	delivery	5	22
111839	2020-08-06 18:41:26	2020-08-06	12	[{"id_menu":1,"count":1}]	26570	delivery	5	17
111840	2020-08-06 18:41:53	2020-08-06	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	13068	delivery	5	26
111841	2020-08-06 18:42:52	2020-08-06	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	42759	delivery	5	23
111842	2020-08-06 18:44:32	2020-08-06	12	[{"id_menu":3,"count":1}]	27398	delivery	5	17
111843	2020-08-06 18:47:15	2020-08-06	12	[{"id_menu":1,"count":1}]	1676	pick-up	0	12
111844	2020-08-06 18:47:50	2020-08-06	9	[{"id_menu":7,"count":1}]	42792	delivery	5	14
111845	2020-08-06 18:49:37	2020-08-06	12	[{"id_menu":3,"count":1}]	6302	delivery	5	17
111846	2020-08-06 18:50:55	2020-08-06	9	[{"id_menu":7,"count":1}]	16438	delivery	5	14
111847	2020-08-06 18:53:05	2020-08-06	8	[{"id_menu":5,"count":1}]	42765	delivery	5	13
111848	2020-08-06 18:57:56	2020-08-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	26336	pick-up	0	23
111849	2020-08-06 18:58:05	2020-08-06	9	[{"id_menu":7,"count":1}]	7804	delivery	5	14
111850	2020-08-06 18:59:08	2020-08-06	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	40359	delivery	5	35
111851	2020-08-06 19:03:32	2020-08-06	12	[{"id_menu":1,"count":1}]	5292	pick-up	0	12
111852	2020-08-06 19:05:28	2020-08-06	14	[{"id_menu":2,"count":1}]	42806	delivery	5	19
111853	2020-08-06 19:09:38	2020-08-06	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":3}]	42921	delivery	5	23
111854	2020-08-06 19:14:52	2020-08-06	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2980	delivery	5	26
111855	2020-08-06 19:15:06	2020-08-06	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	42910	delivery	5	37
111856	2020-08-06 19:19:17	2020-08-06	9	[{"id_menu":7,"count":1}]	42815	delivery	5	14
111857	2020-08-06 19:21:35	2020-08-06	14	[{"id_menu":2,"count":1}]	41228	delivery	5	19
111858	2020-08-06 19:24:18	2020-08-06	8	[{"id_menu":5,"count":1}]	42853	delivery	5	13
111859	2020-08-06 19:31:32	2020-08-06	9	[{"id_menu":7,"count":1}]	42783	delivery	5	14
111860	2020-08-06 19:31:34	2020-08-06	8	[{"id_menu":5,"count":1}]	42678	delivery	5	13
111861	2020-08-06 19:33:11	2020-08-06	12	[{"id_menu":1,"count":1}]	14628	pick-up	0	12
111862	2020-08-06 19:35:40	2020-08-06	17	[{"id_menu":4,"count":1}]	14714	delivery	5	22
111863	2020-08-06 19:36:00	2020-08-06	12	[{"id_menu":3,"count":1}]	34750	delivery	5	17
111864	2020-08-06 19:38:20	2020-08-06	9	[{"id_menu":6,"count":1}]	4794	delivery	5	14
111865	2020-08-06 19:40:06	2020-08-06	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	42693	delivery	5	22
111866	2020-08-06 19:47:14	2020-08-06	17	[{"id_menu":4,"count":1}]	6916	delivery	5	22
111867	2020-08-06 19:47:15	2020-08-06	12	[{"id_menu":3,"count":1}]	42798	pick-up	0	12
111868	2020-08-06 19:47:42	2020-08-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	15386	delivery	5	28
111869	2020-08-06 19:48:28	2020-08-06	17	[{"id_menu":4,"count":1}]	15882	delivery	5	22
111870	2020-08-06 19:48:49	2020-08-06	8	[{"id_menu":5,"count":1}]	42873	delivery	5	13
111871	2020-08-06 19:51:07	2020-08-06	8	[{"id_menu":5,"count":1}]	41708	delivery	5	13
111872	2020-08-06 19:52:59	2020-08-06	9	[{"id_menu":7,"count":1}]	42819	delivery	5	14
111873	2020-08-06 19:55:15	2020-08-06	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5781	delivery	5	22
111874	2020-08-06 19:59:51	2020-08-06	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2288	pick-up	0	21
111875	2020-08-06 20:00:47	2020-08-06	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3431	delivery	5	31
111876	2020-08-06 20:01:02	2020-08-06	14	[{"id_menu":2,"count":1}]	8609	pick-up	0	14
111877	2020-08-06 20:04:03	2020-08-06	17	[{"id_menu":4,"count":1}]	12384	delivery	5	22
111878	2020-08-06 20:05:09	2020-08-06	17	[{"id_menu":4,"count":1}]	3567	delivery	5	22
111879	2020-08-06 20:08:50	2020-08-06	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	42733	delivery	5	31
111880	2020-08-06 20:09:22	2020-08-06	8	[{"id_menu":5,"count":1}]	1120	pick-up	0	8
111881	2020-08-06 20:09:43	2020-08-06	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	28485	delivery	5	45
111882	2020-08-06 20:12:13	2020-08-06	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	42850	delivery	5	57
111883	2020-08-06 20:17:20	2020-08-06	9	[{"id_menu":6,"count":1}]	36548	delivery	5	14
111884	2020-08-06 20:19:06	2020-08-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	29716	pick-up	0	23
111885	2020-08-06 20:20:57	2020-08-06	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	42739	delivery	5	40
111886	2020-08-06 20:23:06	2020-08-06	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	42702	delivery	5	29
111887	2020-08-06 20:25:01	2020-08-06	12	[{"id_menu":3,"count":1}]	5857	pick-up	0	12
111888	2020-08-06 20:27:15	2020-08-06	12	[{"id_menu":3,"count":1}]	39483	delivery	5	17
111889	2020-08-06 20:31:26	2020-08-06	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	42699	delivery	5	40
111890	2020-08-06 20:33:54	2020-08-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	18519	pick-up	0	23
111891	2020-08-06 20:36:06	2020-08-06	9	[{"id_menu":7,"count":1}]	13553	delivery	5	14
111892	2020-08-06 20:37:10	2020-08-06	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	36012	delivery	5	28
111893	2020-08-06 20:43:58	2020-08-06	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	8147	delivery	5	25
111894	2020-08-06 20:48:05	2020-08-06	12	[{"id_menu":3,"count":1}]	41154	delivery	5	17
111895	2020-08-06 20:49:18	2020-08-06	9	[{"id_menu":6,"count":1}]	13391	pick-up	0	9
111896	2020-08-06 20:51:24	2020-08-06	17	[{"id_menu":4,"count":2}]	25532	pick-up	0	17
111897	2020-08-06 20:57:05	2020-08-06	9	[{"id_menu":6,"count":1}]	42753	pick-up	0	9
111898	2020-08-06 20:58:03	2020-08-06	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	42834	delivery	5	38
111899	2020-08-06 20:59:57	2020-08-06	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	42912	delivery	5	31
111900	2020-08-06 20:59:58	2020-08-06	9	[{"id_menu":7,"count":1}]	42898	delivery	5	14
111901	2020-08-06 21:00:12	2020-08-06	14	[{"id_menu":2,"count":1}]	35455	delivery	5	19
111902	2020-08-06 21:00:37	2020-08-06	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8198	delivery	5	44
111903	2020-08-06 21:03:15	2020-08-06	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	42812	delivery	5	38
111904	2020-08-06 21:09:34	2020-08-06	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	20136	pick-up	0	17
111905	2020-08-06 21:09:43	2020-08-06	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	19582	delivery	5	36
111906	2020-08-06 21:15:13	2020-08-06	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	42741	delivery	5	34
111907	2020-08-06 21:19:59	2020-08-06	12	[{"id_menu":3,"count":1}]	29236	delivery	5	17
111908	2020-08-06 21:20:08	2020-08-06	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":2}]	42796	delivery	5	22
111909	2020-08-06 21:22:05	2020-08-06	8	[{"id_menu":5,"count":1}]	29490	delivery	5	13
111910	2020-08-06 21:23:03	2020-08-06	8	[{"id_menu":5,"count":1}]	8382	delivery	5	13
111911	2020-08-06 21:24:02	2020-08-06	12	[{"id_menu":1,"count":1}]	9403	pick-up	0	12
111912	2020-08-06 21:26:11	2020-08-06	12	[{"id_menu":3,"count":1}]	42703	delivery	5	17
111913	2020-08-06 21:29:03	2020-08-06	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	42906	delivery	5	36
111914	2020-08-06 21:32:45	2020-08-06	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16996	delivery	5	31
111915	2020-08-06 21:33:29	2020-08-06	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3006	delivery	5	30
111916	2020-08-06 21:38:36	2020-08-06	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11210	delivery	5	45
111917	2020-08-06 21:38:46	2020-08-06	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12273	delivery	5	31
111918	2020-08-06 21:41:19	2020-08-06	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	33298	delivery	5	37
111919	2020-08-06 21:43:17	2020-08-06	9	[{"id_menu":7,"count":1}]	8726	delivery	5	14
111920	2020-08-06 21:44:28	2020-08-06	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	29042	pick-up	0	35
111921	2020-08-06 21:48:39	2020-08-06	9	[{"id_menu":6,"count":1}]	33259	delivery	5	14
111922	2020-08-06 21:52:32	2020-08-06	9	[{"id_menu":6,"count":3}]	42762	delivery	5	14
111923	2020-08-06 21:53:03	2020-08-06	9	[{"id_menu":6,"count":1}]	42743	pick-up	0	9
111924	2020-08-06 21:54:55	2020-08-06	9	[{"id_menu":7,"count":1}]	2026	pick-up	0	9
111925	2020-08-06 22:00:59	2020-08-06	9	[{"id_menu":6,"count":1}]	42790	delivery	5	14
111926	2020-08-06 22:01:59	2020-08-06	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	35122	delivery	5	31
111927	2020-08-06 22:03:20	2020-08-06	9	[{"id_menu":6,"count":1}]	42748	delivery	5	14
111928	2020-08-06 22:06:09	2020-08-06	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	42846	delivery	5	29
111929	2020-08-06 22:07:27	2020-08-06	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	37196	delivery	5	28
111930	2020-08-06 22:07:55	2020-08-06	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	16244	pick-up	0	39
111931	2020-08-06 22:08:55	2020-08-06	9	[{"id_menu":6,"count":1}]	27130	delivery	5	14
111932	2020-08-06 22:10:50	2020-08-06	20	[{"id_menu":1,"count":3},{"id_menu":5,"count":1}]	23025	delivery	5	25
111933	2020-08-06 22:13:02	2020-08-06	12	[{"id_menu":1,"count":1}]	13218	delivery	5	17
111934	2020-08-06 22:15:07	2020-08-06	14	[{"id_menu":2,"count":2}]	25557	delivery	5	19
111935	2020-08-06 22:15:37	2020-08-06	9	[{"id_menu":7,"count":1}]	9394	pick-up	0	9
111936	2020-08-06 22:25:05	2020-08-06	14	[{"id_menu":2,"count":1}]	33683	delivery	5	19
111937	2020-08-06 22:27:21	2020-08-06	12	[{"id_menu":1,"count":1}]	13400	pick-up	0	12
111938	2020-08-06 22:28:25	2020-08-06	12	[{"id_menu":1,"count":1}]	29099	delivery	5	17
111939	2020-08-06 22:30:38	2020-08-06	9	[{"id_menu":7,"count":1}]	23600	delivery	5	14
111940	2020-08-06 22:31:11	2020-08-06	12	[{"id_menu":1,"count":1}]	196	delivery	5	17
111941	2020-08-06 22:33:14	2020-08-06	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	42755	delivery	5	40
111942	2020-08-06 22:35:29	2020-08-06	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	19711	pick-up	0	26
111943	2020-08-06 22:39:12	2020-08-06	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11150	delivery	5	36
111944	2020-08-06 22:41:00	2020-08-06	17	[{"id_menu":4,"count":1}]	2562	delivery	5	22
111945	2020-08-06 22:46:22	2020-08-06	9	[{"id_menu":7,"count":1}]	42881	pick-up	0	9
111946	2020-08-06 22:47:40	2020-08-06	12	[{"id_menu":3,"count":1}]	7140	delivery	5	17
111947	2020-08-06 22:48:51	2020-08-06	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	39741	pick-up	0	30
111948	2020-08-06 22:49:48	2020-08-06	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	30741	pick-up	0	31
111949	2020-08-06 22:51:52	2020-08-06	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	42688	delivery	5	25
111950	2020-08-06 23:01:20	2020-08-06	8	[{"id_menu":5,"count":1}]	29810	delivery	5	13
111951	2020-08-06 23:01:34	2020-08-06	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28653	delivery	5	23
111952	2020-08-06 23:04:14	2020-08-06	12	[{"id_menu":1,"count":1}]	39796	delivery	5	17
111953	2020-08-06 23:09:32	2020-08-06	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	42761	delivery	5	49
111954	2020-08-06 23:09:55	2020-08-06	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	6144	delivery	5	26
111955	2020-08-06 23:11:37	2020-08-06	9	[{"id_menu":6,"count":1}]	23575	delivery	5	14
111956	2020-08-06 23:12:19	2020-08-06	49	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	14307	delivery	5	54
111957	2020-08-06 23:15:34	2020-08-06	9	[{"id_menu":6,"count":1}]	7303	delivery	5	14
111958	2020-08-06 23:16:59	2020-08-06	17	[{"id_menu":4,"count":1}]	1819	pick-up	0	17
111959	2020-08-06 23:18:30	2020-08-06	8	[{"id_menu":5,"count":1}]	42629	delivery	5	13
111960	2020-08-06 23:21:25	2020-08-06	12	[{"id_menu":3,"count":1}]	3528	delivery	5	17
111961	2020-08-06 23:23:42	2020-08-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	42864	delivery	5	28
111962	2020-08-06 23:25:10	2020-08-06	8	[{"id_menu":5,"count":1}]	7741	pick-up	0	8
111963	2020-08-06 23:28:32	2020-08-06	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	42894	delivery	5	28
111964	2020-08-06 23:30:01	2020-08-06	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	10451	delivery	5	34
111965	2020-08-06 23:34:33	2020-08-06	9	[{"id_menu":6,"count":1}]	31280	delivery	5	14
111966	2020-08-06 23:38:20	2020-08-06	9	[{"id_menu":6,"count":1}]	8166	delivery	5	14
111967	2020-08-06 23:52:15	2020-08-06	12	[{"id_menu":1,"count":1}]	30513	pick-up	0	12
111968	2020-08-06 23:52:32	2020-08-06	9	[{"id_menu":6,"count":1}]	7773	delivery	5	14
111969	2020-08-06 23:52:35	2020-08-06	9	[{"id_menu":7,"count":1}]	42867	delivery	5	14
111970	2020-08-06 23:53:26	2020-08-06	9	[{"id_menu":6,"count":1}]	32826	delivery	5	14
111971	2020-08-06 23:53:40	2020-08-06	12	[{"id_menu":1,"count":1}]	29367	pick-up	0	12
111972	2020-08-06 23:54:53	2020-08-06	17	[{"id_menu":4,"count":1}]	41768	pick-up	0	17
111973	2020-08-06 23:55:07	2020-08-06	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28579	delivery	5	39
111974	2020-08-06 23:56:47	2020-08-06	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	16813	pick-up	0	21
111975	2020-08-06 23:56:53	2020-08-06	17	[{"id_menu":4,"count":1}]	11779	pick-up	0	17
111976	2020-08-07 00:00:06	2020-08-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	43135	delivery	5	26
111977	2020-08-07 00:01:03	2020-08-07	9	[{"id_menu":6,"count":1}]	19932	delivery	5	14
111978	2020-08-07 00:01:09	2020-08-07	9	[{"id_menu":7,"count":1}]	43022	delivery	5	14
111979	2020-08-07 00:05:41	2020-08-07	12	[{"id_menu":1,"count":1}]	4293	delivery	5	17
111980	2020-08-07 00:05:54	2020-08-07	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	42959	delivery	5	39
111981	2020-08-07 00:06:29	2020-08-07	26	[{"id_menu":4,"count":3},{"id_menu":7,"count":1}]	17799	delivery	5	31
111982	2020-08-07 00:07:13	2020-08-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	42254	delivery	5	28
111983	2020-08-07 00:09:24	2020-08-07	9	[{"id_menu":7,"count":1}]	25028	delivery	5	14
111984	2020-08-07 00:11:02	2020-08-07	14	[{"id_menu":2,"count":1}]	11525	delivery	5	19
111985	2020-08-07 00:11:10	2020-08-07	9	[{"id_menu":6,"count":1}]	33829	pick-up	0	9
111986	2020-08-07 00:23:46	2020-08-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	42928	pick-up	0	23
111987	2020-08-07 00:30:15	2020-08-07	14	[{"id_menu":2,"count":1}]	10589	pick-up	0	14
111988	2020-08-07 00:31:58	2020-08-07	8	[{"id_menu":5,"count":2}]	34110	delivery	5	13
111989	2020-08-07 00:37:57	2020-08-07	9	[{"id_menu":6,"count":1}]	10180	delivery	5	14
111990	2020-08-07 00:38:34	2020-08-07	9	[{"id_menu":7,"count":1}]	40459	pick-up	0	9
111991	2020-08-07 00:39:00	2020-08-07	9	[{"id_menu":6,"count":1}]	15052	pick-up	0	9
111992	2020-08-07 00:41:47	2020-08-07	14	[{"id_menu":2,"count":1}]	25447	delivery	5	19
111993	2020-08-07 00:42:25	2020-08-07	14	[{"id_menu":2,"count":1}]	4172	pick-up	0	14
111994	2020-08-07 00:43:34	2020-08-07	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23233	delivery	5	22
111995	2020-08-07 00:44:32	2020-08-07	14	[{"id_menu":2,"count":1}]	26930	delivery	5	19
111996	2020-08-07 00:45:24	2020-08-07	9	[{"id_menu":7,"count":1}]	42983	delivery	5	14
111997	2020-08-07 00:48:21	2020-08-07	8	[{"id_menu":5,"count":1}]	31166	delivery	5	13
111998	2020-08-07 00:50:58	2020-08-07	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	43119	delivery	5	38
111999	2020-08-07 00:53:12	2020-08-07	9	[{"id_menu":6,"count":1}]	28526	delivery	5	14
112000	2020-08-07 00:53:44	2020-08-07	8	[{"id_menu":5,"count":1}]	29393	delivery	5	13
112001	2020-08-07 00:57:39	2020-08-07	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	42979	delivery	5	43
112002	2020-08-07 00:58:48	2020-08-07	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":2}]	6686	delivery	5	27
112003	2020-08-07 00:58:49	2020-08-07	9	[{"id_menu":6,"count":1}]	43129	delivery	5	14
112004	2020-08-07 01:16:09	2020-08-07	17	[{"id_menu":4,"count":1}]	41740	delivery	5	22
112005	2020-08-07 01:16:20	2020-08-07	9	[{"id_menu":6,"count":1}]	40031	delivery	5	14
112006	2020-08-07 01:16:28	2020-08-07	14	[{"id_menu":2,"count":2}]	3224	pick-up	0	14
112007	2020-08-07 01:19:25	2020-08-07	12	[{"id_menu":1,"count":1}]	14635	delivery	5	17
112008	2020-08-07 01:22:42	2020-08-07	12	[{"id_menu":1,"count":1}]	35933	pick-up	0	12
112009	2020-08-07 01:23:01	2020-08-07	8	[{"id_menu":5,"count":1}]	36944	delivery	5	13
112010	2020-08-07 01:23:19	2020-08-07	8	[{"id_menu":5,"count":1}]	43133	delivery	5	13
112011	2020-08-07 01:24:49	2020-08-07	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	42963	delivery	5	25
112012	2020-08-07 01:25:46	2020-08-07	14	[{"id_menu":2,"count":1}]	3999	delivery	5	19
112013	2020-08-07 01:30:58	2020-08-07	9	[{"id_menu":6,"count":1}]	6769	pick-up	0	9
112014	2020-08-07 01:42:59	2020-08-07	9	[{"id_menu":6,"count":1}]	21003	delivery	5	14
112015	2020-08-07 01:48:24	2020-08-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	13567	delivery	5	28
112016	2020-08-07 01:48:52	2020-08-07	14	[{"id_menu":2,"count":1}]	13615	delivery	5	19
112017	2020-08-07 01:50:51	2020-08-07	12	[{"id_menu":1,"count":1}]	32300	delivery	5	17
112018	2020-08-07 01:58:26	2020-08-07	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	43145	delivery	5	34
112019	2020-08-07 01:58:39	2020-08-07	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	38089	delivery	5	38
112020	2020-08-07 01:59:40	2020-08-07	9	[{"id_menu":7,"count":1}]	43041	delivery	5	14
112021	2020-08-07 02:00:19	2020-08-07	12	[{"id_menu":1,"count":1}]	27332	delivery	5	17
112022	2020-08-07 02:01:53	2020-08-07	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	41072	delivery	5	39
112023	2020-08-07 02:04:22	2020-08-07	9	[{"id_menu":6,"count":1}]	19243	pick-up	0	9
112024	2020-08-07 02:09:08	2020-08-07	8	[{"id_menu":5,"count":1}]	28056	delivery	5	13
112025	2020-08-07 02:09:10	2020-08-07	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35017	delivery	5	49
112026	2020-08-07 02:09:47	2020-08-07	17	[{"id_menu":4,"count":1}]	43180	delivery	5	22
112027	2020-08-07 02:10:12	2020-08-07	17	[{"id_menu":4,"count":1}]	16367	delivery	5	22
112028	2020-08-07 02:12:23	2020-08-07	14	[{"id_menu":2,"count":2}]	39839	delivery	5	19
112029	2020-08-07 02:15:17	2020-08-07	12	[{"id_menu":3,"count":1}]	38335	delivery	5	17
112030	2020-08-07 02:15:23	2020-08-07	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	7428	delivery	5	40
112031	2020-08-07 02:17:51	2020-08-07	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	23931	pick-up	0	26
112032	2020-08-07 02:22:15	2020-08-07	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12515	delivery	5	34
112033	2020-08-07 02:23:43	2020-08-07	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	15117	pick-up	0	31
112034	2020-08-07 02:27:49	2020-08-07	9	[{"id_menu":6,"count":1}]	42975	delivery	5	14
112035	2020-08-07 02:29:33	2020-08-07	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	43173	delivery	5	31
112036	2020-08-07 02:30:28	2020-08-07	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2185	pick-up	0	21
112037	2020-08-07 02:30:30	2020-08-07	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11287	delivery	5	31
112038	2020-08-07 02:30:58	2020-08-07	8	[{"id_menu":5,"count":1}]	6457	delivery	5	13
112039	2020-08-07 02:34:14	2020-08-07	14	[{"id_menu":2,"count":1}]	43120	delivery	5	19
112040	2020-08-07 02:37:01	2020-08-07	9	[{"id_menu":7,"count":1}]	25743	delivery	5	14
112041	2020-08-07 02:38:50	2020-08-07	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	43005	pick-up	0	26
112042	2020-08-07 02:43:32	2020-08-07	9	[{"id_menu":7,"count":1}]	43137	delivery	5	14
112043	2020-08-07 02:43:59	2020-08-07	12	[{"id_menu":1,"count":1}]	2659	delivery	5	17
112044	2020-08-07 02:44:07	2020-08-07	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	22252	delivery	5	22
112045	2020-08-07 02:46:17	2020-08-07	8	[{"id_menu":5,"count":1}]	115	pick-up	0	8
112046	2020-08-07 02:46:36	2020-08-07	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	24621	pick-up	0	29
112047	2020-08-07 02:46:59	2020-08-07	17	[{"id_menu":4,"count":1}]	39110	delivery	5	22
112048	2020-08-07 02:47:10	2020-08-07	14	[{"id_menu":2,"count":1}]	7335	delivery	5	19
112049	2020-08-07 02:47:24	2020-08-07	9	[{"id_menu":6,"count":1}]	26974	pick-up	0	9
112050	2020-08-07 02:49:10	2020-08-07	29	[{"id_menu":3,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	42950	delivery	5	34
112051	2020-08-07 02:50:26	2020-08-07	17	[{"id_menu":4,"count":1}]	43163	delivery	5	22
112052	2020-08-07 02:51:15	2020-08-07	9	[{"id_menu":6,"count":1}]	37655	delivery	5	14
112053	2020-08-07 02:51:59	2020-08-07	14	[{"id_menu":2,"count":2}]	35685	delivery	5	19
112054	2020-08-07 02:54:07	2020-08-07	12	[{"id_menu":3,"count":2}]	31318	pick-up	0	12
112055	2020-08-07 02:54:17	2020-08-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	477	pick-up	0	23
112056	2020-08-07 02:54:29	2020-08-07	14	[{"id_menu":2,"count":1}]	24135	delivery	5	19
112057	2020-08-07 02:59:09	2020-08-07	8	[{"id_menu":5,"count":1}]	41680	delivery	5	13
112058	2020-08-07 03:02:36	2020-08-07	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	38250	delivery	5	31
112059	2020-08-07 03:03:36	2020-08-07	17	[{"id_menu":4,"count":1}]	20379	pick-up	0	17
112060	2020-08-07 03:03:52	2020-08-07	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":3}]	14106	delivery	5	26
112061	2020-08-07 03:11:32	2020-08-07	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	209	pick-up	0	29
112062	2020-08-07 03:12:33	2020-08-07	9	[{"id_menu":6,"count":1}]	42977	delivery	5	14
112063	2020-08-07 03:13:15	2020-08-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	30961	delivery	5	22
112064	2020-08-07 03:13:18	2020-08-07	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10568	delivery	5	53
112065	2020-08-07 03:18:54	2020-08-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	43064	delivery	5	28
112066	2020-08-07 03:26:11	2020-08-07	8	[{"id_menu":5,"count":1}]	16878	delivery	5	13
112067	2020-08-07 03:29:33	2020-08-07	9	[{"id_menu":6,"count":1}]	20653	delivery	5	14
112068	2020-08-07 03:30:05	2020-08-07	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	43030	delivery	5	30
112069	2020-08-07 03:35:44	2020-08-07	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":3}]	17969	delivery	5	31
112070	2020-08-07 03:36:58	2020-08-07	9	[{"id_menu":7,"count":1}]	38394	pick-up	0	9
112071	2020-08-07 03:37:53	2020-08-07	12	[{"id_menu":3,"count":1}]	12384	delivery	5	17
112072	2020-08-07 03:38:47	2020-08-07	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	467	pick-up	0	20
112073	2020-08-07 03:39:23	2020-08-07	12	[{"id_menu":1,"count":1}]	36922	delivery	5	17
112074	2020-08-07 03:40:02	2020-08-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	40945	pick-up	0	23
112075	2020-08-07 03:43:02	2020-08-07	9	[{"id_menu":7,"count":1}]	43160	delivery	5	14
112076	2020-08-07 03:43:02	2020-08-07	9	[{"id_menu":6,"count":1}]	14758	delivery	5	14
112077	2020-08-07 03:43:11	2020-08-07	8	[{"id_menu":5,"count":1}]	23524	delivery	5	13
112078	2020-08-07 03:43:21	2020-08-07	8	[{"id_menu":5,"count":1}]	6959	delivery	5	13
112079	2020-08-07 03:43:56	2020-08-07	9	[{"id_menu":7,"count":2}]	43112	delivery	5	14
112080	2020-08-07 03:45:03	2020-08-07	17	[{"id_menu":4,"count":1}]	43011	delivery	5	22
112081	2020-08-07 03:46:07	2020-08-07	12	[{"id_menu":1,"count":1}]	22626	pick-up	0	12
112082	2020-08-07 03:48:20	2020-08-07	9	[{"id_menu":7,"count":1}]	42934	delivery	5	14
112083	2020-08-07 03:49:48	2020-08-07	17	[{"id_menu":4,"count":1}]	32288	delivery	5	22
112084	2020-08-07 03:51:16	2020-08-07	9	[{"id_menu":6,"count":1}]	2771	pick-up	0	9
112085	2020-08-07 03:52:23	2020-08-07	12	[{"id_menu":3,"count":1}]	4790	pick-up	0	12
112086	2020-08-07 03:53:46	2020-08-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8781	delivery	5	23
112087	2020-08-07 03:59:43	2020-08-07	12	[{"id_menu":1,"count":1}]	42953	delivery	5	17
112088	2020-08-07 04:02:17	2020-08-07	8	[{"id_menu":5,"count":1}]	43165	delivery	5	13
112089	2020-08-07 04:10:53	2020-08-07	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	43152	delivery	5	39
112090	2020-08-07 04:12:58	2020-08-07	9	[{"id_menu":6,"count":1}]	24221	delivery	5	14
112091	2020-08-07 04:14:13	2020-08-07	9	[{"id_menu":6,"count":1}]	43076	delivery	5	14
112092	2020-08-07 04:17:38	2020-08-07	12	[{"id_menu":1,"count":1}]	42930	delivery	5	17
112093	2020-08-07 04:18:26	2020-08-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	10276	delivery	5	28
112094	2020-08-07 04:20:10	2020-08-07	17	[{"id_menu":4,"count":1}]	24892	delivery	5	22
112095	2020-08-07 04:21:38	2020-08-07	17	[{"id_menu":4,"count":1}]	2405	delivery	5	22
112096	2020-08-07 04:27:22	2020-08-07	12	[{"id_menu":1,"count":1}]	8637	pick-up	0	12
112097	2020-08-07 04:28:01	2020-08-07	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	10708	pick-up	0	29
112098	2020-08-07 04:30:53	2020-08-07	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21451	delivery	5	39
112099	2020-08-07 04:31:24	2020-08-07	9	[{"id_menu":6,"count":1}]	2845	delivery	5	14
112100	2020-08-07 04:40:24	2020-08-07	9	[{"id_menu":6,"count":1}]	30204	pick-up	0	9
112101	2020-08-07 04:43:45	2020-08-07	9	[{"id_menu":6,"count":1}]	16481	pick-up	0	9
112102	2020-08-07 04:46:15	2020-08-07	12	[{"id_menu":1,"count":1}]	15845	delivery	5	17
112103	2020-08-07 04:46:27	2020-08-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22977	delivery	5	23
112104	2020-08-07 04:47:03	2020-08-07	12	[{"id_menu":3,"count":1}]	43088	delivery	5	17
112105	2020-08-07 04:51:03	2020-08-07	8	[{"id_menu":5,"count":1}]	26188	delivery	5	13
112106	2020-08-07 04:58:41	2020-08-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	195	pick-up	0	17
112107	2020-08-07 05:00:57	2020-08-07	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	34052	pick-up	0	26
112108	2020-08-07 05:02:23	2020-08-07	9	[{"id_menu":7,"count":1}]	30303	delivery	5	14
112109	2020-08-07 05:02:33	2020-08-07	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	14781	delivery	5	28
112110	2020-08-07 05:02:48	2020-08-07	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":3}]	43036	delivery	5	22
112111	2020-08-07 05:04:32	2020-08-07	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	43132	delivery	5	26
112112	2020-08-07 05:04:50	2020-08-07	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	993	delivery	5	43
112113	2020-08-07 05:13:51	2020-08-07	12	[{"id_menu":1,"count":1}]	42341	pick-up	0	12
112114	2020-08-07 05:17:37	2020-08-07	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	26997	delivery	5	42
112115	2020-08-07 05:20:51	2020-08-07	9	[{"id_menu":7,"count":1}]	41736	delivery	5	14
112116	2020-08-07 05:21:07	2020-08-07	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	42961	delivery	5	39
112117	2020-08-07 05:23:02	2020-08-07	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	17127	delivery	5	36
112118	2020-08-07 05:24:46	2020-08-07	9	[{"id_menu":6,"count":1}]	25825	delivery	5	14
112119	2020-08-07 05:25:46	2020-08-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10177	pick-up	0	18
112120	2020-08-07 05:28:51	2020-08-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	36113	delivery	5	22
112121	2020-08-07 05:33:41	2020-08-07	14	[{"id_menu":2,"count":1}]	2740	delivery	5	19
112122	2020-08-07 05:35:52	2020-08-07	17	[{"id_menu":4,"count":1}]	16549	pick-up	0	17
112123	2020-08-07 05:37:08	2020-08-07	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	43170	delivery	5	40
112124	2020-08-07 05:39:07	2020-08-07	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":3}]	27783	delivery	5	26
112125	2020-08-07 05:41:16	2020-08-07	14	[{"id_menu":2,"count":1}]	43033	delivery	5	19
112126	2020-08-07 05:41:37	2020-08-07	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20650	delivery	5	48
112127	2020-08-07 05:43:50	2020-08-07	12	[{"id_menu":3,"count":1}]	21756	delivery	5	17
112128	2020-08-07 05:44:21	2020-08-07	9	[{"id_menu":6,"count":1}]	43079	delivery	5	14
112129	2020-08-07 05:44:58	2020-08-07	9	[{"id_menu":7,"count":1}]	26355	delivery	5	14
112130	2020-08-07 05:46:13	2020-08-07	14	[{"id_menu":2,"count":2}]	26801	delivery	5	19
112131	2020-08-07 05:50:37	2020-08-07	9	[{"id_menu":6,"count":1}]	36562	delivery	5	14
112132	2020-08-07 05:51:09	2020-08-07	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	16603	delivery	5	27
112133	2020-08-07 05:52:35	2020-08-07	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1044	pick-up	0	29
112134	2020-08-07 05:58:18	2020-08-07	17	[{"id_menu":4,"count":1}]	39312	delivery	5	22
112135	2020-08-07 05:58:27	2020-08-07	9	[{"id_menu":6,"count":1}]	23340	delivery	5	14
112136	2020-08-07 06:03:00	2020-08-07	9	[{"id_menu":7,"count":1}]	11923	delivery	5	14
112137	2020-08-07 06:04:04	2020-08-07	12	[{"id_menu":3,"count":1}]	33619	delivery	5	17
112138	2020-08-07 06:07:39	2020-08-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43008	pick-up	0	18
112139	2020-08-07 06:08:38	2020-08-07	17	[{"id_menu":4,"count":1}]	19664	delivery	5	22
112140	2020-08-07 06:08:54	2020-08-07	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	42986	delivery	5	22
112141	2020-08-07 06:09:15	2020-08-07	9	[{"id_menu":7,"count":2}]	38578	delivery	5	14
112142	2020-08-07 06:09:23	2020-08-07	9	[{"id_menu":6,"count":1}]	43075	delivery	5	14
112143	2020-08-07 06:09:54	2020-08-07	17	[{"id_menu":5,"count":3},{"id_menu":6,"count":1}]	26486	delivery	5	22
112144	2020-08-07 06:09:54	2020-08-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	6765	delivery	5	23
112145	2020-08-07 06:10:21	2020-08-07	12	[{"id_menu":1,"count":1}]	43083	delivery	5	17
112146	2020-08-07 06:14:56	2020-08-07	9	[{"id_menu":6,"count":2}]	42951	pick-up	0	9
112147	2020-08-07 06:27:30	2020-08-07	17	[{"id_menu":4,"count":1}]	15459	delivery	5	22
112148	2020-08-07 06:33:43	2020-08-07	12	[{"id_menu":1,"count":1}]	43057	pick-up	0	12
112149	2020-08-07 06:34:19	2020-08-07	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	42936	delivery	5	38
112150	2020-08-07 06:34:29	2020-08-07	9	[{"id_menu":6,"count":1}]	950	delivery	5	14
112151	2020-08-07 06:34:58	2020-08-07	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	19758	delivery	5	31
112152	2020-08-07 06:35:36	2020-08-07	12	[{"id_menu":1,"count":1}]	17067	delivery	5	17
112153	2020-08-07 06:36:54	2020-08-07	14	[{"id_menu":2,"count":1}]	74	pick-up	0	14
112154	2020-08-07 06:42:12	2020-08-07	14	[{"id_menu":2,"count":1}]	1140	pick-up	0	14
112155	2020-08-07 06:45:55	2020-08-07	12	[{"id_menu":1,"count":1}]	2418	delivery	5	17
112156	2020-08-07 06:49:03	2020-08-07	17	[{"id_menu":4,"count":1}]	28249	delivery	5	22
112157	2020-08-07 06:49:41	2020-08-07	12	[{"id_menu":3,"count":1}]	9124	delivery	5	17
112158	2020-08-07 06:52:00	2020-08-07	12	[{"id_menu":1,"count":1}]	29438	delivery	5	17
112159	2020-08-07 06:53:05	2020-08-07	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	806	pick-up	0	30
112160	2020-08-07 06:56:48	2020-08-07	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	42883	delivery	5	43
112161	2020-08-07 06:57:54	2020-08-07	12	[{"id_menu":1,"count":1}]	140	pick-up	0	12
112162	2020-08-07 07:02:52	2020-08-07	9	[{"id_menu":6,"count":1}]	30122	delivery	5	14
112163	2020-08-07 07:09:31	2020-08-07	12	[{"id_menu":1,"count":1}]	37533	pick-up	0	12
112164	2020-08-07 07:10:20	2020-08-07	9	[{"id_menu":7,"count":1}]	43047	delivery	5	14
112165	2020-08-07 07:10:26	2020-08-07	12	[{"id_menu":3,"count":1}]	20503	pick-up	0	12
112166	2020-08-07 07:10:45	2020-08-07	9	[{"id_menu":7,"count":1}]	34111	delivery	5	14
112167	2020-08-07 07:12:28	2020-08-07	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	16128	delivery	5	34
112168	2020-08-07 07:13:40	2020-08-07	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	43051	delivery	5	31
112169	2020-08-07 07:14:17	2020-08-07	9	[{"id_menu":7,"count":1}]	43169	delivery	5	14
112170	2020-08-07 07:16:02	2020-08-07	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	16538	delivery	5	42
112171	2020-08-07 07:16:22	2020-08-07	9	[{"id_menu":6,"count":3}]	8423	delivery	5	14
112172	2020-08-07 07:18:40	2020-08-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	43164	delivery	5	28
112173	2020-08-07 07:20:47	2020-08-07	8	[{"id_menu":5,"count":1}]	16753	pick-up	0	8
112174	2020-08-07 07:25:14	2020-08-07	9	[{"id_menu":6,"count":1}]	1905	pick-up	0	9
112175	2020-08-07 07:26:33	2020-08-07	9	[{"id_menu":6,"count":1}]	43095	delivery	5	14
112176	2020-08-07 07:29:28	2020-08-07	12	[{"id_menu":3,"count":1}]	21509	pick-up	0	12
112177	2020-08-07 07:29:55	2020-08-07	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	19624	pick-up	0	20
112178	2020-08-07 07:31:10	2020-08-07	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29111	delivery	5	49
112179	2020-08-07 07:33:55	2020-08-07	14	[{"id_menu":2,"count":1}]	1657	pick-up	0	14
112180	2020-08-07 07:35:01	2020-08-07	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7151	delivery	5	43
112181	2020-08-07 07:37:25	2020-08-07	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	42940	delivery	5	34
112182	2020-08-07 07:37:47	2020-08-07	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	24018	pick-up	0	20
112183	2020-08-07 07:39:19	2020-08-07	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	42957	delivery	5	31
112184	2020-08-07 07:42:45	2020-08-07	14	[{"id_menu":2,"count":1}]	43125	delivery	5	19
112185	2020-08-07 07:44:27	2020-08-07	14	[{"id_menu":2,"count":2}]	35501	pick-up	0	14
112186	2020-08-07 07:49:49	2020-08-07	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	25015	pick-up	0	22
112187	2020-08-07 07:50:22	2020-08-07	9	[{"id_menu":7,"count":1}]	12139	delivery	5	14
112188	2020-08-07 07:52:23	2020-08-07	9	[{"id_menu":7,"count":1}]	29822	delivery	5	14
112189	2020-08-07 07:52:38	2020-08-07	9	[{"id_menu":6,"count":1}]	19019	delivery	5	14
112190	2020-08-07 07:52:45	2020-08-07	9	[{"id_menu":6,"count":1}]	39095	delivery	5	14
112191	2020-08-07 07:55:16	2020-08-07	9	[{"id_menu":6,"count":2}]	42929	delivery	5	14
112192	2020-08-07 07:57:50	2020-08-07	9	[{"id_menu":6,"count":1}]	5287	delivery	5	14
112193	2020-08-07 07:57:54	2020-08-07	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	673	pick-up	0	26
112194	2020-08-07 07:59:34	2020-08-07	9	[{"id_menu":7,"count":1}]	43080	delivery	5	14
112195	2020-08-07 08:01:39	2020-08-07	9	[{"id_menu":6,"count":1}]	13697	delivery	5	14
112196	2020-08-07 08:02:32	2020-08-07	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	32044	delivery	5	40
112197	2020-08-07 08:03:29	2020-08-07	9	[{"id_menu":6,"count":1}]	32867	delivery	5	14
112198	2020-08-07 08:04:53	2020-08-07	9	[{"id_menu":7,"count":1}]	43142	delivery	5	14
112199	2020-08-07 08:05:40	2020-08-07	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	43058	delivery	5	42
112200	2020-08-07 08:06:25	2020-08-07	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	18271	delivery	5	48
112201	2020-08-07 08:07:41	2020-08-07	9	[{"id_menu":7,"count":1}]	8287	delivery	5	14
112202	2020-08-07 08:08:52	2020-08-07	17	[{"id_menu":4,"count":1}]	26303	delivery	5	22
112203	2020-08-07 08:11:29	2020-08-07	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41749	delivery	5	54
112204	2020-08-07 08:12:00	2020-08-07	14	[{"id_menu":2,"count":1}]	43063	pick-up	0	14
112205	2020-08-07 08:15:28	2020-08-07	9	[{"id_menu":7,"count":1}]	43155	delivery	5	14
112206	2020-08-07 08:17:37	2020-08-07	9	[{"id_menu":6,"count":1}]	33376	delivery	5	14
112207	2020-08-07 08:18:22	2020-08-07	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	822	pick-up	0	24
112208	2020-08-07 08:19:12	2020-08-07	17	[{"id_menu":4,"count":1}]	43105	delivery	5	22
112209	2020-08-07 08:23:09	2020-08-07	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	43154	delivery	5	22
112210	2020-08-07 08:25:55	2020-08-07	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	43122	delivery	5	43
112211	2020-08-07 08:29:27	2020-08-07	9	[{"id_menu":7,"count":1}]	42952	delivery	5	14
112212	2020-08-07 08:32:04	2020-08-07	17	[{"id_menu":4,"count":1}]	5961	delivery	5	22
112213	2020-08-07 08:33:24	2020-08-07	9	[{"id_menu":7,"count":1}]	36682	delivery	5	14
112214	2020-08-07 08:34:13	2020-08-07	9	[{"id_menu":7,"count":1}]	24682	delivery	5	14
112215	2020-08-07 08:35:11	2020-08-07	12	[{"id_menu":3,"count":2}]	24697	delivery	5	17
112216	2020-08-07 08:36:34	2020-08-07	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29866	delivery	5	39
112217	2020-08-07 08:37:25	2020-08-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9600	delivery	5	28
112218	2020-08-07 08:38:36	2020-08-07	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4451	pick-up	0	46
112219	2020-08-07 08:41:05	2020-08-07	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	43026	delivery	5	26
112220	2020-08-07 08:41:57	2020-08-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	28574	delivery	5	28
112221	2020-08-07 08:44:01	2020-08-07	8	[{"id_menu":5,"count":1}]	34196	delivery	5	13
112222	2020-08-07 08:45:20	2020-08-07	12	[{"id_menu":3,"count":1}]	1649	delivery	5	17
112223	2020-08-07 08:50:40	2020-08-07	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	22007	delivery	5	26
112224	2020-08-07 08:51:12	2020-08-07	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	34551	pick-up	0	38
112225	2020-08-07 08:51:26	2020-08-07	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	30391	pick-up	0	40
112226	2020-08-07 08:52:26	2020-08-07	14	[{"id_menu":2,"count":1}]	38807	delivery	5	19
112227	2020-08-07 08:53:58	2020-08-07	9	[{"id_menu":7,"count":1}]	42007	delivery	5	14
112228	2020-08-07 08:54:59	2020-08-07	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	43039	delivery	5	40
112229	2020-08-07 08:55:07	2020-08-07	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	20136	pick-up	0	29
112230	2020-08-07 08:55:12	2020-08-07	9	[{"id_menu":7,"count":1}]	8845	delivery	5	14
112231	2020-08-07 08:55:26	2020-08-07	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29097	delivery	5	51
112232	2020-08-07 08:59:53	2020-08-07	9	[{"id_menu":7,"count":1}]	11138	delivery	5	14
112233	2020-08-07 09:02:06	2020-08-07	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	43162	delivery	5	30
112234	2020-08-07 09:08:30	2020-08-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	42985	pick-up	0	23
112235	2020-08-07 09:08:46	2020-08-07	17	[{"id_menu":4,"count":1}]	14662	delivery	5	22
112236	2020-08-07 09:10:41	2020-08-07	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	43168	delivery	5	42
112237	2020-08-07 09:11:38	2020-08-07	14	[{"id_menu":2,"count":1}]	30393	delivery	5	19
112238	2020-08-07 09:13:40	2020-08-07	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	43150	delivery	5	43
112239	2020-08-07 09:14:40	2020-08-07	9	[{"id_menu":6,"count":1}]	43138	delivery	5	14
112240	2020-08-07 09:16:11	2020-08-07	17	[{"id_menu":4,"count":1}]	10880	delivery	5	22
112241	2020-08-07 09:16:22	2020-08-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41443	delivery	5	23
112242	2020-08-07 09:18:24	2020-08-07	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	20970	delivery	5	45
112243	2020-08-07 09:21:32	2020-08-07	12	[{"id_menu":1,"count":1}]	42965	delivery	5	17
112244	2020-08-07 09:21:52	2020-08-07	12	[{"id_menu":1,"count":1}]	40393	pick-up	0	12
112245	2020-08-07 09:23:29	2020-08-07	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	7510	pick-up	0	21
112246	2020-08-07 09:23:41	2020-08-07	9	[{"id_menu":6,"count":1}]	43078	delivery	5	14
112247	2020-08-07 09:24:36	2020-08-07	14	[{"id_menu":2,"count":1}]	8614	delivery	5	19
112248	2020-08-07 09:24:54	2020-08-07	9	[{"id_menu":6,"count":3}]	17126	delivery	5	14
112249	2020-08-07 09:25:00	2020-08-07	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	4582	delivery	5	27
112250	2020-08-07 09:29:29	2020-08-07	9	[{"id_menu":7,"count":2}]	39557	delivery	5	14
112251	2020-08-07 09:32:36	2020-08-07	9	[{"id_menu":6,"count":1}]	15896	delivery	5	14
112252	2020-08-07 09:32:48	2020-08-07	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	22179	delivery	5	26
112253	2020-08-07 09:35:59	2020-08-07	12	[{"id_menu":1,"count":1}]	6461	delivery	5	17
112254	2020-08-07 09:37:27	2020-08-07	12	[{"id_menu":1,"count":1}]	29453	delivery	5	17
112255	2020-08-07 09:37:28	2020-08-07	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4395	delivery	5	36
112256	2020-08-07 09:37:30	2020-08-07	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	825	delivery	5	36
112257	2020-08-07 09:38:08	2020-08-07	12	[{"id_menu":3,"count":1}]	43099	delivery	5	17
112258	2020-08-07 09:43:45	2020-08-07	12	[{"id_menu":1,"count":1}]	646	pick-up	0	12
112259	2020-08-07 09:43:59	2020-08-07	8	[{"id_menu":5,"count":1}]	12364	delivery	5	13
112260	2020-08-07 09:46:13	2020-08-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20126	delivery	5	23
112261	2020-08-07 09:48:28	2020-08-07	8	[{"id_menu":5,"count":1}]	250	pick-up	0	8
112262	2020-08-07 09:49:19	2020-08-07	12	[{"id_menu":3,"count":1}]	36642	delivery	5	17
112263	2020-08-07 09:54:45	2020-08-07	9	[{"id_menu":6,"count":1}]	43073	delivery	5	14
112264	2020-08-07 09:58:47	2020-08-07	9	[{"id_menu":7,"count":3}]	43014	delivery	5	14
112265	2020-08-07 10:02:15	2020-08-07	12	[{"id_menu":1,"count":1}]	11749	delivery	5	17
112266	2020-08-07 10:04:59	2020-08-07	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	40956	delivery	5	27
112267	2020-08-07 10:05:41	2020-08-07	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37747	delivery	5	35
112268	2020-08-07 10:06:18	2020-08-07	9	[{"id_menu":6,"count":1}]	19965	delivery	5	14
112269	2020-08-07 10:07:31	2020-08-07	9	[{"id_menu":6,"count":1}]	12078	delivery	5	14
112270	2020-08-07 10:08:03	2020-08-07	9	[{"id_menu":7,"count":1}]	19109	delivery	5	14
112271	2020-08-07 10:10:14	2020-08-07	12	[{"id_menu":1,"count":1}]	22519	delivery	5	17
112272	2020-08-07 10:10:53	2020-08-07	8	[{"id_menu":5,"count":1}]	23334	delivery	5	13
112273	2020-08-07 10:11:10	2020-08-07	9	[{"id_menu":7,"count":1}]	11150	delivery	5	14
112274	2020-08-07 10:12:01	2020-08-07	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	43172	delivery	5	36
112275	2020-08-07 10:12:12	2020-08-07	8	[{"id_menu":5,"count":1}]	42964	delivery	5	13
112276	2020-08-07 10:15:46	2020-08-07	14	[{"id_menu":2,"count":1}]	24808	delivery	5	19
112277	2020-08-07 10:22:52	2020-08-07	8	[{"id_menu":5,"count":1}]	20824	delivery	5	13
112278	2020-08-07 10:26:48	2020-08-07	9	[{"id_menu":6,"count":1}]	43176	delivery	5	14
112279	2020-08-07 10:33:35	2020-08-07	12	[{"id_menu":1,"count":1}]	778	pick-up	0	12
112280	2020-08-07 10:36:59	2020-08-07	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	13228	delivery	5	26
112281	2020-08-07 10:39:51	2020-08-07	14	[{"id_menu":2,"count":1}]	42966	delivery	5	19
112282	2020-08-07 10:41:10	2020-08-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	42943	delivery	5	22
112283	2020-08-07 10:41:25	2020-08-07	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	23213	delivery	5	28
112284	2020-08-07 10:44:35	2020-08-07	12	[{"id_menu":1,"count":1}]	43094	delivery	5	17
112285	2020-08-07 10:44:42	2020-08-07	9	[{"id_menu":7,"count":1}]	42967	delivery	5	14
112286	2020-08-07 10:45:32	2020-08-07	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3040	delivery	5	40
112287	2020-08-07 10:48:06	2020-08-07	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	39214	delivery	5	39
112288	2020-08-07 10:53:07	2020-08-07	14	[{"id_menu":2,"count":1}]	2585	pick-up	0	14
112289	2020-08-07 10:53:14	2020-08-07	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1857	delivery	5	45
112290	2020-08-07 10:53:42	2020-08-07	9	[{"id_menu":6,"count":1}]	33173	delivery	5	14
112291	2020-08-07 10:55:17	2020-08-07	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31288	pick-up	0	17
112292	2020-08-07 10:56:28	2020-08-07	9	[{"id_menu":6,"count":1}]	36968	delivery	5	14
112293	2020-08-07 10:58:14	2020-08-07	12	[{"id_menu":1,"count":1}]	23523	pick-up	0	12
112294	2020-08-07 10:59:24	2020-08-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	42815	delivery	5	28
112295	2020-08-07 11:03:45	2020-08-07	9	[{"id_menu":6,"count":1}]	20538	pick-up	0	9
112296	2020-08-07 11:04:54	2020-08-07	9	[{"id_menu":7,"count":1}]	28605	pick-up	0	9
112297	2020-08-07 11:05:56	2020-08-07	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43157	delivery	5	37
112298	2020-08-07 11:06:18	2020-08-07	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	43126	delivery	5	26
112299	2020-08-07 11:06:56	2020-08-07	9	[{"id_menu":7,"count":1}]	2050	pick-up	0	9
112300	2020-08-07 11:11:18	2020-08-07	17	[{"id_menu":4,"count":1}]	26759	delivery	5	22
112301	2020-08-07 11:13:36	2020-08-07	9	[{"id_menu":6,"count":1}]	17493	delivery	5	14
112302	2020-08-07 11:13:57	2020-08-07	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	39805	delivery	5	31
112303	2020-08-07 11:14:53	2020-08-07	9	[{"id_menu":6,"count":1}]	30892	delivery	5	14
112304	2020-08-07 11:15:32	2020-08-07	9	[{"id_menu":6,"count":1}]	41729	pick-up	0	9
112305	2020-08-07 11:20:54	2020-08-07	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4662	delivery	5	31
112306	2020-08-07 11:21:08	2020-08-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	41284	delivery	5	22
112307	2020-08-07 11:21:12	2020-08-07	8	[{"id_menu":5,"count":1}]	22037	delivery	5	13
112308	2020-08-07 11:21:52	2020-08-07	12	[{"id_menu":3,"count":1}]	31596	pick-up	0	12
112309	2020-08-07 11:28:29	2020-08-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	42948	delivery	5	26
112310	2020-08-07 11:31:30	2020-08-07	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	42960	delivery	5	26
112311	2020-08-07 11:32:26	2020-08-07	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	26841	delivery	5	34
112312	2020-08-07 11:32:34	2020-08-07	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	43024	delivery	5	39
112313	2020-08-07 11:32:34	2020-08-07	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	13109	delivery	5	45
112314	2020-08-07 11:33:20	2020-08-07	9	[{"id_menu":6,"count":1}]	42973	delivery	5	14
112315	2020-08-07 11:36:59	2020-08-07	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3006	delivery	5	48
112316	2020-08-07 11:38:03	2020-08-07	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20429	delivery	5	48
112317	2020-08-07 11:38:47	2020-08-07	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	43042	delivery	5	36
112318	2020-08-07 11:40:11	2020-08-07	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	1402	delivery	5	36
112319	2020-08-07 11:45:11	2020-08-07	14	[{"id_menu":2,"count":1}]	9345	delivery	5	19
112320	2020-08-07 11:46:36	2020-08-07	9	[{"id_menu":6,"count":1}]	30818	delivery	5	14
112321	2020-08-07 11:47:17	2020-08-07	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	43090	delivery	5	36
112322	2020-08-07 11:54:09	2020-08-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1457	delivery	5	23
112323	2020-08-07 12:01:01	2020-08-07	8	[{"id_menu":5,"count":1}]	7031	delivery	5	13
112324	2020-08-07 12:02:27	2020-08-07	12	[{"id_menu":3,"count":1}]	33815	delivery	5	17
112325	2020-08-07 12:03:36	2020-08-07	14	[{"id_menu":2,"count":1}]	19791	delivery	5	19
112326	2020-08-07 12:16:25	2020-08-07	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	36586	delivery	5	22
112327	2020-08-07 12:23:01	2020-08-07	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43134	delivery	5	37
112328	2020-08-07 12:24:47	2020-08-07	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	40869	delivery	5	22
112329	2020-08-07 12:24:55	2020-08-07	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	40627	delivery	5	37
112330	2020-08-07 12:25:20	2020-08-07	14	[{"id_menu":2,"count":1}]	15659	delivery	5	19
112331	2020-08-07 12:27:07	2020-08-07	17	[{"id_menu":4,"count":1}]	8517	delivery	5	22
112332	2020-08-07 12:27:18	2020-08-07	17	[{"id_menu":4,"count":1}]	40397	delivery	5	22
112333	2020-08-07 12:30:22	2020-08-07	9	[{"id_menu":6,"count":1}]	24716	delivery	5	14
112334	2020-08-07 12:30:28	2020-08-07	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	31065	delivery	5	45
112335	2020-08-07 12:32:28	2020-08-07	14	[{"id_menu":2,"count":1}]	30512	delivery	5	19
112336	2020-08-07 12:33:51	2020-08-07	9	[{"id_menu":6,"count":1}]	28191	delivery	5	14
112337	2020-08-07 12:38:06	2020-08-07	14	[{"id_menu":2,"count":2}]	42924	delivery	5	19
112338	2020-08-07 12:39:12	2020-08-07	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	43144	delivery	5	22
112339	2020-08-07 12:43:16	2020-08-07	12	[{"id_menu":3,"count":1}]	42996	delivery	5	17
112340	2020-08-07 12:48:24	2020-08-07	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27284	delivery	5	22
112341	2020-08-07 12:54:55	2020-08-07	12	[{"id_menu":3,"count":1}]	22827	delivery	5	17
112342	2020-08-07 12:55:28	2020-08-07	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	37099	pick-up	0	20
112343	2020-08-07 12:56:00	2020-08-07	14	[{"id_menu":2,"count":1}]	31155	delivery	5	19
112344	2020-08-07 13:01:10	2020-08-07	9	[{"id_menu":7,"count":1}]	42981	pick-up	0	9
112345	2020-08-07 13:04:18	2020-08-07	9	[{"id_menu":7,"count":1}]	2259	pick-up	0	9
112346	2020-08-07 13:05:06	2020-08-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	18777	delivery	5	28
112347	2020-08-07 13:06:13	2020-08-07	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	11735	delivery	5	26
112348	2020-08-07 13:10:44	2020-08-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	42968	delivery	5	23
112349	2020-08-07 13:12:25	2020-08-07	12	[{"id_menu":1,"count":1}]	2445	pick-up	0	12
112350	2020-08-07 13:13:02	2020-08-07	12	[{"id_menu":3,"count":1}]	13528	pick-up	0	12
112351	2020-08-07 13:13:13	2020-08-07	8	[{"id_menu":5,"count":1}]	43018	delivery	5	13
112352	2020-08-07 13:15:09	2020-08-07	14	[{"id_menu":2,"count":1}]	9196	delivery	5	19
112353	2020-08-07 13:16:18	2020-08-07	9	[{"id_menu":7,"count":1}]	42926	delivery	5	14
112354	2020-08-07 13:16:56	2020-08-07	8	[{"id_menu":5,"count":1}]	37686	delivery	5	13
112355	2020-08-07 13:18:36	2020-08-07	8	[{"id_menu":5,"count":1}]	35511	delivery	5	13
112356	2020-08-07 13:19:29	2020-08-07	9	[{"id_menu":6,"count":1}]	43117	delivery	5	14
112357	2020-08-07 13:19:55	2020-08-07	12	[{"id_menu":1,"count":1}]	42995	pick-up	0	12
112358	2020-08-07 13:21:40	2020-08-07	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	33546	pick-up	0	22
112359	2020-08-07 13:22:33	2020-08-07	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11623	delivery	5	22
112360	2020-08-07 13:23:35	2020-08-07	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	42931	delivery	5	43
112361	2020-08-07 13:23:36	2020-08-07	8	[{"id_menu":5,"count":1}]	3129	delivery	5	13
112362	2020-08-07 13:28:34	2020-08-07	14	[{"id_menu":2,"count":1}]	42958	delivery	5	19
112363	2020-08-07 13:30:31	2020-08-07	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	39026	delivery	5	40
112364	2020-08-07 13:30:55	2020-08-07	12	[{"id_menu":3,"count":1}]	43086	pick-up	0	12
112365	2020-08-07 13:34:49	2020-08-07	12	[{"id_menu":3,"count":1}]	29518	delivery	5	17
112366	2020-08-07 13:37:53	2020-08-07	17	[{"id_menu":4,"count":1}]	42151	delivery	5	22
112367	2020-08-07 13:38:50	2020-08-07	12	[{"id_menu":1,"count":1}]	23819	delivery	5	17
112368	2020-08-07 13:40:39	2020-08-07	8	[{"id_menu":5,"count":1}]	8747	delivery	5	13
112369	2020-08-07 13:41:00	2020-08-07	8	[{"id_menu":5,"count":2}]	41191	delivery	5	13
112370	2020-08-07 13:42:38	2020-08-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43116	delivery	5	23
112371	2020-08-07 13:43:59	2020-08-07	8	[{"id_menu":5,"count":1}]	42976	delivery	5	13
112372	2020-08-07 13:46:17	2020-08-07	17	[{"id_menu":4,"count":1}]	19449	delivery	5	22
112373	2020-08-07 13:51:20	2020-08-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	43153	delivery	5	26
112374	2020-08-07 13:52:43	2020-08-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5428	delivery	5	22
112375	2020-08-07 13:54:23	2020-08-07	17	[{"id_menu":4,"count":1}]	42971	delivery	5	22
112376	2020-08-07 13:55:25	2020-08-07	14	[{"id_menu":2,"count":1}]	43127	delivery	5	19
112377	2020-08-07 13:57:31	2020-08-07	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	26043	delivery	5	39
112378	2020-08-07 13:58:11	2020-08-07	9	[{"id_menu":7,"count":1}]	43146	delivery	5	14
112379	2020-08-07 13:58:30	2020-08-07	9	[{"id_menu":6,"count":1}]	6396	pick-up	0	9
112380	2020-08-07 13:58:46	2020-08-07	12	[{"id_menu":1,"count":1}]	43109	delivery	5	17
112381	2020-08-07 13:59:44	2020-08-07	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	14519	delivery	5	36
112382	2020-08-07 14:01:55	2020-08-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13445	delivery	5	22
112383	2020-08-07 14:05:07	2020-08-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	27287	delivery	5	22
112384	2020-08-07 14:11:50	2020-08-07	9	[{"id_menu":6,"count":1}]	42884	delivery	5	14
112385	2020-08-07 14:12:02	2020-08-07	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	7273	delivery	5	39
112386	2020-08-07 14:12:05	2020-08-07	8	[{"id_menu":5,"count":1}]	29134	pick-up	0	8
112387	2020-08-07 14:13:19	2020-08-07	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12952	delivery	5	43
112388	2020-08-07 14:18:55	2020-08-07	9	[{"id_menu":7,"count":1}]	21675	delivery	5	14
112389	2020-08-07 14:23:02	2020-08-07	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43038	delivery	5	35
112390	2020-08-07 14:23:16	2020-08-07	9	[{"id_menu":6,"count":1}]	8987	delivery	5	14
112391	2020-08-07 14:26:06	2020-08-07	14	[{"id_menu":2,"count":1}]	19434	pick-up	0	14
112392	2020-08-07 14:32:35	2020-08-07	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	41196	delivery	5	26
112393	2020-08-07 14:32:40	2020-08-07	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	10741	pick-up	0	21
112394	2020-08-07 14:40:30	2020-08-07	8	[{"id_menu":5,"count":1}]	43052	delivery	5	13
112395	2020-08-07 14:40:48	2020-08-07	9	[{"id_menu":7,"count":1}]	43032	delivery	5	14
112396	2020-08-07 14:43:29	2020-08-07	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	12577	pick-up	0	26
112397	2020-08-07 14:43:43	2020-08-07	9	[{"id_menu":7,"count":1}]	43182	delivery	5	14
112398	2020-08-07 14:44:00	2020-08-07	12	[{"id_menu":3,"count":1}]	9322	delivery	5	17
112399	2020-08-07 14:47:15	2020-08-07	12	[{"id_menu":1,"count":1}]	43019	delivery	5	17
112400	2020-08-07 14:47:51	2020-08-07	9	[{"id_menu":6,"count":1}]	18460	delivery	5	14
112401	2020-08-07 14:59:02	2020-08-07	8	[{"id_menu":5,"count":1}]	5637	pick-up	0	8
112402	2020-08-07 15:00:56	2020-08-07	8	[{"id_menu":5,"count":1}]	27565	delivery	5	13
112403	2020-08-07 15:02:02	2020-08-07	14	[{"id_menu":2,"count":1}]	286	pick-up	0	14
112404	2020-08-07 15:03:12	2020-08-07	17	[{"id_menu":4,"count":1}]	6351	pick-up	0	17
112405	2020-08-07 15:05:50	2020-08-07	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	14050	delivery	5	30
112406	2020-08-07 15:07:21	2020-08-07	17	[{"id_menu":4,"count":1}]	370	pick-up	0	17
112407	2020-08-07 15:09:32	2020-08-07	9	[{"id_menu":7,"count":1}]	5596	delivery	5	14
112408	2020-08-07 15:12:18	2020-08-07	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4369	delivery	5	30
112409	2020-08-07 15:14:07	2020-08-07	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	42935	delivery	5	22
112410	2020-08-07 15:18:17	2020-08-07	8	[{"id_menu":5,"count":1}]	12301	delivery	5	13
112411	2020-08-07 15:20:03	2020-08-07	9	[{"id_menu":7,"count":1}]	40275	delivery	5	14
112412	2020-08-07 15:20:41	2020-08-07	8	[{"id_menu":5,"count":1}]	25704	delivery	5	13
112413	2020-08-07 15:20:42	2020-08-07	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18557	pick-up	0	17
112414	2020-08-07 15:20:45	2020-08-07	9	[{"id_menu":7,"count":1}]	32050	delivery	5	14
112415	2020-08-07 15:20:59	2020-08-07	9	[{"id_menu":7,"count":1}]	5335	delivery	5	14
112416	2020-08-07 15:25:09	2020-08-07	9	[{"id_menu":6,"count":1}]	13797	delivery	5	14
112417	2020-08-07 15:26:11	2020-08-07	9	[{"id_menu":7,"count":1}]	32936	delivery	5	14
112418	2020-08-07 15:27:07	2020-08-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	17928	delivery	5	26
112419	2020-08-07 15:35:48	2020-08-07	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43118	delivery	5	40
112420	2020-08-07 15:37:26	2020-08-07	17	[{"id_menu":4,"count":1}]	32015	delivery	5	22
112421	2020-08-07 15:39:07	2020-08-07	8	[{"id_menu":5,"count":1}]	43007	delivery	5	13
112422	2020-08-07 15:40:44	2020-08-07	8	[{"id_menu":5,"count":1}]	7122	delivery	5	13
112423	2020-08-07 15:41:48	2020-08-07	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	33003	delivery	5	34
112424	2020-08-07 15:44:19	2020-08-07	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	43096	pick-up	0	26
112425	2020-08-07 15:47:08	2020-08-07	17	[{"id_menu":4,"count":1}]	4314	delivery	5	22
112426	2020-08-07 15:48:28	2020-08-07	9	[{"id_menu":7,"count":1}]	19749	delivery	5	14
112427	2020-08-07 15:52:49	2020-08-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	43179	pick-up	0	23
112428	2020-08-07 15:53:26	2020-08-07	12	[{"id_menu":3,"count":1}]	43054	delivery	5	17
112429	2020-08-07 15:54:18	2020-08-07	9	[{"id_menu":6,"count":1}]	14472	pick-up	0	9
112430	2020-08-07 15:56:56	2020-08-07	12	[{"id_menu":1,"count":1}]	21395	delivery	5	17
112431	2020-08-07 15:58:48	2020-08-07	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	43085	delivery	5	40
112432	2020-08-07 16:02:11	2020-08-07	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	42937	delivery	5	45
112433	2020-08-07 16:03:35	2020-08-07	14	[{"id_menu":2,"count":1}]	33180	delivery	5	19
112434	2020-08-07 16:14:03	2020-08-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	43177	delivery	5	28
112435	2020-08-07 16:18:27	2020-08-07	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43061	delivery	5	40
112436	2020-08-07 16:21:22	2020-08-07	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	7221	delivery	5	31
112437	2020-08-07 16:26:16	2020-08-07	9	[{"id_menu":6,"count":3}]	42974	delivery	5	14
112438	2020-08-07 16:29:17	2020-08-07	12	[{"id_menu":1,"count":2}]	4550	pick-up	0	12
112439	2020-08-07 16:29:32	2020-08-07	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	32640	delivery	5	36
112440	2020-08-07 16:30:39	2020-08-07	14	[{"id_menu":2,"count":1}]	12615	delivery	5	19
112441	2020-08-07 16:32:14	2020-08-07	8	[{"id_menu":5,"count":1}]	42972	delivery	5	13
112442	2020-08-07 16:32:50	2020-08-07	14	[{"id_menu":2,"count":1}]	39925	delivery	5	19
112443	2020-08-07 16:38:03	2020-08-07	14	[{"id_menu":2,"count":1}]	43104	delivery	5	19
112444	2020-08-07 16:40:29	2020-08-07	14	[{"id_menu":2,"count":1}]	4745	delivery	5	19
112445	2020-08-07 16:43:34	2020-08-07	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	37080	delivery	5	25
112446	2020-08-07 16:43:50	2020-08-07	9	[{"id_menu":6,"count":1}]	38605	delivery	5	14
112447	2020-08-07 16:46:10	2020-08-07	9	[{"id_menu":6,"count":1}]	8665	delivery	5	14
112448	2020-08-07 16:46:54	2020-08-07	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	43069	delivery	5	27
112449	2020-08-07 16:47:44	2020-08-07	12	[{"id_menu":3,"count":1}]	35626	delivery	5	17
112450	2020-08-07 16:49:51	2020-08-07	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	15569	delivery	5	48
112451	2020-08-07 16:52:01	2020-08-07	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34791	delivery	5	31
112452	2020-08-07 16:53:58	2020-08-07	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	12367	pick-up	0	21
112453	2020-08-07 16:54:29	2020-08-07	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	42999	delivery	5	44
112454	2020-08-07 16:55:22	2020-08-07	9	[{"id_menu":6,"count":2}]	32240	delivery	5	14
112455	2020-08-07 16:56:23	2020-08-07	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	7963	pick-up	0	21
112456	2020-08-07 16:56:49	2020-08-07	9	[{"id_menu":7,"count":2}]	7400	delivery	5	14
112457	2020-08-07 16:57:04	2020-08-07	8	[{"id_menu":5,"count":1}]	42925	delivery	5	13
112458	2020-08-07 16:57:04	2020-08-07	9	[{"id_menu":7,"count":3}]	16809	delivery	5	14
112459	2020-08-07 16:58:07	2020-08-07	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	43029	delivery	5	31
112460	2020-08-07 16:58:21	2020-08-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	16925	delivery	5	26
112461	2020-08-07 16:59:18	2020-08-07	9	[{"id_menu":7,"count":1}]	42797	delivery	5	14
112462	2020-08-07 17:01:02	2020-08-07	8	[{"id_menu":5,"count":1}]	22718	delivery	5	13
112463	2020-08-07 17:02:56	2020-08-07	12	[{"id_menu":1,"count":1}]	34036	delivery	5	17
112464	2020-08-07 17:09:06	2020-08-07	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	2110	pick-up	0	24
112465	2020-08-07 17:09:32	2020-08-07	8	[{"id_menu":5,"count":1}]	38944	delivery	5	13
112466	2020-08-07 17:13:06	2020-08-07	14	[{"id_menu":2,"count":1}]	38222	delivery	5	19
112467	2020-08-07 17:14:11	2020-08-07	12	[{"id_menu":1,"count":1}]	226	delivery	5	17
112468	2020-08-07 17:18:31	2020-08-07	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	43044	delivery	5	40
112469	2020-08-07 17:23:45	2020-08-07	12	[{"id_menu":1,"count":1}]	39009	delivery	5	17
112470	2020-08-07 17:24:06	2020-08-07	12	[{"id_menu":1,"count":2}]	6921	delivery	5	17
112471	2020-08-07 17:25:09	2020-08-07	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	531	pick-up	0	29
112472	2020-08-07 17:25:45	2020-08-07	17	[{"id_menu":4,"count":1}]	36998	delivery	5	22
112473	2020-08-07 17:25:55	2020-08-07	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43031	delivery	5	37
112474	2020-08-07 17:26:39	2020-08-07	9	[{"id_menu":6,"count":2}]	31229	delivery	5	14
112475	2020-08-07 17:29:27	2020-08-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	42923	delivery	5	26
112476	2020-08-07 17:31:06	2020-08-07	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	43110	delivery	5	39
112477	2020-08-07 17:32:32	2020-08-07	9	[{"id_menu":7,"count":1}]	8217	delivery	5	14
112478	2020-08-07 17:33:18	2020-08-07	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	43067	delivery	5	39
112479	2020-08-07 17:36:12	2020-08-07	17	[{"id_menu":4,"count":1}]	42933	delivery	5	22
112480	2020-08-07 17:37:05	2020-08-07	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8090	pick-up	0	26
112481	2020-08-07 17:43:26	2020-08-07	14	[{"id_menu":2,"count":1}]	26674	delivery	5	19
112482	2020-08-07 17:44:51	2020-08-07	12	[{"id_menu":1,"count":1}]	37158	pick-up	0	12
112483	2020-08-07 17:45:32	2020-08-07	9	[{"id_menu":6,"count":1}]	25477	delivery	5	14
112484	2020-08-07 17:53:58	2020-08-07	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	43065	delivery	5	31
112485	2020-08-07 17:54:24	2020-08-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	13973	delivery	5	28
112486	2020-08-07 17:55:24	2020-08-07	17	[{"id_menu":4,"count":1}]	5338	pick-up	0	17
112487	2020-08-07 17:57:31	2020-08-07	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	30179	delivery	5	36
112488	2020-08-07 17:59:55	2020-08-07	9	[{"id_menu":7,"count":1}]	39105	delivery	5	14
112489	2020-08-07 18:02:21	2020-08-07	9	[{"id_menu":7,"count":1}]	7119	pick-up	0	9
112490	2020-08-07 18:04:11	2020-08-07	17	[{"id_menu":4,"count":2}]	17784	delivery	5	22
112491	2020-08-07 18:05:01	2020-08-07	12	[{"id_menu":1,"count":1}]	12484	pick-up	0	12
112492	2020-08-07 18:09:54	2020-08-07	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	13819	delivery	5	26
112493	2020-08-07 18:12:00	2020-08-07	17	[{"id_menu":4,"count":1}]	43059	pick-up	0	17
112494	2020-08-07 18:12:21	2020-08-07	17	[{"id_menu":4,"count":1}]	36379	delivery	5	22
112495	2020-08-07 18:16:22	2020-08-07	17	[{"id_menu":4,"count":1}]	39751	delivery	5	22
112496	2020-08-07 18:19:44	2020-08-07	9	[{"id_menu":7,"count":1}]	37812	delivery	5	14
112497	2020-08-07 18:23:47	2020-08-07	12	[{"id_menu":1,"count":1}]	39656	delivery	5	17
112498	2020-08-07 18:25:42	2020-08-07	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	28922	delivery	5	31
112499	2020-08-07 18:27:50	2020-08-07	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	43010	delivery	5	55
112500	2020-08-07 18:30:12	2020-08-07	17	[{"id_menu":4,"count":1}]	4615	pick-up	0	17
112501	2020-08-07 18:30:51	2020-08-07	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	38396	delivery	5	27
112502	2020-08-07 18:32:02	2020-08-07	9	[{"id_menu":7,"count":1}]	42956	delivery	5	14
112503	2020-08-07 18:35:26	2020-08-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	42994	delivery	5	26
112504	2020-08-07 18:37:22	2020-08-07	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	6614	delivery	5	45
112505	2020-08-07 18:40:35	2020-08-07	17	[{"id_menu":4,"count":1}]	13399	delivery	5	22
112506	2020-08-07 18:46:42	2020-08-07	9	[{"id_menu":6,"count":1}]	9294	delivery	5	14
112507	2020-08-07 18:47:10	2020-08-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	42954	delivery	5	28
112508	2020-08-07 18:47:54	2020-08-07	8	[{"id_menu":5,"count":1}]	42947	delivery	5	13
112509	2020-08-07 18:50:54	2020-08-07	9	[{"id_menu":6,"count":1}]	39255	pick-up	0	9
112510	2020-08-07 18:54:05	2020-08-07	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	28053	delivery	5	25
112511	2020-08-07 18:55:03	2020-08-07	14	[{"id_menu":2,"count":1}]	27618	delivery	5	19
112512	2020-08-07 18:55:17	2020-08-07	14	[{"id_menu":2,"count":1}]	7798	delivery	5	19
112513	2020-08-07 18:55:23	2020-08-07	8	[{"id_menu":5,"count":1}]	38145	delivery	5	13
112514	2020-08-07 18:58:33	2020-08-07	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32533	delivery	5	46
112515	2020-08-07 18:59:03	2020-08-07	12	[{"id_menu":1,"count":1}]	19821	delivery	5	17
112516	2020-08-07 18:59:33	2020-08-07	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	43006	delivery	5	22
112517	2020-08-07 19:00:43	2020-08-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43040	delivery	5	23
112518	2020-08-07 19:05:11	2020-08-07	12	[{"id_menu":1,"count":1}]	26717	delivery	5	17
112519	2020-08-07 19:08:19	2020-08-07	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	43066	delivery	5	43
112520	2020-08-07 19:10:17	2020-08-07	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	42944	delivery	5	45
112521	2020-08-07 19:17:09	2020-08-07	9	[{"id_menu":7,"count":1}]	8944	delivery	5	14
112522	2020-08-07 19:19:05	2020-08-07	9	[{"id_menu":6,"count":1}]	12670	delivery	5	14
112523	2020-08-07 19:22:02	2020-08-07	9	[{"id_menu":7,"count":1}]	3931	pick-up	0	9
112524	2020-08-07 19:26:46	2020-08-07	9	[{"id_menu":6,"count":1}]	11998	delivery	5	14
112525	2020-08-07 19:28:21	2020-08-07	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	938	delivery	5	39
112526	2020-08-07 19:28:22	2020-08-07	9	[{"id_menu":6,"count":1}]	43136	delivery	5	14
112527	2020-08-07 19:28:22	2020-08-07	9	[{"id_menu":6,"count":1}]	21493	delivery	5	14
112528	2020-08-07 19:28:48	2020-08-07	8	[{"id_menu":5,"count":1}]	43000	delivery	5	13
112529	2020-08-07 19:29:55	2020-08-07	17	[{"id_menu":4,"count":1}]	2616	delivery	5	22
112530	2020-08-07 19:34:16	2020-08-07	17	[{"id_menu":4,"count":1}]	42980	delivery	5	22
112531	2020-08-07 19:35:10	2020-08-07	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	22056	delivery	5	42
112532	2020-08-07 19:36:22	2020-08-07	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	17739	delivery	5	28
112533	2020-08-07 19:37:34	2020-08-07	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	36470	delivery	5	38
112534	2020-08-07 19:39:25	2020-08-07	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	42213	delivery	5	43
112535	2020-08-07 19:39:43	2020-08-07	12	[{"id_menu":3,"count":1}]	14372	delivery	5	17
112536	2020-08-07 19:39:48	2020-08-07	12	[{"id_menu":3,"count":1}]	33094	delivery	5	17
112537	2020-08-07 19:39:51	2020-08-07	9	[{"id_menu":7,"count":1}]	29036	pick-up	0	9
112538	2020-08-07 19:40:42	2020-08-07	9	[{"id_menu":6,"count":1}]	37598	delivery	5	14
112539	2020-08-07 19:40:45	2020-08-07	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	42949	delivery	5	31
112540	2020-08-07 19:41:43	2020-08-07	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	42581	delivery	5	35
112541	2020-08-07 19:45:16	2020-08-07	9	[{"id_menu":6,"count":1}]	40081	delivery	5	14
112542	2020-08-07 19:46:25	2020-08-07	12	[{"id_menu":3,"count":2}]	36299	pick-up	0	12
112543	2020-08-07 19:46:28	2020-08-07	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2657	delivery	5	54
112544	2020-08-07 19:50:28	2020-08-07	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	37933	pick-up	0	24
112545	2020-08-07 19:51:40	2020-08-07	17	[{"id_menu":4,"count":2}]	42941	delivery	5	22
112546	2020-08-07 19:53:25	2020-08-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	30783	delivery	5	28
112547	2020-08-07 19:55:03	2020-08-07	9	[{"id_menu":7,"count":1}]	14836	delivery	5	14
112548	2020-08-07 19:55:05	2020-08-07	8	[{"id_menu":5,"count":1}]	11314	pick-up	0	8
112549	2020-08-07 19:56:20	2020-08-07	9	[{"id_menu":7,"count":2}]	11104	delivery	5	14
112550	2020-08-07 19:56:46	2020-08-07	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	43161	pick-up	0	26
112551	2020-08-07 19:57:23	2020-08-07	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	42987	delivery	5	29
112552	2020-08-07 19:58:30	2020-08-07	9	[{"id_menu":6,"count":1}]	32277	delivery	5	14
112553	2020-08-07 19:59:08	2020-08-07	9	[{"id_menu":7,"count":1}]	16484	delivery	5	14
112554	2020-08-07 19:59:52	2020-08-07	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	35174	delivery	5	36
112555	2020-08-07 20:00:30	2020-08-07	9	[{"id_menu":6,"count":1}]	43074	delivery	5	14
112556	2020-08-07 20:03:26	2020-08-07	8	[{"id_menu":5,"count":1}]	4097	pick-up	0	8
112557	2020-08-07 20:04:44	2020-08-07	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	43143	delivery	5	43
112558	2020-08-07 20:08:49	2020-08-07	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	25775	pick-up	0	29
112559	2020-08-07 20:11:03	2020-08-07	12	[{"id_menu":1,"count":1}]	16834	delivery	5	17
112560	2020-08-07 20:16:42	2020-08-07	9	[{"id_menu":7,"count":1}]	2275	pick-up	0	9
112561	2020-08-07 20:21:03	2020-08-07	9	[{"id_menu":7,"count":1}]	33371	delivery	5	14
112562	2020-08-07 20:22:30	2020-08-07	9	[{"id_menu":7,"count":2}]	32861	delivery	5	14
112563	2020-08-07 20:23:34	2020-08-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13568	delivery	5	23
112564	2020-08-07 20:25:17	2020-08-07	12	[{"id_menu":3,"count":1}]	28942	delivery	5	17
112565	2020-08-07 20:26:21	2020-08-07	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	19668	delivery	5	26
112566	2020-08-07 20:27:17	2020-08-07	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29542	delivery	5	34
112567	2020-08-07 20:29:04	2020-08-07	12	[{"id_menu":3,"count":1}]	10744	delivery	5	17
112568	2020-08-07 20:30:22	2020-08-07	12	[{"id_menu":3,"count":1}]	2407	pick-up	0	12
112569	2020-08-07 20:34:16	2020-08-07	12	[{"id_menu":3,"count":1}]	30660	pick-up	0	12
112570	2020-08-07 20:36:03	2020-08-07	9	[{"id_menu":7,"count":1}]	43027	delivery	5	14
112571	2020-08-07 20:36:13	2020-08-07	8	[{"id_menu":5,"count":1}]	42998	delivery	5	13
112572	2020-08-07 20:36:19	2020-08-07	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":3}]	32178	pick-up	0	31
112573	2020-08-07 20:37:19	2020-08-07	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	9112	pick-up	0	21
112574	2020-08-07 20:40:37	2020-08-07	12	[{"id_menu":1,"count":1}]	3647	pick-up	0	12
112575	2020-08-07 20:43:12	2020-08-07	9	[{"id_menu":7,"count":1}]	43025	delivery	5	14
112576	2020-08-07 20:46:23	2020-08-07	9	[{"id_menu":6,"count":1}]	36358	delivery	5	14
112577	2020-08-07 20:49:05	2020-08-07	9	[{"id_menu":7,"count":1}]	43084	delivery	5	14
112578	2020-08-07 20:51:24	2020-08-07	17	[{"id_menu":4,"count":1}]	42993	delivery	5	22
112579	2020-08-07 20:52:16	2020-08-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3271	delivery	5	28
112580	2020-08-07 20:53:54	2020-08-07	12	[{"id_menu":3,"count":1}]	37388	delivery	5	17
112581	2020-08-07 20:54:37	2020-08-07	9	[{"id_menu":6,"count":1}]	42990	delivery	5	14
112582	2020-08-07 20:55:58	2020-08-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9798	delivery	5	23
112583	2020-08-07 20:57:02	2020-08-07	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	11124	pick-up	0	21
112584	2020-08-07 21:07:15	2020-08-07	8	[{"id_menu":5,"count":1}]	15660	delivery	5	13
112585	2020-08-07 21:12:08	2020-08-07	8	[{"id_menu":5,"count":1}]	35263	delivery	5	13
112586	2020-08-07 21:13:28	2020-08-07	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	24241	delivery	5	31
112587	2020-08-07 21:14:49	2020-08-07	14	[{"id_menu":2,"count":1}]	25685	delivery	5	19
112588	2020-08-07 21:14:51	2020-08-07	12	[{"id_menu":1,"count":1}]	6063	pick-up	0	12
112589	2020-08-07 21:23:40	2020-08-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43020	delivery	5	23
112590	2020-08-07 21:25:45	2020-08-07	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	11260	delivery	5	34
112591	2020-08-07 21:26:14	2020-08-07	17	[{"id_menu":4,"count":1}]	40498	delivery	5	22
112592	2020-08-07 21:27:50	2020-08-07	17	[{"id_menu":4,"count":1}]	41700	pick-up	0	17
112593	2020-08-07 21:29:27	2020-08-07	9	[{"id_menu":7,"count":1}]	18408	delivery	5	14
112594	2020-08-07 21:30:12	2020-08-07	14	[{"id_menu":2,"count":1}]	12043	pick-up	0	14
112595	2020-08-07 21:32:27	2020-08-07	9	[{"id_menu":7,"count":1}]	22030	delivery	5	14
112596	2020-08-07 21:33:26	2020-08-07	9	[{"id_menu":6,"count":1}]	16648	delivery	5	14
112597	2020-08-07 21:33:53	2020-08-07	8	[{"id_menu":5,"count":1}]	31485	delivery	5	13
112598	2020-08-07 21:35:15	2020-08-07	14	[{"id_menu":2,"count":1}]	1769	pick-up	0	14
112599	2020-08-07 21:35:25	2020-08-07	12	[{"id_menu":3,"count":1}]	13716	delivery	5	17
112600	2020-08-07 21:36:10	2020-08-07	17	[{"id_menu":4,"count":1}]	43097	delivery	5	22
112601	2020-08-07 21:39:19	2020-08-07	9	[{"id_menu":6,"count":1}]	20910	pick-up	0	9
112602	2020-08-07 21:41:00	2020-08-07	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	43130	delivery	5	34
112603	2020-08-07 21:45:15	2020-08-07	9	[{"id_menu":6,"count":2}]	779	delivery	5	14
112604	2020-08-07 21:47:23	2020-08-07	9	[{"id_menu":7,"count":2}]	12609	delivery	5	14
112605	2020-08-07 21:47:51	2020-08-07	9	[{"id_menu":6,"count":1}]	19103	delivery	5	14
112606	2020-08-07 21:51:07	2020-08-07	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10336	delivery	5	22
112607	2020-08-07 22:00:01	2020-08-07	12	[{"id_menu":3,"count":1}]	43181	delivery	5	17
112608	2020-08-07 22:01:04	2020-08-07	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	42945	delivery	5	30
112609	2020-08-07 22:03:21	2020-08-07	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12292	delivery	5	39
112610	2020-08-07 22:04:50	2020-08-07	17	[{"id_menu":4,"count":1}]	22804	pick-up	0	17
112611	2020-08-07 22:05:39	2020-08-07	9	[{"id_menu":6,"count":1}]	9632	delivery	5	14
112612	2020-08-07 22:06:35	2020-08-07	8	[{"id_menu":5,"count":1}]	43156	delivery	5	13
112613	2020-08-07 22:08:26	2020-08-07	12	[{"id_menu":3,"count":1}]	26387	delivery	5	17
112614	2020-08-07 22:12:33	2020-08-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	42978	delivery	5	22
112615	2020-08-07 22:13:28	2020-08-07	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	43046	delivery	5	31
112616	2020-08-07 22:14:32	2020-08-07	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	41198	delivery	5	34
112617	2020-08-07 22:15:22	2020-08-07	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	12763	delivery	5	34
112618	2020-08-07 22:16:35	2020-08-07	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	26557	delivery	5	43
112619	2020-08-07 22:17:59	2020-08-07	17	[{"id_menu":4,"count":1}]	22159	delivery	5	22
112620	2020-08-07 22:21:18	2020-08-07	9	[{"id_menu":7,"count":1}]	40183	delivery	5	14
112621	2020-08-07 22:22:21	2020-08-07	8	[{"id_menu":5,"count":1}]	17560	delivery	5	13
112622	2020-08-07 22:23:53	2020-08-07	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	39590	delivery	5	31
112623	2020-08-07 22:24:08	2020-08-07	8	[{"id_menu":5,"count":1}]	11327	delivery	5	13
112624	2020-08-07 22:26:14	2020-08-07	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	43108	delivery	5	46
112625	2020-08-07 22:31:44	2020-08-07	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9440	delivery	5	22
112626	2020-08-07 22:32:38	2020-08-07	12	[{"id_menu":1,"count":1}]	43139	pick-up	0	12
112627	2020-08-07 22:33:05	2020-08-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":3}]	39712	delivery	5	28
112628	2020-08-07 22:33:08	2020-08-07	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	29065	pick-up	0	43
112629	2020-08-07 22:36:14	2020-08-07	9	[{"id_menu":7,"count":1}]	43121	pick-up	0	9
112630	2020-08-07 22:37:09	2020-08-07	9	[{"id_menu":7,"count":1}]	31683	delivery	5	14
112631	2020-08-07 22:37:55	2020-08-07	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38755	delivery	5	31
112632	2020-08-07 22:38:03	2020-08-07	12	[{"id_menu":3,"count":2}]	15926	pick-up	0	12
112633	2020-08-07 22:38:55	2020-08-07	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43071	delivery	5	35
112634	2020-08-07 22:42:49	2020-08-07	14	[{"id_menu":2,"count":1}]	43001	delivery	5	19
112635	2020-08-07 22:43:18	2020-08-07	12	[{"id_menu":3,"count":1}]	5189	pick-up	0	12
112636	2020-08-07 22:45:07	2020-08-07	8	[{"id_menu":5,"count":1}]	43016	pick-up	0	8
112637	2020-08-07 22:46:51	2020-08-07	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	42991	delivery	5	30
112638	2020-08-07 22:48:07	2020-08-07	12	[{"id_menu":1,"count":1}]	17338	pick-up	0	12
112639	2020-08-07 22:49:55	2020-08-07	14	[{"id_menu":2,"count":1}]	43087	pick-up	0	14
112640	2020-08-07 22:50:07	2020-08-07	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	43034	delivery	5	29
112641	2020-08-07 22:50:58	2020-08-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	42984	delivery	5	28
112642	2020-08-07 22:51:56	2020-08-07	8	[{"id_menu":5,"count":2}]	36599	delivery	5	13
112643	2020-08-07 22:56:34	2020-08-07	17	[{"id_menu":4,"count":1}]	19806	delivery	5	22
112644	2020-08-07 22:56:59	2020-08-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	36531	delivery	5	28
112645	2020-08-07 23:00:41	2020-08-07	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10624	delivery	5	35
112646	2020-08-07 23:03:09	2020-08-07	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23716	delivery	5	23
112647	2020-08-07 23:06:22	2020-08-07	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	42970	delivery	5	26
112648	2020-08-07 23:13:11	2020-08-07	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6787	delivery	5	22
112649	2020-08-07 23:18:34	2020-08-07	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	5155	delivery	5	28
112650	2020-08-07 23:21:17	2020-08-07	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	40016	delivery	5	39
112651	2020-08-07 23:22:41	2020-08-07	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	36639	delivery	5	25
112652	2020-08-07 23:26:04	2020-08-07	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	8852	delivery	5	31
112653	2020-08-07 23:27:23	2020-08-07	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	34790	delivery	5	29
112654	2020-08-07 23:29:06	2020-08-07	8	[{"id_menu":5,"count":1}]	42946	delivery	5	13
112655	2020-08-07 23:29:38	2020-08-07	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	43149	delivery	5	31
112656	2020-08-07 23:42:09	2020-08-07	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	43009	delivery	5	28
112657	2020-08-07 23:43:23	2020-08-07	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	42997	delivery	5	34
112658	2020-08-07 23:49:26	2020-08-07	17	[{"id_menu":4,"count":2}]	43106	delivery	5	22
112659	2020-08-07 23:51:40	2020-08-07	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	36942	delivery	5	45
112660	2020-08-07 23:51:52	2020-08-07	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	40954	delivery	5	22
112661	2020-08-07 23:53:21	2020-08-07	9	[{"id_menu":7,"count":1}]	43140	delivery	5	14
112662	2020-08-07 23:57:19	2020-08-07	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16003	delivery	5	35
112663	2020-08-07 23:58:04	2020-08-07	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	32417	pick-up	0	40
112664	2020-08-08 00:01:54	2020-08-08	17	[{"id_menu":4,"count":1}]	43313	delivery	5	22
112665	2020-08-08 00:02:14	2020-08-08	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43415	delivery	5	31
112666	2020-08-08 00:06:33	2020-08-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	12570	delivery	5	22
112667	2020-08-08 00:08:48	2020-08-08	9	[{"id_menu":7,"count":1}]	34260	delivery	5	14
112668	2020-08-08 00:10:28	2020-08-08	9	[{"id_menu":6,"count":1}]	9781	delivery	5	14
112669	2020-08-08 00:11:26	2020-08-08	9	[{"id_menu":7,"count":1}]	43214	delivery	5	14
112670	2020-08-08 00:12:41	2020-08-08	8	[{"id_menu":5,"count":1}]	8399	delivery	5	13
112671	2020-08-08 00:14:53	2020-08-08	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	43291	delivery	5	43
112672	2020-08-08 00:15:13	2020-08-08	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	19109	delivery	5	45
112673	2020-08-08 00:16:06	2020-08-08	12	[{"id_menu":3,"count":1}]	13996	pick-up	0	12
112674	2020-08-08 00:17:58	2020-08-08	8	[{"id_menu":5,"count":1}]	43386	delivery	5	13
112675	2020-08-08 00:18:00	2020-08-08	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	23585	delivery	5	26
112676	2020-08-08 00:19:40	2020-08-08	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	26697	delivery	5	23
112677	2020-08-08 00:23:46	2020-08-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	35298	delivery	5	23
112678	2020-08-08 00:27:05	2020-08-08	8	[{"id_menu":5,"count":1}]	16813	pick-up	0	8
112679	2020-08-08 00:28:07	2020-08-08	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	5345	delivery	5	25
112680	2020-08-08 00:29:26	2020-08-08	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	18509	delivery	5	40
112681	2020-08-08 00:32:09	2020-08-08	9	[{"id_menu":6,"count":1}]	35554	delivery	5	14
112682	2020-08-08 00:34:58	2020-08-08	17	[{"id_menu":4,"count":1}]	43250	pick-up	0	17
112683	2020-08-08 00:36:21	2020-08-08	14	[{"id_menu":2,"count":1}]	43360	delivery	5	19
112684	2020-08-08 00:40:00	2020-08-08	8	[{"id_menu":5,"count":1}]	12967	delivery	5	13
112685	2020-08-08 00:40:15	2020-08-08	8	[{"id_menu":5,"count":1}]	27556	delivery	5	13
112686	2020-08-08 00:40:22	2020-08-08	8	[{"id_menu":5,"count":1}]	43246	delivery	5	13
112687	2020-08-08 00:41:55	2020-08-08	12	[{"id_menu":1,"count":1}]	8286	pick-up	0	12
112688	2020-08-08 00:47:44	2020-08-08	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	7714	delivery	5	34
112689	2020-08-08 00:49:31	2020-08-08	12	[{"id_menu":3,"count":1}]	6895	delivery	5	17
112690	2020-08-08 00:51:21	2020-08-08	9	[{"id_menu":6,"count":1}]	26963	delivery	5	14
112691	2020-08-08 00:53:33	2020-08-08	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	43244	delivery	5	48
112692	2020-08-08 00:55:42	2020-08-08	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	27389	delivery	5	43
112693	2020-08-08 00:57:44	2020-08-08	9	[{"id_menu":6,"count":1}]	27758	delivery	5	14
112694	2020-08-08 00:58:01	2020-08-08	12	[{"id_menu":1,"count":1}]	12855	delivery	5	17
112695	2020-08-08 00:58:29	2020-08-08	9	[{"id_menu":7,"count":1}]	21462	delivery	5	14
112696	2020-08-08 00:58:49	2020-08-08	12	[{"id_menu":3,"count":1}]	6327	pick-up	0	12
112697	2020-08-08 01:02:06	2020-08-08	14	[{"id_menu":2,"count":1}]	39580	delivery	5	19
112698	2020-08-08 01:02:45	2020-08-08	17	[{"id_menu":4,"count":1}]	15265	pick-up	0	17
112699	2020-08-08 01:08:04	2020-08-08	12	[{"id_menu":1,"count":1}]	12534	pick-up	0	12
112700	2020-08-08 01:13:15	2020-08-08	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	14354	delivery	5	39
112701	2020-08-08 01:13:27	2020-08-08	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9617	delivery	5	48
112702	2020-08-08 01:15:05	2020-08-08	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	29170	delivery	5	45
112703	2020-08-08 01:15:28	2020-08-08	8	[{"id_menu":5,"count":1}]	40338	delivery	5	13
112704	2020-08-08 01:21:21	2020-08-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	29193	delivery	5	23
112705	2020-08-08 01:22:27	2020-08-08	17	[{"id_menu":4,"count":1}]	31661	delivery	5	22
112706	2020-08-08 01:26:12	2020-08-08	14	[{"id_menu":2,"count":1}]	43327	delivery	5	19
112707	2020-08-08 01:28:00	2020-08-08	9	[{"id_menu":7,"count":1}]	43280	delivery	5	14
112708	2020-08-08 01:28:48	2020-08-08	9	[{"id_menu":6,"count":1}]	14743	delivery	5	14
112709	2020-08-08 01:29:41	2020-08-08	17	[{"id_menu":4,"count":1}]	29223	delivery	5	22
112710	2020-08-08 01:29:48	2020-08-08	17	[{"id_menu":4,"count":1}]	9050	delivery	5	22
112711	2020-08-08 01:30:11	2020-08-08	12	[{"id_menu":3,"count":1}]	43240	pick-up	0	12
112712	2020-08-08 01:31:52	2020-08-08	12	[{"id_menu":3,"count":1}]	2679	delivery	5	17
112713	2020-08-08 01:32:40	2020-08-08	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	26683	delivery	5	29
112714	2020-08-08 01:34:24	2020-08-08	14	[{"id_menu":2,"count":1}]	5498	delivery	5	19
112715	2020-08-08 01:37:14	2020-08-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	4982	delivery	5	28
112716	2020-08-08 01:39:08	2020-08-08	14	[{"id_menu":2,"count":1}]	26529	delivery	5	19
112717	2020-08-08 01:40:57	2020-08-08	26	[{"id_menu":4,"count":3},{"id_menu":6,"count":1}]	43391	delivery	5	31
112718	2020-08-08 01:41:41	2020-08-08	8	[{"id_menu":5,"count":1}]	22686	delivery	5	13
112719	2020-08-08 01:45:36	2020-08-08	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	32058	delivery	5	40
112720	2020-08-08 01:45:47	2020-08-08	14	[{"id_menu":2,"count":1}]	43230	pick-up	0	14
112721	2020-08-08 01:48:15	2020-08-08	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	43284	delivery	5	40
112722	2020-08-08 01:50:01	2020-08-08	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17094	delivery	5	35
112723	2020-08-08 01:50:02	2020-08-08	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17599	delivery	5	36
112724	2020-08-08 01:53:43	2020-08-08	9	[{"id_menu":6,"count":1}]	2148	delivery	5	14
112725	2020-08-08 01:54:42	2020-08-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	13156	delivery	5	28
112726	2020-08-08 01:55:26	2020-08-08	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	37253	delivery	5	31
112727	2020-08-08 01:59:42	2020-08-08	12	[{"id_menu":3,"count":1}]	43344	delivery	5	17
112728	2020-08-08 02:04:09	2020-08-08	9	[{"id_menu":6,"count":1}]	13854	delivery	5	14
112729	2020-08-08 02:05:14	2020-08-08	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	7991	delivery	5	29
112730	2020-08-08 02:07:18	2020-08-08	9	[{"id_menu":6,"count":1}]	21448	pick-up	0	9
112731	2020-08-08 02:08:19	2020-08-08	8	[{"id_menu":5,"count":1}]	21184	pick-up	0	8
112732	2020-08-08 02:09:09	2020-08-08	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	23010	delivery	5	27
112733	2020-08-08 02:12:15	2020-08-08	17	[{"id_menu":4,"count":1}]	2377	pick-up	0	17
112734	2020-08-08 02:14:57	2020-08-08	12	[{"id_menu":3,"count":1}]	33377	delivery	5	17
112735	2020-08-08 02:15:50	2020-08-08	9	[{"id_menu":6,"count":2}]	27211	pick-up	0	9
112736	2020-08-08 02:18:00	2020-08-08	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	43373	delivery	5	26
112737	2020-08-08 02:18:40	2020-08-08	14	[{"id_menu":2,"count":1}]	43380	delivery	5	19
112738	2020-08-08 02:20:29	2020-08-08	12	[{"id_menu":1,"count":1}]	9107	pick-up	0	12
112739	2020-08-08 02:22:17	2020-08-08	9	[{"id_menu":7,"count":1}]	43207	pick-up	0	9
112740	2020-08-08 02:24:10	2020-08-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2052	delivery	5	28
112741	2020-08-08 02:26:32	2020-08-08	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7331	pick-up	0	26
112742	2020-08-08 02:28:36	2020-08-08	8	[{"id_menu":5,"count":1}]	43188	delivery	5	13
112743	2020-08-08 02:31:54	2020-08-08	8	[{"id_menu":5,"count":1}]	43206	delivery	5	13
112744	2020-08-08 02:32:40	2020-08-08	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	24593	delivery	5	22
112745	2020-08-08 02:36:58	2020-08-08	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	19869	delivery	5	26
112746	2020-08-08 02:43:05	2020-08-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	43407	delivery	5	22
112747	2020-08-08 02:43:22	2020-08-08	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38323	delivery	5	31
112748	2020-08-08 02:46:14	2020-08-08	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9192	delivery	5	42
112749	2020-08-08 02:47:12	2020-08-08	14	[{"id_menu":2,"count":1}]	2590	pick-up	0	14
112750	2020-08-08 02:50:07	2020-08-08	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	5571	delivery	5	22
112751	2020-08-08 02:51:13	2020-08-08	14	[{"id_menu":2,"count":1}]	43335	delivery	5	19
112752	2020-08-08 02:51:41	2020-08-08	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	43300	delivery	5	27
112753	2020-08-08 02:51:41	2020-08-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	16361	delivery	5	22
112754	2020-08-08 02:53:46	2020-08-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	23671	delivery	5	28
112755	2020-08-08 02:57:00	2020-08-08	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	43363	delivery	5	30
112756	2020-08-08 02:58:32	2020-08-08	12	[{"id_menu":1,"count":1}]	16353	pick-up	0	12
112757	2020-08-08 02:58:55	2020-08-08	9	[{"id_menu":7,"count":1}]	6800	delivery	5	14
112758	2020-08-08 02:59:55	2020-08-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	39627	delivery	5	22
112759	2020-08-08 03:02:11	2020-08-08	9	[{"id_menu":6,"count":1}]	4892	delivery	5	14
112760	2020-08-08 03:02:42	2020-08-08	9	[{"id_menu":7,"count":2}]	22705	delivery	5	14
112761	2020-08-08 03:02:47	2020-08-08	8	[{"id_menu":5,"count":1}]	43432	delivery	5	13
112762	2020-08-08 03:04:34	2020-08-08	8	[{"id_menu":5,"count":1}]	9205	delivery	5	13
112763	2020-08-08 03:08:48	2020-08-08	9	[{"id_menu":7,"count":1}]	25085	delivery	5	14
112764	2020-08-08 03:08:55	2020-08-08	14	[{"id_menu":2,"count":1}]	24221	delivery	5	19
112765	2020-08-08 03:09:02	2020-08-08	55	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	34850	delivery	5	60
112766	2020-08-08 03:09:59	2020-08-08	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	28775	delivery	5	27
112767	2020-08-08 03:16:34	2020-08-08	14	[{"id_menu":2,"count":1}]	42695	delivery	5	19
112768	2020-08-08 03:19:52	2020-08-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	35213	pick-up	0	17
112769	2020-08-08 03:20:00	2020-08-08	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	33716	delivery	5	31
112770	2020-08-08 03:23:57	2020-08-08	14	[{"id_menu":2,"count":1}]	43332	delivery	5	19
112771	2020-08-08 03:25:48	2020-08-08	9	[{"id_menu":6,"count":1}]	10810	delivery	5	14
112772	2020-08-08 03:26:26	2020-08-08	14	[{"id_menu":2,"count":1}]	1127	pick-up	0	14
112773	2020-08-08 03:30:48	2020-08-08	12	[{"id_menu":1,"count":1}]	43414	delivery	5	17
112774	2020-08-08 03:31:20	2020-08-08	9	[{"id_menu":6,"count":1}]	43433	delivery	5	14
112775	2020-08-08 03:43:05	2020-08-08	9	[{"id_menu":7,"count":1}]	43191	delivery	5	14
112776	2020-08-08 03:44:02	2020-08-08	12	[{"id_menu":3,"count":1}]	15552	pick-up	0	12
112777	2020-08-08 03:44:12	2020-08-08	9	[{"id_menu":7,"count":1}]	12648	pick-up	0	9
112778	2020-08-08 03:50:00	2020-08-08	9	[{"id_menu":7,"count":1}]	25533	delivery	5	14
112779	2020-08-08 03:50:42	2020-08-08	9	[{"id_menu":6,"count":1}]	16367	delivery	5	14
112780	2020-08-08 03:54:00	2020-08-08	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	43350	delivery	5	39
112781	2020-08-08 03:55:14	2020-08-08	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	43351	delivery	5	22
112782	2020-08-08 03:56:34	2020-08-08	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	30230	delivery	5	43
112783	2020-08-08 03:56:56	2020-08-08	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	43406	delivery	5	23
112784	2020-08-08 03:58:45	2020-08-08	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	7217	delivery	5	34
112785	2020-08-08 03:59:11	2020-08-08	9	[{"id_menu":7,"count":1}]	21004	delivery	5	14
112786	2020-08-08 04:00:21	2020-08-08	14	[{"id_menu":2,"count":1}]	28176	delivery	5	19
112787	2020-08-08 04:08:07	2020-08-08	12	[{"id_menu":3,"count":1}]	43297	delivery	5	17
112788	2020-08-08 04:08:18	2020-08-08	9	[{"id_menu":6,"count":1}]	33331	delivery	5	14
112789	2020-08-08 04:08:51	2020-08-08	12	[{"id_menu":3,"count":1}]	25165	delivery	5	17
112790	2020-08-08 04:10:14	2020-08-08	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":2}]	8733	delivery	5	26
112791	2020-08-08 04:10:43	2020-08-08	9	[{"id_menu":7,"count":1}]	30710	delivery	5	14
112792	2020-08-08 04:13:11	2020-08-08	9	[{"id_menu":7,"count":1}]	401	pick-up	0	9
112793	2020-08-08 04:13:57	2020-08-08	14	[{"id_menu":2,"count":1}]	33582	delivery	5	19
112794	2020-08-08 04:14:11	2020-08-08	14	[{"id_menu":2,"count":1}]	5064	pick-up	0	14
112795	2020-08-08 04:14:51	2020-08-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	37272	delivery	5	22
112796	2020-08-08 04:15:16	2020-08-08	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	19363	delivery	5	34
112797	2020-08-08 04:16:24	2020-08-08	9	[{"id_menu":7,"count":1}]	41556	delivery	5	14
112798	2020-08-08 04:16:31	2020-08-08	12	[{"id_menu":3,"count":1}]	36361	delivery	5	17
112799	2020-08-08 04:17:07	2020-08-08	9	[{"id_menu":7,"count":1}]	10791	delivery	5	14
112800	2020-08-08 04:18:17	2020-08-08	12	[{"id_menu":1,"count":1}]	43248	pick-up	0	12
112801	2020-08-08 04:22:59	2020-08-08	9	[{"id_menu":6,"count":1}]	14461	delivery	5	14
112802	2020-08-08 04:23:55	2020-08-08	9	[{"id_menu":6,"count":1}]	22422	pick-up	0	9
112803	2020-08-08 04:24:10	2020-08-08	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	6559	delivery	5	27
112804	2020-08-08 04:24:27	2020-08-08	14	[{"id_menu":2,"count":1}]	39283	pick-up	0	14
112805	2020-08-08 04:25:47	2020-08-08	12	[{"id_menu":1,"count":1}]	35300	pick-up	0	12
112806	2020-08-08 04:26:36	2020-08-08	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	43416	delivery	5	45
112807	2020-08-08 04:26:37	2020-08-08	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	24718	pick-up	0	30
112808	2020-08-08 04:26:48	2020-08-08	17	[{"id_menu":4,"count":1}]	21075	delivery	5	22
112809	2020-08-08 04:31:08	2020-08-08	17	[{"id_menu":4,"count":1}]	41584	delivery	5	22
112810	2020-08-08 04:31:54	2020-08-08	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	38190	delivery	5	48
112811	2020-08-08 04:34:07	2020-08-08	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	26628	delivery	5	31
112812	2020-08-08 04:34:56	2020-08-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43362	delivery	5	23
112813	2020-08-08 04:37:14	2020-08-08	12	[{"id_menu":3,"count":1}]	12528	delivery	5	17
112814	2020-08-08 04:38:58	2020-08-08	17	[{"id_menu":4,"count":1}]	9079	pick-up	0	17
112815	2020-08-08 04:39:11	2020-08-08	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	43320	delivery	5	34
112816	2020-08-08 04:42:19	2020-08-08	9	[{"id_menu":7,"count":1}]	43276	delivery	5	14
112817	2020-08-08 04:43:01	2020-08-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	30269	delivery	5	28
112818	2020-08-08 04:43:10	2020-08-08	8	[{"id_menu":5,"count":1}]	35033	delivery	5	13
112819	2020-08-08 04:44:01	2020-08-08	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	43346	delivery	5	25
112820	2020-08-08 04:44:08	2020-08-08	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	11175	delivery	5	40
112821	2020-08-08 04:47:57	2020-08-08	14	[{"id_menu":2,"count":1}]	11686	pick-up	0	14
112822	2020-08-08 04:48:13	2020-08-08	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	43261	pick-up	0	34
112823	2020-08-08 04:48:36	2020-08-08	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	28484	delivery	5	40
112824	2020-08-08 04:50:09	2020-08-08	14	[{"id_menu":2,"count":1}]	14558	delivery	5	19
112825	2020-08-08 04:51:58	2020-08-08	12	[{"id_menu":1,"count":2}]	30233	delivery	5	17
112826	2020-08-08 04:55:30	2020-08-08	12	[{"id_menu":1,"count":1}]	372	pick-up	0	12
112827	2020-08-08 04:57:03	2020-08-08	14	[{"id_menu":2,"count":1}]	67	delivery	5	19
112828	2020-08-08 04:57:10	2020-08-08	9	[{"id_menu":6,"count":2}]	23457	delivery	5	14
112829	2020-08-08 04:59:50	2020-08-08	9	[{"id_menu":6,"count":1}]	43349	delivery	5	14
112830	2020-08-08 04:59:52	2020-08-08	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	43418	pick-up	0	23
112831	2020-08-08 05:01:38	2020-08-08	8	[{"id_menu":5,"count":1}]	25907	delivery	5	13
112832	2020-08-08 05:02:14	2020-08-08	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1507	delivery	5	31
112833	2020-08-08 05:04:35	2020-08-08	8	[{"id_menu":5,"count":1}]	4765	pick-up	0	8
112834	2020-08-08 05:07:38	2020-08-08	12	[{"id_menu":3,"count":2}]	4714	delivery	5	17
112835	2020-08-08 05:08:16	2020-08-08	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	32120	delivery	5	22
112836	2020-08-08 05:09:42	2020-08-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	43254	delivery	5	22
112837	2020-08-08 05:10:26	2020-08-08	9	[{"id_menu":7,"count":1}]	43305	delivery	5	14
112838	2020-08-08 05:10:27	2020-08-08	12	[{"id_menu":1,"count":1}]	27869	delivery	5	17
112839	2020-08-08 05:10:34	2020-08-08	9	[{"id_menu":6,"count":1}]	32753	delivery	5	14
112840	2020-08-08 05:11:57	2020-08-08	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	30929	pick-up	0	26
112841	2020-08-08 05:13:04	2020-08-08	12	[{"id_menu":1,"count":1}]	17691	delivery	5	17
112842	2020-08-08 05:16:15	2020-08-08	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	12820	delivery	5	40
112843	2020-08-08 05:18:40	2020-08-08	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	3773	delivery	5	28
112844	2020-08-08 05:18:52	2020-08-08	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	43262	delivery	5	31
112845	2020-08-08 05:19:04	2020-08-08	12	[{"id_menu":1,"count":1}]	2275	delivery	5	17
112846	2020-08-08 05:21:34	2020-08-08	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	541	pick-up	0	31
112847	2020-08-08 05:21:49	2020-08-08	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	43285	delivery	5	36
112848	2020-08-08 05:23:02	2020-08-08	12	[{"id_menu":1,"count":2}]	2618	pick-up	0	12
112849	2020-08-08 05:25:11	2020-08-08	9	[{"id_menu":6,"count":1}]	14902	delivery	5	14
112850	2020-08-08 05:25:54	2020-08-08	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	1813	pick-up	0	20
112851	2020-08-08 05:30:41	2020-08-08	9	[{"id_menu":7,"count":1}]	8248	delivery	5	14
112852	2020-08-08 05:34:15	2020-08-08	17	[{"id_menu":4,"count":1}]	33427	pick-up	0	17
112853	2020-08-08 05:43:21	2020-08-08	9	[{"id_menu":6,"count":1}]	24809	delivery	5	14
112854	2020-08-08 05:46:56	2020-08-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38447	delivery	5	23
112855	2020-08-08 05:48:00	2020-08-08	12	[{"id_menu":3,"count":1}]	43376	delivery	5	17
112856	2020-08-08 05:48:25	2020-08-08	9	[{"id_menu":7,"count":2}]	28654	delivery	5	14
112857	2020-08-08 05:48:58	2020-08-08	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43290	delivery	5	47
112858	2020-08-08 05:49:16	2020-08-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	18612	delivery	5	28
112859	2020-08-08 05:49:42	2020-08-08	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25941	delivery	5	34
112860	2020-08-08 05:49:55	2020-08-08	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	20072	delivery	5	52
112861	2020-08-08 05:50:51	2020-08-08	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	43329	delivery	5	40
112862	2020-08-08 05:51:16	2020-08-08	9	[{"id_menu":6,"count":1}]	6271	delivery	5	14
112863	2020-08-08 05:52:27	2020-08-08	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43396	delivery	5	37
112864	2020-08-08 05:53:30	2020-08-08	9	[{"id_menu":7,"count":1}]	43312	delivery	5	14
112865	2020-08-08 05:56:31	2020-08-08	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8583	delivery	5	30
112866	2020-08-08 05:59:31	2020-08-08	14	[{"id_menu":2,"count":1}]	37742	delivery	5	19
112867	2020-08-08 05:59:59	2020-08-08	9	[{"id_menu":7,"count":1}]	38375	delivery	5	14
112868	2020-08-08 06:02:46	2020-08-08	14	[{"id_menu":2,"count":1}]	23561	pick-up	0	14
112869	2020-08-08 06:03:54	2020-08-08	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	22752	delivery	5	35
112870	2020-08-08 06:05:03	2020-08-08	14	[{"id_menu":2,"count":1}]	43377	delivery	5	19
112871	2020-08-08 06:07:46	2020-08-08	8	[{"id_menu":5,"count":1}]	36307	delivery	5	13
112872	2020-08-08 06:12:16	2020-08-08	9	[{"id_menu":7,"count":1}]	43356	delivery	5	14
112873	2020-08-08 06:12:29	2020-08-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	27158	delivery	5	23
112874	2020-08-08 06:12:58	2020-08-08	9	[{"id_menu":7,"count":1}]	797	pick-up	0	9
112875	2020-08-08 06:16:51	2020-08-08	14	[{"id_menu":2,"count":1}]	6221	delivery	5	19
112876	2020-08-08 06:16:57	2020-08-08	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	43278	delivery	5	37
112877	2020-08-08 06:18:15	2020-08-08	9	[{"id_menu":7,"count":1}]	6385	delivery	5	14
112878	2020-08-08 06:22:32	2020-08-08	29	[{"id_menu":3,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	43395	delivery	5	34
112879	2020-08-08 06:23:07	2020-08-08	9	[{"id_menu":6,"count":1}]	19892	delivery	5	14
112880	2020-08-08 06:23:18	2020-08-08	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	43209	delivery	5	40
112881	2020-08-08 06:23:53	2020-08-08	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	25749	delivery	5	31
112882	2020-08-08 06:25:07	2020-08-08	43	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	19300	pick-up	0	43
112883	2020-08-08 06:27:04	2020-08-08	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30273	delivery	5	37
112884	2020-08-08 06:34:07	2020-08-08	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	30238	delivery	5	22
112885	2020-08-08 06:36:53	2020-08-08	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	43310	delivery	5	26
112886	2020-08-08 06:37:38	2020-08-08	17	[{"id_menu":4,"count":1}]	2085	pick-up	0	17
112887	2020-08-08 06:39:07	2020-08-08	17	[{"id_menu":4,"count":1}]	19210	delivery	5	22
112888	2020-08-08 06:46:08	2020-08-08	14	[{"id_menu":2,"count":2}]	4166	delivery	5	19
112889	2020-08-08 06:47:28	2020-08-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	43413	delivery	5	22
112890	2020-08-08 06:47:34	2020-08-08	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	25802	delivery	5	26
112891	2020-08-08 06:48:43	2020-08-08	9	[{"id_menu":7,"count":1}]	43204	delivery	5	14
112892	2020-08-08 06:49:29	2020-08-08	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	20126	delivery	5	45
112893	2020-08-08 06:53:33	2020-08-08	9	[{"id_menu":7,"count":1}]	22156	delivery	5	14
112894	2020-08-08 06:56:14	2020-08-08	17	[{"id_menu":4,"count":1}]	14239	delivery	5	22
112895	2020-08-08 06:58:58	2020-08-08	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	29664	delivery	5	31
112896	2020-08-08 07:00:09	2020-08-08	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	9319	delivery	5	38
112897	2020-08-08 07:01:35	2020-08-08	8	[{"id_menu":5,"count":1}]	43331	delivery	5	13
112898	2020-08-08 07:01:41	2020-08-08	9	[{"id_menu":7,"count":2}]	23546	delivery	5	14
112899	2020-08-08 07:04:54	2020-08-08	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	11491	pick-up	0	29
112900	2020-08-08 07:07:03	2020-08-08	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	40267	delivery	5	34
112901	2020-08-08 07:07:15	2020-08-08	12	[{"id_menu":3,"count":1}]	43366	pick-up	0	12
112902	2020-08-08 07:08:37	2020-08-08	8	[{"id_menu":5,"count":1}]	20572	delivery	5	13
112903	2020-08-08 07:09:07	2020-08-08	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	10538	delivery	5	40
112904	2020-08-08 07:11:58	2020-08-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	40872	delivery	5	28
112905	2020-08-08 07:13:25	2020-08-08	12	[{"id_menu":1,"count":1}]	1908	pick-up	0	12
112906	2020-08-08 07:14:45	2020-08-08	12	[{"id_menu":1,"count":1}]	43208	delivery	5	17
112907	2020-08-08 07:17:58	2020-08-08	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	43194	delivery	5	25
112908	2020-08-08 07:19:56	2020-08-08	17	[{"id_menu":4,"count":1}]	30330	pick-up	0	17
112909	2020-08-08 07:20:08	2020-08-08	17	[{"id_menu":4,"count":1}]	40947	delivery	5	22
112910	2020-08-08 07:20:47	2020-08-08	12	[{"id_menu":1,"count":1}]	41157	delivery	5	17
112911	2020-08-08 07:22:35	2020-08-08	17	[{"id_menu":4,"count":1}]	39111	delivery	5	22
112912	2020-08-08 07:23:06	2020-08-08	9	[{"id_menu":6,"count":1}]	43231	pick-up	0	9
112913	2020-08-08 07:23:38	2020-08-08	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	38107	delivery	5	34
112914	2020-08-08 07:26:20	2020-08-08	8	[{"id_menu":5,"count":1}]	26748	delivery	5	13
112915	2020-08-08 07:27:03	2020-08-08	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	21095	delivery	5	40
112916	2020-08-08 07:27:25	2020-08-08	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	26122	delivery	5	36
112917	2020-08-08 07:28:13	2020-08-08	17	[{"id_menu":4,"count":1}]	43190	delivery	5	22
112918	2020-08-08 07:28:25	2020-08-08	8	[{"id_menu":5,"count":1}]	15360	delivery	5	13
112919	2020-08-08 07:29:42	2020-08-08	9	[{"id_menu":6,"count":1}]	30064	delivery	5	14
112920	2020-08-08 07:33:44	2020-08-08	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	43348	delivery	5	37
112921	2020-08-08 07:35:03	2020-08-08	8	[{"id_menu":5,"count":1}]	43417	delivery	5	13
112922	2020-08-08 07:37:09	2020-08-08	12	[{"id_menu":3,"count":1}]	43358	delivery	5	17
112923	2020-08-08 07:44:36	2020-08-08	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33900	delivery	5	31
112924	2020-08-08 07:46:29	2020-08-08	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43269	delivery	5	47
112925	2020-08-08 07:48:51	2020-08-08	9	[{"id_menu":7,"count":1}]	14715	delivery	5	14
112926	2020-08-08 07:49:48	2020-08-08	17	[{"id_menu":4,"count":2}]	31775	delivery	5	22
112927	2020-08-08 07:52:39	2020-08-08	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	8654	delivery	5	36
112928	2020-08-08 07:53:16	2020-08-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	16881	delivery	5	28
112929	2020-08-08 07:53:27	2020-08-08	8	[{"id_menu":5,"count":1}]	2217	pick-up	0	8
112930	2020-08-08 07:54:25	2020-08-08	14	[{"id_menu":2,"count":1}]	43402	delivery	5	19
112931	2020-08-08 07:56:32	2020-08-08	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	43243	delivery	5	31
112932	2020-08-08 07:59:30	2020-08-08	14	[{"id_menu":2,"count":1}]	35148	delivery	5	19
112933	2020-08-08 08:00:13	2020-08-08	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	37456	delivery	5	39
112934	2020-08-08 08:01:55	2020-08-08	14	[{"id_menu":2,"count":1}]	40219	delivery	5	19
112935	2020-08-08 08:08:08	2020-08-08	12	[{"id_menu":3,"count":1}]	15129	pick-up	0	12
112936	2020-08-08 08:09:09	2020-08-08	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	906	pick-up	0	26
112937	2020-08-08 08:13:17	2020-08-08	12	[{"id_menu":1,"count":1}]	17460	pick-up	0	12
112938	2020-08-08 08:14:44	2020-08-08	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35452	delivery	5	45
112939	2020-08-08 08:15:36	2020-08-08	8	[{"id_menu":5,"count":1}]	4444	pick-up	0	8
112940	2020-08-08 08:16:22	2020-08-08	9	[{"id_menu":7,"count":1}]	113	pick-up	0	9
112941	2020-08-08 08:17:05	2020-08-08	12	[{"id_menu":3,"count":1}]	6851	pick-up	0	12
112942	2020-08-08 08:20:16	2020-08-08	9	[{"id_menu":7,"count":1}]	11488	delivery	5	14
112943	2020-08-08 08:20:25	2020-08-08	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	14814	delivery	5	25
112944	2020-08-08 08:23:07	2020-08-08	9	[{"id_menu":7,"count":1}]	9516	delivery	5	14
112945	2020-08-08 08:23:34	2020-08-08	17	[{"id_menu":4,"count":1}]	19155	delivery	5	22
112946	2020-08-08 08:23:56	2020-08-08	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	37832	delivery	5	48
112947	2020-08-08 08:27:00	2020-08-08	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	43292	delivery	5	36
112948	2020-08-08 08:29:18	2020-08-08	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	11702	delivery	5	40
112949	2020-08-08 08:31:43	2020-08-08	9	[{"id_menu":7,"count":1}]	23805	delivery	5	14
112950	2020-08-08 08:37:01	2020-08-08	14	[{"id_menu":2,"count":1}]	43306	delivery	5	19
112951	2020-08-08 08:37:33	2020-08-08	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	43302	delivery	5	55
112952	2020-08-08 08:42:11	2020-08-08	17	[{"id_menu":4,"count":1}]	5311	pick-up	0	17
112953	2020-08-08 08:42:12	2020-08-08	14	[{"id_menu":2,"count":1}]	41450	pick-up	0	14
112954	2020-08-08 08:42:39	2020-08-08	12	[{"id_menu":1,"count":1}]	31183	delivery	5	17
112955	2020-08-08 08:42:41	2020-08-08	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	40885	delivery	5	30
112956	2020-08-08 08:44:38	2020-08-08	12	[{"id_menu":3,"count":1}]	1889	pick-up	0	12
112957	2020-08-08 08:54:19	2020-08-08	17	[{"id_menu":4,"count":1}]	43359	delivery	5	22
112958	2020-08-08 08:54:46	2020-08-08	8	[{"id_menu":5,"count":1}]	43387	delivery	5	13
112959	2020-08-08 08:55:47	2020-08-08	12	[{"id_menu":3,"count":1}]	43330	delivery	5	17
112960	2020-08-08 08:57:03	2020-08-08	14	[{"id_menu":2,"count":1}]	43184	delivery	5	19
112961	2020-08-08 08:58:10	2020-08-08	9	[{"id_menu":6,"count":1}]	38962	delivery	5	14
112962	2020-08-08 08:58:41	2020-08-08	17	[{"id_menu":4,"count":1}]	26968	delivery	5	22
112963	2020-08-08 09:04:29	2020-08-08	8	[{"id_menu":5,"count":1}]	22794	delivery	5	13
112964	2020-08-08 09:04:33	2020-08-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	15264	delivery	5	28
112965	2020-08-08 09:04:43	2020-08-08	9	[{"id_menu":6,"count":1}]	7476	delivery	5	14
112966	2020-08-08 09:06:38	2020-08-08	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	34896	delivery	5	27
112967	2020-08-08 09:07:59	2020-08-08	9	[{"id_menu":6,"count":1}]	38708	delivery	5	14
112968	2020-08-08 09:08:08	2020-08-08	9	[{"id_menu":6,"count":1}]	1072	delivery	5	14
112969	2020-08-08 09:09:05	2020-08-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	43216	delivery	5	22
112970	2020-08-08 09:09:35	2020-08-08	9	[{"id_menu":7,"count":1}]	43205	pick-up	0	9
112971	2020-08-08 09:09:47	2020-08-08	9	[{"id_menu":7,"count":1}]	20371	delivery	5	14
112972	2020-08-08 09:10:59	2020-08-08	12	[{"id_menu":3,"count":1}]	1055	pick-up	0	12
112973	2020-08-08 09:11:26	2020-08-08	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	43215	delivery	5	25
112974	2020-08-08 09:15:23	2020-08-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	43249	delivery	5	28
112975	2020-08-08 09:16:43	2020-08-08	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25137	delivery	5	49
112976	2020-08-08 09:18:05	2020-08-08	14	[{"id_menu":2,"count":1}]	19095	delivery	5	19
112977	2020-08-08 09:19:06	2020-08-08	9	[{"id_menu":6,"count":1}]	43234	delivery	5	14
112978	2020-08-08 09:23:22	2020-08-08	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	4818	delivery	5	22
112979	2020-08-08 09:23:52	2020-08-08	12	[{"id_menu":1,"count":1}]	40838	delivery	5	17
112980	2020-08-08 09:24:36	2020-08-08	9	[{"id_menu":6,"count":1}]	24073	delivery	5	14
112981	2020-08-08 09:24:45	2020-08-08	9	[{"id_menu":7,"count":1}]	19231	delivery	5	14
112982	2020-08-08 09:25:43	2020-08-08	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	37559	delivery	5	31
112983	2020-08-08 09:25:45	2020-08-08	17	[{"id_menu":4,"count":1}]	6469	pick-up	0	17
112984	2020-08-08 09:27:00	2020-08-08	9	[{"id_menu":7,"count":1}]	10281	pick-up	0	9
112985	2020-08-08 09:27:28	2020-08-08	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	32438	delivery	5	29
112986	2020-08-08 09:29:10	2020-08-08	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	40738	delivery	5	36
112987	2020-08-08 09:32:03	2020-08-08	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	43383	delivery	5	31
112988	2020-08-08 09:32:31	2020-08-08	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	23987	delivery	5	31
112989	2020-08-08 09:39:01	2020-08-08	9	[{"id_menu":6,"count":2}]	19817	delivery	5	14
112990	2020-08-08 09:43:34	2020-08-08	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	43321	delivery	5	43
112991	2020-08-08 09:45:53	2020-08-08	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43314	delivery	5	37
112992	2020-08-08 09:46:31	2020-08-08	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	43247	delivery	5	25
112993	2020-08-08 09:47:57	2020-08-08	9	[{"id_menu":7,"count":1}]	14124	delivery	5	14
112994	2020-08-08 09:49:21	2020-08-08	12	[{"id_menu":3,"count":1}]	18569	pick-up	0	12
112995	2020-08-08 09:49:40	2020-08-08	9	[{"id_menu":7,"count":1}]	43334	pick-up	0	9
112996	2020-08-08 09:50:03	2020-08-08	9	[{"id_menu":7,"count":1}]	20797	pick-up	0	9
112997	2020-08-08 09:51:12	2020-08-08	12	[{"id_menu":1,"count":1}]	3968	pick-up	0	12
112998	2020-08-08 09:53:11	2020-08-08	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10573	delivery	5	22
112999	2020-08-08 09:54:20	2020-08-08	9	[{"id_menu":7,"count":1}]	43270	delivery	5	14
113000	2020-08-08 09:56:45	2020-08-08	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	43317	delivery	5	57
113001	2020-08-08 09:57:37	2020-08-08	12	[{"id_menu":3,"count":1}]	28225	delivery	5	17
113002	2020-08-08 09:58:50	2020-08-08	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25179	delivery	5	53
113003	2020-08-08 10:01:25	2020-08-08	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	43423	delivery	5	52
113004	2020-08-08 10:03:22	2020-08-08	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	31137	delivery	5	44
113005	2020-08-08 10:04:26	2020-08-08	14	[{"id_menu":2,"count":1}]	22338	pick-up	0	14
113006	2020-08-08 10:05:58	2020-08-08	17	[{"id_menu":4,"count":1}]	25835	delivery	5	22
113007	2020-08-08 10:06:12	2020-08-08	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	43221	delivery	5	34
113008	2020-08-08 10:07:07	2020-08-08	12	[{"id_menu":1,"count":1}]	43195	delivery	5	17
113009	2020-08-08 10:08:53	2020-08-08	8	[{"id_menu":5,"count":1}]	43341	delivery	5	13
113010	2020-08-08 10:09:54	2020-08-08	8	[{"id_menu":5,"count":1}]	43318	delivery	5	13
113011	2020-08-08 10:13:10	2020-08-08	8	[{"id_menu":5,"count":2}]	43431	delivery	5	13
113012	2020-08-08 10:13:42	2020-08-08	12	[{"id_menu":3,"count":1}]	26018	delivery	5	17
113013	2020-08-08 10:15:40	2020-08-08	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	2519	pick-up	0	21
113014	2020-08-08 10:15:57	2020-08-08	9	[{"id_menu":6,"count":1}]	15028	pick-up	0	9
113015	2020-08-08 10:20:46	2020-08-08	9	[{"id_menu":7,"count":2}]	8598	pick-up	0	9
113016	2020-08-08 10:22:37	2020-08-08	12	[{"id_menu":1,"count":1}]	29685	delivery	5	17
113017	2020-08-08 10:24:59	2020-08-08	12	[{"id_menu":1,"count":1}]	34083	pick-up	0	12
113018	2020-08-08 10:26:06	2020-08-08	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	43255	delivery	5	30
113019	2020-08-08 10:28:38	2020-08-08	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	43324	delivery	5	27
113020	2020-08-08 10:35:15	2020-08-08	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33000	delivery	5	37
113021	2020-08-08 10:38:47	2020-08-08	9	[{"id_menu":7,"count":1}]	43273	pick-up	0	9
113022	2020-08-08 10:40:11	2020-08-08	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3898	delivery	5	36
113023	2020-08-08 10:41:48	2020-08-08	12	[{"id_menu":1,"count":1}]	39047	pick-up	0	12
113024	2020-08-08 10:42:23	2020-08-08	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	37084	delivery	5	25
113025	2020-08-08 10:45:39	2020-08-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3470	pick-up	0	23
113026	2020-08-08 10:48:38	2020-08-08	9	[{"id_menu":7,"count":1}]	38391	delivery	5	14
113027	2020-08-08 10:49:12	2020-08-08	8	[{"id_menu":5,"count":1}]	43398	delivery	5	13
113028	2020-08-08 10:49:38	2020-08-08	9	[{"id_menu":6,"count":1}]	43315	delivery	5	14
113029	2020-08-08 10:50:45	2020-08-08	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	43429	delivery	5	43
113030	2020-08-08 10:53:44	2020-08-08	9	[{"id_menu":6,"count":1}]	1146	pick-up	0	9
113031	2020-08-08 10:59:54	2020-08-08	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":3}]	43375	delivery	5	31
113032	2020-08-08 10:59:57	2020-08-08	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2457	pick-up	0	40
113033	2020-08-08 11:00:58	2020-08-08	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	14494	delivery	5	40
113034	2020-08-08 11:01:20	2020-08-08	17	[{"id_menu":4,"count":1}]	24991	pick-up	0	17
113035	2020-08-08 11:02:28	2020-08-08	9	[{"id_menu":6,"count":1}]	32687	delivery	5	14
113036	2020-08-08 11:03:44	2020-08-08	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	42571	delivery	5	40
113037	2020-08-08 11:10:39	2020-08-08	8	[{"id_menu":5,"count":1}]	43235	delivery	5	13
113038	2020-08-08 11:11:20	2020-08-08	12	[{"id_menu":1,"count":1}]	43223	delivery	5	17
113039	2020-08-08 11:11:21	2020-08-08	8	[{"id_menu":5,"count":1}]	7802	delivery	5	13
113040	2020-08-08 11:11:21	2020-08-08	9	[{"id_menu":7,"count":1}]	3555	delivery	5	14
113041	2020-08-08 11:14:03	2020-08-08	9	[{"id_menu":6,"count":1}]	27187	delivery	5	14
113042	2020-08-08 11:18:18	2020-08-08	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	33698	delivery	5	40
113043	2020-08-08 11:19:19	2020-08-08	9	[{"id_menu":6,"count":1}]	3291	pick-up	0	9
113044	2020-08-08 11:19:32	2020-08-08	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	33197	delivery	5	26
113045	2020-08-08 11:19:44	2020-08-08	9	[{"id_menu":7,"count":1}]	43224	delivery	5	14
113046	2020-08-08 11:23:28	2020-08-08	17	[{"id_menu":4,"count":1}]	18468	delivery	5	22
113047	2020-08-08 11:23:30	2020-08-08	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2517	pick-up	0	22
113048	2020-08-08 11:25:21	2020-08-08	12	[{"id_menu":1,"count":1}]	43227	delivery	5	17
113049	2020-08-08 11:28:12	2020-08-08	14	[{"id_menu":2,"count":1}]	26565	delivery	5	19
113050	2020-08-08 11:28:33	2020-08-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	964	delivery	5	28
113051	2020-08-08 11:32:21	2020-08-08	14	[{"id_menu":2,"count":1}]	26499	delivery	5	19
113052	2020-08-08 11:35:51	2020-08-08	14	[{"id_menu":2,"count":1}]	24690	delivery	5	19
113053	2020-08-08 11:36:47	2020-08-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40397	delivery	5	23
113054	2020-08-08 11:40:19	2020-08-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	32754	delivery	5	28
113055	2020-08-08 11:47:07	2020-08-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	43274	delivery	5	28
113056	2020-08-08 11:47:15	2020-08-08	9	[{"id_menu":6,"count":2}]	34307	delivery	5	14
113057	2020-08-08 11:47:56	2020-08-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5483	pick-up	0	23
113058	2020-08-08 11:48:11	2020-08-08	9	[{"id_menu":6,"count":1}]	36468	pick-up	0	9
113059	2020-08-08 11:49:05	2020-08-08	12	[{"id_menu":1,"count":1}]	5492	delivery	5	17
113060	2020-08-08 11:49:24	2020-08-08	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22459	pick-up	0	32
113061	2020-08-08 11:51:25	2020-08-08	9	[{"id_menu":6,"count":1}]	39872	pick-up	0	9
113062	2020-08-08 11:56:28	2020-08-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3835	delivery	5	28
113063	2020-08-08 11:57:55	2020-08-08	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	43424	pick-up	0	21
113064	2020-08-08 11:58:06	2020-08-08	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	42550	delivery	5	44
113065	2020-08-08 11:59:07	2020-08-08	14	[{"id_menu":2,"count":1}]	20989	pick-up	0	14
113066	2020-08-08 11:59:28	2020-08-08	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	43277	delivery	5	31
113067	2020-08-08 12:00:04	2020-08-08	12	[{"id_menu":1,"count":1}]	1720	pick-up	0	12
113068	2020-08-08 12:00:27	2020-08-08	8	[{"id_menu":5,"count":1}]	43275	delivery	5	13
113069	2020-08-08 12:01:35	2020-08-08	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	43353	delivery	5	26
113070	2020-08-08 12:02:53	2020-08-08	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10068	delivery	5	48
113071	2020-08-08 12:04:24	2020-08-08	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	43427	delivery	5	31
113072	2020-08-08 12:04:57	2020-08-08	8	[{"id_menu":5,"count":1}]	8834	delivery	5	13
113073	2020-08-08 12:05:28	2020-08-08	8	[{"id_menu":5,"count":1}]	43409	pick-up	0	8
113074	2020-08-08 12:05:44	2020-08-08	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	14207	delivery	5	37
113075	2020-08-08 12:06:19	2020-08-08	9	[{"id_menu":6,"count":1}]	43371	delivery	5	14
113076	2020-08-08 12:13:25	2020-08-08	14	[{"id_menu":2,"count":1}]	506	pick-up	0	14
113077	2020-08-08 12:16:17	2020-08-08	9	[{"id_menu":6,"count":1}]	10768	delivery	5	14
113078	2020-08-08 12:19:07	2020-08-08	9	[{"id_menu":6,"count":1}]	16084	pick-up	0	9
113079	2020-08-08 12:19:55	2020-08-08	12	[{"id_menu":1,"count":1}]	43293	delivery	5	17
113080	2020-08-08 12:21:24	2020-08-08	14	[{"id_menu":2,"count":1}]	8180	pick-up	0	14
113081	2020-08-08 12:24:27	2020-08-08	14	[{"id_menu":2,"count":1}]	37333	delivery	5	19
113082	2020-08-08 12:24:43	2020-08-08	9	[{"id_menu":6,"count":1}]	39227	delivery	5	14
113083	2020-08-08 12:24:56	2020-08-08	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	43198	delivery	5	39
113084	2020-08-08 12:27:05	2020-08-08	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	43419	delivery	5	22
113085	2020-08-08 12:27:54	2020-08-08	17	[{"id_menu":4,"count":1}]	10629	pick-up	0	17
113086	2020-08-08 12:28:01	2020-08-08	14	[{"id_menu":2,"count":1}]	14994	delivery	5	19
113087	2020-08-08 12:28:34	2020-08-08	9	[{"id_menu":6,"count":1}]	16346	delivery	5	14
113088	2020-08-08 12:30:08	2020-08-08	12	[{"id_menu":3,"count":1}]	21202	delivery	5	17
113089	2020-08-08 12:31:16	2020-08-08	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	43225	delivery	5	22
113090	2020-08-08 12:32:24	2020-08-08	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18271	delivery	5	35
113091	2020-08-08 12:34:17	2020-08-08	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	43272	pick-up	0	26
113092	2020-08-08 12:36:01	2020-08-08	17	[{"id_menu":4,"count":2}]	43347	delivery	5	22
113093	2020-08-08 12:39:01	2020-08-08	9	[{"id_menu":6,"count":1}]	43338	delivery	5	14
113094	2020-08-08 12:41:11	2020-08-08	17	[{"id_menu":4,"count":1}]	12055	delivery	5	22
113095	2020-08-08 12:41:52	2020-08-08	17	[{"id_menu":4,"count":2}]	43201	pick-up	0	17
113096	2020-08-08 12:42:11	2020-08-08	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30611	delivery	5	47
113097	2020-08-08 12:43:25	2020-08-08	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	6489	pick-up	0	29
113098	2020-08-08 12:43:38	2020-08-08	14	[{"id_menu":2,"count":1}]	43381	delivery	5	19
113099	2020-08-08 12:45:50	2020-08-08	8	[{"id_menu":5,"count":1}]	19832	delivery	5	13
113100	2020-08-08 12:48:29	2020-08-08	17	[{"id_menu":4,"count":1}]	43185	delivery	5	22
113101	2020-08-08 12:51:23	2020-08-08	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	43385	delivery	5	28
113102	2020-08-08 12:52:05	2020-08-08	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":3}]	43325	delivery	5	26
113103	2020-08-08 12:52:07	2020-08-08	17	[{"id_menu":4,"count":2}]	22618	delivery	5	22
113104	2020-08-08 12:52:59	2020-08-08	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	43202	pick-up	0	20
113105	2020-08-08 12:54:07	2020-08-08	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	16042	pick-up	0	25
113106	2020-08-08 12:54:15	2020-08-08	14	[{"id_menu":2,"count":1}]	18021	pick-up	0	14
113107	2020-08-08 12:56:47	2020-08-08	12	[{"id_menu":1,"count":1}]	10452	pick-up	0	12
113108	2020-08-08 12:56:54	2020-08-08	9	[{"id_menu":6,"count":1}]	28154	delivery	5	14
113109	2020-08-08 12:57:21	2020-08-08	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	43260	delivery	5	45
113110	2020-08-08 12:57:35	2020-08-08	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	22533	delivery	5	22
113111	2020-08-08 12:57:49	2020-08-08	9	[{"id_menu":7,"count":1}]	6201	delivery	5	14
113112	2020-08-08 12:58:07	2020-08-08	9	[{"id_menu":7,"count":1}]	3447	pick-up	0	9
113113	2020-08-08 12:59:04	2020-08-08	14	[{"id_menu":2,"count":1}]	43286	delivery	5	19
113114	2020-08-08 13:00:12	2020-08-08	12	[{"id_menu":3,"count":1}]	43428	delivery	5	17
113115	2020-08-08 13:03:20	2020-08-08	8	[{"id_menu":5,"count":1}]	43001	delivery	5	13
113116	2020-08-08 13:05:18	2020-08-08	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	27557	delivery	5	36
113117	2020-08-08 13:05:19	2020-08-08	8	[{"id_menu":5,"count":1}]	37728	delivery	5	13
113118	2020-08-08 13:06:57	2020-08-08	9	[{"id_menu":7,"count":1}]	43268	delivery	5	14
113119	2020-08-08 13:08:54	2020-08-08	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	25925	delivery	5	25
113120	2020-08-08 13:10:02	2020-08-08	12	[{"id_menu":3,"count":1}]	20805	pick-up	0	12
113121	2020-08-08 13:11:06	2020-08-08	12	[{"id_menu":1,"count":1}]	10946	delivery	5	17
113122	2020-08-08 13:16:53	2020-08-08	9	[{"id_menu":6,"count":1}]	29948	delivery	5	14
113123	2020-08-08 13:17:13	2020-08-08	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	43295	delivery	5	31
113124	2020-08-08 13:18:40	2020-08-08	8	[{"id_menu":5,"count":1}]	43296	delivery	5	13
113125	2020-08-08 13:23:48	2020-08-08	9	[{"id_menu":7,"count":1}]	19883	delivery	5	14
113126	2020-08-08 13:24:01	2020-08-08	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18762	delivery	5	45
113127	2020-08-08 13:24:22	2020-08-08	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	43405	delivery	5	56
113128	2020-08-08 13:25:47	2020-08-08	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	43372	delivery	5	38
113129	2020-08-08 13:26:17	2020-08-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16550	pick-up	0	17
113130	2020-08-08 13:27:56	2020-08-08	43	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	11531	delivery	5	48
113131	2020-08-08 13:28:07	2020-08-08	9	[{"id_menu":6,"count":1}]	10652	delivery	5	14
113132	2020-08-08 13:28:26	2020-08-08	9	[{"id_menu":6,"count":1}]	41720	pick-up	0	9
113133	2020-08-08 13:32:07	2020-08-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31837	delivery	5	23
113134	2020-08-08 13:32:43	2020-08-08	9	[{"id_menu":7,"count":1}]	16681	delivery	5	14
113135	2020-08-08 13:33:37	2020-08-08	12	[{"id_menu":1,"count":1}]	39389	delivery	5	17
113136	2020-08-08 13:33:40	2020-08-08	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	43229	delivery	5	26
113137	2020-08-08 13:34:05	2020-08-08	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	915	pick-up	0	22
113138	2020-08-08 13:34:40	2020-08-08	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	43226	delivery	5	40
113139	2020-08-08 13:39:15	2020-08-08	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	43410	delivery	5	29
113140	2020-08-08 13:40:42	2020-08-08	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10872	delivery	5	30
113141	2020-08-08 13:43:17	2020-08-08	9	[{"id_menu":6,"count":1}]	2579	delivery	5	14
113142	2020-08-08 13:44:24	2020-08-08	8	[{"id_menu":5,"count":1}]	43251	delivery	5	13
113143	2020-08-08 13:45:06	2020-08-08	12	[{"id_menu":1,"count":1}]	39217	delivery	5	17
113144	2020-08-08 13:46:47	2020-08-08	12	[{"id_menu":3,"count":1}]	12623	pick-up	0	12
113145	2020-08-08 13:47:20	2020-08-08	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9563	delivery	5	49
113146	2020-08-08 13:50:55	2020-08-08	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40948	delivery	5	40
113147	2020-08-08 13:54:19	2020-08-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	43219	delivery	5	28
113148	2020-08-08 13:58:16	2020-08-08	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	22369	delivery	5	31
113149	2020-08-08 13:59:47	2020-08-08	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	40262	delivery	5	55
113150	2020-08-08 14:08:54	2020-08-08	17	[{"id_menu":4,"count":1}]	27931	delivery	5	22
113151	2020-08-08 14:09:13	2020-08-08	12	[{"id_menu":3,"count":1}]	7025	delivery	5	17
113152	2020-08-08 14:09:57	2020-08-08	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	43404	delivery	5	36
113153	2020-08-08 14:10:07	2020-08-08	12	[{"id_menu":1,"count":1}]	9061	pick-up	0	12
113154	2020-08-08 14:11:03	2020-08-08	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	34547	delivery	5	25
113155	2020-08-08 14:12:48	2020-08-08	9	[{"id_menu":7,"count":1}]	43345	delivery	5	14
113156	2020-08-08 14:14:45	2020-08-08	9	[{"id_menu":7,"count":2}]	28507	delivery	5	14
113157	2020-08-08 14:14:52	2020-08-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	12699	pick-up	0	23
113158	2020-08-08 14:16:12	2020-08-08	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	40800	delivery	5	48
113159	2020-08-08 14:16:23	2020-08-08	9	[{"id_menu":6,"count":3}]	30174	delivery	5	14
113160	2020-08-08 14:16:35	2020-08-08	9	[{"id_menu":7,"count":1}]	31614	delivery	5	14
113161	2020-08-08 14:21:28	2020-08-08	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	43303	delivery	5	34
113162	2020-08-08 14:28:02	2020-08-08	9	[{"id_menu":6,"count":2}]	43232	delivery	5	14
113163	2020-08-08 14:28:09	2020-08-08	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	43355	delivery	5	38
113164	2020-08-08 14:30:20	2020-08-08	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	43374	delivery	5	57
113165	2020-08-08 14:30:41	2020-08-08	9	[{"id_menu":6,"count":1}]	2546	pick-up	0	9
113166	2020-08-08 14:31:49	2020-08-08	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13383	delivery	5	31
113167	2020-08-08 14:32:35	2020-08-08	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40483	delivery	5	31
113168	2020-08-08 14:35:34	2020-08-08	9	[{"id_menu":6,"count":1}]	43220	delivery	5	14
113169	2020-08-08 14:36:21	2020-08-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	24045	delivery	5	28
113170	2020-08-08 14:41:49	2020-08-08	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26927	delivery	5	43
113171	2020-08-08 14:42:25	2020-08-08	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	24853	pick-up	0	21
113172	2020-08-08 14:42:33	2020-08-08	8	[{"id_menu":5,"count":1}]	24630	delivery	5	13
113173	2020-08-08 14:43:01	2020-08-08	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	43326	pick-up	0	26
113174	2020-08-08 14:43:14	2020-08-08	9	[{"id_menu":6,"count":1}]	24752	pick-up	0	9
113175	2020-08-08 14:43:16	2020-08-08	17	[{"id_menu":4,"count":1}]	14202	delivery	5	22
113176	2020-08-08 14:43:23	2020-08-08	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31804	delivery	5	35
113177	2020-08-08 14:46:23	2020-08-08	14	[{"id_menu":2,"count":1}]	33732	pick-up	0	14
113178	2020-08-08 14:47:17	2020-08-08	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	41300	pick-up	0	35
113179	2020-08-08 14:47:55	2020-08-08	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	39654	delivery	5	26
113180	2020-08-08 14:50:41	2020-08-08	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	20852	delivery	5	34
113181	2020-08-08 14:50:54	2020-08-08	8	[{"id_menu":5,"count":1}]	4577	delivery	5	13
113182	2020-08-08 14:53:42	2020-08-08	12	[{"id_menu":3,"count":1}]	438	pick-up	0	12
113183	2020-08-08 14:56:44	2020-08-08	9	[{"id_menu":6,"count":1}]	42271	delivery	5	14
113184	2020-08-08 14:57:35	2020-08-08	12	[{"id_menu":3,"count":1}]	5421	pick-up	0	12
113185	2020-08-08 14:58:46	2020-08-08	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	42964	delivery	5	37
113186	2020-08-08 15:00:00	2020-08-08	9	[{"id_menu":7,"count":1}]	2627	pick-up	0	9
113187	2020-08-08 15:04:10	2020-08-08	8	[{"id_menu":5,"count":1}]	38605	delivery	5	13
113188	2020-08-08 15:05:09	2020-08-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	43354	pick-up	0	23
113189	2020-08-08 15:06:45	2020-08-08	17	[{"id_menu":4,"count":1}]	22605	pick-up	0	17
113190	2020-08-08 15:07:12	2020-08-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	30353	delivery	5	28
113191	2020-08-08 15:09:15	2020-08-08	9	[{"id_menu":7,"count":1}]	13882	delivery	5	14
113192	2020-08-08 15:12:39	2020-08-08	17	[{"id_menu":4,"count":1}]	33709	delivery	5	22
113193	2020-08-08 15:13:46	2020-08-08	12	[{"id_menu":1,"count":1}]	4634	pick-up	0	12
113194	2020-08-08 15:16:03	2020-08-08	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	1645	pick-up	0	29
113195	2020-08-08 15:18:56	2020-08-08	9	[{"id_menu":6,"count":1}]	12098	delivery	5	14
113196	2020-08-08 15:19:21	2020-08-08	9	[{"id_menu":6,"count":1}]	32144	pick-up	0	9
113197	2020-08-08 15:19:49	2020-08-08	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	4054	delivery	5	26
113198	2020-08-08 15:21:13	2020-08-08	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	43187	delivery	5	25
113199	2020-08-08 15:21:17	2020-08-08	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	22854	delivery	5	31
113200	2020-08-08 15:21:36	2020-08-08	9	[{"id_menu":7,"count":1}]	3009	pick-up	0	9
113201	2020-08-08 15:21:38	2020-08-08	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3015	pick-up	0	43
113202	2020-08-08 15:22:25	2020-08-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	43245	delivery	5	28
113203	2020-08-08 15:23:22	2020-08-08	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	26601	delivery	5	22
113204	2020-08-08 15:23:33	2020-08-08	14	[{"id_menu":2,"count":1}]	6744	delivery	5	19
113205	2020-08-08 15:25:29	2020-08-08	9	[{"id_menu":7,"count":1}]	43389	delivery	5	14
113206	2020-08-08 15:26:24	2020-08-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	13528	delivery	5	28
113207	2020-08-08 15:26:30	2020-08-08	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	43218	delivery	5	42
113208	2020-08-08 15:27:10	2020-08-08	12	[{"id_menu":3,"count":1}]	3684	delivery	5	17
113209	2020-08-08 15:27:40	2020-08-08	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	19771	delivery	5	26
113210	2020-08-08 15:28:39	2020-08-08	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	43403	delivery	5	26
113211	2020-08-08 15:29:49	2020-08-08	14	[{"id_menu":2,"count":1}]	1369	pick-up	0	14
113212	2020-08-08 15:33:15	2020-08-08	9	[{"id_menu":6,"count":1}]	33914	delivery	5	14
113213	2020-08-08 15:34:21	2020-08-08	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	8054	pick-up	0	29
113214	2020-08-08 15:35:01	2020-08-08	14	[{"id_menu":2,"count":3}]	22650	delivery	5	19
113215	2020-08-08 15:36:34	2020-08-08	12	[{"id_menu":3,"count":1}]	30275	pick-up	0	12
113216	2020-08-08 15:37:45	2020-08-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	18496	delivery	5	28
113217	2020-08-08 15:38:16	2020-08-08	9	[{"id_menu":7,"count":1}]	43392	delivery	5	14
113218	2020-08-08 15:38:30	2020-08-08	8	[{"id_menu":5,"count":1}]	32167	pick-up	0	8
113219	2020-08-08 15:39:01	2020-08-08	12	[{"id_menu":1,"count":1}]	4800	pick-up	0	12
113220	2020-08-08 15:40:06	2020-08-08	8	[{"id_menu":5,"count":1}]	11085	delivery	5	13
113221	2020-08-08 15:41:45	2020-08-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	709	pick-up	0	18
113222	2020-08-08 15:45:27	2020-08-08	9	[{"id_menu":7,"count":1}]	25367	delivery	5	14
113223	2020-08-08 15:47:39	2020-08-08	12	[{"id_menu":3,"count":1}]	1457	delivery	5	17
113224	2020-08-08 15:48:39	2020-08-08	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	11893	delivery	5	26
113225	2020-08-08 15:49:14	2020-08-08	12	[{"id_menu":3,"count":1}]	6589	delivery	5	17
113226	2020-08-08 15:49:45	2020-08-08	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	43343	delivery	5	26
113227	2020-08-08 15:50:10	2020-08-08	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	43304	delivery	5	25
113228	2020-08-08 15:50:19	2020-08-08	12	[{"id_menu":1,"count":1}]	43267	delivery	5	17
113229	2020-08-08 15:50:48	2020-08-08	14	[{"id_menu":2,"count":1}]	173	pick-up	0	14
113230	2020-08-08 15:53:01	2020-08-08	8	[{"id_menu":5,"count":1}]	28417	delivery	5	13
113231	2020-08-08 15:54:24	2020-08-08	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17084	delivery	5	40
113232	2020-08-08 15:57:53	2020-08-08	14	[{"id_menu":2,"count":1}]	32503	delivery	5	19
113233	2020-08-08 15:58:11	2020-08-08	9	[{"id_menu":7,"count":1}]	19662	delivery	5	14
113234	2020-08-08 16:03:27	2020-08-08	17	[{"id_menu":4,"count":1}]	4102	pick-up	0	17
113235	2020-08-08 16:03:32	2020-08-08	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	33224	delivery	5	31
113236	2020-08-08 16:03:53	2020-08-08	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":2}]	11081	delivery	5	27
113237	2020-08-08 16:04:21	2020-08-08	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16140	delivery	5	31
113238	2020-08-08 16:04:48	2020-08-08	9	[{"id_menu":7,"count":1}]	17858	delivery	5	14
113239	2020-08-08 16:07:31	2020-08-08	17	[{"id_menu":4,"count":1}]	30349	delivery	5	22
113240	2020-08-08 16:07:55	2020-08-08	12	[{"id_menu":3,"count":1}]	43258	delivery	5	17
113241	2020-08-08 16:10:21	2020-08-08	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	43352	delivery	5	30
113242	2020-08-08 16:10:33	2020-08-08	12	[{"id_menu":3,"count":1}]	1303	pick-up	0	12
113243	2020-08-08 16:10:52	2020-08-08	9	[{"id_menu":6,"count":1}]	43287	delivery	5	14
113244	2020-08-08 16:14:01	2020-08-08	14	[{"id_menu":2,"count":1}]	30469	pick-up	0	14
113245	2020-08-08 16:14:05	2020-08-08	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	43193	delivery	5	34
113246	2020-08-08 16:17:27	2020-08-08	12	[{"id_menu":1,"count":1}]	8476	delivery	5	17
113247	2020-08-08 16:18:23	2020-08-08	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20868	delivery	5	40
113248	2020-08-08 16:22:06	2020-08-08	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	38926	delivery	5	36
113249	2020-08-08 16:22:07	2020-08-08	17	[{"id_menu":4,"count":1}]	32528	delivery	5	22
113250	2020-08-08 16:22:37	2020-08-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	10618	delivery	5	28
113251	2020-08-08 16:25:52	2020-08-08	9	[{"id_menu":7,"count":1}]	43264	delivery	5	14
113252	2020-08-08 16:32:56	2020-08-08	9	[{"id_menu":6,"count":3}]	43367	delivery	5	14
113253	2020-08-08 16:33:48	2020-08-08	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	37735	delivery	5	22
113254	2020-08-08 16:36:38	2020-08-08	8	[{"id_menu":5,"count":1}]	27662	delivery	5	13
113255	2020-08-08 16:36:49	2020-08-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43412	delivery	5	23
113256	2020-08-08 16:37:46	2020-08-08	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11543	delivery	5	57
113257	2020-08-08 16:39:50	2020-08-08	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8139	delivery	5	42
113258	2020-08-08 16:41:12	2020-08-08	12	[{"id_menu":3,"count":1}]	31161	delivery	5	17
113259	2020-08-08 16:42:19	2020-08-08	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	8550	pick-up	0	29
113260	2020-08-08 16:44:22	2020-08-08	14	[{"id_menu":2,"count":1}]	8406	delivery	5	19
113261	2020-08-08 16:45:16	2020-08-08	12	[{"id_menu":3,"count":1}]	11838	pick-up	0	12
113262	2020-08-08 16:46:48	2020-08-08	12	[{"id_menu":3,"count":1}]	34491	delivery	5	17
113263	2020-08-08 16:49:44	2020-08-08	9	[{"id_menu":7,"count":1}]	43213	delivery	5	14
113264	2020-08-08 16:52:02	2020-08-08	8	[{"id_menu":5,"count":1}]	43369	delivery	5	13
113265	2020-08-08 16:56:54	2020-08-08	12	[{"id_menu":1,"count":1}]	40921	delivery	5	17
113266	2020-08-08 16:57:15	2020-08-08	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	43238	delivery	5	48
113267	2020-08-08 17:00:22	2020-08-08	8	[{"id_menu":5,"count":1}]	10812	delivery	5	13
113268	2020-08-08 17:06:34	2020-08-08	8	[{"id_menu":5,"count":1}]	38806	delivery	5	13
113269	2020-08-08 17:06:48	2020-08-08	12	[{"id_menu":3,"count":1}]	43411	delivery	5	17
113270	2020-08-08 17:07:28	2020-08-08	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17044	delivery	5	22
113271	2020-08-08 17:07:36	2020-08-08	9	[{"id_menu":7,"count":1}]	10483	pick-up	0	9
113272	2020-08-08 17:09:27	2020-08-08	14	[{"id_menu":2,"count":1}]	2101	pick-up	0	14
113273	2020-08-08 17:09:28	2020-08-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7022	delivery	5	23
113274	2020-08-08 17:10:22	2020-08-08	9	[{"id_menu":6,"count":1}]	35691	delivery	5	14
113275	2020-08-08 17:14:13	2020-08-08	9	[{"id_menu":6,"count":1}]	37020	delivery	5	14
113276	2020-08-08 17:15:39	2020-08-08	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	37062	delivery	5	31
113277	2020-08-08 17:16:21	2020-08-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43426	delivery	5	23
113278	2020-08-08 17:18:29	2020-08-08	9	[{"id_menu":6,"count":1}]	43408	delivery	5	14
113279	2020-08-08 17:19:33	2020-08-08	14	[{"id_menu":2,"count":1}]	32818	pick-up	0	14
113280	2020-08-08 17:20:19	2020-08-08	9	[{"id_menu":6,"count":1}]	43319	delivery	5	14
113281	2020-08-08 17:21:08	2020-08-08	9	[{"id_menu":7,"count":1}]	23614	delivery	5	14
113282	2020-08-08 17:23:18	2020-08-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	10964	delivery	5	23
113283	2020-08-08 17:26:40	2020-08-08	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	3111	pick-up	0	21
113284	2020-08-08 17:27:34	2020-08-08	8	[{"id_menu":5,"count":1}]	6733	delivery	5	13
113285	2020-08-08 17:27:57	2020-08-08	12	[{"id_menu":3,"count":1}]	12254	pick-up	0	12
113286	2020-08-08 17:30:23	2020-08-08	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	10950	delivery	5	31
113287	2020-08-08 17:30:52	2020-08-08	9	[{"id_menu":6,"count":1}]	43388	delivery	5	14
113288	2020-08-08 17:31:22	2020-08-08	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43263	delivery	5	37
113289	2020-08-08 17:31:23	2020-08-08	9	[{"id_menu":6,"count":1}]	24091	delivery	5	14
113290	2020-08-08 17:31:47	2020-08-08	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	38052	delivery	5	29
113291	2020-08-08 17:31:49	2020-08-08	14	[{"id_menu":2,"count":1}]	36371	delivery	5	19
113292	2020-08-08 17:32:26	2020-08-08	17	[{"id_menu":4,"count":1}]	13697	pick-up	0	17
113293	2020-08-08 17:36:59	2020-08-08	9	[{"id_menu":7,"count":1}]	27862	pick-up	0	9
113294	2020-08-08 17:37:54	2020-08-08	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	43420	delivery	5	43
113295	2020-08-08 17:38:59	2020-08-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	26659	delivery	5	22
113296	2020-08-08 17:40:01	2020-08-08	12	[{"id_menu":3,"count":1}]	5586	pick-up	0	12
113297	2020-08-08 17:41:16	2020-08-08	12	[{"id_menu":1,"count":1}]	43239	delivery	5	17
113298	2020-08-08 17:42:26	2020-08-08	17	[{"id_menu":4,"count":1}]	1415	pick-up	0	17
113299	2020-08-08 17:42:35	2020-08-08	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	21002	pick-up	0	35
113300	2020-08-08 17:43:01	2020-08-08	14	[{"id_menu":2,"count":1}]	11621	delivery	5	19
113301	2020-08-08 17:43:20	2020-08-08	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	35265	pick-up	0	41
113302	2020-08-08 17:45:15	2020-08-08	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23358	delivery	5	35
113303	2020-08-08 17:47:35	2020-08-08	12	[{"id_menu":1,"count":1}]	28446	delivery	5	17
113304	2020-08-08 17:48:56	2020-08-08	14	[{"id_menu":2,"count":1}]	43323	delivery	5	19
113305	2020-08-08 17:53:52	2020-08-08	9	[{"id_menu":7,"count":1}]	25608	delivery	5	14
113306	2020-08-08 17:55:06	2020-08-08	9	[{"id_menu":7,"count":1}]	39090	delivery	5	14
113307	2020-08-08 17:57:45	2020-08-08	9	[{"id_menu":7,"count":1}]	34357	delivery	5	14
113308	2020-08-08 18:02:54	2020-08-08	12	[{"id_menu":3,"count":1}]	19647	delivery	5	17
113309	2020-08-08 18:03:48	2020-08-08	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	8651	delivery	5	40
113310	2020-08-08 18:05:54	2020-08-08	9	[{"id_menu":7,"count":1}]	43256	delivery	5	14
113311	2020-08-08 18:06:00	2020-08-08	9	[{"id_menu":6,"count":1}]	8877	delivery	5	14
113312	2020-08-08 18:07:00	2020-08-08	9	[{"id_menu":7,"count":1}]	43421	delivery	5	14
113313	2020-08-08 18:08:42	2020-08-08	9	[{"id_menu":6,"count":1}]	13305	delivery	5	14
113314	2020-08-08 18:09:36	2020-08-08	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	28950	delivery	5	31
113315	2020-08-08 18:12:24	2020-08-08	8	[{"id_menu":5,"count":1}]	2490	delivery	5	13
113316	2020-08-08 18:15:02	2020-08-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	26443	delivery	5	22
113317	2020-08-08 18:16:40	2020-08-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	11963	delivery	5	28
113318	2020-08-08 18:16:47	2020-08-08	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	43289	delivery	5	34
113319	2020-08-08 18:16:57	2020-08-08	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	43257	delivery	5	36
113320	2020-08-08 18:17:21	2020-08-08	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	43378	delivery	5	36
113321	2020-08-08 18:17:26	2020-08-08	14	[{"id_menu":2,"count":1}]	43233	delivery	5	19
113322	2020-08-08 18:18:31	2020-08-08	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40854	delivery	5	43
113323	2020-08-08 18:23:37	2020-08-08	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	20629	delivery	5	40
113324	2020-08-08 18:25:30	2020-08-08	8	[{"id_menu":5,"count":1}]	2623	pick-up	0	8
113325	2020-08-08 18:25:41	2020-08-08	17	[{"id_menu":4,"count":1}]	7746	pick-up	0	17
113326	2020-08-08 18:25:51	2020-08-08	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	33819	delivery	5	26
113327	2020-08-08 18:26:21	2020-08-08	12	[{"id_menu":3,"count":1}]	43342	pick-up	0	12
113328	2020-08-08 18:30:40	2020-08-08	14	[{"id_menu":2,"count":1}]	7428	delivery	5	19
113329	2020-08-08 18:30:58	2020-08-08	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	43357	delivery	5	44
113330	2020-08-08 18:32:07	2020-08-08	17	[{"id_menu":4,"count":1}]	5712	pick-up	0	17
113331	2020-08-08 18:38:37	2020-08-08	9	[{"id_menu":7,"count":1}]	43365	delivery	5	14
113332	2020-08-08 18:38:40	2020-08-08	8	[{"id_menu":5,"count":1}]	43422	delivery	5	13
113333	2020-08-08 18:42:05	2020-08-08	9	[{"id_menu":7,"count":1}]	18180	delivery	5	14
113334	2020-08-08 18:42:33	2020-08-08	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	33585	delivery	5	40
113335	2020-08-08 18:43:00	2020-08-08	12	[{"id_menu":3,"count":1}]	19926	delivery	5	17
113336	2020-08-08 18:45:36	2020-08-08	12	[{"id_menu":1,"count":1}]	16978	delivery	5	17
113337	2020-08-08 18:47:25	2020-08-08	9	[{"id_menu":6,"count":1}]	31158	delivery	5	14
113338	2020-08-08 18:48:17	2020-08-08	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38399	delivery	5	40
113339	2020-08-08 18:55:02	2020-08-08	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	43309	delivery	5	31
113340	2020-08-08 18:55:22	2020-08-08	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	43307	delivery	5	36
113341	2020-08-08 18:56:29	2020-08-08	9	[{"id_menu":6,"count":2}]	41142	delivery	5	14
113342	2020-08-08 18:58:40	2020-08-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15201	delivery	5	23
113343	2020-08-08 18:58:57	2020-08-08	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	43370	delivery	5	34
113344	2020-08-08 19:01:08	2020-08-08	12	[{"id_menu":1,"count":1}]	18418	delivery	5	17
113345	2020-08-08 19:01:28	2020-08-08	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	43311	delivery	5	45
113346	2020-08-08 19:01:37	2020-08-08	12	[{"id_menu":1,"count":1}]	31376	delivery	5	17
113347	2020-08-08 19:01:43	2020-08-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	43189	pick-up	0	17
113348	2020-08-08 19:02:21	2020-08-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4069	delivery	5	22
113349	2020-08-08 19:02:57	2020-08-08	14	[{"id_menu":2,"count":1}]	7550	delivery	5	19
113350	2020-08-08 19:03:27	2020-08-08	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	15744	delivery	5	34
113351	2020-08-08 19:04:18	2020-08-08	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7403	delivery	5	31
113352	2020-08-08 19:07:16	2020-08-08	9	[{"id_menu":7,"count":1}]	29146	delivery	5	14
113353	2020-08-08 19:09:33	2020-08-08	8	[{"id_menu":5,"count":1}]	24873	delivery	5	13
113354	2020-08-08 19:10:19	2020-08-08	17	[{"id_menu":4,"count":1}]	43401	delivery	5	22
113355	2020-08-08 19:12:02	2020-08-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	624	pick-up	0	23
113356	2020-08-08 19:17:41	2020-08-08	9	[{"id_menu":6,"count":1}]	43322	delivery	5	14
113357	2020-08-08 19:17:59	2020-08-08	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	43299	delivery	5	42
113358	2020-08-08 19:18:05	2020-08-08	12	[{"id_menu":1,"count":1}]	43397	delivery	5	17
113359	2020-08-08 19:18:18	2020-08-08	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	23735	pick-up	0	26
113360	2020-08-08 19:18:31	2020-08-08	9	[{"id_menu":6,"count":1}]	28727	delivery	5	14
113361	2020-08-08 19:18:45	2020-08-08	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6860	pick-up	0	35
113362	2020-08-08 19:19:22	2020-08-08	17	[{"id_menu":4,"count":1}]	14593	delivery	5	22
113363	2020-08-08 19:21:35	2020-08-08	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	24768	delivery	5	43
113364	2020-08-08 19:21:43	2020-08-08	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43228	delivery	5	35
113365	2020-08-08 19:22:05	2020-08-08	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	22176	pick-up	0	21
113366	2020-08-08 19:22:20	2020-08-08	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	43241	delivery	5	40
113367	2020-08-08 19:23:19	2020-08-08	9	[{"id_menu":7,"count":1}]	23023	delivery	5	14
113368	2020-08-08 19:26:23	2020-08-08	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	43337	delivery	5	30
113369	2020-08-08 19:26:57	2020-08-08	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	9260	delivery	5	38
113370	2020-08-08 19:27:04	2020-08-08	14	[{"id_menu":2,"count":2}]	1325	delivery	5	19
113371	2020-08-08 19:27:08	2020-08-08	9	[{"id_menu":6,"count":2}]	2351	pick-up	0	9
113372	2020-08-08 19:29:36	2020-08-08	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	37154	delivery	5	40
113373	2020-08-08 19:29:47	2020-08-08	9	[{"id_menu":6,"count":1}]	30790	delivery	5	14
113374	2020-08-08 19:29:59	2020-08-08	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	43200	delivery	5	36
113375	2020-08-08 19:41:30	2020-08-08	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	43217	delivery	5	38
113376	2020-08-08 19:42:01	2020-08-08	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22872	delivery	5	22
113377	2020-08-08 19:46:06	2020-08-08	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	43294	delivery	5	34
113378	2020-08-08 19:48:44	2020-08-08	14	[{"id_menu":2,"count":1}]	17165	delivery	5	19
113379	2020-08-08 19:50:53	2020-08-08	8	[{"id_menu":5,"count":1}]	32143	delivery	5	13
113380	2020-08-08 19:51:14	2020-08-08	9	[{"id_menu":7,"count":1}]	43242	delivery	5	14
113381	2020-08-08 19:53:55	2020-08-08	8	[{"id_menu":5,"count":1}]	42318	pick-up	0	8
113382	2020-08-08 19:56:38	2020-08-08	12	[{"id_menu":1,"count":1}]	38844	pick-up	0	12
113383	2020-08-08 19:56:59	2020-08-08	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	10679	delivery	5	34
113384	2020-08-08 19:58:10	2020-08-08	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	14133	delivery	5	26
113385	2020-08-08 19:58:38	2020-08-08	14	[{"id_menu":2,"count":1}]	33592	delivery	5	19
113386	2020-08-08 19:58:42	2020-08-08	9	[{"id_menu":6,"count":1}]	9191	pick-up	0	9
113387	2020-08-08 19:58:56	2020-08-08	9	[{"id_menu":7,"count":1}]	13429	pick-up	0	9
113388	2020-08-08 20:00:24	2020-08-08	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	16878	delivery	5	28
113389	2020-08-08 20:03:06	2020-08-08	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15172	pick-up	0	17
113390	2020-08-08 20:04:07	2020-08-08	9	[{"id_menu":6,"count":1}]	23571	pick-up	0	9
113391	2020-08-08 20:05:25	2020-08-08	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	43203	delivery	5	25
113392	2020-08-08 20:07:24	2020-08-08	12	[{"id_menu":1,"count":1}]	23861	delivery	5	17
113527	2020-08-09 00:44:50	2020-08-09	9	[{"id_menu":7,"count":1}]	34128	delivery	5	14
113393	2020-08-08 20:07:36	2020-08-08	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	37824	delivery	5	48
113394	2020-08-08 20:08:13	2020-08-08	9	[{"id_menu":7,"count":2}]	37387	delivery	5	14
113395	2020-08-08 20:10:48	2020-08-08	17	[{"id_menu":4,"count":1}]	12002	delivery	5	22
113396	2020-08-08 20:10:49	2020-08-08	8	[{"id_menu":5,"count":1}]	31160	delivery	5	13
113397	2020-08-08 20:14:14	2020-08-08	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	14455	pick-up	0	22
113398	2020-08-08 20:15:01	2020-08-08	9	[{"id_menu":6,"count":1}]	14394	delivery	5	14
113399	2020-08-08 20:16:50	2020-08-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39827	delivery	5	22
113400	2020-08-08 20:22:27	2020-08-08	14	[{"id_menu":2,"count":1}]	3994	delivery	5	19
113401	2020-08-08 20:22:49	2020-08-08	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	36871	delivery	5	39
113402	2020-08-08 20:25:05	2020-08-08	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	13189	delivery	5	30
113403	2020-08-08 20:29:31	2020-08-08	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36007	delivery	5	23
113404	2020-08-08 20:30:40	2020-08-08	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	364	pick-up	0	26
113405	2020-08-08 20:34:44	2020-08-08	9	[{"id_menu":6,"count":1}]	43316	delivery	5	14
113406	2020-08-08 20:36:38	2020-08-08	9	[{"id_menu":7,"count":1}]	26361	delivery	5	14
113407	2020-08-08 20:38:05	2020-08-08	9	[{"id_menu":6,"count":1}]	9002	delivery	5	14
113408	2020-08-08 20:38:55	2020-08-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	43237	delivery	5	28
113409	2020-08-08 20:39:01	2020-08-08	14	[{"id_menu":2,"count":1}]	9688	pick-up	0	14
113410	2020-08-08 20:42:21	2020-08-08	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	16883	pick-up	0	26
113411	2020-08-08 20:47:14	2020-08-08	9	[{"id_menu":6,"count":1}]	14661	delivery	5	14
113412	2020-08-08 20:51:39	2020-08-08	9	[{"id_menu":6,"count":1}]	17499	delivery	5	14
113413	2020-08-08 20:55:08	2020-08-08	8	[{"id_menu":5,"count":1}]	35296	delivery	5	13
113414	2020-08-08 20:55:41	2020-08-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	23615	delivery	5	22
113415	2020-08-08 20:56:18	2020-08-08	17	[{"id_menu":4,"count":1}]	36999	delivery	5	22
113416	2020-08-08 21:00:58	2020-08-08	12	[{"id_menu":3,"count":1}]	8235	delivery	5	17
113417	2020-08-08 21:01:37	2020-08-08	9	[{"id_menu":7,"count":1}]	43282	delivery	5	14
113418	2020-08-08 21:01:59	2020-08-08	14	[{"id_menu":2,"count":1}]	43393	delivery	5	19
113419	2020-08-08 21:06:43	2020-08-08	12	[{"id_menu":3,"count":1}]	3971	pick-up	0	12
113420	2020-08-08 21:07:12	2020-08-08	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	43253	delivery	5	27
113421	2020-08-08 21:09:48	2020-08-08	9	[{"id_menu":7,"count":1}]	33568	delivery	5	14
113422	2020-08-08 21:10:49	2020-08-08	14	[{"id_menu":2,"count":1}]	24615	pick-up	0	14
113423	2020-08-08 21:11:38	2020-08-08	14	[{"id_menu":2,"count":1}]	43283	delivery	5	19
113424	2020-08-08 21:15:43	2020-08-08	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19702	delivery	5	22
113425	2020-08-08 21:16:14	2020-08-08	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1002	pick-up	0	26
113426	2020-08-08 21:22:45	2020-08-08	9	[{"id_menu":7,"count":1}]	23123	delivery	5	14
113427	2020-08-08 21:26:16	2020-08-08	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8358	delivery	5	52
113428	2020-08-08 21:28:08	2020-08-08	14	[{"id_menu":2,"count":1}]	43211	delivery	5	19
113429	2020-08-08 21:31:48	2020-08-08	12	[{"id_menu":3,"count":2}]	43222	delivery	5	17
113430	2020-08-08 21:33:12	2020-08-08	14	[{"id_menu":2,"count":1}]	33671	delivery	5	19
113431	2020-08-08 21:34:38	2020-08-08	12	[{"id_menu":3,"count":1}]	43197	delivery	5	17
113432	2020-08-08 21:35:17	2020-08-08	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20219	delivery	5	53
113433	2020-08-08 21:38:39	2020-08-08	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	43333	delivery	5	26
113434	2020-08-08 21:39:55	2020-08-08	12	[{"id_menu":1,"count":1}]	3864	pick-up	0	12
113435	2020-08-08 21:42:04	2020-08-08	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	43425	delivery	5	23
113436	2020-08-08 21:42:24	2020-08-08	17	[{"id_menu":4,"count":1}]	12649	delivery	5	22
113437	2020-08-08 21:45:10	2020-08-08	9	[{"id_menu":7,"count":1}]	43308	delivery	5	14
113438	2020-08-08 21:49:29	2020-08-08	17	[{"id_menu":4,"count":1}]	41735	delivery	5	22
113439	2020-08-08 21:52:32	2020-08-08	14	[{"id_menu":2,"count":1}]	43279	delivery	5	19
113440	2020-08-08 21:54:54	2020-08-08	14	[{"id_menu":2,"count":1}]	43281	pick-up	0	14
113441	2020-08-08 21:55:02	2020-08-08	9	[{"id_menu":7,"count":1}]	5480	delivery	5	14
113442	2020-08-08 21:55:31	2020-08-08	9	[{"id_menu":6,"count":1}]	1151	delivery	5	14
113443	2020-08-08 21:59:55	2020-08-08	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	43271	delivery	5	26
113444	2020-08-08 22:02:46	2020-08-08	8	[{"id_menu":5,"count":1}]	31903	pick-up	0	8
113445	2020-08-08 22:05:54	2020-08-08	12	[{"id_menu":1,"count":1}]	43430	pick-up	0	12
113446	2020-08-08 22:07:04	2020-08-08	8	[{"id_menu":5,"count":1}]	43212	delivery	5	13
113447	2020-08-08 22:09:11	2020-08-08	17	[{"id_menu":4,"count":1}]	43288	pick-up	0	17
113448	2020-08-08 22:11:01	2020-08-08	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	3747	pick-up	0	26
113449	2020-08-08 22:12:24	2020-08-08	9	[{"id_menu":7,"count":1}]	43336	delivery	5	14
113450	2020-08-08 22:13:34	2020-08-08	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	43400	delivery	5	34
113451	2020-08-08 22:16:50	2020-08-08	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	14867	delivery	5	23
113452	2020-08-08 22:16:57	2020-08-08	8	[{"id_menu":5,"count":1}]	38182	delivery	5	13
113453	2020-08-08 22:28:08	2020-08-08	17	[{"id_menu":4,"count":1}]	10063	delivery	5	22
113454	2020-08-08 22:32:36	2020-08-08	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43236	delivery	5	37
113455	2020-08-08 22:34:24	2020-08-08	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	37952	delivery	5	28
113456	2020-08-08 22:34:44	2020-08-08	12	[{"id_menu":1,"count":1}]	23554	delivery	5	17
113457	2020-08-08 22:34:45	2020-08-08	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	43399	delivery	5	22
113458	2020-08-08 22:35:15	2020-08-08	8	[{"id_menu":5,"count":2}]	40257	delivery	5	13
113459	2020-08-08 22:37:13	2020-08-08	14	[{"id_menu":2,"count":1}]	6849	delivery	5	19
113528	2020-08-09 00:45:24	2020-08-09	14	[{"id_menu":2,"count":1}]	2477	pick-up	0	14
113460	2020-08-08 22:37:21	2020-08-08	46	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	43339	delivery	5	51
113461	2020-08-08 22:37:46	2020-08-08	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	10461	delivery	5	31
113462	2020-08-08 22:39:47	2020-08-08	12	[{"id_menu":1,"count":1}]	2272	pick-up	0	12
113463	2020-08-08 22:43:14	2020-08-08	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	34917	delivery	5	27
113464	2020-08-08 22:49:07	2020-08-08	14	[{"id_menu":2,"count":1}]	6530	delivery	5	19
113465	2020-08-08 22:49:51	2020-08-08	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	7623	delivery	5	46
113466	2020-08-08 22:49:54	2020-08-08	17	[{"id_menu":4,"count":1}]	43384	delivery	5	22
113467	2020-08-08 22:54:03	2020-08-08	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	43174	delivery	5	43
113468	2020-08-08 22:59:58	2020-08-08	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	39461	delivery	5	31
113469	2020-08-08 22:59:59	2020-08-08	14	[{"id_menu":2,"count":1}]	20783	delivery	5	19
113470	2020-08-08 23:01:39	2020-08-08	12	[{"id_menu":3,"count":1}]	43196	delivery	5	17
113471	2020-08-08 23:05:42	2020-08-08	9	[{"id_menu":6,"count":1}]	3371	delivery	5	14
113472	2020-08-08 23:06:36	2020-08-08	12	[{"id_menu":3,"count":1}]	42149	delivery	5	17
113473	2020-08-08 23:07:21	2020-08-08	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	43259	delivery	5	38
113474	2020-08-08 23:08:18	2020-08-08	14	[{"id_menu":2,"count":1}]	7603	delivery	5	19
113475	2020-08-08 23:14:14	2020-08-08	12	[{"id_menu":1,"count":1}]	43394	delivery	5	17
113476	2020-08-08 23:14:14	2020-08-08	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	43252	delivery	5	25
113477	2020-08-08 23:15:50	2020-08-08	14	[{"id_menu":2,"count":1}]	43364	delivery	5	19
113478	2020-08-08 23:16:43	2020-08-08	9	[{"id_menu":6,"count":1}]	19490	pick-up	0	9
113479	2020-08-08 23:18:41	2020-08-08	9	[{"id_menu":6,"count":1}]	22462	delivery	5	14
113480	2020-08-08 23:20:44	2020-08-08	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	13767	pick-up	0	29
113481	2020-08-08 23:25:11	2020-08-08	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	33765	delivery	5	31
113482	2020-08-08 23:30:42	2020-08-08	12	[{"id_menu":1,"count":1}]	22572	delivery	5	17
113483	2020-08-08 23:30:52	2020-08-08	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	41674	delivery	5	23
113484	2020-08-08 23:33:56	2020-08-08	9	[{"id_menu":6,"count":1}]	43210	delivery	5	14
113485	2020-08-08 23:34:28	2020-08-08	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	43266	delivery	5	28
113486	2020-08-08 23:39:29	2020-08-08	9	[{"id_menu":6,"count":2}]	35937	delivery	5	14
113487	2020-08-08 23:41:46	2020-08-08	9	[{"id_menu":7,"count":1}]	43301	delivery	5	14
113488	2020-08-08 23:43:26	2020-08-08	8	[{"id_menu":5,"count":1}]	4190	delivery	5	13
113489	2020-08-08 23:49:32	2020-08-08	14	[{"id_menu":2,"count":1}]	37924	delivery	5	19
113490	2020-08-08 23:51:21	2020-08-08	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	43382	delivery	5	43
113491	2020-08-08 23:51:21	2020-08-08	12	[{"id_menu":1,"count":1}]	43186	delivery	5	17
113492	2020-08-08 23:54:22	2020-08-08	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	32141	pick-up	0	34
113493	2020-08-08 23:57:19	2020-08-08	8	[{"id_menu":5,"count":1}]	43265	pick-up	0	8
113494	2020-08-08 23:58:44	2020-08-08	14	[{"id_menu":2,"count":1}]	25570	delivery	5	19
113495	2020-08-09 00:02:30	2020-08-09	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1451	pick-up	0	31
113496	2020-08-09 00:02:42	2020-08-09	12	[{"id_menu":3,"count":1}]	43666	delivery	5	17
113497	2020-08-09 00:05:19	2020-08-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	12132	delivery	5	28
113498	2020-08-09 00:06:18	2020-08-09	12	[{"id_menu":3,"count":1}]	43683	delivery	5	17
113499	2020-08-09 00:07:00	2020-08-09	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	26361	delivery	5	25
113500	2020-08-09 00:07:37	2020-08-09	9	[{"id_menu":7,"count":1}]	5048	pick-up	0	9
113501	2020-08-09 00:10:59	2020-08-09	12	[{"id_menu":1,"count":1}]	24069	delivery	5	17
113502	2020-08-09 00:12:26	2020-08-09	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":2}]	25490	delivery	5	28
113503	2020-08-09 00:12:32	2020-08-09	9	[{"id_menu":6,"count":1}]	43539	pick-up	0	9
113504	2020-08-09 00:14:42	2020-08-09	8	[{"id_menu":5,"count":1}]	39430	delivery	5	13
113505	2020-08-09 00:15:24	2020-08-09	14	[{"id_menu":2,"count":1}]	15091	delivery	5	19
113506	2020-08-09 00:16:00	2020-08-09	12	[{"id_menu":1,"count":1}]	43460	pick-up	0	12
113507	2020-08-09 00:17:04	2020-08-09	9	[{"id_menu":6,"count":1}]	21474	delivery	5	14
113508	2020-08-09 00:18:21	2020-08-09	8	[{"id_menu":5,"count":1}]	18374	pick-up	0	8
113509	2020-08-09 00:18:26	2020-08-09	9	[{"id_menu":6,"count":1}]	511	delivery	5	14
113510	2020-08-09 00:23:33	2020-08-09	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43604	delivery	5	45
113511	2020-08-09 00:27:16	2020-08-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	609	pick-up	0	17
113512	2020-08-09 00:28:19	2020-08-09	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	34822	pick-up	0	31
113513	2020-08-09 00:28:37	2020-08-09	14	[{"id_menu":2,"count":1}]	42887	pick-up	0	14
113514	2020-08-09 00:28:45	2020-08-09	8	[{"id_menu":5,"count":1}]	7489	delivery	5	13
113515	2020-08-09 00:30:07	2020-08-09	9	[{"id_menu":6,"count":1}]	30789	delivery	5	14
113516	2020-08-09 00:32:15	2020-08-09	12	[{"id_menu":1,"count":1}]	37344	delivery	5	17
113517	2020-08-09 00:33:31	2020-08-09	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30309	delivery	5	35
113518	2020-08-09 00:33:57	2020-08-09	9	[{"id_menu":7,"count":1}]	8399	delivery	5	14
113519	2020-08-09 00:35:43	2020-08-09	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":3}]	17188	delivery	5	31
113520	2020-08-09 00:35:50	2020-08-09	9	[{"id_menu":6,"count":1}]	3621	delivery	5	14
113521	2020-08-09 00:36:02	2020-08-09	14	[{"id_menu":2,"count":1}]	20389	delivery	5	19
113522	2020-08-09 00:36:54	2020-08-09	9	[{"id_menu":7,"count":1}]	5485	delivery	5	14
113523	2020-08-09 00:37:15	2020-08-09	9	[{"id_menu":6,"count":1}]	526	delivery	5	14
113524	2020-08-09 00:39:23	2020-08-09	9	[{"id_menu":6,"count":1}]	10820	delivery	5	14
113525	2020-08-09 00:41:02	2020-08-09	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	43577	delivery	5	34
113526	2020-08-09 00:43:48	2020-08-09	9	[{"id_menu":6,"count":1}]	41245	delivery	5	14
113529	2020-08-09 00:45:26	2020-08-09	14	[{"id_menu":2,"count":1}]	5945	delivery	5	19
113530	2020-08-09 00:45:37	2020-08-09	14	[{"id_menu":2,"count":1}]	1177	pick-up	0	14
113531	2020-08-09 00:49:31	2020-08-09	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	8253	delivery	5	28
113532	2020-08-09 00:53:16	2020-08-09	9	[{"id_menu":6,"count":1}]	25944	pick-up	0	9
113533	2020-08-09 00:54:16	2020-08-09	12	[{"id_menu":1,"count":1}]	19653	delivery	5	17
113534	2020-08-09 00:54:25	2020-08-09	17	[{"id_menu":4,"count":1}]	30281	pick-up	0	17
113535	2020-08-09 00:55:10	2020-08-09	17	[{"id_menu":4,"count":1}]	2470	pick-up	0	17
113536	2020-08-09 00:56:32	2020-08-09	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1334	delivery	5	27
113537	2020-08-09 00:56:38	2020-08-09	8	[{"id_menu":5,"count":1}]	43543	delivery	5	13
113538	2020-08-09 01:06:08	2020-08-09	17	[{"id_menu":4,"count":1}]	43628	delivery	5	22
113539	2020-08-09 01:06:47	2020-08-09	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	43580	delivery	5	31
113540	2020-08-09 01:08:00	2020-08-09	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	8597	delivery	5	25
113541	2020-08-09 01:09:57	2020-08-09	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43442	delivery	5	37
113542	2020-08-09 01:10:12	2020-08-09	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13962	delivery	5	34
113543	2020-08-09 01:13:46	2020-08-09	9	[{"id_menu":6,"count":1}]	43521	delivery	5	14
113544	2020-08-09 01:15:24	2020-08-09	8	[{"id_menu":5,"count":1}]	43464	delivery	5	13
113545	2020-08-09 01:15:38	2020-08-09	12	[{"id_menu":1,"count":1}]	1282	delivery	5	17
113546	2020-08-09 01:15:47	2020-08-09	12	[{"id_menu":3,"count":1}]	34986	delivery	5	17
113547	2020-08-09 01:17:21	2020-08-09	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9923	delivery	5	22
113548	2020-08-09 01:18:02	2020-08-09	14	[{"id_menu":2,"count":1}]	8657	delivery	5	19
113549	2020-08-09 01:18:57	2020-08-09	9	[{"id_menu":7,"count":1}]	8697	delivery	5	14
113550	2020-08-09 01:19:55	2020-08-09	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	43554	delivery	5	38
113551	2020-08-09 01:22:02	2020-08-09	9	[{"id_menu":7,"count":2}]	43466	delivery	5	14
113552	2020-08-09 01:23:12	2020-08-09	8	[{"id_menu":5,"count":1}]	18598	delivery	5	13
113553	2020-08-09 01:27:51	2020-08-09	17	[{"id_menu":4,"count":1}]	12369	delivery	5	22
113554	2020-08-09 01:29:24	2020-08-09	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	40743	delivery	5	31
113555	2020-08-09 01:32:54	2020-08-09	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	43601	delivery	5	22
113556	2020-08-09 01:33:31	2020-08-09	14	[{"id_menu":2,"count":1}]	21618	pick-up	0	14
113557	2020-08-09 01:33:35	2020-08-09	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13051	delivery	5	43
113558	2020-08-09 01:34:01	2020-08-09	14	[{"id_menu":2,"count":1}]	28579	delivery	5	19
113559	2020-08-09 01:39:14	2020-08-09	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	12484	pick-up	0	26
113560	2020-08-09 01:39:15	2020-08-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43617	delivery	5	23
113561	2020-08-09 01:42:19	2020-08-09	14	[{"id_menu":2,"count":1}]	13193	delivery	5	19
113562	2020-08-09 01:43:45	2020-08-09	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	43540	delivery	5	40
113563	2020-08-09 01:44:17	2020-08-09	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	29754	delivery	5	40
113564	2020-08-09 01:50:01	2020-08-09	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	26255	delivery	5	22
113565	2020-08-09 01:51:32	2020-08-09	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	37257	delivery	5	23
113566	2020-08-09 01:52:50	2020-08-09	12	[{"id_menu":1,"count":1}]	17959	delivery	5	17
113567	2020-08-09 01:56:55	2020-08-09	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	16621	delivery	5	26
113568	2020-08-09 01:58:17	2020-08-09	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	32097	pick-up	0	26
113569	2020-08-09 02:00:23	2020-08-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	43667	delivery	5	28
113570	2020-08-09 02:00:55	2020-08-09	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	43595	delivery	5	29
113571	2020-08-09 02:01:09	2020-08-09	9	[{"id_menu":7,"count":1}]	3814	pick-up	0	9
113572	2020-08-09 02:02:40	2020-08-09	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	40608	delivery	5	36
113573	2020-08-09 02:03:06	2020-08-09	8	[{"id_menu":5,"count":1}]	620	delivery	5	13
113574	2020-08-09 02:04:46	2020-08-09	8	[{"id_menu":5,"count":1}]	43534	delivery	5	13
113575	2020-08-09 02:05:27	2020-08-09	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	35534	delivery	5	36
113576	2020-08-09 02:05:28	2020-08-09	9	[{"id_menu":7,"count":1}]	2203	delivery	5	14
113577	2020-08-09 02:06:56	2020-08-09	9	[{"id_menu":6,"count":1}]	41533	delivery	5	14
113578	2020-08-09 02:08:33	2020-08-09	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	43317	delivery	5	29
113579	2020-08-09 02:10:23	2020-08-09	14	[{"id_menu":2,"count":1}]	43545	delivery	5	19
113580	2020-08-09 02:14:15	2020-08-09	17	[{"id_menu":4,"count":1}]	20983	delivery	5	22
113581	2020-08-09 02:14:35	2020-08-09	17	[{"id_menu":4,"count":1}]	28586	pick-up	0	17
113582	2020-08-09 02:15:34	2020-08-09	14	[{"id_menu":2,"count":1}]	22722	delivery	5	19
113583	2020-08-09 02:15:45	2020-08-09	8	[{"id_menu":5,"count":1}]	43643	delivery	5	13
113584	2020-08-09 02:17:04	2020-08-09	17	[{"id_menu":4,"count":2}]	18770	pick-up	0	17
113585	2020-08-09 02:18:25	2020-08-09	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	30262	delivery	5	26
113586	2020-08-09 02:21:26	2020-08-09	9	[{"id_menu":7,"count":1}]	24313	delivery	5	14
113587	2020-08-09 02:22:00	2020-08-09	12	[{"id_menu":1,"count":1}]	30594	delivery	5	17
113588	2020-08-09 02:24:00	2020-08-09	12	[{"id_menu":1,"count":1}]	43640	pick-up	0	12
113589	2020-08-09 02:24:43	2020-08-09	17	[{"id_menu":4,"count":1}]	43701	delivery	5	22
113590	2020-08-09 02:25:13	2020-08-09	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	43559	delivery	5	31
113591	2020-08-09 02:26:15	2020-08-09	14	[{"id_menu":2,"count":1}]	37896	delivery	5	19
113592	2020-08-09 02:27:24	2020-08-09	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	43549	delivery	5	35
113593	2020-08-09 02:28:17	2020-08-09	12	[{"id_menu":1,"count":1}]	43468	delivery	5	17
113594	2020-08-09 02:28:42	2020-08-09	9	[{"id_menu":6,"count":1}]	9766	delivery	5	14
113595	2020-08-09 02:30:38	2020-08-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43681	delivery	5	23
113596	2020-08-09 02:31:05	2020-08-09	9	[{"id_menu":7,"count":1}]	17673	delivery	5	14
113597	2020-08-09 02:31:44	2020-08-09	8	[{"id_menu":5,"count":1}]	43463	delivery	5	13
113598	2020-08-09 02:32:03	2020-08-09	14	[{"id_menu":2,"count":1}]	43660	pick-up	0	14
113599	2020-08-09 02:33:30	2020-08-09	14	[{"id_menu":2,"count":1}]	24964	pick-up	0	14
113600	2020-08-09 02:33:35	2020-08-09	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2605	delivery	5	26
113601	2020-08-09 02:35:08	2020-08-09	8	[{"id_menu":5,"count":1}]	36196	delivery	5	13
113602	2020-08-09 02:35:30	2020-08-09	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	43603	delivery	5	40
113603	2020-08-09 02:36:50	2020-08-09	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	23633	delivery	5	27
113604	2020-08-09 02:37:13	2020-08-09	8	[{"id_menu":5,"count":1}]	21444	delivery	5	13
113605	2020-08-09 02:37:41	2020-08-09	9	[{"id_menu":6,"count":1}]	39596	delivery	5	14
113606	2020-08-09 02:39:28	2020-08-09	17	[{"id_menu":4,"count":1}]	41825	delivery	5	22
113607	2020-08-09 02:39:30	2020-08-09	12	[{"id_menu":3,"count":1}]	24899	delivery	5	17
113608	2020-08-09 02:41:09	2020-08-09	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	43500	delivery	5	25
113609	2020-08-09 02:42:25	2020-08-09	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	43646	delivery	5	43
113610	2020-08-09 02:45:27	2020-08-09	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	17594	pick-up	0	31
113611	2020-08-09 02:48:59	2020-08-09	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	14320	delivery	5	43
113612	2020-08-09 02:49:30	2020-08-09	14	[{"id_menu":2,"count":1}]	40196	delivery	5	19
113613	2020-08-09 02:49:33	2020-08-09	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	43592	delivery	5	38
113614	2020-08-09 02:49:46	2020-08-09	9	[{"id_menu":6,"count":1}]	9749	delivery	5	14
113615	2020-08-09 02:51:29	2020-08-09	12	[{"id_menu":3,"count":1}]	40233	delivery	5	17
113616	2020-08-09 02:54:31	2020-08-09	14	[{"id_menu":2,"count":1}]	43520	pick-up	0	14
113617	2020-08-09 02:56:18	2020-08-09	38	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	33251	pick-up	0	38
113618	2020-08-09 02:58:57	2020-08-09	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2076	pick-up	0	21
113619	2020-08-09 03:00:50	2020-08-09	8	[{"id_menu":5,"count":1}]	38197	delivery	5	13
113620	2020-08-09 03:01:34	2020-08-09	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	13285	delivery	5	43
113621	2020-08-09 03:01:57	2020-08-09	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1933	pick-up	0	25
113622	2020-08-09 03:02:33	2020-08-09	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	43616	delivery	5	26
113623	2020-08-09 03:04:25	2020-08-09	9	[{"id_menu":6,"count":1}]	2050	delivery	5	14
113624	2020-08-09 03:06:08	2020-08-09	9	[{"id_menu":7,"count":1}]	43457	delivery	5	14
113625	2020-08-09 03:07:07	2020-08-09	14	[{"id_menu":2,"count":1}]	14127	pick-up	0	14
113626	2020-08-09 03:08:39	2020-08-09	12	[{"id_menu":1,"count":1}]	38368	delivery	5	17
113627	2020-08-09 03:08:57	2020-08-09	9	[{"id_menu":6,"count":2}]	43538	delivery	5	14
113628	2020-08-09 03:10:54	2020-08-09	9	[{"id_menu":6,"count":1}]	33578	delivery	5	14
113629	2020-08-09 03:11:22	2020-08-09	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	28244	delivery	5	27
113630	2020-08-09 03:17:13	2020-08-09	9	[{"id_menu":6,"count":1}]	11969	pick-up	0	9
113631	2020-08-09 03:19:45	2020-08-09	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	43478	delivery	5	31
113632	2020-08-09 03:22:56	2020-08-09	9	[{"id_menu":6,"count":1}]	6873	delivery	5	14
113633	2020-08-09 03:22:58	2020-08-09	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	34272	pick-up	0	29
113634	2020-08-09 03:28:50	2020-08-09	17	[{"id_menu":4,"count":1}]	5600	delivery	5	22
113635	2020-08-09 03:29:07	2020-08-09	9	[{"id_menu":6,"count":1}]	7582	pick-up	0	9
113636	2020-08-09 03:29:12	2020-08-09	9	[{"id_menu":6,"count":1}]	41141	delivery	5	14
113637	2020-08-09 03:30:51	2020-08-09	12	[{"id_menu":1,"count":1}]	32491	pick-up	0	12
113638	2020-08-09 03:31:21	2020-08-09	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	23828	delivery	5	48
113639	2020-08-09 03:31:42	2020-08-09	17	[{"id_menu":4,"count":1}]	33747	pick-up	0	17
113640	2020-08-09 03:38:24	2020-08-09	9	[{"id_menu":6,"count":1}]	43487	delivery	5	14
113641	2020-08-09 03:39:52	2020-08-09	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	43568	delivery	5	27
113642	2020-08-09 03:40:12	2020-08-09	14	[{"id_menu":2,"count":2}]	1414	delivery	5	19
113643	2020-08-09 03:43:02	2020-08-09	17	[{"id_menu":4,"count":1}]	21357	pick-up	0	17
113644	2020-08-09 03:43:32	2020-08-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3802	delivery	5	22
113645	2020-08-09 03:44:12	2020-08-09	12	[{"id_menu":1,"count":1}]	43695	delivery	5	17
113646	2020-08-09 03:45:34	2020-08-09	14	[{"id_menu":2,"count":1}]	32810	delivery	5	19
113647	2020-08-09 03:46:02	2020-08-09	14	[{"id_menu":2,"count":1}]	43273	pick-up	0	14
113648	2020-08-09 03:47:17	2020-08-09	17	[{"id_menu":4,"count":1}]	24668	delivery	5	22
113649	2020-08-09 03:52:16	2020-08-09	17	[{"id_menu":4,"count":1}]	43447	delivery	5	22
113650	2020-08-09 03:52:25	2020-08-09	14	[{"id_menu":2,"count":1}]	53	pick-up	0	14
113651	2020-08-09 03:56:50	2020-08-09	8	[{"id_menu":5,"count":1}]	1263	pick-up	0	8
113652	2020-08-09 03:57:29	2020-08-09	12	[{"id_menu":1,"count":1}]	43493	delivery	5	17
113653	2020-08-09 04:01:54	2020-08-09	17	[{"id_menu":4,"count":1}]	43685	delivery	5	22
113654	2020-08-09 04:02:20	2020-08-09	14	[{"id_menu":2,"count":1}]	38090	delivery	5	19
113655	2020-08-09 04:03:43	2020-08-09	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	43644	delivery	5	35
113656	2020-08-09 04:05:19	2020-08-09	8	[{"id_menu":5,"count":1}]	43525	delivery	5	13
113657	2020-08-09 04:07:00	2020-08-09	14	[{"id_menu":2,"count":1}]	35464	delivery	5	19
113658	2020-08-09 04:07:08	2020-08-09	17	[{"id_menu":4,"count":1}]	43655	delivery	5	22
113659	2020-08-09 04:11:11	2020-08-09	14	[{"id_menu":2,"count":1}]	265	delivery	5	19
113660	2020-08-09 04:12:52	2020-08-09	17	[{"id_menu":4,"count":1}]	15134	delivery	5	22
113661	2020-08-09 04:13:56	2020-08-09	17	[{"id_menu":4,"count":1}]	1296	pick-up	0	17
113662	2020-08-09 04:14:48	2020-08-09	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35141	delivery	5	37
113663	2020-08-09 04:16:30	2020-08-09	9	[{"id_menu":6,"count":1}]	43622	delivery	5	14
113664	2020-08-09 04:17:07	2020-08-09	17	[{"id_menu":4,"count":1}]	1592	delivery	5	22
113665	2020-08-09 04:17:37	2020-08-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5306	pick-up	0	17
113666	2020-08-09 04:18:40	2020-08-09	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	18337	delivery	5	26
113667	2020-08-09 04:20:28	2020-08-09	8	[{"id_menu":5,"count":1}]	39340	pick-up	0	8
113668	2020-08-09 04:20:38	2020-08-09	9	[{"id_menu":6,"count":1}]	2783	delivery	5	14
113669	2020-08-09 04:21:12	2020-08-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	36451	delivery	5	28
113670	2020-08-09 04:21:32	2020-08-09	8	[{"id_menu":5,"count":1}]	26380	delivery	5	13
113671	2020-08-09 04:23:27	2020-08-09	9	[{"id_menu":7,"count":1}]	14721	delivery	5	14
113672	2020-08-09 04:23:28	2020-08-09	9	[{"id_menu":7,"count":1}]	43631	delivery	5	14
113673	2020-08-09 04:23:48	2020-08-09	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12474	pick-up	0	29
113674	2020-08-09 04:27:18	2020-08-09	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	37342	delivery	5	22
113675	2020-08-09 04:27:29	2020-08-09	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	43584	delivery	5	30
113676	2020-08-09 04:28:10	2020-08-09	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2351	pick-up	0	38
113677	2020-08-09 04:28:37	2020-08-09	9	[{"id_menu":7,"count":1}]	43514	pick-up	0	9
113678	2020-08-09 04:30:03	2020-08-09	17	[{"id_menu":4,"count":1}]	29036	delivery	5	22
113679	2020-08-09 04:30:40	2020-08-09	17	[{"id_menu":4,"count":1}]	36279	delivery	5	22
113680	2020-08-09 04:31:02	2020-08-09	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	34375	delivery	5	36
113681	2020-08-09 04:33:31	2020-08-09	17	[{"id_menu":4,"count":2}]	18821	delivery	5	22
113682	2020-08-09 04:33:33	2020-08-09	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	22708	pick-up	0	24
113683	2020-08-09 04:35:23	2020-08-09	14	[{"id_menu":2,"count":1}]	43523	delivery	5	19
113684	2020-08-09 04:40:45	2020-08-09	9	[{"id_menu":6,"count":1}]	43503	delivery	5	14
113685	2020-08-09 04:44:09	2020-08-09	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43506	delivery	5	45
113686	2020-08-09 04:44:43	2020-08-09	9	[{"id_menu":7,"count":1}]	43444	delivery	5	14
113687	2020-08-09 04:45:31	2020-08-09	9	[{"id_menu":7,"count":1}]	35571	delivery	5	14
113688	2020-08-09 04:45:35	2020-08-09	14	[{"id_menu":2,"count":2}]	22744	delivery	5	19
113689	2020-08-09 04:46:34	2020-08-09	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	17534	delivery	5	34
113690	2020-08-09 04:49:36	2020-08-09	9	[{"id_menu":6,"count":1}]	43609	delivery	5	14
113691	2020-08-09 04:51:37	2020-08-09	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	41727	delivery	5	22
113692	2020-08-09 04:52:40	2020-08-09	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	38379	delivery	5	34
113693	2020-08-09 04:55:49	2020-08-09	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32009	delivery	5	43
113694	2020-08-09 04:56:56	2020-08-09	8	[{"id_menu":5,"count":1}]	6947	pick-up	0	8
113695	2020-08-09 05:04:31	2020-08-09	12	[{"id_menu":1,"count":1}]	35804	pick-up	0	12
113696	2020-08-09 05:05:12	2020-08-09	8	[{"id_menu":5,"count":1}]	4578	delivery	5	13
113697	2020-08-09 05:06:56	2020-08-09	9	[{"id_menu":7,"count":1}]	7817	pick-up	0	9
113698	2020-08-09 05:07:38	2020-08-09	14	[{"id_menu":2,"count":1}]	4688	delivery	5	19
113699	2020-08-09 05:07:45	2020-08-09	17	[{"id_menu":4,"count":1}]	43647	delivery	5	22
113700	2020-08-09 05:10:35	2020-08-09	9	[{"id_menu":6,"count":1}]	43475	delivery	5	14
113701	2020-08-09 05:11:11	2020-08-09	8	[{"id_menu":5,"count":1}]	32451	delivery	5	13
113702	2020-08-09 05:13:47	2020-08-09	9	[{"id_menu":6,"count":1}]	34254	delivery	5	14
113703	2020-08-09 05:14:02	2020-08-09	12	[{"id_menu":1,"count":1}]	43671	delivery	5	17
113704	2020-08-09 05:14:05	2020-08-09	9	[{"id_menu":7,"count":1}]	43578	delivery	5	14
113705	2020-08-09 05:15:31	2020-08-09	9	[{"id_menu":6,"count":1}]	15454	delivery	5	14
113706	2020-08-09 05:16:55	2020-08-09	8	[{"id_menu":5,"count":1}]	43637	delivery	5	13
113707	2020-08-09 05:17:31	2020-08-09	12	[{"id_menu":3,"count":1}]	29728	delivery	5	17
113708	2020-08-09 05:23:02	2020-08-09	8	[{"id_menu":5,"count":1}]	8609	pick-up	0	8
113709	2020-08-09 05:23:37	2020-08-09	9	[{"id_menu":7,"count":1}]	17153	delivery	5	14
113710	2020-08-09 05:24:21	2020-08-09	12	[{"id_menu":3,"count":1}]	43524	delivery	5	17
113711	2020-08-09 05:24:57	2020-08-09	14	[{"id_menu":2,"count":2}]	43678	delivery	5	19
113712	2020-08-09 05:29:25	2020-08-09	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15996	delivery	5	40
113713	2020-08-09 05:30:31	2020-08-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36858	delivery	5	23
113714	2020-08-09 05:30:37	2020-08-09	17	[{"id_menu":4,"count":1}]	22626	pick-up	0	17
113715	2020-08-09 05:31:43	2020-08-09	8	[{"id_menu":5,"count":1}]	42579	delivery	5	13
113716	2020-08-09 05:33:08	2020-08-09	14	[{"id_menu":2,"count":1}]	43675	delivery	5	19
113717	2020-08-09 05:36:49	2020-08-09	17	[{"id_menu":4,"count":1}]	43591	pick-up	0	17
113718	2020-08-09 05:37:00	2020-08-09	17	[{"id_menu":4,"count":1}]	3155	pick-up	0	17
113719	2020-08-09 05:37:39	2020-08-09	9	[{"id_menu":6,"count":1}]	39130	delivery	5	14
113720	2020-08-09 05:38:52	2020-08-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	14302	delivery	5	28
113721	2020-08-09 05:39:04	2020-08-09	9	[{"id_menu":7,"count":1}]	43474	delivery	5	14
113722	2020-08-09 05:39:57	2020-08-09	14	[{"id_menu":2,"count":1}]	29823	pick-up	0	14
113723	2020-08-09 05:41:15	2020-08-09	9	[{"id_menu":6,"count":2}]	14081	delivery	5	14
113724	2020-08-09 05:41:37	2020-08-09	14	[{"id_menu":2,"count":1}]	43551	pick-up	0	14
113725	2020-08-09 05:44:03	2020-08-09	12	[{"id_menu":1,"count":1}]	34812	delivery	5	17
113726	2020-08-09 05:44:10	2020-08-09	8	[{"id_menu":5,"count":1}]	19580	delivery	5	13
113727	2020-08-09 05:44:24	2020-08-09	12	[{"id_menu":3,"count":1}]	24404	delivery	5	17
113728	2020-08-09 05:44:52	2020-08-09	17	[{"id_menu":4,"count":1}]	6310	delivery	5	22
113729	2020-08-09 05:47:05	2020-08-09	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15820	delivery	5	34
113730	2020-08-09 05:47:40	2020-08-09	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7623	delivery	5	45
113731	2020-08-09 05:47:51	2020-08-09	9	[{"id_menu":6,"count":1}]	9748	pick-up	0	9
113732	2020-08-09 05:48:52	2020-08-09	9	[{"id_menu":7,"count":2}]	32625	delivery	5	14
113733	2020-08-09 05:49:21	2020-08-09	9	[{"id_menu":6,"count":1}]	6730	delivery	5	14
113734	2020-08-09 05:50:36	2020-08-09	12	[{"id_menu":1,"count":1}]	37439	pick-up	0	12
113735	2020-08-09 05:53:19	2020-08-09	17	[{"id_menu":4,"count":1}]	42904	delivery	5	22
113736	2020-08-09 05:53:23	2020-08-09	9	[{"id_menu":6,"count":1}]	7345	delivery	5	14
113737	2020-08-09 05:55:01	2020-08-09	17	[{"id_menu":4,"count":1}]	9682	pick-up	0	17
113738	2020-08-09 05:55:14	2020-08-09	8	[{"id_menu":5,"count":1}]	2725	pick-up	0	8
113739	2020-08-09 05:56:18	2020-08-09	8	[{"id_menu":5,"count":1}]	1781	pick-up	0	8
113740	2020-08-09 05:58:54	2020-08-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32727	delivery	5	22
113741	2020-08-09 05:59:13	2020-08-09	14	[{"id_menu":2,"count":1}]	4684	delivery	5	19
113742	2020-08-09 05:59:46	2020-08-09	8	[{"id_menu":5,"count":1}]	16181	delivery	5	13
113743	2020-08-09 05:59:56	2020-08-09	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	27623	delivery	5	31
113744	2020-08-09 06:01:48	2020-08-09	17	[{"id_menu":4,"count":1}]	43700	delivery	5	22
113745	2020-08-09 06:02:04	2020-08-09	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	40314	delivery	5	37
113746	2020-08-09 06:02:32	2020-08-09	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	26966	delivery	5	31
113747	2020-08-09 06:06:24	2020-08-09	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	330	pick-up	0	29
113748	2020-08-09 06:07:16	2020-08-09	9	[{"id_menu":7,"count":1}]	28186	delivery	5	14
113749	2020-08-09 06:08:10	2020-08-09	14	[{"id_menu":2,"count":1}]	9977	delivery	5	19
113750	2020-08-09 06:10:29	2020-08-09	8	[{"id_menu":5,"count":1}]	227	pick-up	0	8
113751	2020-08-09 06:11:21	2020-08-09	49	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	813	pick-up	0	49
113752	2020-08-09 06:11:52	2020-08-09	9	[{"id_menu":6,"count":1}]	43633	delivery	5	14
113753	2020-08-09 06:13:15	2020-08-09	12	[{"id_menu":3,"count":1}]	43582	delivery	5	17
113754	2020-08-09 06:13:18	2020-08-09	8	[{"id_menu":5,"count":1}]	43528	delivery	5	13
113755	2020-08-09 06:14:10	2020-08-09	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	36159	delivery	5	36
113756	2020-08-09 06:15:41	2020-08-09	8	[{"id_menu":5,"count":1}]	43512	delivery	5	13
113757	2020-08-09 06:16:14	2020-08-09	17	[{"id_menu":4,"count":1}]	1306	delivery	5	22
113758	2020-08-09 06:18:58	2020-08-09	9	[{"id_menu":6,"count":1}]	43496	delivery	5	14
113759	2020-08-09 06:21:36	2020-08-09	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	40936	delivery	5	26
113760	2020-08-09 06:21:58	2020-08-09	9	[{"id_menu":7,"count":1}]	43558	delivery	5	14
113761	2020-08-09 06:24:02	2020-08-09	9	[{"id_menu":6,"count":1}]	43515	delivery	5	14
113762	2020-08-09 06:26:45	2020-08-09	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	43621	delivery	5	55
113763	2020-08-09 06:26:51	2020-08-09	9	[{"id_menu":7,"count":1}]	32339	delivery	5	14
113764	2020-08-09 06:26:58	2020-08-09	14	[{"id_menu":2,"count":1}]	2615	pick-up	0	14
113765	2020-08-09 06:27:30	2020-08-09	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	43086	delivery	5	26
113766	2020-08-09 06:28:26	2020-08-09	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	27514	delivery	5	35
113767	2020-08-09 06:32:48	2020-08-09	17	[{"id_menu":4,"count":1}]	43669	delivery	5	22
113768	2020-08-09 06:32:50	2020-08-09	9	[{"id_menu":6,"count":1}]	43648	delivery	5	14
113769	2020-08-09 06:33:41	2020-08-09	8	[{"id_menu":5,"count":1}]	13490	delivery	5	13
113770	2020-08-09 06:33:42	2020-08-09	12	[{"id_menu":3,"count":1}]	20009	pick-up	0	12
113771	2020-08-09 06:34:15	2020-08-09	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	138	pick-up	0	21
113772	2020-08-09 06:38:20	2020-08-09	12	[{"id_menu":1,"count":1}]	39203	delivery	5	17
113773	2020-08-09 06:40:27	2020-08-09	12	[{"id_menu":1,"count":1}]	30904	delivery	5	17
113774	2020-08-09 06:42:10	2020-08-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	27941	pick-up	0	23
113775	2020-08-09 06:42:32	2020-08-09	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	43602	delivery	5	45
113776	2020-08-09 06:46:05	2020-08-09	14	[{"id_menu":2,"count":1}]	43555	delivery	5	19
113777	2020-08-09 06:46:27	2020-08-09	9	[{"id_menu":7,"count":1}]	6470	delivery	5	14
113778	2020-08-09 06:47:02	2020-08-09	12	[{"id_menu":3,"count":1}]	14661	pick-up	0	12
113779	2020-08-09 06:48:13	2020-08-09	14	[{"id_menu":2,"count":1}]	43495	pick-up	0	14
113780	2020-08-09 06:50:08	2020-08-09	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	28295	delivery	5	43
113781	2020-08-09 06:52:46	2020-08-09	9	[{"id_menu":7,"count":1}]	27679	delivery	5	14
113782	2020-08-09 06:53:02	2020-08-09	9	[{"id_menu":7,"count":1}]	23074	delivery	5	14
113783	2020-08-09 06:53:48	2020-08-09	14	[{"id_menu":2,"count":1}]	12977	delivery	5	19
113784	2020-08-09 06:53:48	2020-08-09	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	14433	delivery	5	37
113785	2020-08-09 06:56:01	2020-08-09	8	[{"id_menu":5,"count":1}]	38913	delivery	5	13
113786	2020-08-09 06:56:02	2020-08-09	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20250	delivery	5	34
113787	2020-08-09 06:56:17	2020-08-09	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18332	delivery	5	22
113788	2020-08-09 06:56:25	2020-08-09	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	3684	delivery	5	25
113789	2020-08-09 06:56:40	2020-08-09	12	[{"id_menu":3,"count":1}]	28237	delivery	5	17
113790	2020-08-09 06:57:06	2020-08-09	12	[{"id_menu":3,"count":1}]	43585	delivery	5	17
113791	2020-08-09 06:57:11	2020-08-09	9	[{"id_menu":6,"count":1}]	19399	delivery	5	14
113792	2020-08-09 07:04:50	2020-08-09	9	[{"id_menu":7,"count":1}]	6681	delivery	5	14
113793	2020-08-09 07:06:38	2020-08-09	14	[{"id_menu":2,"count":1}]	26127	delivery	5	19
113794	2020-08-09 07:07:50	2020-08-09	17	[{"id_menu":4,"count":1}]	34728	delivery	5	22
113795	2020-08-09 07:12:10	2020-08-09	14	[{"id_menu":2,"count":1}]	2200	pick-up	0	14
113796	2020-08-09 07:12:52	2020-08-09	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	24863	delivery	5	26
113797	2020-08-09 07:17:30	2020-08-09	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	39042	delivery	5	39
113798	2020-08-09 07:19:17	2020-08-09	14	[{"id_menu":2,"count":1}]	12912	delivery	5	19
113799	2020-08-09 07:19:30	2020-08-09	12	[{"id_menu":1,"count":1}]	7293	delivery	5	17
113800	2020-08-09 07:20:24	2020-08-09	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	36113	delivery	5	23
113801	2020-08-09 07:22:08	2020-08-09	22	[{"id_menu":2,"count":3},{"id_menu":5,"count":1}]	21253	delivery	5	27
113802	2020-08-09 07:24:46	2020-08-09	9	[{"id_menu":7,"count":1}]	32119	delivery	5	14
113803	2020-08-09 07:26:09	2020-08-09	8	[{"id_menu":5,"count":1}]	43501	pick-up	0	8
113804	2020-08-09 07:26:19	2020-08-09	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	12935	delivery	5	26
113805	2020-08-09 07:27:06	2020-08-09	8	[{"id_menu":5,"count":1}]	35907	delivery	5	13
113806	2020-08-09 07:28:46	2020-08-09	9	[{"id_menu":7,"count":1}]	43620	delivery	5	14
113807	2020-08-09 07:29:01	2020-08-09	17	[{"id_menu":4,"count":1}]	42103	pick-up	0	17
113808	2020-08-09 07:29:21	2020-08-09	12	[{"id_menu":1,"count":1}]	10457	delivery	5	17
113809	2020-08-09 07:30:35	2020-08-09	14	[{"id_menu":2,"count":1}]	2139	pick-up	0	14
113810	2020-08-09 07:34:16	2020-08-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11833	pick-up	0	18
113811	2020-08-09 07:40:43	2020-08-09	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	33677	delivery	5	36
113812	2020-08-09 07:41:13	2020-08-09	14	[{"id_menu":2,"count":1}]	5611	pick-up	0	14
113813	2020-08-09 07:41:21	2020-08-09	14	[{"id_menu":2,"count":1}]	3350	delivery	5	19
113814	2020-08-09 07:41:25	2020-08-09	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	27137	pick-up	0	26
113815	2020-08-09 07:41:59	2020-08-09	9	[{"id_menu":7,"count":1}]	43439	delivery	5	14
113816	2020-08-09 07:43:16	2020-08-09	8	[{"id_menu":5,"count":2}]	14581	delivery	5	13
113817	2020-08-09 07:43:19	2020-08-09	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	63	delivery	5	39
113818	2020-08-09 07:43:29	2020-08-09	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	43507	delivery	5	37
113819	2020-08-09 07:45:35	2020-08-09	14	[{"id_menu":2,"count":1}]	42279	delivery	5	19
113820	2020-08-09 07:48:25	2020-08-09	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	23789	delivery	5	44
113821	2020-08-09 07:57:21	2020-08-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8757	pick-up	0	23
113822	2020-08-09 07:59:19	2020-08-09	9	[{"id_menu":6,"count":1}]	2080	pick-up	0	9
113823	2020-08-09 08:00:00	2020-08-09	12	[{"id_menu":3,"count":1}]	43696	delivery	5	17
113824	2020-08-09 08:01:07	2020-08-09	9	[{"id_menu":6,"count":1}]	14622	delivery	5	14
113825	2020-08-09 08:01:09	2020-08-09	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	42715	delivery	5	26
113826	2020-08-09 08:02:00	2020-08-09	9	[{"id_menu":6,"count":1}]	9343	delivery	5	14
113827	2020-08-09 08:04:35	2020-08-09	14	[{"id_menu":2,"count":1}]	43560	delivery	5	19
113828	2020-08-09 08:06:20	2020-08-09	8	[{"id_menu":5,"count":1}]	29193	delivery	5	13
113829	2020-08-09 08:08:12	2020-08-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	43455	delivery	5	23
113830	2020-08-09 08:09:19	2020-08-09	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21289	delivery	5	43
113831	2020-08-09 08:09:48	2020-08-09	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	43532	delivery	5	34
113832	2020-08-09 08:11:55	2020-08-09	9	[{"id_menu":7,"count":2}]	43510	delivery	5	14
113833	2020-08-09 08:12:13	2020-08-09	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22601	delivery	5	36
113834	2020-08-09 08:12:53	2020-08-09	14	[{"id_menu":2,"count":1}]	43498	delivery	5	19
113835	2020-08-09 08:13:07	2020-08-09	9	[{"id_menu":6,"count":1}]	43612	delivery	5	14
113836	2020-08-09 08:13:37	2020-08-09	9	[{"id_menu":6,"count":1}]	43451	delivery	5	14
113837	2020-08-09 08:17:31	2020-08-09	9	[{"id_menu":6,"count":1}]	43377	delivery	5	14
113838	2020-08-09 08:18:41	2020-08-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1987	delivery	5	22
113839	2020-08-09 08:20:00	2020-08-09	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	31497	delivery	5	25
113840	2020-08-09 08:20:54	2020-08-09	9	[{"id_menu":6,"count":1}]	27011	delivery	5	14
113841	2020-08-09 08:22:56	2020-08-09	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	36989	delivery	5	30
113842	2020-08-09 08:26:06	2020-08-09	14	[{"id_menu":2,"count":1}]	35962	pick-up	0	14
113843	2020-08-09 08:27:29	2020-08-09	14	[{"id_menu":2,"count":1}]	43661	delivery	5	19
113844	2020-08-09 08:28:14	2020-08-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39893	delivery	5	22
113845	2020-08-09 08:33:05	2020-08-09	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	27513	delivery	5	28
113846	2020-08-09 08:33:16	2020-08-09	12	[{"id_menu":3,"count":1}]	43687	delivery	5	17
113847	2020-08-09 08:34:33	2020-08-09	12	[{"id_menu":1,"count":1}]	18981	pick-up	0	12
113848	2020-08-09 08:36:00	2020-08-09	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33128	delivery	5	31
113849	2020-08-09 08:39:24	2020-08-09	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	30947	pick-up	0	26
113850	2020-08-09 08:40:33	2020-08-09	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	43437	delivery	5	31
113851	2020-08-09 08:42:51	2020-08-09	9	[{"id_menu":7,"count":1}]	3839	delivery	5	14
113852	2020-08-09 08:44:14	2020-08-09	14	[{"id_menu":2,"count":1}]	12791	pick-up	0	14
113853	2020-08-09 08:44:32	2020-08-09	9	[{"id_menu":6,"count":1}]	39032	delivery	5	14
113854	2020-08-09 08:46:16	2020-08-09	17	[{"id_menu":4,"count":1}]	17633	delivery	5	22
113855	2020-08-09 08:50:05	2020-08-09	14	[{"id_menu":2,"count":1}]	18533	pick-up	0	14
113856	2020-08-09 08:50:55	2020-08-09	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	2401	pick-up	0	31
113857	2020-08-09 08:51:53	2020-08-09	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	19254	delivery	5	42
113858	2020-08-09 08:52:30	2020-08-09	14	[{"id_menu":2,"count":1}]	43690	delivery	5	19
113859	2020-08-09 08:53:07	2020-08-09	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	431	pick-up	0	39
113860	2020-08-09 08:56:47	2020-08-09	14	[{"id_menu":2,"count":1}]	43657	delivery	5	19
113861	2020-08-09 08:56:51	2020-08-09	9	[{"id_menu":6,"count":1}]	40148	delivery	5	14
113862	2020-08-09 08:56:59	2020-08-09	9	[{"id_menu":6,"count":1}]	30385	delivery	5	14
113863	2020-08-09 09:05:25	2020-08-09	12	[{"id_menu":1,"count":1}]	1820	pick-up	0	12
113864	2020-08-09 09:06:02	2020-08-09	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	37834	delivery	5	31
113865	2020-08-09 09:08:26	2020-08-09	14	[{"id_menu":2,"count":1}]	22436	delivery	5	19
113866	2020-08-09 09:08:30	2020-08-09	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	26840	delivery	5	31
113867	2020-08-09 09:09:45	2020-08-09	14	[{"id_menu":2,"count":1}]	43494	delivery	5	19
113868	2020-08-09 09:10:36	2020-08-09	9	[{"id_menu":7,"count":1}]	1516	delivery	5	14
113869	2020-08-09 09:11:21	2020-08-09	14	[{"id_menu":2,"count":1}]	9924	delivery	5	19
113870	2020-08-09 09:13:19	2020-08-09	17	[{"id_menu":4,"count":1}]	4223	delivery	5	22
113871	2020-08-09 09:13:39	2020-08-09	8	[{"id_menu":5,"count":1}]	40000	delivery	5	13
113872	2020-08-09 09:15:14	2020-08-09	14	[{"id_menu":2,"count":1}]	23696	pick-up	0	14
113873	2020-08-09 09:16:22	2020-08-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	22274	delivery	5	28
113874	2020-08-09 09:18:32	2020-08-09	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	29320	delivery	5	26
113875	2020-08-09 09:20:07	2020-08-09	17	[{"id_menu":4,"count":2}]	5758	pick-up	0	17
113876	2020-08-09 09:21:48	2020-08-09	9	[{"id_menu":6,"count":1}]	43625	delivery	5	14
113877	2020-08-09 09:22:58	2020-08-09	9	[{"id_menu":7,"count":1}]	5527	delivery	5	14
113878	2020-08-09 09:23:32	2020-08-09	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	43557	delivery	5	40
113879	2020-08-09 09:24:22	2020-08-09	9	[{"id_menu":7,"count":1}]	43635	pick-up	0	9
113880	2020-08-09 09:25:19	2020-08-09	9	[{"id_menu":6,"count":2}]	30401	delivery	5	14
113881	2020-08-09 09:25:51	2020-08-09	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	43440	delivery	5	38
113882	2020-08-09 09:26:44	2020-08-09	9	[{"id_menu":6,"count":2}]	43484	delivery	5	14
113883	2020-08-09 09:28:44	2020-08-09	8	[{"id_menu":5,"count":1}]	43462	delivery	5	13
113884	2020-08-09 09:29:41	2020-08-09	9	[{"id_menu":6,"count":1}]	31191	pick-up	0	9
113885	2020-08-09 09:31:46	2020-08-09	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	749	pick-up	0	32
113886	2020-08-09 09:32:45	2020-08-09	8	[{"id_menu":5,"count":1}]	29348	pick-up	0	8
113887	2020-08-09 09:33:22	2020-08-09	17	[{"id_menu":4,"count":1}]	39073	delivery	5	22
113888	2020-08-09 09:33:52	2020-08-09	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	24807	delivery	5	42
113889	2020-08-09 09:34:15	2020-08-09	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	42038	delivery	5	22
113890	2020-08-09 09:35:59	2020-08-09	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38414	delivery	5	37
113891	2020-08-09 09:36:13	2020-08-09	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	43583	delivery	5	45
113892	2020-08-09 09:36:43	2020-08-09	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	43618	delivery	5	26
113893	2020-08-09 09:38:47	2020-08-09	12	[{"id_menu":3,"count":1}]	43699	delivery	5	17
113894	2020-08-09 09:38:50	2020-08-09	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	25608	delivery	5	26
113895	2020-08-09 09:40:12	2020-08-09	9	[{"id_menu":7,"count":2}]	15628	delivery	5	14
113896	2020-08-09 09:42:27	2020-08-09	9	[{"id_menu":6,"count":1}]	43639	delivery	5	14
113897	2020-08-09 09:45:32	2020-08-09	33	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	14247	delivery	5	38
113898	2020-08-09 09:47:53	2020-08-09	9	[{"id_menu":6,"count":1}]	1303	pick-up	0	9
113899	2020-08-09 09:49:17	2020-08-09	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13326	delivery	5	36
113900	2020-08-09 09:49:55	2020-08-09	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	8445	delivery	5	26
113901	2020-08-09 09:51:23	2020-08-09	9	[{"id_menu":6,"count":1}]	25504	delivery	5	14
113902	2020-08-09 10:00:47	2020-08-09	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	43649	delivery	5	34
113903	2020-08-09 10:01:50	2020-08-09	9	[{"id_menu":7,"count":1}]	6977	pick-up	0	9
113904	2020-08-09 10:01:55	2020-08-09	9	[{"id_menu":7,"count":1}]	7638	delivery	5	14
113905	2020-08-09 10:02:14	2020-08-09	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	14642	pick-up	0	26
113906	2020-08-09 10:04:11	2020-08-09	12	[{"id_menu":1,"count":1}]	40508	delivery	5	17
113907	2020-08-09 10:04:44	2020-08-09	8	[{"id_menu":5,"count":1}]	20322	delivery	5	13
113908	2020-08-09 10:05:36	2020-08-09	9	[{"id_menu":7,"count":1}]	28750	delivery	5	14
113909	2020-08-09 10:07:27	2020-08-09	12	[{"id_menu":1,"count":1}]	3835	delivery	5	17
113910	2020-08-09 10:07:42	2020-08-09	9	[{"id_menu":6,"count":1}]	36587	delivery	5	14
113911	2020-08-09 10:08:06	2020-08-09	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	20000	delivery	5	22
113912	2020-08-09 10:08:33	2020-08-09	9	[{"id_menu":6,"count":2}]	35264	pick-up	0	9
113913	2020-08-09 10:09:38	2020-08-09	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10127	delivery	5	40
113914	2020-08-09 10:09:43	2020-08-09	9	[{"id_menu":7,"count":1}]	31178	delivery	5	14
113915	2020-08-09 10:10:02	2020-08-09	14	[{"id_menu":2,"count":1}]	16342	delivery	5	19
113916	2020-08-09 10:10:08	2020-08-09	9	[{"id_menu":6,"count":1}]	20602	delivery	5	14
113917	2020-08-09 10:10:08	2020-08-09	12	[{"id_menu":3,"count":1}]	40493	pick-up	0	12
113918	2020-08-09 10:10:19	2020-08-09	12	[{"id_menu":1,"count":1}]	24585	pick-up	0	12
113919	2020-08-09 10:10:55	2020-08-09	9	[{"id_menu":6,"count":2}]	43668	delivery	5	14
113920	2020-08-09 10:12:25	2020-08-09	17	[{"id_menu":4,"count":1}]	3090	delivery	5	22
113921	2020-08-09 10:12:54	2020-08-09	9	[{"id_menu":6,"count":1}]	15982	delivery	5	14
113922	2020-08-09 10:13:17	2020-08-09	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	765	pick-up	0	26
113923	2020-08-09 10:14:00	2020-08-09	17	[{"id_menu":4,"count":1}]	35003	delivery	5	22
113924	2020-08-09 10:15:25	2020-08-09	12	[{"id_menu":3,"count":1}]	1773	pick-up	0	12
113925	2020-08-09 10:15:59	2020-08-09	17	[{"id_menu":4,"count":1}]	43436	delivery	5	22
113926	2020-08-09 10:16:18	2020-08-09	9	[{"id_menu":7,"count":2}]	40022	delivery	5	14
113927	2020-08-09 10:19:09	2020-08-09	9	[{"id_menu":6,"count":1}]	43473	delivery	5	14
113928	2020-08-09 10:19:20	2020-08-09	8	[{"id_menu":5,"count":1}]	4634	pick-up	0	8
113929	2020-08-09 10:21:12	2020-08-09	9	[{"id_menu":7,"count":1}]	20522	delivery	5	14
113930	2020-08-09 10:22:11	2020-08-09	9	[{"id_menu":6,"count":1}]	43476	delivery	5	14
113931	2020-08-09 10:25:04	2020-08-09	12	[{"id_menu":1,"count":1}]	10807	pick-up	0	12
113932	2020-08-09 10:27:20	2020-08-09	12	[{"id_menu":3,"count":2}]	43654	delivery	5	17
113933	2020-08-09 10:27:36	2020-08-09	9	[{"id_menu":7,"count":1}]	43461	delivery	5	14
113934	2020-08-09 10:28:52	2020-08-09	9	[{"id_menu":6,"count":1}]	43546	delivery	5	14
113935	2020-08-09 10:29:02	2020-08-09	9	[{"id_menu":6,"count":1}]	16938	pick-up	0	9
113936	2020-08-09 10:29:25	2020-08-09	9	[{"id_menu":7,"count":1}]	10331	pick-up	0	9
113937	2020-08-09 10:30:32	2020-08-09	9	[{"id_menu":6,"count":1}]	2642	pick-up	0	9
113938	2020-08-09 10:32:00	2020-08-09	14	[{"id_menu":2,"count":1}]	28339	delivery	5	19
113939	2020-08-09 10:33:01	2020-08-09	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	38046	delivery	5	23
113940	2020-08-09 10:33:02	2020-08-09	9	[{"id_menu":6,"count":1}]	20395	delivery	5	14
113941	2020-08-09 10:34:30	2020-08-09	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	36940	delivery	5	27
113942	2020-08-09 10:35:25	2020-08-09	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	16018	pick-up	0	21
113943	2020-08-09 10:38:45	2020-08-09	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	43574	delivery	5	31
113944	2020-08-09 10:41:04	2020-08-09	9	[{"id_menu":7,"count":1}]	26864	delivery	5	14
113945	2020-08-09 10:41:22	2020-08-09	8	[{"id_menu":5,"count":1}]	25591	delivery	5	13
113946	2020-08-09 10:42:41	2020-08-09	30	[{"id_menu":3,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2665	delivery	5	35
113947	2020-08-09 10:43:37	2020-08-09	9	[{"id_menu":7,"count":1}]	18348	pick-up	0	9
113948	2020-08-09 10:44:02	2020-08-09	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	43598	delivery	5	31
113949	2020-08-09 10:44:33	2020-08-09	17	[{"id_menu":4,"count":1}]	506	pick-up	0	17
113950	2020-08-09 10:44:59	2020-08-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	10199	delivery	5	28
113951	2020-08-09 10:45:05	2020-08-09	17	[{"id_menu":4,"count":1}]	43449	delivery	5	22
113952	2020-08-09 10:45:45	2020-08-09	12	[{"id_menu":3,"count":1}]	20782	pick-up	0	12
113953	2020-08-09 10:45:52	2020-08-09	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	28669	delivery	5	27
113954	2020-08-09 10:46:48	2020-08-09	12	[{"id_menu":3,"count":1}]	43615	delivery	5	17
113955	2020-08-09 10:46:55	2020-08-09	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	43597	delivery	5	48
113956	2020-08-09 10:47:47	2020-08-09	12	[{"id_menu":1,"count":1}]	14531	pick-up	0	12
113957	2020-08-09 10:48:56	2020-08-09	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	43565	pick-up	0	21
113958	2020-08-09 10:52:34	2020-08-09	14	[{"id_menu":2,"count":1}]	43651	delivery	5	19
113959	2020-08-09 10:57:09	2020-08-09	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	39441	pick-up	0	21
113960	2020-08-09 11:02:44	2020-08-09	9	[{"id_menu":6,"count":1}]	28080	delivery	5	14
113961	2020-08-09 11:03:32	2020-08-09	14	[{"id_menu":2,"count":1}]	43511	pick-up	0	14
113962	2020-08-09 11:06:06	2020-08-09	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	946	pick-up	0	21
113963	2020-08-09 11:06:41	2020-08-09	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	35619	delivery	5	26
113964	2020-08-09 11:09:22	2020-08-09	9	[{"id_menu":7,"count":1}]	33393	delivery	5	14
113965	2020-08-09 11:13:09	2020-08-09	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	31646	delivery	5	37
113966	2020-08-09 11:14:35	2020-08-09	8	[{"id_menu":5,"count":1}]	36458	delivery	5	13
113967	2020-08-09 11:15:41	2020-08-09	14	[{"id_menu":2,"count":1}]	25994	delivery	5	19
113968	2020-08-09 11:16:49	2020-08-09	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	38541	delivery	5	31
113969	2020-08-09 11:17:37	2020-08-09	8	[{"id_menu":5,"count":1}]	43586	pick-up	0	8
113970	2020-08-09 11:19:29	2020-08-09	9	[{"id_menu":6,"count":1}]	40583	delivery	5	14
113971	2020-08-09 11:21:29	2020-08-09	14	[{"id_menu":2,"count":2}]	34243	pick-up	0	14
113972	2020-08-09 11:22:03	2020-08-09	14	[{"id_menu":2,"count":1}]	38815	pick-up	0	14
113973	2020-08-09 11:24:04	2020-08-09	9	[{"id_menu":7,"count":1}]	17641	pick-up	0	9
113974	2020-08-09 11:24:25	2020-08-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27356	pick-up	0	17
113975	2020-08-09 11:24:55	2020-08-09	12	[{"id_menu":3,"count":2}]	21620	delivery	5	17
113976	2020-08-09 11:26:15	2020-08-09	9	[{"id_menu":6,"count":1}]	43611	delivery	5	14
113977	2020-08-09 11:26:56	2020-08-09	12	[{"id_menu":3,"count":1}]	43581	delivery	5	17
113978	2020-08-09 11:31:12	2020-08-09	9	[{"id_menu":6,"count":1}]	32247	pick-up	0	9
113979	2020-08-09 11:31:53	2020-08-09	17	[{"id_menu":4,"count":1}]	43664	delivery	5	22
113980	2020-08-09 11:33:11	2020-08-09	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	43541	delivery	5	45
113981	2020-08-09 11:36:14	2020-08-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	43629	delivery	5	23
113982	2020-08-09 11:36:50	2020-08-09	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	21386	delivery	5	31
113983	2020-08-09 11:39:04	2020-08-09	12	[{"id_menu":3,"count":1}]	3763	delivery	5	17
113984	2020-08-09 11:39:11	2020-08-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	39471	pick-up	0	23
113985	2020-08-09 11:40:39	2020-08-09	12	[{"id_menu":1,"count":1}]	43677	delivery	5	17
113986	2020-08-09 11:41:38	2020-08-09	12	[{"id_menu":1,"count":1}]	10209	pick-up	0	12
113987	2020-08-09 11:42:15	2020-08-09	8	[{"id_menu":5,"count":2}]	43483	delivery	5	13
113988	2020-08-09 11:43:35	2020-08-09	14	[{"id_menu":2,"count":1}]	43536	delivery	5	19
113989	2020-08-09 11:44:33	2020-08-09	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	37259	delivery	5	26
113990	2020-08-09 11:46:42	2020-08-09	14	[{"id_menu":2,"count":1}]	34850	delivery	5	19
113991	2020-08-09 11:47:51	2020-08-09	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28239	delivery	5	31
113992	2020-08-09 11:50:20	2020-08-09	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16346	delivery	5	36
113993	2020-08-09 11:50:30	2020-08-09	12	[{"id_menu":1,"count":1}]	28431	pick-up	0	12
113994	2020-08-09 11:50:49	2020-08-09	9	[{"id_menu":7,"count":1}]	26106	delivery	5	14
113995	2020-08-09 11:51:29	2020-08-09	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	43454	delivery	5	30
113996	2020-08-09 11:51:32	2020-08-09	14	[{"id_menu":2,"count":1}]	31368	delivery	5	19
113997	2020-08-09 11:53:13	2020-08-09	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2172	pick-up	0	21
113998	2020-08-09 11:55:22	2020-08-09	8	[{"id_menu":5,"count":1}]	1640	pick-up	0	8
113999	2020-08-09 11:55:50	2020-08-09	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	26681	delivery	5	36
114000	2020-08-09 11:59:16	2020-08-09	9	[{"id_menu":7,"count":1}]	43638	delivery	5	14
114001	2020-08-09 12:00:03	2020-08-09	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32697	delivery	5	48
114002	2020-08-09 12:01:01	2020-08-09	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	26897	delivery	5	31
114003	2020-08-09 12:01:26	2020-08-09	17	[{"id_menu":4,"count":1}]	26239	delivery	5	22
114004	2020-08-09 12:01:34	2020-08-09	17	[{"id_menu":4,"count":1}]	43547	delivery	5	22
114005	2020-08-09 12:02:38	2020-08-09	9	[{"id_menu":7,"count":1}]	43453	pick-up	0	9
114006	2020-08-09 12:04:49	2020-08-09	9	[{"id_menu":6,"count":1}]	27920	pick-up	0	9
114007	2020-08-09 12:06:00	2020-08-09	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	43576	delivery	5	30
114008	2020-08-09 12:06:53	2020-08-09	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	7851	delivery	5	26
114009	2020-08-09 12:07:06	2020-08-09	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	43573	delivery	5	39
114010	2020-08-09 12:07:43	2020-08-09	14	[{"id_menu":2,"count":1}]	29052	pick-up	0	14
114011	2020-08-09 12:09:12	2020-08-09	9	[{"id_menu":7,"count":1}]	43477	delivery	5	14
114012	2020-08-09 12:09:18	2020-08-09	12	[{"id_menu":1,"count":1}]	41861	delivery	5	17
114013	2020-08-09 12:09:42	2020-08-09	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43619	delivery	5	40
114014	2020-08-09 12:09:52	2020-08-09	14	[{"id_menu":2,"count":1}]	32325	pick-up	0	14
114015	2020-08-09 12:11:39	2020-08-09	14	[{"id_menu":2,"count":1}]	43456	delivery	5	19
114016	2020-08-09 12:14:23	2020-08-09	14	[{"id_menu":2,"count":1}]	39996	pick-up	0	14
114017	2020-08-09 12:15:50	2020-08-09	17	[{"id_menu":4,"count":2}]	1914	delivery	5	22
114018	2020-08-09 12:16:28	2020-08-09	9	[{"id_menu":6,"count":1}]	18375	delivery	5	14
114019	2020-08-09 12:18:38	2020-08-09	12	[{"id_menu":3,"count":1}]	25935	delivery	5	17
114020	2020-08-09 12:19:14	2020-08-09	14	[{"id_menu":2,"count":1}]	43587	delivery	5	19
114021	2020-08-09 12:20:05	2020-08-09	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	42951	pick-up	0	29
114022	2020-08-09 12:21:40	2020-08-09	8	[{"id_menu":5,"count":1}]	17001	delivery	5	13
114023	2020-08-09 12:24:37	2020-08-09	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	26624	delivery	5	34
114024	2020-08-09 12:24:40	2020-08-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	43572	pick-up	0	17
114025	2020-08-09 12:30:50	2020-08-09	9	[{"id_menu":7,"count":1}]	38701	delivery	5	14
114026	2020-08-09 12:32:05	2020-08-09	9	[{"id_menu":6,"count":3}]	29241	delivery	5	14
114027	2020-08-09 12:34:18	2020-08-09	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	20178	delivery	5	35
114028	2020-08-09 12:34:56	2020-08-09	12	[{"id_menu":1,"count":2}]	5015	pick-up	0	12
114029	2020-08-09 12:35:12	2020-08-09	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	9884	pick-up	0	26
114030	2020-08-09 12:37:02	2020-08-09	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	1309	delivery	5	25
114031	2020-08-09 12:38:02	2020-08-09	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	20817	delivery	5	26
114032	2020-08-09 12:38:54	2020-08-09	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	42919	delivery	5	53
114033	2020-08-09 12:44:12	2020-08-09	17	[{"id_menu":4,"count":1}]	43452	delivery	5	22
114034	2020-08-09 12:45:38	2020-08-09	14	[{"id_menu":2,"count":1}]	27388	delivery	5	19
114035	2020-08-09 12:47:27	2020-08-09	9	[{"id_menu":7,"count":1}]	43485	delivery	5	14
114036	2020-08-09 12:47:38	2020-08-09	14	[{"id_menu":2,"count":1}]	42526	delivery	5	19
114037	2020-08-09 12:48:57	2020-08-09	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	35038	pick-up	0	26
114038	2020-08-09 12:50:51	2020-08-09	17	[{"id_menu":4,"count":1}]	34163	delivery	5	22
114039	2020-08-09 12:52:07	2020-08-09	9	[{"id_menu":6,"count":1}]	15702	delivery	5	14
114040	2020-08-09 12:52:56	2020-08-09	9	[{"id_menu":6,"count":1}]	43682	delivery	5	14
114041	2020-08-09 12:55:05	2020-08-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	36992	pick-up	0	23
114042	2020-08-09 12:56:53	2020-08-09	17	[{"id_menu":4,"count":1}]	21002	pick-up	0	17
114043	2020-08-09 12:56:58	2020-08-09	9	[{"id_menu":6,"count":1}]	263	delivery	5	14
114044	2020-08-09 12:57:38	2020-08-09	8	[{"id_menu":5,"count":1}]	20216	pick-up	0	8
114045	2020-08-09 12:59:13	2020-08-09	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9733	delivery	5	22
114046	2020-08-09 13:01:09	2020-08-09	8	[{"id_menu":5,"count":2}]	43605	delivery	5	13
114047	2020-08-09 13:02:24	2020-08-09	8	[{"id_menu":5,"count":1}]	23582	pick-up	0	8
114048	2020-08-09 13:04:04	2020-08-09	9	[{"id_menu":7,"count":1}]	23652	delivery	5	14
114049	2020-08-09 13:05:19	2020-08-09	12	[{"id_menu":3,"count":1}]	33241	pick-up	0	12
114050	2020-08-09 13:05:47	2020-08-09	9	[{"id_menu":6,"count":1}]	18017	delivery	5	14
114051	2020-08-09 13:08:04	2020-08-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	43641	delivery	5	23
114052	2020-08-09 13:09:03	2020-08-09	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	18645	delivery	5	40
114053	2020-08-09 13:10:50	2020-08-09	17	[{"id_menu":4,"count":1}]	12799	delivery	5	22
114054	2020-08-09 13:13:03	2020-08-09	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	43544	delivery	5	31
114055	2020-08-09 13:13:17	2020-08-09	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":3}]	13105	delivery	5	26
114056	2020-08-09 13:15:41	2020-08-09	9	[{"id_menu":6,"count":2}]	15810	delivery	5	14
114057	2020-08-09 13:17:39	2020-08-09	17	[{"id_menu":4,"count":1}]	8323	delivery	5	22
114058	2020-08-09 13:18:47	2020-08-09	14	[{"id_menu":2,"count":1}]	43446	pick-up	0	14
114059	2020-08-09 13:19:13	2020-08-09	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39279	delivery	5	31
114060	2020-08-09 13:19:28	2020-08-09	12	[{"id_menu":1,"count":1}]	14579	delivery	5	17
114061	2020-08-09 13:21:20	2020-08-09	14	[{"id_menu":2,"count":1}]	3868	delivery	5	19
114062	2020-08-09 13:25:09	2020-08-09	8	[{"id_menu":5,"count":1}]	43673	delivery	5	13
114063	2020-08-09 13:25:50	2020-08-09	17	[{"id_menu":4,"count":1}]	10244	pick-up	0	17
114064	2020-08-09 13:26:25	2020-08-09	14	[{"id_menu":2,"count":1}]	43570	delivery	5	19
114065	2020-08-09 13:28:00	2020-08-09	8	[{"id_menu":5,"count":1}]	18202	pick-up	0	8
114066	2020-08-09 13:31:17	2020-08-09	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	38787	delivery	5	22
114067	2020-08-09 13:37:39	2020-08-09	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	43569	delivery	5	36
114068	2020-08-09 13:38:35	2020-08-09	9	[{"id_menu":6,"count":1}]	20425	delivery	5	14
114069	2020-08-09 13:39:16	2020-08-09	8	[{"id_menu":5,"count":1}]	35726	delivery	5	13
114070	2020-08-09 13:41:33	2020-08-09	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	43486	delivery	5	34
114071	2020-08-09 13:41:51	2020-08-09	12	[{"id_menu":1,"count":1}]	24995	delivery	5	17
114072	2020-08-09 13:42:09	2020-08-09	8	[{"id_menu":5,"count":1}]	43684	delivery	5	13
114073	2020-08-09 13:42:58	2020-08-09	9	[{"id_menu":6,"count":1}]	27256	delivery	5	14
114074	2020-08-09 13:44:44	2020-08-09	9	[{"id_menu":6,"count":1}]	39224	delivery	5	14
114075	2020-08-09 13:46:08	2020-08-09	9	[{"id_menu":6,"count":1}]	31432	delivery	5	14
114076	2020-08-09 13:48:27	2020-08-09	12	[{"id_menu":1,"count":1}]	14195	delivery	5	17
114077	2020-08-09 13:50:57	2020-08-09	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5730	delivery	5	30
114078	2020-08-09 13:51:18	2020-08-09	8	[{"id_menu":5,"count":1}]	25303	delivery	5	13
114079	2020-08-09 13:51:23	2020-08-09	8	[{"id_menu":5,"count":1}]	43566	delivery	5	13
114080	2020-08-09 13:52:29	2020-08-09	9	[{"id_menu":7,"count":1}]	43563	delivery	5	14
114081	2020-08-09 13:57:03	2020-08-09	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	5718	delivery	5	40
114082	2020-08-09 13:58:18	2020-08-09	17	[{"id_menu":4,"count":1}]	43502	delivery	5	22
114083	2020-08-09 14:03:38	2020-08-09	12	[{"id_menu":3,"count":1}]	43608	delivery	5	17
114084	2020-08-09 14:05:28	2020-08-09	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	43600	delivery	5	35
114085	2020-08-09 14:06:02	2020-08-09	12	[{"id_menu":3,"count":1}]	40576	delivery	5	17
114086	2020-08-09 14:06:39	2020-08-09	12	[{"id_menu":3,"count":1}]	37431	pick-up	0	12
114087	2020-08-09 14:09:14	2020-08-09	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	43636	delivery	5	30
114088	2020-08-09 14:09:28	2020-08-09	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	39095	delivery	5	31
114089	2020-08-09 14:10:17	2020-08-09	17	[{"id_menu":4,"count":1}]	35455	delivery	5	22
114090	2020-08-09 14:10:56	2020-08-09	14	[{"id_menu":2,"count":1}]	32245	delivery	5	19
114091	2020-08-09 14:12:02	2020-08-09	9	[{"id_menu":6,"count":1}]	28808	delivery	5	14
114092	2020-08-09 14:13:03	2020-08-09	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	43672	delivery	5	34
114093	2020-08-09 14:17:33	2020-08-09	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	36639	delivery	5	36
114094	2020-08-09 14:19:46	2020-08-09	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22426	delivery	5	31
114095	2020-08-09 14:22:49	2020-08-09	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	43663	delivery	5	31
114096	2020-08-09 14:23:29	2020-08-09	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	31825	delivery	5	36
114097	2020-08-09 14:24:51	2020-08-09	9	[{"id_menu":7,"count":1}]	8334	delivery	5	14
114098	2020-08-09 14:26:06	2020-08-09	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	43481	delivery	5	22
114099	2020-08-09 14:26:52	2020-08-09	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43567	delivery	5	37
114100	2020-08-09 14:27:02	2020-08-09	9	[{"id_menu":7,"count":1}]	25889	delivery	5	14
114101	2020-08-09 14:28:08	2020-08-09	9	[{"id_menu":7,"count":1}]	5961	pick-up	0	9
114102	2020-08-09 14:29:35	2020-08-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	43513	delivery	5	22
114103	2020-08-09 14:31:58	2020-08-09	14	[{"id_menu":2,"count":1}]	43652	delivery	5	19
114104	2020-08-09 14:32:37	2020-08-09	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6937	delivery	5	36
114105	2020-08-09 14:34:58	2020-08-09	9	[{"id_menu":6,"count":1}]	40794	pick-up	0	9
114106	2020-08-09 14:39:21	2020-08-09	12	[{"id_menu":3,"count":1}]	21866	delivery	5	17
114107	2020-08-09 14:40:44	2020-08-09	17	[{"id_menu":4,"count":1}]	21322	delivery	5	22
114108	2020-08-09 14:42:08	2020-08-09	8	[{"id_menu":5,"count":1}]	1176	pick-up	0	8
114109	2020-08-09 14:43:14	2020-08-09	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	40611	pick-up	0	43
114110	2020-08-09 14:43:20	2020-08-09	14	[{"id_menu":2,"count":1}]	33255	delivery	5	19
114111	2020-08-09 14:43:21	2020-08-09	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	7387	delivery	5	37
114112	2020-08-09 14:45:14	2020-08-09	9	[{"id_menu":7,"count":1}]	43438	delivery	5	14
114113	2020-08-09 14:47:07	2020-08-09	9	[{"id_menu":6,"count":1}]	2562	pick-up	0	9
114114	2020-08-09 14:48:59	2020-08-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	39904	delivery	5	28
114115	2020-08-09 14:51:00	2020-08-09	9	[{"id_menu":7,"count":1}]	16081	delivery	5	14
114116	2020-08-09 14:51:02	2020-08-09	8	[{"id_menu":5,"count":1}]	4042	pick-up	0	8
114117	2020-08-09 14:51:08	2020-08-09	9	[{"id_menu":6,"count":1}]	43589	delivery	5	14
114118	2020-08-09 14:54:53	2020-08-09	12	[{"id_menu":3,"count":1}]	31164	delivery	5	17
114119	2020-08-09 14:55:31	2020-08-09	8	[{"id_menu":5,"count":1}]	41326	delivery	5	13
114120	2020-08-09 14:57:09	2020-08-09	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11239	pick-up	0	26
114121	2020-08-09 14:57:29	2020-08-09	9	[{"id_menu":7,"count":1}]	18067	delivery	5	14
114122	2020-08-09 15:02:21	2020-08-09	9	[{"id_menu":6,"count":2}]	43630	delivery	5	14
114123	2020-08-09 15:02:34	2020-08-09	8	[{"id_menu":5,"count":1}]	30555	delivery	5	13
114124	2020-08-09 15:04:38	2020-08-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6276	delivery	5	23
114125	2020-08-09 15:05:19	2020-08-09	9	[{"id_menu":6,"count":1}]	42976	delivery	5	14
114126	2020-08-09 15:05:48	2020-08-09	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17410	delivery	5	34
114127	2020-08-09 15:07:25	2020-08-09	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	29943	delivery	5	25
114128	2020-08-09 15:08:39	2020-08-09	12	[{"id_menu":3,"count":1}]	43459	delivery	5	17
114129	2020-08-09 15:09:46	2020-08-09	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	25836	pick-up	0	26
114130	2020-08-09 15:11:02	2020-08-09	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	35274	delivery	5	40
114131	2020-08-09 15:11:38	2020-08-09	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	43482	delivery	5	31
114132	2020-08-09 15:14:22	2020-08-09	9	[{"id_menu":6,"count":1}]	43564	delivery	5	14
114133	2020-08-09 15:18:44	2020-08-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2442	pick-up	0	23
114134	2020-08-09 15:20:25	2020-08-09	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	29810	delivery	5	45
114135	2020-08-09 15:21:41	2020-08-09	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	43593	delivery	5	39
114136	2020-08-09 15:21:44	2020-08-09	17	[{"id_menu":4,"count":1}]	2250	pick-up	0	17
114137	2020-08-09 15:23:40	2020-08-09	14	[{"id_menu":2,"count":1}]	21036	pick-up	0	14
114138	2020-08-09 15:24:10	2020-08-09	9	[{"id_menu":7,"count":1}]	43674	delivery	5	14
114139	2020-08-09 15:24:18	2020-08-09	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4652	pick-up	0	35
114140	2020-08-09 15:27:15	2020-08-09	12	[{"id_menu":1,"count":1}]	1337	pick-up	0	12
114141	2020-08-09 15:31:58	2020-08-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27071	delivery	5	22
114142	2020-08-09 15:34:23	2020-08-09	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6206	delivery	5	40
114143	2020-08-09 15:36:52	2020-08-09	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	36202	delivery	5	34
114144	2020-08-09 15:41:39	2020-08-09	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	43659	delivery	5	26
114145	2020-08-09 15:42:51	2020-08-09	14	[{"id_menu":2,"count":1}]	17033	delivery	5	19
114146	2020-08-09 15:44:44	2020-08-09	9	[{"id_menu":7,"count":1}]	38122	delivery	5	14
114147	2020-08-09 15:45:41	2020-08-09	9	[{"id_menu":7,"count":1}]	14391	pick-up	0	9
114148	2020-08-09 15:46:33	2020-08-09	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43509	delivery	5	54
114149	2020-08-09 15:46:37	2020-08-09	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":2}]	5520	pick-up	0	23
114150	2020-08-09 15:48:11	2020-08-09	12	[{"id_menu":1,"count":2}]	24350	pick-up	0	12
114151	2020-08-09 15:49:58	2020-08-09	9	[{"id_menu":6,"count":1}]	34546	delivery	5	14
114152	2020-08-09 15:53:38	2020-08-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	43505	pick-up	0	17
114153	2020-08-09 15:54:39	2020-08-09	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":3}]	27401	delivery	5	26
114154	2020-08-09 15:54:52	2020-08-09	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	43472	delivery	5	22
114155	2020-08-09 15:55:16	2020-08-09	8	[{"id_menu":5,"count":1}]	27291	delivery	5	13
114156	2020-08-09 15:55:28	2020-08-09	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21732	delivery	5	35
114157	2020-08-09 15:56:14	2020-08-09	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9813	pick-up	0	34
114158	2020-08-09 15:57:38	2020-08-09	8	[{"id_menu":5,"count":1}]	43552	delivery	5	13
114159	2020-08-09 15:59:08	2020-08-09	17	[{"id_menu":4,"count":1}]	28595	delivery	5	22
114160	2020-08-09 16:00:42	2020-08-09	9	[{"id_menu":7,"count":1}]	19606	delivery	5	14
114161	2020-08-09 16:01:24	2020-08-09	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	5158	delivery	5	45
114162	2020-08-09 16:01:51	2020-08-09	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	25295	pick-up	0	43
114163	2020-08-09 16:02:06	2020-08-09	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	19750	delivery	5	26
114164	2020-08-09 16:02:22	2020-08-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	24717	delivery	5	28
114165	2020-08-09 16:04:45	2020-08-09	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	29805	delivery	5	34
114166	2020-08-09 16:05:18	2020-08-09	12	[{"id_menu":1,"count":1}]	1654	pick-up	0	12
114167	2020-08-09 16:08:14	2020-08-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32772	delivery	5	23
114168	2020-08-09 16:08:45	2020-08-09	9	[{"id_menu":6,"count":1}]	43588	delivery	5	14
114169	2020-08-09 16:09:14	2020-08-09	17	[{"id_menu":4,"count":1}]	42216	delivery	5	22
114170	2020-08-09 16:10:59	2020-08-09	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	24294	delivery	5	40
114171	2020-08-09 16:14:33	2020-08-09	9	[{"id_menu":6,"count":1}]	18782	delivery	5	14
114172	2020-08-09 16:15:05	2020-08-09	23	[{"id_menu":2,"count":3},{"id_menu":6,"count":1}]	16702	delivery	5	28
114173	2020-08-09 16:15:56	2020-08-09	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	19566	delivery	5	25
114174	2020-08-09 16:16:27	2020-08-09	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6169	delivery	5	39
114175	2020-08-09 16:17:17	2020-08-09	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	18872	delivery	5	27
114176	2020-08-09 16:18:07	2020-08-09	9	[{"id_menu":6,"count":1}]	9780	delivery	5	14
114177	2020-08-09 16:18:54	2020-08-09	8	[{"id_menu":5,"count":1}]	41486	delivery	5	13
114178	2020-08-09 16:23:19	2020-08-09	17	[{"id_menu":4,"count":1}]	14825	delivery	5	22
114179	2020-08-09 16:23:36	2020-08-09	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2850	pick-up	0	17
114180	2020-08-09 16:27:16	2020-08-09	17	[{"id_menu":4,"count":1}]	15018	delivery	5	22
114181	2020-08-09 16:30:58	2020-08-09	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4072	pick-up	0	41
114182	2020-08-09 16:35:52	2020-08-09	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	22369	delivery	5	45
114183	2020-08-09 16:35:56	2020-08-09	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	30396	delivery	5	34
114184	2020-08-09 16:39:26	2020-08-09	8	[{"id_menu":5,"count":1}]	32368	delivery	5	13
114185	2020-08-09 16:40:30	2020-08-09	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	5201	delivery	5	34
114186	2020-08-09 16:41:18	2020-08-09	8	[{"id_menu":5,"count":1}]	10715	delivery	5	13
114187	2020-08-09 16:44:02	2020-08-09	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	43697	delivery	5	35
114188	2020-08-09 16:44:15	2020-08-09	14	[{"id_menu":2,"count":1}]	25084	delivery	5	19
114189	2020-08-09 16:44:33	2020-08-09	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	40614	delivery	5	31
114190	2020-08-09 16:46:49	2020-08-09	8	[{"id_menu":5,"count":1}]	14736	delivery	5	13
114191	2020-08-09 16:46:53	2020-08-09	14	[{"id_menu":2,"count":1}]	26019	delivery	5	19
114192	2020-08-09 16:51:14	2020-08-09	9	[{"id_menu":7,"count":1}]	43624	delivery	5	14
114193	2020-08-09 16:51:50	2020-08-09	14	[{"id_menu":2,"count":1}]	30196	delivery	5	19
114194	2020-08-09 16:53:48	2020-08-09	12	[{"id_menu":3,"count":1}]	27863	pick-up	0	12
114195	2020-08-09 16:54:29	2020-08-09	14	[{"id_menu":2,"count":1}]	1991	delivery	5	19
114196	2020-08-09 16:56:10	2020-08-09	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	27014	delivery	5	31
114197	2020-08-09 16:56:31	2020-08-09	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	20623	delivery	5	42
114198	2020-08-09 16:57:15	2020-08-09	9	[{"id_menu":7,"count":1}]	35247	pick-up	0	9
114199	2020-08-09 16:57:57	2020-08-09	12	[{"id_menu":1,"count":1}]	27035	delivery	5	17
114200	2020-08-09 17:00:53	2020-08-09	8	[{"id_menu":5,"count":1}]	2623	delivery	5	13
114201	2020-08-09 17:01:17	2020-08-09	17	[{"id_menu":4,"count":1}]	43606	pick-up	0	17
114202	2020-08-09 17:01:36	2020-08-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	43533	delivery	5	23
114203	2020-08-09 17:03:11	2020-08-09	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	43435	delivery	5	31
114204	2020-08-09 17:03:41	2020-08-09	14	[{"id_menu":2,"count":1}]	8505	delivery	5	19
114205	2020-08-09 17:04:35	2020-08-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20711	delivery	5	23
114206	2020-08-09 17:05:18	2020-08-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	40658	pick-up	0	23
114207	2020-08-09 17:06:07	2020-08-09	14	[{"id_menu":2,"count":1}]	10026	delivery	5	19
114208	2020-08-09 17:06:10	2020-08-09	9	[{"id_menu":7,"count":1}]	12251	delivery	5	14
114209	2020-08-09 17:09:22	2020-08-09	8	[{"id_menu":5,"count":1}]	27971	pick-up	0	8
114210	2020-08-09 17:13:31	2020-08-09	9	[{"id_menu":6,"count":1}]	15120	delivery	5	14
114211	2020-08-09 17:13:37	2020-08-09	9	[{"id_menu":6,"count":1}]	42342	delivery	5	14
114212	2020-08-09 17:15:21	2020-08-09	17	[{"id_menu":4,"count":1}]	36725	pick-up	0	17
114213	2020-08-09 17:16:47	2020-08-09	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	43448	delivery	5	34
114214	2020-08-09 17:17:18	2020-08-09	12	[{"id_menu":1,"count":1}]	31847	pick-up	0	12
114215	2020-08-09 17:19:58	2020-08-09	17	[{"id_menu":4,"count":1}]	39969	delivery	5	22
114216	2020-08-09 17:21:10	2020-08-09	17	[{"id_menu":4,"count":1}]	43537	delivery	5	22
114217	2020-08-09 17:22:04	2020-08-09	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	43693	delivery	5	23
114218	2020-08-09 17:22:45	2020-08-09	9	[{"id_menu":7,"count":1}]	6265	pick-up	0	9
114219	2020-08-09 17:23:35	2020-08-09	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	36853	delivery	5	37
114220	2020-08-09 17:25:02	2020-08-09	8	[{"id_menu":5,"count":1}]	41146	pick-up	0	8
114221	2020-08-09 17:28:01	2020-08-09	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43522	delivery	5	37
114222	2020-08-09 17:29:44	2020-08-09	8	[{"id_menu":5,"count":1}]	43562	delivery	5	13
114223	2020-08-09 17:29:55	2020-08-09	17	[{"id_menu":4,"count":1}]	43488	delivery	5	22
114224	2020-08-09 17:33:14	2020-08-09	14	[{"id_menu":2,"count":1}]	43491	delivery	5	19
114225	2020-08-09 17:35:13	2020-08-09	14	[{"id_menu":2,"count":1}]	43689	delivery	5	19
114226	2020-08-09 17:35:39	2020-08-09	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34330	delivery	5	45
114227	2020-08-09 17:36:40	2020-08-09	9	[{"id_menu":7,"count":1}]	20483	delivery	5	14
114228	2020-08-09 17:38:53	2020-08-09	9	[{"id_menu":7,"count":1}]	43542	delivery	5	14
114229	2020-08-09 17:39:02	2020-08-09	9	[{"id_menu":6,"count":1}]	10491	delivery	5	14
114230	2020-08-09 17:40:52	2020-08-09	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	43579	delivery	5	31
114231	2020-08-09 17:42:42	2020-08-09	12	[{"id_menu":3,"count":1}]	10802	delivery	5	17
114232	2020-08-09 17:43:36	2020-08-09	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	43590	delivery	5	31
114233	2020-08-09 17:45:19	2020-08-09	17	[{"id_menu":4,"count":1}]	43614	delivery	5	22
114234	2020-08-09 17:46:36	2020-08-09	14	[{"id_menu":2,"count":1}]	43680	delivery	5	19
114235	2020-08-09 17:46:55	2020-08-09	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	36790	delivery	5	40
114236	2020-08-09 17:47:57	2020-08-09	14	[{"id_menu":2,"count":1}]	16858	pick-up	0	14
114237	2020-08-09 17:50:14	2020-08-09	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	7772	pick-up	0	32
114238	2020-08-09 17:52:02	2020-08-09	12	[{"id_menu":3,"count":1}]	40620	pick-up	0	12
114239	2020-08-09 17:55:10	2020-08-09	17	[{"id_menu":4,"count":1}]	43679	delivery	5	22
114240	2020-08-09 17:56:53	2020-08-09	17	[{"id_menu":4,"count":1}]	19466	delivery	5	22
114241	2020-08-09 18:02:02	2020-08-09	17	[{"id_menu":4,"count":1}]	28013	delivery	5	22
114242	2020-08-09 18:02:24	2020-08-09	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	43504	delivery	5	31
114243	2020-08-09 18:02:30	2020-08-09	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	36931	delivery	5	34
114244	2020-08-09 18:03:20	2020-08-09	9	[{"id_menu":7,"count":1}]	2567	delivery	5	14
114245	2020-08-09 18:05:24	2020-08-09	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43492	delivery	5	35
114246	2020-08-09 18:06:12	2020-08-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	15105	delivery	5	28
114247	2020-08-09 18:06:59	2020-08-09	12	[{"id_menu":1,"count":1}]	111	pick-up	0	12
114248	2020-08-09 18:08:03	2020-08-09	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	43518	delivery	5	40
114249	2020-08-09 18:10:31	2020-08-09	14	[{"id_menu":2,"count":1}]	3372	delivery	5	19
114250	2020-08-09 18:11:21	2020-08-09	12	[{"id_menu":3,"count":2}]	43656	pick-up	0	12
114251	2020-08-09 18:13:25	2020-08-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	43698	pick-up	0	23
114252	2020-08-09 18:14:13	2020-08-09	17	[{"id_menu":4,"count":1}]	3724	delivery	5	22
114253	2020-08-09 18:14:15	2020-08-09	9	[{"id_menu":6,"count":1}]	43489	delivery	5	14
114254	2020-08-09 18:16:46	2020-08-09	9	[{"id_menu":7,"count":1}]	5347	delivery	5	14
114255	2020-08-09 18:17:01	2020-08-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43531	delivery	5	23
114256	2020-08-09 18:17:22	2020-08-09	9	[{"id_menu":7,"count":1}]	18271	delivery	5	14
114257	2020-08-09 18:17:30	2020-08-09	14	[{"id_menu":2,"count":1}]	43470	delivery	5	19
114258	2020-08-09 18:20:32	2020-08-09	14	[{"id_menu":2,"count":1}]	43519	delivery	5	19
114259	2020-08-09 18:22:07	2020-08-09	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	43445	delivery	5	42
114260	2020-08-09 18:23:05	2020-08-09	9	[{"id_menu":6,"count":1}]	1269	pick-up	0	9
114261	2020-08-09 18:23:19	2020-08-09	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	43553	delivery	5	43
114262	2020-08-09 18:23:59	2020-08-09	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	7982	delivery	5	26
114263	2020-08-09 18:25:42	2020-08-09	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43467	delivery	5	52
114264	2020-08-09 18:28:58	2020-08-09	12	[{"id_menu":3,"count":1}]	16869	delivery	5	17
114265	2020-08-09 18:31:20	2020-08-09	12	[{"id_menu":1,"count":1}]	21617	pick-up	0	12
114266	2020-08-09 18:33:01	2020-08-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6150	delivery	5	22
114267	2020-08-09 18:33:35	2020-08-09	14	[{"id_menu":2,"count":1}]	18810	pick-up	0	14
114268	2020-08-09 18:36:13	2020-08-09	9	[{"id_menu":7,"count":1}]	43665	delivery	5	14
114269	2020-08-09 18:36:48	2020-08-09	12	[{"id_menu":1,"count":1}]	43613	delivery	5	17
114270	2020-08-09 18:38:35	2020-08-09	8	[{"id_menu":5,"count":1}]	21765	delivery	5	13
114271	2020-08-09 18:39:10	2020-08-09	14	[{"id_menu":2,"count":1}]	6182	pick-up	0	14
114272	2020-08-09 18:40:15	2020-08-09	8	[{"id_menu":5,"count":1}]	30238	delivery	5	13
114273	2020-08-09 18:40:38	2020-08-09	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	36406	delivery	5	31
114274	2020-08-09 18:41:59	2020-08-09	14	[{"id_menu":2,"count":2}]	1509	delivery	5	19
114275	2020-08-09 18:47:03	2020-08-09	9	[{"id_menu":7,"count":1}]	16016	delivery	5	14
114276	2020-08-09 18:47:26	2020-08-09	14	[{"id_menu":2,"count":1}]	38452	delivery	5	19
114277	2020-08-09 18:48:35	2020-08-09	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	542	delivery	5	42
114278	2020-08-09 18:48:40	2020-08-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	43529	delivery	5	28
114279	2020-08-09 18:50:04	2020-08-09	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	36316	delivery	5	43
114280	2020-08-09 18:50:42	2020-08-09	14	[{"id_menu":2,"count":1}]	17345	delivery	5	19
114281	2020-08-09 18:51:13	2020-08-09	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":3}]	36288	delivery	5	31
114282	2020-08-09 18:52:14	2020-08-09	17	[{"id_menu":4,"count":1}]	43594	delivery	5	22
114283	2020-08-09 18:52:57	2020-08-09	9	[{"id_menu":7,"count":1}]	14913	pick-up	0	9
114284	2020-08-09 18:53:13	2020-08-09	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	20545	delivery	5	31
114285	2020-08-09 18:54:55	2020-08-09	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13111	delivery	5	43
114286	2020-08-09 18:55:38	2020-08-09	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	13800	delivery	5	31
114287	2020-08-09 18:55:56	2020-08-09	8	[{"id_menu":5,"count":1}]	43653	delivery	5	13
114288	2020-08-09 18:56:38	2020-08-09	8	[{"id_menu":5,"count":1}]	10647	delivery	5	13
114289	2020-08-09 18:57:09	2020-08-09	9	[{"id_menu":6,"count":1}]	28601	delivery	5	14
114290	2020-08-09 18:57:45	2020-08-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	35505	delivery	5	22
114291	2020-08-09 18:57:59	2020-08-09	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	43596	pick-up	0	24
114292	2020-08-09 18:59:08	2020-08-09	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	33647	delivery	5	53
114293	2020-08-09 19:01:52	2020-08-09	8	[{"id_menu":5,"count":1}]	2014	pick-up	0	8
114294	2020-08-09 19:01:59	2020-08-09	9	[{"id_menu":6,"count":2}]	43535	delivery	5	14
114295	2020-08-09 19:04:41	2020-08-09	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	42840	delivery	5	22
114296	2020-08-09 19:06:10	2020-08-09	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	519	delivery	5	26
114297	2020-08-09 19:06:38	2020-08-09	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	13844	pick-up	0	21
114298	2020-08-09 19:07:20	2020-08-09	12	[{"id_menu":1,"count":1}]	18950	pick-up	0	12
114299	2020-08-09 19:09:48	2020-08-09	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	5138	pick-up	0	22
114300	2020-08-09 19:10:54	2020-08-09	17	[{"id_menu":4,"count":1}]	3604	pick-up	0	17
114301	2020-08-09 19:11:11	2020-08-09	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18840	delivery	5	22
114302	2020-08-09 19:11:16	2020-08-09	17	[{"id_menu":4,"count":1}]	34219	delivery	5	22
114303	2020-08-09 19:12:12	2020-08-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26542	delivery	5	23
114304	2020-08-09 19:12:50	2020-08-09	12	[{"id_menu":3,"count":1}]	8442	delivery	5	17
114305	2020-08-09 19:15:34	2020-08-09	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5336	pick-up	0	40
114306	2020-08-09 19:18:04	2020-08-09	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	43499	delivery	5	26
114307	2020-08-09 19:18:14	2020-08-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	43610	delivery	5	22
114308	2020-08-09 19:20:15	2020-08-09	14	[{"id_menu":2,"count":1}]	20035	delivery	5	19
114309	2020-08-09 19:20:58	2020-08-09	9	[{"id_menu":7,"count":1}]	43471	delivery	5	14
114310	2020-08-09 19:21:30	2020-08-09	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	24604	delivery	5	25
114311	2020-08-09 19:22:49	2020-08-09	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	19163	delivery	5	45
114312	2020-08-09 19:25:21	2020-08-09	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43686	delivery	5	49
114313	2020-08-09 19:25:56	2020-08-09	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	37950	delivery	5	28
114314	2020-08-09 19:26:10	2020-08-09	8	[{"id_menu":5,"count":1}]	37089	delivery	5	13
114315	2020-08-09 19:26:51	2020-08-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	21450	delivery	5	28
114316	2020-08-09 19:27:39	2020-08-09	9	[{"id_menu":6,"count":1}]	21383	delivery	5	14
114317	2020-08-09 19:29:28	2020-08-09	17	[{"id_menu":4,"count":1}]	6622	pick-up	0	17
114318	2020-08-09 19:29:30	2020-08-09	9	[{"id_menu":6,"count":2}]	40587	delivery	5	14
114319	2020-08-09 19:29:51	2020-08-09	14	[{"id_menu":2,"count":1}]	1374	pick-up	0	14
114320	2020-08-09 19:31:04	2020-08-09	8	[{"id_menu":5,"count":1}]	23130	delivery	5	13
114321	2020-08-09 19:33:51	2020-08-09	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	14491	delivery	5	30
114322	2020-08-09 19:35:29	2020-08-09	9	[{"id_menu":6,"count":1}]	43694	pick-up	0	9
114323	2020-08-09 19:39:17	2020-08-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	28612	delivery	5	23
114324	2020-08-09 19:39:18	2020-08-09	12	[{"id_menu":1,"count":1}]	29860	delivery	5	17
114325	2020-08-09 19:40:23	2020-08-09	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	37925	delivery	5	45
114326	2020-08-09 19:48:06	2020-08-09	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	20877	delivery	5	43
114327	2020-08-09 19:51:52	2020-08-09	17	[{"id_menu":4,"count":1}]	24752	delivery	5	22
114328	2020-08-09 19:52:19	2020-08-09	12	[{"id_menu":1,"count":1}]	15884	delivery	5	17
114329	2020-08-09 19:56:19	2020-08-09	9	[{"id_menu":6,"count":1}]	26628	pick-up	0	9
114330	2020-08-09 19:58:39	2020-08-09	17	[{"id_menu":4,"count":1}]	15400	pick-up	0	17
114331	2020-08-09 19:59:20	2020-08-09	9	[{"id_menu":6,"count":1}]	36842	delivery	5	14
114332	2020-08-09 20:01:35	2020-08-09	9	[{"id_menu":7,"count":1}]	28754	delivery	5	14
114466	2020-08-09 23:28:55	2020-08-09	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	30107	delivery	5	31
114333	2020-08-09 20:01:51	2020-08-09	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	34462	delivery	5	34
114334	2020-08-09 20:04:23	2020-08-09	12	[{"id_menu":3,"count":1}]	18409	pick-up	0	12
114335	2020-08-09 20:04:45	2020-08-09	14	[{"id_menu":2,"count":1}]	16845	delivery	5	19
114336	2020-08-09 20:06:49	2020-08-09	8	[{"id_menu":5,"count":1}]	27090	delivery	5	13
114337	2020-08-09 20:12:25	2020-08-09	8	[{"id_menu":5,"count":1}]	43340	delivery	5	13
114338	2020-08-09 20:12:54	2020-08-09	17	[{"id_menu":4,"count":1}]	12832	pick-up	0	17
114339	2020-08-09 20:14:20	2020-08-09	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	35454	delivery	5	36
114340	2020-08-09 20:16:44	2020-08-09	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	2979	delivery	5	31
114341	2020-08-09 20:19:05	2020-08-09	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	5857	pick-up	0	29
114342	2020-08-09 20:19:14	2020-08-09	8	[{"id_menu":5,"count":1}]	10175	delivery	5	13
114343	2020-08-09 20:25:29	2020-08-09	12	[{"id_menu":1,"count":1}]	17906	pick-up	0	12
114344	2020-08-09 20:27:54	2020-08-09	17	[{"id_menu":4,"count":1}]	37578	delivery	5	22
114345	2020-08-09 20:28:39	2020-08-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	43607	delivery	5	28
114346	2020-08-09 20:28:55	2020-08-09	14	[{"id_menu":2,"count":1}]	43561	delivery	5	19
114347	2020-08-09 20:29:07	2020-08-09	9	[{"id_menu":6,"count":1}]	17995	pick-up	0	9
114348	2020-08-09 20:32:51	2020-08-09	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	43623	delivery	5	43
114349	2020-08-09 20:34:11	2020-08-09	8	[{"id_menu":5,"count":1}]	43443	delivery	5	13
114350	2020-08-09 20:35:08	2020-08-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	15279	delivery	5	28
114351	2020-08-09 20:35:57	2020-08-09	17	[{"id_menu":4,"count":1}]	36888	delivery	5	22
114352	2020-08-09 20:38:03	2020-08-09	9	[{"id_menu":6,"count":1}]	43497	delivery	5	14
114353	2020-08-09 20:39:12	2020-08-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	38206	delivery	5	22
114354	2020-08-09 20:40:00	2020-08-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	43434	delivery	5	28
114355	2020-08-09 20:46:46	2020-08-09	12	[{"id_menu":3,"count":1}]	43450	delivery	5	17
114356	2020-08-09 20:47:12	2020-08-09	8	[{"id_menu":5,"count":1}]	17218	delivery	5	13
114357	2020-08-09 20:49:35	2020-08-09	17	[{"id_menu":4,"count":1}]	26425	delivery	5	22
114358	2020-08-09 20:56:36	2020-08-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43441	delivery	5	23
114359	2020-08-09 20:59:04	2020-08-09	14	[{"id_menu":2,"count":1}]	43634	pick-up	0	14
114360	2020-08-09 21:02:55	2020-08-09	12	[{"id_menu":3,"count":1}]	18119	delivery	5	17
114361	2020-08-09 21:04:28	2020-08-09	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2445	pick-up	0	26
114362	2020-08-09 21:04:35	2020-08-09	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1258	pick-up	0	26
114363	2020-08-09 21:04:41	2020-08-09	9	[{"id_menu":6,"count":1}]	43575	delivery	5	14
114364	2020-08-09 21:05:03	2020-08-09	14	[{"id_menu":2,"count":1}]	13169	delivery	5	19
114365	2020-08-09 21:06:54	2020-08-09	9	[{"id_menu":7,"count":1}]	11314	delivery	5	14
114366	2020-08-09 21:07:01	2020-08-09	8	[{"id_menu":5,"count":1}]	10870	pick-up	0	8
114367	2020-08-09 21:07:40	2020-08-09	9	[{"id_menu":6,"count":1}]	16120	delivery	5	14
114368	2020-08-09 21:08:37	2020-08-09	9	[{"id_menu":6,"count":1}]	6444	delivery	5	14
114369	2020-08-09 21:09:33	2020-08-09	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17527	delivery	5	37
114370	2020-08-09 21:09:58	2020-08-09	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	43642	delivery	5	31
114371	2020-08-09 21:12:06	2020-08-09	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	34581	delivery	5	22
114372	2020-08-09 21:12:18	2020-08-09	12	[{"id_menu":1,"count":1}]	14605	delivery	5	17
114373	2020-08-09 21:12:41	2020-08-09	9	[{"id_menu":6,"count":1}]	40679	pick-up	0	9
114374	2020-08-09 21:13:17	2020-08-09	14	[{"id_menu":2,"count":1}]	8041	delivery	5	19
114375	2020-08-09 21:14:10	2020-08-09	8	[{"id_menu":5,"count":1}]	36020	pick-up	0	8
114376	2020-08-09 21:15:53	2020-08-09	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	24073	delivery	5	44
114377	2020-08-09 21:18:45	2020-08-09	12	[{"id_menu":3,"count":1}]	43676	delivery	5	17
114378	2020-08-09 21:20:49	2020-08-09	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	41131	delivery	5	34
114379	2020-08-09 21:23:50	2020-08-09	9	[{"id_menu":7,"count":1}]	43662	delivery	5	14
114380	2020-08-09 21:24:28	2020-08-09	12	[{"id_menu":1,"count":1}]	3006	delivery	5	17
114381	2020-08-09 21:25:05	2020-08-09	12	[{"id_menu":1,"count":1}]	11358	delivery	5	17
114382	2020-08-09 21:25:10	2020-08-09	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	28288	delivery	5	27
114383	2020-08-09 21:25:11	2020-08-09	17	[{"id_menu":4,"count":1}]	37	pick-up	0	17
114384	2020-08-09 21:26:37	2020-08-09	17	[{"id_menu":4,"count":1}]	37077	pick-up	0	17
114385	2020-08-09 21:26:56	2020-08-09	14	[{"id_menu":2,"count":1}]	8341	delivery	5	19
114386	2020-08-09 21:28:23	2020-08-09	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	43526	delivery	5	52
114387	2020-08-09 21:29:35	2020-08-09	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	43465	delivery	5	43
114388	2020-08-09 21:31:25	2020-08-09	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	612	pick-up	0	21
114389	2020-08-09 21:35:12	2020-08-09	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	33918	delivery	5	57
114390	2020-08-09 21:36:40	2020-08-09	9	[{"id_menu":6,"count":1}]	14146	pick-up	0	9
114391	2020-08-09 21:37:17	2020-08-09	14	[{"id_menu":2,"count":1}]	43458	pick-up	0	14
114392	2020-08-09 21:39:45	2020-08-09	9	[{"id_menu":7,"count":1}]	19300	pick-up	0	9
114393	2020-08-09 21:39:56	2020-08-09	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9621	delivery	5	43
114394	2020-08-09 21:40:15	2020-08-09	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	43632	delivery	5	38
114395	2020-08-09 21:40:33	2020-08-09	8	[{"id_menu":5,"count":1}]	37702	delivery	5	13
114396	2020-08-09 21:44:46	2020-08-09	14	[{"id_menu":2,"count":3}]	38965	delivery	5	19
114397	2020-08-09 21:47:20	2020-08-09	8	[{"id_menu":5,"count":1}]	4998	delivery	5	13
114398	2020-08-09 21:47:45	2020-08-09	9	[{"id_menu":7,"count":1}]	43548	delivery	5	14
114399	2020-08-09 21:50:40	2020-08-09	17	[{"id_menu":4,"count":1}]	40543	delivery	5	22
114400	2020-08-09 21:52:27	2020-08-09	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16544	delivery	5	43
114401	2020-08-09 21:54:02	2020-08-09	9	[{"id_menu":7,"count":1}]	35415	delivery	5	14
114402	2020-08-09 21:54:32	2020-08-09	17	[{"id_menu":4,"count":1}]	25639	pick-up	0	17
114403	2020-08-09 21:56:46	2020-08-09	14	[{"id_menu":2,"count":1}]	39300	pick-up	0	14
114404	2020-08-09 21:57:12	2020-08-09	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	35060	delivery	5	26
114405	2020-08-09 22:00:34	2020-08-09	9	[{"id_menu":6,"count":1}]	42274	delivery	5	14
114406	2020-08-09 22:00:47	2020-08-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31546	pick-up	0	17
114407	2020-08-09 22:01:12	2020-08-09	17	[{"id_menu":4,"count":2}]	42027	delivery	5	22
114408	2020-08-09 22:02:43	2020-08-09	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	40458	delivery	5	46
114409	2020-08-09 22:03:20	2020-08-09	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	11167	delivery	5	39
114410	2020-08-09 22:03:25	2020-08-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":3}]	36515	delivery	5	23
114411	2020-08-09 22:03:26	2020-08-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	27488	pick-up	0	23
114412	2020-08-09 22:06:42	2020-08-09	9	[{"id_menu":6,"count":2}]	14558	delivery	5	14
114413	2020-08-09 22:08:12	2020-08-09	12	[{"id_menu":3,"count":1}]	42314	delivery	5	17
114414	2020-08-09 22:08:29	2020-08-09	12	[{"id_menu":3,"count":1}]	14258	pick-up	0	12
114415	2020-08-09 22:09:24	2020-08-09	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	43645	delivery	5	22
114416	2020-08-09 22:10:37	2020-08-09	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	10997	delivery	5	25
114417	2020-08-09 22:12:41	2020-08-09	12	[{"id_menu":1,"count":1}]	42465	delivery	5	17
114418	2020-08-09 22:14:49	2020-08-09	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	12862	delivery	5	37
114419	2020-08-09 22:15:29	2020-08-09	12	[{"id_menu":1,"count":1}]	15565	pick-up	0	12
114420	2020-08-09 22:16:03	2020-08-09	14	[{"id_menu":2,"count":1}]	6829	pick-up	0	14
114421	2020-08-09 22:17:14	2020-08-09	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	31557	delivery	5	25
114422	2020-08-09 22:20:37	2020-08-09	9	[{"id_menu":7,"count":1}]	40712	delivery	5	14
114423	2020-08-09 22:23:44	2020-08-09	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	18085	delivery	5	26
114424	2020-08-09 22:23:48	2020-08-09	17	[{"id_menu":4,"count":1}]	33542	delivery	5	22
114425	2020-08-09 22:25:43	2020-08-09	9	[{"id_menu":6,"count":2}]	43688	delivery	5	14
114426	2020-08-09 22:27:01	2020-08-09	9	[{"id_menu":6,"count":3}]	43691	delivery	5	14
114427	2020-08-09 22:27:14	2020-08-09	9	[{"id_menu":6,"count":2}]	15267	delivery	5	14
114428	2020-08-09 22:29:37	2020-08-09	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	35732	delivery	5	26
114429	2020-08-09 22:29:53	2020-08-09	9	[{"id_menu":7,"count":1}]	21690	delivery	5	14
114430	2020-08-09 22:31:46	2020-08-09	17	[{"id_menu":4,"count":1}]	43530	delivery	5	22
114431	2020-08-09 22:32:16	2020-08-09	14	[{"id_menu":2,"count":1}]	43490	delivery	5	19
114432	2020-08-09 22:33:16	2020-08-09	9	[{"id_menu":6,"count":1}]	40688	delivery	5	14
114433	2020-08-09 22:33:47	2020-08-09	9	[{"id_menu":7,"count":1}]	43670	delivery	5	14
114434	2020-08-09 22:34:08	2020-08-09	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	20288	delivery	5	31
114435	2020-08-09 22:38:59	2020-08-09	14	[{"id_menu":2,"count":1}]	33020	delivery	5	19
114436	2020-08-09 22:39:25	2020-08-09	9	[{"id_menu":7,"count":1}]	27560	delivery	5	14
114437	2020-08-09 22:40:57	2020-08-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	26588	delivery	5	28
114438	2020-08-09 22:41:11	2020-08-09	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":3}]	5183	delivery	5	23
114439	2020-08-09 22:41:16	2020-08-09	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	43650	delivery	5	26
114440	2020-08-09 22:41:53	2020-08-09	12	[{"id_menu":3,"count":1}]	43479	delivery	5	17
114441	2020-08-09 22:44:38	2020-08-09	9	[{"id_menu":7,"count":2}]	1322	pick-up	0	9
114442	2020-08-09 22:45:29	2020-08-09	9	[{"id_menu":6,"count":1}]	28929	pick-up	0	9
114443	2020-08-09 22:47:05	2020-08-09	9	[{"id_menu":6,"count":1}]	30490	delivery	5	14
114444	2020-08-09 22:48:40	2020-08-09	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	43556	delivery	5	39
114445	2020-08-09 22:49:42	2020-08-09	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	31018	delivery	5	42
114446	2020-08-09 22:55:42	2020-08-09	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	30478	delivery	5	34
114447	2020-08-09 22:58:16	2020-08-09	9	[{"id_menu":7,"count":1}]	19741	delivery	5	14
114448	2020-08-09 22:58:47	2020-08-09	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	29678	pick-up	0	26
114449	2020-08-09 22:59:20	2020-08-09	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	27907	delivery	5	28
114450	2020-08-09 23:00:42	2020-08-09	12	[{"id_menu":1,"count":2}]	43480	delivery	5	17
114451	2020-08-09 23:01:45	2020-08-09	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	43692	delivery	5	22
114452	2020-08-09 23:01:59	2020-08-09	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5799	delivery	5	40
114453	2020-08-09 23:04:34	2020-08-09	12	[{"id_menu":3,"count":2}]	4956	pick-up	0	12
114454	2020-08-09 23:09:45	2020-08-09	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10702	delivery	5	31
114455	2020-08-09 23:11:10	2020-08-09	9	[{"id_menu":6,"count":1}]	26261	delivery	5	14
114456	2020-08-09 23:11:17	2020-08-09	12	[{"id_menu":3,"count":1}]	34286	delivery	5	17
114457	2020-08-09 23:11:23	2020-08-09	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	337	pick-up	0	26
114458	2020-08-09 23:13:34	2020-08-09	12	[{"id_menu":1,"count":1}]	43626	delivery	5	17
114459	2020-08-09 23:13:37	2020-08-09	17	[{"id_menu":4,"count":1}]	6020	pick-up	0	17
114460	2020-08-09 23:13:58	2020-08-09	12	[{"id_menu":3,"count":1}]	38666	delivery	5	17
114461	2020-08-09 23:20:56	2020-08-09	9	[{"id_menu":7,"count":1}]	10968	pick-up	0	9
114462	2020-08-09 23:21:35	2020-08-09	12	[{"id_menu":3,"count":1}]	287	delivery	5	17
114463	2020-08-09 23:22:03	2020-08-09	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27547	delivery	5	31
114464	2020-08-09 23:22:07	2020-08-09	12	[{"id_menu":1,"count":1}]	43469	delivery	5	17
114465	2020-08-09 23:26:29	2020-08-09	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	35951	delivery	5	28
114467	2020-08-09 23:31:02	2020-08-09	12	[{"id_menu":1,"count":1}]	14565	delivery	5	17
114468	2020-08-09 23:36:34	2020-08-09	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	6156	pick-up	0	21
114469	2020-08-09 23:37:34	2020-08-09	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	25590	pick-up	0	38
114470	2020-08-09 23:37:38	2020-08-09	17	[{"id_menu":4,"count":1}]	43658	pick-up	0	17
114471	2020-08-09 23:40:51	2020-08-09	14	[{"id_menu":2,"count":1}]	7626	delivery	5	19
114472	2020-08-09 23:41:04	2020-08-09	14	[{"id_menu":2,"count":1}]	10223	pick-up	0	14
114473	2020-08-09 23:41:25	2020-08-09	17	[{"id_menu":4,"count":1}]	43527	delivery	5	22
114474	2020-08-09 23:42:43	2020-08-09	17	[{"id_menu":4,"count":1}]	21251	delivery	5	22
114475	2020-08-09 23:44:30	2020-08-09	8	[{"id_menu":5,"count":1}]	41296	pick-up	0	8
114476	2020-08-09 23:44:46	2020-08-09	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22611	delivery	5	34
114477	2020-08-09 23:44:57	2020-08-09	8	[{"id_menu":5,"count":1}]	43627	delivery	5	13
114478	2020-08-09 23:45:23	2020-08-09	12	[{"id_menu":1,"count":1}]	1007	pick-up	0	12
114479	2020-08-09 23:48:08	2020-08-09	9	[{"id_menu":7,"count":1}]	43508	delivery	5	14
114480	2020-08-09 23:48:54	2020-08-09	14	[{"id_menu":2,"count":1}]	33202	delivery	5	19
114481	2020-08-09 23:50:25	2020-08-09	9	[{"id_menu":7,"count":1}]	28525	delivery	5	14
114482	2020-08-09 23:53:17	2020-08-09	8	[{"id_menu":5,"count":1}]	5303	delivery	5	13
114483	2020-08-09 23:53:47	2020-08-09	9	[{"id_menu":7,"count":2}]	39033	delivery	5	14
114484	2020-08-10 00:09:27	2020-08-10	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	9633	delivery	5	45
114485	2020-08-10 00:11:13	2020-08-10	9	[{"id_menu":6,"count":1}]	14290	pick-up	0	9
114486	2020-08-10 00:12:53	2020-08-10	9	[{"id_menu":6,"count":2}]	24808	delivery	5	14
114487	2020-08-10 00:13:22	2020-08-10	14	[{"id_menu":2,"count":1}]	7118	delivery	5	19
114488	2020-08-10 00:13:32	2020-08-10	14	[{"id_menu":2,"count":1}]	43837	delivery	5	19
114489	2020-08-10 00:13:51	2020-08-10	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	43763	delivery	5	22
114490	2020-08-10 00:15:00	2020-08-10	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	34252	pick-up	0	31
114491	2020-08-10 00:16:43	2020-08-10	12	[{"id_menu":1,"count":1}]	31997	pick-up	0	12
114492	2020-08-10 00:25:37	2020-08-10	12	[{"id_menu":1,"count":1}]	10273	pick-up	0	12
114493	2020-08-10 00:29:23	2020-08-10	9	[{"id_menu":6,"count":1}]	19210	delivery	5	14
114494	2020-08-10 00:30:30	2020-08-10	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	19382	pick-up	0	21
114495	2020-08-10 00:35:36	2020-08-10	9	[{"id_menu":6,"count":1}]	43930	delivery	5	14
114496	2020-08-10 00:36:42	2020-08-10	8	[{"id_menu":5,"count":1}]	15205	delivery	5	13
114497	2020-08-10 00:38:48	2020-08-10	17	[{"id_menu":4,"count":1}]	33032	delivery	5	22
114498	2020-08-10 00:40:19	2020-08-10	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	27273	delivery	5	31
114499	2020-08-10 00:40:48	2020-08-10	9	[{"id_menu":6,"count":1}]	27268	delivery	5	14
114500	2020-08-10 00:44:10	2020-08-10	12	[{"id_menu":1,"count":1}]	43746	delivery	5	17
114501	2020-08-10 00:45:35	2020-08-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13740	delivery	5	22
114502	2020-08-10 00:47:11	2020-08-10	14	[{"id_menu":2,"count":1}]	41689	delivery	5	19
114503	2020-08-10 00:48:40	2020-08-10	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	43952	delivery	5	45
114504	2020-08-10 00:49:36	2020-08-10	9	[{"id_menu":6,"count":1}]	12527	delivery	5	14
114505	2020-08-10 00:52:15	2020-08-10	12	[{"id_menu":1,"count":1}]	13528	delivery	5	17
114506	2020-08-10 00:56:42	2020-08-10	8	[{"id_menu":5,"count":1}]	38181	delivery	5	13
114507	2020-08-10 00:59:56	2020-08-10	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	15086	delivery	5	26
114508	2020-08-10 01:01:43	2020-08-10	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	43913	delivery	5	29
114509	2020-08-10 01:01:56	2020-08-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43941	delivery	5	23
114510	2020-08-10 01:07:36	2020-08-10	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18218	delivery	5	36
114511	2020-08-10 01:08:10	2020-08-10	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1548	pick-up	0	26
114512	2020-08-10 01:10:21	2020-08-10	9	[{"id_menu":6,"count":1}]	27230	delivery	5	14
114513	2020-08-10 01:10:48	2020-08-10	8	[{"id_menu":5,"count":1}]	43735	delivery	5	13
114514	2020-08-10 01:11:16	2020-08-10	9	[{"id_menu":6,"count":1}]	24996	pick-up	0	9
114515	2020-08-10 01:17:36	2020-08-10	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	31671	delivery	5	22
114516	2020-08-10 01:18:08	2020-08-10	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	29231	pick-up	0	52
114517	2020-08-10 01:19:49	2020-08-10	17	[{"id_menu":4,"count":1}]	2219	pick-up	0	17
114518	2020-08-10 01:21:28	2020-08-10	8	[{"id_menu":5,"count":1}]	28972	delivery	5	13
114519	2020-08-10 01:26:49	2020-08-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	43886	delivery	5	28
114520	2020-08-10 01:29:24	2020-08-10	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	41294	delivery	5	40
114521	2020-08-10 01:29:34	2020-08-10	17	[{"id_menu":4,"count":1}]	21121	delivery	5	22
114522	2020-08-10 01:30:12	2020-08-10	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11156	pick-up	0	38
114523	2020-08-10 01:31:09	2020-08-10	12	[{"id_menu":3,"count":1}]	6134	pick-up	0	12
114524	2020-08-10 01:32:16	2020-08-10	12	[{"id_menu":3,"count":1}]	9685	delivery	5	17
114525	2020-08-10 01:32:48	2020-08-10	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	5468	delivery	5	22
114526	2020-08-10 01:40:16	2020-08-10	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	27895	delivery	5	26
114527	2020-08-10 01:43:46	2020-08-10	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	43937	delivery	5	31
114528	2020-08-10 01:44:32	2020-08-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	43794	delivery	5	22
114529	2020-08-10 01:44:42	2020-08-10	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29728	delivery	5	40
114530	2020-08-10 01:47:19	2020-08-10	17	[{"id_menu":4,"count":1}]	31401	delivery	5	22
114531	2020-08-10 01:47:45	2020-08-10	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	28302	delivery	5	30
114532	2020-08-10 01:58:38	2020-08-10	9	[{"id_menu":7,"count":1}]	21325	delivery	5	14
114533	2020-08-10 02:02:00	2020-08-10	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	43867	delivery	5	43
114534	2020-08-10 02:02:26	2020-08-10	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	43872	delivery	5	31
114535	2020-08-10 02:04:48	2020-08-10	9	[{"id_menu":7,"count":1}]	1321	pick-up	0	9
114536	2020-08-10 02:06:33	2020-08-10	8	[{"id_menu":5,"count":1}]	43770	delivery	5	13
114537	2020-08-10 02:07:02	2020-08-10	9	[{"id_menu":6,"count":1}]	10208	delivery	5	14
114538	2020-08-10 02:13:49	2020-08-10	9	[{"id_menu":7,"count":1}]	24923	delivery	5	14
114539	2020-08-10 02:18:14	2020-08-10	17	[{"id_menu":4,"count":1}]	9082	delivery	5	22
114540	2020-08-10 02:20:07	2020-08-10	14	[{"id_menu":2,"count":1}]	1316	pick-up	0	14
114541	2020-08-10 02:24:23	2020-08-10	14	[{"id_menu":2,"count":1}]	35795	delivery	5	19
114542	2020-08-10 02:25:00	2020-08-10	17	[{"id_menu":4,"count":1}]	43791	delivery	5	22
114543	2020-08-10 02:26:11	2020-08-10	9	[{"id_menu":6,"count":1}]	9693	pick-up	0	9
114544	2020-08-10 02:27:39	2020-08-10	8	[{"id_menu":5,"count":1}]	4146	delivery	5	13
114545	2020-08-10 02:29:46	2020-08-10	12	[{"id_menu":3,"count":1}]	20298	delivery	5	17
114546	2020-08-10 02:31:37	2020-08-10	12	[{"id_menu":1,"count":1}]	5582	delivery	5	17
114547	2020-08-10 02:35:05	2020-08-10	9	[{"id_menu":7,"count":1}]	22390	delivery	5	14
114548	2020-08-10 02:35:58	2020-08-10	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24708	delivery	5	34
114549	2020-08-10 02:38:11	2020-08-10	12	[{"id_menu":1,"count":1}]	36574	pick-up	0	12
114550	2020-08-10 02:39:05	2020-08-10	14	[{"id_menu":2,"count":1}]	1617	pick-up	0	14
114551	2020-08-10 02:44:20	2020-08-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17181	delivery	5	23
114552	2020-08-10 02:47:04	2020-08-10	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5871	delivery	5	45
114553	2020-08-10 03:01:14	2020-08-10	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	21390	pick-up	0	29
114554	2020-08-10 03:02:12	2020-08-10	9	[{"id_menu":6,"count":1}]	8081	pick-up	0	9
114555	2020-08-10 03:10:27	2020-08-10	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":2}]	37966	delivery	5	31
114556	2020-08-10 03:12:30	2020-08-10	9	[{"id_menu":7,"count":1}]	40407	delivery	5	14
114557	2020-08-10 03:16:12	2020-08-10	8	[{"id_menu":5,"count":1}]	43774	pick-up	0	8
114558	2020-08-10 03:16:53	2020-08-10	9	[{"id_menu":7,"count":1}]	42249	delivery	5	14
114559	2020-08-10 03:18:30	2020-08-10	9	[{"id_menu":6,"count":1}]	35807	delivery	5	14
114560	2020-08-10 03:27:19	2020-08-10	17	[{"id_menu":4,"count":1}]	22539	delivery	5	22
114561	2020-08-10 03:33:37	2020-08-10	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	43945	delivery	5	40
114562	2020-08-10 03:33:52	2020-08-10	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	43748	delivery	5	22
114563	2020-08-10 03:35:07	2020-08-10	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	18974	pick-up	0	26
114564	2020-08-10 03:36:56	2020-08-10	12	[{"id_menu":1,"count":1}]	18948	delivery	5	17
114565	2020-08-10 03:39:27	2020-08-10	12	[{"id_menu":1,"count":1}]	37913	delivery	5	17
114566	2020-08-10 03:45:08	2020-08-10	12	[{"id_menu":1,"count":1}]	39080	delivery	5	17
114567	2020-08-10 03:46:43	2020-08-10	9	[{"id_menu":6,"count":1}]	37061	pick-up	0	9
114568	2020-08-10 03:56:11	2020-08-10	9	[{"id_menu":6,"count":1}]	2153	pick-up	0	9
114569	2020-08-10 03:58:30	2020-08-10	14	[{"id_menu":2,"count":1}]	43745	delivery	5	19
114570	2020-08-10 04:01:15	2020-08-10	17	[{"id_menu":4,"count":1}]	10186	delivery	5	22
114571	2020-08-10 04:01:16	2020-08-10	14	[{"id_menu":2,"count":1}]	40139	pick-up	0	14
114572	2020-08-10 04:11:56	2020-08-10	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	15186	delivery	5	26
114573	2020-08-10 04:13:21	2020-08-10	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	35160	delivery	5	26
114574	2020-08-10 04:16:57	2020-08-10	9	[{"id_menu":6,"count":1}]	43936	delivery	5	14
114575	2020-08-10 04:21:35	2020-08-10	12	[{"id_menu":3,"count":1}]	7119	pick-up	0	12
114576	2020-08-10 04:24:06	2020-08-10	12	[{"id_menu":3,"count":1}]	3030	delivery	5	17
114577	2020-08-10 04:25:15	2020-08-10	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	21847	delivery	5	31
114578	2020-08-10 04:25:51	2020-08-10	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	21783	delivery	5	39
114579	2020-08-10 04:26:35	2020-08-10	8	[{"id_menu":5,"count":1}]	40472	delivery	5	13
114580	2020-08-10 04:27:46	2020-08-10	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	38818	delivery	5	37
114581	2020-08-10 04:31:34	2020-08-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	5613	delivery	5	28
114582	2020-08-10 04:32:52	2020-08-10	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5106	delivery	5	45
114583	2020-08-10 04:34:23	2020-08-10	12	[{"id_menu":3,"count":1}]	3047	delivery	5	17
114584	2020-08-10 04:37:39	2020-08-10	14	[{"id_menu":2,"count":1}]	25790	delivery	5	19
114585	2020-08-10 04:40:00	2020-08-10	17	[{"id_menu":4,"count":1}]	221	pick-up	0	17
114586	2020-08-10 04:47:19	2020-08-10	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	10203	delivery	5	26
114587	2020-08-10 04:55:46	2020-08-10	17	[{"id_menu":4,"count":1}]	43806	delivery	5	22
114588	2020-08-10 04:57:59	2020-08-10	8	[{"id_menu":5,"count":1}]	4854	pick-up	0	8
114589	2020-08-10 04:59:15	2020-08-10	34	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	43953	delivery	5	39
114590	2020-08-10 04:59:44	2020-08-10	8	[{"id_menu":5,"count":1}]	21002	pick-up	0	8
114591	2020-08-10 05:00:43	2020-08-10	8	[{"id_menu":5,"count":1}]	34677	delivery	5	13
114592	2020-08-10 05:02:06	2020-08-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	43827	delivery	5	28
114593	2020-08-10 05:02:12	2020-08-10	8	[{"id_menu":5,"count":1}]	43798	pick-up	0	8
114594	2020-08-10 05:02:15	2020-08-10	9	[{"id_menu":6,"count":1}]	43894	delivery	5	14
114595	2020-08-10 05:03:22	2020-08-10	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	43848	delivery	5	27
114596	2020-08-10 05:05:03	2020-08-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	28229	delivery	5	28
114597	2020-08-10 05:06:06	2020-08-10	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	29939	delivery	5	26
114598	2020-08-10 05:12:05	2020-08-10	9	[{"id_menu":7,"count":1}]	5447	delivery	5	14
114599	2020-08-10 05:16:39	2020-08-10	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	18468	delivery	5	43
114600	2020-08-10 05:16:40	2020-08-10	9	[{"id_menu":6,"count":2}]	14956	delivery	5	14
114601	2020-08-10 05:18:30	2020-08-10	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	15326	pick-up	0	26
114602	2020-08-10 05:19:55	2020-08-10	17	[{"id_menu":4,"count":1}]	18746	delivery	5	22
114603	2020-08-10 05:20:19	2020-08-10	17	[{"id_menu":4,"count":1}]	13795	delivery	5	22
114604	2020-08-10 05:23:04	2020-08-10	17	[{"id_menu":4,"count":1}]	1929	pick-up	0	17
114605	2020-08-10 05:23:52	2020-08-10	14	[{"id_menu":2,"count":1}]	43786	delivery	5	19
114606	2020-08-10 05:28:55	2020-08-10	14	[{"id_menu":2,"count":1}]	2172	pick-up	0	14
114607	2020-08-10 05:30:29	2020-08-10	9	[{"id_menu":7,"count":1}]	43811	delivery	5	14
114608	2020-08-10 05:33:51	2020-08-10	12	[{"id_menu":3,"count":1}]	3071	pick-up	0	12
114609	2020-08-10 05:35:04	2020-08-10	17	[{"id_menu":4,"count":1}]	43864	pick-up	0	17
114610	2020-08-10 05:40:23	2020-08-10	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	20329	delivery	5	38
114611	2020-08-10 05:43:27	2020-08-10	8	[{"id_menu":5,"count":1}]	9093	pick-up	0	8
114612	2020-08-10 05:47:37	2020-08-10	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14354	delivery	5	35
114613	2020-08-10 05:49:01	2020-08-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	43766	delivery	5	28
114614	2020-08-10 05:49:34	2020-08-10	14	[{"id_menu":2,"count":1}]	18227	pick-up	0	14
114615	2020-08-10 05:53:24	2020-08-10	8	[{"id_menu":5,"count":1}]	23343	delivery	5	13
114616	2020-08-10 05:54:58	2020-08-10	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	19883	delivery	5	52
114617	2020-08-10 05:58:31	2020-08-10	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	17700	pick-up	0	20
114618	2020-08-10 06:01:03	2020-08-10	8	[{"id_menu":5,"count":1}]	2925	delivery	5	13
114619	2020-08-10 06:01:42	2020-08-10	9	[{"id_menu":7,"count":1}]	22604	delivery	5	14
114620	2020-08-10 06:09:43	2020-08-10	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43828	delivery	5	31
114621	2020-08-10 06:12:38	2020-08-10	14	[{"id_menu":2,"count":1}]	31780	pick-up	0	14
114622	2020-08-10 06:13:54	2020-08-10	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	2021	delivery	5	29
114623	2020-08-10 06:21:28	2020-08-10	9	[{"id_menu":7,"count":1}]	26829	delivery	5	14
114624	2020-08-10 06:36:51	2020-08-10	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	35898	delivery	5	26
114625	2020-08-10 06:38:19	2020-08-10	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	43775	delivery	5	36
114626	2020-08-10 06:38:27	2020-08-10	9	[{"id_menu":6,"count":1}]	10546	delivery	5	14
114627	2020-08-10 06:40:30	2020-08-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9970	delivery	5	23
114628	2020-08-10 06:40:55	2020-08-10	12	[{"id_menu":1,"count":1}]	2794	pick-up	0	12
114629	2020-08-10 06:41:49	2020-08-10	8	[{"id_menu":5,"count":1}]	8229	delivery	5	13
114630	2020-08-10 06:51:25	2020-08-10	17	[{"id_menu":4,"count":1}]	38721	pick-up	0	17
114631	2020-08-10 06:55:01	2020-08-10	12	[{"id_menu":1,"count":1}]	43926	delivery	5	17
114632	2020-08-10 06:55:07	2020-08-10	8	[{"id_menu":5,"count":2}]	37304	delivery	5	13
114633	2020-08-10 06:55:38	2020-08-10	8	[{"id_menu":5,"count":1}]	43829	delivery	5	13
114634	2020-08-10 07:06:00	2020-08-10	8	[{"id_menu":5,"count":1}]	43863	delivery	5	13
114635	2020-08-10 07:13:49	2020-08-10	17	[{"id_menu":4,"count":1}]	43955	delivery	5	22
114636	2020-08-10 07:17:50	2020-08-10	9	[{"id_menu":7,"count":1}]	43719	delivery	5	14
114637	2020-08-10 07:21:34	2020-08-10	12	[{"id_menu":3,"count":1}]	2055	delivery	5	17
114638	2020-08-10 07:28:45	2020-08-10	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	17629	delivery	5	37
114639	2020-08-10 07:28:48	2020-08-10	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	43730	delivery	5	48
114640	2020-08-10 07:31:55	2020-08-10	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	13155	delivery	5	48
114641	2020-08-10 07:32:41	2020-08-10	14	[{"id_menu":2,"count":1}]	1229	pick-up	0	14
114642	2020-08-10 07:34:14	2020-08-10	8	[{"id_menu":5,"count":1}]	2492	pick-up	0	8
114643	2020-08-10 07:41:19	2020-08-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11413	delivery	5	22
114644	2020-08-10 07:44:23	2020-08-10	43	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	43768	pick-up	0	43
114645	2020-08-10 07:48:37	2020-08-10	9	[{"id_menu":6,"count":1}]	43844	delivery	5	14
114646	2020-08-10 07:49:31	2020-08-10	9	[{"id_menu":6,"count":1}]	43743	delivery	5	14
114647	2020-08-10 07:53:02	2020-08-10	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	43194	delivery	5	43
114648	2020-08-10 07:53:27	2020-08-10	17	[{"id_menu":4,"count":1}]	8866	delivery	5	22
114649	2020-08-10 07:53:33	2020-08-10	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	20219	delivery	5	31
114650	2020-08-10 07:54:12	2020-08-10	17	[{"id_menu":4,"count":1}]	29030	delivery	5	22
114651	2020-08-10 08:00:27	2020-08-10	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	22987	pick-up	0	26
114652	2020-08-10 08:01:22	2020-08-10	12	[{"id_menu":1,"count":1}]	43840	delivery	5	17
114653	2020-08-10 08:04:25	2020-08-10	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	43760	delivery	5	31
114654	2020-08-10 08:06:27	2020-08-10	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	3924	pick-up	0	21
114655	2020-08-10 08:10:28	2020-08-10	14	[{"id_menu":2,"count":1}]	23931	pick-up	0	14
114656	2020-08-10 08:11:57	2020-08-10	17	[{"id_menu":4,"count":1}]	2806	delivery	5	22
114657	2020-08-10 08:19:53	2020-08-10	12	[{"id_menu":1,"count":1}]	2333	delivery	5	17
114658	2020-08-10 08:20:34	2020-08-10	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	39666	delivery	5	22
114659	2020-08-10 08:20:50	2020-08-10	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	43858	delivery	5	31
114660	2020-08-10 08:22:18	2020-08-10	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	34991	delivery	5	39
114661	2020-08-10 08:23:08	2020-08-10	12	[{"id_menu":1,"count":1}]	17861	pick-up	0	12
114662	2020-08-10 08:23:08	2020-08-10	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	43732	delivery	5	36
114663	2020-08-10 08:24:01	2020-08-10	14	[{"id_menu":2,"count":1}]	12692	delivery	5	19
114664	2020-08-10 08:24:38	2020-08-10	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	30011	delivery	5	26
114665	2020-08-10 08:25:07	2020-08-10	17	[{"id_menu":4,"count":1}]	43866	delivery	5	22
114666	2020-08-10 08:25:51	2020-08-10	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	43839	delivery	5	37
114667	2020-08-10 08:26:56	2020-08-10	12	[{"id_menu":3,"count":1}]	35885	pick-up	0	12
114668	2020-08-10 08:28:39	2020-08-10	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4798	pick-up	0	39
114669	2020-08-10 08:32:25	2020-08-10	9	[{"id_menu":6,"count":1}]	28656	delivery	5	14
114670	2020-08-10 08:34:52	2020-08-10	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	43815	delivery	5	26
114671	2020-08-10 08:35:17	2020-08-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	9465	delivery	5	28
114672	2020-08-10 08:40:18	2020-08-10	17	[{"id_menu":4,"count":1}]	43728	delivery	5	22
114673	2020-08-10 08:41:44	2020-08-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	43950	delivery	5	23
114674	2020-08-10 08:49:40	2020-08-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	43706	delivery	5	22
114675	2020-08-10 08:55:05	2020-08-10	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	23621	delivery	5	43
114676	2020-08-10 08:57:38	2020-08-10	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	34059	delivery	5	39
114677	2020-08-10 08:58:19	2020-08-10	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	9350	delivery	5	29
114678	2020-08-10 08:58:58	2020-08-10	17	[{"id_menu":4,"count":1}]	34421	pick-up	0	17
114679	2020-08-10 09:03:15	2020-08-10	9	[{"id_menu":6,"count":3}]	12049	delivery	5	14
114680	2020-08-10 09:04:39	2020-08-10	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43851	delivery	5	35
114681	2020-08-10 09:12:16	2020-08-10	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	268	pick-up	0	21
114682	2020-08-10 09:16:23	2020-08-10	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	43756	delivery	5	40
114683	2020-08-10 09:17:24	2020-08-10	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15110	pick-up	0	29
114684	2020-08-10 09:32:19	2020-08-10	9	[{"id_menu":7,"count":1}]	43817	delivery	5	14
114685	2020-08-10 09:36:04	2020-08-10	12	[{"id_menu":1,"count":1}]	23738	pick-up	0	12
114686	2020-08-10 09:37:22	2020-08-10	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2572	pick-up	0	26
114687	2020-08-10 09:54:56	2020-08-10	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	43415	delivery	5	26
114688	2020-08-10 09:59:42	2020-08-10	9	[{"id_menu":7,"count":1}]	43855	delivery	5	14
114689	2020-08-10 10:01:12	2020-08-10	9	[{"id_menu":6,"count":1}]	19735	delivery	5	14
114690	2020-08-10 10:08:27	2020-08-10	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29726	delivery	5	37
114691	2020-08-10 10:12:36	2020-08-10	14	[{"id_menu":2,"count":3}]	43790	pick-up	0	14
114692	2020-08-10 10:12:59	2020-08-10	9	[{"id_menu":7,"count":1}]	37137	delivery	5	14
114693	2020-08-10 10:21:54	2020-08-10	12	[{"id_menu":1,"count":1}]	2183	pick-up	0	12
114694	2020-08-10 10:38:16	2020-08-10	29	[{"id_menu":3,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	43961	delivery	5	34
114695	2020-08-10 10:40:37	2020-08-10	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	7373	delivery	5	27
114696	2020-08-10 10:51:13	2020-08-10	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11907	delivery	5	43
114697	2020-08-10 10:54:42	2020-08-10	8	[{"id_menu":5,"count":1}]	647	delivery	5	13
114698	2020-08-10 10:55:59	2020-08-10	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43752	delivery	5	43
114699	2020-08-10 10:57:13	2020-08-10	8	[{"id_menu":5,"count":1}]	35838	delivery	5	13
114700	2020-08-10 11:04:12	2020-08-10	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	41209	delivery	5	22
114701	2020-08-10 11:05:15	2020-08-10	12	[{"id_menu":1,"count":1}]	43749	delivery	5	17
114702	2020-08-10 11:09:24	2020-08-10	9	[{"id_menu":6,"count":1}]	27320	delivery	5	14
114703	2020-08-10 11:10:07	2020-08-10	12	[{"id_menu":3,"count":1}]	43847	delivery	5	17
114704	2020-08-10 11:10:50	2020-08-10	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	43923	delivery	5	34
114705	2020-08-10 11:14:35	2020-08-10	8	[{"id_menu":5,"count":1}]	43821	delivery	5	13
114706	2020-08-10 11:21:49	2020-08-10	9	[{"id_menu":6,"count":1}]	7361	pick-up	0	9
114707	2020-08-10 11:23:58	2020-08-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	43747	delivery	5	28
114708	2020-08-10 11:24:41	2020-08-10	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	43881	pick-up	0	26
114709	2020-08-10 11:25:11	2020-08-10	8	[{"id_menu":5,"count":1}]	43016	delivery	5	13
114710	2020-08-10 11:27:33	2020-08-10	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	997	pick-up	0	17
114711	2020-08-10 11:34:13	2020-08-10	9	[{"id_menu":6,"count":1}]	43834	pick-up	0	9
114712	2020-08-10 11:35:15	2020-08-10	9	[{"id_menu":6,"count":1}]	21580	delivery	5	14
114713	2020-08-10 11:35:23	2020-08-10	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	3634	pick-up	0	20
114714	2020-08-10 11:37:33	2020-08-10	14	[{"id_menu":2,"count":1}]	1485	pick-up	0	14
114715	2020-08-10 11:44:09	2020-08-10	9	[{"id_menu":7,"count":1}]	12502	delivery	5	14
114716	2020-08-10 11:45:16	2020-08-10	14	[{"id_menu":2,"count":1}]	43918	delivery	5	19
114717	2020-08-10 11:45:48	2020-08-10	8	[{"id_menu":5,"count":1}]	8262	delivery	5	13
114718	2020-08-10 11:51:45	2020-08-10	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	41240	delivery	5	25
114719	2020-08-10 11:53:45	2020-08-10	9	[{"id_menu":7,"count":1}]	30526	delivery	5	14
114720	2020-08-10 12:09:54	2020-08-10	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	9348	pick-up	0	29
114721	2020-08-10 12:16:43	2020-08-10	12	[{"id_menu":1,"count":1}]	28384	delivery	5	17
114722	2020-08-10 12:18:48	2020-08-10	14	[{"id_menu":2,"count":1}]	43895	delivery	5	19
114723	2020-08-10 12:19:23	2020-08-10	12	[{"id_menu":1,"count":1}]	43869	delivery	5	17
114724	2020-08-10 12:19:27	2020-08-10	9	[{"id_menu":6,"count":1}]	16904	delivery	5	14
114725	2020-08-10 12:20:23	2020-08-10	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8303	pick-up	0	26
114726	2020-08-10 12:20:33	2020-08-10	9	[{"id_menu":6,"count":1}]	30400	delivery	5	14
114727	2020-08-10 12:21:53	2020-08-10	9	[{"id_menu":6,"count":1}]	14873	delivery	5	14
114728	2020-08-10 12:30:13	2020-08-10	9	[{"id_menu":7,"count":1}]	18380	delivery	5	14
114729	2020-08-10 12:30:22	2020-08-10	14	[{"id_menu":2,"count":2}]	9394	pick-up	0	14
114730	2020-08-10 12:32:03	2020-08-10	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	33251	delivery	5	36
114731	2020-08-10 12:34:43	2020-08-10	12	[{"id_menu":3,"count":1}]	30620	pick-up	0	12
114732	2020-08-10 12:35:08	2020-08-10	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	43724	delivery	5	48
114733	2020-08-10 12:35:59	2020-08-10	17	[{"id_menu":4,"count":1}]	6182	pick-up	0	17
114734	2020-08-10 12:37:13	2020-08-10	9	[{"id_menu":6,"count":1}]	26580	pick-up	0	9
114735	2020-08-10 12:37:44	2020-08-10	9	[{"id_menu":6,"count":1}]	37462	delivery	5	14
114736	2020-08-10 12:41:26	2020-08-10	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	43738	pick-up	0	21
114737	2020-08-10 12:42:29	2020-08-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	43805	delivery	5	28
114738	2020-08-10 12:42:55	2020-08-10	9	[{"id_menu":6,"count":1}]	42194	pick-up	0	9
114739	2020-08-10 12:44:08	2020-08-10	9	[{"id_menu":7,"count":1}]	33095	pick-up	0	9
114740	2020-08-10 12:46:06	2020-08-10	14	[{"id_menu":2,"count":1}]	17372	pick-up	0	14
114741	2020-08-10 12:55:32	2020-08-10	14	[{"id_menu":2,"count":1}]	43781	delivery	5	19
114742	2020-08-10 12:56:52	2020-08-10	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10221	delivery	5	31
114743	2020-08-10 12:57:04	2020-08-10	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4867	pick-up	0	25
114744	2020-08-10 13:01:17	2020-08-10	12	[{"id_menu":1,"count":1}]	1076	pick-up	0	12
114745	2020-08-10 13:05:43	2020-08-10	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	43734	delivery	5	29
114746	2020-08-10 13:10:11	2020-08-10	9	[{"id_menu":6,"count":1}]	43731	delivery	5	14
114747	2020-08-10 13:11:58	2020-08-10	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	27076	delivery	5	39
114748	2020-08-10 13:12:22	2020-08-10	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	43924	delivery	5	43
114749	2020-08-10 13:13:03	2020-08-10	17	[{"id_menu":4,"count":1}]	2894	pick-up	0	17
114750	2020-08-10 13:15:44	2020-08-10	9	[{"id_menu":6,"count":1}]	43754	delivery	5	14
114751	2020-08-10 13:16:55	2020-08-10	14	[{"id_menu":2,"count":1}]	8668	pick-up	0	14
114752	2020-08-10 13:19:26	2020-08-10	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	43915	delivery	5	36
114753	2020-08-10 13:24:27	2020-08-10	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	12040	delivery	5	48
114754	2020-08-10 13:25:27	2020-08-10	9	[{"id_menu":6,"count":1}]	3316	delivery	5	14
114755	2020-08-10 13:29:50	2020-08-10	9	[{"id_menu":7,"count":1}]	14149	delivery	5	14
114756	2020-08-10 13:35:09	2020-08-10	17	[{"id_menu":4,"count":1}]	43942	pick-up	0	17
114757	2020-08-10 13:39:48	2020-08-10	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24703	delivery	5	39
114758	2020-08-10 13:41:49	2020-08-10	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6773	delivery	5	34
114759	2020-08-10 13:44:54	2020-08-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8300	pick-up	0	23
114760	2020-08-10 13:49:22	2020-08-10	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	38839	delivery	5	34
114761	2020-08-10 13:51:10	2020-08-10	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12506	delivery	5	31
114762	2020-08-10 13:57:02	2020-08-10	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	43939	delivery	5	39
114763	2020-08-10 13:59:31	2020-08-10	8	[{"id_menu":5,"count":1}]	43717	delivery	5	13
114764	2020-08-10 14:01:08	2020-08-10	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	41555	delivery	5	36
114765	2020-08-10 14:17:38	2020-08-10	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	6769	pick-up	0	21
114766	2020-08-10 14:19:28	2020-08-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26336	pick-up	0	18
114767	2020-08-10 14:19:46	2020-08-10	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	21606	delivery	5	37
114768	2020-08-10 14:21:12	2020-08-10	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	43720	pick-up	0	26
114769	2020-08-10 14:24:07	2020-08-10	12	[{"id_menu":3,"count":1}]	43845	delivery	5	17
114770	2020-08-10 14:29:38	2020-08-10	9	[{"id_menu":7,"count":1}]	38119	delivery	5	14
114771	2020-08-10 14:34:41	2020-08-10	9	[{"id_menu":6,"count":1}]	3010	pick-up	0	9
114772	2020-08-10 14:38:08	2020-08-10	9	[{"id_menu":7,"count":1}]	35643	delivery	5	14
114773	2020-08-10 14:41:11	2020-08-10	9	[{"id_menu":7,"count":1}]	43707	delivery	5	14
114774	2020-08-10 14:41:12	2020-08-10	14	[{"id_menu":2,"count":1}]	38657	pick-up	0	14
114775	2020-08-10 14:42:41	2020-08-10	14	[{"id_menu":2,"count":1}]	38387	delivery	5	19
114776	2020-08-10 14:43:23	2020-08-10	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	6589	pick-up	0	21
114777	2020-08-10 14:47:33	2020-08-10	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	26288	delivery	5	45
114778	2020-08-10 14:55:09	2020-08-10	12	[{"id_menu":1,"count":1}]	43900	delivery	5	17
114779	2020-08-10 14:57:27	2020-08-10	9	[{"id_menu":6,"count":1}]	14038	pick-up	0	9
114780	2020-08-10 15:06:29	2020-08-10	17	[{"id_menu":4,"count":1}]	26552	delivery	5	22
114781	2020-08-10 15:07:36	2020-08-10	9	[{"id_menu":6,"count":1}]	996	delivery	5	14
114782	2020-08-10 15:08:02	2020-08-10	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	33937	delivery	5	34
114783	2020-08-10 15:08:24	2020-08-10	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	43885	delivery	5	27
114784	2020-08-10 15:10:59	2020-08-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	43948	delivery	5	28
114785	2020-08-10 15:11:08	2020-08-10	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	34221	delivery	5	23
114786	2020-08-10 15:21:19	2020-08-10	9	[{"id_menu":6,"count":1}]	43408	delivery	5	14
114787	2020-08-10 15:23:03	2020-08-10	9	[{"id_menu":6,"count":1}]	43778	delivery	5	14
114788	2020-08-10 15:33:31	2020-08-10	8	[{"id_menu":5,"count":1}]	19832	delivery	5	13
114789	2020-08-10 15:33:52	2020-08-10	14	[{"id_menu":2,"count":1}]	43870	delivery	5	19
114790	2020-08-10 15:40:32	2020-08-10	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	26466	delivery	5	45
114791	2020-08-10 15:42:24	2020-08-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	28315	delivery	5	23
114792	2020-08-10 15:43:23	2020-08-10	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	8375	pick-up	0	29
114793	2020-08-10 15:45:08	2020-08-10	9	[{"id_menu":7,"count":1}]	13493	delivery	5	14
114794	2020-08-10 15:45:47	2020-08-10	17	[{"id_menu":4,"count":1}]	43807	pick-up	0	17
114795	2020-08-10 15:47:43	2020-08-10	9	[{"id_menu":6,"count":1}]	73	pick-up	0	9
114796	2020-08-10 15:48:00	2020-08-10	17	[{"id_menu":4,"count":1}]	43934	delivery	5	22
114797	2020-08-10 15:52:02	2020-08-10	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	8600	delivery	5	39
114798	2020-08-10 15:56:07	2020-08-10	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	7709	delivery	5	26
114799	2020-08-10 15:58:09	2020-08-10	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	34482	delivery	5	25
114800	2020-08-10 15:58:38	2020-08-10	9	[{"id_menu":7,"count":3}]	22065	delivery	5	14
114801	2020-08-10 16:03:43	2020-08-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	43932	delivery	5	28
114802	2020-08-10 16:04:00	2020-08-10	8	[{"id_menu":5,"count":1}]	28151	pick-up	0	8
114803	2020-08-10 16:04:20	2020-08-10	14	[{"id_menu":2,"count":1}]	504	pick-up	0	14
114804	2020-08-10 16:04:56	2020-08-10	17	[{"id_menu":4,"count":1}]	42321	delivery	5	22
114805	2020-08-10 16:07:34	2020-08-10	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	16813	pick-up	0	21
114806	2020-08-10 16:12:48	2020-08-10	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	36794	pick-up	0	20
114807	2020-08-10 16:16:55	2020-08-10	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	43859	delivery	5	26
114808	2020-08-10 16:20:31	2020-08-10	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	33435	delivery	5	45
114809	2020-08-10 16:27:36	2020-08-10	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	42772	pick-up	0	18
114810	2020-08-10 16:38:23	2020-08-10	8	[{"id_menu":5,"count":1}]	13717	delivery	5	13
114811	2020-08-10 16:38:45	2020-08-10	9	[{"id_menu":6,"count":1}]	34958	delivery	5	14
114812	2020-08-10 16:40:52	2020-08-10	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	43882	delivery	5	44
114813	2020-08-10 16:45:29	2020-08-10	9	[{"id_menu":6,"count":1}]	39799	delivery	5	14
114814	2020-08-10 16:48:19	2020-08-10	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	25544	pick-up	0	20
114815	2020-08-10 16:52:22	2020-08-10	12	[{"id_menu":1,"count":1}]	40613	delivery	5	17
114816	2020-08-10 16:53:31	2020-08-10	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	20333	delivery	5	39
114817	2020-08-10 16:55:15	2020-08-10	12	[{"id_menu":3,"count":1}]	2551	delivery	5	17
114818	2020-08-10 16:58:54	2020-08-10	9	[{"id_menu":7,"count":1}]	43861	delivery	5	14
114819	2020-08-10 17:02:41	2020-08-10	9	[{"id_menu":7,"count":1}]	16100	delivery	5	14
114820	2020-08-10 17:06:08	2020-08-10	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	43826	delivery	5	25
114821	2020-08-10 17:09:14	2020-08-10	8	[{"id_menu":5,"count":1}]	38895	delivery	5	13
114822	2020-08-10 17:13:45	2020-08-10	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43856	pick-up	0	44
114823	2020-08-10 17:17:27	2020-08-10	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	41069	delivery	5	26
114824	2020-08-10 17:22:01	2020-08-10	9	[{"id_menu":6,"count":1}]	43957	delivery	5	14
114825	2020-08-10 17:27:02	2020-08-10	14	[{"id_menu":2,"count":1}]	37142	pick-up	0	14
114826	2020-08-10 17:29:43	2020-08-10	8	[{"id_menu":5,"count":1}]	16434	delivery	5	13
114827	2020-08-10 17:39:11	2020-08-10	9	[{"id_menu":7,"count":1}]	31906	delivery	5	14
114828	2020-08-10 17:42:12	2020-08-10	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	27256	delivery	5	35
114829	2020-08-10 17:48:59	2020-08-10	8	[{"id_menu":5,"count":1}]	42143	delivery	5	13
114830	2020-08-10 17:50:53	2020-08-10	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	10880	delivery	5	26
114831	2020-08-10 17:52:02	2020-08-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	36088	delivery	5	28
114832	2020-08-10 17:54:35	2020-08-10	12	[{"id_menu":3,"count":1}]	40333	delivery	5	17
114833	2020-08-10 17:57:41	2020-08-10	17	[{"id_menu":4,"count":1}]	42694	pick-up	0	17
114834	2020-08-10 18:08:37	2020-08-10	17	[{"id_menu":4,"count":2}]	41851	delivery	5	22
114835	2020-08-10 18:09:17	2020-08-10	9	[{"id_menu":6,"count":1}]	41425	delivery	5	14
114836	2020-08-10 18:16:50	2020-08-10	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29831	delivery	5	37
114837	2020-08-10 18:16:58	2020-08-10	9	[{"id_menu":6,"count":1}]	43704	delivery	5	14
114838	2020-08-10 18:16:59	2020-08-10	9	[{"id_menu":6,"count":1}]	43898	delivery	5	14
114839	2020-08-10 18:29:08	2020-08-10	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	22242	pick-up	0	20
114840	2020-08-10 18:30:47	2020-08-10	17	[{"id_menu":4,"count":1}]	43813	delivery	5	22
114841	2020-08-10 18:38:43	2020-08-10	9	[{"id_menu":7,"count":1}]	43776	delivery	5	14
114842	2020-08-10 18:42:03	2020-08-10	8	[{"id_menu":5,"count":1}]	42549	delivery	5	13
114843	2020-08-10 18:44:49	2020-08-10	12	[{"id_menu":1,"count":1}]	43892	pick-up	0	12
114844	2020-08-10 18:44:57	2020-08-10	9	[{"id_menu":7,"count":1}]	40790	pick-up	0	9
114845	2020-08-10 18:45:10	2020-08-10	9	[{"id_menu":7,"count":1}]	11264	delivery	5	14
114846	2020-08-10 18:47:37	2020-08-10	12	[{"id_menu":1,"count":1}]	22064	delivery	5	17
114847	2020-08-10 18:50:24	2020-08-10	8	[{"id_menu":5,"count":1}]	43865	delivery	5	13
114848	2020-08-10 18:53:44	2020-08-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3823	delivery	5	28
114849	2020-08-10 18:57:29	2020-08-10	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2018	pick-up	0	38
114850	2020-08-10 19:01:47	2020-08-10	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	25904	delivery	5	31
114851	2020-08-10 19:02:07	2020-08-10	12	[{"id_menu":1,"count":1}]	17415	pick-up	0	12
114852	2020-08-10 19:07:38	2020-08-10	9	[{"id_menu":7,"count":1}]	43887	delivery	5	14
114853	2020-08-10 19:14:30	2020-08-10	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	15270	delivery	5	45
114854	2020-08-10 19:18:11	2020-08-10	9	[{"id_menu":7,"count":1}]	43705	delivery	5	14
114855	2020-08-10 19:28:49	2020-08-10	9	[{"id_menu":7,"count":1}]	12242	delivery	5	14
114856	2020-08-10 19:30:03	2020-08-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7992	delivery	5	22
114857	2020-08-10 19:33:38	2020-08-10	9	[{"id_menu":6,"count":1}]	26827	delivery	5	14
114858	2020-08-10 19:34:50	2020-08-10	8	[{"id_menu":5,"count":1}]	8098	pick-up	0	8
114859	2020-08-10 19:40:18	2020-08-10	17	[{"id_menu":4,"count":1}]	43919	pick-up	0	17
114860	2020-08-10 19:44:26	2020-08-10	12	[{"id_menu":1,"count":1}]	6218	delivery	5	17
114861	2020-08-10 19:53:02	2020-08-10	12	[{"id_menu":1,"count":1}]	11444	delivery	5	17
114862	2020-08-10 19:59:28	2020-08-10	9	[{"id_menu":6,"count":1}]	43908	delivery	5	14
114863	2020-08-10 20:05:45	2020-08-10	12	[{"id_menu":3,"count":1}]	24366	delivery	5	17
114864	2020-08-10 20:10:09	2020-08-10	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	43835	delivery	5	26
114865	2020-08-10 20:10:57	2020-08-10	9	[{"id_menu":7,"count":2}]	42791	delivery	5	14
114866	2020-08-10 20:15:00	2020-08-10	12	[{"id_menu":3,"count":1}]	43854	delivery	5	17
114867	2020-08-10 20:17:00	2020-08-10	12	[{"id_menu":1,"count":1}]	330	pick-up	0	12
114868	2020-08-10 20:24:49	2020-08-10	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	43888	delivery	5	38
114869	2020-08-10 20:31:49	2020-08-10	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	41507	pick-up	0	25
114870	2020-08-10 20:38:39	2020-08-10	14	[{"id_menu":2,"count":1}]	43799	delivery	5	19
114871	2020-08-10 20:39:43	2020-08-10	14	[{"id_menu":2,"count":1}]	8115	delivery	5	19
114872	2020-08-10 20:43:59	2020-08-10	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	43884	delivery	5	48
114873	2020-08-10 20:44:43	2020-08-10	14	[{"id_menu":2,"count":1}]	7358	delivery	5	19
114874	2020-08-10 20:45:03	2020-08-10	9	[{"id_menu":6,"count":1}]	1179	delivery	5	14
114875	2020-08-10 20:48:20	2020-08-10	14	[{"id_menu":2,"count":1}]	43708	pick-up	0	14
114876	2020-08-10 20:54:45	2020-08-10	9	[{"id_menu":6,"count":1}]	19169	delivery	5	14
114877	2020-08-10 20:56:58	2020-08-10	9	[{"id_menu":6,"count":1}]	43722	delivery	5	14
114878	2020-08-10 20:57:44	2020-08-10	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	40769	delivery	5	42
114879	2020-08-10 20:58:18	2020-08-10	17	[{"id_menu":4,"count":1}]	43808	delivery	5	22
114880	2020-08-10 20:59:43	2020-08-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32208	delivery	5	22
114881	2020-08-10 20:59:56	2020-08-10	14	[{"id_menu":2,"count":1}]	840	pick-up	0	14
114882	2020-08-10 21:03:33	2020-08-10	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19011	pick-up	0	32
114883	2020-08-10 21:07:09	2020-08-10	9	[{"id_menu":6,"count":1}]	11829	delivery	5	14
114884	2020-08-10 21:08:20	2020-08-10	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	18842	delivery	5	26
114885	2020-08-10 21:09:14	2020-08-10	9	[{"id_menu":6,"count":2}]	35031	delivery	5	14
114886	2020-08-10 21:12:42	2020-08-10	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	43917	delivery	5	40
114887	2020-08-10 21:15:36	2020-08-10	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	43906	delivery	5	39
114888	2020-08-10 21:16:08	2020-08-10	9	[{"id_menu":7,"count":1}]	40027	delivery	5	14
114889	2020-08-10 21:16:17	2020-08-10	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3253	delivery	5	30
114890	2020-08-10 21:22:39	2020-08-10	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	23334	delivery	5	26
114891	2020-08-10 21:24:11	2020-08-10	14	[{"id_menu":2,"count":1}]	13549	delivery	5	19
114892	2020-08-10 21:25:21	2020-08-10	9	[{"id_menu":6,"count":1}]	9640	pick-up	0	9
114893	2020-08-10 21:25:55	2020-08-10	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	25430	delivery	5	27
114894	2020-08-10 21:27:59	2020-08-10	14	[{"id_menu":2,"count":1}]	43795	delivery	5	19
114895	2020-08-10 21:29:14	2020-08-10	30	[{"id_menu":1,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43757	delivery	5	35
114896	2020-08-10 21:31:20	2020-08-10	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	11863	delivery	5	36
114897	2020-08-10 21:37:20	2020-08-10	14	[{"id_menu":2,"count":1}]	1731	pick-up	0	14
114898	2020-08-10 21:40:18	2020-08-10	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2004	pick-up	0	23
114899	2020-08-10 21:43:08	2020-08-10	12	[{"id_menu":1,"count":1}]	43767	pick-up	0	12
114900	2020-08-10 21:45:20	2020-08-10	14	[{"id_menu":2,"count":1}]	43741	delivery	5	19
114901	2020-08-10 21:45:52	2020-08-10	12	[{"id_menu":3,"count":1}]	19163	delivery	5	17
114902	2020-08-10 21:49:02	2020-08-10	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	43842	delivery	5	28
114903	2020-08-10 21:53:02	2020-08-10	17	[{"id_menu":4,"count":1}]	43935	delivery	5	22
114904	2020-08-10 21:59:34	2020-08-10	34	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	6080	delivery	5	39
114905	2020-08-10 22:05:45	2020-08-10	17	[{"id_menu":4,"count":1}]	37986	delivery	5	22
114906	2020-08-10 22:06:00	2020-08-10	12	[{"id_menu":3,"count":1}]	43785	delivery	5	17
114907	2020-08-10 22:06:38	2020-08-10	17	[{"id_menu":4,"count":3}]	277	delivery	5	22
114908	2020-08-10 22:07:59	2020-08-10	9	[{"id_menu":7,"count":1}]	42341	pick-up	0	9
114909	2020-08-10 22:08:55	2020-08-10	8	[{"id_menu":5,"count":1}]	43878	delivery	5	13
114910	2020-08-10 22:14:53	2020-08-10	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21664	delivery	5	36
114911	2020-08-10 22:16:18	2020-08-10	14	[{"id_menu":2,"count":1}]	29589	pick-up	0	14
114912	2020-08-10 22:16:19	2020-08-10	8	[{"id_menu":5,"count":1}]	8722	delivery	5	13
114913	2020-08-10 22:19:52	2020-08-10	8	[{"id_menu":5,"count":1}]	43753	delivery	5	13
114914	2020-08-10 22:25:04	2020-08-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	43928	delivery	5	22
114915	2020-08-10 22:25:18	2020-08-10	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	18715	delivery	5	48
114916	2020-08-10 22:26:33	2020-08-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39163	delivery	5	22
114917	2020-08-10 22:29:11	2020-08-10	14	[{"id_menu":2,"count":1}]	43832	delivery	5	19
114918	2020-08-10 22:31:14	2020-08-10	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2470	delivery	5	34
114919	2020-08-10 22:34:45	2020-08-10	9	[{"id_menu":7,"count":1}]	43893	delivery	5	14
114920	2020-08-10 22:35:05	2020-08-10	17	[{"id_menu":4,"count":1}]	40184	delivery	5	22
114921	2020-08-10 22:39:19	2020-08-10	9	[{"id_menu":7,"count":1}]	696	pick-up	0	9
114922	2020-08-10 22:41:09	2020-08-10	17	[{"id_menu":4,"count":1}]	18069	delivery	5	22
114923	2020-08-10 22:44:20	2020-08-10	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3393	delivery	5	36
114924	2020-08-10 22:44:32	2020-08-10	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	43857	delivery	5	29
114925	2020-08-10 22:49:41	2020-08-10	9	[{"id_menu":7,"count":2}]	43797	delivery	5	14
114926	2020-08-10 22:49:47	2020-08-10	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	43714	delivery	5	43
114927	2020-08-10 22:49:55	2020-08-10	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27362	delivery	5	39
114928	2020-08-10 22:54:45	2020-08-10	12	[{"id_menu":1,"count":1}]	43909	pick-up	0	12
114929	2020-08-10 22:57:15	2020-08-10	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	43868	pick-up	0	26
114930	2020-08-10 22:57:55	2020-08-10	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	33438	delivery	5	26
114931	2020-08-10 22:58:16	2020-08-10	12	[{"id_menu":1,"count":1}]	9941	pick-up	0	12
114932	2020-08-10 22:59:05	2020-08-10	9	[{"id_menu":6,"count":1}]	43712	delivery	5	14
114933	2020-08-10 22:59:13	2020-08-10	12	[{"id_menu":1,"count":1}]	5861	delivery	5	17
114934	2020-08-10 22:59:38	2020-08-10	9	[{"id_menu":6,"count":1}]	38554	pick-up	0	9
114935	2020-08-10 23:00:03	2020-08-10	9	[{"id_menu":7,"count":1}]	4010	delivery	5	14
114936	2020-08-10 23:07:04	2020-08-10	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21574	delivery	5	54
114937	2020-08-10 23:07:17	2020-08-10	14	[{"id_menu":2,"count":1}]	1832	pick-up	0	14
114938	2020-08-10 23:09:43	2020-08-10	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	31129	delivery	5	27
114939	2020-08-10 23:15:12	2020-08-10	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	969	delivery	5	26
114940	2020-08-10 23:21:34	2020-08-10	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":2}]	33607	delivery	5	28
114941	2020-08-10 23:23:00	2020-08-10	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":3}]	28630	delivery	5	31
114942	2020-08-10 23:24:49	2020-08-10	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	18390	delivery	5	37
114943	2020-08-10 23:25:57	2020-08-10	9	[{"id_menu":6,"count":2}]	30458	delivery	5	14
114944	2020-08-10 23:27:36	2020-08-10	17	[{"id_menu":4,"count":1}]	39077	delivery	5	22
114945	2020-08-10 23:32:07	2020-08-10	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	12516	delivery	5	42
114946	2020-08-10 23:33:31	2020-08-10	9	[{"id_menu":7,"count":1}]	43846	delivery	5	14
114947	2020-08-10 23:34:08	2020-08-10	14	[{"id_menu":2,"count":1}]	43784	delivery	5	19
114948	2020-08-10 23:35:07	2020-08-10	8	[{"id_menu":5,"count":3}]	43838	delivery	5	13
114949	2020-08-10 23:41:00	2020-08-10	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	35654	delivery	5	22
114950	2020-08-10 23:41:00	2020-08-10	8	[{"id_menu":5,"count":1}]	43764	delivery	5	13
114951	2020-08-10 23:45:09	2020-08-10	8	[{"id_menu":5,"count":2}]	43904	delivery	5	13
114952	2020-08-10 23:45:35	2020-08-10	9	[{"id_menu":6,"count":1}]	43772	delivery	5	14
114953	2020-08-10 23:46:10	2020-08-10	9	[{"id_menu":6,"count":1}]	7724	pick-up	0	9
114954	2020-08-10 23:47:20	2020-08-10	12	[{"id_menu":1,"count":1}]	3382	delivery	5	17
114955	2020-08-10 23:49:52	2020-08-10	14	[{"id_menu":2,"count":1}]	42062	delivery	5	19
114956	2020-08-11 00:02:42	2020-08-11	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	28293	pick-up	0	21
114957	2020-08-11 00:07:24	2020-08-11	14	[{"id_menu":2,"count":1}]	42617	delivery	5	19
114958	2020-08-11 00:13:48	2020-08-11	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	43971	delivery	5	38
114959	2020-08-11 00:14:30	2020-08-11	8	[{"id_menu":5,"count":1}]	44074	delivery	5	13
114960	2020-08-11 00:15:52	2020-08-11	12	[{"id_menu":1,"count":1}]	2848	delivery	5	17
114961	2020-08-11 00:17:11	2020-08-11	14	[{"id_menu":2,"count":1}]	10222	delivery	5	19
114962	2020-08-11 00:22:32	2020-08-11	9	[{"id_menu":7,"count":1}]	44075	delivery	5	14
114963	2020-08-11 00:32:32	2020-08-11	9	[{"id_menu":6,"count":1}]	25469	pick-up	0	9
114964	2020-08-11 00:33:47	2020-08-11	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	42436	delivery	5	31
114965	2020-08-11 00:36:02	2020-08-11	9	[{"id_menu":6,"count":1}]	44058	delivery	5	14
114966	2020-08-11 00:40:11	2020-08-11	9	[{"id_menu":7,"count":1}]	44050	delivery	5	14
114967	2020-08-11 00:43:21	2020-08-11	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	14677	delivery	5	26
114968	2020-08-11 00:44:41	2020-08-11	17	[{"id_menu":4,"count":1}]	13256	pick-up	0	17
114969	2020-08-11 00:52:11	2020-08-11	17	[{"id_menu":4,"count":1}]	35726	delivery	5	22
114970	2020-08-11 00:53:03	2020-08-11	12	[{"id_menu":3,"count":1}]	44127	pick-up	0	12
114971	2020-08-11 00:54:34	2020-08-11	8	[{"id_menu":5,"count":1}]	36017	delivery	5	13
114972	2020-08-11 00:57:48	2020-08-11	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	43976	delivery	5	34
114973	2020-08-11 00:58:50	2020-08-11	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	15623	delivery	5	27
114974	2020-08-11 00:59:23	2020-08-11	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4192	delivery	5	27
114975	2020-08-11 00:59:43	2020-08-11	8	[{"id_menu":5,"count":1}]	10444	delivery	5	13
114976	2020-08-11 00:59:44	2020-08-11	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10802	delivery	5	34
114977	2020-08-11 01:05:29	2020-08-11	14	[{"id_menu":2,"count":1}]	44158	pick-up	0	14
114978	2020-08-11 01:05:48	2020-08-11	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	44104	pick-up	0	29
114979	2020-08-11 01:10:51	2020-08-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	32207	delivery	5	28
114980	2020-08-11 01:20:48	2020-08-11	17	[{"id_menu":4,"count":1}]	44003	delivery	5	22
114981	2020-08-11 01:21:55	2020-08-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22126	delivery	5	23
114982	2020-08-11 01:23:11	2020-08-11	8	[{"id_menu":5,"count":1}]	44079	delivery	5	13
114983	2020-08-11 01:31:07	2020-08-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	44136	delivery	5	22
114984	2020-08-11 01:32:32	2020-08-11	17	[{"id_menu":4,"count":1}]	1157	pick-up	0	17
114985	2020-08-11 01:33:58	2020-08-11	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27405	delivery	5	35
114986	2020-08-11 01:34:50	2020-08-11	17	[{"id_menu":4,"count":1}]	20222	delivery	5	22
114987	2020-08-11 01:44:56	2020-08-11	8	[{"id_menu":5,"count":3}]	44035	delivery	5	13
114988	2020-08-11 01:49:00	2020-08-11	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	44038	delivery	5	26
114989	2020-08-11 01:50:53	2020-08-11	14	[{"id_menu":2,"count":1}]	11892	pick-up	0	14
114990	2020-08-11 01:52:45	2020-08-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28039	delivery	5	23
114991	2020-08-11 01:58:06	2020-08-11	9	[{"id_menu":7,"count":1}]	18652	pick-up	0	9
114992	2020-08-11 01:58:07	2020-08-11	9	[{"id_menu":7,"count":1}]	35485	delivery	5	14
114993	2020-08-11 02:01:00	2020-08-11	9	[{"id_menu":7,"count":1}]	12050	delivery	5	14
114994	2020-08-11 02:02:32	2020-08-11	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	43237	delivery	5	38
114995	2020-08-11 02:02:46	2020-08-11	9	[{"id_menu":7,"count":1}]	31781	delivery	5	14
114996	2020-08-11 02:03:24	2020-08-11	9	[{"id_menu":6,"count":1}]	23754	delivery	5	14
114997	2020-08-11 02:03:43	2020-08-11	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44164	delivery	5	31
114998	2020-08-11 02:04:04	2020-08-11	9	[{"id_menu":7,"count":1}]	34019	delivery	5	14
114999	2020-08-11 02:08:37	2020-08-11	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	8735	delivery	5	26
115000	2020-08-11 02:12:27	2020-08-11	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	4426	delivery	5	36
115001	2020-08-11 02:14:32	2020-08-11	12	[{"id_menu":3,"count":1}]	38029	delivery	5	17
115002	2020-08-11 02:17:53	2020-08-11	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	33230	delivery	5	39
115003	2020-08-11 02:21:43	2020-08-11	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	11543	delivery	5	40
115004	2020-08-11 02:23:26	2020-08-11	17	[{"id_menu":4,"count":1}]	25244	delivery	5	22
115005	2020-08-11 02:27:06	2020-08-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5461	pick-up	0	23
115006	2020-08-11 02:31:12	2020-08-11	9	[{"id_menu":6,"count":1}]	24108	pick-up	0	9
115007	2020-08-11 02:32:25	2020-08-11	9	[{"id_menu":6,"count":1}]	33837	delivery	5	14
115008	2020-08-11 02:34:27	2020-08-11	17	[{"id_menu":4,"count":1}]	29379	delivery	5	22
115009	2020-08-11 02:35:42	2020-08-11	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	11073	delivery	5	25
115010	2020-08-11 02:40:24	2020-08-11	14	[{"id_menu":2,"count":1}]	32415	delivery	5	19
115011	2020-08-11 02:43:11	2020-08-11	9	[{"id_menu":7,"count":1}]	44086	delivery	5	14
115012	2020-08-11 02:43:52	2020-08-11	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	44133	delivery	5	45
115013	2020-08-11 02:44:02	2020-08-11	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	44098	delivery	5	26
115014	2020-08-11 02:46:06	2020-08-11	8	[{"id_menu":5,"count":1}]	35152	delivery	5	13
115015	2020-08-11 02:52:02	2020-08-11	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	44053	delivery	5	26
115016	2020-08-11 02:55:17	2020-08-11	14	[{"id_menu":2,"count":1}]	43579	delivery	5	19
115017	2020-08-11 02:56:36	2020-08-11	17	[{"id_menu":4,"count":1}]	32891	delivery	5	22
115018	2020-08-11 03:01:20	2020-08-11	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	32003	delivery	5	56
115019	2020-08-11 03:03:18	2020-08-11	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	44117	pick-up	0	26
115020	2020-08-11 03:04:35	2020-08-11	9	[{"id_menu":7,"count":1}]	44040	delivery	5	14
115021	2020-08-11 03:07:04	2020-08-11	8	[{"id_menu":5,"count":1}]	2401	pick-up	0	8
115022	2020-08-11 03:08:48	2020-08-11	9	[{"id_menu":6,"count":1}]	21353	delivery	5	14
115023	2020-08-11 03:09:08	2020-08-11	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	42799	delivery	5	29
115024	2020-08-11 03:09:14	2020-08-11	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	39465	pick-up	0	34
115025	2020-08-11 03:13:16	2020-08-11	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	44139	delivery	5	26
115026	2020-08-11 03:18:52	2020-08-11	14	[{"id_menu":2,"count":1}]	19695	pick-up	0	14
115027	2020-08-11 03:31:13	2020-08-11	9	[{"id_menu":6,"count":1}]	3679	delivery	5	14
115028	2020-08-11 03:36:54	2020-08-11	14	[{"id_menu":2,"count":2}]	5041	delivery	5	19
115029	2020-08-11 03:39:15	2020-08-11	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	6101	pick-up	0	21
115030	2020-08-11 03:41:51	2020-08-11	17	[{"id_menu":4,"count":1}]	38159	delivery	5	22
115031	2020-08-11 03:45:13	2020-08-11	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	14990	delivery	5	26
115032	2020-08-11 03:45:18	2020-08-11	12	[{"id_menu":3,"count":1}]	23531	pick-up	0	12
115033	2020-08-11 03:46:28	2020-08-11	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32839	delivery	5	34
115034	2020-08-11 03:47:28	2020-08-11	14	[{"id_menu":2,"count":1}]	1857	delivery	5	19
115035	2020-08-11 03:51:18	2020-08-11	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	10235	delivery	5	26
115036	2020-08-11 03:52:26	2020-08-11	9	[{"id_menu":7,"count":2}]	13477	delivery	5	14
115037	2020-08-11 03:54:40	2020-08-11	9	[{"id_menu":6,"count":1}]	12306	delivery	5	14
115038	2020-08-11 03:57:36	2020-08-11	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6235	delivery	5	36
115039	2020-08-11 03:57:37	2020-08-11	14	[{"id_menu":2,"count":1}]	5458	pick-up	0	14
115040	2020-08-11 03:59:42	2020-08-11	12	[{"id_menu":3,"count":1}]	36099	delivery	5	17
115041	2020-08-11 04:02:31	2020-08-11	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6066	delivery	5	36
115042	2020-08-11 04:02:40	2020-08-11	9	[{"id_menu":6,"count":1}]	39908	delivery	5	14
115043	2020-08-11 04:04:33	2020-08-11	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	17803	delivery	5	39
115044	2020-08-11 04:04:33	2020-08-11	9	[{"id_menu":7,"count":1}]	40393	pick-up	0	9
115045	2020-08-11 04:06:38	2020-08-11	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	33147	delivery	5	26
115046	2020-08-11 04:07:56	2020-08-11	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	40939	delivery	5	36
115047	2020-08-11 04:08:15	2020-08-11	12	[{"id_menu":3,"count":1}]	33698	delivery	5	17
115048	2020-08-11 04:11:09	2020-08-11	14	[{"id_menu":2,"count":1}]	35740	pick-up	0	14
115049	2020-08-11 04:15:15	2020-08-11	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6848	delivery	5	31
115050	2020-08-11 04:16:53	2020-08-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5297	delivery	5	28
115051	2020-08-11 04:20:32	2020-08-11	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32611	delivery	5	48
115052	2020-08-11 04:26:18	2020-08-11	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22407	delivery	5	39
115053	2020-08-11 04:26:37	2020-08-11	17	[{"id_menu":4,"count":1}]	10177	pick-up	0	17
115054	2020-08-11 04:26:40	2020-08-11	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	40931	delivery	5	43
115055	2020-08-11 04:28:20	2020-08-11	8	[{"id_menu":5,"count":1}]	44089	pick-up	0	8
115056	2020-08-11 04:28:26	2020-08-11	12	[{"id_menu":1,"count":1}]	44188	delivery	5	17
115057	2020-08-11 04:32:22	2020-08-11	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40189	delivery	5	31
115058	2020-08-11 04:36:07	2020-08-11	9	[{"id_menu":7,"count":1}]	34999	pick-up	0	9
115059	2020-08-11 04:36:40	2020-08-11	17	[{"id_menu":4,"count":1}]	13858	pick-up	0	17
115060	2020-08-11 04:37:50	2020-08-11	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21807	delivery	5	31
115061	2020-08-11 04:39:08	2020-08-11	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	9283	delivery	5	22
115062	2020-08-11 04:42:49	2020-08-11	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44160	delivery	5	31
115063	2020-08-11 04:42:52	2020-08-11	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44043	delivery	5	43
115064	2020-08-11 04:45:43	2020-08-11	9	[{"id_menu":6,"count":1}]	43865	delivery	5	14
115065	2020-08-11 04:45:55	2020-08-11	17	[{"id_menu":4,"count":1}]	33079	delivery	5	22
115066	2020-08-11 04:46:24	2020-08-11	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":2}]	7706	delivery	5	26
115067	2020-08-11 04:47:51	2020-08-11	12	[{"id_menu":3,"count":1}]	42862	pick-up	0	12
115068	2020-08-11 04:49:07	2020-08-11	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	27152	delivery	5	43
115069	2020-08-11 04:50:59	2020-08-11	12	[{"id_menu":3,"count":1}]	13881	delivery	5	17
115070	2020-08-11 04:51:32	2020-08-11	12	[{"id_menu":3,"count":1}]	35015	pick-up	0	12
115071	2020-08-11 04:52:39	2020-08-11	9	[{"id_menu":6,"count":1}]	8902	pick-up	0	9
115072	2020-08-11 04:52:44	2020-08-11	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	15016	delivery	5	31
115073	2020-08-11 04:53:35	2020-08-11	9	[{"id_menu":6,"count":1}]	42118	delivery	5	14
115074	2020-08-11 04:55:58	2020-08-11	17	[{"id_menu":4,"count":1}]	44171	delivery	5	22
115075	2020-08-11 05:04:48	2020-08-11	17	[{"id_menu":4,"count":1}]	21510	pick-up	0	17
115076	2020-08-11 05:05:53	2020-08-11	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	44084	delivery	5	39
115077	2020-08-11 05:07:17	2020-08-11	9	[{"id_menu":6,"count":1}]	4058	delivery	5	14
115078	2020-08-11 05:09:19	2020-08-11	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36411	delivery	5	49
115079	2020-08-11 05:09:33	2020-08-11	14	[{"id_menu":2,"count":1}]	35933	delivery	5	19
115080	2020-08-11 05:10:48	2020-08-11	8	[{"id_menu":5,"count":1}]	541	pick-up	0	8
115081	2020-08-11 05:11:16	2020-08-11	12	[{"id_menu":3,"count":1}]	26135	delivery	5	17
115082	2020-08-11 05:14:46	2020-08-11	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27715	delivery	5	53
115083	2020-08-11 05:20:46	2020-08-11	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	35974	delivery	5	36
115084	2020-08-11 05:28:07	2020-08-11	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	44077	delivery	5	39
115085	2020-08-11 05:28:36	2020-08-11	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9777	delivery	5	34
115086	2020-08-11 05:31:16	2020-08-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	43823	delivery	5	28
115087	2020-08-11 05:32:08	2020-08-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25295	pick-up	0	18
115088	2020-08-11 05:34:09	2020-08-11	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11955	delivery	5	36
115089	2020-08-11 05:35:51	2020-08-11	14	[{"id_menu":2,"count":1}]	6823	delivery	5	19
115090	2020-08-11 05:35:58	2020-08-11	8	[{"id_menu":5,"count":1}]	43889	delivery	5	13
115091	2020-08-11 05:38:59	2020-08-11	9	[{"id_menu":7,"count":1}]	44137	delivery	5	14
115092	2020-08-11 05:40:28	2020-08-11	8	[{"id_menu":5,"count":1}]	36539	delivery	5	13
115093	2020-08-11 05:40:29	2020-08-11	17	[{"id_menu":4,"count":1}]	21494	delivery	5	22
115094	2020-08-11 05:41:21	2020-08-11	9	[{"id_menu":7,"count":1}]	6606	delivery	5	14
115095	2020-08-11 05:41:32	2020-08-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	36992	pick-up	0	23
115096	2020-08-11 05:43:19	2020-08-11	9	[{"id_menu":7,"count":1}]	44182	delivery	5	14
115097	2020-08-11 05:45:07	2020-08-11	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	40699	delivery	5	34
115098	2020-08-11 05:47:35	2020-08-11	14	[{"id_menu":2,"count":1}]	38436	delivery	5	19
115099	2020-08-11 05:48:07	2020-08-11	9	[{"id_menu":6,"count":1}]	9766	delivery	5	14
115100	2020-08-11 05:48:20	2020-08-11	9	[{"id_menu":6,"count":1}]	32988	delivery	5	14
115101	2020-08-11 05:53:03	2020-08-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	20017	delivery	5	28
115102	2020-08-11 05:54:39	2020-08-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14858	pick-up	0	17
115103	2020-08-11 05:58:28	2020-08-11	17	[{"id_menu":4,"count":1}]	44024	delivery	5	22
115104	2020-08-11 05:58:42	2020-08-11	9	[{"id_menu":6,"count":1}]	35784	pick-up	0	9
115105	2020-08-11 06:12:32	2020-08-11	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	22965	pick-up	0	40
115106	2020-08-11 06:18:44	2020-08-11	14	[{"id_menu":2,"count":1}]	30473	delivery	5	19
115107	2020-08-11 06:20:38	2020-08-11	8	[{"id_menu":5,"count":1}]	20242	delivery	5	13
115108	2020-08-11 06:20:58	2020-08-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	11486	delivery	5	23
115109	2020-08-11 06:24:16	2020-08-11	14	[{"id_menu":2,"count":2}]	39416	delivery	5	19
115110	2020-08-11 06:30:40	2020-08-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24513	pick-up	0	17
115111	2020-08-11 06:31:28	2020-08-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	27332	pick-up	0	18
115112	2020-08-11 06:31:43	2020-08-11	14	[{"id_menu":2,"count":1}]	36952	delivery	5	19
115113	2020-08-11 06:32:35	2020-08-11	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	43986	delivery	5	46
115114	2020-08-11 06:33:53	2020-08-11	9	[{"id_menu":7,"count":1}]	15732	pick-up	0	9
115115	2020-08-11 06:35:07	2020-08-11	12	[{"id_menu":1,"count":1}]	25978	delivery	5	17
115116	2020-08-11 06:39:54	2020-08-11	9	[{"id_menu":6,"count":2}]	44168	pick-up	0	9
115117	2020-08-11 06:41:13	2020-08-11	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	27212	delivery	5	30
115118	2020-08-11 06:41:39	2020-08-11	8	[{"id_menu":5,"count":1}]	7177	delivery	5	13
115119	2020-08-11 06:42:08	2020-08-11	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	41962	delivery	5	25
115120	2020-08-11 06:42:27	2020-08-11	12	[{"id_menu":1,"count":1}]	44010	delivery	5	17
115121	2020-08-11 06:43:13	2020-08-11	17	[{"id_menu":4,"count":1}]	41300	pick-up	0	17
115122	2020-08-11 06:44:42	2020-08-11	9	[{"id_menu":7,"count":1}]	12551	delivery	5	14
115123	2020-08-11 06:47:26	2020-08-11	9	[{"id_menu":6,"count":2}]	44008	delivery	5	14
115124	2020-08-11 06:48:44	2020-08-11	9	[{"id_menu":6,"count":1}]	29601	delivery	5	14
115125	2020-08-11 06:48:58	2020-08-11	9	[{"id_menu":7,"count":1}]	24937	pick-up	0	9
115126	2020-08-11 06:51:00	2020-08-11	17	[{"id_menu":4,"count":1}]	260	pick-up	0	17
115127	2020-08-11 06:52:32	2020-08-11	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	44090	delivery	5	52
115128	2020-08-11 06:54:04	2020-08-11	9	[{"id_menu":6,"count":1}]	30904	delivery	5	14
115129	2020-08-11 06:55:40	2020-08-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	40131	delivery	5	22
115130	2020-08-11 06:56:58	2020-08-11	8	[{"id_menu":5,"count":1}]	39683	delivery	5	13
115131	2020-08-11 06:58:58	2020-08-11	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	34624	delivery	5	26
115132	2020-08-11 07:00:08	2020-08-11	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29692	delivery	5	31
115133	2020-08-11 07:00:55	2020-08-11	17	[{"id_menu":4,"count":1}]	33110	delivery	5	22
115134	2020-08-11 07:02:21	2020-08-11	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	42481	pick-up	0	43
115135	2020-08-11 07:02:40	2020-08-11	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28320	delivery	5	35
115136	2020-08-11 07:03:40	2020-08-11	9	[{"id_menu":6,"count":2}]	31682	delivery	5	14
115137	2020-08-11 07:04:43	2020-08-11	9	[{"id_menu":6,"count":1}]	22479	delivery	5	14
115138	2020-08-11 07:05:36	2020-08-11	9	[{"id_menu":7,"count":1}]	30162	delivery	5	14
115139	2020-08-11 07:06:19	2020-08-11	8	[{"id_menu":5,"count":1}]	24655	delivery	5	13
115140	2020-08-11 07:07:11	2020-08-11	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20995	delivery	5	34
115141	2020-08-11 07:07:20	2020-08-11	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	32649	delivery	5	28
115142	2020-08-11 07:10:39	2020-08-11	9	[{"id_menu":6,"count":1}]	33562	delivery	5	14
115143	2020-08-11 07:10:56	2020-08-11	12	[{"id_menu":3,"count":1}]	19056	delivery	5	17
115144	2020-08-11 07:12:20	2020-08-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43965	delivery	5	23
115145	2020-08-11 07:19:08	2020-08-11	17	[{"id_menu":4,"count":1}]	2990	pick-up	0	17
115146	2020-08-11 07:27:59	2020-08-11	14	[{"id_menu":2,"count":1}]	44146	delivery	5	19
115147	2020-08-11 07:29:15	2020-08-11	14	[{"id_menu":2,"count":2}]	44055	delivery	5	19
115148	2020-08-11 07:29:57	2020-08-11	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	15155	delivery	5	26
115149	2020-08-11 07:33:43	2020-08-11	17	[{"id_menu":4,"count":1}]	44073	delivery	5	22
115150	2020-08-11 07:33:56	2020-08-11	9	[{"id_menu":7,"count":1}]	11644	pick-up	0	9
115151	2020-08-11 07:35:49	2020-08-11	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":2}]	29568	delivery	5	28
115152	2020-08-11 07:41:23	2020-08-11	9	[{"id_menu":6,"count":1}]	44150	delivery	5	14
115153	2020-08-11 07:42:17	2020-08-11	9	[{"id_menu":7,"count":1}]	24890	delivery	5	14
115154	2020-08-11 07:42:28	2020-08-11	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	15907	pick-up	0	21
115155	2020-08-11 07:44:02	2020-08-11	9	[{"id_menu":7,"count":1}]	38055	delivery	5	14
115156	2020-08-11 07:45:22	2020-08-11	14	[{"id_menu":2,"count":1}]	21184	pick-up	0	14
115157	2020-08-11 07:47:21	2020-08-11	17	[{"id_menu":4,"count":1}]	20605	delivery	5	22
115158	2020-08-11 07:49:14	2020-08-11	14	[{"id_menu":2,"count":1}]	44176	delivery	5	19
115159	2020-08-11 07:49:27	2020-08-11	14	[{"id_menu":2,"count":1}]	8755	pick-up	0	14
115160	2020-08-11 07:52:12	2020-08-11	17	[{"id_menu":4,"count":1}]	13465	delivery	5	22
115161	2020-08-11 07:59:19	2020-08-11	9	[{"id_menu":7,"count":1}]	43990	delivery	5	14
115162	2020-08-11 08:00:02	2020-08-11	9	[{"id_menu":6,"count":1}]	44072	delivery	5	14
115163	2020-08-11 08:00:42	2020-08-11	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15022	delivery	5	43
115164	2020-08-11 08:01:12	2020-08-11	17	[{"id_menu":4,"count":2}]	4585	pick-up	0	17
115165	2020-08-11 08:01:32	2020-08-11	9	[{"id_menu":7,"count":2}]	6173	pick-up	0	9
115166	2020-08-11 08:04:00	2020-08-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	44064	delivery	5	22
115167	2020-08-11 08:05:28	2020-08-11	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	10781	delivery	5	26
115168	2020-08-11 08:08:18	2020-08-11	8	[{"id_menu":5,"count":1}]	39307	pick-up	0	8
115169	2020-08-11 08:09:31	2020-08-11	12	[{"id_menu":1,"count":2}]	43987	delivery	5	17
115170	2020-08-11 08:09:46	2020-08-11	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	44006	delivery	5	27
115171	2020-08-11 08:10:54	2020-08-11	9	[{"id_menu":6,"count":1}]	6579	delivery	5	14
115172	2020-08-11 08:11:29	2020-08-11	9	[{"id_menu":6,"count":1}]	30275	pick-up	0	9
115173	2020-08-11 08:11:44	2020-08-11	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":2}]	44097	delivery	5	26
115174	2020-08-11 08:17:06	2020-08-11	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	21900	delivery	5	27
115175	2020-08-11 08:19:42	2020-08-11	17	[{"id_menu":4,"count":1}]	44165	delivery	5	22
115176	2020-08-11 08:24:10	2020-08-11	9	[{"id_menu":6,"count":1}]	44106	delivery	5	14
115177	2020-08-11 08:24:28	2020-08-11	9	[{"id_menu":7,"count":1}]	43991	delivery	5	14
115178	2020-08-11 08:26:17	2020-08-11	8	[{"id_menu":5,"count":1}]	6168	delivery	5	13
115179	2020-08-11 08:27:07	2020-08-11	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	43992	delivery	5	40
115180	2020-08-11 08:27:16	2020-08-11	9	[{"id_menu":7,"count":1}]	43501	pick-up	0	9
115181	2020-08-11 08:31:05	2020-08-11	12	[{"id_menu":3,"count":1}]	34997	delivery	5	17
115182	2020-08-11 08:31:21	2020-08-11	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	33787	delivery	5	26
115183	2020-08-11 08:36:03	2020-08-11	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3870	pick-up	0	38
115184	2020-08-11 08:46:33	2020-08-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	44078	delivery	5	22
115185	2020-08-11 08:48:04	2020-08-11	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	38447	delivery	5	25
115186	2020-08-11 08:50:54	2020-08-11	17	[{"id_menu":4,"count":1}]	43666	delivery	5	22
115187	2020-08-11 08:55:03	2020-08-11	9	[{"id_menu":7,"count":1}]	13972	delivery	5	14
115188	2020-08-11 08:55:58	2020-08-11	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	13100	delivery	5	43
115189	2020-08-11 08:57:41	2020-08-11	9	[{"id_menu":7,"count":1}]	40236	delivery	5	14
115190	2020-08-11 08:59:03	2020-08-11	9	[{"id_menu":7,"count":1}]	30891	delivery	5	14
115191	2020-08-11 08:59:22	2020-08-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4465	pick-up	0	18
115192	2020-08-11 09:02:10	2020-08-11	12	[{"id_menu":3,"count":1}]	16477	delivery	5	17
115193	2020-08-11 09:03:17	2020-08-11	14	[{"id_menu":2,"count":1}]	38822	delivery	5	19
115194	2020-08-11 09:06:11	2020-08-11	9	[{"id_menu":7,"count":1}]	9307	delivery	5	14
115195	2020-08-11 09:06:20	2020-08-11	12	[{"id_menu":1,"count":1}]	20254	delivery	5	17
115196	2020-08-11 09:20:33	2020-08-11	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	5443	delivery	5	23
115197	2020-08-11 09:29:24	2020-08-11	9	[{"id_menu":6,"count":1}]	44080	delivery	5	14
115198	2020-08-11 09:34:30	2020-08-11	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	44049	delivery	5	53
115199	2020-08-11 09:38:19	2020-08-11	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	37068	delivery	5	31
115200	2020-08-11 09:38:37	2020-08-11	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24223	delivery	5	35
115201	2020-08-11 09:40:24	2020-08-11	9	[{"id_menu":7,"count":1}]	43117	delivery	5	14
115202	2020-08-11 09:41:03	2020-08-11	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	43094	delivery	5	43
115203	2020-08-11 09:50:04	2020-08-11	14	[{"id_menu":2,"count":1}]	1387	pick-up	0	14
115204	2020-08-11 09:52:19	2020-08-11	12	[{"id_menu":1,"count":1}]	24766	pick-up	0	12
115205	2020-08-11 09:54:19	2020-08-11	9	[{"id_menu":7,"count":1}]	44119	delivery	5	14
115206	2020-08-11 10:07:51	2020-08-11	8	[{"id_menu":5,"count":1}]	16755	delivery	5	13
115207	2020-08-11 10:08:51	2020-08-11	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32484	delivery	5	40
115208	2020-08-11 10:12:08	2020-08-11	17	[{"id_menu":4,"count":1}]	16979	pick-up	0	17
115209	2020-08-11 10:12:56	2020-08-11	9	[{"id_menu":7,"count":1}]	44135	delivery	5	14
115210	2020-08-11 10:15:02	2020-08-11	8	[{"id_menu":5,"count":1}]	16575	pick-up	0	8
115211	2020-08-11 10:15:39	2020-08-11	14	[{"id_menu":2,"count":1}]	42775	delivery	5	19
115212	2020-08-11 10:16:04	2020-08-11	17	[{"id_menu":4,"count":1}]	3380	pick-up	0	17
115213	2020-08-11 10:17:38	2020-08-11	9	[{"id_menu":7,"count":1}]	4102	pick-up	0	9
115214	2020-08-11 10:17:56	2020-08-11	30	[{"id_menu":3,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44162	delivery	5	35
115215	2020-08-11 10:19:25	2020-08-11	8	[{"id_menu":5,"count":1}]	9753	delivery	5	13
115216	2020-08-11 10:27:42	2020-08-11	17	[{"id_menu":4,"count":1}]	27820	pick-up	0	17
115217	2020-08-11 10:29:41	2020-08-11	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	44140	delivery	5	39
115218	2020-08-11 10:30:44	2020-08-11	9	[{"id_menu":6,"count":1}]	38103	delivery	5	14
115219	2020-08-11 10:30:44	2020-08-11	8	[{"id_menu":5,"count":4}]	19545	delivery	5	13
115220	2020-08-11 10:34:02	2020-08-11	14	[{"id_menu":2,"count":1}]	36193	pick-up	0	14
115221	2020-08-11 10:34:10	2020-08-11	12	[{"id_menu":1,"count":2}]	4845	delivery	5	17
115222	2020-08-11 10:37:26	2020-08-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7582	pick-up	0	23
115223	2020-08-11 10:38:16	2020-08-11	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	14678	delivery	5	22
115224	2020-08-11 10:41:11	2020-08-11	12	[{"id_menu":1,"count":1}]	15187	pick-up	0	12
115225	2020-08-11 10:45:35	2020-08-11	9	[{"id_menu":7,"count":1}]	7233	delivery	5	14
115226	2020-08-11 10:45:41	2020-08-11	12	[{"id_menu":3,"count":1}]	16768	delivery	5	17
115227	2020-08-11 10:46:35	2020-08-11	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	31374	pick-up	0	29
115228	2020-08-11 10:49:08	2020-08-11	8	[{"id_menu":5,"count":1}]	4909	delivery	5	13
115229	2020-08-11 10:53:29	2020-08-11	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	44021	pick-up	0	26
115230	2020-08-11 10:54:41	2020-08-11	8	[{"id_menu":5,"count":1}]	23446	delivery	5	13
115231	2020-08-11 10:59:58	2020-08-11	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	265	pick-up	0	29
115232	2020-08-11 11:01:53	2020-08-11	12	[{"id_menu":1,"count":1}]	5259	delivery	5	17
115233	2020-08-11 11:10:55	2020-08-11	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	44138	delivery	5	26
115234	2020-08-11 11:13:23	2020-08-11	9	[{"id_menu":7,"count":1}]	3055	delivery	5	14
115235	2020-08-11 11:13:33	2020-08-11	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	44167	pick-up	0	38
115236	2020-08-11 11:17:33	2020-08-11	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	13498	pick-up	0	31
115237	2020-08-11 11:20:35	2020-08-11	12	[{"id_menu":3,"count":1}]	28624	delivery	5	17
115238	2020-08-11 11:21:32	2020-08-11	24	[{"id_menu":1,"count":3},{"id_menu":3,"count":1}]	8285	pick-up	0	24
115239	2020-08-11 11:21:50	2020-08-11	9	[{"id_menu":7,"count":1}]	44030	delivery	5	14
115240	2020-08-11 11:22:41	2020-08-11	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	44107	delivery	5	26
115241	2020-08-11 11:22:42	2020-08-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23298	delivery	5	23
115242	2020-08-11 11:24:00	2020-08-11	14	[{"id_menu":2,"count":1}]	2346	pick-up	0	14
115243	2020-08-11 11:25:20	2020-08-11	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	38926	delivery	5	26
115244	2020-08-11 11:31:24	2020-08-11	12	[{"id_menu":3,"count":1}]	43999	delivery	5	17
115245	2020-08-11 11:32:13	2020-08-11	14	[{"id_menu":2,"count":1}]	44100	delivery	5	19
115246	2020-08-11 11:34:07	2020-08-11	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	23427	delivery	5	26
115247	2020-08-11 11:34:40	2020-08-11	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	42864	delivery	5	34
115248	2020-08-11 11:37:31	2020-08-11	8	[{"id_menu":5,"count":1}]	43995	delivery	5	13
115249	2020-08-11 11:37:37	2020-08-11	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	44121	delivery	5	43
115250	2020-08-11 11:40:45	2020-08-11	12	[{"id_menu":3,"count":1}]	4704	delivery	5	17
115251	2020-08-11 11:42:52	2020-08-11	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18637	delivery	5	39
115252	2020-08-11 11:53:13	2020-08-11	8	[{"id_menu":5,"count":1}]	6334	delivery	5	13
115253	2020-08-11 11:53:36	2020-08-11	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	18166	delivery	5	36
115254	2020-08-11 11:54:43	2020-08-11	14	[{"id_menu":2,"count":1}]	11611	delivery	5	19
115255	2020-08-11 11:55:39	2020-08-11	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	44057	delivery	5	26
115256	2020-08-11 12:00:13	2020-08-11	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	44066	delivery	5	28
115257	2020-08-11 12:05:58	2020-08-11	12	[{"id_menu":3,"count":1}]	10240	delivery	5	17
115258	2020-08-11 12:08:04	2020-08-11	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	44032	delivery	5	40
115259	2020-08-11 12:09:04	2020-08-11	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	14263	delivery	5	28
115260	2020-08-11 12:09:23	2020-08-11	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	12568	delivery	5	31
115261	2020-08-11 12:09:52	2020-08-11	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	44148	delivery	5	39
115262	2020-08-11 12:12:21	2020-08-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	33212	delivery	5	28
115263	2020-08-11 12:15:03	2020-08-11	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43998	delivery	5	43
115264	2020-08-11 12:15:10	2020-08-11	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27559	delivery	5	34
115265	2020-08-11 12:17:35	2020-08-11	9	[{"id_menu":6,"count":1}]	44082	pick-up	0	9
115266	2020-08-11 12:17:44	2020-08-11	14	[{"id_menu":2,"count":1}]	36292	delivery	5	19
115267	2020-08-11 12:18:36	2020-08-11	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	44026	delivery	5	31
115268	2020-08-11 12:18:43	2020-08-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44001	delivery	5	23
115269	2020-08-11 12:19:08	2020-08-11	9	[{"id_menu":7,"count":1}]	29418	delivery	5	14
115270	2020-08-11 12:22:15	2020-08-11	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	37439	delivery	5	26
115271	2020-08-11 12:22:44	2020-08-11	9	[{"id_menu":7,"count":1}]	10632	pick-up	0	9
115272	2020-08-11 12:22:58	2020-08-11	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	33053	delivery	5	45
115273	2020-08-11 12:23:34	2020-08-11	17	[{"id_menu":4,"count":1}]	32867	delivery	5	22
115274	2020-08-11 12:25:00	2020-08-11	14	[{"id_menu":2,"count":1}]	44109	delivery	5	19
115275	2020-08-11 12:25:41	2020-08-11	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22924	delivery	5	48
115276	2020-08-11 12:30:32	2020-08-11	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	24900	delivery	5	26
115277	2020-08-11 12:34:32	2020-08-11	14	[{"id_menu":2,"count":1}]	27752	delivery	5	19
115278	2020-08-11 12:36:12	2020-08-11	12	[{"id_menu":1,"count":1}]	44190	delivery	5	17
115279	2020-08-11 12:47:54	2020-08-11	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	12178	delivery	5	39
115280	2020-08-11 12:49:11	2020-08-11	9	[{"id_menu":6,"count":1}]	44113	pick-up	0	9
115281	2020-08-11 12:52:55	2020-08-11	12	[{"id_menu":1,"count":1}]	15648	delivery	5	17
115282	2020-08-11 12:55:31	2020-08-11	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	44130	delivery	5	40
115283	2020-08-11 12:55:40	2020-08-11	17	[{"id_menu":4,"count":1}]	25901	delivery	5	22
115284	2020-08-11 12:59:29	2020-08-11	12	[{"id_menu":3,"count":1}]	44067	delivery	5	17
115285	2020-08-11 13:00:40	2020-08-11	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	30690	delivery	5	46
115286	2020-08-11 13:02:17	2020-08-11	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	6983	delivery	5	37
115287	2020-08-11 13:02:45	2020-08-11	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	44178	pick-up	0	31
115288	2020-08-11 13:04:27	2020-08-11	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	43982	delivery	5	30
115289	2020-08-11 13:06:33	2020-08-11	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	6378	delivery	5	36
115290	2020-08-11 13:07:11	2020-08-11	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	44155	delivery	5	31
115291	2020-08-11 13:08:09	2020-08-11	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29769	delivery	5	49
115292	2020-08-11 13:09:54	2020-08-11	9	[{"id_menu":6,"count":1}]	33167	delivery	5	14
115293	2020-08-11 13:19:07	2020-08-11	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24725	pick-up	0	31
115294	2020-08-11 13:19:23	2020-08-11	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":3}]	44028	delivery	5	22
115295	2020-08-11 13:19:30	2020-08-11	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19783	delivery	5	39
115296	2020-08-11 13:19:58	2020-08-11	9	[{"id_menu":7,"count":1}]	39736	delivery	5	14
115297	2020-08-11 13:21:10	2020-08-11	14	[{"id_menu":2,"count":1}]	41720	pick-up	0	14
115298	2020-08-11 13:24:45	2020-08-11	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	12907	delivery	5	31
115299	2020-08-11 13:31:11	2020-08-11	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	37870	delivery	5	44
115300	2020-08-11 13:33:42	2020-08-11	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	44070	delivery	5	34
115301	2020-08-11 13:33:55	2020-08-11	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27658	delivery	5	37
115302	2020-08-11 13:38:39	2020-08-11	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	21324	delivery	5	39
115303	2020-08-11 13:44:28	2020-08-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	40679	pick-up	0	23
115304	2020-08-11 13:48:37	2020-08-11	17	[{"id_menu":4,"count":1}]	43993	pick-up	0	17
115305	2020-08-11 13:53:31	2020-08-11	9	[{"id_menu":7,"count":1}]	33254	pick-up	0	9
115306	2020-08-11 13:56:45	2020-08-11	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	17710	delivery	5	28
115307	2020-08-11 13:57:09	2020-08-11	8	[{"id_menu":5,"count":1}]	35230	pick-up	0	8
115308	2020-08-11 13:57:41	2020-08-11	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2187	pick-up	0	38
115309	2020-08-11 13:58:40	2020-08-11	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	44060	delivery	5	30
115310	2020-08-11 13:59:47	2020-08-11	26	[{"id_menu":1,"count":3},{"id_menu":2,"count":1}]	14578	pick-up	0	26
115311	2020-08-11 14:01:59	2020-08-11	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	44181	delivery	5	30
115312	2020-08-11 14:11:36	2020-08-11	8	[{"id_menu":5,"count":1}]	20883	pick-up	0	8
115313	2020-08-11 14:14:07	2020-08-11	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2244	pick-up	0	21
115314	2020-08-11 14:16:53	2020-08-11	9	[{"id_menu":6,"count":1}]	5996	delivery	5	14
115315	2020-08-11 14:18:51	2020-08-11	12	[{"id_menu":1,"count":1}]	43968	pick-up	0	12
115316	2020-08-11 14:19:15	2020-08-11	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	39891	delivery	5	22
115317	2020-08-11 14:33:06	2020-08-11	9	[{"id_menu":6,"count":1}]	44019	delivery	5	14
115318	2020-08-11 14:35:01	2020-08-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	21785	pick-up	0	23
115319	2020-08-11 14:35:46	2020-08-11	8	[{"id_menu":5,"count":2}]	44192	delivery	5	13
115320	2020-08-11 14:38:00	2020-08-11	9	[{"id_menu":7,"count":1}]	20873	delivery	5	14
115321	2020-08-11 14:41:38	2020-08-11	9	[{"id_menu":6,"count":2}]	18687	pick-up	0	9
115322	2020-08-11 14:42:41	2020-08-11	9	[{"id_menu":7,"count":1}]	8165	delivery	5	14
115323	2020-08-11 14:45:02	2020-08-11	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	10076	delivery	5	39
115324	2020-08-11 14:54:13	2020-08-11	8	[{"id_menu":5,"count":1}]	38118	delivery	5	13
115325	2020-08-11 14:57:08	2020-08-11	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44173	delivery	5	35
115326	2020-08-11 14:58:19	2020-08-11	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8050	delivery	5	57
115327	2020-08-11 15:00:12	2020-08-11	9	[{"id_menu":7,"count":1}]	7903	delivery	5	14
115328	2020-08-11 15:01:05	2020-08-11	8	[{"id_menu":5,"count":1}]	38809	pick-up	0	8
115329	2020-08-11 15:02:25	2020-08-11	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	9193	pick-up	0	21
115330	2020-08-11 15:02:47	2020-08-11	14	[{"id_menu":2,"count":1}]	43981	pick-up	0	14
115331	2020-08-11 15:08:22	2020-08-11	14	[{"id_menu":2,"count":1}]	44000	delivery	5	19
115332	2020-08-11 15:09:13	2020-08-11	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2712	delivery	5	26
115333	2020-08-11 15:10:55	2020-08-11	14	[{"id_menu":2,"count":1}]	44175	delivery	5	19
115334	2020-08-11 15:11:47	2020-08-11	8	[{"id_menu":5,"count":1}]	44103	delivery	5	13
115335	2020-08-11 15:14:40	2020-08-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28647	delivery	5	22
115336	2020-08-11 15:16:45	2020-08-11	9	[{"id_menu":6,"count":1}]	26292	delivery	5	14
115337	2020-08-11 15:19:14	2020-08-11	12	[{"id_menu":1,"count":1}]	1541	delivery	5	17
115338	2020-08-11 15:22:17	2020-08-11	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	638	pick-up	0	26
115339	2020-08-11 15:32:17	2020-08-11	9	[{"id_menu":7,"count":1}]	946	pick-up	0	9
115340	2020-08-11 15:37:09	2020-08-11	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	722	delivery	5	31
115341	2020-08-11 15:37:38	2020-08-11	9	[{"id_menu":6,"count":1}]	2119	pick-up	0	9
115342	2020-08-11 15:38:05	2020-08-11	14	[{"id_menu":2,"count":1}]	905	pick-up	0	14
115343	2020-08-11 15:38:38	2020-08-11	9	[{"id_menu":6,"count":1}]	8459	delivery	5	14
115344	2020-08-11 15:42:44	2020-08-11	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4045	delivery	5	36
115345	2020-08-11 15:42:54	2020-08-11	9	[{"id_menu":7,"count":1}]	44115	delivery	5	14
115346	2020-08-11 15:43:04	2020-08-11	8	[{"id_menu":5,"count":1}]	37400	pick-up	0	8
115347	2020-08-11 15:45:14	2020-08-11	17	[{"id_menu":4,"count":2}]	15797	pick-up	0	17
115348	2020-08-11 15:46:03	2020-08-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34311	delivery	5	23
115349	2020-08-11 15:46:06	2020-08-11	12	[{"id_menu":1,"count":1}]	609	pick-up	0	12
115350	2020-08-11 15:47:11	2020-08-11	14	[{"id_menu":2,"count":1}]	44087	pick-up	0	14
115351	2020-08-11 15:48:51	2020-08-11	12	[{"id_menu":3,"count":1}]	44151	delivery	5	17
115352	2020-08-11 15:50:50	2020-08-11	12	[{"id_menu":1,"count":1}]	9445	delivery	5	17
115353	2020-08-11 15:51:09	2020-08-11	9	[{"id_menu":6,"count":1}]	19464	delivery	5	14
115354	2020-08-11 15:53:57	2020-08-11	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	43969	delivery	5	48
115355	2020-08-11 15:53:59	2020-08-11	8	[{"id_menu":5,"count":1}]	11969	delivery	5	13
115356	2020-08-11 15:55:54	2020-08-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	35079	delivery	5	22
115357	2020-08-11 16:01:00	2020-08-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17794	delivery	5	23
115358	2020-08-11 16:04:04	2020-08-11	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	33022	pick-up	0	17
115359	2020-08-11 16:04:21	2020-08-11	8	[{"id_menu":5,"count":1}]	499	delivery	5	13
115360	2020-08-11 16:05:42	2020-08-11	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	44071	delivery	5	31
115361	2020-08-11 16:09:42	2020-08-11	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	7588	delivery	5	27
115362	2020-08-11 16:09:43	2020-08-11	12	[{"id_menu":3,"count":1}]	533	delivery	5	17
115363	2020-08-11 16:12:33	2020-08-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	44056	delivery	5	22
115364	2020-08-11 16:13:52	2020-08-11	14	[{"id_menu":2,"count":1}]	3864	pick-up	0	14
115365	2020-08-11 16:14:48	2020-08-11	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	44016	delivery	5	46
115366	2020-08-11 16:16:48	2020-08-11	12	[{"id_menu":3,"count":1}]	4552	delivery	5	17
115367	2020-08-11 16:17:29	2020-08-11	14	[{"id_menu":2,"count":1}]	26163	delivery	5	19
115368	2020-08-11 16:19:31	2020-08-11	17	[{"id_menu":4,"count":1}]	4995	pick-up	0	17
115369	2020-08-11 16:19:37	2020-08-11	8	[{"id_menu":5,"count":1}]	43962	delivery	5	13
115370	2020-08-11 16:32:44	2020-08-11	9	[{"id_menu":6,"count":1}]	25781	delivery	5	14
115371	2020-08-11 16:34:24	2020-08-11	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	41810	delivery	5	34
115372	2020-08-11 16:39:15	2020-08-11	14	[{"id_menu":2,"count":1}]	44170	delivery	5	19
115373	2020-08-11 16:39:56	2020-08-11	17	[{"id_menu":4,"count":1}]	12249	delivery	5	22
115374	2020-08-11 16:42:46	2020-08-11	12	[{"id_menu":3,"count":1}]	21243	delivery	5	17
115375	2020-08-11 16:45:14	2020-08-11	8	[{"id_menu":5,"count":1}]	9554	delivery	5	13
115376	2020-08-11 16:46:54	2020-08-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	44174	delivery	5	28
115377	2020-08-11 16:47:35	2020-08-11	9	[{"id_menu":7,"count":1}]	44085	delivery	5	14
115378	2020-08-11 16:59:50	2020-08-11	9	[{"id_menu":7,"count":1}]	44159	delivery	5	14
115379	2020-08-11 17:02:24	2020-08-11	14	[{"id_menu":2,"count":1}]	21901	pick-up	0	14
115380	2020-08-11 17:07:28	2020-08-11	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	44145	delivery	5	43
115381	2020-08-11 17:09:46	2020-08-11	9	[{"id_menu":6,"count":1}]	44025	delivery	5	14
115382	2020-08-11 17:11:58	2020-08-11	12	[{"id_menu":1,"count":1}]	29890	delivery	5	17
115383	2020-08-11 17:13:49	2020-08-11	17	[{"id_menu":4,"count":1}]	5967	delivery	5	22
115384	2020-08-11 17:17:57	2020-08-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44128	delivery	5	23
115385	2020-08-11 17:20:30	2020-08-11	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	41757	delivery	5	36
115386	2020-08-11 17:20:33	2020-08-11	14	[{"id_menu":2,"count":1}]	43970	delivery	5	19
115387	2020-08-11 17:21:42	2020-08-11	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	6769	pick-up	0	21
115388	2020-08-11 17:24:29	2020-08-11	9	[{"id_menu":7,"count":1}]	44093	pick-up	0	9
115389	2020-08-11 17:33:08	2020-08-11	14	[{"id_menu":2,"count":1}]	8693	delivery	5	19
115390	2020-08-11 17:35:22	2020-08-11	14	[{"id_menu":2,"count":1}]	44156	delivery	5	19
115391	2020-08-11 17:36:06	2020-08-11	9	[{"id_menu":7,"count":1}]	30832	delivery	5	14
115392	2020-08-11 17:39:48	2020-08-11	9	[{"id_menu":7,"count":1}]	17234	delivery	5	14
115393	2020-08-11 17:42:43	2020-08-11	12	[{"id_menu":1,"count":1}]	21800	delivery	5	17
115394	2020-08-11 17:46:07	2020-08-11	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	32633	delivery	5	42
115395	2020-08-11 17:53:02	2020-08-11	8	[{"id_menu":5,"count":1}]	1183	pick-up	0	8
115396	2020-08-11 17:54:17	2020-08-11	9	[{"id_menu":6,"count":1}]	852	delivery	5	14
115397	2020-08-11 17:54:37	2020-08-11	8	[{"id_menu":5,"count":1}]	29632	delivery	5	13
115398	2020-08-11 17:55:34	2020-08-11	8	[{"id_menu":5,"count":1}]	36693	delivery	5	13
115399	2020-08-11 17:58:44	2020-08-11	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	281	delivery	5	31
115400	2020-08-11 18:00:24	2020-08-11	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	38219	delivery	5	34
115401	2020-08-11 18:02:05	2020-08-11	9	[{"id_menu":6,"count":1}]	13273	delivery	5	14
115402	2020-08-11 18:04:12	2020-08-11	9	[{"id_menu":6,"count":1}]	31696	delivery	5	14
115403	2020-08-11 18:04:15	2020-08-11	14	[{"id_menu":2,"count":1}]	30050	delivery	5	19
115404	2020-08-11 18:04:28	2020-08-11	8	[{"id_menu":5,"count":2}]	6186	delivery	5	13
115405	2020-08-11 18:05:45	2020-08-11	8	[{"id_menu":5,"count":1}]	11705	delivery	5	13
115406	2020-08-11 18:10:52	2020-08-11	8	[{"id_menu":5,"count":1}]	1867	pick-up	0	8
115407	2020-08-11 18:13:32	2020-08-11	14	[{"id_menu":2,"count":1}]	28617	delivery	5	19
115408	2020-08-11 18:17:27	2020-08-11	17	[{"id_menu":4,"count":1}]	44147	delivery	5	22
115409	2020-08-11 18:17:34	2020-08-11	8	[{"id_menu":5,"count":1}]	25559	delivery	5	13
115410	2020-08-11 18:17:47	2020-08-11	9	[{"id_menu":7,"count":1}]	19628	delivery	5	14
115411	2020-08-11 18:19:49	2020-08-11	9	[{"id_menu":7,"count":1}]	10338	delivery	5	14
115412	2020-08-11 18:20:10	2020-08-11	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	43966	delivery	5	31
115413	2020-08-11 18:20:44	2020-08-11	14	[{"id_menu":2,"count":1}]	23607	pick-up	0	14
115414	2020-08-11 18:21:26	2020-08-11	9	[{"id_menu":7,"count":1}]	44061	delivery	5	14
115415	2020-08-11 18:21:50	2020-08-11	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	44076	delivery	5	22
115416	2020-08-11 18:21:51	2020-08-11	12	[{"id_menu":1,"count":1}]	26127	delivery	5	17
115417	2020-08-11 18:25:28	2020-08-11	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	37634	delivery	5	31
115418	2020-08-11 18:26:18	2020-08-11	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10258	pick-up	0	26
115419	2020-08-11 18:28:31	2020-08-11	9	[{"id_menu":7,"count":1}]	44047	delivery	5	14
115420	2020-08-11 18:28:51	2020-08-11	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10013	delivery	5	43
115421	2020-08-11 18:30:13	2020-08-11	17	[{"id_menu":4,"count":1}]	13931	delivery	5	22
115422	2020-08-11 18:33:33	2020-08-11	14	[{"id_menu":2,"count":1}]	18973	delivery	5	19
115423	2020-08-11 18:38:57	2020-08-11	12	[{"id_menu":1,"count":1}]	44153	delivery	5	17
115424	2020-08-11 18:41:27	2020-08-11	9	[{"id_menu":7,"count":1}]	44186	delivery	5	14
115425	2020-08-11 18:43:47	2020-08-11	17	[{"id_menu":4,"count":1}]	31102	delivery	5	22
115426	2020-08-11 18:44:24	2020-08-11	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	12662	delivery	5	26
115427	2020-08-11 18:57:09	2020-08-11	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5925	delivery	5	39
115428	2020-08-11 18:57:38	2020-08-11	12	[{"id_menu":3,"count":1}]	1772	pick-up	0	12
115429	2020-08-11 18:58:10	2020-08-11	12	[{"id_menu":3,"count":1}]	28290	delivery	5	17
115430	2020-08-11 18:59:43	2020-08-11	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3168	delivery	5	31
115431	2020-08-11 19:01:51	2020-08-11	9	[{"id_menu":6,"count":1}]	16853	pick-up	0	9
115432	2020-08-11 19:02:56	2020-08-11	9	[{"id_menu":6,"count":1}]	44012	delivery	5	14
115433	2020-08-11 19:03:18	2020-08-11	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	44020	delivery	5	31
115434	2020-08-11 19:04:37	2020-08-11	8	[{"id_menu":5,"count":1}]	27432	delivery	5	13
115435	2020-08-11 19:05:44	2020-08-11	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	41107	delivery	5	39
115436	2020-08-11 19:08:31	2020-08-11	9	[{"id_menu":6,"count":1}]	13086	delivery	5	14
115437	2020-08-11 19:08:41	2020-08-11	9	[{"id_menu":6,"count":1}]	44081	delivery	5	14
115438	2020-08-11 19:09:31	2020-08-11	8	[{"id_menu":5,"count":1}]	44179	delivery	5	13
115439	2020-08-11 19:09:37	2020-08-11	9	[{"id_menu":7,"count":1}]	34946	delivery	5	14
115440	2020-08-11 19:11:56	2020-08-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41586	delivery	5	23
115441	2020-08-11 19:12:39	2020-08-11	9	[{"id_menu":7,"count":1}]	18274	delivery	5	14
115442	2020-08-11 19:13:34	2020-08-11	12	[{"id_menu":1,"count":1}]	26311	pick-up	0	12
115443	2020-08-11 19:14:20	2020-08-11	9	[{"id_menu":6,"count":1}]	44122	delivery	5	14
115444	2020-08-11 19:16:09	2020-08-11	17	[{"id_menu":4,"count":1}]	39788	delivery	5	22
115445	2020-08-11 19:25:15	2020-08-11	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	30140	pick-up	0	31
115446	2020-08-11 19:27:55	2020-08-11	12	[{"id_menu":1,"count":1}]	34478	delivery	5	17
115447	2020-08-11 19:28:20	2020-08-11	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	44088	delivery	5	57
115448	2020-08-11 19:29:45	2020-08-11	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	38500	delivery	5	43
115449	2020-08-11 19:34:53	2020-08-11	12	[{"id_menu":3,"count":1}]	14751	pick-up	0	12
115450	2020-08-11 19:38:23	2020-08-11	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3127	delivery	5	35
115451	2020-08-11 19:40:21	2020-08-11	14	[{"id_menu":2,"count":1}]	43637	delivery	5	19
115452	2020-08-11 19:42:46	2020-08-11	17	[{"id_menu":4,"count":1}]	23890	pick-up	0	17
115453	2020-08-11 19:48:35	2020-08-11	9	[{"id_menu":6,"count":1}]	36029	delivery	5	14
115454	2020-08-11 19:50:19	2020-08-11	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44102	delivery	5	43
115455	2020-08-11 19:55:26	2020-08-11	34	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	44131	delivery	5	39
115456	2020-08-11 19:55:40	2020-08-11	8	[{"id_menu":5,"count":1}]	41795	delivery	5	13
115457	2020-08-11 19:55:55	2020-08-11	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	9308	pick-up	0	29
115458	2020-08-11 19:56:19	2020-08-11	17	[{"id_menu":4,"count":1}]	44177	pick-up	0	17
115459	2020-08-11 19:56:28	2020-08-11	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	22220	delivery	5	40
115460	2020-08-11 20:06:51	2020-08-11	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	44094	delivery	5	43
115461	2020-08-11 20:07:08	2020-08-11	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	44184	delivery	5	30
115462	2020-08-11 20:10:19	2020-08-11	9	[{"id_menu":6,"count":1}]	27012	delivery	5	14
115463	2020-08-11 20:13:23	2020-08-11	9	[{"id_menu":6,"count":1}]	14660	delivery	5	14
115464	2020-08-11 20:16:44	2020-08-11	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	27191	delivery	5	26
115465	2020-08-11 20:18:56	2020-08-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	44161	delivery	5	28
115466	2020-08-11 20:19:01	2020-08-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	44036	delivery	5	28
115467	2020-08-11 20:21:01	2020-08-11	9	[{"id_menu":6,"count":1}]	8586	delivery	5	14
115468	2020-08-11 20:22:30	2020-08-11	8	[{"id_menu":5,"count":1}]	44110	delivery	5	13
115469	2020-08-11 20:24:49	2020-08-11	9	[{"id_menu":7,"count":1}]	43964	delivery	5	14
115470	2020-08-11 20:29:35	2020-08-11	9	[{"id_menu":6,"count":1}]	42249	delivery	5	14
115471	2020-08-11 20:29:47	2020-08-11	8	[{"id_menu":5,"count":1}]	38585	delivery	5	13
115472	2020-08-11 20:30:15	2020-08-11	9	[{"id_menu":6,"count":1}]	33593	delivery	5	14
115473	2020-08-11 20:31:26	2020-08-11	8	[{"id_menu":5,"count":1}]	7345	delivery	5	13
115474	2020-08-11 20:32:51	2020-08-11	12	[{"id_menu":1,"count":1}]	44185	pick-up	0	12
115475	2020-08-11 20:34:39	2020-08-11	14	[{"id_menu":2,"count":2}]	34079	delivery	5	19
115476	2020-08-11 20:35:27	2020-08-11	12	[{"id_menu":1,"count":1}]	42521	delivery	5	17
115477	2020-08-11 20:35:29	2020-08-11	14	[{"id_menu":2,"count":1}]	12043	pick-up	0	14
115478	2020-08-11 20:36:32	2020-08-11	9	[{"id_menu":7,"count":1}]	43983	delivery	5	14
115479	2020-08-11 20:36:47	2020-08-11	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	12479	delivery	5	40
115480	2020-08-11 20:36:49	2020-08-11	8	[{"id_menu":5,"count":1}]	725	delivery	5	13
115481	2020-08-11 20:39:43	2020-08-11	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	44099	delivery	5	36
115482	2020-08-11 20:40:00	2020-08-11	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	44034	delivery	5	36
115483	2020-08-11 20:49:59	2020-08-11	12	[{"id_menu":1,"count":1}]	32934	delivery	5	17
115484	2020-08-11 20:50:26	2020-08-11	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	24872	pick-up	0	20
115485	2020-08-11 20:52:50	2020-08-11	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	16406	pick-up	0	21
115486	2020-08-11 21:00:25	2020-08-11	12	[{"id_menu":1,"count":1}]	8640	delivery	5	17
115487	2020-08-11 21:05:30	2020-08-11	9	[{"id_menu":6,"count":1}]	34388	delivery	5	14
115488	2020-08-11 21:06:20	2020-08-11	12	[{"id_menu":3,"count":1}]	832	delivery	5	17
115489	2020-08-11 21:06:58	2020-08-11	9	[{"id_menu":7,"count":1}]	44111	delivery	5	14
115490	2020-08-11 21:09:01	2020-08-11	34	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	43973	delivery	5	39
115491	2020-08-11 21:09:26	2020-08-11	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	44187	delivery	5	39
115492	2020-08-11 21:14:52	2020-08-11	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	44132	delivery	5	25
115493	2020-08-11 21:22:08	2020-08-11	8	[{"id_menu":5,"count":1}]	4451	pick-up	0	8
115494	2020-08-11 21:24:59	2020-08-11	9	[{"id_menu":7,"count":1}]	18353	pick-up	0	9
115495	2020-08-11 21:28:14	2020-08-11	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	35367	delivery	5	25
115496	2020-08-11 21:28:49	2020-08-11	9	[{"id_menu":7,"count":1}]	1155	pick-up	0	9
115497	2020-08-11 21:38:30	2020-08-11	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	44059	pick-up	0	26
115498	2020-08-11 21:39:33	2020-08-11	9	[{"id_menu":7,"count":1}]	14146	delivery	5	14
115499	2020-08-11 21:41:29	2020-08-11	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	39478	delivery	5	34
115500	2020-08-11 21:42:52	2020-08-11	12	[{"id_menu":1,"count":1}]	9086	pick-up	0	12
115501	2020-08-11 21:43:11	2020-08-11	8	[{"id_menu":5,"count":1}]	22014	delivery	5	13
115502	2020-08-11 21:46:50	2020-08-11	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	14199	delivery	5	31
115503	2020-08-11 21:50:00	2020-08-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	39163	delivery	5	28
115504	2020-08-11 21:52:49	2020-08-11	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	865	pick-up	0	29
115505	2020-08-11 21:55:01	2020-08-11	9	[{"id_menu":7,"count":1}]	16946	pick-up	0	9
115506	2020-08-11 21:58:01	2020-08-11	8	[{"id_menu":5,"count":1}]	11394	pick-up	0	8
115507	2020-08-11 21:58:41	2020-08-11	8	[{"id_menu":5,"count":1}]	5758	delivery	5	13
115508	2020-08-11 22:02:01	2020-08-11	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	44017	delivery	5	36
115509	2020-08-11 22:03:33	2020-08-11	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	43594	pick-up	0	21
115510	2020-08-11 22:04:52	2020-08-11	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	44009	delivery	5	30
115511	2020-08-11 22:06:34	2020-08-11	9	[{"id_menu":6,"count":1}]	37904	delivery	5	14
115512	2020-08-11 22:09:20	2020-08-11	8	[{"id_menu":5,"count":1}]	15736	delivery	5	13
115513	2020-08-11 22:10:46	2020-08-11	17	[{"id_menu":4,"count":1}]	44044	delivery	5	22
115514	2020-08-11 22:20:09	2020-08-11	14	[{"id_menu":2,"count":1}]	15285	pick-up	0	14
115515	2020-08-11 22:23:56	2020-08-11	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	44154	delivery	5	26
115516	2020-08-11 22:30:05	2020-08-11	9	[{"id_menu":6,"count":1}]	23411	pick-up	0	9
115517	2020-08-11 22:36:40	2020-08-11	9	[{"id_menu":7,"count":2}]	17685	pick-up	0	9
115518	2020-08-11 22:40:59	2020-08-11	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	5786	delivery	5	31
115519	2020-08-11 22:46:37	2020-08-11	8	[{"id_menu":5,"count":1}]	12506	pick-up	0	8
115520	2020-08-11 22:51:53	2020-08-11	9	[{"id_menu":7,"count":1}]	29869	delivery	5	14
115521	2020-08-11 22:53:06	2020-08-11	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34751	delivery	5	40
115522	2020-08-11 22:54:14	2020-08-11	9	[{"id_menu":6,"count":1}]	36356	delivery	5	14
115523	2020-08-11 22:57:08	2020-08-11	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12478	delivery	5	39
115524	2020-08-11 22:57:43	2020-08-11	9	[{"id_menu":7,"count":1}]	35707	delivery	5	14
115525	2020-08-11 22:59:21	2020-08-11	12	[{"id_menu":3,"count":1}]	43963	delivery	5	17
115526	2020-08-11 23:01:03	2020-08-11	8	[{"id_menu":5,"count":1}]	29702	delivery	5	13
115527	2020-08-11 23:03:32	2020-08-11	12	[{"id_menu":1,"count":1}]	44157	delivery	5	17
115528	2020-08-11 23:03:50	2020-08-11	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	17381	delivery	5	25
115529	2020-08-11 23:04:02	2020-08-11	9	[{"id_menu":6,"count":1}]	40085	pick-up	0	9
115530	2020-08-11 23:07:51	2020-08-11	9	[{"id_menu":7,"count":1}]	44144	pick-up	0	9
115531	2020-08-11 23:10:30	2020-08-11	14	[{"id_menu":2,"count":1}]	28367	pick-up	0	14
115532	2020-08-11 23:11:28	2020-08-11	8	[{"id_menu":5,"count":1}]	16792	pick-up	0	8
115533	2020-08-11 23:12:57	2020-08-11	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	44141	delivery	5	42
115534	2020-08-11 23:18:52	2020-08-11	9	[{"id_menu":6,"count":1}]	8488	delivery	5	14
115535	2020-08-11 23:20:52	2020-08-11	9	[{"id_menu":6,"count":1}]	9148	delivery	5	14
115536	2020-08-11 23:23:57	2020-08-11	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	38939	delivery	5	40
115537	2020-08-11 23:24:42	2020-08-11	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14875	delivery	5	36
115538	2020-08-11 23:35:40	2020-08-11	14	[{"id_menu":2,"count":1}]	35038	delivery	5	19
115539	2020-08-11 23:49:03	2020-08-11	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	14897	delivery	5	28
115540	2020-08-11 23:55:53	2020-08-11	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	19591	delivery	5	23
115541	2020-08-11 23:56:34	2020-08-11	14	[{"id_menu":2,"count":1}]	27151	delivery	5	19
115542	2020-08-11 23:59:14	2020-08-11	12	[{"id_menu":3,"count":1}]	21109	delivery	5	17
115543	2020-08-12 00:10:46	2020-08-12	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	37456	delivery	5	36
115544	2020-08-12 00:11:06	2020-08-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	44423	delivery	5	22
115545	2020-08-12 00:13:16	2020-08-12	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	44232	delivery	5	28
115546	2020-08-12 00:14:41	2020-08-12	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	44270	delivery	5	25
115547	2020-08-12 00:14:41	2020-08-12	14	[{"id_menu":2,"count":1}]	16539	pick-up	0	14
115548	2020-08-12 00:14:43	2020-08-12	9	[{"id_menu":7,"count":1}]	40126	delivery	5	14
115549	2020-08-12 00:24:12	2020-08-12	17	[{"id_menu":4,"count":1}]	21148	delivery	5	22
115550	2020-08-12 00:24:35	2020-08-12	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	24215	delivery	5	35
115551	2020-08-12 00:24:43	2020-08-12	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	20329	delivery	5	31
115552	2020-08-12 00:25:50	2020-08-12	12	[{"id_menu":1,"count":1}]	5338	pick-up	0	12
115553	2020-08-12 00:27:07	2020-08-12	14	[{"id_menu":2,"count":1}]	25407	delivery	5	19
115554	2020-08-12 00:39:43	2020-08-12	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	40680	delivery	5	39
115555	2020-08-12 00:40:17	2020-08-12	9	[{"id_menu":6,"count":1}]	1453	pick-up	0	9
115556	2020-08-12 00:41:01	2020-08-12	8	[{"id_menu":5,"count":1}]	25060	delivery	5	13
115557	2020-08-12 00:41:23	2020-08-12	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	44303	pick-up	0	23
115558	2020-08-12 00:51:14	2020-08-12	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	26321	delivery	5	31
115559	2020-08-12 00:52:32	2020-08-12	12	[{"id_menu":1,"count":1}]	33551	delivery	5	17
115560	2020-08-12 00:52:49	2020-08-12	8	[{"id_menu":5,"count":1}]	23742	delivery	5	13
115561	2020-08-12 00:56:25	2020-08-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	44324	delivery	5	28
115562	2020-08-12 00:57:07	2020-08-12	12	[{"id_menu":1,"count":1}]	24041	delivery	5	17
115563	2020-08-12 00:58:54	2020-08-12	9	[{"id_menu":6,"count":1}]	44383	delivery	5	14
115564	2020-08-12 01:00:36	2020-08-12	14	[{"id_menu":2,"count":1}]	44202	pick-up	0	14
115565	2020-08-12 01:06:27	2020-08-12	8	[{"id_menu":5,"count":1}]	40560	delivery	5	13
115566	2020-08-12 01:06:57	2020-08-12	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12790	delivery	5	43
115567	2020-08-12 01:08:50	2020-08-12	8	[{"id_menu":5,"count":1}]	28720	delivery	5	13
115568	2020-08-12 01:09:08	2020-08-12	9	[{"id_menu":7,"count":1}]	23589	delivery	5	14
115569	2020-08-12 01:09:22	2020-08-12	9	[{"id_menu":7,"count":1}]	36485	delivery	5	14
115570	2020-08-12 01:10:06	2020-08-12	9	[{"id_menu":6,"count":1}]	6439	delivery	5	14
115571	2020-08-12 01:18:44	2020-08-12	9	[{"id_menu":7,"count":1}]	44438	delivery	5	14
115572	2020-08-12 01:19:26	2020-08-12	12	[{"id_menu":1,"count":1}]	9689	delivery	5	17
115573	2020-08-12 01:20:47	2020-08-12	9	[{"id_menu":6,"count":1}]	24733	pick-up	0	9
115574	2020-08-12 01:23:20	2020-08-12	17	[{"id_menu":4,"count":1}]	9358	pick-up	0	17
115575	2020-08-12 01:25:25	2020-08-12	17	[{"id_menu":4,"count":1}]	5369	pick-up	0	17
115576	2020-08-12 01:30:36	2020-08-12	9	[{"id_menu":6,"count":1}]	40092	pick-up	0	9
115577	2020-08-12 01:32:02	2020-08-12	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22363	delivery	5	22
115578	2020-08-12 01:35:16	2020-08-12	9	[{"id_menu":7,"count":1}]	11150	delivery	5	14
115579	2020-08-12 01:36:35	2020-08-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	37019	delivery	5	22
115580	2020-08-12 01:37:01	2020-08-12	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	23735	delivery	5	22
115581	2020-08-12 01:42:38	2020-08-12	9	[{"id_menu":7,"count":1}]	38888	delivery	5	14
115582	2020-08-12 01:43:23	2020-08-12	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	36887	delivery	5	31
115583	2020-08-12 01:44:14	2020-08-12	14	[{"id_menu":2,"count":1}]	32184	pick-up	0	14
115584	2020-08-12 01:47:28	2020-08-12	9	[{"id_menu":7,"count":1}]	44231	delivery	5	14
115585	2020-08-12 01:47:51	2020-08-12	12	[{"id_menu":3,"count":1}]	25668	delivery	5	17
115586	2020-08-12 01:48:52	2020-08-12	9	[{"id_menu":7,"count":1}]	44325	delivery	5	14
115587	2020-08-12 01:55:15	2020-08-12	12	[{"id_menu":3,"count":1}]	1810	delivery	5	17
115588	2020-08-12 01:56:57	2020-08-12	12	[{"id_menu":3,"count":1}]	40487	pick-up	0	12
115589	2020-08-12 02:00:45	2020-08-12	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	44291	delivery	5	36
115590	2020-08-12 02:02:53	2020-08-12	12	[{"id_menu":3,"count":1}]	9156	delivery	5	17
115591	2020-08-12 02:06:23	2020-08-12	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21544	delivery	5	35
115592	2020-08-12 02:08:06	2020-08-12	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	44257	delivery	5	36
115593	2020-08-12 02:12:10	2020-08-12	12	[{"id_menu":3,"count":1}]	44273	delivery	5	17
115594	2020-08-12 02:13:15	2020-08-12	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	41829	delivery	5	34
115595	2020-08-12 02:16:22	2020-08-12	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	30440	delivery	5	27
115596	2020-08-12 02:16:37	2020-08-12	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	36537	delivery	5	31
115597	2020-08-12 02:21:05	2020-08-12	14	[{"id_menu":2,"count":1}]	36468	pick-up	0	14
115598	2020-08-12 02:23:55	2020-08-12	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28816	delivery	5	37
115599	2020-08-12 02:23:58	2020-08-12	9	[{"id_menu":7,"count":1}]	36063	delivery	5	14
115600	2020-08-12 02:25:09	2020-08-12	12	[{"id_menu":1,"count":1}]	32355	delivery	5	17
115601	2020-08-12 02:26:10	2020-08-12	9	[{"id_menu":6,"count":1}]	44252	delivery	5	14
115602	2020-08-12 02:27:43	2020-08-12	12	[{"id_menu":3,"count":1}]	41557	delivery	5	17
115603	2020-08-12 02:28:03	2020-08-12	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	9565	delivery	5	26
115604	2020-08-12 02:29:28	2020-08-12	12	[{"id_menu":1,"count":2}]	23830	pick-up	0	12
115605	2020-08-12 02:30:40	2020-08-12	8	[{"id_menu":5,"count":1}]	5481	delivery	5	13
115606	2020-08-12 02:33:05	2020-08-12	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	44341	delivery	5	30
115607	2020-08-12 02:34:07	2020-08-12	8	[{"id_menu":5,"count":1}]	33936	delivery	5	13
115608	2020-08-12 02:36:38	2020-08-12	9	[{"id_menu":7,"count":1}]	15026	pick-up	0	9
115609	2020-08-12 02:40:11	2020-08-12	17	[{"id_menu":4,"count":1}]	26232	pick-up	0	17
115610	2020-08-12 02:41:15	2020-08-12	12	[{"id_menu":1,"count":1}]	44334	delivery	5	17
115611	2020-08-12 02:45:43	2020-08-12	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	44248	delivery	5	39
115612	2020-08-12 02:47:05	2020-08-12	9	[{"id_menu":6,"count":1}]	28655	delivery	5	14
115613	2020-08-12 02:47:48	2020-08-12	9	[{"id_menu":6,"count":1}]	11739	delivery	5	14
115614	2020-08-12 02:49:20	2020-08-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43135	delivery	5	23
115615	2020-08-12 02:52:05	2020-08-12	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	5194	pick-up	0	29
115616	2020-08-12 02:52:26	2020-08-12	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	44200	delivery	5	53
115617	2020-08-12 02:56:23	2020-08-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39627	delivery	5	23
115618	2020-08-12 02:57:09	2020-08-12	8	[{"id_menu":5,"count":1}]	34105	delivery	5	13
115619	2020-08-12 02:58:27	2020-08-12	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	44421	delivery	5	51
115620	2020-08-12 03:00:23	2020-08-12	8	[{"id_menu":5,"count":1}]	2172	delivery	5	13
115621	2020-08-12 03:04:38	2020-08-12	14	[{"id_menu":2,"count":1}]	2604	delivery	5	19
115622	2020-08-12 03:04:53	2020-08-12	9	[{"id_menu":7,"count":1}]	40374	pick-up	0	9
115623	2020-08-12 03:08:22	2020-08-12	17	[{"id_menu":4,"count":1}]	24796	delivery	5	22
115624	2020-08-12 03:14:52	2020-08-12	17	[{"id_menu":4,"count":1}]	16593	delivery	5	22
115625	2020-08-12 03:15:07	2020-08-12	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	32324	delivery	5	36
115626	2020-08-12 03:16:44	2020-08-12	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	44386	pick-up	0	21
115627	2020-08-12 03:18:13	2020-08-12	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	39294	delivery	5	36
115628	2020-08-12 03:23:21	2020-08-12	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	2272	delivery	5	34
115629	2020-08-12 03:23:22	2020-08-12	9	[{"id_menu":7,"count":1}]	19908	delivery	5	14
115630	2020-08-12 03:23:34	2020-08-12	9	[{"id_menu":6,"count":1}]	44326	delivery	5	14
115631	2020-08-12 03:25:13	2020-08-12	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	39021	delivery	5	27
115632	2020-08-12 03:25:44	2020-08-12	17	[{"id_menu":4,"count":1}]	13391	pick-up	0	17
115633	2020-08-12 03:28:26	2020-08-12	14	[{"id_menu":2,"count":1}]	44374	delivery	5	19
115634	2020-08-12 03:29:18	2020-08-12	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	18409	pick-up	0	43
115635	2020-08-12 03:34:26	2020-08-12	12	[{"id_menu":3,"count":1}]	39683	delivery	5	17
115636	2020-08-12 03:36:19	2020-08-12	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	44393	delivery	5	34
115637	2020-08-12 03:38:00	2020-08-12	12	[{"id_menu":3,"count":1}]	36784	delivery	5	17
115638	2020-08-12 03:45:48	2020-08-12	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	44402	delivery	5	56
115639	2020-08-12 03:45:53	2020-08-12	9	[{"id_menu":6,"count":2}]	20494	delivery	5	14
115640	2020-08-12 03:54:18	2020-08-12	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	44244	delivery	5	28
115641	2020-08-12 03:56:37	2020-08-12	12	[{"id_menu":1,"count":1}]	13459	delivery	5	17
115642	2020-08-12 03:57:51	2020-08-12	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	44214	delivery	5	35
115643	2020-08-12 04:04:29	2020-08-12	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2418	delivery	5	31
115644	2020-08-12 04:05:33	2020-08-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9040	pick-up	0	17
115645	2020-08-12 04:05:48	2020-08-12	9	[{"id_menu":7,"count":1}]	19287	pick-up	0	9
115646	2020-08-12 04:05:55	2020-08-12	17	[{"id_menu":4,"count":1}]	44212	delivery	5	22
115647	2020-08-12 04:06:25	2020-08-12	8	[{"id_menu":5,"count":1}]	44294	delivery	5	13
115648	2020-08-12 04:07:27	2020-08-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	44290	delivery	5	28
115649	2020-08-12 04:10:18	2020-08-12	17	[{"id_menu":4,"count":1}]	44227	delivery	5	22
115650	2020-08-12 04:12:19	2020-08-12	8	[{"id_menu":5,"count":1}]	39238	pick-up	0	8
115651	2020-08-12 04:14:39	2020-08-12	9	[{"id_menu":7,"count":1}]	33192	delivery	5	14
115652	2020-08-12 04:14:51	2020-08-12	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	25337	pick-up	0	31
115653	2020-08-12 04:18:15	2020-08-12	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44309	delivery	5	35
115654	2020-08-12 04:19:15	2020-08-12	9	[{"id_menu":7,"count":1}]	31703	pick-up	0	9
115655	2020-08-12 04:19:43	2020-08-12	9	[{"id_menu":6,"count":1}]	44356	delivery	5	14
115656	2020-08-12 04:23:23	2020-08-12	14	[{"id_menu":2,"count":1}]	27895	delivery	5	19
115657	2020-08-12 04:24:59	2020-08-12	9	[{"id_menu":7,"count":1}]	36674	pick-up	0	9
115658	2020-08-12 04:25:00	2020-08-12	9	[{"id_menu":6,"count":1}]	4239	delivery	5	14
115659	2020-08-12 04:28:30	2020-08-12	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	36542	delivery	5	48
115660	2020-08-12 04:28:41	2020-08-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	44220	pick-up	0	23
115661	2020-08-12 04:29:20	2020-08-12	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	19035	delivery	5	36
115662	2020-08-12 04:33:48	2020-08-12	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	21134	delivery	5	34
115663	2020-08-12 04:36:22	2020-08-12	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	39581	delivery	5	22
115664	2020-08-12 04:36:52	2020-08-12	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	18316	pick-up	0	21
115665	2020-08-12 04:37:30	2020-08-12	9	[{"id_menu":6,"count":2}]	32636	delivery	5	14
115666	2020-08-12 04:38:42	2020-08-12	9	[{"id_menu":7,"count":1}]	24001	delivery	5	14
115667	2020-08-12 04:39:06	2020-08-12	12	[{"id_menu":1,"count":1}]	44364	delivery	5	17
115668	2020-08-12 04:39:55	2020-08-12	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3659	pick-up	0	26
115669	2020-08-12 04:40:33	2020-08-12	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	43331	delivery	5	36
115670	2020-08-12 04:40:35	2020-08-12	12	[{"id_menu":3,"count":1}]	26197	delivery	5	17
115671	2020-08-12 04:41:09	2020-08-12	8	[{"id_menu":5,"count":2}]	26746	pick-up	0	8
115672	2020-08-12 04:41:22	2020-08-12	17	[{"id_menu":4,"count":1}]	27219	delivery	5	22
115673	2020-08-12 04:41:37	2020-08-12	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	44213	delivery	5	39
115674	2020-08-12 04:42:00	2020-08-12	14	[{"id_menu":2,"count":1}]	2659	pick-up	0	14
115675	2020-08-12 04:46:33	2020-08-12	8	[{"id_menu":5,"count":1}]	506	pick-up	0	8
115676	2020-08-12 04:48:17	2020-08-12	9	[{"id_menu":6,"count":1}]	44266	delivery	5	14
115677	2020-08-12 04:48:37	2020-08-12	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	7227	delivery	5	31
115678	2020-08-12 04:49:20	2020-08-12	12	[{"id_menu":3,"count":1}]	24890	delivery	5	17
115679	2020-08-12 04:50:52	2020-08-12	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	44435	delivery	5	22
115680	2020-08-12 04:54:30	2020-08-12	12	[{"id_menu":3,"count":1}]	27516	delivery	5	17
115681	2020-08-12 04:55:18	2020-08-12	9	[{"id_menu":6,"count":1}]	33376	delivery	5	14
115682	2020-08-12 04:56:13	2020-08-12	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	17053	delivery	5	34
115683	2020-08-12 04:56:27	2020-08-12	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	15572	delivery	5	31
115684	2020-08-12 04:57:59	2020-08-12	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	44196	pick-up	0	25
115685	2020-08-12 04:58:08	2020-08-12	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	24614	delivery	5	35
115686	2020-08-12 05:01:53	2020-08-12	20	[{"id_menu":1,"count":3},{"id_menu":5,"count":1}]	17342	delivery	5	25
115687	2020-08-12 05:03:10	2020-08-12	34	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	44338	delivery	5	39
115688	2020-08-12 05:03:14	2020-08-12	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	6591	delivery	5	26
115689	2020-08-12 05:03:53	2020-08-12	17	[{"id_menu":4,"count":1}]	23141	delivery	5	22
115690	2020-08-12 05:04:19	2020-08-12	17	[{"id_menu":4,"count":1}]	44263	delivery	5	22
115691	2020-08-12 05:06:36	2020-08-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	12305	delivery	5	28
115692	2020-08-12 05:10:52	2020-08-12	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5549	delivery	5	36
115693	2020-08-12 05:11:43	2020-08-12	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	44197	delivery	5	39
115694	2020-08-12 05:13:17	2020-08-12	9	[{"id_menu":7,"count":1}]	38534	delivery	5	14
115695	2020-08-12 05:21:30	2020-08-12	9	[{"id_menu":6,"count":1}]	34935	delivery	5	14
115696	2020-08-12 05:24:02	2020-08-12	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	44280	delivery	5	26
115697	2020-08-12 05:24:30	2020-08-12	9	[{"id_menu":7,"count":1}]	12729	delivery	5	14
115698	2020-08-12 05:24:55	2020-08-12	39	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	34155	delivery	5	44
115699	2020-08-12 05:25:20	2020-08-12	12	[{"id_menu":3,"count":1}]	29968	delivery	5	17
115700	2020-08-12 05:26:54	2020-08-12	17	[{"id_menu":4,"count":1}]	1387	delivery	5	22
115701	2020-08-12 05:27:36	2020-08-12	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	35234	delivery	5	55
115702	2020-08-12 05:28:06	2020-08-12	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	40131	delivery	5	36
115703	2020-08-12 05:30:09	2020-08-12	14	[{"id_menu":2,"count":1}]	44256	delivery	5	19
115704	2020-08-12 05:30:23	2020-08-12	14	[{"id_menu":2,"count":1}]	35808	pick-up	0	14
115705	2020-08-12 05:31:33	2020-08-12	8	[{"id_menu":5,"count":1}]	44281	delivery	5	13
115706	2020-08-12 05:33:30	2020-08-12	12	[{"id_menu":1,"count":1}]	8340	delivery	5	17
115707	2020-08-12 05:34:21	2020-08-12	12	[{"id_menu":1,"count":1}]	44362	delivery	5	17
115708	2020-08-12 05:35:01	2020-08-12	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	11688	delivery	5	34
115709	2020-08-12 05:35:19	2020-08-12	9	[{"id_menu":6,"count":1}]	25877	delivery	5	14
115710	2020-08-12 05:36:40	2020-08-12	12	[{"id_menu":1,"count":1}]	25498	delivery	5	17
115711	2020-08-12 05:36:47	2020-08-12	9	[{"id_menu":6,"count":1}]	2613	delivery	5	14
115712	2020-08-12 05:40:04	2020-08-12	12	[{"id_menu":1,"count":1}]	44238	delivery	5	17
115713	2020-08-12 05:40:36	2020-08-12	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11177	delivery	5	22
115714	2020-08-12 05:42:47	2020-08-12	9	[{"id_menu":7,"count":1}]	13091	delivery	5	14
115715	2020-08-12 05:43:01	2020-08-12	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	43957	delivery	5	28
115716	2020-08-12 05:44:35	2020-08-12	12	[{"id_menu":3,"count":2}]	44210	pick-up	0	12
115717	2020-08-12 05:47:02	2020-08-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	44249	delivery	5	28
115718	2020-08-12 05:47:26	2020-08-12	14	[{"id_menu":2,"count":1}]	43723	delivery	5	19
115719	2020-08-12 05:57:18	2020-08-12	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	26690	delivery	5	31
115720	2020-08-12 05:59:35	2020-08-12	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8161	pick-up	0	17
115721	2020-08-12 05:59:58	2020-08-12	9	[{"id_menu":7,"count":1}]	44207	pick-up	0	9
115722	2020-08-12 06:01:50	2020-08-12	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	11769	delivery	5	31
115723	2020-08-12 06:03:22	2020-08-12	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	44394	delivery	5	46
115724	2020-08-12 06:06:04	2020-08-12	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	16813	pick-up	0	23
115725	2020-08-12 06:07:16	2020-08-12	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	19889	delivery	5	31
115726	2020-08-12 06:10:45	2020-08-12	12	[{"id_menu":1,"count":1}]	32571	delivery	5	17
115727	2020-08-12 06:14:43	2020-08-12	14	[{"id_menu":2,"count":1}]	30468	delivery	5	19
115728	2020-08-12 06:14:59	2020-08-12	17	[{"id_menu":4,"count":1}]	41546	pick-up	0	17
115729	2020-08-12 06:19:37	2020-08-12	12	[{"id_menu":1,"count":1}]	28440	pick-up	0	12
115730	2020-08-12 06:19:53	2020-08-12	9	[{"id_menu":6,"count":1}]	5015	pick-up	0	9
115731	2020-08-12 06:20:40	2020-08-12	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13486	delivery	5	43
115732	2020-08-12 06:21:02	2020-08-12	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	44219	delivery	5	46
115733	2020-08-12 06:22:40	2020-08-12	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	44360	delivery	5	31
115734	2020-08-12 06:29:55	2020-08-12	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	27140	delivery	5	22
115735	2020-08-12 06:30:38	2020-08-12	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	38574	delivery	5	39
115736	2020-08-12 06:32:08	2020-08-12	9	[{"id_menu":7,"count":1}]	21460	delivery	5	14
115737	2020-08-12 06:34:34	2020-08-12	9	[{"id_menu":6,"count":1}]	10670	delivery	5	14
115738	2020-08-12 06:34:56	2020-08-12	14	[{"id_menu":2,"count":1}]	6511	pick-up	0	14
115739	2020-08-12 06:37:34	2020-08-12	12	[{"id_menu":3,"count":1}]	44250	delivery	5	17
115740	2020-08-12 06:40:35	2020-08-12	9	[{"id_menu":6,"count":1}]	13561	delivery	5	14
115741	2020-08-12 06:40:56	2020-08-12	17	[{"id_menu":4,"count":1}]	37903	delivery	5	22
115742	2020-08-12 06:43:14	2020-08-12	9	[{"id_menu":6,"count":1}]	1193	pick-up	0	9
115743	2020-08-12 06:44:37	2020-08-12	8	[{"id_menu":5,"count":1}]	44398	delivery	5	13
115744	2020-08-12 06:46:55	2020-08-12	8	[{"id_menu":5,"count":2}]	44422	delivery	5	13
115745	2020-08-12 06:48:50	2020-08-12	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	44390	delivery	5	40
115746	2020-08-12 06:53:01	2020-08-12	17	[{"id_menu":4,"count":1}]	44223	pick-up	0	17
115747	2020-08-12 06:53:23	2020-08-12	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	33231	delivery	5	36
115748	2020-08-12 06:53:32	2020-08-12	12	[{"id_menu":1,"count":1}]	25064	delivery	5	17
115749	2020-08-12 06:55:06	2020-08-12	12	[{"id_menu":1,"count":1}]	2511	pick-up	0	12
115750	2020-08-12 06:55:20	2020-08-12	8	[{"id_menu":5,"count":1}]	16926	pick-up	0	8
115751	2020-08-12 07:00:26	2020-08-12	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2443	pick-up	0	26
115752	2020-08-12 07:00:45	2020-08-12	8	[{"id_menu":5,"count":1}]	44405	delivery	5	13
115753	2020-08-12 07:01:02	2020-08-12	8	[{"id_menu":5,"count":1}]	44241	delivery	5	13
115754	2020-08-12 07:04:14	2020-08-12	9	[{"id_menu":6,"count":1}]	44412	delivery	5	14
115755	2020-08-12 07:04:33	2020-08-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44315	delivery	5	23
115756	2020-08-12 07:05:33	2020-08-12	17	[{"id_menu":4,"count":1}]	44310	delivery	5	22
115757	2020-08-12 07:09:45	2020-08-12	9	[{"id_menu":7,"count":1}]	37097	pick-up	0	9
115758	2020-08-12 07:10:32	2020-08-12	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	44336	delivery	5	36
115759	2020-08-12 07:12:14	2020-08-12	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7591	pick-up	0	25
115760	2020-08-12 07:13:25	2020-08-12	17	[{"id_menu":4,"count":1}]	44226	delivery	5	22
115761	2020-08-12 07:19:02	2020-08-12	9	[{"id_menu":7,"count":1}]	34467	delivery	5	14
115762	2020-08-12 07:20:22	2020-08-12	8	[{"id_menu":5,"count":1}]	30635	delivery	5	13
115763	2020-08-12 07:22:05	2020-08-12	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	36029	pick-up	0	29
115764	2020-08-12 07:22:49	2020-08-12	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44434	delivery	5	37
115765	2020-08-12 07:23:08	2020-08-12	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	44372	delivery	5	25
115766	2020-08-12 07:23:24	2020-08-12	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	44247	delivery	5	36
115767	2020-08-12 07:25:07	2020-08-12	14	[{"id_menu":2,"count":1}]	7710	pick-up	0	14
115768	2020-08-12 07:29:04	2020-08-12	17	[{"id_menu":4,"count":1}]	39107	delivery	5	22
115769	2020-08-12 07:35:53	2020-08-12	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3451	delivery	5	36
115770	2020-08-12 07:37:12	2020-08-12	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	638	delivery	5	29
115771	2020-08-12 07:37:42	2020-08-12	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	12290	delivery	5	22
115772	2020-08-12 07:42:38	2020-08-12	17	[{"id_menu":4,"count":1}]	35096	pick-up	0	17
115773	2020-08-12 07:43:11	2020-08-12	9	[{"id_menu":7,"count":1}]	44416	delivery	5	14
115774	2020-08-12 07:46:16	2020-08-12	17	[{"id_menu":4,"count":1}]	37613	delivery	5	22
115775	2020-08-12 07:46:40	2020-08-12	17	[{"id_menu":4,"count":1}]	44369	delivery	5	22
115776	2020-08-12 07:49:09	2020-08-12	30	[{"id_menu":1,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27517	delivery	5	35
115777	2020-08-12 07:50:12	2020-08-12	12	[{"id_menu":1,"count":1}]	44265	delivery	5	17
115778	2020-08-12 07:54:17	2020-08-12	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25731	delivery	5	51
115779	2020-08-12 07:57:23	2020-08-12	12	[{"id_menu":3,"count":1}]	23949	delivery	5	17
115780	2020-08-12 07:58:45	2020-08-12	9	[{"id_menu":6,"count":1}]	25692	delivery	5	14
115781	2020-08-12 07:59:08	2020-08-12	9	[{"id_menu":7,"count":1}]	44067	delivery	5	14
115782	2020-08-12 07:59:31	2020-08-12	14	[{"id_menu":2,"count":1}]	14764	delivery	5	19
115783	2020-08-12 07:59:58	2020-08-12	17	[{"id_menu":4,"count":1}]	5704	delivery	5	22
115784	2020-08-12 08:02:47	2020-08-12	9	[{"id_menu":7,"count":1}]	43604	delivery	5	14
115785	2020-08-12 08:04:37	2020-08-12	14	[{"id_menu":2,"count":1}]	18666	delivery	5	19
115786	2020-08-12 08:07:25	2020-08-12	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	23727	delivery	5	38
115787	2020-08-12 08:08:46	2020-08-12	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3024	pick-up	0	22
115788	2020-08-12 08:10:33	2020-08-12	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	16127	pick-up	0	22
115789	2020-08-12 08:15:45	2020-08-12	9	[{"id_menu":6,"count":1}]	40467	delivery	5	14
115790	2020-08-12 08:16:03	2020-08-12	12	[{"id_menu":1,"count":1}]	333	pick-up	0	12
115791	2020-08-12 08:17:10	2020-08-12	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	2184	pick-up	0	24
115792	2020-08-12 08:18:31	2020-08-12	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	33851	delivery	5	34
115793	2020-08-12 08:21:44	2020-08-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	26955	pick-up	0	23
115794	2020-08-12 08:30:50	2020-08-12	12	[{"id_menu":1,"count":1}]	7041	delivery	5	17
115795	2020-08-12 08:35:26	2020-08-12	9	[{"id_menu":7,"count":2}]	25529	delivery	5	14
115796	2020-08-12 08:37:40	2020-08-12	8	[{"id_menu":5,"count":1}]	37828	delivery	5	13
115797	2020-08-12 08:40:34	2020-08-12	8	[{"id_menu":5,"count":1}]	44253	delivery	5	13
115798	2020-08-12 08:41:55	2020-08-12	14	[{"id_menu":2,"count":1}]	21290	delivery	5	19
115799	2020-08-12 08:43:06	2020-08-12	8	[{"id_menu":5,"count":1}]	22627	delivery	5	13
115800	2020-08-12 08:44:09	2020-08-12	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	9330	delivery	5	29
115801	2020-08-12 08:45:30	2020-08-12	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	44413	delivery	5	29
115802	2020-08-12 08:46:12	2020-08-12	14	[{"id_menu":2,"count":1}]	24248	delivery	5	19
115803	2020-08-12 08:47:17	2020-08-12	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	14862	delivery	5	46
115804	2020-08-12 08:47:52	2020-08-12	14	[{"id_menu":2,"count":1}]	44361	delivery	5	19
115805	2020-08-12 08:48:04	2020-08-12	9	[{"id_menu":6,"count":1}]	7734	delivery	5	14
115806	2020-08-12 08:53:19	2020-08-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	35373	delivery	5	22
115807	2020-08-12 08:53:32	2020-08-12	12	[{"id_menu":1,"count":1}]	18057	pick-up	0	12
115808	2020-08-12 08:57:00	2020-08-12	9	[{"id_menu":6,"count":1}]	44246	delivery	5	14
115809	2020-08-12 08:57:17	2020-08-12	14	[{"id_menu":2,"count":1}]	44297	delivery	5	19
115810	2020-08-12 08:58:21	2020-08-12	14	[{"id_menu":2,"count":1}]	41249	delivery	5	19
115811	2020-08-12 09:03:32	2020-08-12	9	[{"id_menu":7,"count":1}]	16923	delivery	5	14
115812	2020-08-12 09:04:11	2020-08-12	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	40713	delivery	5	31
115813	2020-08-12 09:06:47	2020-08-12	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	15118	delivery	5	44
115814	2020-08-12 09:10:33	2020-08-12	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	25275	delivery	5	26
115815	2020-08-12 09:14:10	2020-08-12	17	[{"id_menu":4,"count":3}]	28884	pick-up	0	17
115816	2020-08-12 09:14:42	2020-08-12	12	[{"id_menu":1,"count":1}]	44432	delivery	5	17
115817	2020-08-12 09:19:36	2020-08-12	9	[{"id_menu":7,"count":2}]	14257	delivery	5	14
115818	2020-08-12 09:20:24	2020-08-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	32901	pick-up	0	23
115819	2020-08-12 09:22:52	2020-08-12	12	[{"id_menu":1,"count":1}]	3558	delivery	5	17
115820	2020-08-12 09:23:16	2020-08-12	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	44340	delivery	5	31
115821	2020-08-12 09:28:37	2020-08-12	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	35838	delivery	5	31
115822	2020-08-12 09:31:19	2020-08-12	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	6644	pick-up	0	40
115823	2020-08-12 09:31:36	2020-08-12	8	[{"id_menu":5,"count":1}]	44367	delivery	5	13
115824	2020-08-12 09:31:37	2020-08-12	9	[{"id_menu":7,"count":1}]	5019	pick-up	0	9
115825	2020-08-12 09:33:18	2020-08-12	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	21493	delivery	5	26
115826	2020-08-12 09:36:03	2020-08-12	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	12185	delivery	5	52
115827	2020-08-12 09:36:13	2020-08-12	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	44259	delivery	5	34
115828	2020-08-12 09:36:56	2020-08-12	14	[{"id_menu":2,"count":1}]	22170	delivery	5	19
115829	2020-08-12 09:38:01	2020-08-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	36375	delivery	5	28
115830	2020-08-12 09:40:49	2020-08-12	14	[{"id_menu":2,"count":1}]	44384	delivery	5	19
115831	2020-08-12 09:42:26	2020-08-12	9	[{"id_menu":6,"count":1}]	44306	pick-up	0	9
115832	2020-08-12 09:42:30	2020-08-12	14	[{"id_menu":2,"count":1}]	23724	pick-up	0	14
115833	2020-08-12 09:45:25	2020-08-12	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	44304	delivery	5	30
115834	2020-08-12 09:45:35	2020-08-12	9	[{"id_menu":7,"count":1}]	23867	delivery	5	14
115835	2020-08-12 09:59:21	2020-08-12	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	7509	delivery	5	27
115836	2020-08-12 09:59:27	2020-08-12	17	[{"id_menu":4,"count":1}]	131	pick-up	0	17
115837	2020-08-12 10:01:05	2020-08-12	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	33648	delivery	5	38
115838	2020-08-12 10:02:31	2020-08-12	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	44288	delivery	5	23
115839	2020-08-12 10:03:02	2020-08-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	4735	delivery	5	28
115840	2020-08-12 10:03:07	2020-08-12	14	[{"id_menu":2,"count":1}]	44293	delivery	5	19
115841	2020-08-12 10:04:11	2020-08-12	14	[{"id_menu":2,"count":1}]	38773	pick-up	0	14
115842	2020-08-12 10:10:37	2020-08-12	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	26341	delivery	5	36
115843	2020-08-12 10:13:25	2020-08-12	17	[{"id_menu":4,"count":1}]	43015	delivery	5	22
115844	2020-08-12 10:16:07	2020-08-12	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	9180	delivery	5	40
115845	2020-08-12 10:16:14	2020-08-12	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44320	delivery	5	52
115846	2020-08-12 10:16:24	2020-08-12	9	[{"id_menu":7,"count":1}]	10676	delivery	5	14
115847	2020-08-12 10:16:25	2020-08-12	9	[{"id_menu":6,"count":1}]	1119	pick-up	0	9
115848	2020-08-12 10:20:54	2020-08-12	9	[{"id_menu":7,"count":1}]	4596	delivery	5	14
115849	2020-08-12 10:21:06	2020-08-12	9	[{"id_menu":7,"count":1}]	44236	delivery	5	14
115850	2020-08-12 10:22:23	2020-08-12	8	[{"id_menu":5,"count":1}]	28605	pick-up	0	8
115851	2020-08-12 10:23:44	2020-08-12	9	[{"id_menu":6,"count":1}]	33056	delivery	5	14
115852	2020-08-12 10:27:23	2020-08-12	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	44245	delivery	5	25
115853	2020-08-12 10:29:25	2020-08-12	9	[{"id_menu":6,"count":1}]	44343	delivery	5	14
115854	2020-08-12 10:32:05	2020-08-12	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	1846	delivery	5	25
115855	2020-08-12 10:34:35	2020-08-12	8	[{"id_menu":5,"count":1}]	44382	delivery	5	13
115856	2020-08-12 10:36:11	2020-08-12	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	787	pick-up	0	30
115857	2020-08-12 10:41:32	2020-08-12	9	[{"id_menu":7,"count":1}]	44391	delivery	5	14
115858	2020-08-12 10:43:26	2020-08-12	12	[{"id_menu":1,"count":1}]	25644	delivery	5	17
115859	2020-08-12 10:44:09	2020-08-12	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8918	delivery	5	31
115860	2020-08-12 10:49:12	2020-08-12	14	[{"id_menu":2,"count":1}]	17366	delivery	5	19
115861	2020-08-12 10:55:06	2020-08-12	9	[{"id_menu":6,"count":1}]	44410	delivery	5	14
115862	2020-08-12 10:56:49	2020-08-12	14	[{"id_menu":2,"count":1}]	1929	delivery	5	19
115863	2020-08-12 10:59:39	2020-08-12	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	9833	delivery	5	34
115864	2020-08-12 11:03:15	2020-08-12	9	[{"id_menu":7,"count":1}]	9128	pick-up	0	9
115865	2020-08-12 11:11:18	2020-08-12	9	[{"id_menu":7,"count":1}]	23809	delivery	5	14
115866	2020-08-12 11:12:22	2020-08-12	9	[{"id_menu":6,"count":1}]	33574	delivery	5	14
115867	2020-08-12 11:15:17	2020-08-12	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	491	pick-up	0	21
115868	2020-08-12 11:15:21	2020-08-12	9	[{"id_menu":6,"count":1}]	7842	delivery	5	14
115869	2020-08-12 11:16:26	2020-08-12	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	33632	delivery	5	51
115870	2020-08-12 11:16:51	2020-08-12	14	[{"id_menu":2,"count":1}]	42997	delivery	5	19
115871	2020-08-12 11:19:42	2020-08-12	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	44269	delivery	5	31
115872	2020-08-12 11:22:54	2020-08-12	9	[{"id_menu":7,"count":1}]	35807	delivery	5	14
115873	2020-08-12 11:24:43	2020-08-12	17	[{"id_menu":4,"count":1}]	18912	delivery	5	22
115874	2020-08-12 11:27:56	2020-08-12	14	[{"id_menu":2,"count":1}]	16592	pick-up	0	14
115875	2020-08-12 11:30:50	2020-08-12	17	[{"id_menu":4,"count":1}]	14558	delivery	5	22
115876	2020-08-12 11:33:39	2020-08-12	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	41216	pick-up	0	43
115877	2020-08-12 11:34:05	2020-08-12	17	[{"id_menu":4,"count":1}]	30981	pick-up	0	17
115878	2020-08-12 11:38:08	2020-08-12	9	[{"id_menu":7,"count":1}]	34342	delivery	5	14
115879	2020-08-12 11:38:13	2020-08-12	9	[{"id_menu":7,"count":1}]	26312	delivery	5	14
115880	2020-08-12 11:39:39	2020-08-12	9	[{"id_menu":6,"count":1}]	17088	delivery	5	14
115881	2020-08-12 11:39:55	2020-08-12	9	[{"id_menu":7,"count":1}]	44400	pick-up	0	9
115882	2020-08-12 11:40:29	2020-08-12	9	[{"id_menu":6,"count":1}]	44399	delivery	5	14
115883	2020-08-12 11:42:15	2020-08-12	9	[{"id_menu":7,"count":1}]	44404	delivery	5	14
115884	2020-08-12 11:43:23	2020-08-12	17	[{"id_menu":4,"count":1}]	24883	delivery	5	22
115885	2020-08-12 11:43:57	2020-08-12	14	[{"id_menu":2,"count":1}]	1406	pick-up	0	14
115886	2020-08-12 11:44:34	2020-08-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	44365	delivery	5	28
115887	2020-08-12 11:46:25	2020-08-12	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	172	pick-up	0	25
115888	2020-08-12 11:48:33	2020-08-12	9	[{"id_menu":7,"count":1}]	12474	delivery	5	14
115889	2020-08-12 11:49:09	2020-08-12	12	[{"id_menu":3,"count":1}]	44228	pick-up	0	12
115890	2020-08-12 11:53:29	2020-08-12	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	29164	delivery	5	45
115891	2020-08-12 11:57:09	2020-08-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	44292	delivery	5	23
115892	2020-08-12 11:58:04	2020-08-12	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3530	delivery	5	34
115893	2020-08-12 11:58:38	2020-08-12	8	[{"id_menu":5,"count":1}]	44268	delivery	5	13
115894	2020-08-12 12:01:18	2020-08-12	12	[{"id_menu":1,"count":1}]	1148	pick-up	0	12
115895	2020-08-12 12:06:08	2020-08-12	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	12016	delivery	5	40
115896	2020-08-12 12:12:55	2020-08-12	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	40833	delivery	5	35
115897	2020-08-12 12:17:30	2020-08-12	17	[{"id_menu":4,"count":2}]	8574	pick-up	0	17
115898	2020-08-12 12:23:19	2020-08-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	30230	delivery	5	31
115899	2020-08-12 12:24:24	2020-08-12	12	[{"id_menu":3,"count":1}]	44353	pick-up	0	12
115900	2020-08-12 12:26:13	2020-08-12	12	[{"id_menu":1,"count":1}]	11366	delivery	5	17
115901	2020-08-12 12:29:09	2020-08-12	9	[{"id_menu":7,"count":1}]	22650	delivery	5	14
115902	2020-08-12 12:30:31	2020-08-12	8	[{"id_menu":5,"count":1}]	10634	delivery	5	13
115903	2020-08-12 12:33:12	2020-08-12	12	[{"id_menu":3,"count":1}]	19119	delivery	5	17
115904	2020-08-12 12:35:28	2020-08-12	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	44419	delivery	5	35
115905	2020-08-12 12:39:31	2020-08-12	14	[{"id_menu":2,"count":1}]	1900	pick-up	0	14
115906	2020-08-12 12:40:01	2020-08-12	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	44193	delivery	5	28
115907	2020-08-12 12:46:16	2020-08-12	14	[{"id_menu":2,"count":1}]	14094	delivery	5	19
115908	2020-08-12 12:47:52	2020-08-12	17	[{"id_menu":4,"count":1}]	33798	pick-up	0	17
115909	2020-08-12 12:49:05	2020-08-12	12	[{"id_menu":3,"count":1}]	9920	pick-up	0	12
115910	2020-08-12 12:51:19	2020-08-12	30	[{"id_menu":1,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44203	delivery	5	35
115911	2020-08-12 12:51:32	2020-08-12	14	[{"id_menu":2,"count":1}]	44428	delivery	5	19
115912	2020-08-12 12:56:48	2020-08-12	9	[{"id_menu":7,"count":1}]	22964	delivery	5	14
115913	2020-08-12 13:03:45	2020-08-12	8	[{"id_menu":5,"count":1}]	17873	delivery	5	13
115914	2020-08-12 13:04:03	2020-08-12	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	44431	delivery	5	25
115915	2020-08-12 13:05:39	2020-08-12	12	[{"id_menu":3,"count":1}]	44420	pick-up	0	12
115916	2020-08-12 13:06:11	2020-08-12	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	14103	delivery	5	36
115917	2020-08-12 13:06:22	2020-08-12	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	44359	delivery	5	45
115918	2020-08-12 13:08:11	2020-08-12	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6694	delivery	5	35
115919	2020-08-12 13:09:46	2020-08-12	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	44430	delivery	5	43
115920	2020-08-12 13:11:43	2020-08-12	14	[{"id_menu":2,"count":2}]	36779	delivery	5	19
115921	2020-08-12 13:13:28	2020-08-12	9	[{"id_menu":6,"count":1}]	19876	delivery	5	14
115922	2020-08-12 13:14:07	2020-08-12	14	[{"id_menu":2,"count":1}]	24943	pick-up	0	14
115923	2020-08-12 13:16:06	2020-08-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	24678	delivery	5	22
115924	2020-08-12 13:17:41	2020-08-12	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	18364	delivery	5	31
115925	2020-08-12 13:17:53	2020-08-12	17	[{"id_menu":4,"count":1}]	1303	delivery	5	22
115926	2020-08-12 13:18:44	2020-08-12	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	44218	delivery	5	22
115927	2020-08-12 13:20:02	2020-08-12	12	[{"id_menu":3,"count":1}]	8956	pick-up	0	12
115928	2020-08-12 13:25:55	2020-08-12	9	[{"id_menu":6,"count":1}]	44401	delivery	5	14
115929	2020-08-12 13:28:04	2020-08-12	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	22556	delivery	5	35
115930	2020-08-12 13:30:49	2020-08-12	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	44216	delivery	5	42
115931	2020-08-12 13:35:55	2020-08-12	8	[{"id_menu":5,"count":1}]	44296	delivery	5	13
115932	2020-08-12 13:36:25	2020-08-12	9	[{"id_menu":6,"count":1}]	1104	pick-up	0	9
115933	2020-08-12 13:39:35	2020-08-12	8	[{"id_menu":5,"count":1}]	28515	pick-up	0	8
115934	2020-08-12 13:45:02	2020-08-12	8	[{"id_menu":5,"count":1}]	44305	delivery	5	13
115935	2020-08-12 13:45:32	2020-08-12	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	39777	delivery	5	25
115936	2020-08-12 13:47:17	2020-08-12	17	[{"id_menu":4,"count":1}]	43830	delivery	5	22
115937	2020-08-12 13:49:35	2020-08-12	14	[{"id_menu":2,"count":1}]	44354	delivery	5	19
115938	2020-08-12 13:51:29	2020-08-12	9	[{"id_menu":7,"count":1}]	1390	pick-up	0	9
115939	2020-08-12 13:53:35	2020-08-12	14	[{"id_menu":2,"count":3}]	6664	delivery	5	19
115940	2020-08-12 14:00:51	2020-08-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24235	delivery	5	22
115941	2020-08-12 14:01:34	2020-08-12	14	[{"id_menu":2,"count":1}]	19911	pick-up	0	14
115942	2020-08-12 14:01:53	2020-08-12	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	31015	delivery	5	30
115943	2020-08-12 14:02:32	2020-08-12	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	44319	delivery	5	22
115944	2020-08-12 14:03:33	2020-08-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	44286	delivery	5	31
115945	2020-08-12 14:05:55	2020-08-12	8	[{"id_menu":5,"count":1}]	44331	delivery	5	13
115946	2020-08-12 14:08:35	2020-08-12	12	[{"id_menu":3,"count":1}]	44330	pick-up	0	12
115947	2020-08-12 14:11:05	2020-08-12	9	[{"id_menu":6,"count":1}]	7764	delivery	5	14
115948	2020-08-12 14:11:50	2020-08-12	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	34551	delivery	5	27
115949	2020-08-12 14:13:02	2020-08-12	12	[{"id_menu":1,"count":1}]	44272	delivery	5	17
115950	2020-08-12 14:15:21	2020-08-12	17	[{"id_menu":4,"count":1}]	26361	delivery	5	22
115951	2020-08-12 14:24:31	2020-08-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	20711	delivery	5	22
115952	2020-08-12 14:26:15	2020-08-12	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	43678	delivery	5	22
115953	2020-08-12 14:28:11	2020-08-12	9	[{"id_menu":6,"count":1}]	44437	delivery	5	14
115954	2020-08-12 14:29:23	2020-08-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	44387	delivery	5	28
115955	2020-08-12 14:31:56	2020-08-12	17	[{"id_menu":4,"count":1}]	17361	delivery	5	22
115956	2020-08-12 14:33:27	2020-08-12	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	27661	pick-up	0	21
115957	2020-08-12 14:37:13	2020-08-12	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	40611	pick-up	0	23
115958	2020-08-12 14:38:48	2020-08-12	9	[{"id_menu":6,"count":1}]	44295	delivery	5	14
115959	2020-08-12 14:39:10	2020-08-12	12	[{"id_menu":3,"count":1}]	29915	delivery	5	17
115960	2020-08-12 14:39:40	2020-08-12	12	[{"id_menu":3,"count":1}]	15109	pick-up	0	12
115961	2020-08-12 14:40:55	2020-08-12	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	44230	delivery	5	25
115962	2020-08-12 14:41:07	2020-08-12	9	[{"id_menu":6,"count":1}]	44395	delivery	5	14
115963	2020-08-12 14:47:22	2020-08-12	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3122	delivery	5	43
115964	2020-08-12 14:47:37	2020-08-12	12	[{"id_menu":1,"count":1}]	9943	pick-up	0	12
115965	2020-08-12 14:51:51	2020-08-12	8	[{"id_menu":5,"count":1}]	44377	delivery	5	13
115966	2020-08-12 14:54:22	2020-08-12	9	[{"id_menu":7,"count":1}]	1889	pick-up	0	9
115967	2020-08-12 14:54:43	2020-08-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	5238	pick-up	0	23
115968	2020-08-12 14:58:59	2020-08-12	8	[{"id_menu":5,"count":1}]	10101	delivery	5	13
115969	2020-08-12 14:59:26	2020-08-12	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24186	delivery	5	31
115970	2020-08-12 15:01:00	2020-08-12	14	[{"id_menu":2,"count":1}]	3461	pick-up	0	14
115971	2020-08-12 15:01:04	2020-08-12	17	[{"id_menu":4,"count":1}]	12355	delivery	5	22
115972	2020-08-12 15:01:29	2020-08-12	12	[{"id_menu":3,"count":1}]	25819	delivery	5	17
115973	2020-08-12 15:03:00	2020-08-12	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	44302	delivery	5	31
115974	2020-08-12 15:04:08	2020-08-12	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	27426	delivery	5	22
115975	2020-08-12 15:07:04	2020-08-12	17	[{"id_menu":4,"count":1}]	23494	pick-up	0	17
115976	2020-08-12 15:07:41	2020-08-12	8	[{"id_menu":5,"count":1}]	44373	delivery	5	13
115977	2020-08-12 15:15:47	2020-08-12	17	[{"id_menu":4,"count":1}]	27187	delivery	5	22
115978	2020-08-12 15:18:03	2020-08-12	9	[{"id_menu":7,"count":1}]	36472	pick-up	0	9
115979	2020-08-12 15:18:48	2020-08-12	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7772	pick-up	0	30
115980	2020-08-12 15:19:18	2020-08-12	12	[{"id_menu":1,"count":1}]	44321	delivery	5	17
115981	2020-08-12 15:20:20	2020-08-12	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	44329	delivery	5	31
115982	2020-08-12 15:22:36	2020-08-12	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	44301	delivery	5	40
115983	2020-08-12 15:23:25	2020-08-12	9	[{"id_menu":7,"count":1}]	24329	delivery	5	14
115984	2020-08-12 15:29:44	2020-08-12	9	[{"id_menu":6,"count":1}]	8798	delivery	5	14
115985	2020-08-12 15:33:27	2020-08-12	8	[{"id_menu":5,"count":2}]	44287	delivery	5	13
115986	2020-08-12 15:35:32	2020-08-12	9	[{"id_menu":6,"count":1}]	15	pick-up	0	9
115987	2020-08-12 15:35:49	2020-08-12	14	[{"id_menu":2,"count":1}]	14559	delivery	5	19
115988	2020-08-12 15:37:23	2020-08-12	8	[{"id_menu":5,"count":1}]	14591	delivery	5	13
115989	2020-08-12 15:38:10	2020-08-12	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	27488	delivery	5	22
115990	2020-08-12 15:41:12	2020-08-12	17	[{"id_menu":4,"count":1}]	43995	delivery	5	22
115991	2020-08-12 15:43:52	2020-08-12	8	[{"id_menu":5,"count":1}]	39721	delivery	5	13
115992	2020-08-12 15:48:00	2020-08-12	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	44345	delivery	5	40
115993	2020-08-12 15:48:17	2020-08-12	8	[{"id_menu":5,"count":1}]	38512	delivery	5	13
115994	2020-08-12 15:51:07	2020-08-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44289	delivery	5	23
115995	2020-08-12 15:51:41	2020-08-12	9	[{"id_menu":6,"count":1}]	16096	delivery	5	14
115996	2020-08-12 15:56:30	2020-08-12	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44298	delivery	5	48
115997	2020-08-12 15:57:12	2020-08-12	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	25880	pick-up	0	43
115998	2020-08-12 15:59:11	2020-08-12	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	11557	delivery	5	31
115999	2020-08-12 16:01:57	2020-08-12	9	[{"id_menu":7,"count":1}]	15472	delivery	5	14
116000	2020-08-12 16:05:56	2020-08-12	8	[{"id_menu":5,"count":3}]	31658	delivery	5	13
116001	2020-08-12 16:08:29	2020-08-12	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	18488	pick-up	0	21
116002	2020-08-12 16:10:49	2020-08-12	12	[{"id_menu":3,"count":1}]	44316	delivery	5	17
116003	2020-08-12 16:12:06	2020-08-12	8	[{"id_menu":5,"count":1}]	14870	delivery	5	13
116004	2020-08-12 16:15:20	2020-08-12	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":3}]	15679	delivery	5	27
116005	2020-08-12 16:15:50	2020-08-12	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44371	delivery	5	35
116006	2020-08-12 16:16:29	2020-08-12	12	[{"id_menu":1,"count":1}]	44376	delivery	5	17
116007	2020-08-12 16:18:37	2020-08-12	12	[{"id_menu":3,"count":1}]	10019	delivery	5	17
116008	2020-08-12 16:22:10	2020-08-12	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	28970	delivery	5	45
116009	2020-08-12 16:23:46	2020-08-12	12	[{"id_menu":1,"count":1}]	39870	delivery	5	17
116010	2020-08-12 16:28:01	2020-08-12	12	[{"id_menu":1,"count":1}]	2195	pick-up	0	12
116011	2020-08-12 16:28:21	2020-08-12	12	[{"id_menu":1,"count":1}]	17329	pick-up	0	12
116012	2020-08-12 16:29:14	2020-08-12	12	[{"id_menu":1,"count":1}]	19129	pick-up	0	12
116013	2020-08-12 16:30:04	2020-08-12	17	[{"id_menu":4,"count":1}]	33348	delivery	5	22
116014	2020-08-12 16:32:43	2020-08-12	12	[{"id_menu":3,"count":1}]	3478	pick-up	0	12
116015	2020-08-12 16:34:47	2020-08-12	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	39454	delivery	5	39
116016	2020-08-12 16:36:07	2020-08-12	9	[{"id_menu":7,"count":1}]	39174	delivery	5	14
116017	2020-08-12 16:36:27	2020-08-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	21171	delivery	5	28
116018	2020-08-12 16:36:30	2020-08-12	17	[{"id_menu":4,"count":2}]	44275	delivery	5	22
116019	2020-08-12 16:37:36	2020-08-12	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	29632	delivery	5	39
116020	2020-08-12 16:40:18	2020-08-12	9	[{"id_menu":7,"count":1}]	36310	delivery	5	14
116021	2020-08-12 16:41:10	2020-08-12	9	[{"id_menu":7,"count":1}]	22349	delivery	5	14
116022	2020-08-12 16:41:25	2020-08-12	14	[{"id_menu":2,"count":1}]	31567	delivery	5	19
116023	2020-08-12 16:43:35	2020-08-12	9	[{"id_menu":7,"count":1}]	17493	delivery	5	14
116024	2020-08-12 16:49:04	2020-08-12	12	[{"id_menu":1,"count":1}]	24471	delivery	5	17
116025	2020-08-12 16:54:54	2020-08-12	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	22283	pick-up	0	21
116026	2020-08-12 16:56:23	2020-08-12	12	[{"id_menu":1,"count":1}]	44327	delivery	5	17
116027	2020-08-12 16:58:05	2020-08-12	9	[{"id_menu":7,"count":1}]	44328	delivery	5	14
116028	2020-08-12 16:58:20	2020-08-12	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	26210	delivery	5	26
116029	2020-08-12 17:00:43	2020-08-12	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	13950	pick-up	0	22
116030	2020-08-12 17:03:45	2020-08-12	9	[{"id_menu":6,"count":1}]	44335	delivery	5	14
116031	2020-08-12 17:03:53	2020-08-12	17	[{"id_menu":4,"count":1}]	43391	delivery	5	22
116032	2020-08-12 17:05:11	2020-08-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	13128	delivery	5	28
116033	2020-08-12 17:14:43	2020-08-12	9	[{"id_menu":6,"count":1}]	36451	delivery	5	14
116034	2020-08-12 17:16:27	2020-08-12	17	[{"id_menu":4,"count":1}]	44417	delivery	5	22
116035	2020-08-12 17:22:06	2020-08-12	14	[{"id_menu":2,"count":1}]	5921	delivery	5	19
116036	2020-08-12 17:23:11	2020-08-12	12	[{"id_menu":1,"count":1}]	2465	pick-up	0	12
116037	2020-08-12 17:23:12	2020-08-12	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	36830	delivery	5	34
116038	2020-08-12 17:24:23	2020-08-12	9	[{"id_menu":6,"count":1}]	34133	delivery	5	14
116039	2020-08-12 17:25:30	2020-08-12	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	44381	delivery	5	26
116040	2020-08-12 17:25:31	2020-08-12	9	[{"id_menu":7,"count":1}]	7966	delivery	5	14
116041	2020-08-12 17:26:09	2020-08-12	14	[{"id_menu":2,"count":1}]	38208	delivery	5	19
116042	2020-08-12 17:26:30	2020-08-12	9	[{"id_menu":6,"count":1}]	44397	delivery	5	14
116043	2020-08-12 17:28:40	2020-08-12	12	[{"id_menu":1,"count":1}]	3701	pick-up	0	12
116044	2020-08-12 17:31:20	2020-08-12	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	25206	delivery	5	43
116045	2020-08-12 17:31:32	2020-08-12	9	[{"id_menu":7,"count":2}]	30645	delivery	5	14
116046	2020-08-12 17:32:23	2020-08-12	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	20140	delivery	5	31
116047	2020-08-12 17:34:50	2020-08-12	8	[{"id_menu":5,"count":1}]	28377	pick-up	0	8
116048	2020-08-12 17:34:50	2020-08-12	12	[{"id_menu":1,"count":1}]	7834	delivery	5	17
116049	2020-08-12 17:35:32	2020-08-12	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	5972	delivery	5	26
116050	2020-08-12 17:37:29	2020-08-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	44346	delivery	5	28
116051	2020-08-12 17:40:45	2020-08-12	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	22380	delivery	5	39
116052	2020-08-12 17:49:26	2020-08-12	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4436	pick-up	0	38
116053	2020-08-12 17:51:34	2020-08-12	17	[{"id_menu":4,"count":1}]	30175	delivery	5	22
116054	2020-08-12 17:53:07	2020-08-12	14	[{"id_menu":2,"count":1}]	44221	delivery	5	19
116055	2020-08-12 17:55:23	2020-08-12	9	[{"id_menu":6,"count":1}]	44276	delivery	5	14
116056	2020-08-12 17:55:43	2020-08-12	9	[{"id_menu":6,"count":1}]	13806	pick-up	0	9
116057	2020-08-12 17:57:47	2020-08-12	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	44368	delivery	5	36
116058	2020-08-12 17:58:27	2020-08-12	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	19777	delivery	5	28
116059	2020-08-12 17:58:54	2020-08-12	14	[{"id_menu":2,"count":1}]	166	delivery	5	19
116060	2020-08-12 18:01:00	2020-08-12	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	23430	delivery	5	26
116061	2020-08-12 18:02:24	2020-08-12	12	[{"id_menu":3,"count":1}]	44229	delivery	5	17
116127	2020-08-12 20:36:46	2020-08-12	12	[{"id_menu":1,"count":1}]	40619	delivery	5	17
116062	2020-08-12 18:05:12	2020-08-12	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21392	delivery	5	47
116063	2020-08-12 18:05:58	2020-08-12	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	13473	pick-up	0	22
116064	2020-08-12 18:08:24	2020-08-12	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	748	delivery	5	28
116065	2020-08-12 18:08:44	2020-08-12	17	[{"id_menu":4,"count":1}]	20690	delivery	5	22
116066	2020-08-12 18:09:38	2020-08-12	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	22542	delivery	5	31
116067	2020-08-12 18:10:16	2020-08-12	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44271	delivery	5	40
116068	2020-08-12 18:12:45	2020-08-12	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4621	delivery	5	30
116069	2020-08-12 18:13:45	2020-08-12	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	24283	delivery	5	37
116070	2020-08-12 18:16:14	2020-08-12	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	14186	delivery	5	22
116071	2020-08-12 18:16:15	2020-08-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	44407	delivery	5	28
116072	2020-08-12 18:18:53	2020-08-12	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44433	delivery	5	48
116073	2020-08-12 18:24:51	2020-08-12	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	905	delivery	5	34
116074	2020-08-12 18:25:18	2020-08-12	14	[{"id_menu":2,"count":1}]	9716	pick-up	0	14
116075	2020-08-12 18:28:16	2020-08-12	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	43070	delivery	5	31
116076	2020-08-12 18:28:40	2020-08-12	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	44337	delivery	5	31
116077	2020-08-12 18:29:10	2020-08-12	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	39992	delivery	5	43
116078	2020-08-12 18:30:42	2020-08-12	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	27644	delivery	5	39
116079	2020-08-12 18:31:46	2020-08-12	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	31324	delivery	5	25
116080	2020-08-12 18:32:50	2020-08-12	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	44235	delivery	5	39
116081	2020-08-12 18:35:44	2020-08-12	17	[{"id_menu":4,"count":1}]	32597	delivery	5	22
116082	2020-08-12 18:36:03	2020-08-12	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2993	pick-up	0	29
116083	2020-08-12 18:36:34	2020-08-12	12	[{"id_menu":3,"count":1}]	44198	delivery	5	17
116084	2020-08-12 18:38:16	2020-08-12	8	[{"id_menu":5,"count":1}]	33829	delivery	5	13
116085	2020-08-12 18:38:31	2020-08-12	9	[{"id_menu":6,"count":1}]	44299	delivery	5	14
116086	2020-08-12 18:42:15	2020-08-12	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18271	delivery	5	31
116087	2020-08-12 18:43:00	2020-08-12	14	[{"id_menu":2,"count":1}]	34294	delivery	5	19
116088	2020-08-12 18:50:22	2020-08-12	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	5109	delivery	5	36
116089	2020-08-12 18:50:23	2020-08-12	14	[{"id_menu":2,"count":1}]	44333	delivery	5	19
116090	2020-08-12 18:55:30	2020-08-12	17	[{"id_menu":4,"count":1}]	1664	delivery	5	22
116091	2020-08-12 19:03:42	2020-08-12	9	[{"id_menu":7,"count":1}]	4003	delivery	5	14
116092	2020-08-12 19:04:35	2020-08-12	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17806	delivery	5	36
116093	2020-08-12 19:08:36	2020-08-12	9	[{"id_menu":7,"count":1}]	14364	pick-up	0	9
116094	2020-08-12 19:12:18	2020-08-12	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	44436	delivery	5	31
116095	2020-08-12 19:13:56	2020-08-12	8	[{"id_menu":5,"count":2}]	37218	delivery	5	13
116096	2020-08-12 19:14:21	2020-08-12	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	14280	delivery	5	25
116097	2020-08-12 19:14:32	2020-08-12	8	[{"id_menu":5,"count":1}]	40431	delivery	5	13
116098	2020-08-12 19:14:35	2020-08-12	9	[{"id_menu":6,"count":1}]	528	delivery	5	14
116099	2020-08-12 19:15:30	2020-08-12	9	[{"id_menu":7,"count":2}]	28159	delivery	5	14
116100	2020-08-12 19:23:58	2020-08-12	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	44274	delivery	5	23
116101	2020-08-12 19:24:46	2020-08-12	8	[{"id_menu":5,"count":1}]	9766	pick-up	0	8
116102	2020-08-12 19:28:04	2020-08-12	12	[{"id_menu":1,"count":1}]	17685	pick-up	0	12
116103	2020-08-12 19:28:14	2020-08-12	12	[{"id_menu":3,"count":1}]	39064	pick-up	0	12
116104	2020-08-12 19:30:48	2020-08-12	9	[{"id_menu":7,"count":1}]	12884	delivery	5	14
116105	2020-08-12 19:32:33	2020-08-12	14	[{"id_menu":2,"count":1}]	44342	pick-up	0	14
116106	2020-08-12 19:33:43	2020-08-12	9	[{"id_menu":7,"count":1}]	10140	pick-up	0	9
116107	2020-08-12 19:34:31	2020-08-12	12	[{"id_menu":3,"count":1}]	27077	delivery	5	17
116108	2020-08-12 19:35:01	2020-08-12	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":2}]	27206	delivery	5	22
116109	2020-08-12 19:44:45	2020-08-12	8	[{"id_menu":5,"count":1}]	44279	pick-up	0	8
116110	2020-08-12 19:46:26	2020-08-12	9	[{"id_menu":6,"count":1}]	9127	delivery	5	14
116111	2020-08-12 19:47:21	2020-08-12	17	[{"id_menu":4,"count":1}]	25646	delivery	5	22
116112	2020-08-12 19:54:25	2020-08-12	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1839	pick-up	0	21
116113	2020-08-12 19:57:52	2020-08-12	8	[{"id_menu":5,"count":1}]	13451	delivery	5	13
116114	2020-08-12 20:01:32	2020-08-12	8	[{"id_menu":5,"count":1}]	36075	delivery	5	13
116115	2020-08-12 20:02:14	2020-08-12	9	[{"id_menu":7,"count":1}]	11279	delivery	5	14
116116	2020-08-12 20:04:37	2020-08-12	14	[{"id_menu":2,"count":1}]	6877	delivery	5	19
116117	2020-08-12 20:09:36	2020-08-12	14	[{"id_menu":2,"count":3}]	29363	delivery	5	19
116118	2020-08-12 20:12:23	2020-08-12	9	[{"id_menu":6,"count":1}]	41852	delivery	5	14
116119	2020-08-12 20:14:47	2020-08-12	9	[{"id_menu":6,"count":1}]	12990	pick-up	0	9
116120	2020-08-12 20:17:59	2020-08-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	44242	delivery	5	22
116121	2020-08-12 20:26:31	2020-08-12	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1061	pick-up	0	24
116122	2020-08-12 20:29:16	2020-08-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	44426	delivery	5	28
116123	2020-08-12 20:31:32	2020-08-12	23	[{"id_menu":2,"count":3},{"id_menu":7,"count":1}]	14845	pick-up	0	23
116124	2020-08-12 20:33:00	2020-08-12	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	44205	delivery	5	34
116125	2020-08-12 20:33:46	2020-08-12	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	34448	delivery	5	30
116126	2020-08-12 20:36:36	2020-08-12	9	[{"id_menu":7,"count":1}]	44222	delivery	5	14
116128	2020-08-12 20:40:44	2020-08-12	9	[{"id_menu":7,"count":1}]	21387	pick-up	0	9
116129	2020-08-12 20:41:39	2020-08-12	12	[{"id_menu":3,"count":1}]	9688	pick-up	0	12
116130	2020-08-12 20:44:42	2020-08-12	17	[{"id_menu":4,"count":2}]	36277	delivery	5	22
116131	2020-08-12 20:51:04	2020-08-12	14	[{"id_menu":2,"count":2}]	16937	delivery	5	19
116132	2020-08-12 20:52:17	2020-08-12	8	[{"id_menu":5,"count":1}]	6789	pick-up	0	8
116133	2020-08-12 20:52:32	2020-08-12	9	[{"id_menu":6,"count":1}]	13393	delivery	5	14
116134	2020-08-12 20:55:07	2020-08-12	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15361	pick-up	0	26
116135	2020-08-12 20:55:45	2020-08-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	44378	delivery	5	23
116136	2020-08-12 20:57:43	2020-08-12	17	[{"id_menu":4,"count":1}]	44314	delivery	5	22
116137	2020-08-12 20:58:44	2020-08-12	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	18476	delivery	5	27
116138	2020-08-12 20:59:41	2020-08-12	12	[{"id_menu":1,"count":1}]	44308	delivery	5	17
116139	2020-08-12 21:03:29	2020-08-12	17	[{"id_menu":4,"count":1}]	11172	delivery	5	22
116140	2020-08-12 21:05:01	2020-08-12	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	26271	pick-up	0	17
116141	2020-08-12 21:08:47	2020-08-12	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	44322	pick-up	0	25
116142	2020-08-12 21:09:23	2020-08-12	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	44403	delivery	5	34
116143	2020-08-12 21:10:27	2020-08-12	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	44415	delivery	5	28
116144	2020-08-12 21:11:29	2020-08-12	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	9483	pick-up	0	31
116145	2020-08-12 21:12:22	2020-08-12	14	[{"id_menu":2,"count":1}]	11983	delivery	5	19
116146	2020-08-12 21:12:27	2020-08-12	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3991	delivery	5	37
116147	2020-08-12 21:12:51	2020-08-12	9	[{"id_menu":6,"count":1}]	21860	pick-up	0	9
116148	2020-08-12 21:14:10	2020-08-12	9	[{"id_menu":7,"count":1}]	44388	delivery	5	14
116149	2020-08-12 21:14:23	2020-08-12	14	[{"id_menu":2,"count":1}]	42073	delivery	5	19
116150	2020-08-12 21:14:42	2020-08-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	44283	delivery	5	31
116151	2020-08-12 21:17:26	2020-08-12	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6470	pick-up	0	26
116152	2020-08-12 21:19:26	2020-08-12	9	[{"id_menu":7,"count":1}]	38049	delivery	5	14
116153	2020-08-12 21:19:48	2020-08-12	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":2}]	44318	delivery	5	22
116154	2020-08-12 21:22:41	2020-08-12	8	[{"id_menu":5,"count":1}]	23699	delivery	5	13
116155	2020-08-12 21:23:40	2020-08-12	12	[{"id_menu":3,"count":1}]	21138	delivery	5	17
116156	2020-08-12 21:25:49	2020-08-12	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	20970	pick-up	0	21
116157	2020-08-12 21:28:16	2020-08-12	9	[{"id_menu":7,"count":1}]	39340	pick-up	0	9
116158	2020-08-12 21:31:16	2020-08-12	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	44349	delivery	5	39
116159	2020-08-12 21:31:29	2020-08-12	8	[{"id_menu":5,"count":1}]	8598	delivery	5	13
116160	2020-08-12 21:31:43	2020-08-12	9	[{"id_menu":7,"count":2}]	44380	delivery	5	14
116161	2020-08-12 21:32:11	2020-08-12	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	44424	delivery	5	31
116162	2020-08-12 21:32:29	2020-08-12	17	[{"id_menu":4,"count":1}]	31480	delivery	5	22
116163	2020-08-12 21:33:00	2020-08-12	12	[{"id_menu":3,"count":1}]	17963	delivery	5	17
116164	2020-08-12 21:34:15	2020-08-12	12	[{"id_menu":3,"count":1}]	44396	delivery	5	17
116165	2020-08-12 21:35:30	2020-08-12	9	[{"id_menu":6,"count":1}]	44215	delivery	5	14
116166	2020-08-12 21:36:02	2020-08-12	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44411	delivery	5	31
116167	2020-08-12 21:37:42	2020-08-12	17	[{"id_menu":4,"count":1}]	44224	delivery	5	22
116168	2020-08-12 21:40:46	2020-08-12	9	[{"id_menu":7,"count":1}]	7387	delivery	5	14
116169	2020-08-12 21:43:21	2020-08-12	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	35131	pick-up	0	21
116170	2020-08-12 21:46:27	2020-08-12	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	6296	delivery	5	22
116171	2020-08-12 21:48:54	2020-08-12	9	[{"id_menu":6,"count":1}]	11239	pick-up	0	9
116172	2020-08-12 21:49:04	2020-08-12	14	[{"id_menu":2,"count":1}]	18837	delivery	5	19
116173	2020-08-12 21:49:05	2020-08-12	8	[{"id_menu":5,"count":1}]	14002	pick-up	0	8
116174	2020-08-12 21:49:44	2020-08-12	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	44277	delivery	5	27
116175	2020-08-12 21:50:06	2020-08-12	9	[{"id_menu":6,"count":1}]	304	delivery	5	14
116176	2020-08-12 21:50:41	2020-08-12	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	35573	delivery	5	28
116177	2020-08-12 21:52:00	2020-08-12	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2329	pick-up	0	44
116178	2020-08-12 21:52:02	2020-08-12	9	[{"id_menu":7,"count":1}]	20780	pick-up	0	9
116179	2020-08-12 21:52:04	2020-08-12	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44209	delivery	5	48
116180	2020-08-12 21:54:45	2020-08-12	12	[{"id_menu":1,"count":1}]	15319	pick-up	0	12
116181	2020-08-12 21:56:07	2020-08-12	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	13424	delivery	5	28
116182	2020-08-12 22:00:27	2020-08-12	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	37950	delivery	5	36
116183	2020-08-12 22:02:39	2020-08-12	9	[{"id_menu":6,"count":1}]	37856	delivery	5	14
116184	2020-08-12 22:06:09	2020-08-12	9	[{"id_menu":6,"count":1}]	25793	pick-up	0	9
116185	2020-08-12 22:06:25	2020-08-12	12	[{"id_menu":1,"count":1}]	36335	delivery	5	17
116186	2020-08-12 22:07:25	2020-08-12	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	44375	delivery	5	34
116187	2020-08-12 22:07:31	2020-08-12	9	[{"id_menu":7,"count":1}]	17992	delivery	5	14
116188	2020-08-12 22:09:28	2020-08-12	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	20255	delivery	5	25
116189	2020-08-12 22:10:51	2020-08-12	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13371	delivery	5	51
116190	2020-08-12 22:14:57	2020-08-12	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	23656	delivery	5	39
116191	2020-08-12 22:15:38	2020-08-12	9	[{"id_menu":7,"count":1}]	25728	delivery	5	14
116192	2020-08-12 22:15:42	2020-08-12	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	26904	delivery	5	30
116193	2020-08-12 22:17:51	2020-08-12	14	[{"id_menu":2,"count":1}]	2932	pick-up	0	14
116194	2020-08-12 22:20:38	2020-08-12	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9105	delivery	5	31
116195	2020-08-12 22:21:05	2020-08-12	17	[{"id_menu":4,"count":1}]	2757	delivery	5	22
116196	2020-08-12 22:21:23	2020-08-12	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	37398	delivery	5	34
116197	2020-08-12 22:23:59	2020-08-12	9	[{"id_menu":7,"count":1}]	17938	pick-up	0	9
116198	2020-08-12 22:26:21	2020-08-12	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	26456	delivery	5	56
116199	2020-08-12 22:28:11	2020-08-12	12	[{"id_menu":3,"count":1}]	8474	pick-up	0	12
116200	2020-08-12 22:29:23	2020-08-12	9	[{"id_menu":6,"count":1}]	44243	delivery	5	14
116201	2020-08-12 22:29:30	2020-08-12	14	[{"id_menu":2,"count":2}]	2050	pick-up	0	14
116202	2020-08-12 22:29:55	2020-08-12	12	[{"id_menu":1,"count":1}]	9847	pick-up	0	12
116203	2020-08-12 22:30:55	2020-08-12	9	[{"id_menu":6,"count":1}]	34823	delivery	5	14
116204	2020-08-12 22:31:28	2020-08-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	35190	delivery	5	28
116205	2020-08-12 22:31:42	2020-08-12	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	8737	delivery	5	27
116206	2020-08-12 22:32:50	2020-08-12	14	[{"id_menu":2,"count":1}]	32565	delivery	5	19
116207	2020-08-12 22:33:34	2020-08-12	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23323	delivery	5	52
116208	2020-08-12 22:36:16	2020-08-12	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	9007	delivery	5	28
116209	2020-08-12 22:37:25	2020-08-12	30	[{"id_menu":1,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34200	delivery	5	35
116210	2020-08-12 22:44:57	2020-08-12	12	[{"id_menu":1,"count":2}]	2207	pick-up	0	12
116211	2020-08-12 22:51:28	2020-08-12	17	[{"id_menu":4,"count":1}]	27049	delivery	5	22
116212	2020-08-12 22:52:07	2020-08-12	9	[{"id_menu":6,"count":1}]	16679	delivery	5	14
116213	2020-08-12 22:52:53	2020-08-12	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	10899	delivery	5	27
116214	2020-08-12 22:53:32	2020-08-12	17	[{"id_menu":4,"count":1}]	16550	pick-up	0	17
116215	2020-08-12 22:53:34	2020-08-12	14	[{"id_menu":2,"count":1}]	44348	delivery	5	19
116216	2020-08-12 22:55:11	2020-08-12	9	[{"id_menu":7,"count":1}]	31738	pick-up	0	9
116217	2020-08-12 22:59:11	2020-08-12	14	[{"id_menu":2,"count":1}]	743	delivery	5	19
116218	2020-08-12 23:01:22	2020-08-12	17	[{"id_menu":4,"count":1}]	43598	delivery	5	22
116219	2020-08-12 23:03:08	2020-08-12	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	14424	delivery	5	23
116220	2020-08-12 23:03:32	2020-08-12	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	36791	delivery	5	34
116221	2020-08-12 23:05:07	2020-08-12	8	[{"id_menu":5,"count":1}]	44208	delivery	5	13
116222	2020-08-12 23:06:56	2020-08-12	17	[{"id_menu":4,"count":1}]	431	delivery	5	22
116223	2020-08-12 23:09:31	2020-08-12	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	9563	delivery	5	48
116224	2020-08-12 23:11:28	2020-08-12	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	10848	delivery	5	26
116225	2020-08-12 23:12:35	2020-08-12	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	42137	delivery	5	26
116226	2020-08-12 23:13:02	2020-08-12	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	44409	delivery	5	27
116227	2020-08-12 23:14:49	2020-08-12	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	24348	delivery	5	22
116228	2020-08-12 23:16:38	2020-08-12	9	[{"id_menu":7,"count":1}]	31511	delivery	5	14
116229	2020-08-12 23:19:05	2020-08-12	9	[{"id_menu":7,"count":1}]	2943	pick-up	0	9
116230	2020-08-12 23:20:11	2020-08-12	17	[{"id_menu":4,"count":1}]	14531	delivery	5	22
116231	2020-08-12 23:22:23	2020-08-12	12	[{"id_menu":1,"count":1}]	40499	pick-up	0	12
116232	2020-08-12 23:23:12	2020-08-12	12	[{"id_menu":1,"count":1}]	17708	pick-up	0	12
116233	2020-08-12 23:25:03	2020-08-12	14	[{"id_menu":2,"count":1}]	40192	delivery	5	19
116234	2020-08-12 23:27:18	2020-08-12	9	[{"id_menu":6,"count":1}]	44206	delivery	5	14
116235	2020-08-12 23:29:23	2020-08-12	9	[{"id_menu":6,"count":1}]	44255	delivery	5	14
116236	2020-08-12 23:31:52	2020-08-12	8	[{"id_menu":5,"count":1}]	42755	delivery	5	13
116237	2020-08-12 23:32:09	2020-08-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	43223	delivery	5	28
116238	2020-08-12 23:34:56	2020-08-12	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9190	pick-up	0	17
116239	2020-08-12 23:36:47	2020-08-12	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44344	delivery	5	48
116240	2020-08-12 23:38:45	2020-08-12	14	[{"id_menu":2,"count":1}]	6814	delivery	5	19
116241	2020-08-12 23:40:00	2020-08-12	8	[{"id_menu":5,"count":1}]	20697	pick-up	0	8
116242	2020-08-12 23:43:58	2020-08-12	9	[{"id_menu":7,"count":1}]	44351	delivery	5	14
116243	2020-08-12 23:45:21	2020-08-12	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	32567	delivery	5	28
116244	2020-08-12 23:45:28	2020-08-12	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	44414	delivery	5	34
116245	2020-08-12 23:50:10	2020-08-12	14	[{"id_menu":2,"count":1}]	2065	delivery	5	19
116246	2020-08-12 23:50:58	2020-08-12	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	44282	delivery	5	40
116247	2020-08-12 23:55:43	2020-08-12	12	[{"id_menu":3,"count":1}]	40972	delivery	5	17
116248	2020-08-12 23:58:32	2020-08-12	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	13577	delivery	5	38
116249	2020-08-13 00:03:56	2020-08-13	9	[{"id_menu":7,"count":1}]	43679	delivery	5	14
116250	2020-08-13 00:10:14	2020-08-13	9	[{"id_menu":7,"count":1}]	29192	delivery	5	14
116251	2020-08-13 00:10:55	2020-08-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	44411	delivery	5	28
116252	2020-08-13 00:13:00	2020-08-13	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	44647	pick-up	0	21
116253	2020-08-13 00:18:42	2020-08-13	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	28530	delivery	5	26
116254	2020-08-13 00:19:33	2020-08-13	8	[{"id_menu":5,"count":1}]	13370	pick-up	0	8
116255	2020-08-13 00:26:10	2020-08-13	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	19839	delivery	5	30
116256	2020-08-13 00:27:56	2020-08-13	9	[{"id_menu":7,"count":1}]	28673	delivery	5	14
116257	2020-08-13 00:30:25	2020-08-13	17	[{"id_menu":4,"count":1}]	1889	pick-up	0	17
116258	2020-08-13 00:30:32	2020-08-13	9	[{"id_menu":6,"count":1}]	33720	delivery	5	14
116259	2020-08-13 00:31:48	2020-08-13	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4199	delivery	5	22
116260	2020-08-13 00:34:00	2020-08-13	14	[{"id_menu":2,"count":2}]	28277	delivery	5	19
116261	2020-08-13 00:34:15	2020-08-13	12	[{"id_menu":3,"count":1}]	35424	pick-up	0	12
116262	2020-08-13 00:34:22	2020-08-13	14	[{"id_menu":2,"count":1}]	44462	delivery	5	19
116263	2020-08-13 00:35:03	2020-08-13	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	29284	delivery	5	39
116264	2020-08-13 00:35:21	2020-08-13	17	[{"id_menu":4,"count":1}]	34856	pick-up	0	17
116265	2020-08-13 00:41:49	2020-08-13	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	22420	delivery	5	31
116266	2020-08-13 00:42:25	2020-08-13	14	[{"id_menu":2,"count":1}]	11411	delivery	5	19
116267	2020-08-13 00:46:05	2020-08-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	28528	delivery	5	28
116268	2020-08-13 00:46:20	2020-08-13	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	31114	delivery	5	43
116269	2020-08-13 00:46:36	2020-08-13	12	[{"id_menu":3,"count":1}]	44476	delivery	5	17
116270	2020-08-13 00:48:19	2020-08-13	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	7610	delivery	5	31
116271	2020-08-13 00:51:49	2020-08-13	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44555	delivery	5	43
116272	2020-08-13 00:52:08	2020-08-13	9	[{"id_menu":6,"count":1}]	44624	delivery	5	14
116273	2020-08-13 00:52:28	2020-08-13	12	[{"id_menu":1,"count":1}]	44613	delivery	5	17
116274	2020-08-13 00:52:39	2020-08-13	9	[{"id_menu":6,"count":1}]	43525	delivery	5	14
116275	2020-08-13 00:54:22	2020-08-13	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2750	pick-up	0	22
116276	2020-08-13 00:55:05	2020-08-13	9	[{"id_menu":7,"count":1}]	9860	delivery	5	14
116277	2020-08-13 00:55:46	2020-08-13	14	[{"id_menu":2,"count":1}]	8808	delivery	5	19
116278	2020-08-13 00:56:19	2020-08-13	9	[{"id_menu":7,"count":1}]	35069	delivery	5	14
116279	2020-08-13 00:56:26	2020-08-13	9	[{"id_menu":6,"count":1}]	44692	delivery	5	14
116280	2020-08-13 01:01:00	2020-08-13	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	21334	pick-up	0	29
116281	2020-08-13 01:04:44	2020-08-13	9	[{"id_menu":7,"count":1}]	2164	delivery	5	14
116282	2020-08-13 01:06:44	2020-08-13	12	[{"id_menu":1,"count":1}]	44460	delivery	5	17
116283	2020-08-13 01:08:01	2020-08-13	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44683	delivery	5	35
116284	2020-08-13 01:19:11	2020-08-13	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	44667	delivery	5	37
116285	2020-08-13 01:19:46	2020-08-13	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	5704	delivery	5	36
116286	2020-08-13 01:22:02	2020-08-13	9	[{"id_menu":7,"count":1}]	808	pick-up	0	9
116287	2020-08-13 01:23:24	2020-08-13	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	44531	delivery	5	26
116288	2020-08-13 01:28:35	2020-08-13	9	[{"id_menu":6,"count":1}]	15997	delivery	5	14
116289	2020-08-13 01:30:14	2020-08-13	14	[{"id_menu":2,"count":1}]	4172	pick-up	0	14
116290	2020-08-13 01:30:16	2020-08-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13938	delivery	5	23
116291	2020-08-13 01:31:33	2020-08-13	9	[{"id_menu":7,"count":1}]	6962	pick-up	0	9
116292	2020-08-13 01:32:57	2020-08-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	42939	delivery	5	36
116293	2020-08-13 01:34:12	2020-08-13	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14982	pick-up	0	26
116294	2020-08-13 01:36:26	2020-08-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	40062	delivery	5	28
116295	2020-08-13 01:37:13	2020-08-13	9	[{"id_menu":7,"count":1}]	36922	delivery	5	14
116296	2020-08-13 01:38:25	2020-08-13	14	[{"id_menu":2,"count":1}]	44684	delivery	5	19
116297	2020-08-13 01:38:54	2020-08-13	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	44574	delivery	5	39
116298	2020-08-13 01:39:43	2020-08-13	9	[{"id_menu":6,"count":1}]	17226	delivery	5	14
116299	2020-08-13 01:44:12	2020-08-13	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12931	delivery	5	31
116300	2020-08-13 01:45:13	2020-08-13	8	[{"id_menu":5,"count":1}]	3250	delivery	5	13
116301	2020-08-13 01:47:24	2020-08-13	12	[{"id_menu":3,"count":1}]	44581	delivery	5	17
116302	2020-08-13 01:48:05	2020-08-13	14	[{"id_menu":2,"count":1}]	44665	pick-up	0	14
116303	2020-08-13 01:50:47	2020-08-13	12	[{"id_menu":3,"count":1}]	22037	delivery	5	17
116304	2020-08-13 01:52:31	2020-08-13	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	26963	delivery	5	40
116305	2020-08-13 01:52:36	2020-08-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	44700	pick-up	0	23
116306	2020-08-13 01:55:36	2020-08-13	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	30709	delivery	5	26
116307	2020-08-13 01:57:07	2020-08-13	14	[{"id_menu":2,"count":1}]	3825	pick-up	0	14
116308	2020-08-13 01:57:59	2020-08-13	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	12345	delivery	5	31
116309	2020-08-13 01:58:23	2020-08-13	17	[{"id_menu":4,"count":1}]	38976	delivery	5	22
116310	2020-08-13 01:59:13	2020-08-13	12	[{"id_menu":3,"count":1}]	31927	delivery	5	17
116311	2020-08-13 02:02:15	2020-08-13	12	[{"id_menu":3,"count":1}]	36952	delivery	5	17
116312	2020-08-13 02:02:51	2020-08-13	9	[{"id_menu":6,"count":1}]	9342	pick-up	0	9
116313	2020-08-13 02:03:02	2020-08-13	8	[{"id_menu":5,"count":1}]	22244	delivery	5	13
116314	2020-08-13 02:03:38	2020-08-13	9	[{"id_menu":7,"count":1}]	7316	delivery	5	14
116315	2020-08-13 02:04:27	2020-08-13	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	44452	delivery	5	37
116316	2020-08-13 02:05:28	2020-08-13	17	[{"id_menu":4,"count":1}]	873	delivery	5	22
116317	2020-08-13 02:05:41	2020-08-13	8	[{"id_menu":5,"count":1}]	14252	pick-up	0	8
116318	2020-08-13 02:05:52	2020-08-13	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	15303	delivery	5	31
116319	2020-08-13 02:07:15	2020-08-13	8	[{"id_menu":5,"count":1}]	44523	delivery	5	13
116320	2020-08-13 02:08:34	2020-08-13	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6668	delivery	5	31
116321	2020-08-13 02:09:21	2020-08-13	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	35810	delivery	5	22
116322	2020-08-13 02:10:55	2020-08-13	8	[{"id_menu":5,"count":1}]	44525	delivery	5	13
116323	2020-08-13 02:12:42	2020-08-13	8	[{"id_menu":5,"count":1}]	5041	pick-up	0	8
116324	2020-08-13 02:12:53	2020-08-13	8	[{"id_menu":5,"count":1}]	17613	delivery	5	13
116325	2020-08-13 02:14:44	2020-08-13	17	[{"id_menu":4,"count":1}]	16952	delivery	5	22
116389	2020-08-13 04:10:33	2020-08-13	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	44560	pick-up	0	21
116326	2020-08-13 02:17:47	2020-08-13	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44634	delivery	5	31
116327	2020-08-13 02:17:51	2020-08-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	28964	delivery	5	36
116328	2020-08-13 02:23:02	2020-08-13	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	807	pick-up	0	21
116329	2020-08-13 02:27:58	2020-08-13	12	[{"id_menu":1,"count":1}]	4371	delivery	5	17
116330	2020-08-13 02:28:13	2020-08-13	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	42516	delivery	5	22
116331	2020-08-13 02:29:50	2020-08-13	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	39284	pick-up	0	26
116332	2020-08-13 02:30:15	2020-08-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	44614	delivery	5	36
116333	2020-08-13 02:32:32	2020-08-13	12	[{"id_menu":3,"count":1}]	44617	delivery	5	17
116334	2020-08-13 02:32:38	2020-08-13	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	24080	delivery	5	57
116335	2020-08-13 02:32:45	2020-08-13	49	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	44334	delivery	5	54
116336	2020-08-13 02:32:52	2020-08-13	9	[{"id_menu":7,"count":1}]	40026	pick-up	0	9
116337	2020-08-13 02:40:05	2020-08-13	9	[{"id_menu":7,"count":1}]	22699	delivery	5	14
116338	2020-08-13 02:40:18	2020-08-13	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24050	delivery	5	48
116339	2020-08-13 02:41:30	2020-08-13	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3767	delivery	5	51
116340	2020-08-13 02:41:51	2020-08-13	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39763	delivery	5	22
116341	2020-08-13 02:45:21	2020-08-13	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	44544	delivery	5	25
116342	2020-08-13 02:45:45	2020-08-13	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7293	delivery	5	31
116343	2020-08-13 02:48:20	2020-08-13	14	[{"id_menu":2,"count":1}]	20792	delivery	5	19
116344	2020-08-13 02:49:09	2020-08-13	17	[{"id_menu":4,"count":1}]	39458	delivery	5	22
116345	2020-08-13 02:50:00	2020-08-13	17	[{"id_menu":4,"count":1}]	38394	pick-up	0	17
116346	2020-08-13 02:54:16	2020-08-13	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	14531	pick-up	0	26
116347	2020-08-13 02:55:27	2020-08-13	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1409	delivery	5	36
116348	2020-08-13 02:57:03	2020-08-13	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44550	delivery	5	37
116349	2020-08-13 02:58:11	2020-08-13	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	44517	delivery	5	26
116350	2020-08-13 02:58:14	2020-08-13	9	[{"id_menu":7,"count":1}]	29573	delivery	5	14
116351	2020-08-13 03:02:36	2020-08-13	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	13662	pick-up	0	26
116352	2020-08-13 03:02:40	2020-08-13	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31634	delivery	5	43
116353	2020-08-13 03:02:49	2020-08-13	12	[{"id_menu":1,"count":1}]	7707	delivery	5	17
116354	2020-08-13 03:05:10	2020-08-13	8	[{"id_menu":5,"count":2}]	44458	delivery	5	13
116355	2020-08-13 03:06:11	2020-08-13	14	[{"id_menu":2,"count":1}]	10412	pick-up	0	14
116356	2020-08-13 03:06:12	2020-08-13	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	44538	delivery	5	37
116357	2020-08-13 03:07:05	2020-08-13	9	[{"id_menu":6,"count":1}]	20641	delivery	5	14
116358	2020-08-13 03:09:23	2020-08-13	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	44641	delivery	5	43
116359	2020-08-13 03:09:41	2020-08-13	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	44610	delivery	5	26
116360	2020-08-13 03:09:43	2020-08-13	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	29582	delivery	5	43
116361	2020-08-13 03:13:36	2020-08-13	17	[{"id_menu":4,"count":1}]	44584	delivery	5	22
116362	2020-08-13 03:14:29	2020-08-13	9	[{"id_menu":7,"count":1}]	4054	pick-up	0	9
116363	2020-08-13 03:16:26	2020-08-13	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	5391	delivery	5	31
116364	2020-08-13 03:17:06	2020-08-13	8	[{"id_menu":5,"count":1}]	13837	pick-up	0	8
116365	2020-08-13 03:19:55	2020-08-13	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	26685	delivery	5	36
116366	2020-08-13 03:22:41	2020-08-13	9	[{"id_menu":6,"count":1}]	25701	delivery	5	14
116367	2020-08-13 03:23:58	2020-08-13	9	[{"id_menu":6,"count":1}]	20960	delivery	5	14
116368	2020-08-13 03:25:36	2020-08-13	9	[{"id_menu":6,"count":1}]	44660	delivery	5	14
116369	2020-08-13 03:28:11	2020-08-13	14	[{"id_menu":2,"count":1}]	19703	delivery	5	19
116370	2020-08-13 03:29:59	2020-08-13	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	44480	delivery	5	34
116371	2020-08-13 03:32:50	2020-08-13	9	[{"id_menu":6,"count":1}]	33012	delivery	5	14
116372	2020-08-13 03:33:01	2020-08-13	12	[{"id_menu":3,"count":1}]	43702	delivery	5	17
116373	2020-08-13 03:34:42	2020-08-13	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	41851	delivery	5	30
116374	2020-08-13 03:34:50	2020-08-13	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	44520	delivery	5	26
116375	2020-08-13 03:36:40	2020-08-13	14	[{"id_menu":2,"count":1}]	23111	delivery	5	19
116376	2020-08-13 03:37:51	2020-08-13	14	[{"id_menu":2,"count":1}]	30022	delivery	5	19
116377	2020-08-13 03:38:35	2020-08-13	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	23432	delivery	5	31
116378	2020-08-13 03:40:03	2020-08-13	9	[{"id_menu":6,"count":1}]	44470	delivery	5	14
116379	2020-08-13 03:40:22	2020-08-13	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29619	delivery	5	34
116380	2020-08-13 03:45:57	2020-08-13	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	44487	delivery	5	34
116381	2020-08-13 03:54:05	2020-08-13	12	[{"id_menu":3,"count":1}]	42212	delivery	5	17
116382	2020-08-13 03:56:28	2020-08-13	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	22308	delivery	5	25
116383	2020-08-13 03:58:52	2020-08-13	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	44669	delivery	5	26
116384	2020-08-13 04:01:24	2020-08-13	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32597	delivery	5	22
116385	2020-08-13 04:03:12	2020-08-13	9	[{"id_menu":6,"count":1}]	43582	pick-up	0	9
116386	2020-08-13 04:05:10	2020-08-13	17	[{"id_menu":4,"count":1}]	33945	delivery	5	22
116387	2020-08-13 04:06:08	2020-08-13	14	[{"id_menu":2,"count":1}]	16518	delivery	5	19
116388	2020-08-13 04:06:25	2020-08-13	14	[{"id_menu":2,"count":2}]	42318	pick-up	0	14
116390	2020-08-13 04:10:50	2020-08-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3848	pick-up	0	31
116391	2020-08-13 04:16:25	2020-08-13	17	[{"id_menu":4,"count":1}]	11772	delivery	5	22
116392	2020-08-13 04:16:43	2020-08-13	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	44592	delivery	5	31
116393	2020-08-13 04:20:12	2020-08-13	9	[{"id_menu":7,"count":1}]	24579	delivery	5	14
116394	2020-08-13 04:22:36	2020-08-13	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	44600	delivery	5	40
116395	2020-08-13 04:24:09	2020-08-13	17	[{"id_menu":4,"count":1}]	26530	delivery	5	22
116396	2020-08-13 04:31:51	2020-08-13	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44661	delivery	5	52
116397	2020-08-13 04:33:40	2020-08-13	12	[{"id_menu":3,"count":1}]	2481	delivery	5	17
116398	2020-08-13 04:39:13	2020-08-13	9	[{"id_menu":6,"count":1}]	44646	delivery	5	14
116399	2020-08-13 04:41:22	2020-08-13	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	34739	delivery	5	43
116400	2020-08-13 04:43:08	2020-08-13	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	44017	delivery	5	45
116401	2020-08-13 04:43:30	2020-08-13	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39297	delivery	5	34
116402	2020-08-13 04:44:00	2020-08-13	9	[{"id_menu":6,"count":1}]	14293	delivery	5	14
116403	2020-08-13 04:45:36	2020-08-13	12	[{"id_menu":3,"count":1}]	44653	delivery	5	17
116404	2020-08-13 04:48:27	2020-08-13	12	[{"id_menu":1,"count":1}]	5929	delivery	5	17
116405	2020-08-13 04:49:14	2020-08-13	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13577	delivery	5	31
116406	2020-08-13 04:50:29	2020-08-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29450	pick-up	0	18
116407	2020-08-13 04:52:29	2020-08-13	9	[{"id_menu":6,"count":1}]	16019	delivery	5	14
116408	2020-08-13 04:52:39	2020-08-13	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	44645	delivery	5	34
116409	2020-08-13 04:54:37	2020-08-13	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	7726	pick-up	0	29
116410	2020-08-13 04:55:29	2020-08-13	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15693	delivery	5	45
116411	2020-08-13 04:57:51	2020-08-13	17	[{"id_menu":4,"count":1}]	35266	pick-up	0	17
116412	2020-08-13 04:59:49	2020-08-13	9	[{"id_menu":7,"count":1}]	13305	delivery	5	14
116413	2020-08-13 05:00:00	2020-08-13	9	[{"id_menu":6,"count":1}]	44562	delivery	5	14
116414	2020-08-13 05:02:21	2020-08-13	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	44499	delivery	5	28
116415	2020-08-13 05:09:03	2020-08-13	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	31818	delivery	5	26
116416	2020-08-13 05:09:26	2020-08-13	8	[{"id_menu":5,"count":1}]	44565	delivery	5	13
116417	2020-08-13 05:12:44	2020-08-13	14	[{"id_menu":2,"count":1}]	44590	pick-up	0	14
116418	2020-08-13 05:12:58	2020-08-13	14	[{"id_menu":2,"count":1}]	2897	pick-up	0	14
116419	2020-08-13 05:16:38	2020-08-13	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	21295	delivery	5	30
116420	2020-08-13 05:19:38	2020-08-13	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	38219	delivery	5	26
116421	2020-08-13 05:26:05	2020-08-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	15385	pick-up	0	23
116422	2020-08-13 05:27:01	2020-08-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	44576	delivery	5	36
116423	2020-08-13 05:35:42	2020-08-13	9	[{"id_menu":7,"count":1}]	44556	delivery	5	14
116424	2020-08-13 05:39:35	2020-08-13	8	[{"id_menu":5,"count":1}]	39194	delivery	5	13
116425	2020-08-13 05:41:07	2020-08-13	12	[{"id_menu":3,"count":1}]	30363	delivery	5	17
116426	2020-08-13 05:41:15	2020-08-13	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	688	pick-up	0	17
116427	2020-08-13 05:41:49	2020-08-13	9	[{"id_menu":6,"count":1}]	36519	delivery	5	14
116428	2020-08-13 05:45:18	2020-08-13	9	[{"id_menu":6,"count":1}]	43564	delivery	5	14
116429	2020-08-13 05:46:37	2020-08-13	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	44524	delivery	5	28
116430	2020-08-13 05:47:25	2020-08-13	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	30153	delivery	5	25
116431	2020-08-13 05:48:52	2020-08-13	9	[{"id_menu":6,"count":1}]	5768	delivery	5	14
116432	2020-08-13 05:49:02	2020-08-13	8	[{"id_menu":5,"count":1}]	26506	delivery	5	13
116433	2020-08-13 05:49:07	2020-08-13	12	[{"id_menu":1,"count":1}]	18876	pick-up	0	12
116434	2020-08-13 05:49:57	2020-08-13	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	35179	delivery	5	22
116435	2020-08-13 05:51:04	2020-08-13	17	[{"id_menu":4,"count":1}]	44546	pick-up	0	17
116436	2020-08-13 05:56:17	2020-08-13	14	[{"id_menu":2,"count":1}]	18346	delivery	5	19
116437	2020-08-13 05:57:13	2020-08-13	14	[{"id_menu":2,"count":1}]	1463	delivery	5	19
116438	2020-08-13 05:58:21	2020-08-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44687	delivery	5	23
116439	2020-08-13 05:59:37	2020-08-13	8	[{"id_menu":5,"count":1}]	38477	delivery	5	13
116440	2020-08-13 06:01:06	2020-08-13	12	[{"id_menu":1,"count":2}]	29709	pick-up	0	12
116441	2020-08-13 06:07:08	2020-08-13	9	[{"id_menu":6,"count":1}]	17857	delivery	5	14
116442	2020-08-13 06:08:03	2020-08-13	14	[{"id_menu":2,"count":1}]	17974	delivery	5	19
116443	2020-08-13 06:08:25	2020-08-13	12	[{"id_menu":3,"count":1}]	34077	pick-up	0	12
116444	2020-08-13 06:13:45	2020-08-13	17	[{"id_menu":4,"count":1}]	21258	delivery	5	22
116445	2020-08-13 06:17:57	2020-08-13	9	[{"id_menu":7,"count":1}]	44527	delivery	5	14
116446	2020-08-13 06:19:39	2020-08-13	12	[{"id_menu":1,"count":1}]	19883	delivery	5	17
116447	2020-08-13 06:23:28	2020-08-13	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	34032	delivery	5	26
116448	2020-08-13 06:29:26	2020-08-13	14	[{"id_menu":2,"count":1}]	20583	delivery	5	19
116449	2020-08-13 06:32:10	2020-08-13	12	[{"id_menu":1,"count":2}]	38267	pick-up	0	12
116450	2020-08-13 06:33:39	2020-08-13	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	31076	pick-up	0	21
116451	2020-08-13 06:37:34	2020-08-13	17	[{"id_menu":4,"count":1}]	10807	delivery	5	22
116452	2020-08-13 06:37:34	2020-08-13	8	[{"id_menu":5,"count":1}]	44688	delivery	5	13
116453	2020-08-13 06:37:57	2020-08-13	14	[{"id_menu":2,"count":1}]	5979	delivery	5	19
116454	2020-08-13 06:38:50	2020-08-13	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35276	delivery	5	49
116455	2020-08-13 06:42:14	2020-08-13	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	28945	delivery	5	31
116456	2020-08-13 06:45:24	2020-08-13	9	[{"id_menu":6,"count":1}]	43321	delivery	5	14
116457	2020-08-13 06:47:38	2020-08-13	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	38701	delivery	5	36
116458	2020-08-13 06:47:59	2020-08-13	12	[{"id_menu":1,"count":2}]	31729	delivery	5	17
116459	2020-08-13 06:49:26	2020-08-13	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	44451	delivery	5	28
116460	2020-08-13 06:49:28	2020-08-13	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	20150	delivery	5	40
116461	2020-08-13 06:52:05	2020-08-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	25658	delivery	5	36
116462	2020-08-13 06:52:21	2020-08-13	12	[{"id_menu":3,"count":1}]	44682	pick-up	0	12
116463	2020-08-13 06:53:46	2020-08-13	9	[{"id_menu":7,"count":1}]	21705	delivery	5	14
116464	2020-08-13 06:56:51	2020-08-13	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	18283	delivery	5	31
116465	2020-08-13 07:03:47	2020-08-13	14	[{"id_menu":2,"count":1}]	3718	pick-up	0	14
116466	2020-08-13 07:04:20	2020-08-13	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11262	pick-up	0	30
116467	2020-08-13 07:06:08	2020-08-13	14	[{"id_menu":2,"count":1}]	6132	pick-up	0	14
116468	2020-08-13 07:06:10	2020-08-13	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	30422	pick-up	0	29
116469	2020-08-13 07:07:07	2020-08-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	39982	delivery	5	28
116470	2020-08-13 07:08:09	2020-08-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	44627	delivery	5	23
116471	2020-08-13 07:08:11	2020-08-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	42313	delivery	5	23
116472	2020-08-13 07:08:22	2020-08-13	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	19523	pick-up	0	26
116473	2020-08-13 07:09:33	2020-08-13	8	[{"id_menu":5,"count":1}]	44668	delivery	5	13
116474	2020-08-13 07:09:52	2020-08-13	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5053	delivery	5	22
116475	2020-08-13 07:10:57	2020-08-13	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	44607	delivery	5	26
116476	2020-08-13 07:13:44	2020-08-13	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13371	delivery	5	39
116477	2020-08-13 07:16:21	2020-08-13	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5264	delivery	5	31
116478	2020-08-13 07:17:45	2020-08-13	12	[{"id_menu":3,"count":1}]	44678	delivery	5	17
116479	2020-08-13 07:18:04	2020-08-13	9	[{"id_menu":6,"count":1}]	36046	delivery	5	14
116480	2020-08-13 07:19:39	2020-08-13	14	[{"id_menu":2,"count":1}]	21701	delivery	5	19
116481	2020-08-13 07:24:28	2020-08-13	14	[{"id_menu":2,"count":1}]	11992	pick-up	0	14
116482	2020-08-13 07:26:16	2020-08-13	17	[{"id_menu":4,"count":1}]	44644	delivery	5	22
116483	2020-08-13 07:27:46	2020-08-13	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	25018	delivery	5	40
116484	2020-08-13 07:27:50	2020-08-13	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	44485	delivery	5	34
116485	2020-08-13 07:28:23	2020-08-13	12	[{"id_menu":3,"count":1}]	44486	delivery	5	17
116486	2020-08-13 07:30:22	2020-08-13	17	[{"id_menu":4,"count":1}]	20713	pick-up	0	17
116487	2020-08-13 07:33:39	2020-08-13	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	456	pick-up	0	23
116488	2020-08-13 07:45:39	2020-08-13	12	[{"id_menu":3,"count":1}]	11124	delivery	5	17
116489	2020-08-13 07:46:55	2020-08-13	17	[{"id_menu":4,"count":1}]	44583	delivery	5	22
116490	2020-08-13 07:48:32	2020-08-13	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	39277	delivery	5	34
116491	2020-08-13 07:49:53	2020-08-13	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	25884	delivery	5	48
116492	2020-08-13 07:50:12	2020-08-13	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	44468	delivery	5	45
116493	2020-08-13 07:51:33	2020-08-13	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	28305	pick-up	0	25
116494	2020-08-13 07:52:48	2020-08-13	9	[{"id_menu":6,"count":1}]	44698	pick-up	0	9
116495	2020-08-13 07:54:16	2020-08-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33714	delivery	5	23
116496	2020-08-13 07:57:53	2020-08-13	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12320	delivery	5	36
116497	2020-08-13 07:58:18	2020-08-13	9	[{"id_menu":7,"count":1}]	44552	delivery	5	14
116498	2020-08-13 07:59:50	2020-08-13	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1329	delivery	5	26
116499	2020-08-13 08:08:37	2020-08-13	9	[{"id_menu":7,"count":1}]	26138	delivery	5	14
116500	2020-08-13 08:11:12	2020-08-13	9	[{"id_menu":7,"count":1}]	44505	delivery	5	14
116501	2020-08-13 08:14:19	2020-08-13	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43995	delivery	5	35
116502	2020-08-13 08:14:52	2020-08-13	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	44649	delivery	5	31
116503	2020-08-13 08:15:04	2020-08-13	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	44672	delivery	5	34
116504	2020-08-13 08:20:06	2020-08-13	17	[{"id_menu":4,"count":2}]	4646	delivery	5	22
116505	2020-08-13 08:21:25	2020-08-13	8	[{"id_menu":5,"count":1}]	16553	delivery	5	13
116506	2020-08-13 08:22:30	2020-08-13	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	28987	delivery	5	28
116507	2020-08-13 08:26:31	2020-08-13	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	44622	delivery	5	31
116508	2020-08-13 08:30:01	2020-08-13	17	[{"id_menu":4,"count":1}]	41624	delivery	5	22
116509	2020-08-13 08:30:41	2020-08-13	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	25751	delivery	5	31
116510	2020-08-13 08:34:11	2020-08-13	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	42536	delivery	5	26
116511	2020-08-13 08:42:57	2020-08-13	9	[{"id_menu":7,"count":1}]	32477	delivery	5	14
116512	2020-08-13 08:44:07	2020-08-13	14	[{"id_menu":2,"count":1}]	13151	pick-up	0	14
116513	2020-08-13 08:45:57	2020-08-13	8	[{"id_menu":5,"count":1}]	44493	delivery	5	13
116514	2020-08-13 08:46:44	2020-08-13	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	17818	delivery	5	26
116515	2020-08-13 08:47:25	2020-08-13	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11877	delivery	5	39
116516	2020-08-13 08:48:40	2020-08-13	9	[{"id_menu":7,"count":1}]	44500	delivery	5	14
116517	2020-08-13 08:51:55	2020-08-13	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	44628	delivery	5	52
116518	2020-08-13 08:52:18	2020-08-13	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	44589	delivery	5	34
116519	2020-08-13 08:58:21	2020-08-13	8	[{"id_menu":5,"count":2}]	44681	delivery	5	13
116520	2020-08-13 09:02:50	2020-08-13	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3786	delivery	5	36
116521	2020-08-13 09:04:52	2020-08-13	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	35933	delivery	5	39
116522	2020-08-13 09:08:04	2020-08-13	14	[{"id_menu":2,"count":1}]	44449	delivery	5	19
116523	2020-08-13 09:09:42	2020-08-13	14	[{"id_menu":2,"count":1}]	17582	pick-up	0	14
116524	2020-08-13 09:10:16	2020-08-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12700	delivery	5	23
116525	2020-08-13 09:10:36	2020-08-13	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3119	delivery	5	27
116526	2020-08-13 09:12:03	2020-08-13	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	44608	delivery	5	31
116527	2020-08-13 09:13:47	2020-08-13	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17941	delivery	5	31
116528	2020-08-13 09:14:58	2020-08-13	9	[{"id_menu":6,"count":1}]	44450	delivery	5	14
116529	2020-08-13 09:17:13	2020-08-13	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20520	delivery	5	36
116530	2020-08-13 09:17:51	2020-08-13	12	[{"id_menu":1,"count":1}]	19525	delivery	5	17
116531	2020-08-13 09:17:53	2020-08-13	9	[{"id_menu":7,"count":1}]	26878	delivery	5	14
116532	2020-08-13 09:18:45	2020-08-13	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9998	delivery	5	22
116533	2020-08-13 09:19:32	2020-08-13	17	[{"id_menu":4,"count":1}]	44465	delivery	5	22
116534	2020-08-13 09:19:50	2020-08-13	14	[{"id_menu":2,"count":1}]	44603	delivery	5	19
116535	2020-08-13 09:21:06	2020-08-13	17	[{"id_menu":4,"count":1}]	3364	delivery	5	22
116536	2020-08-13 09:23:11	2020-08-13	12	[{"id_menu":1,"count":1}]	36275	delivery	5	17
116537	2020-08-13 09:23:17	2020-08-13	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	44563	delivery	5	44
116538	2020-08-13 09:24:31	2020-08-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	8013	delivery	5	28
116539	2020-08-13 09:35:07	2020-08-13	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	44529	delivery	5	26
116540	2020-08-13 09:36:47	2020-08-13	14	[{"id_menu":2,"count":2}]	44675	delivery	5	19
116541	2020-08-13 09:39:47	2020-08-13	8	[{"id_menu":5,"count":1}]	18424	pick-up	0	8
116542	2020-08-13 09:41:30	2020-08-13	17	[{"id_menu":4,"count":1}]	34935	delivery	5	22
116543	2020-08-13 09:44:48	2020-08-13	17	[{"id_menu":4,"count":1}]	16692	delivery	5	22
116544	2020-08-13 09:45:23	2020-08-13	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7899	delivery	5	42
116545	2020-08-13 09:45:29	2020-08-13	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	44479	delivery	5	30
116546	2020-08-13 09:48:03	2020-08-13	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	44605	delivery	5	34
116547	2020-08-13 09:50:37	2020-08-13	14	[{"id_menu":2,"count":1}]	33569	delivery	5	19
116548	2020-08-13 09:51:08	2020-08-13	9	[{"id_menu":6,"count":1}]	15051	delivery	5	14
116549	2020-08-13 09:51:31	2020-08-13	8	[{"id_menu":5,"count":1}]	44611	delivery	5	13
116550	2020-08-13 09:54:23	2020-08-13	9	[{"id_menu":6,"count":2}]	37534	pick-up	0	9
116551	2020-08-13 09:56:23	2020-08-13	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	44540	delivery	5	42
116552	2020-08-13 09:57:39	2020-08-13	9	[{"id_menu":6,"count":1}]	2641	pick-up	0	9
116553	2020-08-13 10:00:09	2020-08-13	14	[{"id_menu":2,"count":1}]	23500	pick-up	0	14
116554	2020-08-13 10:00:19	2020-08-13	14	[{"id_menu":2,"count":1}]	44609	delivery	5	19
116555	2020-08-13 10:01:27	2020-08-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25423	delivery	5	23
116556	2020-08-13 10:04:28	2020-08-13	14	[{"id_menu":2,"count":1}]	30361	pick-up	0	14
116557	2020-08-13 10:07:20	2020-08-13	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	44558	delivery	5	25
116558	2020-08-13 10:08:40	2020-08-13	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1968	pick-up	0	46
116559	2020-08-13 10:08:53	2020-08-13	9	[{"id_menu":7,"count":1}]	44454	delivery	5	14
116560	2020-08-13 10:09:34	2020-08-13	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	35018	delivery	5	39
116561	2020-08-13 10:10:53	2020-08-13	17	[{"id_menu":4,"count":1}]	33900	delivery	5	22
116562	2020-08-13 10:11:51	2020-08-13	9	[{"id_menu":6,"count":1}]	24470	delivery	5	14
116563	2020-08-13 10:12:45	2020-08-13	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	44707	delivery	5	31
116564	2020-08-13 10:14:07	2020-08-13	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	11039	delivery	5	26
116565	2020-08-13 10:14:47	2020-08-13	9	[{"id_menu":6,"count":1}]	1011	delivery	5	14
116566	2020-08-13 10:17:13	2020-08-13	17	[{"id_menu":4,"count":2}]	7189	pick-up	0	17
116567	2020-08-13 10:19:50	2020-08-13	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	28588	delivery	5	43
116568	2020-08-13 10:22:25	2020-08-13	9	[{"id_menu":6,"count":1}]	41160	pick-up	0	9
116569	2020-08-13 10:23:11	2020-08-13	14	[{"id_menu":2,"count":1}]	44591	delivery	5	19
116570	2020-08-13 10:23:29	2020-08-13	9	[{"id_menu":6,"count":1}]	25736	delivery	5	14
116571	2020-08-13 10:24:01	2020-08-13	17	[{"id_menu":4,"count":1}]	14369	delivery	5	22
116572	2020-08-13 10:24:28	2020-08-13	14	[{"id_menu":2,"count":1}]	24485	pick-up	0	14
116573	2020-08-13 10:26:02	2020-08-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35685	delivery	5	23
116574	2020-08-13 10:28:40	2020-08-13	8	[{"id_menu":5,"count":1}]	12486	pick-up	0	8
116575	2020-08-13 10:31:03	2020-08-13	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1780	pick-up	0	26
116576	2020-08-13 10:31:46	2020-08-13	14	[{"id_menu":2,"count":1}]	7270	delivery	5	19
116577	2020-08-13 10:31:55	2020-08-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	19132	delivery	5	28
116578	2020-08-13 10:34:37	2020-08-13	14	[{"id_menu":2,"count":1}]	23405	delivery	5	19
116579	2020-08-13 10:36:02	2020-08-13	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	29610	delivery	5	22
116580	2020-08-13 10:37:34	2020-08-13	12	[{"id_menu":1,"count":1}]	44633	delivery	5	17
116581	2020-08-13 10:41:07	2020-08-13	33	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	44637	pick-up	0	33
116582	2020-08-13 10:43:17	2020-08-13	9	[{"id_menu":6,"count":1}]	38712	delivery	5	14
116583	2020-08-13 10:44:41	2020-08-13	9	[{"id_menu":7,"count":1}]	44478	delivery	5	14
116584	2020-08-13 10:49:42	2020-08-13	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1813	delivery	5	25
116585	2020-08-13 10:53:49	2020-08-13	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	44490	delivery	5	36
116586	2020-08-13 10:55:37	2020-08-13	17	[{"id_menu":4,"count":1}]	41770	delivery	5	22
116587	2020-08-13 10:58:42	2020-08-13	9	[{"id_menu":6,"count":1}]	44457	delivery	5	14
116588	2020-08-13 11:01:13	2020-08-13	8	[{"id_menu":5,"count":1}]	27697	delivery	5	13
116589	2020-08-13 11:02:21	2020-08-13	8	[{"id_menu":5,"count":1}]	37983	pick-up	0	8
116590	2020-08-13 11:03:31	2020-08-13	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	24490	delivery	5	26
116591	2020-08-13 11:03:45	2020-08-13	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	44585	delivery	5	31
116592	2020-08-13 11:06:52	2020-08-13	9	[{"id_menu":7,"count":1}]	44615	delivery	5	14
116593	2020-08-13 11:09:02	2020-08-13	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	17067	delivery	5	37
116594	2020-08-13 11:09:31	2020-08-13	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	44492	delivery	5	30
116595	2020-08-13 11:09:54	2020-08-13	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	41802	delivery	5	22
116596	2020-08-13 11:09:57	2020-08-13	9	[{"id_menu":6,"count":1}]	30108	delivery	5	14
116597	2020-08-13 11:10:03	2020-08-13	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	44444	delivery	5	30
116598	2020-08-13 11:11:45	2020-08-13	12	[{"id_menu":3,"count":1}]	39105	pick-up	0	12
116599	2020-08-13 11:14:09	2020-08-13	8	[{"id_menu":5,"count":2}]	7336	delivery	5	13
116600	2020-08-13 11:17:52	2020-08-13	12	[{"id_menu":3,"count":1}]	5194	pick-up	0	12
116601	2020-08-13 11:20:33	2020-08-13	9	[{"id_menu":7,"count":1}]	1091	delivery	5	14
116602	2020-08-13 11:20:47	2020-08-13	17	[{"id_menu":4,"count":1}]	9106	pick-up	0	17
116603	2020-08-13 11:27:34	2020-08-13	9	[{"id_menu":6,"count":1}]	44526	delivery	5	14
116604	2020-08-13 11:29:03	2020-08-13	12	[{"id_menu":1,"count":1}]	33446	delivery	5	17
116605	2020-08-13 11:31:46	2020-08-13	17	[{"id_menu":4,"count":1}]	13559	delivery	5	22
116606	2020-08-13 11:32:38	2020-08-13	9	[{"id_menu":7,"count":1}]	21284	delivery	5	14
116607	2020-08-13 11:37:19	2020-08-13	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14562	delivery	5	22
116608	2020-08-13 11:40:13	2020-08-13	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	31280	delivery	5	40
116609	2020-08-13 11:40:49	2020-08-13	9	[{"id_menu":6,"count":1}]	123	pick-up	0	9
116610	2020-08-13 11:41:44	2020-08-13	12	[{"id_menu":3,"count":1}]	44656	delivery	5	17
116611	2020-08-13 11:45:27	2020-08-13	12	[{"id_menu":1,"count":1}]	7785	delivery	5	17
116612	2020-08-13 11:45:32	2020-08-13	12	[{"id_menu":1,"count":1}]	44518	delivery	5	17
116613	2020-08-13 11:46:24	2020-08-13	17	[{"id_menu":4,"count":1}]	27448	delivery	5	22
116614	2020-08-13 11:46:39	2020-08-13	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	13600	delivery	5	31
116615	2020-08-13 11:48:32	2020-08-13	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	44620	delivery	5	31
116616	2020-08-13 11:54:48	2020-08-13	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	29691	delivery	5	22
116617	2020-08-13 11:55:46	2020-08-13	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	10689	delivery	5	26
116618	2020-08-13 11:56:04	2020-08-13	9	[{"id_menu":6,"count":1}]	5144	pick-up	0	9
116619	2020-08-13 11:59:40	2020-08-13	9	[{"id_menu":7,"count":1}]	44514	delivery	5	14
116620	2020-08-13 12:00:27	2020-08-13	12	[{"id_menu":3,"count":1}]	11737	pick-up	0	12
116621	2020-08-13 12:01:16	2020-08-13	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	44594	delivery	5	25
116622	2020-08-13 12:01:16	2020-08-13	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	16623	pick-up	0	22
116623	2020-08-13 12:06:04	2020-08-13	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18223	delivery	5	31
116624	2020-08-13 12:08:01	2020-08-13	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	19735	delivery	5	28
116625	2020-08-13 12:10:05	2020-08-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15532	delivery	5	23
116626	2020-08-13 12:13:55	2020-08-13	9	[{"id_menu":6,"count":1}]	44612	delivery	5	14
116627	2020-08-13 12:17:33	2020-08-13	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	44542	delivery	5	31
116628	2020-08-13 12:19:07	2020-08-13	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":3}]	44515	delivery	5	22
116629	2020-08-13 12:20:27	2020-08-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20686	delivery	5	23
116630	2020-08-13 12:20:33	2020-08-13	9	[{"id_menu":7,"count":1}]	20714	delivery	5	14
116631	2020-08-13 12:20:34	2020-08-13	9	[{"id_menu":6,"count":1}]	10645	delivery	5	14
116632	2020-08-13 12:20:55	2020-08-13	12	[{"id_menu":1,"count":1}]	17395	delivery	5	17
116633	2020-08-13 12:22:27	2020-08-13	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	44632	delivery	5	22
116634	2020-08-13 12:24:13	2020-08-13	9	[{"id_menu":6,"count":1}]	44464	delivery	5	14
116635	2020-08-13 12:26:03	2020-08-13	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44488	delivery	5	54
116636	2020-08-13 12:27:18	2020-08-13	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	13097	delivery	5	31
116637	2020-08-13 12:28:07	2020-08-13	9	[{"id_menu":6,"count":1}]	44413	pick-up	0	9
116638	2020-08-13 12:28:15	2020-08-13	9	[{"id_menu":6,"count":2}]	44506	delivery	5	14
116639	2020-08-13 12:28:29	2020-08-13	9	[{"id_menu":6,"count":1}]	26787	delivery	5	14
116640	2020-08-13 12:37:16	2020-08-13	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	11504	pick-up	0	26
116641	2020-08-13 12:38:52	2020-08-13	9	[{"id_menu":7,"count":1}]	44595	delivery	5	14
116642	2020-08-13 12:40:46	2020-08-13	12	[{"id_menu":3,"count":1}]	44491	delivery	5	17
116643	2020-08-13 12:43:17	2020-08-13	14	[{"id_menu":2,"count":1}]	37256	pick-up	0	14
116644	2020-08-13 12:44:01	2020-08-13	8	[{"id_menu":5,"count":1}]	44513	delivery	5	13
116645	2020-08-13 12:44:09	2020-08-13	9	[{"id_menu":7,"count":1}]	32266	delivery	5	14
116646	2020-08-13 12:46:30	2020-08-13	9	[{"id_menu":6,"count":1}]	25748	delivery	5	14
116647	2020-08-13 12:46:43	2020-08-13	14	[{"id_menu":2,"count":1}]	44489	delivery	5	19
116648	2020-08-13 12:48:26	2020-08-13	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	30841	delivery	5	22
116649	2020-08-13 12:49:30	2020-08-13	9	[{"id_menu":6,"count":1}]	43235	pick-up	0	9
116650	2020-08-13 12:52:02	2020-08-13	9	[{"id_menu":7,"count":1}]	11150	delivery	5	14
116651	2020-08-13 12:52:31	2020-08-13	9	[{"id_menu":6,"count":1}]	26452	pick-up	0	9
116652	2020-08-13 12:53:28	2020-08-13	14	[{"id_menu":2,"count":1}]	11494	pick-up	0	14
116653	2020-08-13 12:54:09	2020-08-13	9	[{"id_menu":6,"count":1}]	9320	pick-up	0	9
116654	2020-08-13 12:54:26	2020-08-13	8	[{"id_menu":5,"count":1}]	44561	delivery	5	13
116655	2020-08-13 12:57:18	2020-08-13	12	[{"id_menu":3,"count":2}]	19307	delivery	5	17
116656	2020-08-13 12:59:47	2020-08-13	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	43134	delivery	5	43
116657	2020-08-13 13:03:07	2020-08-13	14	[{"id_menu":2,"count":1}]	44639	pick-up	0	14
116658	2020-08-13 13:08:55	2020-08-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	44459	delivery	5	28
116659	2020-08-13 13:09:23	2020-08-13	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	19613	delivery	5	26
116660	2020-08-13 13:09:35	2020-08-13	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6632	delivery	5	22
116661	2020-08-13 13:12:53	2020-08-13	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	44481	delivery	5	36
116662	2020-08-13 13:14:08	2020-08-13	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2054	pick-up	0	21
116663	2020-08-13 13:20:37	2020-08-13	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	26116	delivery	5	52
116664	2020-08-13 13:24:55	2020-08-13	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	44664	delivery	5	31
116665	2020-08-13 13:28:52	2020-08-13	17	[{"id_menu":4,"count":1}]	21338	delivery	5	22
116666	2020-08-13 13:30:18	2020-08-13	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	44534	delivery	5	22
116667	2020-08-13 13:31:12	2020-08-13	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	44551	delivery	5	31
116668	2020-08-13 13:32:03	2020-08-13	8	[{"id_menu":5,"count":1}]	44477	delivery	5	13
116669	2020-08-13 13:32:56	2020-08-13	9	[{"id_menu":6,"count":2}]	34822	pick-up	0	9
116670	2020-08-13 13:34:09	2020-08-13	12	[{"id_menu":1,"count":1}]	36980	delivery	5	17
116671	2020-08-13 13:35:49	2020-08-13	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	44511	delivery	5	56
116672	2020-08-13 13:36:43	2020-08-13	14	[{"id_menu":2,"count":1}]	13780	delivery	5	19
116673	2020-08-13 13:41:15	2020-08-13	12	[{"id_menu":1,"count":1}]	43245	pick-up	0	12
116674	2020-08-13 13:43:19	2020-08-13	17	[{"id_menu":4,"count":1}]	32009	delivery	5	22
116675	2020-08-13 13:43:50	2020-08-13	9	[{"id_menu":7,"count":1}]	44496	delivery	5	14
116676	2020-08-13 13:49:19	2020-08-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	44537	delivery	5	36
116677	2020-08-13 13:49:23	2020-08-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	33202	delivery	5	36
116678	2020-08-13 13:53:44	2020-08-13	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15022	delivery	5	34
116679	2020-08-13 13:56:40	2020-08-13	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	27975	delivery	5	36
116680	2020-08-13 13:56:40	2020-08-13	12	[{"id_menu":1,"count":1}]	32491	pick-up	0	12
116681	2020-08-13 13:58:37	2020-08-13	14	[{"id_menu":2,"count":1}]	547	pick-up	0	14
116682	2020-08-13 13:59:56	2020-08-13	9	[{"id_menu":6,"count":1}]	28311	delivery	5	14
116683	2020-08-13 14:03:43	2020-08-13	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	39554	delivery	5	23
116684	2020-08-13 14:03:48	2020-08-13	12	[{"id_menu":1,"count":1}]	18422	delivery	5	17
116685	2020-08-13 14:07:15	2020-08-13	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	44553	delivery	5	22
116686	2020-08-13 14:10:08	2020-08-13	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	44463	delivery	5	26
116687	2020-08-13 14:10:37	2020-08-13	9	[{"id_menu":6,"count":1}]	5333	delivery	5	14
116688	2020-08-13 14:11:27	2020-08-13	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	18922	delivery	5	30
116689	2020-08-13 14:12:17	2020-08-13	17	[{"id_menu":4,"count":1}]	32119	delivery	5	22
116690	2020-08-13 14:18:23	2020-08-13	8	[{"id_menu":5,"count":1}]	31618	pick-up	0	8
116691	2020-08-13 14:18:59	2020-08-13	17	[{"id_menu":4,"count":1}]	22275	delivery	5	22
116692	2020-08-13 14:19:06	2020-08-13	14	[{"id_menu":2,"count":1}]	44655	delivery	5	19
116693	2020-08-13 14:19:56	2020-08-13	9	[{"id_menu":6,"count":1}]	44577	delivery	5	14
116694	2020-08-13 14:21:11	2020-08-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	25071	delivery	5	28
116695	2020-08-13 14:21:50	2020-08-13	12	[{"id_menu":1,"count":2}]	15082	pick-up	0	12
116696	2020-08-13 14:22:25	2020-08-13	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":3}]	8931	delivery	5	25
116697	2020-08-13 14:23:50	2020-08-13	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	44695	delivery	5	31
116698	2020-08-13 14:24:58	2020-08-13	12	[{"id_menu":3,"count":1}]	34745	delivery	5	17
116699	2020-08-13 14:25:11	2020-08-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	13621	delivery	5	28
116700	2020-08-13 14:25:36	2020-08-13	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29436	delivery	5	22
116701	2020-08-13 14:27:32	2020-08-13	12	[{"id_menu":1,"count":1}]	8323	pick-up	0	12
116702	2020-08-13 14:29:10	2020-08-13	12	[{"id_menu":3,"count":1}]	39024	delivery	5	17
116703	2020-08-13 14:30:39	2020-08-13	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	44654	delivery	5	45
116704	2020-08-13 14:30:59	2020-08-13	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	10935	pick-up	0	20
116705	2020-08-13 14:32:01	2020-08-13	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	41499	delivery	5	22
116706	2020-08-13 14:32:11	2020-08-13	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	44504	delivery	5	45
116707	2020-08-13 14:32:43	2020-08-13	9	[{"id_menu":7,"count":1}]	44651	pick-up	0	9
116708	2020-08-13 14:36:10	2020-08-13	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	44638	delivery	5	40
116709	2020-08-13 14:36:18	2020-08-13	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	44557	delivery	5	34
116710	2020-08-13 14:37:35	2020-08-13	14	[{"id_menu":2,"count":1}]	883	pick-up	0	14
116711	2020-08-13 14:39:51	2020-08-13	9	[{"id_menu":7,"count":1}]	39638	delivery	5	14
116712	2020-08-13 14:42:56	2020-08-13	17	[{"id_menu":4,"count":1}]	41610	delivery	5	22
116713	2020-08-13 14:43:39	2020-08-13	12	[{"id_menu":1,"count":1}]	44569	delivery	5	17
116714	2020-08-13 14:46:08	2020-08-13	14	[{"id_menu":2,"count":1}]	7737	delivery	5	19
116715	2020-08-13 14:46:36	2020-08-13	9	[{"id_menu":6,"count":1}]	23863	delivery	5	14
116716	2020-08-13 14:48:03	2020-08-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	21525	delivery	5	23
116717	2020-08-13 14:48:23	2020-08-13	9	[{"id_menu":6,"count":1}]	2845	delivery	5	14
116718	2020-08-13 14:49:23	2020-08-13	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	16890	delivery	5	31
116719	2020-08-13 14:54:55	2020-08-13	9	[{"id_menu":6,"count":1}]	12841	delivery	5	14
116720	2020-08-13 14:55:44	2020-08-13	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	16170	delivery	5	35
116721	2020-08-13 14:57:56	2020-08-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44596	delivery	5	23
116722	2020-08-13 14:58:15	2020-08-13	17	[{"id_menu":4,"count":1}]	2336	pick-up	0	17
116723	2020-08-13 15:02:26	2020-08-13	14	[{"id_menu":2,"count":1}]	10829	pick-up	0	14
116724	2020-08-13 15:03:49	2020-08-13	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	44705	delivery	5	48
116725	2020-08-13 15:04:23	2020-08-13	12	[{"id_menu":1,"count":1}]	39201	delivery	5	17
116726	2020-08-13 15:05:18	2020-08-13	14	[{"id_menu":2,"count":1}]	44306	pick-up	0	14
116727	2020-08-13 15:08:08	2020-08-13	17	[{"id_menu":4,"count":1}]	44597	delivery	5	22
116728	2020-08-13 15:13:02	2020-08-13	14	[{"id_menu":2,"count":1}]	27344	delivery	5	19
116729	2020-08-13 15:16:03	2020-08-13	14	[{"id_menu":2,"count":1}]	12912	pick-up	0	14
116730	2020-08-13 15:16:55	2020-08-13	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	44439	delivery	5	31
116731	2020-08-13 15:17:45	2020-08-13	9	[{"id_menu":7,"count":1}]	1391	delivery	5	14
116732	2020-08-13 15:20:42	2020-08-13	9	[{"id_menu":6,"count":1}]	33313	delivery	5	14
116733	2020-08-13 15:21:34	2020-08-13	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	32913	delivery	5	23
116734	2020-08-13 15:24:36	2020-08-13	8	[{"id_menu":5,"count":1}]	44640	delivery	5	13
116735	2020-08-13 15:25:31	2020-08-13	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	44666	delivery	5	31
116736	2020-08-13 15:25:32	2020-08-13	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	31129	delivery	5	25
116737	2020-08-13 15:26:55	2020-08-13	9	[{"id_menu":7,"count":1}]	10052	delivery	5	14
116738	2020-08-13 15:28:36	2020-08-13	9	[{"id_menu":7,"count":1}]	19238	pick-up	0	9
116739	2020-08-13 15:35:16	2020-08-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	31418	delivery	5	28
116740	2020-08-13 15:37:20	2020-08-13	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	25190	pick-up	0	26
116741	2020-08-13 15:41:40	2020-08-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44593	delivery	5	23
116742	2020-08-13 15:42:11	2020-08-13	8	[{"id_menu":5,"count":1}]	26809	delivery	5	13
116743	2020-08-13 15:45:01	2020-08-13	12	[{"id_menu":3,"count":1}]	23600	delivery	5	17
116744	2020-08-13 15:46:10	2020-08-13	9	[{"id_menu":6,"count":1}]	8754	delivery	5	14
116745	2020-08-13 15:46:57	2020-08-13	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	38162	delivery	5	26
116746	2020-08-13 15:47:36	2020-08-13	9	[{"id_menu":6,"count":1}]	21990	delivery	5	14
116747	2020-08-13 15:52:56	2020-08-13	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27862	delivery	5	36
116748	2020-08-13 15:56:26	2020-08-13	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8154	delivery	5	30
116749	2020-08-13 15:58:25	2020-08-13	14	[{"id_menu":2,"count":1}]	22477	pick-up	0	14
116750	2020-08-13 16:02:29	2020-08-13	17	[{"id_menu":5,"count":3},{"id_menu":7,"count":1}]	44643	delivery	5	22
116751	2020-08-13 16:03:30	2020-08-13	9	[{"id_menu":7,"count":1}]	18207	pick-up	0	9
116752	2020-08-13 16:04:54	2020-08-13	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	11578	delivery	5	35
116753	2020-08-13 16:06:03	2020-08-13	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10354	delivery	5	45
116754	2020-08-13 16:06:29	2020-08-13	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	44686	delivery	5	28
116755	2020-08-13 16:07:11	2020-08-13	8	[{"id_menu":5,"count":1}]	24991	pick-up	0	8
116756	2020-08-13 16:08:37	2020-08-13	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3705	delivery	5	26
116757	2020-08-13 16:08:55	2020-08-13	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	33658	delivery	5	48
116758	2020-08-13 16:11:09	2020-08-13	17	[{"id_menu":4,"count":1}]	44522	pick-up	0	17
116759	2020-08-13 16:11:28	2020-08-13	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	26974	pick-up	0	26
116760	2020-08-13 16:17:46	2020-08-13	12	[{"id_menu":1,"count":1}]	16139	delivery	5	17
116761	2020-08-13 16:18:46	2020-08-13	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	36383	delivery	5	27
116762	2020-08-13 16:19:57	2020-08-13	9	[{"id_menu":7,"count":1}]	13092	pick-up	0	9
116763	2020-08-13 16:20:06	2020-08-13	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	44484	pick-up	0	26
116764	2020-08-13 16:20:11	2020-08-13	9	[{"id_menu":7,"count":1}]	33828	pick-up	0	9
116765	2020-08-13 16:22:43	2020-08-13	14	[{"id_menu":2,"count":1}]	7236	delivery	5	19
116766	2020-08-13 16:28:14	2020-08-13	8	[{"id_menu":5,"count":1}]	7499	delivery	5	13
116767	2020-08-13 16:29:24	2020-08-13	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	44566	delivery	5	43
116768	2020-08-13 16:31:47	2020-08-13	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44521	delivery	5	31
116769	2020-08-13 16:35:33	2020-08-13	9	[{"id_menu":7,"count":1}]	27641	delivery	5	14
116770	2020-08-13 16:38:03	2020-08-13	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4749	delivery	5	30
116771	2020-08-13 16:38:15	2020-08-13	17	[{"id_menu":4,"count":1}]	23294	pick-up	0	17
116772	2020-08-13 16:40:02	2020-08-13	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	20687	delivery	5	31
116773	2020-08-13 16:44:39	2020-08-13	14	[{"id_menu":2,"count":1}]	1714	pick-up	0	14
116774	2020-08-13 16:45:40	2020-08-13	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	44579	delivery	5	27
116775	2020-08-13 16:48:01	2020-08-13	9	[{"id_menu":7,"count":1}]	24920	delivery	5	14
116776	2020-08-13 16:48:01	2020-08-13	12	[{"id_menu":3,"count":1}]	4327	pick-up	0	12
116777	2020-08-13 16:50:55	2020-08-13	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	37598	delivery	5	28
116778	2020-08-13 16:51:38	2020-08-13	9	[{"id_menu":6,"count":1}]	24232	delivery	5	14
116779	2020-08-13 16:56:18	2020-08-13	9	[{"id_menu":7,"count":1}]	44475	delivery	5	14
116780	2020-08-13 16:56:31	2020-08-13	9	[{"id_menu":6,"count":1}]	12183	pick-up	0	9
116781	2020-08-13 16:59:52	2020-08-13	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	44693	delivery	5	26
116782	2020-08-13 17:00:24	2020-08-13	8	[{"id_menu":5,"count":1}]	7394	delivery	5	13
116783	2020-08-13 17:02:37	2020-08-13	9	[{"id_menu":6,"count":1}]	38305	delivery	5	14
116784	2020-08-13 17:02:41	2020-08-13	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	40509	delivery	5	22
116785	2020-08-13 17:02:42	2020-08-13	9	[{"id_menu":6,"count":1}]	43391	delivery	5	14
116786	2020-08-13 17:04:02	2020-08-13	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	44629	delivery	5	40
116787	2020-08-13 17:08:01	2020-08-13	12	[{"id_menu":3,"count":1}]	44648	delivery	5	17
116788	2020-08-13 17:09:29	2020-08-13	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	44456	delivery	5	45
116789	2020-08-13 17:10:46	2020-08-13	12	[{"id_menu":3,"count":1}]	44567	delivery	5	17
116790	2020-08-13 17:11:33	2020-08-13	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44467	delivery	5	35
116791	2020-08-13 17:14:53	2020-08-13	8	[{"id_menu":5,"count":1}]	44570	delivery	5	13
116792	2020-08-13 17:19:56	2020-08-13	9	[{"id_menu":6,"count":1}]	44508	delivery	5	14
116793	2020-08-13 17:22:15	2020-08-13	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23557	delivery	5	22
116794	2020-08-13 17:24:16	2020-08-13	9	[{"id_menu":6,"count":1}]	24524	delivery	5	14
116795	2020-08-13 17:25:59	2020-08-13	14	[{"id_menu":2,"count":1}]	27544	delivery	5	19
116796	2020-08-13 17:26:17	2020-08-13	8	[{"id_menu":5,"count":2}]	13939	pick-up	0	8
116797	2020-08-13 17:27:53	2020-08-13	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	44626	delivery	5	31
116798	2020-08-13 17:31:04	2020-08-13	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	44497	delivery	5	45
116799	2020-08-13 17:33:39	2020-08-13	14	[{"id_menu":2,"count":1}]	32178	pick-up	0	14
116800	2020-08-13 17:35:04	2020-08-13	9	[{"id_menu":6,"count":1}]	42068	delivery	5	14
116801	2020-08-13 17:37:45	2020-08-13	12	[{"id_menu":1,"count":1}]	44516	delivery	5	17
116802	2020-08-13 17:38:59	2020-08-13	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	38002	delivery	5	22
116803	2020-08-13 17:40:54	2020-08-13	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	3425	pick-up	0	24
116804	2020-08-13 17:41:18	2020-08-13	17	[{"id_menu":4,"count":1}]	21424	delivery	5	22
116805	2020-08-13 17:43:11	2020-08-13	12	[{"id_menu":1,"count":1}]	197	delivery	5	17
116806	2020-08-13 17:44:34	2020-08-13	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	44625	delivery	5	27
116807	2020-08-13 17:44:43	2020-08-13	14	[{"id_menu":2,"count":1}]	30291	delivery	5	19
116808	2020-08-13 17:46:00	2020-08-13	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	44619	delivery	5	57
116809	2020-08-13 17:46:48	2020-08-13	14	[{"id_menu":2,"count":1}]	32876	delivery	5	19
116810	2020-08-13 17:49:14	2020-08-13	9	[{"id_menu":7,"count":1}]	39052	delivery	5	14
116811	2020-08-13 17:51:11	2020-08-13	12	[{"id_menu":3,"count":1}]	41244	delivery	5	17
116812	2020-08-13 18:01:38	2020-08-13	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	44461	delivery	5	22
116813	2020-08-13 18:05:28	2020-08-13	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	42317	delivery	5	26
116814	2020-08-13 18:06:49	2020-08-13	17	[{"id_menu":4,"count":1}]	39728	delivery	5	22
116815	2020-08-13 18:07:07	2020-08-13	9	[{"id_menu":6,"count":1}]	6302	delivery	5	14
116816	2020-08-13 18:07:08	2020-08-13	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	6979	delivery	5	43
116817	2020-08-13 18:17:59	2020-08-13	12	[{"id_menu":1,"count":1}]	17795	delivery	5	17
116818	2020-08-13 18:20:58	2020-08-13	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	34394	delivery	5	26
116819	2020-08-13 18:21:23	2020-08-13	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	34301	delivery	5	34
116820	2020-08-13 18:28:42	2020-08-13	9	[{"id_menu":6,"count":1}]	6611	delivery	5	14
116821	2020-08-13 18:31:09	2020-08-13	17	[{"id_menu":4,"count":1}]	44498	delivery	5	22
116822	2020-08-13 18:31:23	2020-08-13	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	44554	delivery	5	45
116823	2020-08-13 18:33:03	2020-08-13	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	41932	delivery	5	22
116824	2020-08-13 18:34:32	2020-08-13	17	[{"id_menu":4,"count":1}]	43713	delivery	5	22
116825	2020-08-13 18:36:12	2020-08-13	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	26600	pick-up	0	21
116826	2020-08-13 18:37:34	2020-08-13	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	44503	delivery	5	22
116827	2020-08-13 18:38:53	2020-08-13	8	[{"id_menu":5,"count":1}]	42394	delivery	5	13
116828	2020-08-13 18:43:45	2020-08-13	8	[{"id_menu":5,"count":1}]	10648	delivery	5	13
116829	2020-08-13 18:45:32	2020-08-13	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44587	delivery	5	31
116830	2020-08-13 18:46:03	2020-08-13	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	44471	delivery	5	26
116831	2020-08-13 18:46:13	2020-08-13	17	[{"id_menu":4,"count":1}]	4401	pick-up	0	17
116832	2020-08-13 18:47:35	2020-08-13	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44532	delivery	5	40
116833	2020-08-13 18:49:04	2020-08-13	8	[{"id_menu":5,"count":1}]	34425	delivery	5	13
116834	2020-08-13 18:53:09	2020-08-13	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14174	delivery	5	31
116835	2020-08-13 18:53:44	2020-08-13	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19751	delivery	5	35
116836	2020-08-13 18:54:09	2020-08-13	12	[{"id_menu":1,"count":1}]	4825	pick-up	0	12
116837	2020-08-13 18:54:29	2020-08-13	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17938	delivery	5	22
116838	2020-08-13 18:54:48	2020-08-13	12	[{"id_menu":3,"count":1}]	44604	delivery	5	17
116839	2020-08-13 19:01:16	2020-08-13	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	2951	delivery	5	31
116840	2020-08-13 19:06:46	2020-08-13	14	[{"id_menu":2,"count":1}]	41548	pick-up	0	14
116841	2020-08-13 19:07:17	2020-08-13	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	19657	delivery	5	30
116842	2020-08-13 19:08:32	2020-08-13	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	10699	delivery	5	22
116843	2020-08-13 19:09:44	2020-08-13	8	[{"id_menu":5,"count":1}]	44582	delivery	5	13
116844	2020-08-13 19:16:00	2020-08-13	8	[{"id_menu":5,"count":1}]	26760	delivery	5	13
116845	2020-08-13 19:18:16	2020-08-13	8	[{"id_menu":5,"count":1}]	2386	delivery	5	13
116846	2020-08-13 19:19:49	2020-08-13	14	[{"id_menu":2,"count":1}]	44442	pick-up	0	14
116847	2020-08-13 19:20:08	2020-08-13	14	[{"id_menu":2,"count":2}]	25367	pick-up	0	14
116848	2020-08-13 19:22:20	2020-08-13	17	[{"id_menu":4,"count":2}]	3148	delivery	5	22
116849	2020-08-13 19:27:15	2020-08-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	38996	delivery	5	28
116850	2020-08-13 19:28:03	2020-08-13	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	44677	pick-up	0	20
116851	2020-08-13 19:28:46	2020-08-13	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	28514	delivery	5	26
116852	2020-08-13 19:29:46	2020-08-13	9	[{"id_menu":7,"count":1}]	8200	delivery	5	14
116853	2020-08-13 19:29:53	2020-08-13	9	[{"id_menu":6,"count":1}]	44536	delivery	5	14
116854	2020-08-13 19:31:45	2020-08-13	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1376	delivery	5	27
116855	2020-08-13 19:31:55	2020-08-13	9	[{"id_menu":7,"count":1}]	44623	delivery	5	14
116856	2020-08-13 19:32:40	2020-08-13	17	[{"id_menu":4,"count":1}]	3684	delivery	5	22
116857	2020-08-13 19:34:56	2020-08-13	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	44630	delivery	5	25
116858	2020-08-13 19:35:58	2020-08-13	9	[{"id_menu":6,"count":1}]	34366	pick-up	0	9
116859	2020-08-13 19:36:57	2020-08-13	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	44706	delivery	5	43
116860	2020-08-13 19:37:38	2020-08-13	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	25394	delivery	5	35
116861	2020-08-13 19:40:55	2020-08-13	14	[{"id_menu":2,"count":1}]	15278	delivery	5	19
116862	2020-08-13 19:44:07	2020-08-13	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16432	delivery	5	22
116863	2020-08-13 19:46:58	2020-08-13	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	28254	delivery	5	43
116864	2020-08-13 19:56:17	2020-08-13	9	[{"id_menu":7,"count":1}]	3640	pick-up	0	9
116865	2020-08-13 20:03:30	2020-08-13	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	27625	delivery	5	39
116866	2020-08-13 20:06:03	2020-08-13	46	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	23457	delivery	5	51
116867	2020-08-13 20:07:19	2020-08-13	12	[{"id_menu":1,"count":1}]	22859	delivery	5	17
116868	2020-08-13 20:08:07	2020-08-13	8	[{"id_menu":5,"count":1}]	44690	delivery	5	13
116869	2020-08-13 20:08:53	2020-08-13	12	[{"id_menu":3,"count":2}]	7151	pick-up	0	12
116870	2020-08-13 20:12:39	2020-08-13	14	[{"id_menu":2,"count":1}]	44578	delivery	5	19
116871	2020-08-13 20:14:03	2020-08-13	12	[{"id_menu":1,"count":1}]	20002	delivery	5	17
116872	2020-08-13 20:17:48	2020-08-13	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	43394	delivery	5	36
116873	2020-08-13 20:19:09	2020-08-13	9	[{"id_menu":6,"count":1}]	44580	delivery	5	14
116874	2020-08-13 20:19:19	2020-08-13	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	44694	delivery	5	25
116875	2020-08-13 20:20:32	2020-08-13	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	25718	delivery	5	34
116876	2020-08-13 20:20:38	2020-08-13	9	[{"id_menu":6,"count":1}]	44469	delivery	5	14
116877	2020-08-13 20:21:35	2020-08-13	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	44528	delivery	5	44
116878	2020-08-13 20:22:15	2020-08-13	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	44549	pick-up	0	26
116879	2020-08-13 20:23:36	2020-08-13	12	[{"id_menu":1,"count":1}]	44564	pick-up	0	12
116880	2020-08-13 20:24:43	2020-08-13	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18839	delivery	5	39
116881	2020-08-13 20:26:30	2020-08-13	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	36638	delivery	5	37
116882	2020-08-13 20:26:54	2020-08-13	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	14269	delivery	5	26
116883	2020-08-13 20:27:55	2020-08-13	14	[{"id_menu":2,"count":1}]	43834	delivery	5	19
116884	2020-08-13 20:28:26	2020-08-13	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	73	pick-up	0	21
116885	2020-08-13 20:29:59	2020-08-13	14	[{"id_menu":2,"count":1}]	1334	delivery	5	19
116886	2020-08-13 20:32:03	2020-08-13	9	[{"id_menu":6,"count":1}]	44679	delivery	5	14
116887	2020-08-13 20:34:40	2020-08-13	9	[{"id_menu":6,"count":1}]	44616	delivery	5	14
116888	2020-08-13 20:37:09	2020-08-13	9	[{"id_menu":7,"count":1}]	30719	delivery	5	14
116889	2020-08-13 20:37:19	2020-08-13	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	12054	pick-up	0	23
116890	2020-08-13 20:38:59	2020-08-13	12	[{"id_menu":3,"count":1}]	27685	delivery	5	17
116891	2020-08-13 20:44:17	2020-08-13	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	33949	delivery	5	39
116892	2020-08-13 20:46:08	2020-08-13	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	23599	delivery	5	26
116893	2020-08-13 20:46:12	2020-08-13	12	[{"id_menu":3,"count":1}]	44472	delivery	5	17
116894	2020-08-13 20:49:11	2020-08-13	14	[{"id_menu":2,"count":1}]	44572	delivery	5	19
116895	2020-08-13 20:49:44	2020-08-13	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	44635	delivery	5	26
116896	2020-08-13 20:52:08	2020-08-13	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2373	pick-up	0	38
116897	2020-08-13 20:52:17	2020-08-13	12	[{"id_menu":3,"count":1}]	37692	delivery	5	17
116898	2020-08-13 20:52:56	2020-08-13	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	2190	delivery	5	27
116899	2020-08-13 20:55:45	2020-08-13	17	[{"id_menu":4,"count":1}]	996	pick-up	0	17
116900	2020-08-13 20:57:26	2020-08-13	8	[{"id_menu":5,"count":1}]	44494	delivery	5	13
116901	2020-08-13 20:57:34	2020-08-13	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	42063	delivery	5	22
116902	2020-08-13 20:59:33	2020-08-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3997	delivery	5	23
116903	2020-08-13 20:59:55	2020-08-13	12	[{"id_menu":3,"count":1}]	33802	delivery	5	17
116904	2020-08-13 21:00:18	2020-08-13	9	[{"id_menu":7,"count":2}]	856	pick-up	0	9
116905	2020-08-13 21:00:29	2020-08-13	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	44501	pick-up	0	25
116906	2020-08-13 21:01:31	2020-08-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	16242	pick-up	0	31
116907	2020-08-13 21:04:49	2020-08-13	12	[{"id_menu":1,"count":1}]	44657	delivery	5	17
116908	2020-08-13 21:06:18	2020-08-13	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	6695	delivery	5	26
116909	2020-08-13 21:07:57	2020-08-13	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	35827	pick-up	0	25
116910	2020-08-13 21:08:16	2020-08-13	12	[{"id_menu":3,"count":1}]	973	delivery	5	17
116911	2020-08-13 21:10:53	2020-08-13	9	[{"id_menu":7,"count":1}]	44446	delivery	5	14
116912	2020-08-13 21:12:30	2020-08-13	14	[{"id_menu":2,"count":2}]	44631	delivery	5	19
116913	2020-08-13 21:13:45	2020-08-13	8	[{"id_menu":5,"count":1}]	43473	delivery	5	13
116914	2020-08-13 21:14:59	2020-08-13	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	44704	delivery	5	56
116982	2020-08-13 22:56:19	2020-08-13	9	[{"id_menu":6,"count":1}]	13786	delivery	5	14
116915	2020-08-13 21:17:21	2020-08-13	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	44519	delivery	5	51
116916	2020-08-13 21:17:39	2020-08-13	17	[{"id_menu":4,"count":1}]	16114	pick-up	0	17
116917	2020-08-13 21:26:24	2020-08-13	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	44455	delivery	5	43
116918	2020-08-13 21:28:17	2020-08-13	12	[{"id_menu":1,"count":1}]	44703	delivery	5	17
116919	2020-08-13 21:33:10	2020-08-13	14	[{"id_menu":2,"count":1}]	29236	delivery	5	19
116920	2020-08-13 21:34:05	2020-08-13	9	[{"id_menu":6,"count":1}]	35704	delivery	5	14
116921	2020-08-13 21:35:06	2020-08-13	14	[{"id_menu":2,"count":1}]	2147	delivery	5	19
116922	2020-08-13 21:36:20	2020-08-13	17	[{"id_menu":4,"count":1}]	12623	pick-up	0	17
116923	2020-08-13 21:37:12	2020-08-13	17	[{"id_menu":4,"count":1}]	44642	delivery	5	22
116924	2020-08-13 21:39:06	2020-08-13	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	20902	delivery	5	39
116925	2020-08-13 21:39:56	2020-08-13	9	[{"id_menu":7,"count":1}]	44658	delivery	5	14
116926	2020-08-13 21:39:58	2020-08-13	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	3600	pick-up	0	20
116927	2020-08-13 21:40:10	2020-08-13	12	[{"id_menu":1,"count":1}]	3142	delivery	5	17
116928	2020-08-13 21:41:20	2020-08-13	17	[{"id_menu":4,"count":1}]	44535	pick-up	0	17
116929	2020-08-13 21:41:28	2020-08-13	9	[{"id_menu":7,"count":1}]	14495	delivery	5	14
116930	2020-08-13 21:41:53	2020-08-13	12	[{"id_menu":1,"count":1}]	44509	delivery	5	17
116931	2020-08-13 21:41:57	2020-08-13	14	[{"id_menu":2,"count":1}]	25053	pick-up	0	14
116932	2020-08-13 21:44:07	2020-08-13	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	31980	delivery	5	26
116933	2020-08-13 21:45:01	2020-08-13	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17524	delivery	5	37
116934	2020-08-13 21:45:58	2020-08-13	17	[{"id_menu":4,"count":1}]	44539	delivery	5	22
116935	2020-08-13 21:51:37	2020-08-13	9	[{"id_menu":6,"count":1}]	30455	pick-up	0	9
116936	2020-08-13 21:55:01	2020-08-13	17	[{"id_menu":4,"count":1}]	382	delivery	5	22
116937	2020-08-13 21:55:24	2020-08-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44443	delivery	5	23
116938	2020-08-13 21:56:38	2020-08-13	12	[{"id_menu":1,"count":1}]	44512	delivery	5	17
116939	2020-08-13 21:58:32	2020-08-13	12	[{"id_menu":1,"count":2}]	40564	pick-up	0	12
116940	2020-08-13 21:58:55	2020-08-13	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	44559	delivery	5	29
116941	2020-08-13 22:03:20	2020-08-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	44680	delivery	5	36
116942	2020-08-13 22:04:06	2020-08-13	14	[{"id_menu":2,"count":1}]	18102	delivery	5	19
116943	2020-08-13 22:04:40	2020-08-13	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8852	delivery	5	22
116944	2020-08-13 22:05:35	2020-08-13	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	44568	delivery	5	22
116945	2020-08-13 22:06:47	2020-08-13	14	[{"id_menu":2,"count":1}]	2299	pick-up	0	14
116946	2020-08-13 22:08:00	2020-08-13	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	44606	pick-up	0	43
116947	2020-08-13 22:14:00	2020-08-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	44453	delivery	5	23
116948	2020-08-13 22:15:01	2020-08-13	9	[{"id_menu":7,"count":2}]	3795	delivery	5	14
116949	2020-08-13 22:15:18	2020-08-13	12	[{"id_menu":3,"count":1}]	44674	pick-up	0	12
116950	2020-08-13 22:15:20	2020-08-13	9	[{"id_menu":6,"count":1}]	24857	delivery	5	14
116951	2020-08-13 22:15:22	2020-08-13	14	[{"id_menu":2,"count":1}]	437	delivery	5	19
116952	2020-08-13 22:17:22	2020-08-13	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	193	pick-up	0	29
116953	2020-08-13 22:18:21	2020-08-13	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	44685	delivery	5	26
116954	2020-08-13 22:19:03	2020-08-13	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	44502	delivery	5	28
116955	2020-08-13 22:19:35	2020-08-13	8	[{"id_menu":5,"count":1}]	37799	delivery	5	13
116956	2020-08-13 22:20:13	2020-08-13	14	[{"id_menu":2,"count":1}]	37531	pick-up	0	14
116957	2020-08-13 22:21:54	2020-08-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2089	pick-up	0	31
116958	2020-08-13 22:24:50	2020-08-13	17	[{"id_menu":4,"count":1}]	44676	delivery	5	22
116959	2020-08-13 22:25:20	2020-08-13	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	44571	delivery	5	22
116960	2020-08-13 22:26:50	2020-08-13	8	[{"id_menu":5,"count":1}]	16812	delivery	5	13
116961	2020-08-13 22:30:43	2020-08-13	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	15847	delivery	5	26
116962	2020-08-13 22:35:33	2020-08-13	8	[{"id_menu":5,"count":1}]	44689	delivery	5	13
116963	2020-08-13 22:37:56	2020-08-13	9	[{"id_menu":6,"count":1}]	11832	delivery	5	14
116964	2020-08-13 22:40:29	2020-08-13	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15891	delivery	5	43
116965	2020-08-13 22:42:52	2020-08-13	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	41143	delivery	5	36
116966	2020-08-13 22:43:31	2020-08-13	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	44507	delivery	5	43
116967	2020-08-13 22:44:13	2020-08-13	12	[{"id_menu":1,"count":1}]	10606	delivery	5	17
116968	2020-08-13 22:46:03	2020-08-13	9	[{"id_menu":6,"count":1}]	11698	delivery	5	14
116969	2020-08-13 22:48:08	2020-08-13	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	44673	delivery	5	37
116970	2020-08-13 22:48:19	2020-08-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	2275	pick-up	0	18
116971	2020-08-13 22:48:39	2020-08-13	14	[{"id_menu":2,"count":1}]	5792	delivery	5	19
116972	2020-08-13 22:49:35	2020-08-13	9	[{"id_menu":7,"count":1}]	19234	delivery	5	14
116973	2020-08-13 22:51:02	2020-08-13	12	[{"id_menu":1,"count":1}]	24733	pick-up	0	12
116974	2020-08-13 22:51:57	2020-08-13	8	[{"id_menu":5,"count":2}]	44586	pick-up	0	8
116975	2020-08-13 22:52:43	2020-08-13	9	[{"id_menu":7,"count":1}]	20752	delivery	5	14
116976	2020-08-13 22:52:43	2020-08-13	17	[{"id_menu":4,"count":1}]	32042	delivery	5	22
116977	2020-08-13 22:53:07	2020-08-13	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	36636	delivery	5	31
116978	2020-08-13 22:53:22	2020-08-13	14	[{"id_menu":2,"count":1}]	1552	pick-up	0	14
116979	2020-08-13 22:54:26	2020-08-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	44696	delivery	5	23
116980	2020-08-13 22:55:44	2020-08-13	9	[{"id_menu":7,"count":1}]	8231	delivery	5	14
116981	2020-08-13 22:56:08	2020-08-13	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	44448	delivery	5	30
116983	2020-08-13 22:56:25	2020-08-13	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	11440	delivery	5	35
116984	2020-08-13 22:59:46	2020-08-13	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	299	pick-up	0	31
116985	2020-08-13 22:59:50	2020-08-13	9	[{"id_menu":6,"count":1}]	26520	delivery	5	14
116986	2020-08-13 23:04:01	2020-08-13	9	[{"id_menu":6,"count":1}]	3003	pick-up	0	9
116987	2020-08-13 23:05:49	2020-08-13	14	[{"id_menu":2,"count":1}]	15948	pick-up	0	14
116988	2020-08-13 23:06:11	2020-08-13	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	4581	delivery	5	40
116989	2020-08-13 23:06:52	2020-08-13	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2333	pick-up	0	26
116990	2020-08-13 23:07:37	2020-08-13	9	[{"id_menu":7,"count":1}]	44636	delivery	5	14
116991	2020-08-13 23:08:24	2020-08-13	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	35914	delivery	5	22
116992	2020-08-13 23:10:27	2020-08-13	9	[{"id_menu":7,"count":1}]	23835	delivery	5	14
116993	2020-08-13 23:12:51	2020-08-13	14	[{"id_menu":2,"count":1}]	4711	pick-up	0	14
116994	2020-08-13 23:14:50	2020-08-13	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	44495	delivery	5	31
116995	2020-08-13 23:16:13	2020-08-13	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	44652	delivery	5	34
116996	2020-08-13 23:17:14	2020-08-13	9	[{"id_menu":6,"count":1}]	42162	delivery	5	14
116997	2020-08-13 23:18:39	2020-08-13	14	[{"id_menu":2,"count":1}]	30093	pick-up	0	14
116998	2020-08-13 23:18:53	2020-08-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44474	delivery	5	23
116999	2020-08-13 23:19:22	2020-08-13	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	42919	delivery	5	23
117000	2020-08-13 23:21:27	2020-08-13	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36957	pick-up	0	30
117001	2020-08-13 23:22:11	2020-08-13	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	44573	delivery	5	26
117002	2020-08-13 23:23:19	2020-08-13	17	[{"id_menu":4,"count":1}]	44662	delivery	5	22
117003	2020-08-13 23:24:19	2020-08-13	9	[{"id_menu":6,"count":1}]	44548	delivery	5	14
117004	2020-08-13 23:25:10	2020-08-13	9	[{"id_menu":6,"count":1}]	15556	delivery	5	14
117005	2020-08-13 23:27:02	2020-08-13	9	[{"id_menu":7,"count":1}]	12417	delivery	5	14
117006	2020-08-13 23:28:30	2020-08-13	9	[{"id_menu":7,"count":1}]	43474	delivery	5	14
117007	2020-08-13 23:30:53	2020-08-13	9	[{"id_menu":7,"count":1}]	32416	delivery	5	14
117008	2020-08-13 23:32:26	2020-08-13	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15678	pick-up	0	34
117009	2020-08-13 23:34:38	2020-08-13	12	[{"id_menu":3,"count":1}]	44575	delivery	5	17
117010	2020-08-13 23:35:16	2020-08-13	9	[{"id_menu":6,"count":1}]	30634	pick-up	0	9
117011	2020-08-13 23:36:45	2020-08-13	9	[{"id_menu":6,"count":1}]	25073	delivery	5	14
117012	2020-08-13 23:37:55	2020-08-13	9	[{"id_menu":6,"count":1}]	2783	pick-up	0	9
117013	2020-08-13 23:39:16	2020-08-13	14	[{"id_menu":2,"count":1}]	27153	delivery	5	19
117014	2020-08-13 23:40:48	2020-08-13	9	[{"id_menu":6,"count":1}]	24081	delivery	5	14
117015	2020-08-13 23:41:22	2020-08-13	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9835	delivery	5	40
117016	2020-08-13 23:42:16	2020-08-13	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	44659	delivery	5	22
117017	2020-08-13 23:43:56	2020-08-13	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	19300	pick-up	0	26
117018	2020-08-13 23:45:00	2020-08-13	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	36658	pick-up	0	21
117019	2020-08-13 23:45:16	2020-08-13	9	[{"id_menu":7,"count":1}]	14585	pick-up	0	9
117020	2020-08-13 23:51:39	2020-08-13	8	[{"id_menu":5,"count":2}]	44440	delivery	5	13
117021	2020-08-13 23:51:42	2020-08-13	9	[{"id_menu":6,"count":1}]	44650	delivery	5	14
117022	2020-08-13 23:53:37	2020-08-13	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	39648	delivery	5	28
117023	2020-08-13 23:53:39	2020-08-13	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	22425	delivery	5	45
117024	2020-08-13 23:56:00	2020-08-13	9	[{"id_menu":6,"count":1}]	16181	delivery	5	14
117025	2020-08-13 23:58:40	2020-08-13	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	42368	delivery	5	34
117026	2020-08-13 23:59:12	2020-08-13	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	23195	delivery	5	40
117027	2020-08-14 00:04:02	2020-08-14	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	38228	delivery	5	48
117028	2020-08-14 00:06:24	2020-08-14	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10799	delivery	5	31
117029	2020-08-14 00:12:50	2020-08-14	14	[{"id_menu":2,"count":1}]	14735	delivery	5	19
117030	2020-08-14 00:16:03	2020-08-14	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	6468	pick-up	0	21
117031	2020-08-14 00:21:25	2020-08-14	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40704	delivery	5	40
117032	2020-08-14 00:24:47	2020-08-14	14	[{"id_menu":2,"count":1}]	21697	delivery	5	19
117033	2020-08-14 00:24:50	2020-08-14	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44866	delivery	5	40
117034	2020-08-14 00:28:31	2020-08-14	8	[{"id_menu":5,"count":1}]	44723	delivery	5	13
117035	2020-08-14 00:32:45	2020-08-14	8	[{"id_menu":5,"count":1}]	13627	delivery	5	13
117036	2020-08-14 00:33:56	2020-08-14	14	[{"id_menu":2,"count":1}]	16152	delivery	5	19
117037	2020-08-14 00:33:57	2020-08-14	9	[{"id_menu":6,"count":1}]	41409	delivery	5	14
117038	2020-08-14 00:34:53	2020-08-14	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	26742	delivery	5	42
117039	2020-08-14 00:35:02	2020-08-14	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	36917	delivery	5	43
117040	2020-08-14 00:35:23	2020-08-14	12	[{"id_menu":1,"count":1}]	44863	delivery	5	17
117041	2020-08-14 00:35:32	2020-08-14	9	[{"id_menu":6,"count":1}]	44779	delivery	5	14
117042	2020-08-14 00:35:33	2020-08-14	9	[{"id_menu":6,"count":1}]	12699	delivery	5	14
117043	2020-08-14 00:40:27	2020-08-14	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2821	pick-up	0	21
117044	2020-08-14 00:41:41	2020-08-14	9	[{"id_menu":7,"count":2}]	44893	delivery	5	14
117045	2020-08-14 00:42:54	2020-08-14	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	44940	delivery	5	31
117046	2020-08-14 00:46:45	2020-08-14	9	[{"id_menu":7,"count":3}]	44747	delivery	5	14
117047	2020-08-14 00:47:52	2020-08-14	9	[{"id_menu":7,"count":1}]	44900	delivery	5	14
117048	2020-08-14 00:48:17	2020-08-14	12	[{"id_menu":1,"count":1}]	1093	pick-up	0	12
117049	2020-08-14 00:48:57	2020-08-14	9	[{"id_menu":7,"count":1}]	6417	delivery	5	14
117050	2020-08-14 00:51:37	2020-08-14	8	[{"id_menu":5,"count":1}]	6918	delivery	5	13
117051	2020-08-14 00:53:40	2020-08-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	20606	delivery	5	28
117052	2020-08-14 00:55:50	2020-08-14	12	[{"id_menu":3,"count":1}]	44784	delivery	5	17
117053	2020-08-14 00:58:06	2020-08-14	8	[{"id_menu":5,"count":1}]	43124	delivery	5	13
117054	2020-08-14 00:59:43	2020-08-14	12	[{"id_menu":3,"count":1}]	44787	pick-up	0	12
117055	2020-08-14 01:00:31	2020-08-14	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	44933	delivery	5	42
117056	2020-08-14 01:00:41	2020-08-14	8	[{"id_menu":5,"count":2}]	44748	delivery	5	13
117057	2020-08-14 01:03:01	2020-08-14	14	[{"id_menu":2,"count":1}]	24392	delivery	5	19
117058	2020-08-14 01:04:49	2020-08-14	8	[{"id_menu":5,"count":1}]	15088	delivery	5	13
117059	2020-08-14 01:05:19	2020-08-14	9	[{"id_menu":6,"count":1}]	17046	delivery	5	14
117060	2020-08-14 01:08:23	2020-08-14	9	[{"id_menu":7,"count":1}]	19073	delivery	5	14
117061	2020-08-14 01:17:26	2020-08-14	8	[{"id_menu":5,"count":1}]	944	delivery	5	13
117062	2020-08-14 01:18:13	2020-08-14	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	37304	delivery	5	26
117063	2020-08-14 01:18:18	2020-08-14	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	10497	delivery	5	27
117064	2020-08-14 01:18:53	2020-08-14	12	[{"id_menu":1,"count":1}]	37402	delivery	5	17
117065	2020-08-14 01:22:18	2020-08-14	14	[{"id_menu":2,"count":1}]	1815	pick-up	0	14
117066	2020-08-14 01:25:49	2020-08-14	8	[{"id_menu":5,"count":1}]	627	pick-up	0	8
117067	2020-08-14 01:30:23	2020-08-14	17	[{"id_menu":4,"count":1}]	39683	delivery	5	22
117068	2020-08-14 01:32:04	2020-08-14	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	29608	delivery	5	31
117069	2020-08-14 01:37:05	2020-08-14	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26425	delivery	5	23
117070	2020-08-14 01:39:08	2020-08-14	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	37644	pick-up	0	22
117071	2020-08-14 01:42:14	2020-08-14	12	[{"id_menu":3,"count":1}]	18808	delivery	5	17
117072	2020-08-14 01:44:57	2020-08-14	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	13856	delivery	5	26
117073	2020-08-14 01:45:57	2020-08-14	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	34490	delivery	5	26
117074	2020-08-14 01:51:26	2020-08-14	17	[{"id_menu":4,"count":1}]	19181	pick-up	0	17
117075	2020-08-14 01:53:29	2020-08-14	14	[{"id_menu":2,"count":1}]	9591	delivery	5	19
117076	2020-08-14 01:53:51	2020-08-14	9	[{"id_menu":6,"count":1}]	42790	delivery	5	14
117077	2020-08-14 01:54:01	2020-08-14	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6116	delivery	5	40
117078	2020-08-14 01:54:09	2020-08-14	9	[{"id_menu":7,"count":1}]	39778	delivery	5	14
117079	2020-08-14 01:58:44	2020-08-14	9	[{"id_menu":6,"count":1}]	5180	pick-up	0	9
117080	2020-08-14 01:59:52	2020-08-14	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11550	delivery	5	39
117081	2020-08-14 02:05:04	2020-08-14	14	[{"id_menu":2,"count":1}]	44794	pick-up	0	14
117082	2020-08-14 02:08:18	2020-08-14	9	[{"id_menu":6,"count":1}]	43864	pick-up	0	9
117083	2020-08-14 02:11:19	2020-08-14	8	[{"id_menu":5,"count":1}]	44789	delivery	5	13
117084	2020-08-14 02:20:58	2020-08-14	9	[{"id_menu":7,"count":1}]	44929	delivery	5	14
117085	2020-08-14 02:26:33	2020-08-14	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17114	delivery	5	31
117086	2020-08-14 02:34:05	2020-08-14	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	44848	delivery	5	29
117087	2020-08-14 02:40:45	2020-08-14	17	[{"id_menu":4,"count":1}]	33626	delivery	5	22
117088	2020-08-14 02:46:00	2020-08-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31101	pick-up	0	17
117089	2020-08-14 02:54:28	2020-08-14	9	[{"id_menu":7,"count":1}]	8445	delivery	5	14
117090	2020-08-14 02:58:37	2020-08-14	12	[{"id_menu":1,"count":1}]	4877	delivery	5	17
117091	2020-08-14 02:59:40	2020-08-14	12	[{"id_menu":3,"count":1}]	30154	delivery	5	17
117092	2020-08-14 02:59:43	2020-08-14	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13371	delivery	5	39
117093	2020-08-14 03:00:57	2020-08-14	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	7215	delivery	5	26
117094	2020-08-14 03:06:04	2020-08-14	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	44833	delivery	5	31
117095	2020-08-14 03:06:21	2020-08-14	12	[{"id_menu":3,"count":1}]	44867	pick-up	0	12
117096	2020-08-14 03:08:07	2020-08-14	8	[{"id_menu":5,"count":1}]	44806	delivery	5	13
117097	2020-08-14 03:08:22	2020-08-14	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	23252	delivery	5	38
117098	2020-08-14 03:10:09	2020-08-14	9	[{"id_menu":7,"count":1}]	44714	delivery	5	14
117099	2020-08-14 03:17:31	2020-08-14	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	44897	pick-up	0	24
117100	2020-08-14 03:20:36	2020-08-14	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	6425	delivery	5	34
117101	2020-08-14 03:32:40	2020-08-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7304	pick-up	0	26
117102	2020-08-14 03:33:32	2020-08-14	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	17351	delivery	5	27
117103	2020-08-14 03:33:47	2020-08-14	14	[{"id_menu":2,"count":1}]	28899	delivery	5	19
117104	2020-08-14 03:36:28	2020-08-14	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44807	delivery	5	23
117105	2020-08-14 03:36:29	2020-08-14	17	[{"id_menu":4,"count":1}]	40148	delivery	5	22
117106	2020-08-14 03:39:29	2020-08-14	12	[{"id_menu":1,"count":1}]	7280	delivery	5	17
117107	2020-08-14 03:41:34	2020-08-14	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	44826	delivery	5	31
117108	2020-08-14 03:44:13	2020-08-14	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	44814	delivery	5	34
117109	2020-08-14 03:47:17	2020-08-14	12	[{"id_menu":3,"count":1}]	44939	delivery	5	17
117110	2020-08-14 03:49:53	2020-08-14	17	[{"id_menu":4,"count":1}]	16585	delivery	5	22
117111	2020-08-14 03:52:34	2020-08-14	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3348	delivery	5	35
117112	2020-08-14 04:00:21	2020-08-14	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	28058	delivery	5	34
117113	2020-08-14 04:03:55	2020-08-14	12	[{"id_menu":3,"count":1}]	2275	pick-up	0	12
117114	2020-08-14 04:08:20	2020-08-14	17	[{"id_menu":4,"count":1}]	19957	pick-up	0	17
117115	2020-08-14 04:09:13	2020-08-14	8	[{"id_menu":5,"count":1}]	3952	delivery	5	13
117116	2020-08-14 04:15:26	2020-08-14	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	43830	delivery	5	26
117117	2020-08-14 04:17:12	2020-08-14	9	[{"id_menu":7,"count":1}]	5160	delivery	5	14
117118	2020-08-14 04:17:52	2020-08-14	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	36284	delivery	5	37
117119	2020-08-14 04:28:00	2020-08-14	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	13760	pick-up	0	23
117120	2020-08-14 04:33:29	2020-08-14	12	[{"id_menu":1,"count":1}]	17173	pick-up	0	12
117121	2020-08-14 04:34:20	2020-08-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	1369	delivery	5	36
117122	2020-08-14 04:41:19	2020-08-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	31318	delivery	5	36
117123	2020-08-14 04:42:04	2020-08-14	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44734	delivery	5	49
117124	2020-08-14 04:44:02	2020-08-14	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	26349	delivery	5	44
117125	2020-08-14 04:47:29	2020-08-14	14	[{"id_menu":2,"count":1}]	44916	delivery	5	19
117126	2020-08-14 04:49:06	2020-08-14	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	40366	delivery	5	40
117127	2020-08-14 04:49:57	2020-08-14	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	236	pick-up	0	20
117128	2020-08-14 04:52:30	2020-08-14	9	[{"id_menu":6,"count":1}]	44896	delivery	5	14
117129	2020-08-14 04:52:59	2020-08-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8181	delivery	5	31
117130	2020-08-14 04:53:35	2020-08-14	17	[{"id_menu":4,"count":1}]	29832	pick-up	0	17
117131	2020-08-14 04:55:21	2020-08-14	12	[{"id_menu":1,"count":1}]	1460	pick-up	0	12
117132	2020-08-14 05:00:15	2020-08-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	44843	delivery	5	22
117133	2020-08-14 05:00:58	2020-08-14	8	[{"id_menu":5,"count":1}]	41396	pick-up	0	8
117134	2020-08-14 05:05:40	2020-08-14	9	[{"id_menu":6,"count":1}]	44731	delivery	5	14
117135	2020-08-14 05:08:08	2020-08-14	9	[{"id_menu":7,"count":1}]	30998	delivery	5	14
117136	2020-08-14 05:11:31	2020-08-14	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	26781	delivery	5	26
117137	2020-08-14 05:12:30	2020-08-14	12	[{"id_menu":3,"count":1}]	25254	pick-up	0	12
117138	2020-08-14 05:12:55	2020-08-14	8	[{"id_menu":5,"count":1}]	44942	delivery	5	13
117139	2020-08-14 05:13:14	2020-08-14	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	44888	delivery	5	31
117140	2020-08-14 05:18:21	2020-08-14	9	[{"id_menu":7,"count":1}]	44729	pick-up	0	9
117141	2020-08-14 05:19:48	2020-08-14	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	12778	delivery	5	26
117142	2020-08-14 05:25:02	2020-08-14	9	[{"id_menu":7,"count":1}]	24948	delivery	5	14
117143	2020-08-14 05:26:17	2020-08-14	9	[{"id_menu":7,"count":2}]	15643	delivery	5	14
117144	2020-08-14 05:28:00	2020-08-14	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	9554	delivery	5	23
117145	2020-08-14 05:32:19	2020-08-14	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	37037	delivery	5	27
117146	2020-08-14 05:32:28	2020-08-14	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	35599	pick-up	0	29
117147	2020-08-14 05:32:44	2020-08-14	17	[{"id_menu":4,"count":1}]	44959	delivery	5	22
117148	2020-08-14 05:34:54	2020-08-14	9	[{"id_menu":6,"count":1}]	38236	delivery	5	14
117149	2020-08-14 05:38:28	2020-08-14	14	[{"id_menu":2,"count":1}]	30385	delivery	5	19
117150	2020-08-14 05:39:19	2020-08-14	17	[{"id_menu":4,"count":1}]	33067	delivery	5	22
117151	2020-08-14 05:39:28	2020-08-14	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44777	delivery	5	37
117152	2020-08-14 05:39:30	2020-08-14	17	[{"id_menu":4,"count":1}]	44926	delivery	5	22
117153	2020-08-14 05:40:45	2020-08-14	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	44762	delivery	5	25
117154	2020-08-14 05:43:15	2020-08-14	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	32158	delivery	5	28
117155	2020-08-14 05:49:22	2020-08-14	9	[{"id_menu":6,"count":1}]	19771	delivery	5	14
117156	2020-08-14 05:51:24	2020-08-14	12	[{"id_menu":3,"count":1}]	19509	delivery	5	17
117157	2020-08-14 05:53:32	2020-08-14	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	34239	delivery	5	27
117158	2020-08-14 05:54:28	2020-08-14	9	[{"id_menu":7,"count":1}]	31439	pick-up	0	9
117159	2020-08-14 05:55:28	2020-08-14	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	10163	delivery	5	25
117160	2020-08-14 05:58:54	2020-08-14	12	[{"id_menu":1,"count":1}]	34865	delivery	5	17
117161	2020-08-14 06:00:44	2020-08-14	9	[{"id_menu":6,"count":1}]	43828	delivery	5	14
117162	2020-08-14 06:00:54	2020-08-14	14	[{"id_menu":2,"count":2}]	19229	delivery	5	19
117163	2020-08-14 06:01:29	2020-08-14	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32487	delivery	5	35
117164	2020-08-14 06:01:41	2020-08-14	9	[{"id_menu":7,"count":1}]	44909	delivery	5	14
117165	2020-08-14 06:03:34	2020-08-14	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39657	delivery	5	34
117166	2020-08-14 06:09:00	2020-08-14	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	25027	delivery	5	28
117167	2020-08-14 06:09:38	2020-08-14	14	[{"id_menu":2,"count":1}]	27794	delivery	5	19
117168	2020-08-14 06:13:30	2020-08-14	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	3665	delivery	5	25
117169	2020-08-14 06:14:51	2020-08-14	14	[{"id_menu":2,"count":2}]	696	pick-up	0	14
117170	2020-08-14 06:14:57	2020-08-14	14	[{"id_menu":2,"count":1}]	44834	delivery	5	19
117171	2020-08-14 06:16:49	2020-08-14	8	[{"id_menu":5,"count":2}]	44932	delivery	5	13
117172	2020-08-14 06:17:00	2020-08-14	9	[{"id_menu":7,"count":1}]	12030	delivery	5	14
117173	2020-08-14 06:23:37	2020-08-14	17	[{"id_menu":4,"count":1}]	44869	delivery	5	22
117174	2020-08-14 06:24:24	2020-08-14	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	33477	delivery	5	26
117175	2020-08-14 06:26:13	2020-08-14	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23787	delivery	5	48
117176	2020-08-14 06:27:05	2020-08-14	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	6528	delivery	5	27
117177	2020-08-14 06:27:29	2020-08-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	32288	delivery	5	31
117178	2020-08-14 06:31:32	2020-08-14	9	[{"id_menu":6,"count":1}]	44873	delivery	5	14
117179	2020-08-14 06:32:00	2020-08-14	9	[{"id_menu":6,"count":1}]	44831	delivery	5	14
117180	2020-08-14 06:32:38	2020-08-14	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	11655	delivery	5	39
117181	2020-08-14 06:35:49	2020-08-14	8	[{"id_menu":5,"count":1}]	44954	pick-up	0	8
117182	2020-08-14 06:35:51	2020-08-14	14	[{"id_menu":2,"count":1}]	44783	delivery	5	19
117183	2020-08-14 06:37:05	2020-08-14	9	[{"id_menu":7,"count":3}]	44448	delivery	5	14
117184	2020-08-14 06:37:38	2020-08-14	17	[{"id_menu":4,"count":1}]	646	pick-up	0	17
117185	2020-08-14 06:37:52	2020-08-14	12	[{"id_menu":1,"count":1}]	19296	delivery	5	17
117186	2020-08-14 06:40:20	2020-08-14	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	38860	delivery	5	31
117187	2020-08-14 06:48:33	2020-08-14	14	[{"id_menu":2,"count":1}]	8379	delivery	5	19
117188	2020-08-14 06:49:11	2020-08-14	9	[{"id_menu":7,"count":1}]	24059	delivery	5	14
117189	2020-08-14 06:51:30	2020-08-14	9	[{"id_menu":7,"count":1}]	44741	delivery	5	14
117190	2020-08-14 06:52:23	2020-08-14	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	26187	delivery	5	23
117191	2020-08-14 06:52:27	2020-08-14	12	[{"id_menu":3,"count":1}]	7061	delivery	5	17
117192	2020-08-14 06:55:17	2020-08-14	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	31950	pick-up	0	24
117193	2020-08-14 06:55:26	2020-08-14	9	[{"id_menu":7,"count":3}]	44827	delivery	5	14
117194	2020-08-14 06:58:22	2020-08-14	8	[{"id_menu":5,"count":1}]	44859	delivery	5	13
117195	2020-08-14 07:03:15	2020-08-14	8	[{"id_menu":5,"count":1}]	12615	delivery	5	13
117196	2020-08-14 07:06:35	2020-08-14	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43869	delivery	5	45
117197	2020-08-14 07:11:35	2020-08-14	9	[{"id_menu":6,"count":1}]	9651	delivery	5	14
117198	2020-08-14 07:12:04	2020-08-14	17	[{"id_menu":4,"count":1}]	44835	pick-up	0	17
117199	2020-08-14 07:12:20	2020-08-14	12	[{"id_menu":3,"count":1}]	21142	delivery	5	17
117200	2020-08-14 07:12:27	2020-08-14	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	44816	delivery	5	26
117201	2020-08-14 07:15:11	2020-08-14	17	[{"id_menu":4,"count":1}]	1819	pick-up	0	17
117202	2020-08-14 07:17:07	2020-08-14	14	[{"id_menu":2,"count":1}]	15715	pick-up	0	14
117203	2020-08-14 07:20:49	2020-08-14	9	[{"id_menu":7,"count":1}]	24465	delivery	5	14
117204	2020-08-14 07:22:11	2020-08-14	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18874	delivery	5	48
117205	2020-08-14 07:40:26	2020-08-14	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	14965	delivery	5	26
117206	2020-08-14 07:42:29	2020-08-14	8	[{"id_menu":5,"count":1}]	44820	delivery	5	13
117207	2020-08-14 07:43:44	2020-08-14	8	[{"id_menu":5,"count":1}]	44825	delivery	5	13
117208	2020-08-14 07:44:58	2020-08-14	9	[{"id_menu":6,"count":1}]	44716	delivery	5	14
117209	2020-08-14 07:45:39	2020-08-14	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	23797	delivery	5	30
117210	2020-08-14 07:46:28	2020-08-14	12	[{"id_menu":3,"count":1}]	44822	delivery	5	17
117211	2020-08-14 07:49:30	2020-08-14	17	[{"id_menu":4,"count":1}]	41546	delivery	5	22
117212	2020-08-14 07:50:28	2020-08-14	9	[{"id_menu":6,"count":1}]	44875	delivery	5	14
117213	2020-08-14 07:50:58	2020-08-14	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	5822	delivery	5	26
117214	2020-08-14 07:51:41	2020-08-14	9	[{"id_menu":7,"count":1}]	39946	delivery	5	14
117215	2020-08-14 07:53:25	2020-08-14	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44749	delivery	5	35
117216	2020-08-14 07:54:24	2020-08-14	9	[{"id_menu":7,"count":1}]	11922	delivery	5	14
117217	2020-08-14 07:56:53	2020-08-14	12	[{"id_menu":3,"count":1}]	44718	delivery	5	17
117218	2020-08-14 08:00:23	2020-08-14	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14779	delivery	5	36
117219	2020-08-14 08:01:14	2020-08-14	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6107	delivery	5	43
117220	2020-08-14 08:01:33	2020-08-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	10444	delivery	5	22
117221	2020-08-14 08:04:27	2020-08-14	9	[{"id_menu":6,"count":1}]	38203	delivery	5	14
117222	2020-08-14 08:04:49	2020-08-14	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	39797	delivery	5	25
117223	2020-08-14 08:05:39	2020-08-14	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	44737	delivery	5	36
117224	2020-08-14 08:12:35	2020-08-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	44917	delivery	5	28
117225	2020-08-14 08:14:47	2020-08-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	16459	delivery	5	36
117226	2020-08-14 08:16:47	2020-08-14	9	[{"id_menu":7,"count":2}]	44948	delivery	5	14
117227	2020-08-14 08:17:09	2020-08-14	8	[{"id_menu":5,"count":1}]	4605	delivery	5	13
117228	2020-08-14 08:17:42	2020-08-14	12	[{"id_menu":1,"count":1}]	23709	pick-up	0	12
117229	2020-08-14 08:17:43	2020-08-14	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24074	delivery	5	22
117230	2020-08-14 08:19:58	2020-08-14	12	[{"id_menu":3,"count":1}]	30977	delivery	5	17
117231	2020-08-14 08:19:59	2020-08-14	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	44845	delivery	5	43
117232	2020-08-14 08:21:21	2020-08-14	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34157	delivery	5	23
117233	2020-08-14 08:27:50	2020-08-14	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	34259	delivery	5	26
117234	2020-08-14 08:31:10	2020-08-14	12	[{"id_menu":3,"count":1}]	989	pick-up	0	12
117235	2020-08-14 08:36:26	2020-08-14	14	[{"id_menu":2,"count":1}]	29403	delivery	5	19
117236	2020-08-14 08:38:36	2020-08-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	21370	delivery	5	28
117237	2020-08-14 08:39:58	2020-08-14	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	44943	delivery	5	28
117238	2020-08-14 08:48:27	2020-08-14	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	42171	delivery	5	40
117239	2020-08-14 08:48:37	2020-08-14	9	[{"id_menu":6,"count":1}]	34594	pick-up	0	9
117240	2020-08-14 08:49:20	2020-08-14	9	[{"id_menu":6,"count":1}]	44922	delivery	5	14
117241	2020-08-14 08:49:42	2020-08-14	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	40274	delivery	5	34
117242	2020-08-14 08:53:13	2020-08-14	12	[{"id_menu":1,"count":1}]	26629	delivery	5	17
117243	2020-08-14 08:55:01	2020-08-14	8	[{"id_menu":5,"count":1}]	19996	delivery	5	13
117244	2020-08-14 08:55:46	2020-08-14	12	[{"id_menu":1,"count":1}]	44710	delivery	5	17
117245	2020-08-14 08:59:01	2020-08-14	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6499	delivery	5	42
117246	2020-08-14 09:01:39	2020-08-14	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	44889	delivery	5	39
117247	2020-08-14 09:05:55	2020-08-14	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	681	delivery	5	31
117248	2020-08-14 09:07:32	2020-08-14	9	[{"id_menu":6,"count":1}]	44852	delivery	5	14
117249	2020-08-14 09:09:42	2020-08-14	14	[{"id_menu":2,"count":2}]	44735	pick-up	0	14
117250	2020-08-14 09:14:59	2020-08-14	14	[{"id_menu":2,"count":1}]	9513	delivery	5	19
117251	2020-08-14 09:15:13	2020-08-14	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	44841	delivery	5	31
117252	2020-08-14 09:27:13	2020-08-14	14	[{"id_menu":2,"count":1}]	9001	delivery	5	19
117253	2020-08-14 09:27:34	2020-08-14	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	44946	delivery	5	31
117254	2020-08-14 09:36:46	2020-08-14	9	[{"id_menu":7,"count":1}]	18683	delivery	5	14
117255	2020-08-14 09:39:23	2020-08-14	9	[{"id_menu":6,"count":1}]	18925	delivery	5	14
117256	2020-08-14 09:41:58	2020-08-14	9	[{"id_menu":6,"count":1}]	44846	delivery	5	14
117257	2020-08-14 09:41:58	2020-08-14	12	[{"id_menu":1,"count":1}]	23960	pick-up	0	12
117258	2020-08-14 09:43:52	2020-08-14	14	[{"id_menu":2,"count":1}]	3754	delivery	5	19
117259	2020-08-14 09:43:58	2020-08-14	12	[{"id_menu":1,"count":1}]	1442	pick-up	0	12
117260	2020-08-14 09:44:51	2020-08-14	8	[{"id_menu":5,"count":1}]	15964	delivery	5	13
117261	2020-08-14 09:46:27	2020-08-14	17	[{"id_menu":4,"count":1}]	1916	pick-up	0	17
117262	2020-08-14 09:50:31	2020-08-14	14	[{"id_menu":2,"count":1}]	44853	delivery	5	19
117263	2020-08-14 09:52:10	2020-08-14	12	[{"id_menu":1,"count":1}]	44883	delivery	5	17
117264	2020-08-14 09:53:12	2020-08-14	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	37055	delivery	5	43
117265	2020-08-14 09:54:01	2020-08-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	29350	pick-up	0	23
117266	2020-08-14 09:55:41	2020-08-14	9	[{"id_menu":7,"count":3}]	25485	delivery	5	14
117267	2020-08-14 09:56:25	2020-08-14	8	[{"id_menu":5,"count":1}]	44763	delivery	5	13
117268	2020-08-14 09:58:18	2020-08-14	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	15961	pick-up	0	24
117269	2020-08-14 09:58:31	2020-08-14	17	[{"id_menu":4,"count":1}]	20278	delivery	5	22
117270	2020-08-14 09:59:24	2020-08-14	14	[{"id_menu":2,"count":1}]	44771	delivery	5	19
117271	2020-08-14 10:01:20	2020-08-14	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	38316	delivery	5	26
117272	2020-08-14 10:01:48	2020-08-14	9	[{"id_menu":6,"count":3}]	35622	delivery	5	14
117273	2020-08-14 10:02:39	2020-08-14	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12578	pick-up	0	40
117274	2020-08-14 10:03:26	2020-08-14	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	2897	pick-up	0	21
117275	2020-08-14 10:06:17	2020-08-14	12	[{"id_menu":1,"count":1}]	23498	delivery	5	17
117276	2020-08-14 10:06:26	2020-08-14	9	[{"id_menu":6,"count":1}]	44808	delivery	5	14
117277	2020-08-14 10:10:39	2020-08-14	17	[{"id_menu":4,"count":1}]	35213	delivery	5	22
117278	2020-08-14 10:11:47	2020-08-14	8	[{"id_menu":5,"count":1}]	18565	delivery	5	13
117279	2020-08-14 10:12:56	2020-08-14	9	[{"id_menu":7,"count":1}]	2163	delivery	5	14
117280	2020-08-14 10:13:02	2020-08-14	17	[{"id_menu":4,"count":1}]	44931	delivery	5	22
117281	2020-08-14 10:14:52	2020-08-14	9	[{"id_menu":6,"count":1}]	22063	delivery	5	14
117282	2020-08-14 10:15:40	2020-08-14	9	[{"id_menu":6,"count":1}]	4981	pick-up	0	9
117283	2020-08-14 10:16:05	2020-08-14	14	[{"id_menu":2,"count":2}]	44924	delivery	5	19
117284	2020-08-14 10:18:46	2020-08-14	12	[{"id_menu":1,"count":1}]	43087	delivery	5	17
117285	2020-08-14 10:21:00	2020-08-14	9	[{"id_menu":7,"count":1}]	17950	delivery	5	14
117286	2020-08-14 10:22:11	2020-08-14	9	[{"id_menu":6,"count":1}]	29893	delivery	5	14
117287	2020-08-14 10:22:47	2020-08-14	12	[{"id_menu":3,"count":1}]	11215	delivery	5	17
117288	2020-08-14 10:25:33	2020-08-14	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44836	delivery	5	23
117289	2020-08-14 10:25:36	2020-08-14	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":3}]	4117	delivery	5	28
117290	2020-08-14 10:36:03	2020-08-14	17	[{"id_menu":4,"count":1}]	43228	delivery	5	22
117291	2020-08-14 10:36:37	2020-08-14	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	44798	delivery	5	25
117292	2020-08-14 10:38:33	2020-08-14	12	[{"id_menu":3,"count":1}]	41835	delivery	5	17
117293	2020-08-14 10:39:12	2020-08-14	8	[{"id_menu":5,"count":1}]	2064	pick-up	0	8
117294	2020-08-14 10:40:35	2020-08-14	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	15560	delivery	5	26
117295	2020-08-14 10:41:43	2020-08-14	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	37900	delivery	5	27
117296	2020-08-14 10:41:57	2020-08-14	14	[{"id_menu":2,"count":1}]	37798	delivery	5	19
117297	2020-08-14 10:44:36	2020-08-14	9	[{"id_menu":7,"count":2}]	4283	delivery	5	14
117298	2020-08-14 10:48:51	2020-08-14	12	[{"id_menu":3,"count":2}]	44925	delivery	5	17
117299	2020-08-14 10:50:16	2020-08-14	14	[{"id_menu":2,"count":1}]	23529	delivery	5	19
117300	2020-08-14 10:51:00	2020-08-14	14	[{"id_menu":2,"count":1}]	33670	delivery	5	19
117301	2020-08-14 10:53:51	2020-08-14	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	9304	delivery	5	31
117302	2020-08-14 10:54:07	2020-08-14	12	[{"id_menu":3,"count":1}]	10393	pick-up	0	12
117303	2020-08-14 10:54:59	2020-08-14	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30953	delivery	5	43
117304	2020-08-14 10:55:32	2020-08-14	8	[{"id_menu":5,"count":1}]	44860	delivery	5	13
117305	2020-08-14 10:55:59	2020-08-14	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	44842	delivery	5	45
117306	2020-08-14 11:02:31	2020-08-14	9	[{"id_menu":6,"count":1}]	44824	delivery	5	14
117307	2020-08-14 11:04:21	2020-08-14	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12204	delivery	5	40
117308	2020-08-14 11:05:00	2020-08-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	38505	delivery	5	28
117309	2020-08-14 11:06:16	2020-08-14	17	[{"id_menu":4,"count":1}]	44958	delivery	5	22
117310	2020-08-14 11:10:53	2020-08-14	9	[{"id_menu":7,"count":1}]	11627	delivery	5	14
117311	2020-08-14 11:13:51	2020-08-14	14	[{"id_menu":2,"count":1}]	11944	pick-up	0	14
117312	2020-08-14 11:23:55	2020-08-14	12	[{"id_menu":1,"count":2}]	6217	delivery	5	17
117313	2020-08-14 11:24:27	2020-08-14	14	[{"id_menu":2,"count":1}]	25452	delivery	5	19
117314	2020-08-14 11:27:51	2020-08-14	8	[{"id_menu":5,"count":1}]	18425	delivery	5	13
117315	2020-08-14 11:36:18	2020-08-14	17	[{"id_menu":4,"count":1}]	2082	pick-up	0	17
117316	2020-08-14 11:39:33	2020-08-14	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	41412	delivery	5	28
117317	2020-08-14 11:43:02	2020-08-14	14	[{"id_menu":2,"count":1}]	11040	pick-up	0	14
117318	2020-08-14 11:43:23	2020-08-14	12	[{"id_menu":1,"count":2}]	807	pick-up	0	12
117319	2020-08-14 11:48:18	2020-08-14	9	[{"id_menu":7,"count":1}]	23923	delivery	5	14
117320	2020-08-14 11:50:02	2020-08-14	9	[{"id_menu":7,"count":1}]	44790	delivery	5	14
117321	2020-08-14 11:50:05	2020-08-14	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	6729	delivery	5	26
117322	2020-08-14 11:55:29	2020-08-14	9	[{"id_menu":7,"count":1}]	3558	delivery	5	14
117323	2020-08-14 11:56:18	2020-08-14	9	[{"id_menu":7,"count":1}]	42808	delivery	5	14
117324	2020-08-14 11:56:26	2020-08-14	12	[{"id_menu":1,"count":1}]	32410	delivery	5	17
117325	2020-08-14 11:58:27	2020-08-14	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44876	pick-up	0	35
117326	2020-08-14 11:58:53	2020-08-14	12	[{"id_menu":3,"count":1}]	17594	delivery	5	17
117327	2020-08-14 12:00:17	2020-08-14	12	[{"id_menu":1,"count":1}]	44788	pick-up	0	12
117328	2020-08-14 12:01:26	2020-08-14	12	[{"id_menu":3,"count":1}]	20168	delivery	5	17
117329	2020-08-14 12:01:30	2020-08-14	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7964	delivery	5	34
117330	2020-08-14 12:04:54	2020-08-14	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44773	delivery	5	49
117331	2020-08-14 12:05:46	2020-08-14	12	[{"id_menu":1,"count":1}]	28747	delivery	5	17
117332	2020-08-14 12:09:08	2020-08-14	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	41749	delivery	5	43
117333	2020-08-14 12:09:37	2020-08-14	14	[{"id_menu":2,"count":1}]	729	pick-up	0	14
117334	2020-08-14 12:10:12	2020-08-14	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2352	delivery	5	51
117335	2020-08-14 12:15:53	2020-08-14	9	[{"id_menu":6,"count":1}]	44902	delivery	5	14
117336	2020-08-14 12:20:36	2020-08-14	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	26739	pick-up	0	21
117337	2020-08-14 12:22:35	2020-08-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	44907	delivery	5	28
117338	2020-08-14 12:24:40	2020-08-14	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	42288	delivery	5	26
117339	2020-08-14 12:25:06	2020-08-14	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	44877	delivery	5	39
117340	2020-08-14 12:27:41	2020-08-14	12	[{"id_menu":1,"count":2}]	21595	delivery	5	17
117341	2020-08-14 12:28:07	2020-08-14	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28906	delivery	5	35
117342	2020-08-14 12:28:27	2020-08-14	12	[{"id_menu":1,"count":3}]	4836	delivery	5	17
117343	2020-08-14 12:28:51	2020-08-14	9	[{"id_menu":7,"count":1}]	10411	delivery	5	14
117344	2020-08-14 12:29:00	2020-08-14	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	37949	delivery	5	22
117345	2020-08-14 12:30:17	2020-08-14	8	[{"id_menu":5,"count":1}]	44717	delivery	5	13
117346	2020-08-14 12:31:00	2020-08-14	12	[{"id_menu":1,"count":1}]	33946	delivery	5	17
117347	2020-08-14 12:31:13	2020-08-14	17	[{"id_menu":4,"count":1}]	33763	delivery	5	22
117348	2020-08-14 12:39:29	2020-08-14	12	[{"id_menu":3,"count":1}]	9682	pick-up	0	12
117349	2020-08-14 12:40:49	2020-08-14	17	[{"id_menu":4,"count":1}]	10194	pick-up	0	17
117350	2020-08-14 12:41:05	2020-08-14	9	[{"id_menu":6,"count":1}]	44951	delivery	5	14
117351	2020-08-14 12:44:11	2020-08-14	17	[{"id_menu":4,"count":1}]	13939	delivery	5	22
117352	2020-08-14 12:49:16	2020-08-14	17	[{"id_menu":4,"count":1}]	33654	delivery	5	22
117353	2020-08-14 12:49:17	2020-08-14	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44930	delivery	5	35
117354	2020-08-14 12:50:17	2020-08-14	9	[{"id_menu":6,"count":1}]	13473	pick-up	0	9
117355	2020-08-14 12:50:49	2020-08-14	14	[{"id_menu":2,"count":1}]	25852	delivery	5	19
117356	2020-08-14 12:52:17	2020-08-14	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	42060	delivery	5	26
117357	2020-08-14 13:00:29	2020-08-14	17	[{"id_menu":4,"count":1}]	44862	delivery	5	22
117358	2020-08-14 13:00:46	2020-08-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	23789	delivery	5	28
117359	2020-08-14 13:01:47	2020-08-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	30821	pick-up	0	17
117360	2020-08-14 13:04:36	2020-08-14	14	[{"id_menu":2,"count":1}]	5445	delivery	5	19
117361	2020-08-14 13:09:51	2020-08-14	9	[{"id_menu":6,"count":1}]	22320	pick-up	0	9
117362	2020-08-14 13:14:28	2020-08-14	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	44891	delivery	5	45
117363	2020-08-14 13:14:44	2020-08-14	14	[{"id_menu":2,"count":1}]	30623	delivery	5	19
117364	2020-08-14 13:15:01	2020-08-14	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34355	delivery	5	35
117365	2020-08-14 13:21:25	2020-08-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18851	delivery	5	22
117366	2020-08-14 13:24:20	2020-08-14	17	[{"id_menu":4,"count":1}]	1854	pick-up	0	17
117367	2020-08-14 13:24:57	2020-08-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6232	pick-up	0	23
117368	2020-08-14 13:26:27	2020-08-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8229	delivery	5	22
117369	2020-08-14 13:26:42	2020-08-14	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44851	delivery	5	40
117370	2020-08-14 13:27:19	2020-08-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8940	pick-up	0	17
117371	2020-08-14 13:29:25	2020-08-14	8	[{"id_menu":5,"count":1}]	44738	pick-up	0	8
117372	2020-08-14 13:30:16	2020-08-14	12	[{"id_menu":3,"count":1}]	12393	pick-up	0	12
117373	2020-08-14 13:30:41	2020-08-14	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	37689	delivery	5	43
117374	2020-08-14 13:32:12	2020-08-14	9	[{"id_menu":7,"count":1}]	7891	pick-up	0	9
117375	2020-08-14 13:32:47	2020-08-14	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	44914	delivery	5	26
117376	2020-08-14 13:48:49	2020-08-14	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	44849	delivery	5	23
117377	2020-08-14 13:48:53	2020-08-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	11004	delivery	5	28
117378	2020-08-14 13:48:53	2020-08-14	9	[{"id_menu":6,"count":1}]	44904	delivery	5	14
117379	2020-08-14 13:49:54	2020-08-14	9	[{"id_menu":6,"count":2}]	44761	delivery	5	14
117380	2020-08-14 13:56:31	2020-08-14	12	[{"id_menu":3,"count":1}]	41524	delivery	5	17
117381	2020-08-14 13:58:32	2020-08-14	17	[{"id_menu":4,"count":1}]	37822	delivery	5	22
117382	2020-08-14 14:01:58	2020-08-14	12	[{"id_menu":1,"count":1}]	24918	delivery	5	17
117383	2020-08-14 14:02:01	2020-08-14	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	14277	delivery	5	34
117384	2020-08-14 14:09:48	2020-08-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	26556	delivery	5	28
117385	2020-08-14 14:13:50	2020-08-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	29674	delivery	5	28
117386	2020-08-14 14:16:07	2020-08-14	9	[{"id_menu":6,"count":1}]	1380	delivery	5	14
117387	2020-08-14 14:22:13	2020-08-14	8	[{"id_menu":5,"count":1}]	35020	delivery	5	13
117388	2020-08-14 14:24:19	2020-08-14	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	44901	delivery	5	43
117389	2020-08-14 14:24:59	2020-08-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	17861	pick-up	0	23
117390	2020-08-14 14:26:18	2020-08-14	14	[{"id_menu":2,"count":1}]	281	pick-up	0	14
117391	2020-08-14 14:28:27	2020-08-14	14	[{"id_menu":2,"count":1}]	44765	pick-up	0	14
117392	2020-08-14 14:28:59	2020-08-14	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20438	delivery	5	43
117393	2020-08-14 14:29:45	2020-08-14	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17939	delivery	5	36
117394	2020-08-14 14:29:50	2020-08-14	12	[{"id_menu":3,"count":1}]	44745	delivery	5	17
117395	2020-08-14 14:31:26	2020-08-14	12	[{"id_menu":1,"count":1}]	44711	delivery	5	17
117396	2020-08-14 14:32:22	2020-08-14	9	[{"id_menu":7,"count":1}]	8966	pick-up	0	9
117397	2020-08-14 14:32:40	2020-08-14	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30253	delivery	5	40
117398	2020-08-14 14:42:41	2020-08-14	8	[{"id_menu":5,"count":1}]	44936	delivery	5	13
117399	2020-08-14 14:43:25	2020-08-14	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	44879	delivery	5	40
117400	2020-08-14 14:45:33	2020-08-14	17	[{"id_menu":4,"count":1}]	42147	delivery	5	22
117401	2020-08-14 14:49:03	2020-08-14	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	44728	delivery	5	45
117402	2020-08-14 14:52:59	2020-08-14	17	[{"id_menu":4,"count":1}]	44712	delivery	5	22
117403	2020-08-14 14:54:19	2020-08-14	9	[{"id_menu":6,"count":1}]	33282	delivery	5	14
117404	2020-08-14 14:56:13	2020-08-14	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	44793	delivery	5	39
117405	2020-08-14 14:58:40	2020-08-14	14	[{"id_menu":2,"count":1}]	1106	pick-up	0	14
117406	2020-08-14 14:59:26	2020-08-14	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	19654	delivery	5	40
117407	2020-08-14 15:01:25	2020-08-14	17	[{"id_menu":4,"count":1}]	44894	delivery	5	22
117408	2020-08-14 15:03:49	2020-08-14	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	33144	delivery	5	43
117409	2020-08-14 15:06:34	2020-08-14	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	29120	delivery	5	31
117410	2020-08-14 15:07:33	2020-08-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	25351	pick-up	0	31
117411	2020-08-14 15:09:10	2020-08-14	14	[{"id_menu":2,"count":2}]	42798	pick-up	0	14
117412	2020-08-14 15:09:56	2020-08-14	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	12371	delivery	5	40
117413	2020-08-14 15:14:46	2020-08-14	12	[{"id_menu":3,"count":1}]	44838	delivery	5	17
117414	2020-08-14 15:15:32	2020-08-14	9	[{"id_menu":7,"count":1}]	19307	delivery	5	14
117415	2020-08-14 15:17:29	2020-08-14	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	44950	delivery	5	52
117416	2020-08-14 15:19:31	2020-08-14	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	41404	delivery	5	34
117417	2020-08-14 15:21:00	2020-08-14	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	34382	delivery	5	30
117418	2020-08-14 15:21:25	2020-08-14	8	[{"id_menu":5,"count":1}]	33594	delivery	5	13
117419	2020-08-14 15:26:45	2020-08-14	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12732	delivery	5	31
117420	2020-08-14 15:31:30	2020-08-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	44750	delivery	5	22
117421	2020-08-14 15:37:48	2020-08-14	9	[{"id_menu":6,"count":1}]	12302	delivery	5	14
117422	2020-08-14 15:37:50	2020-08-14	14	[{"id_menu":2,"count":1}]	15637	pick-up	0	14
117423	2020-08-14 15:44:49	2020-08-14	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	27596	delivery	5	25
117424	2020-08-14 15:45:05	2020-08-14	14	[{"id_menu":2,"count":1}]	43539	delivery	5	19
117425	2020-08-14 15:46:26	2020-08-14	9	[{"id_menu":7,"count":1}]	17291	delivery	5	14
117426	2020-08-14 15:55:05	2020-08-14	17	[{"id_menu":4,"count":1}]	1042	pick-up	0	17
117427	2020-08-14 15:56:36	2020-08-14	17	[{"id_menu":4,"count":1}]	7848	delivery	5	22
117428	2020-08-14 15:58:50	2020-08-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	41643	pick-up	0	26
117429	2020-08-14 16:03:51	2020-08-14	14	[{"id_menu":2,"count":1}]	8021	delivery	5	19
117430	2020-08-14 16:09:51	2020-08-14	12	[{"id_menu":3,"count":1}]	5354	delivery	5	17
117431	2020-08-14 16:10:40	2020-08-14	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	16450	delivery	5	26
117432	2020-08-14 16:11:33	2020-08-14	9	[{"id_menu":7,"count":1}]	26482	delivery	5	14
117433	2020-08-14 16:13:35	2020-08-14	9	[{"id_menu":6,"count":1}]	7612	pick-up	0	9
117434	2020-08-14 16:14:03	2020-08-14	12	[{"id_menu":1,"count":1}]	6538	delivery	5	17
117435	2020-08-14 16:14:32	2020-08-14	14	[{"id_menu":2,"count":1}]	21729	delivery	5	19
117436	2020-08-14 16:15:03	2020-08-14	9	[{"id_menu":7,"count":1}]	44938	delivery	5	14
117437	2020-08-14 16:16:27	2020-08-14	14	[{"id_menu":2,"count":1}]	44772	delivery	5	19
117438	2020-08-14 16:18:01	2020-08-14	17	[{"id_menu":4,"count":1}]	44661	delivery	5	22
117439	2020-08-14 16:19:38	2020-08-14	9	[{"id_menu":6,"count":1}]	30149	delivery	5	14
117440	2020-08-14 16:20:29	2020-08-14	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	1814	delivery	5	31
117441	2020-08-14 16:21:04	2020-08-14	9	[{"id_menu":7,"count":1}]	36752	delivery	5	14
117442	2020-08-14 16:21:11	2020-08-14	12	[{"id_menu":3,"count":1}]	44796	delivery	5	17
117443	2020-08-14 16:22:49	2020-08-14	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	44872	delivery	5	30
117444	2020-08-14 16:25:52	2020-08-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16413	delivery	5	22
117445	2020-08-14 16:28:27	2020-08-14	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	44713	delivery	5	57
117446	2020-08-14 16:31:08	2020-08-14	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	44720	delivery	5	31
117447	2020-08-14 16:31:15	2020-08-14	8	[{"id_menu":5,"count":1}]	23213	delivery	5	13
117448	2020-08-14 16:32:30	2020-08-14	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	44764	pick-up	0	31
117449	2020-08-14 16:36:53	2020-08-14	17	[{"id_menu":4,"count":1}]	233	delivery	5	22
117450	2020-08-14 16:39:29	2020-08-14	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1007	delivery	5	25
117451	2020-08-14 16:40:08	2020-08-14	17	[{"id_menu":4,"count":1}]	12541	pick-up	0	17
117452	2020-08-14 16:41:50	2020-08-14	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	44709	pick-up	0	17
117453	2020-08-14 16:43:30	2020-08-14	12	[{"id_menu":3,"count":1}]	10479	pick-up	0	12
117454	2020-08-14 16:50:52	2020-08-14	9	[{"id_menu":7,"count":1}]	1170	pick-up	0	9
117455	2020-08-14 16:56:30	2020-08-14	9	[{"id_menu":7,"count":1}]	13344	delivery	5	14
117456	2020-08-14 16:59:52	2020-08-14	17	[{"id_menu":4,"count":1}]	39972	delivery	5	22
117457	2020-08-14 17:00:09	2020-08-14	9	[{"id_menu":6,"count":1}]	10528	delivery	5	14
117458	2020-08-14 17:02:56	2020-08-14	9	[{"id_menu":7,"count":1}]	11809	pick-up	0	9
117459	2020-08-14 17:05:43	2020-08-14	12	[{"id_menu":3,"count":1}]	44892	delivery	5	17
117460	2020-08-14 17:11:39	2020-08-14	9	[{"id_menu":6,"count":1}]	10900	delivery	5	14
117461	2020-08-14 17:11:58	2020-08-14	9	[{"id_menu":7,"count":1}]	15203	delivery	5	14
117462	2020-08-14 17:12:07	2020-08-14	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	44884	delivery	5	34
117463	2020-08-14 17:14:14	2020-08-14	9	[{"id_menu":7,"count":1}]	4743	delivery	5	14
117464	2020-08-14 17:14:40	2020-08-14	8	[{"id_menu":5,"count":1}]	3916	pick-up	0	8
117465	2020-08-14 17:15:47	2020-08-14	9	[{"id_menu":6,"count":1}]	26808	delivery	5	14
117466	2020-08-14 17:19:48	2020-08-14	9	[{"id_menu":7,"count":1}]	21910	pick-up	0	9
117467	2020-08-14 17:20:27	2020-08-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10989	pick-up	0	26
117468	2020-08-14 17:21:22	2020-08-14	8	[{"id_menu":5,"count":1}]	6090	pick-up	0	8
117469	2020-08-14 17:24:41	2020-08-14	12	[{"id_menu":1,"count":1}]	30131	delivery	5	17
117470	2020-08-14 17:27:23	2020-08-14	17	[{"id_menu":4,"count":1}]	2	pick-up	0	17
117471	2020-08-14 17:29:46	2020-08-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17995	pick-up	0	17
117472	2020-08-14 17:30:15	2020-08-14	8	[{"id_menu":5,"count":1}]	44898	delivery	5	13
117473	2020-08-14 17:34:22	2020-08-14	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	17237	delivery	5	25
117474	2020-08-14 17:34:25	2020-08-14	8	[{"id_menu":5,"count":1}]	14146	delivery	5	13
117475	2020-08-14 17:34:35	2020-08-14	14	[{"id_menu":2,"count":1}]	5473	pick-up	0	14
117476	2020-08-14 17:40:00	2020-08-14	9	[{"id_menu":6,"count":1}]	40116	delivery	5	14
117477	2020-08-14 17:42:11	2020-08-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	29134	pick-up	0	17
117478	2020-08-14 17:44:14	2020-08-14	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16470	delivery	5	34
117479	2020-08-14 17:45:27	2020-08-14	14	[{"id_menu":2,"count":1}]	44934	delivery	5	19
117480	2020-08-14 17:48:39	2020-08-14	9	[{"id_menu":7,"count":1}]	20413	pick-up	0	9
117481	2020-08-14 17:49:20	2020-08-14	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	44945	delivery	5	43
117482	2020-08-14 17:50:55	2020-08-14	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	37014	delivery	5	22
117483	2020-08-14 17:53:06	2020-08-14	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	42436	delivery	5	43
117484	2020-08-14 17:55:11	2020-08-14	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	44708	delivery	5	43
117485	2020-08-14 17:56:19	2020-08-14	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17265	delivery	5	39
117486	2020-08-14 17:59:38	2020-08-14	9	[{"id_menu":6,"count":1}]	35986	pick-up	0	9
117487	2020-08-14 18:00:44	2020-08-14	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	44857	delivery	5	30
117488	2020-08-14 18:01:16	2020-08-14	14	[{"id_menu":2,"count":1}]	1053	pick-up	0	14
117489	2020-08-14 18:11:57	2020-08-14	14	[{"id_menu":2,"count":1}]	44766	delivery	5	19
117490	2020-08-14 18:13:33	2020-08-14	9	[{"id_menu":6,"count":1}]	44858	delivery	5	14
117491	2020-08-14 18:13:53	2020-08-14	9	[{"id_menu":6,"count":1}]	30864	delivery	5	14
117492	2020-08-14 18:16:24	2020-08-14	12	[{"id_menu":1,"count":1}]	44769	delivery	5	17
117493	2020-08-14 18:16:33	2020-08-14	9	[{"id_menu":6,"count":1}]	44828	delivery	5	14
117494	2020-08-14 18:17:19	2020-08-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	44910	delivery	5	36
117495	2020-08-14 18:19:53	2020-08-14	14	[{"id_menu":2,"count":1}]	44855	delivery	5	19
117496	2020-08-14 18:20:43	2020-08-14	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	39705	pick-up	0	26
117497	2020-08-14 18:20:44	2020-08-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	44941	delivery	5	22
117498	2020-08-14 18:27:41	2020-08-14	12	[{"id_menu":1,"count":1}]	17410	delivery	5	17
117499	2020-08-14 18:31:06	2020-08-14	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	44758	delivery	5	43
117500	2020-08-14 18:31:41	2020-08-14	12	[{"id_menu":1,"count":1}]	44744	delivery	5	17
117501	2020-08-14 18:31:58	2020-08-14	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	25206	delivery	5	30
117502	2020-08-14 18:33:30	2020-08-14	9	[{"id_menu":6,"count":3}]	1669	delivery	5	14
117503	2020-08-14 18:36:01	2020-08-14	9	[{"id_menu":7,"count":1}]	29323	delivery	5	14
117504	2020-08-14 18:37:24	2020-08-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	29171	pick-up	0	17
117505	2020-08-14 18:37:59	2020-08-14	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	44957	delivery	5	22
117506	2020-08-14 18:40:27	2020-08-14	9	[{"id_menu":7,"count":1}]	44780	delivery	5	14
117507	2020-08-14 18:41:14	2020-08-14	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	44722	delivery	5	26
117508	2020-08-14 18:42:25	2020-08-14	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	43333	delivery	5	22
117509	2020-08-14 18:45:34	2020-08-14	12	[{"id_menu":1,"count":1}]	44817	delivery	5	17
117510	2020-08-14 18:47:29	2020-08-14	17	[{"id_menu":4,"count":1}]	44818	delivery	5	22
117511	2020-08-14 18:50:44	2020-08-14	14	[{"id_menu":2,"count":1}]	21821	delivery	5	19
117512	2020-08-14 18:51:24	2020-08-14	14	[{"id_menu":2,"count":1}]	44906	delivery	5	19
117513	2020-08-14 18:52:10	2020-08-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	30283	delivery	5	28
117514	2020-08-14 18:55:20	2020-08-14	17	[{"id_menu":4,"count":1}]	44865	delivery	5	22
117515	2020-08-14 18:55:27	2020-08-14	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	44949	delivery	5	31
117516	2020-08-14 18:57:10	2020-08-14	17	[{"id_menu":4,"count":1}]	17676	delivery	5	22
117517	2020-08-14 19:01:36	2020-08-14	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	17699	delivery	5	34
117518	2020-08-14 19:02:52	2020-08-14	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	34669	delivery	5	22
117519	2020-08-14 19:07:49	2020-08-14	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	44840	pick-up	0	35
117520	2020-08-14 19:07:57	2020-08-14	9	[{"id_menu":6,"count":1}]	16259	delivery	5	14
117521	2020-08-14 19:08:18	2020-08-14	12	[{"id_menu":3,"count":1}]	44878	delivery	5	17
117522	2020-08-14 19:25:57	2020-08-14	14	[{"id_menu":2,"count":1}]	1569	pick-up	0	14
117523	2020-08-14 19:25:59	2020-08-14	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14440	delivery	5	40
117524	2020-08-14 19:28:51	2020-08-14	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	43025	delivery	5	30
117525	2020-08-14 19:29:29	2020-08-14	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	20184	delivery	5	37
117526	2020-08-14 19:32:29	2020-08-14	9	[{"id_menu":7,"count":1}]	40315	delivery	5	14
117527	2020-08-14 19:36:32	2020-08-14	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	42860	delivery	5	27
117528	2020-08-14 19:36:45	2020-08-14	9	[{"id_menu":7,"count":1}]	21903	pick-up	0	9
117529	2020-08-14 19:44:16	2020-08-14	8	[{"id_menu":5,"count":1}]	20723	delivery	5	13
117530	2020-08-14 19:47:04	2020-08-14	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	26905	delivery	5	34
117531	2020-08-14 19:52:56	2020-08-14	17	[{"id_menu":4,"count":2}]	44732	pick-up	0	17
117532	2020-08-14 19:55:23	2020-08-14	9	[{"id_menu":7,"count":1}]	44727	delivery	5	14
117533	2020-08-14 19:57:08	2020-08-14	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	44759	delivery	5	40
117534	2020-08-14 19:59:50	2020-08-14	9	[{"id_menu":6,"count":1}]	27827	delivery	5	14
117535	2020-08-14 20:04:17	2020-08-14	14	[{"id_menu":2,"count":1}]	37377	delivery	5	19
117536	2020-08-14 20:13:18	2020-08-14	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	44856	delivery	5	26
117537	2020-08-14 20:15:37	2020-08-14	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	43784	delivery	5	31
117538	2020-08-14 20:19:53	2020-08-14	14	[{"id_menu":2,"count":1}]	26995	delivery	5	19
117539	2020-08-14 20:22:05	2020-08-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	44915	delivery	5	31
117540	2020-08-14 20:24:28	2020-08-14	8	[{"id_menu":5,"count":1}]	3640	pick-up	0	8
117541	2020-08-14 20:26:50	2020-08-14	8	[{"id_menu":5,"count":1}]	17245	pick-up	0	8
117542	2020-08-14 20:27:17	2020-08-14	8	[{"id_menu":5,"count":1}]	26437	delivery	5	13
117543	2020-08-14 20:29:17	2020-08-14	17	[{"id_menu":4,"count":1}]	44935	delivery	5	22
117544	2020-08-14 20:32:15	2020-08-14	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	16929	delivery	5	40
117545	2020-08-14 20:35:07	2020-08-14	9	[{"id_menu":7,"count":1}]	20576	delivery	5	14
117546	2020-08-14 20:41:36	2020-08-14	14	[{"id_menu":2,"count":1}]	44953	delivery	5	19
117547	2020-08-14 20:43:13	2020-08-14	9	[{"id_menu":6,"count":2}]	41725	delivery	5	14
117548	2020-08-14 20:45:48	2020-08-14	12	[{"id_menu":3,"count":1}]	7736	delivery	5	17
117549	2020-08-14 20:49:24	2020-08-14	9	[{"id_menu":7,"count":1}]	44832	delivery	5	14
117550	2020-08-14 20:52:08	2020-08-14	9	[{"id_menu":6,"count":1}]	39700	delivery	5	14
117551	2020-08-14 20:54:38	2020-08-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32760	delivery	5	22
117552	2020-08-14 20:56:57	2020-08-14	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	27602	delivery	5	45
117553	2020-08-14 20:58:51	2020-08-14	9	[{"id_menu":6,"count":1}]	26396	delivery	5	14
117554	2020-08-14 21:01:54	2020-08-14	9	[{"id_menu":6,"count":1}]	44920	pick-up	0	9
117555	2020-08-14 21:02:14	2020-08-14	9	[{"id_menu":6,"count":1}]	8263	delivery	5	14
117556	2020-08-14 21:03:11	2020-08-14	17	[{"id_menu":4,"count":1}]	16056	delivery	5	22
117557	2020-08-14 21:05:02	2020-08-14	8	[{"id_menu":5,"count":1}]	8402	pick-up	0	8
117558	2020-08-14 21:08:19	2020-08-14	9	[{"id_menu":7,"count":1}]	26930	pick-up	0	9
117559	2020-08-14 21:13:41	2020-08-14	9	[{"id_menu":6,"count":1}]	39521	delivery	5	14
117560	2020-08-14 21:16:29	2020-08-14	9	[{"id_menu":7,"count":1}]	3260	delivery	5	14
117561	2020-08-14 21:17:46	2020-08-14	12	[{"id_menu":3,"count":1}]	44881	delivery	5	17
117562	2020-08-14 21:20:22	2020-08-14	17	[{"id_menu":4,"count":1}]	32785	delivery	5	22
117563	2020-08-14 21:22:59	2020-08-14	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	44800	delivery	5	28
117564	2020-08-14 21:24:43	2020-08-14	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	30826	delivery	5	44
117565	2020-08-14 21:24:52	2020-08-14	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	35485	delivery	5	30
117566	2020-08-14 21:25:14	2020-08-14	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	44371	delivery	5	36
117567	2020-08-14 21:25:39	2020-08-14	8	[{"id_menu":5,"count":1}]	44899	delivery	5	13
117568	2020-08-14 21:26:27	2020-08-14	9	[{"id_menu":7,"count":1}]	16385	delivery	5	14
117569	2020-08-14 21:29:14	2020-08-14	12	[{"id_menu":3,"count":1}]	9508	pick-up	0	12
117570	2020-08-14 21:29:46	2020-08-14	9	[{"id_menu":6,"count":1}]	39576	delivery	5	14
117571	2020-08-14 21:35:18	2020-08-14	8	[{"id_menu":5,"count":1}]	10882	pick-up	0	8
117572	2020-08-14 21:36:16	2020-08-14	17	[{"id_menu":4,"count":2}]	44063	pick-up	0	17
117573	2020-08-14 21:37:31	2020-08-14	9	[{"id_menu":7,"count":1}]	29262	delivery	5	14
117574	2020-08-14 21:39:16	2020-08-14	12	[{"id_menu":1,"count":1}]	4392	pick-up	0	12
117575	2020-08-14 21:42:54	2020-08-14	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	3237	delivery	5	29
117576	2020-08-14 21:47:49	2020-08-14	8	[{"id_menu":5,"count":1}]	35136	delivery	5	13
117577	2020-08-14 21:47:58	2020-08-14	9	[{"id_menu":7,"count":1}]	44774	delivery	5	14
117578	2020-08-14 21:49:42	2020-08-14	12	[{"id_menu":1,"count":1}]	25932	delivery	5	17
117579	2020-08-14 21:50:40	2020-08-14	17	[{"id_menu":4,"count":1}]	19966	delivery	5	22
117580	2020-08-14 21:52:38	2020-08-14	8	[{"id_menu":5,"count":1}]	27515	delivery	5	13
117581	2020-08-14 21:53:28	2020-08-14	9	[{"id_menu":6,"count":1}]	1968	pick-up	0	9
117582	2020-08-14 21:54:47	2020-08-14	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	44887	delivery	5	45
117583	2020-08-14 21:55:16	2020-08-14	9	[{"id_menu":7,"count":1}]	22194	pick-up	0	9
117584	2020-08-14 21:57:14	2020-08-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	44740	pick-up	0	26
117585	2020-08-14 21:57:28	2020-08-14	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	42485	delivery	5	23
117586	2020-08-14 21:58:57	2020-08-14	17	[{"id_menu":4,"count":1}]	12872	pick-up	0	17
117587	2020-08-14 22:00:30	2020-08-14	17	[{"id_menu":4,"count":1}]	6977	delivery	5	22
117588	2020-08-14 22:01:18	2020-08-14	12	[{"id_menu":3,"count":1}]	18877	pick-up	0	12
117589	2020-08-14 22:02:42	2020-08-14	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	8755	delivery	5	28
117590	2020-08-14 22:05:20	2020-08-14	8	[{"id_menu":5,"count":1}]	13923	pick-up	0	8
117591	2020-08-14 22:05:52	2020-08-14	17	[{"id_menu":4,"count":1}]	19737	delivery	5	22
117592	2020-08-14 22:06:09	2020-08-14	46	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	8474	pick-up	0	46
117593	2020-08-14 22:10:24	2020-08-14	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	21193	pick-up	0	25
117594	2020-08-14 22:10:31	2020-08-14	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	44937	delivery	5	46
117595	2020-08-14 22:16:44	2020-08-14	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	44785	delivery	5	52
117596	2020-08-14 22:17:11	2020-08-14	9	[{"id_menu":6,"count":1}]	997	pick-up	0	9
117597	2020-08-14 22:20:50	2020-08-14	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	44844	delivery	5	26
117598	2020-08-14 22:22:34	2020-08-14	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	41348	delivery	5	31
117599	2020-08-14 22:23:11	2020-08-14	12	[{"id_menu":3,"count":1}]	33912	delivery	5	17
117600	2020-08-14 22:23:26	2020-08-14	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8740	delivery	5	28
117601	2020-08-14 22:24:48	2020-08-14	12	[{"id_menu":1,"count":1}]	5780	pick-up	0	12
117602	2020-08-14 22:24:53	2020-08-14	8	[{"id_menu":5,"count":1}]	8960	delivery	5	13
117603	2020-08-14 22:25:11	2020-08-14	17	[{"id_menu":4,"count":1}]	44870	delivery	5	22
117604	2020-08-14 22:25:58	2020-08-14	8	[{"id_menu":5,"count":1}]	11183	delivery	5	13
117605	2020-08-14 22:27:16	2020-08-14	17	[{"id_menu":4,"count":1}]	44811	delivery	5	22
117606	2020-08-14 22:31:21	2020-08-14	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2841	pick-up	0	29
117607	2020-08-14 22:32:08	2020-08-14	8	[{"id_menu":5,"count":1}]	44752	pick-up	0	8
117608	2020-08-14 22:33:02	2020-08-14	9	[{"id_menu":7,"count":1}]	38723	delivery	5	14
117609	2020-08-14 22:36:02	2020-08-14	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36275	delivery	5	40
117610	2020-08-14 22:36:20	2020-08-14	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	44792	delivery	5	37
117611	2020-08-14 22:37:09	2020-08-14	17	[{"id_menu":4,"count":1}]	22493	pick-up	0	17
117612	2020-08-14 22:42:37	2020-08-14	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	22755	delivery	5	22
117613	2020-08-14 22:42:56	2020-08-14	9	[{"id_menu":7,"count":1}]	42396	delivery	5	14
117614	2020-08-14 22:44:57	2020-08-14	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28222	delivery	5	39
117615	2020-08-14 22:47:22	2020-08-14	9	[{"id_menu":6,"count":1}]	44918	pick-up	0	9
117616	2020-08-14 22:48:42	2020-08-14	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44753	delivery	5	23
117617	2020-08-14 22:54:30	2020-08-14	8	[{"id_menu":5,"count":1}]	40880	delivery	5	13
117618	2020-08-14 22:55:51	2020-08-14	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	42667	pick-up	0	20
117619	2020-08-14 23:00:50	2020-08-14	12	[{"id_menu":1,"count":1}]	44554	delivery	5	17
117620	2020-08-14 23:03:00	2020-08-14	12	[{"id_menu":1,"count":1}]	2314	pick-up	0	12
117621	2020-08-14 23:03:49	2020-08-14	9	[{"id_menu":6,"count":1}]	44786	delivery	5	14
117622	2020-08-14 23:05:44	2020-08-14	8	[{"id_menu":5,"count":1}]	38174	delivery	5	13
117623	2020-08-14 23:06:50	2020-08-14	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	32298	delivery	5	31
117624	2020-08-14 23:06:57	2020-08-14	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	41145	delivery	5	28
117625	2020-08-14 23:08:46	2020-08-14	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1714	pick-up	0	31
117626	2020-08-14 23:15:37	2020-08-14	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6733	pick-up	0	26
117627	2020-08-14 23:16:03	2020-08-14	12	[{"id_menu":1,"count":1}]	44921	delivery	5	17
117628	2020-08-14 23:16:15	2020-08-14	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	37173	delivery	5	22
117629	2020-08-14 23:17:46	2020-08-14	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	42900	pick-up	0	40
117630	2020-08-14 23:27:02	2020-08-14	9	[{"id_menu":7,"count":1}]	44819	delivery	5	14
117631	2020-08-14 23:28:35	2020-08-14	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	44756	delivery	5	31
117632	2020-08-14 23:29:56	2020-08-14	8	[{"id_menu":5,"count":1}]	44864	delivery	5	13
117633	2020-08-14 23:32:48	2020-08-14	9	[{"id_menu":6,"count":1}]	18259	pick-up	0	9
117634	2020-08-14 23:39:23	2020-08-14	17	[{"id_menu":4,"count":1}]	44861	delivery	5	22
117635	2020-08-14 23:44:51	2020-08-14	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15092	delivery	5	31
117636	2020-08-14 23:48:11	2020-08-14	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	20907	delivery	5	34
117637	2020-08-14 23:48:52	2020-08-14	14	[{"id_menu":2,"count":1}]	17215	delivery	5	19
117638	2020-08-14 23:52:42	2020-08-14	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":3}]	31823	delivery	5	22
117639	2020-08-14 23:54:30	2020-08-14	17	[{"id_menu":4,"count":1}]	16914	pick-up	0	17
117640	2020-08-14 23:56:19	2020-08-14	8	[{"id_menu":5,"count":1}]	44310	delivery	5	13
117641	2020-08-14 23:57:57	2020-08-14	9	[{"id_menu":6,"count":1}]	22844	pick-up	0	9
117642	2020-08-15 00:00:09	2020-08-15	12	[{"id_menu":3,"count":1}]	45038	delivery	5	17
117643	2020-08-15 00:02:15	2020-08-15	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	45188	delivery	5	26
117644	2020-08-15 00:03:14	2020-08-15	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	41615	delivery	5	34
117645	2020-08-15 00:04:10	2020-08-15	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	2699	pick-up	0	22
117646	2020-08-15 00:05:10	2020-08-15	12	[{"id_menu":3,"count":1}]	4245	pick-up	0	12
117647	2020-08-15 00:05:37	2020-08-15	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	19321	pick-up	0	29
117648	2020-08-15 00:05:51	2020-08-15	9	[{"id_menu":7,"count":2}]	45106	delivery	5	14
117649	2020-08-15 00:08:34	2020-08-15	9	[{"id_menu":7,"count":1}]	45056	delivery	5	14
117650	2020-08-15 00:12:22	2020-08-15	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	45066	delivery	5	23
117651	2020-08-15 00:12:54	2020-08-15	14	[{"id_menu":2,"count":1}]	45027	delivery	5	19
117652	2020-08-15 00:14:15	2020-08-15	14	[{"id_menu":2,"count":1}]	26622	delivery	5	19
117653	2020-08-15 00:14:48	2020-08-15	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	40899	pick-up	0	35
117654	2020-08-15 00:15:30	2020-08-15	14	[{"id_menu":2,"count":1}]	10960	delivery	5	19
117655	2020-08-15 00:19:16	2020-08-15	17	[{"id_menu":4,"count":1}]	34559	delivery	5	22
117656	2020-08-15 00:20:05	2020-08-15	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":2}]	23074	delivery	5	25
117657	2020-08-15 00:20:26	2020-08-15	12	[{"id_menu":1,"count":2}]	45146	pick-up	0	12
117658	2020-08-15 00:20:42	2020-08-15	9	[{"id_menu":6,"count":1}]	25048	delivery	5	14
117659	2020-08-15 00:22:00	2020-08-15	8	[{"id_menu":5,"count":1}]	44968	delivery	5	13
117660	2020-08-15 00:23:32	2020-08-15	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	42231	delivery	5	37
117661	2020-08-15 00:24:09	2020-08-15	9	[{"id_menu":6,"count":1}]	11076	delivery	5	14
117662	2020-08-15 00:24:16	2020-08-15	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	34163	delivery	5	34
117663	2020-08-15 00:24:40	2020-08-15	12	[{"id_menu":3,"count":1}]	12451	delivery	5	17
117664	2020-08-15 00:25:01	2020-08-15	9	[{"id_menu":6,"count":1}]	13643	delivery	5	14
117665	2020-08-15 00:27:23	2020-08-15	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	44967	delivery	5	43
117666	2020-08-15 00:29:22	2020-08-15	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	34417	delivery	5	25
117667	2020-08-15 00:30:37	2020-08-15	9	[{"id_menu":7,"count":1}]	45072	delivery	5	14
117668	2020-08-15 00:37:22	2020-08-15	14	[{"id_menu":2,"count":2}]	45024	delivery	5	19
117669	2020-08-15 00:39:26	2020-08-15	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	45022	delivery	5	48
117670	2020-08-15 00:40:24	2020-08-15	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	34644	delivery	5	28
117671	2020-08-15 00:40:52	2020-08-15	49	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	13054	pick-up	0	49
117672	2020-08-15 00:51:34	2020-08-15	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	14540	delivery	5	22
117673	2020-08-15 00:51:48	2020-08-15	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	42809	pick-up	0	31
117674	2020-08-15 00:53:32	2020-08-15	9	[{"id_menu":6,"count":1}]	12456	delivery	5	14
117675	2020-08-15 00:55:20	2020-08-15	9	[{"id_menu":6,"count":2}]	13284	delivery	5	14
117676	2020-08-15 00:57:34	2020-08-15	9	[{"id_menu":6,"count":1}]	10809	delivery	5	14
117677	2020-08-15 00:59:18	2020-08-15	14	[{"id_menu":2,"count":1}]	25300	delivery	5	19
117678	2020-08-15 00:59:49	2020-08-15	12	[{"id_menu":1,"count":1}]	2807	pick-up	0	12
117679	2020-08-15 01:01:35	2020-08-15	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	45060	delivery	5	26
117680	2020-08-15 01:01:42	2020-08-15	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17492	delivery	5	53
117681	2020-08-15 01:04:09	2020-08-15	8	[{"id_menu":5,"count":1}]	45030	delivery	5	13
117682	2020-08-15 01:06:28	2020-08-15	17	[{"id_menu":4,"count":3}]	29481	delivery	5	22
117683	2020-08-15 01:07:23	2020-08-15	8	[{"id_menu":5,"count":1}]	45196	delivery	5	13
117684	2020-08-15 01:07:39	2020-08-15	9	[{"id_menu":7,"count":1}]	45182	delivery	5	14
117685	2020-08-15 01:08:08	2020-08-15	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	13797	delivery	5	40
117686	2020-08-15 01:09:16	2020-08-15	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	24392	delivery	5	34
117687	2020-08-15 01:10:37	2020-08-15	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	45041	delivery	5	31
117688	2020-08-15 01:11:43	2020-08-15	8	[{"id_menu":5,"count":1}]	14220	delivery	5	13
117689	2020-08-15 01:13:23	2020-08-15	14	[{"id_menu":2,"count":1}]	8297	pick-up	0	14
117690	2020-08-15 01:14:05	2020-08-15	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	45172	delivery	5	31
117691	2020-08-15 01:16:02	2020-08-15	8	[{"id_menu":5,"count":1}]	18971	delivery	5	13
117692	2020-08-15 01:19:45	2020-08-15	9	[{"id_menu":7,"count":1}]	17847	delivery	5	14
117693	2020-08-15 01:20:32	2020-08-15	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	45158	delivery	5	31
117694	2020-08-15 01:22:06	2020-08-15	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	45194	delivery	5	31
117695	2020-08-15 01:23:41	2020-08-15	9	[{"id_menu":6,"count":1}]	40790	pick-up	0	9
117696	2020-08-15 01:24:10	2020-08-15	12	[{"id_menu":1,"count":1}]	1562	pick-up	0	12
117697	2020-08-15 01:25:20	2020-08-15	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	22811	delivery	5	26
117698	2020-08-15 01:26:45	2020-08-15	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	45127	delivery	5	26
117699	2020-08-15 01:26:53	2020-08-15	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	35671	delivery	5	45
117700	2020-08-15 01:27:50	2020-08-15	12	[{"id_menu":3,"count":1}]	38798	pick-up	0	12
117701	2020-08-15 01:28:09	2020-08-15	8	[{"id_menu":5,"count":1}]	45096	delivery	5	13
117702	2020-08-15 01:28:10	2020-08-15	9	[{"id_menu":7,"count":2}]	21980	pick-up	0	9
117703	2020-08-15 01:28:33	2020-08-15	14	[{"id_menu":2,"count":1}]	1223	pick-up	0	14
117704	2020-08-15 01:31:09	2020-08-15	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	42401	delivery	5	36
117705	2020-08-15 01:32:02	2020-08-15	8	[{"id_menu":5,"count":1}]	21308	pick-up	0	8
117706	2020-08-15 01:32:09	2020-08-15	12	[{"id_menu":3,"count":2}]	11421	delivery	5	17
117707	2020-08-15 01:34:45	2020-08-15	17	[{"id_menu":4,"count":1}]	45147	pick-up	0	17
117708	2020-08-15 01:36:35	2020-08-15	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	12167	delivery	5	30
117709	2020-08-15 01:37:46	2020-08-15	12	[{"id_menu":1,"count":1}]	45026	delivery	5	17
117710	2020-08-15 01:40:36	2020-08-15	14	[{"id_menu":2,"count":1}]	45160	delivery	5	19
117711	2020-08-15 01:40:40	2020-08-15	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	45016	delivery	5	22
117712	2020-08-15 01:41:01	2020-08-15	12	[{"id_menu":3,"count":1}]	20948	delivery	5	17
117713	2020-08-15 01:44:44	2020-08-15	9	[{"id_menu":6,"count":2}]	39341	delivery	5	14
117714	2020-08-15 01:44:55	2020-08-15	9	[{"id_menu":6,"count":1}]	18490	pick-up	0	9
117715	2020-08-15 01:45:47	2020-08-15	8	[{"id_menu":5,"count":1}]	11825	delivery	5	13
117716	2020-08-15 01:49:13	2020-08-15	14	[{"id_menu":2,"count":3}]	29536	delivery	5	19
117717	2020-08-15 01:52:24	2020-08-15	9	[{"id_menu":6,"count":1}]	16042	pick-up	0	9
117718	2020-08-15 01:52:30	2020-08-15	12	[{"id_menu":3,"count":1}]	30614	pick-up	0	12
117719	2020-08-15 01:53:04	2020-08-15	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	314	pick-up	0	25
117720	2020-08-15 01:55:32	2020-08-15	9	[{"id_menu":6,"count":1}]	21897	delivery	5	14
117721	2020-08-15 01:56:13	2020-08-15	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	40148	delivery	5	39
117722	2020-08-15 01:59:05	2020-08-15	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29230	delivery	5	48
117723	2020-08-15 02:00:22	2020-08-15	12	[{"id_menu":3,"count":1}]	12633	delivery	5	17
117724	2020-08-15 02:00:31	2020-08-15	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	38688	delivery	5	31
117725	2020-08-15 02:00:56	2020-08-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	45167	delivery	5	28
117726	2020-08-15 02:01:18	2020-08-15	9	[{"id_menu":6,"count":1}]	11583	delivery	5	14
117727	2020-08-15 02:04:40	2020-08-15	14	[{"id_menu":2,"count":1}]	44969	delivery	5	19
117728	2020-08-15 02:05:40	2020-08-15	14	[{"id_menu":2,"count":1}]	14407	delivery	5	19
117729	2020-08-15 02:07:14	2020-08-15	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	560	delivery	5	26
117730	2020-08-15 02:09:45	2020-08-15	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":3}]	45166	delivery	5	27
117731	2020-08-15 02:10:35	2020-08-15	9	[{"id_menu":7,"count":1}]	9797	delivery	5	14
117732	2020-08-15 02:12:52	2020-08-15	9	[{"id_menu":7,"count":1}]	44422	delivery	5	14
117733	2020-08-15 02:13:04	2020-08-15	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18738	delivery	5	37
117734	2020-08-15 02:13:15	2020-08-15	9	[{"id_menu":6,"count":1}]	36606	delivery	5	14
117735	2020-08-15 02:14:48	2020-08-15	17	[{"id_menu":4,"count":1}]	44997	delivery	5	22
117736	2020-08-15 02:19:04	2020-08-15	9	[{"id_menu":7,"count":1}]	27031	delivery	5	14
117737	2020-08-15 02:19:14	2020-08-15	12	[{"id_menu":1,"count":1}]	7218	delivery	5	17
117738	2020-08-15 02:21:09	2020-08-15	9	[{"id_menu":6,"count":1}]	7025	delivery	5	14
117739	2020-08-15 02:23:06	2020-08-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20467	delivery	5	23
117740	2020-08-15 02:28:12	2020-08-15	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	38986	delivery	5	43
117741	2020-08-15 02:29:02	2020-08-15	9	[{"id_menu":6,"count":1}]	45163	delivery	5	14
117742	2020-08-15 02:29:27	2020-08-15	9	[{"id_menu":7,"count":1}]	45145	delivery	5	14
117743	2020-08-15 02:31:35	2020-08-15	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1219	delivery	5	30
117744	2020-08-15 02:32:54	2020-08-15	9	[{"id_menu":6,"count":1}]	34963	delivery	5	14
117745	2020-08-15 02:33:11	2020-08-15	14	[{"id_menu":2,"count":1}]	13731	pick-up	0	14
117746	2020-08-15 02:37:14	2020-08-15	8	[{"id_menu":5,"count":1}]	2187	pick-up	0	8
117747	2020-08-15 02:38:03	2020-08-15	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	39579	pick-up	0	24
117748	2020-08-15 02:47:04	2020-08-15	12	[{"id_menu":3,"count":1}]	17798	pick-up	0	12
117749	2020-08-15 02:53:15	2020-08-15	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	34747	pick-up	0	26
117750	2020-08-15 02:53:43	2020-08-15	17	[{"id_menu":4,"count":1}]	8471	pick-up	0	17
117751	2020-08-15 02:55:02	2020-08-15	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	23362	delivery	5	38
117752	2020-08-15 02:58:03	2020-08-15	12	[{"id_menu":1,"count":1}]	25785	delivery	5	17
117753	2020-08-15 02:59:59	2020-08-15	14	[{"id_menu":2,"count":1}]	30238	delivery	5	19
117754	2020-08-15 03:01:07	2020-08-15	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	43961	delivery	5	51
117755	2020-08-15 03:02:58	2020-08-15	17	[{"id_menu":4,"count":2}]	30687	pick-up	0	17
117756	2020-08-15 03:04:34	2020-08-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	17214	delivery	5	28
117757	2020-08-15 03:05:53	2020-08-15	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	30171	delivery	5	34
117758	2020-08-15 03:05:54	2020-08-15	17	[{"id_menu":4,"count":1}]	7211	delivery	5	22
117759	2020-08-15 03:07:42	2020-08-15	9	[{"id_menu":7,"count":1}]	21048	delivery	5	14
117760	2020-08-15 03:08:29	2020-08-15	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	11586	delivery	5	37
117761	2020-08-15 03:10:40	2020-08-15	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44984	delivery	5	45
117762	2020-08-15 03:13:38	2020-08-15	9	[{"id_menu":7,"count":1}]	21690	delivery	5	14
117763	2020-08-15 03:19:04	2020-08-15	14	[{"id_menu":2,"count":1}]	18526	pick-up	0	14
117764	2020-08-15 03:22:11	2020-08-15	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	7449	delivery	5	37
117765	2020-08-15 03:22:45	2020-08-15	12	[{"id_menu":1,"count":1}]	7415	pick-up	0	12
117766	2020-08-15 03:23:16	2020-08-15	12	[{"id_menu":1,"count":1}]	43390	delivery	5	17
117767	2020-08-15 03:23:39	2020-08-15	17	[{"id_menu":4,"count":1}]	33563	delivery	5	22
117768	2020-08-15 03:25:36	2020-08-15	8	[{"id_menu":5,"count":1}]	19566	delivery	5	13
117769	2020-08-15 03:26:31	2020-08-15	14	[{"id_menu":2,"count":2}]	18332	delivery	5	19
117770	2020-08-15 03:27:16	2020-08-15	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24572	delivery	5	36
117771	2020-08-15 03:27:21	2020-08-15	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	22631	delivery	5	39
117772	2020-08-15 03:28:20	2020-08-15	9	[{"id_menu":6,"count":1}]	45213	delivery	5	14
117773	2020-08-15 03:29:09	2020-08-15	9	[{"id_menu":6,"count":1}]	23030	delivery	5	14
117774	2020-08-15 03:29:12	2020-08-15	14	[{"id_menu":2,"count":1}]	10337	delivery	5	19
117775	2020-08-15 03:31:59	2020-08-15	17	[{"id_menu":4,"count":1}]	18976	pick-up	0	17
117776	2020-08-15 03:32:20	2020-08-15	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	38663	delivery	5	40
117777	2020-08-15 03:32:28	2020-08-15	9	[{"id_menu":7,"count":1}]	39508	delivery	5	14
117778	2020-08-15 03:33:30	2020-08-15	17	[{"id_menu":4,"count":1}]	45202	delivery	5	22
117779	2020-08-15 03:34:25	2020-08-15	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	14153	delivery	5	44
117780	2020-08-15 03:36:43	2020-08-15	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	19729	pick-up	0	38
117781	2020-08-15 03:36:56	2020-08-15	14	[{"id_menu":2,"count":1}]	44095	delivery	5	19
117782	2020-08-15 03:40:48	2020-08-15	9	[{"id_menu":6,"count":1}]	45069	delivery	5	14
117783	2020-08-15 03:40:56	2020-08-15	9	[{"id_menu":6,"count":1}]	5296	delivery	5	14
117784	2020-08-15 03:41:50	2020-08-15	9	[{"id_menu":6,"count":1}]	40311	delivery	5	14
117785	2020-08-15 03:42:19	2020-08-15	12	[{"id_menu":1,"count":1}]	45183	delivery	5	17
117786	2020-08-15 03:42:23	2020-08-15	9	[{"id_menu":6,"count":1}]	45177	delivery	5	14
117787	2020-08-15 03:43:22	2020-08-15	12	[{"id_menu":3,"count":1}]	45119	delivery	5	17
117788	2020-08-15 03:46:35	2020-08-15	9	[{"id_menu":6,"count":1}]	45151	pick-up	0	9
117789	2020-08-15 03:47:17	2020-08-15	9	[{"id_menu":7,"count":1}]	28114	pick-up	0	9
117790	2020-08-15 03:48:07	2020-08-15	9	[{"id_menu":6,"count":1}]	32332	delivery	5	14
117791	2020-08-15 03:49:38	2020-08-15	12	[{"id_menu":3,"count":1}]	31117	delivery	5	17
117792	2020-08-15 03:50:09	2020-08-15	17	[{"id_menu":4,"count":1}]	45062	delivery	5	22
117793	2020-08-15 03:51:03	2020-08-15	8	[{"id_menu":5,"count":1}]	16737	pick-up	0	8
117794	2020-08-15 03:51:52	2020-08-15	9	[{"id_menu":7,"count":1}]	33801	delivery	5	14
117795	2020-08-15 03:52:24	2020-08-15	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	23291	delivery	5	40
117796	2020-08-15 03:55:37	2020-08-15	9	[{"id_menu":6,"count":1}]	792	pick-up	0	9
117797	2020-08-15 03:56:02	2020-08-15	8	[{"id_menu":5,"count":1}]	39654	delivery	5	13
117798	2020-08-15 03:59:05	2020-08-15	14	[{"id_menu":2,"count":1}]	45212	delivery	5	19
117799	2020-08-15 03:59:39	2020-08-15	9	[{"id_menu":6,"count":1}]	45130	delivery	5	14
117800	2020-08-15 04:00:23	2020-08-15	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	25263	delivery	5	26
117801	2020-08-15 04:05:01	2020-08-15	9	[{"id_menu":7,"count":1}]	17124	delivery	5	14
117802	2020-08-15 04:06:58	2020-08-15	9	[{"id_menu":7,"count":1}]	45059	delivery	5	14
117803	2020-08-15 04:10:08	2020-08-15	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	6850	delivery	5	26
117804	2020-08-15 04:12:04	2020-08-15	14	[{"id_menu":2,"count":1}]	24070	delivery	5	19
117805	2020-08-15 04:12:44	2020-08-15	12	[{"id_menu":1,"count":1}]	16934	delivery	5	17
117806	2020-08-15 04:14:02	2020-08-15	12	[{"id_menu":1,"count":1}]	11781	delivery	5	17
117807	2020-08-15 04:15:19	2020-08-15	8	[{"id_menu":5,"count":1}]	19584	delivery	5	13
117808	2020-08-15 04:16:47	2020-08-15	17	[{"id_menu":4,"count":1}]	1322	pick-up	0	17
117809	2020-08-15 04:17:06	2020-08-15	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	29929	delivery	5	22
117810	2020-08-15 04:20:44	2020-08-15	9	[{"id_menu":6,"count":1}]	45136	delivery	5	14
117811	2020-08-15 04:21:40	2020-08-15	9	[{"id_menu":6,"count":1}]	45152	delivery	5	14
117812	2020-08-15 04:22:24	2020-08-15	12	[{"id_menu":1,"count":1}]	44972	delivery	5	17
117813	2020-08-15 04:22:38	2020-08-15	9	[{"id_menu":6,"count":1}]	18180	delivery	5	14
117814	2020-08-15 04:23:58	2020-08-15	8	[{"id_menu":5,"count":1}]	19930	delivery	5	13
117815	2020-08-15 04:25:46	2020-08-15	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	29608	delivery	5	23
117816	2020-08-15 04:26:45	2020-08-15	12	[{"id_menu":1,"count":1}]	26528	pick-up	0	12
117817	2020-08-15 04:27:19	2020-08-15	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44994	delivery	5	47
117818	2020-08-15 04:28:48	2020-08-15	14	[{"id_menu":2,"count":1}]	45144	delivery	5	19
117819	2020-08-15 04:30:16	2020-08-15	17	[{"id_menu":4,"count":1}]	8142	delivery	5	22
117820	2020-08-15 04:30:54	2020-08-15	14	[{"id_menu":2,"count":1}]	45143	delivery	5	19
117821	2020-08-15 04:31:27	2020-08-15	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	44970	delivery	5	43
117822	2020-08-15 04:32:27	2020-08-15	8	[{"id_menu":5,"count":1}]	13324	pick-up	0	8
117823	2020-08-15 04:33:50	2020-08-15	12	[{"id_menu":1,"count":1}]	21492	delivery	5	17
117824	2020-08-15 04:34:30	2020-08-15	12	[{"id_menu":1,"count":1}]	7709	delivery	5	17
117825	2020-08-15 04:34:42	2020-08-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	36759	delivery	5	28
117826	2020-08-15 04:38:55	2020-08-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10807	delivery	5	23
117827	2020-08-15 04:40:16	2020-08-15	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44976	delivery	5	49
117828	2020-08-15 04:42:09	2020-08-15	14	[{"id_menu":2,"count":1}]	45189	delivery	5	19
117829	2020-08-15 04:43:00	2020-08-15	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	925	pick-up	0	29
117830	2020-08-15 04:43:58	2020-08-15	14	[{"id_menu":2,"count":1}]	10623	delivery	5	19
117831	2020-08-15 04:44:48	2020-08-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8514	delivery	5	23
117832	2020-08-15 04:44:58	2020-08-15	17	[{"id_menu":4,"count":1}]	38941	delivery	5	22
117833	2020-08-15 04:47:27	2020-08-15	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	39626	delivery	5	37
117834	2020-08-15 04:49:21	2020-08-15	17	[{"id_menu":4,"count":1}]	10990	delivery	5	22
117835	2020-08-15 04:51:29	2020-08-15	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	44978	delivery	5	40
117836	2020-08-15 04:52:24	2020-08-15	14	[{"id_menu":2,"count":1}]	2057	delivery	5	19
117837	2020-08-15 04:56:52	2020-08-15	12	[{"id_menu":1,"count":1}]	6794	delivery	5	17
117838	2020-08-15 04:59:24	2020-08-15	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	14263	delivery	5	45
117839	2020-08-15 05:00:32	2020-08-15	9	[{"id_menu":7,"count":1}]	27313	delivery	5	14
117840	2020-08-15 05:01:01	2020-08-15	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	45184	delivery	5	27
117841	2020-08-15 05:03:31	2020-08-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	45035	delivery	5	31
117842	2020-08-15 05:07:37	2020-08-15	9	[{"id_menu":6,"count":1}]	26289	delivery	5	14
117843	2020-08-15 05:12:01	2020-08-15	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37486	delivery	5	48
117844	2020-08-15 05:15:47	2020-08-15	9	[{"id_menu":7,"count":1}]	2311	pick-up	0	9
117845	2020-08-15 05:17:08	2020-08-15	9	[{"id_menu":6,"count":1}]	20586	delivery	5	14
117846	2020-08-15 05:24:42	2020-08-15	9	[{"id_menu":7,"count":1}]	45014	delivery	5	14
117847	2020-08-15 05:27:13	2020-08-15	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	10676	delivery	5	43
117848	2020-08-15 05:27:16	2020-08-15	12	[{"id_menu":3,"count":1}]	25749	delivery	5	17
117849	2020-08-15 05:28:37	2020-08-15	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	45074	delivery	5	25
117850	2020-08-15 05:33:01	2020-08-15	12	[{"id_menu":1,"count":1}]	18190	delivery	5	17
117851	2020-08-15 05:33:48	2020-08-15	8	[{"id_menu":5,"count":1}]	3148	pick-up	0	8
117852	2020-08-15 05:35:15	2020-08-15	9	[{"id_menu":6,"count":1}]	31155	delivery	5	14
117853	2020-08-15 05:36:23	2020-08-15	8	[{"id_menu":5,"count":1}]	45149	delivery	5	13
117854	2020-08-15 05:36:38	2020-08-15	9	[{"id_menu":6,"count":1}]	3596	pick-up	0	9
117855	2020-08-15 05:42:37	2020-08-15	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	35291	delivery	5	26
117856	2020-08-15 05:47:48	2020-08-15	8	[{"id_menu":5,"count":1}]	4060	delivery	5	13
117857	2020-08-15 05:48:42	2020-08-15	9	[{"id_menu":7,"count":1}]	9303	pick-up	0	9
117858	2020-08-15 05:49:13	2020-08-15	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33927	delivery	5	31
117859	2020-08-15 05:51:34	2020-08-15	9	[{"id_menu":6,"count":1}]	197	pick-up	0	9
117860	2020-08-15 05:51:37	2020-08-15	12	[{"id_menu":1,"count":1}]	45162	delivery	5	17
117861	2020-08-15 05:51:48	2020-08-15	9	[{"id_menu":6,"count":1}]	45099	delivery	5	14
117862	2020-08-15 05:52:43	2020-08-15	14	[{"id_menu":2,"count":1}]	41376	delivery	5	19
117863	2020-08-15 05:57:07	2020-08-15	17	[{"id_menu":4,"count":1}]	28842	delivery	5	22
117864	2020-08-15 05:58:18	2020-08-15	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	45055	delivery	5	25
117865	2020-08-15 06:01:43	2020-08-15	12	[{"id_menu":1,"count":1}]	45090	delivery	5	17
117866	2020-08-15 06:04:25	2020-08-15	12	[{"id_menu":1,"count":1}]	11183	delivery	5	17
117867	2020-08-15 06:06:24	2020-08-15	9	[{"id_menu":6,"count":2}]	24435	delivery	5	14
117868	2020-08-15 06:07:33	2020-08-15	14	[{"id_menu":2,"count":1}]	44973	delivery	5	19
117869	2020-08-15 06:11:07	2020-08-15	9	[{"id_menu":6,"count":1}]	35599	delivery	5	14
117870	2020-08-15 06:13:01	2020-08-15	9	[{"id_menu":6,"count":1}]	1423	delivery	5	14
117871	2020-08-15 06:13:09	2020-08-15	14	[{"id_menu":2,"count":1}]	1592	delivery	5	19
117872	2020-08-15 06:15:27	2020-08-15	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	42566	delivery	5	22
117873	2020-08-15 06:16:59	2020-08-15	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	45214	delivery	5	34
117874	2020-08-15 06:17:13	2020-08-15	9	[{"id_menu":6,"count":1}]	31467	delivery	5	14
117875	2020-08-15 06:17:15	2020-08-15	9	[{"id_menu":7,"count":1}]	45169	delivery	5	14
117876	2020-08-15 06:18:36	2020-08-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	9891	delivery	5	28
117877	2020-08-15 06:23:00	2020-08-15	12	[{"id_menu":3,"count":1}]	23677	pick-up	0	12
117878	2020-08-15 06:24:27	2020-08-15	9	[{"id_menu":7,"count":1}]	45123	delivery	5	14
117879	2020-08-15 06:25:00	2020-08-15	12	[{"id_menu":3,"count":1}]	11464	delivery	5	17
117880	2020-08-15 06:31:56	2020-08-15	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	35812	pick-up	0	33
117881	2020-08-15 06:37:04	2020-08-15	9	[{"id_menu":6,"count":1}]	2434	pick-up	0	9
117882	2020-08-15 06:37:04	2020-08-15	9	[{"id_menu":7,"count":1}]	29678	pick-up	0	9
117883	2020-08-15 06:40:34	2020-08-15	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	35265	pick-up	0	21
117884	2020-08-15 06:42:50	2020-08-15	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	15961	pick-up	0	21
117885	2020-08-15 06:42:57	2020-08-15	12	[{"id_menu":1,"count":1}]	27183	delivery	5	17
117886	2020-08-15 06:43:19	2020-08-15	8	[{"id_menu":5,"count":1}]	38594	delivery	5	13
117887	2020-08-15 06:45:58	2020-08-15	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	44962	delivery	5	37
117888	2020-08-15 06:46:27	2020-08-15	17	[{"id_menu":4,"count":1}]	26618	pick-up	0	17
117889	2020-08-15 06:46:31	2020-08-15	9	[{"id_menu":7,"count":1}]	8465	delivery	5	14
117890	2020-08-15 06:46:48	2020-08-15	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	33431	pick-up	0	31
117891	2020-08-15 06:50:16	2020-08-15	14	[{"id_menu":2,"count":1}]	25088	pick-up	0	14
117892	2020-08-15 06:50:38	2020-08-15	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	45137	delivery	5	26
117893	2020-08-15 06:54:18	2020-08-15	9	[{"id_menu":7,"count":1}]	17055	delivery	5	14
117894	2020-08-15 06:54:34	2020-08-15	12	[{"id_menu":1,"count":1}]	34226	delivery	5	17
117895	2020-08-15 06:54:46	2020-08-15	9	[{"id_menu":6,"count":1}]	17412	delivery	5	14
117896	2020-08-15 06:55:07	2020-08-15	9	[{"id_menu":7,"count":1}]	24399	delivery	5	14
117897	2020-08-15 06:56:41	2020-08-15	12	[{"id_menu":3,"count":1}]	20709	delivery	5	17
117898	2020-08-15 06:56:43	2020-08-15	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16734	delivery	5	45
117899	2020-08-15 06:57:11	2020-08-15	14	[{"id_menu":2,"count":1}]	1722	delivery	5	19
117900	2020-08-15 06:58:09	2020-08-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	45155	delivery	5	31
117901	2020-08-15 06:58:12	2020-08-15	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	45207	delivery	5	31
117902	2020-08-15 06:59:11	2020-08-15	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20471	delivery	5	34
117903	2020-08-15 07:01:48	2020-08-15	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	30967	delivery	5	34
117904	2020-08-15 07:02:12	2020-08-15	12	[{"id_menu":3,"count":1}]	45021	delivery	5	17
117905	2020-08-15 07:03:17	2020-08-15	9	[{"id_menu":7,"count":1}]	10381	pick-up	0	9
117906	2020-08-15 07:03:53	2020-08-15	9	[{"id_menu":6,"count":1}]	209	pick-up	0	9
117907	2020-08-15 07:06:19	2020-08-15	8	[{"id_menu":5,"count":1}]	22259	delivery	5	13
117908	2020-08-15 07:06:22	2020-08-15	46	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	7476	delivery	5	51
117909	2020-08-15 07:07:08	2020-08-15	9	[{"id_menu":6,"count":1}]	32566	delivery	5	14
117910	2020-08-15 07:07:21	2020-08-15	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	45054	delivery	5	43
117911	2020-08-15 07:07:48	2020-08-15	17	[{"id_menu":4,"count":1}]	27205	delivery	5	22
117912	2020-08-15 07:11:30	2020-08-15	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	45023	delivery	5	40
117913	2020-08-15 07:12:17	2020-08-15	14	[{"id_menu":2,"count":1}]	36650	delivery	5	19
117914	2020-08-15 07:14:51	2020-08-15	9	[{"id_menu":7,"count":1}]	41823	delivery	5	14
117915	2020-08-15 07:17:20	2020-08-15	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	45077	delivery	5	23
117916	2020-08-15 07:18:14	2020-08-15	9	[{"id_menu":7,"count":1}]	9306	delivery	5	14
117917	2020-08-15 07:20:51	2020-08-15	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	11104	delivery	5	25
117918	2020-08-15 07:21:31	2020-08-15	17	[{"id_menu":4,"count":1}]	30755	delivery	5	22
117919	2020-08-15 07:22:33	2020-08-15	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	45088	delivery	5	31
117920	2020-08-15 07:26:19	2020-08-15	9	[{"id_menu":7,"count":1}]	9934	pick-up	0	9
117921	2020-08-15 07:27:44	2020-08-15	9	[{"id_menu":7,"count":1}]	2083	pick-up	0	9
117922	2020-08-15 07:28:18	2020-08-15	14	[{"id_menu":2,"count":1}]	8004	pick-up	0	14
117923	2020-08-15 07:31:12	2020-08-15	9	[{"id_menu":7,"count":1}]	20297	delivery	5	14
117924	2020-08-15 07:36:04	2020-08-15	17	[{"id_menu":4,"count":1}]	4411	delivery	5	22
117925	2020-08-15 07:36:55	2020-08-15	9	[{"id_menu":7,"count":1}]	31230	delivery	5	14
117926	2020-08-15 07:37:43	2020-08-15	9	[{"id_menu":7,"count":1}]	12602	pick-up	0	9
117927	2020-08-15 07:38:12	2020-08-15	12	[{"id_menu":3,"count":1}]	6535	pick-up	0	12
117928	2020-08-15 07:41:58	2020-08-15	14	[{"id_menu":2,"count":1}]	16868	delivery	5	19
117929	2020-08-15 07:42:18	2020-08-15	14	[{"id_menu":2,"count":1}]	33153	pick-up	0	14
117930	2020-08-15 07:42:53	2020-08-15	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31035	delivery	5	40
117931	2020-08-15 07:43:39	2020-08-15	9	[{"id_menu":6,"count":1}]	44986	delivery	5	14
117932	2020-08-15 07:44:48	2020-08-15	12	[{"id_menu":1,"count":1}]	31323	delivery	5	17
117933	2020-08-15 07:47:17	2020-08-15	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12232	delivery	5	47
117934	2020-08-15 07:49:10	2020-08-15	9	[{"id_menu":7,"count":1}]	15100	delivery	5	14
117935	2020-08-15 07:50:50	2020-08-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	37644	pick-up	0	23
117936	2020-08-15 07:54:04	2020-08-15	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	34932	delivery	5	22
117937	2020-08-15 07:54:43	2020-08-15	9	[{"id_menu":6,"count":2}]	31706	delivery	5	14
117938	2020-08-15 07:55:10	2020-08-15	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	32387	delivery	5	22
117939	2020-08-15 07:57:46	2020-08-15	14	[{"id_menu":2,"count":2}]	21374	delivery	5	19
117940	2020-08-15 07:58:21	2020-08-15	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	41933	delivery	5	45
117941	2020-08-15 07:59:04	2020-08-15	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	27056	delivery	5	42
117942	2020-08-15 07:59:07	2020-08-15	17	[{"id_menu":4,"count":1}]	42249	pick-up	0	17
117943	2020-08-15 08:01:32	2020-08-15	9	[{"id_menu":6,"count":1}]	10278	delivery	5	14
117944	2020-08-15 08:02:26	2020-08-15	12	[{"id_menu":3,"count":1}]	14945	delivery	5	17
117945	2020-08-15 08:02:26	2020-08-15	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	10786	delivery	5	36
117946	2020-08-15 08:05:19	2020-08-15	9	[{"id_menu":7,"count":1}]	29502	delivery	5	14
117947	2020-08-15 08:06:45	2020-08-15	9	[{"id_menu":6,"count":1}]	45051	delivery	5	14
117948	2020-08-15 08:06:56	2020-08-15	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	29912	pick-up	0	26
117949	2020-08-15 08:08:53	2020-08-15	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	35101	delivery	5	30
117950	2020-08-15 08:09:32	2020-08-15	12	[{"id_menu":3,"count":1}]	2902	delivery	5	17
117951	2020-08-15 08:10:40	2020-08-15	9	[{"id_menu":6,"count":1}]	40447	delivery	5	14
117952	2020-08-15 08:13:15	2020-08-15	14	[{"id_menu":2,"count":1}]	27651	delivery	5	19
117953	2020-08-15 08:14:35	2020-08-15	12	[{"id_menu":3,"count":1}]	45075	pick-up	0	12
117954	2020-08-15 08:15:47	2020-08-15	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":2}]	2760	pick-up	0	23
117955	2020-08-15 08:16:39	2020-08-15	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	10549	delivery	5	44
117956	2020-08-15 08:20:08	2020-08-15	9	[{"id_menu":6,"count":1}]	5308	delivery	5	14
117957	2020-08-15 08:21:18	2020-08-15	17	[{"id_menu":4,"count":1}]	29462	delivery	5	22
117958	2020-08-15 08:23:35	2020-08-15	12	[{"id_menu":1,"count":1}]	1656	pick-up	0	12
117959	2020-08-15 08:24:11	2020-08-15	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	28056	delivery	5	26
117960	2020-08-15 08:25:58	2020-08-15	12	[{"id_menu":3,"count":1}]	44999	delivery	5	17
117961	2020-08-15 08:26:00	2020-08-15	14	[{"id_menu":2,"count":2}]	38249	delivery	5	19
117962	2020-08-15 08:26:10	2020-08-15	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	28722	delivery	5	22
117963	2020-08-15 08:30:50	2020-08-15	12	[{"id_menu":3,"count":1}]	15864	pick-up	0	12
117964	2020-08-15 08:33:33	2020-08-15	9	[{"id_menu":6,"count":1}]	140	delivery	5	14
117965	2020-08-15 08:34:14	2020-08-15	17	[{"id_menu":4,"count":1}]	11996	delivery	5	22
117966	2020-08-15 08:34:16	2020-08-15	12	[{"id_menu":1,"count":1}]	45208	delivery	5	17
117967	2020-08-15 08:35:04	2020-08-15	8	[{"id_menu":5,"count":1}]	4414	pick-up	0	8
117968	2020-08-15 08:35:11	2020-08-15	9	[{"id_menu":6,"count":1}]	11282	delivery	5	14
117969	2020-08-15 08:35:35	2020-08-15	17	[{"id_menu":4,"count":1}]	1934	pick-up	0	17
117970	2020-08-15 08:39:09	2020-08-15	8	[{"id_menu":5,"count":1}]	43259	delivery	5	13
117971	2020-08-15 08:40:08	2020-08-15	12	[{"id_menu":3,"count":1}]	32611	delivery	5	17
117972	2020-08-15 08:49:13	2020-08-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	25541	delivery	5	28
117973	2020-08-15 08:51:01	2020-08-15	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29172	delivery	5	48
117974	2020-08-15 08:51:54	2020-08-15	12	[{"id_menu":1,"count":1}]	10343	pick-up	0	12
117975	2020-08-15 08:52:24	2020-08-15	8	[{"id_menu":5,"count":1}]	21680	delivery	5	13
117976	2020-08-15 08:53:57	2020-08-15	9	[{"id_menu":7,"count":1}]	45081	delivery	5	14
117977	2020-08-15 08:55:14	2020-08-15	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	42515	pick-up	0	26
117978	2020-08-15 08:55:15	2020-08-15	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	17183	delivery	5	27
117979	2020-08-15 08:58:23	2020-08-15	9	[{"id_menu":6,"count":1}]	39321	delivery	5	14
117980	2020-08-15 08:58:43	2020-08-15	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	30308	delivery	5	36
117981	2020-08-15 09:00:41	2020-08-15	9	[{"id_menu":7,"count":1}]	14972	delivery	5	14
117982	2020-08-15 09:05:14	2020-08-15	9	[{"id_menu":7,"count":1}]	13522	delivery	5	14
117983	2020-08-15 09:07:53	2020-08-15	9	[{"id_menu":6,"count":1}]	45159	delivery	5	14
117984	2020-08-15 09:08:40	2020-08-15	9	[{"id_menu":7,"count":1}]	34518	delivery	5	14
117985	2020-08-15 09:09:26	2020-08-15	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	13101	delivery	5	26
117986	2020-08-15 09:09:28	2020-08-15	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	45179	delivery	5	40
117987	2020-08-15 09:09:59	2020-08-15	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5797	delivery	5	31
117988	2020-08-15 09:10:14	2020-08-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	25759	delivery	5	28
117989	2020-08-15 09:10:32	2020-08-15	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17703	delivery	5	22
117990	2020-08-15 09:10:36	2020-08-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	42481	pick-up	0	18
117991	2020-08-15 09:12:56	2020-08-15	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	45131	delivery	5	26
117992	2020-08-15 09:13:14	2020-08-15	12	[{"id_menu":3,"count":1}]	45034	delivery	5	17
117993	2020-08-15 09:13:22	2020-08-15	14	[{"id_menu":2,"count":1}]	42318	pick-up	0	14
117994	2020-08-15 09:13:29	2020-08-15	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	14239	delivery	5	45
117995	2020-08-15 09:14:02	2020-08-15	14	[{"id_menu":2,"count":1}]	431	pick-up	0	14
117996	2020-08-15 09:14:16	2020-08-15	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	11559	delivery	5	34
117997	2020-08-15 09:14:18	2020-08-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5830	delivery	5	28
117998	2020-08-15 09:14:41	2020-08-15	9	[{"id_menu":6,"count":1}]	389	delivery	5	14
117999	2020-08-15 09:15:34	2020-08-15	12	[{"id_menu":3,"count":1}]	36275	delivery	5	17
118000	2020-08-15 09:16:22	2020-08-15	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	7311	delivery	5	23
118001	2020-08-15 09:16:23	2020-08-15	9	[{"id_menu":6,"count":1}]	32799	delivery	5	14
118002	2020-08-15 09:18:23	2020-08-15	17	[{"id_menu":4,"count":1}]	27206	delivery	5	22
118003	2020-08-15 09:19:00	2020-08-15	17	[{"id_menu":4,"count":1}]	33291	delivery	5	22
118004	2020-08-15 09:22:10	2020-08-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	45129	delivery	5	23
118005	2020-08-15 09:23:33	2020-08-15	14	[{"id_menu":2,"count":1}]	44964	delivery	5	19
118006	2020-08-15 09:26:43	2020-08-15	9	[{"id_menu":7,"count":1}]	45082	delivery	5	14
118007	2020-08-15 09:30:03	2020-08-15	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	10209	pick-up	0	21
118008	2020-08-15 09:31:11	2020-08-15	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	45191	delivery	5	26
118009	2020-08-15 09:31:13	2020-08-15	9	[{"id_menu":7,"count":1}]	24742	delivery	5	14
118010	2020-08-15 09:34:51	2020-08-15	14	[{"id_menu":2,"count":1}]	38747	delivery	5	19
118011	2020-08-15 09:35:13	2020-08-15	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	13306	delivery	5	26
118012	2020-08-15 09:35:33	2020-08-15	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	1885	pick-up	0	37
118013	2020-08-15 09:39:30	2020-08-15	12	[{"id_menu":3,"count":1}]	24643	delivery	5	17
118014	2020-08-15 09:42:18	2020-08-15	8	[{"id_menu":5,"count":1}]	7227	delivery	5	13
118015	2020-08-15 09:43:40	2020-08-15	9	[{"id_menu":7,"count":1}]	43106	delivery	5	14
118016	2020-08-15 09:43:47	2020-08-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	884	pick-up	0	23
118017	2020-08-15 09:44:51	2020-08-15	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	33322	pick-up	0	41
118018	2020-08-15 09:46:49	2020-08-15	9	[{"id_menu":7,"count":1}]	45199	delivery	5	14
118019	2020-08-15 09:49:54	2020-08-15	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	45036	delivery	5	34
118020	2020-08-15 09:50:26	2020-08-15	8	[{"id_menu":5,"count":1}]	31168	delivery	5	13
118021	2020-08-15 09:50:32	2020-08-15	9	[{"id_menu":7,"count":1}]	6107	delivery	5	14
118022	2020-08-15 09:51:11	2020-08-15	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	19139	delivery	5	43
118023	2020-08-15 09:51:28	2020-08-15	8	[{"id_menu":5,"count":1}]	36218	delivery	5	13
118024	2020-08-15 09:56:50	2020-08-15	9	[{"id_menu":7,"count":1}]	17360	delivery	5	14
118025	2020-08-15 09:59:39	2020-08-15	17	[{"id_menu":4,"count":1}]	20780	pick-up	0	17
118026	2020-08-15 09:59:49	2020-08-15	9	[{"id_menu":7,"count":1}]	45132	pick-up	0	9
118027	2020-08-15 10:00:53	2020-08-15	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	35806	delivery	5	31
118028	2020-08-15 10:02:21	2020-08-15	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1228	pick-up	0	21
118029	2020-08-15 10:03:53	2020-08-15	14	[{"id_menu":2,"count":1}]	39118	delivery	5	19
118030	2020-08-15 10:04:15	2020-08-15	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	11544	delivery	5	31
118031	2020-08-15 10:04:32	2020-08-15	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	23341	delivery	5	37
118032	2020-08-15 10:04:55	2020-08-15	12	[{"id_menu":3,"count":1}]	45086	delivery	5	17
118033	2020-08-15 10:04:56	2020-08-15	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	33492	delivery	5	22
118034	2020-08-15 10:08:11	2020-08-15	14	[{"id_menu":2,"count":1}]	22743	pick-up	0	14
118035	2020-08-15 10:09:20	2020-08-15	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	27037	delivery	5	29
118036	2020-08-15 10:10:22	2020-08-15	12	[{"id_menu":1,"count":1}]	45128	delivery	5	17
118037	2020-08-15 10:11:39	2020-08-15	12	[{"id_menu":3,"count":1}]	45007	delivery	5	17
118038	2020-08-15 10:11:49	2020-08-15	9	[{"id_menu":7,"count":2}]	45185	pick-up	0	9
118039	2020-08-15 10:11:50	2020-08-15	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	136	pick-up	0	35
118040	2020-08-15 10:13:33	2020-08-15	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	34688	delivery	5	26
118041	2020-08-15 10:13:52	2020-08-15	17	[{"id_menu":4,"count":1}]	35986	pick-up	0	17
118042	2020-08-15 10:14:57	2020-08-15	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	45008	delivery	5	25
118043	2020-08-15 10:15:19	2020-08-15	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	45138	delivery	5	31
118044	2020-08-15 10:17:25	2020-08-15	9	[{"id_menu":6,"count":1}]	45095	delivery	5	14
118045	2020-08-15 10:18:41	2020-08-15	9	[{"id_menu":6,"count":1}]	8955	delivery	5	14
118046	2020-08-15 10:21:18	2020-08-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	44971	delivery	5	23
118047	2020-08-15 10:22:34	2020-08-15	12	[{"id_menu":3,"count":1}]	20820	pick-up	0	12
118048	2020-08-15 10:25:05	2020-08-15	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	30999	delivery	5	26
118049	2020-08-15 10:31:30	2020-08-15	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	45000	delivery	5	22
118050	2020-08-15 10:31:59	2020-08-15	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	45058	delivery	5	52
118051	2020-08-15 10:33:05	2020-08-15	14	[{"id_menu":2,"count":1}]	8286	delivery	5	19
118052	2020-08-15 10:33:55	2020-08-15	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	35873	delivery	5	40
118053	2020-08-15 10:35:54	2020-08-15	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	30153	pick-up	0	31
118054	2020-08-15 10:45:08	2020-08-15	9	[{"id_menu":7,"count":1}]	32937	delivery	5	14
118055	2020-08-15 10:50:29	2020-08-15	9	[{"id_menu":6,"count":1}]	45018	pick-up	0	9
118056	2020-08-15 10:51:59	2020-08-15	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	23700	delivery	5	26
118057	2020-08-15 10:52:12	2020-08-15	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	45071	delivery	5	30
118058	2020-08-15 10:52:32	2020-08-15	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	23285	pick-up	0	33
118059	2020-08-15 10:55:04	2020-08-15	12	[{"id_menu":3,"count":1}]	39141	delivery	5	17
118060	2020-08-15 10:55:52	2020-08-15	9	[{"id_menu":6,"count":1}]	5189	pick-up	0	9
118061	2020-08-15 10:56:31	2020-08-15	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7023	delivery	5	43
118062	2020-08-15 10:59:01	2020-08-15	12	[{"id_menu":1,"count":1}]	35961	delivery	5	17
118063	2020-08-15 11:01:30	2020-08-15	9	[{"id_menu":6,"count":1}]	1032	pick-up	0	9
118064	2020-08-15 11:01:48	2020-08-15	9	[{"id_menu":6,"count":1}]	11334	pick-up	0	9
118065	2020-08-15 11:02:05	2020-08-15	9	[{"id_menu":6,"count":2}]	45113	delivery	5	14
118066	2020-08-15 11:04:50	2020-08-15	8	[{"id_menu":5,"count":1}]	45181	delivery	5	13
118067	2020-08-15 11:05:41	2020-08-15	12	[{"id_menu":3,"count":1}]	16170	delivery	5	17
118068	2020-08-15 11:08:26	2020-08-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12936	delivery	5	23
118069	2020-08-15 11:09:35	2020-08-15	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	45193	delivery	5	30
118070	2020-08-15 11:10:44	2020-08-15	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	45203	delivery	5	34
118071	2020-08-15 11:12:43	2020-08-15	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1963	pick-up	0	26
118072	2020-08-15 11:13:02	2020-08-15	8	[{"id_menu":5,"count":2}]	6195	pick-up	0	8
118073	2020-08-15 11:14:15	2020-08-15	8	[{"id_menu":5,"count":1}]	45186	pick-up	0	8
118074	2020-08-15 11:14:16	2020-08-15	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10461	delivery	5	31
118075	2020-08-15 11:14:18	2020-08-15	12	[{"id_menu":3,"count":1}]	36992	delivery	5	17
118076	2020-08-15 11:16:46	2020-08-15	9	[{"id_menu":7,"count":1}]	1509	pick-up	0	9
118077	2020-08-15 11:18:49	2020-08-15	12	[{"id_menu":1,"count":1}]	45098	delivery	5	17
118078	2020-08-15 11:20:45	2020-08-15	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	19316	delivery	5	45
118079	2020-08-15 11:21:27	2020-08-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	42424	delivery	5	28
118080	2020-08-15 11:22:09	2020-08-15	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	45053	delivery	5	40
118081	2020-08-15 11:28:59	2020-08-15	14	[{"id_menu":2,"count":1}]	1940	pick-up	0	14
118082	2020-08-15 11:32:22	2020-08-15	17	[{"id_menu":4,"count":1}]	38602	pick-up	0	17
118083	2020-08-15 11:34:11	2020-08-15	17	[{"id_menu":4,"count":1}]	41741	pick-up	0	17
118084	2020-08-15 11:35:13	2020-08-15	9	[{"id_menu":6,"count":1}]	36770	delivery	5	14
118085	2020-08-15 11:36:03	2020-08-15	8	[{"id_menu":5,"count":1}]	12527	pick-up	0	8
118086	2020-08-15 11:42:14	2020-08-15	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4911	delivery	5	26
118087	2020-08-15 11:45:00	2020-08-15	9	[{"id_menu":7,"count":1}]	30211	delivery	5	14
118088	2020-08-15 11:45:48	2020-08-15	14	[{"id_menu":2,"count":1}]	45134	delivery	5	19
118089	2020-08-15 11:46:30	2020-08-15	9	[{"id_menu":7,"count":1}]	21440	delivery	5	14
118090	2020-08-15 11:49:57	2020-08-15	9	[{"id_menu":6,"count":1}]	45120	delivery	5	14
118091	2020-08-15 11:51:04	2020-08-15	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	35804	delivery	5	31
118092	2020-08-15 12:04:04	2020-08-15	14	[{"id_menu":2,"count":1}]	41408	delivery	5	19
118093	2020-08-15 12:05:01	2020-08-15	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	26920	delivery	5	34
118094	2020-08-15 12:08:43	2020-08-15	14	[{"id_menu":2,"count":1}]	6164	pick-up	0	14
118095	2020-08-15 12:09:26	2020-08-15	8	[{"id_menu":5,"count":1}]	45157	delivery	5	13
118096	2020-08-15 12:10:41	2020-08-15	17	[{"id_menu":4,"count":1}]	4699	delivery	5	22
118097	2020-08-15 12:11:57	2020-08-15	14	[{"id_menu":2,"count":1}]	2362	delivery	5	19
118098	2020-08-15 12:19:13	2020-08-15	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	45065	delivery	5	23
118099	2020-08-15 12:22:51	2020-08-15	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24841	delivery	5	52
118100	2020-08-15 12:22:56	2020-08-15	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4768	delivery	5	40
118101	2020-08-15 12:23:48	2020-08-15	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	30812	delivery	5	30
118102	2020-08-15 12:23:52	2020-08-15	9	[{"id_menu":6,"count":3}]	22752	delivery	5	14
118103	2020-08-15 12:24:14	2020-08-15	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	29543	delivery	5	22
118104	2020-08-15 12:24:48	2020-08-15	9	[{"id_menu":6,"count":1}]	24323	delivery	5	14
118105	2020-08-15 12:27:55	2020-08-15	9	[{"id_menu":7,"count":1}]	21027	delivery	5	14
118106	2020-08-15 12:29:50	2020-08-15	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	45153	delivery	5	37
118107	2020-08-15 12:29:57	2020-08-15	9	[{"id_menu":6,"count":1}]	7520	delivery	5	14
118108	2020-08-15 12:30:23	2020-08-15	12	[{"id_menu":3,"count":1}]	1435	pick-up	0	12
118109	2020-08-15 12:33:11	2020-08-15	12	[{"id_menu":1,"count":1}]	17886	pick-up	0	12
118110	2020-08-15 12:33:58	2020-08-15	14	[{"id_menu":2,"count":1}]	18409	pick-up	0	14
118111	2020-08-15 12:37:01	2020-08-15	14	[{"id_menu":2,"count":1}]	12909	delivery	5	19
118112	2020-08-15 12:41:01	2020-08-15	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	17323	delivery	5	30
118113	2020-08-15 12:41:05	2020-08-15	17	[{"id_menu":4,"count":1}]	20887	delivery	5	22
118114	2020-08-15 12:44:00	2020-08-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	18025	pick-up	0	23
118115	2020-08-15 12:44:27	2020-08-15	17	[{"id_menu":4,"count":1}]	8541	delivery	5	22
118116	2020-08-15 12:47:20	2020-08-15	9	[{"id_menu":7,"count":1}]	8356	delivery	5	14
118117	2020-08-15 12:47:28	2020-08-15	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	45101	delivery	5	26
118118	2020-08-15 12:48:28	2020-08-15	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	14726	delivery	5	23
118119	2020-08-15 12:48:55	2020-08-15	9	[{"id_menu":7,"count":1}]	6163	pick-up	0	9
118120	2020-08-15 12:50:47	2020-08-15	14	[{"id_menu":2,"count":1}]	23111	delivery	5	19
118121	2020-08-15 12:51:17	2020-08-15	17	[{"id_menu":4,"count":1}]	41663	pick-up	0	17
118122	2020-08-15 12:53:16	2020-08-15	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	44975	delivery	5	39
118123	2020-08-15 12:53:38	2020-08-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	41772	pick-up	0	26
118124	2020-08-15 12:55:04	2020-08-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5730	delivery	5	28
118125	2020-08-15 12:56:29	2020-08-15	14	[{"id_menu":2,"count":1}]	92	delivery	5	19
118126	2020-08-15 12:58:02	2020-08-15	14	[{"id_menu":2,"count":1}]	7737	delivery	5	19
118127	2020-08-15 12:59:46	2020-08-15	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	19056	delivery	5	25
118128	2020-08-15 13:00:28	2020-08-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3940	pick-up	0	26
118129	2020-08-15 13:01:29	2020-08-15	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25416	delivery	5	31
118130	2020-08-15 13:02:07	2020-08-15	14	[{"id_menu":2,"count":1}]	35547	delivery	5	19
118131	2020-08-15 13:05:13	2020-08-15	14	[{"id_menu":2,"count":2}]	42599	delivery	5	19
118132	2020-08-15 13:05:51	2020-08-15	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	4937	pick-up	0	20
118133	2020-08-15 13:06:53	2020-08-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	45043	delivery	5	28
118134	2020-08-15 13:07:02	2020-08-15	14	[{"id_menu":2,"count":1}]	44985	delivery	5	19
118135	2020-08-15 13:10:11	2020-08-15	9	[{"id_menu":6,"count":1}]	33798	pick-up	0	9
118136	2020-08-15 13:10:40	2020-08-15	9	[{"id_menu":6,"count":1}]	16308	pick-up	0	9
118137	2020-08-15 13:10:52	2020-08-15	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	24802	pick-up	0	39
118138	2020-08-15 13:11:09	2020-08-15	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	3989	delivery	5	31
118139	2020-08-15 13:11:50	2020-08-15	8	[{"id_menu":5,"count":1}]	45210	pick-up	0	8
118140	2020-08-15 13:11:57	2020-08-15	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	45148	delivery	5	40
118141	2020-08-15 13:14:25	2020-08-15	12	[{"id_menu":3,"count":1}]	23621	pick-up	0	12
118142	2020-08-15 13:19:32	2020-08-15	14	[{"id_menu":2,"count":1}]	45195	pick-up	0	14
118143	2020-08-15 13:21:07	2020-08-15	14	[{"id_menu":2,"count":2}]	17543	delivery	5	19
118144	2020-08-15 13:21:41	2020-08-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	29118	delivery	5	31
118145	2020-08-15 13:21:42	2020-08-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	34394	delivery	5	28
118146	2020-08-15 13:23:34	2020-08-15	9	[{"id_menu":6,"count":2}]	24276	delivery	5	14
118147	2020-08-15 13:23:36	2020-08-15	9	[{"id_menu":7,"count":1}]	45187	delivery	5	14
118148	2020-08-15 13:24:58	2020-08-15	14	[{"id_menu":2,"count":1}]	44586	delivery	5	19
118149	2020-08-15 13:26:53	2020-08-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	45198	delivery	5	28
118150	2020-08-15 13:29:28	2020-08-15	17	[{"id_menu":4,"count":1}]	45033	delivery	5	22
118151	2020-08-15 13:30:38	2020-08-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	45092	delivery	5	28
118152	2020-08-15 13:31:54	2020-08-15	9	[{"id_menu":6,"count":1}]	32335	delivery	5	14
118153	2020-08-15 13:33:17	2020-08-15	9	[{"id_menu":7,"count":1}]	45117	delivery	5	14
118154	2020-08-15 13:36:34	2020-08-15	9	[{"id_menu":7,"count":1}]	20562	delivery	5	14
118155	2020-08-15 13:37:13	2020-08-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6283	delivery	5	23
118156	2020-08-15 13:38:34	2020-08-15	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	43656	pick-up	0	20
118157	2020-08-15 13:39:48	2020-08-15	17	[{"id_menu":4,"count":2}]	45046	delivery	5	22
118158	2020-08-15 13:40:07	2020-08-15	9	[{"id_menu":7,"count":2}]	15489	delivery	5	14
118159	2020-08-15 13:43:13	2020-08-15	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	45164	delivery	5	37
118160	2020-08-15 13:43:22	2020-08-15	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	19715	delivery	5	37
118161	2020-08-15 13:43:33	2020-08-15	9	[{"id_menu":7,"count":2}]	42448	delivery	5	14
118162	2020-08-15 13:43:34	2020-08-15	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	45037	delivery	5	34
118163	2020-08-15 13:46:51	2020-08-15	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	44992	delivery	5	48
118164	2020-08-15 13:49:42	2020-08-15	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2919	delivery	5	40
118165	2020-08-15 13:50:12	2020-08-15	14	[{"id_menu":2,"count":1}]	628	delivery	5	19
118166	2020-08-15 13:51:37	2020-08-15	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	19011	delivery	5	30
118167	2020-08-15 13:52:02	2020-08-15	9	[{"id_menu":7,"count":1}]	3324	delivery	5	14
118168	2020-08-15 13:52:27	2020-08-15	9	[{"id_menu":7,"count":1}]	26407	delivery	5	14
118169	2020-08-15 13:52:37	2020-08-15	14	[{"id_menu":2,"count":1}]	2100	pick-up	0	14
118170	2020-08-15 13:54:11	2020-08-15	8	[{"id_menu":5,"count":1}]	37814	pick-up	0	8
118171	2020-08-15 13:54:51	2020-08-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11051	pick-up	0	18
118172	2020-08-15 13:57:39	2020-08-15	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	7617	delivery	5	28
118173	2020-08-15 13:58:25	2020-08-15	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	30623	pick-up	0	17
118174	2020-08-15 14:02:27	2020-08-15	9	[{"id_menu":7,"count":1}]	5943	pick-up	0	9
118175	2020-08-15 14:02:49	2020-08-15	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	20784	delivery	5	43
118176	2020-08-15 14:03:31	2020-08-15	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14374	delivery	5	40
118177	2020-08-15 14:03:35	2020-08-15	12	[{"id_menu":1,"count":1}]	38180	delivery	5	17
118178	2020-08-15 14:04:07	2020-08-15	9	[{"id_menu":6,"count":1}]	19424	delivery	5	14
118179	2020-08-15 14:06:03	2020-08-15	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	14501	pick-up	0	21
118180	2020-08-15 14:07:41	2020-08-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	43650	delivery	5	31
118181	2020-08-15 14:09:33	2020-08-15	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	36264	delivery	5	22
118182	2020-08-15 14:09:40	2020-08-15	8	[{"id_menu":5,"count":1}]	45112	delivery	5	13
118183	2020-08-15 14:10:03	2020-08-15	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17689	delivery	5	36
118184	2020-08-15 14:11:13	2020-08-15	9	[{"id_menu":6,"count":1}]	28844	delivery	5	14
118185	2020-08-15 14:15:02	2020-08-15	12	[{"id_menu":1,"count":1}]	1685	pick-up	0	12
118186	2020-08-15 14:15:32	2020-08-15	9	[{"id_menu":6,"count":1}]	45200	delivery	5	14
118187	2020-08-15 14:16:23	2020-08-15	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	45091	delivery	5	31
118188	2020-08-15 14:20:48	2020-08-15	9	[{"id_menu":7,"count":2}]	28444	delivery	5	14
118189	2020-08-15 14:23:22	2020-08-15	12	[{"id_menu":1,"count":1}]	12952	delivery	5	17
118190	2020-08-15 14:23:37	2020-08-15	9	[{"id_menu":6,"count":1}]	44988	delivery	5	14
118191	2020-08-15 14:24:55	2020-08-15	12	[{"id_menu":1,"count":1}]	26467	delivery	5	17
118192	2020-08-15 14:26:52	2020-08-15	8	[{"id_menu":5,"count":1}]	45139	delivery	5	13
118193	2020-08-15 14:26:55	2020-08-15	12	[{"id_menu":1,"count":1}]	35933	delivery	5	17
118194	2020-08-15 14:27:56	2020-08-15	9	[{"id_menu":7,"count":1}]	36362	delivery	5	14
118195	2020-08-15 14:28:48	2020-08-15	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13744	delivery	5	31
118196	2020-08-15 14:29:13	2020-08-15	17	[{"id_menu":4,"count":1}]	45122	delivery	5	22
118197	2020-08-15 14:30:25	2020-08-15	9	[{"id_menu":6,"count":1}]	44963	delivery	5	14
118198	2020-08-15 14:31:49	2020-08-15	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	2228	pick-up	0	20
118199	2020-08-15 14:33:36	2020-08-15	9	[{"id_menu":7,"count":1}]	44991	delivery	5	14
118200	2020-08-15 14:35:12	2020-08-15	12	[{"id_menu":3,"count":1}]	27066	delivery	5	17
118201	2020-08-15 14:41:47	2020-08-15	12	[{"id_menu":3,"count":1}]	12917	delivery	5	17
118202	2020-08-15 14:41:51	2020-08-15	14	[{"id_menu":2,"count":1}]	45121	delivery	5	19
118203	2020-08-15 14:43:33	2020-08-15	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	45089	pick-up	0	31
118204	2020-08-15 14:46:35	2020-08-15	17	[{"id_menu":4,"count":1}]	44990	delivery	5	22
118205	2020-08-15 14:47:49	2020-08-15	9	[{"id_menu":7,"count":1}]	43190	delivery	5	14
118206	2020-08-15 14:48:19	2020-08-15	9	[{"id_menu":6,"count":1}]	22608	pick-up	0	9
118207	2020-08-15 14:48:27	2020-08-15	12	[{"id_menu":3,"count":1}]	24074	pick-up	0	12
118208	2020-08-15 14:50:57	2020-08-15	9	[{"id_menu":6,"count":1}]	44989	delivery	5	14
118209	2020-08-15 14:51:54	2020-08-15	12	[{"id_menu":3,"count":1}]	2056	pick-up	0	12
118210	2020-08-15 14:52:14	2020-08-15	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	24900	delivery	5	57
118211	2020-08-15 14:53:08	2020-08-15	12	[{"id_menu":3,"count":1}]	10331	pick-up	0	12
118212	2020-08-15 14:54:29	2020-08-15	9	[{"id_menu":6,"count":1}]	20225	delivery	5	14
118213	2020-08-15 14:55:34	2020-08-15	12	[{"id_menu":3,"count":1}]	19893	pick-up	0	12
118214	2020-08-15 14:56:56	2020-08-15	9	[{"id_menu":6,"count":1}]	44147	delivery	5	14
118215	2020-08-15 14:57:25	2020-08-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	45100	pick-up	0	23
118216	2020-08-15 14:57:28	2020-08-15	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	184	pick-up	0	21
118217	2020-08-15 14:57:56	2020-08-15	9	[{"id_menu":6,"count":1}]	45031	delivery	5	14
118218	2020-08-15 14:59:29	2020-08-15	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2669	delivery	5	31
118219	2020-08-15 15:01:01	2020-08-15	17	[{"id_menu":4,"count":1}]	23488	pick-up	0	17
118220	2020-08-15 15:03:20	2020-08-15	9	[{"id_menu":6,"count":1}]	45156	delivery	5	14
118221	2020-08-15 15:04:09	2020-08-15	9	[{"id_menu":6,"count":1}]	32230	pick-up	0	9
118222	2020-08-15 15:04:56	2020-08-15	14	[{"id_menu":2,"count":1}]	21801	delivery	5	19
118223	2020-08-15 15:05:10	2020-08-15	9	[{"id_menu":7,"count":1}]	10169	delivery	5	14
118224	2020-08-15 15:05:41	2020-08-15	12	[{"id_menu":3,"count":1}]	45176	delivery	5	17
118225	2020-08-15 15:07:19	2020-08-15	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	45197	delivery	5	40
118226	2020-08-15 15:07:19	2020-08-15	14	[{"id_menu":2,"count":1}]	45097	delivery	5	19
118227	2020-08-15 15:07:24	2020-08-15	14	[{"id_menu":2,"count":1}]	822	delivery	5	19
118228	2020-08-15 15:09:13	2020-08-15	9	[{"id_menu":7,"count":1}]	29698	delivery	5	14
118229	2020-08-15 15:11:33	2020-08-15	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	1460	pick-up	0	18
118230	2020-08-15 15:12:34	2020-08-15	17	[{"id_menu":4,"count":1}]	4971	delivery	5	22
118231	2020-08-15 15:14:22	2020-08-15	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	33821	delivery	5	42
118232	2020-08-15 15:16:05	2020-08-15	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	45142	delivery	5	44
118233	2020-08-15 15:19:46	2020-08-15	9	[{"id_menu":7,"count":1}]	33647	pick-up	0	9
118234	2020-08-15 15:20:31	2020-08-15	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	35366	delivery	5	22
118235	2020-08-15 15:21:40	2020-08-15	17	[{"id_menu":4,"count":1}]	41157	delivery	5	22
118236	2020-08-15 15:22:31	2020-08-15	9	[{"id_menu":6,"count":1}]	45206	delivery	5	14
118237	2020-08-15 15:22:48	2020-08-15	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2391	delivery	5	40
118238	2020-08-15 15:22:59	2020-08-15	17	[{"id_menu":4,"count":1}]	135	pick-up	0	17
118239	2020-08-15 15:23:47	2020-08-15	8	[{"id_menu":5,"count":1}]	3964	delivery	5	13
118240	2020-08-15 15:24:10	2020-08-15	17	[{"id_menu":4,"count":1}]	45205	pick-up	0	17
118241	2020-08-15 15:25:03	2020-08-15	8	[{"id_menu":5,"count":1}]	37954	delivery	5	13
118242	2020-08-15 15:25:23	2020-08-15	9	[{"id_menu":7,"count":2}]	31947	delivery	5	14
118243	2020-08-15 15:27:05	2020-08-15	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	45050	delivery	5	22
118244	2020-08-15 15:29:11	2020-08-15	9	[{"id_menu":6,"count":2}]	16342	pick-up	0	9
118245	2020-08-15 15:30:11	2020-08-15	9	[{"id_menu":6,"count":1}]	45161	delivery	5	14
118246	2020-08-15 15:32:42	2020-08-15	12	[{"id_menu":1,"count":1}]	13447	pick-up	0	12
118247	2020-08-15 15:33:51	2020-08-15	12	[{"id_menu":1,"count":1}]	21681	delivery	5	17
118248	2020-08-15 15:36:31	2020-08-15	17	[{"id_menu":4,"count":1}]	20549	pick-up	0	17
118249	2020-08-15 15:40:04	2020-08-15	12	[{"id_menu":1,"count":1}]	45012	delivery	5	17
118250	2020-08-15 15:41:57	2020-08-15	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	21934	delivery	5	43
118251	2020-08-15 15:42:44	2020-08-15	9	[{"id_menu":7,"count":1}]	42117	delivery	5	14
118252	2020-08-15 15:48:28	2020-08-15	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4846	delivery	5	36
118253	2020-08-15 15:48:42	2020-08-15	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24755	delivery	5	36
118254	2020-08-15 15:53:20	2020-08-15	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13636	delivery	5	22
118255	2020-08-15 15:53:23	2020-08-15	14	[{"id_menu":2,"count":1}]	45015	delivery	5	19
118256	2020-08-15 15:57:02	2020-08-15	9	[{"id_menu":6,"count":1}]	44750	delivery	5	14
118257	2020-08-15 15:59:01	2020-08-15	9	[{"id_menu":6,"count":1}]	8476	delivery	5	14
118258	2020-08-15 15:59:11	2020-08-15	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	3685	delivery	5	37
118259	2020-08-15 15:59:45	2020-08-15	8	[{"id_menu":5,"count":1}]	44388	delivery	5	13
118260	2020-08-15 16:00:48	2020-08-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	44819	delivery	5	28
118261	2020-08-15 16:05:26	2020-08-15	9	[{"id_menu":6,"count":1}]	44965	delivery	5	14
118262	2020-08-15 16:07:16	2020-08-15	9	[{"id_menu":7,"count":1}]	45078	delivery	5	14
118263	2020-08-15 16:08:57	2020-08-15	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	45204	delivery	5	43
118264	2020-08-15 16:12:08	2020-08-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	34021	delivery	5	28
118265	2020-08-15 16:12:43	2020-08-15	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15404	delivery	5	37
118266	2020-08-15 16:13:36	2020-08-15	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39745	delivery	5	22
118267	2020-08-15 16:14:03	2020-08-15	8	[{"id_menu":5,"count":1}]	45178	delivery	5	13
118268	2020-08-15 16:15:58	2020-08-15	17	[{"id_menu":4,"count":1}]	38486	delivery	5	22
118269	2020-08-15 16:23:43	2020-08-15	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	20169	delivery	5	23
118270	2020-08-15 16:24:10	2020-08-15	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	11578	delivery	5	26
118271	2020-08-15 16:25:48	2020-08-15	9	[{"id_menu":7,"count":1}]	45211	delivery	5	14
118272	2020-08-15 16:27:02	2020-08-15	9	[{"id_menu":7,"count":1}]	45116	delivery	5	14
118273	2020-08-15 16:30:54	2020-08-15	14	[{"id_menu":2,"count":1}]	23838	delivery	5	19
118274	2020-08-15 16:34:13	2020-08-15	9	[{"id_menu":7,"count":1}]	3028	delivery	5	14
118275	2020-08-15 16:36:21	2020-08-15	9	[{"id_menu":7,"count":2}]	14454	delivery	5	14
118276	2020-08-15 16:36:30	2020-08-15	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	45002	delivery	5	26
118277	2020-08-15 16:37:40	2020-08-15	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	44966	pick-up	0	43
118278	2020-08-15 16:38:40	2020-08-15	14	[{"id_menu":2,"count":1}]	4090	pick-up	0	14
118279	2020-08-15 16:41:40	2020-08-15	9	[{"id_menu":7,"count":1}]	4688	pick-up	0	9
118280	2020-08-15 16:42:05	2020-08-15	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	45192	delivery	5	31
118281	2020-08-15 16:42:46	2020-08-15	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	37465	delivery	5	30
118282	2020-08-15 16:46:50	2020-08-15	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	19506	pick-up	0	22
118283	2020-08-15 16:49:30	2020-08-15	14	[{"id_menu":2,"count":1}]	1085	pick-up	0	14
118284	2020-08-15 16:50:20	2020-08-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	45044	delivery	5	28
118285	2020-08-15 16:51:48	2020-08-15	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	45109	delivery	5	26
118286	2020-08-15 16:51:51	2020-08-15	8	[{"id_menu":5,"count":1}]	18981	pick-up	0	8
118287	2020-08-15 16:52:32	2020-08-15	12	[{"id_menu":1,"count":2}]	35722	pick-up	0	12
118288	2020-08-15 16:53:12	2020-08-15	17	[{"id_menu":4,"count":1}]	36494	pick-up	0	17
118289	2020-08-15 16:55:45	2020-08-15	9	[{"id_menu":6,"count":1}]	10481	delivery	5	14
118290	2020-08-15 16:57:19	2020-08-15	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	44693	delivery	5	36
118291	2020-08-15 16:59:11	2020-08-15	17	[{"id_menu":4,"count":1}]	22478	pick-up	0	17
118292	2020-08-15 17:02:34	2020-08-15	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	45102	delivery	5	35
118293	2020-08-15 17:02:49	2020-08-15	12	[{"id_menu":3,"count":1}]	45063	delivery	5	17
118294	2020-08-15 17:03:44	2020-08-15	9	[{"id_menu":7,"count":1}]	12919	pick-up	0	9
118295	2020-08-15 17:05:33	2020-08-15	14	[{"id_menu":2,"count":1}]	20934	delivery	5	19
118296	2020-08-15 17:07:32	2020-08-15	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	44961	delivery	5	43
118297	2020-08-15 17:08:22	2020-08-15	17	[{"id_menu":4,"count":1}]	15082	delivery	5	22
118298	2020-08-15 17:09:04	2020-08-15	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23373	delivery	5	34
118299	2020-08-15 17:10:39	2020-08-15	12	[{"id_menu":1,"count":1}]	44983	pick-up	0	12
118300	2020-08-15 17:12:06	2020-08-15	12	[{"id_menu":1,"count":1}]	1101	delivery	5	17
118301	2020-08-15 17:12:10	2020-08-15	12	[{"id_menu":3,"count":1}]	45020	delivery	5	17
118302	2020-08-15 17:12:26	2020-08-15	14	[{"id_menu":2,"count":1}]	18304	pick-up	0	14
118303	2020-08-15 17:13:53	2020-08-15	9	[{"id_menu":7,"count":1}]	29013	delivery	5	14
118304	2020-08-15 17:14:06	2020-08-15	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	16227	delivery	5	22
118305	2020-08-15 17:15:00	2020-08-15	14	[{"id_menu":2,"count":1}]	35025	delivery	5	19
118306	2020-08-15 17:18:15	2020-08-15	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	24813	delivery	5	36
118307	2020-08-15 17:19:38	2020-08-15	9	[{"id_menu":6,"count":1}]	44386	pick-up	0	9
118308	2020-08-15 17:22:28	2020-08-15	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	45216	delivery	5	31
118309	2020-08-15 17:24:19	2020-08-15	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12439	delivery	5	39
118310	2020-08-15 17:24:44	2020-08-15	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	30529	delivery	5	23
118311	2020-08-15 17:25:48	2020-08-15	17	[{"id_menu":4,"count":1}]	37562	delivery	5	22
118312	2020-08-15 17:27:49	2020-08-15	8	[{"id_menu":5,"count":1}]	15791	pick-up	0	8
118313	2020-08-15 17:28:01	2020-08-15	9	[{"id_menu":7,"count":1}]	40917	pick-up	0	9
118314	2020-08-15 17:31:00	2020-08-15	9	[{"id_menu":7,"count":1}]	10865	delivery	5	14
118315	2020-08-15 17:32:22	2020-08-15	9	[{"id_menu":6,"count":1}]	44998	delivery	5	14
118316	2020-08-15 17:36:00	2020-08-15	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	45114	delivery	5	43
118317	2020-08-15 17:36:22	2020-08-15	9	[{"id_menu":6,"count":1}]	2076	delivery	5	14
118318	2020-08-15 17:38:20	2020-08-15	12	[{"id_menu":1,"count":1}]	10194	delivery	5	17
118319	2020-08-15 17:38:31	2020-08-15	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	45190	delivery	5	34
118320	2020-08-15 17:38:35	2020-08-15	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	27741	delivery	5	40
118321	2020-08-15 17:45:26	2020-08-15	9	[{"id_menu":6,"count":1}]	45141	delivery	5	14
118322	2020-08-15 17:46:48	2020-08-15	12	[{"id_menu":3,"count":1}]	37099	delivery	5	17
118323	2020-08-15 17:49:32	2020-08-15	9	[{"id_menu":7,"count":1}]	26644	delivery	5	14
118324	2020-08-15 17:50:43	2020-08-15	9	[{"id_menu":6,"count":1}]	3578	pick-up	0	9
118325	2020-08-15 17:53:32	2020-08-15	9	[{"id_menu":6,"count":1}]	36888	delivery	5	14
118326	2020-08-15 17:53:52	2020-08-15	14	[{"id_menu":2,"count":1}]	45028	pick-up	0	14
118327	2020-08-15 17:58:26	2020-08-15	9	[{"id_menu":7,"count":1}]	45029	delivery	5	14
118328	2020-08-15 18:03:13	2020-08-15	8	[{"id_menu":5,"count":1}]	45108	delivery	5	13
118329	2020-08-15 18:04:03	2020-08-15	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	40476	delivery	5	23
118330	2020-08-15 18:09:06	2020-08-15	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	26788	delivery	5	30
118331	2020-08-15 18:11:15	2020-08-15	12	[{"id_menu":1,"count":1}]	45087	delivery	5	17
118332	2020-08-15 18:11:48	2020-08-15	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9273	delivery	5	44
118333	2020-08-15 18:11:49	2020-08-15	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19580	delivery	5	31
118334	2020-08-15 18:13:39	2020-08-15	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28155	delivery	5	22
118335	2020-08-15 18:13:48	2020-08-15	14	[{"id_menu":2,"count":1}]	28456	pick-up	0	14
118336	2020-08-15 18:16:06	2020-08-15	12	[{"id_menu":1,"count":1}]	41785	delivery	5	17
118337	2020-08-15 18:20:50	2020-08-15	17	[{"id_menu":4,"count":1}]	29443	delivery	5	22
118338	2020-08-15 18:22:51	2020-08-15	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6276	delivery	5	35
118339	2020-08-15 18:24:16	2020-08-15	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3508	pick-up	0	31
118340	2020-08-15 18:25:34	2020-08-15	9	[{"id_menu":7,"count":1}]	20670	pick-up	0	9
118341	2020-08-15 18:28:00	2020-08-15	8	[{"id_menu":5,"count":1}]	3333	delivery	5	13
118342	2020-08-15 18:28:16	2020-08-15	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	45042	delivery	5	22
118343	2020-08-15 18:28:53	2020-08-15	14	[{"id_menu":2,"count":1}]	2631	pick-up	0	14
118344	2020-08-15 18:29:03	2020-08-15	14	[{"id_menu":2,"count":1}]	45126	delivery	5	19
118345	2020-08-15 18:30:29	2020-08-15	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	45165	delivery	5	40
118346	2020-08-15 18:30:43	2020-08-15	9	[{"id_menu":7,"count":1}]	9311	delivery	5	14
118347	2020-08-15 18:32:10	2020-08-15	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	28579	delivery	5	37
118348	2020-08-15 18:32:21	2020-08-15	8	[{"id_menu":5,"count":1}]	41023	pick-up	0	8
118349	2020-08-15 18:36:02	2020-08-15	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6156	delivery	5	49
118350	2020-08-15 18:36:47	2020-08-15	14	[{"id_menu":2,"count":1}]	16798	delivery	5	19
118351	2020-08-15 18:37:36	2020-08-15	8	[{"id_menu":5,"count":1}]	45010	delivery	5	13
118352	2020-08-15 18:38:04	2020-08-15	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	40618	delivery	5	30
118353	2020-08-15 18:38:40	2020-08-15	9	[{"id_menu":7,"count":2}]	44981	delivery	5	14
118354	2020-08-15 18:39:47	2020-08-15	9	[{"id_menu":6,"count":1}]	21387	pick-up	0	9
118355	2020-08-15 18:45:04	2020-08-15	14	[{"id_menu":2,"count":1}]	1995	pick-up	0	14
118356	2020-08-15 18:48:54	2020-08-15	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	44982	delivery	5	31
118357	2020-08-15 18:52:51	2020-08-15	12	[{"id_menu":1,"count":1}]	12502	pick-up	0	12
118358	2020-08-15 18:53:26	2020-08-15	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	31997	pick-up	0	21
118359	2020-08-15 18:54:49	2020-08-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	6009	pick-up	0	23
118360	2020-08-15 18:56:15	2020-08-15	12	[{"id_menu":3,"count":1}]	45048	pick-up	0	12
118361	2020-08-15 18:56:31	2020-08-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6594	delivery	5	31
118362	2020-08-15 18:56:47	2020-08-15	14	[{"id_menu":2,"count":1}]	588	pick-up	0	14
118363	2020-08-15 19:00:58	2020-08-15	17	[{"id_menu":4,"count":1}]	45025	delivery	5	22
118364	2020-08-15 19:01:40	2020-08-15	8	[{"id_menu":5,"count":1}]	18959	delivery	5	13
118365	2020-08-15 19:02:37	2020-08-15	17	[{"id_menu":4,"count":1}]	44995	pick-up	0	17
118366	2020-08-15 19:04:31	2020-08-15	14	[{"id_menu":2,"count":2}]	5354	delivery	5	19
118367	2020-08-15 19:05:12	2020-08-15	9	[{"id_menu":7,"count":1}]	45173	pick-up	0	9
118368	2020-08-15 19:05:59	2020-08-15	12	[{"id_menu":1,"count":1}]	28658	delivery	5	17
118369	2020-08-15 19:08:16	2020-08-15	17	[{"id_menu":4,"count":1}]	3898	delivery	5	22
118370	2020-08-15 19:10:25	2020-08-15	12	[{"id_menu":3,"count":1}]	25533	delivery	5	17
118371	2020-08-15 19:11:21	2020-08-15	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	34645	delivery	5	29
118372	2020-08-15 19:11:22	2020-08-15	9	[{"id_menu":6,"count":1}]	45019	delivery	5	14
118373	2020-08-15 19:13:10	2020-08-15	12	[{"id_menu":3,"count":1}]	2827	pick-up	0	12
118374	2020-08-15 19:15:36	2020-08-15	12	[{"id_menu":1,"count":1}]	1445	pick-up	0	12
118375	2020-08-15 19:15:50	2020-08-15	9	[{"id_menu":7,"count":1}]	1318	pick-up	0	9
118376	2020-08-15 19:18:27	2020-08-15	17	[{"id_menu":4,"count":1}]	45039	delivery	5	22
118377	2020-08-15 19:19:35	2020-08-15	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3406	delivery	5	37
118378	2020-08-15 19:19:49	2020-08-15	9	[{"id_menu":7,"count":1}]	41756	delivery	5	14
118379	2020-08-15 19:23:40	2020-08-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	26271	pick-up	0	23
118380	2020-08-15 19:30:00	2020-08-15	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	44977	pick-up	0	20
118381	2020-08-15 19:32:25	2020-08-15	9	[{"id_menu":6,"count":1}]	45170	delivery	5	14
118382	2020-08-15 19:33:33	2020-08-15	17	[{"id_menu":4,"count":1}]	45083	delivery	5	22
118383	2020-08-15 19:37:49	2020-08-15	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	45105	delivery	5	43
118384	2020-08-15 19:38:01	2020-08-15	12	[{"id_menu":3,"count":1}]	17249	delivery	5	17
118385	2020-08-15 19:39:09	2020-08-15	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	45168	delivery	5	22
118386	2020-08-15 19:40:21	2020-08-15	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	45107	delivery	5	35
118387	2020-08-15 19:41:36	2020-08-15	14	[{"id_menu":2,"count":1}]	40658	pick-up	0	14
118388	2020-08-15 19:41:43	2020-08-15	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	34463	delivery	5	34
118389	2020-08-15 19:43:37	2020-08-15	14	[{"id_menu":2,"count":1}]	8109	pick-up	0	14
118390	2020-08-15 19:44:40	2020-08-15	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	5661	delivery	5	31
118391	2020-08-15 19:48:04	2020-08-15	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	44974	delivery	5	42
118392	2020-08-15 19:49:25	2020-08-15	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	45093	delivery	5	48
118393	2020-08-15 19:49:28	2020-08-15	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2874	pick-up	0	41
118394	2020-08-15 19:50:02	2020-08-15	8	[{"id_menu":5,"count":1}]	45070	delivery	5	13
118395	2020-08-15 19:51:27	2020-08-15	12	[{"id_menu":3,"count":1}]	6202	delivery	5	17
118396	2020-08-15 19:53:36	2020-08-15	9	[{"id_menu":7,"count":1}]	3785	pick-up	0	9
118397	2020-08-15 19:54:59	2020-08-15	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	24715	delivery	5	37
118398	2020-08-15 19:55:58	2020-08-15	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	13436	delivery	5	29
118399	2020-08-15 20:00:10	2020-08-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35527	delivery	5	23
118400	2020-08-15 20:01:29	2020-08-15	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	22913	delivery	5	34
118401	2020-08-15 20:02:42	2020-08-15	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	32296	delivery	5	43
118402	2020-08-15 20:03:20	2020-08-15	9	[{"id_menu":6,"count":1}]	45057	delivery	5	14
118403	2020-08-15 20:08:42	2020-08-15	12	[{"id_menu":1,"count":1}]	45047	delivery	5	17
118404	2020-08-15 20:12:31	2020-08-15	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39148	delivery	5	22
118405	2020-08-15 20:16:05	2020-08-15	9	[{"id_menu":6,"count":1}]	18709	delivery	5	14
118406	2020-08-15 20:16:44	2020-08-15	32	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	37983	pick-up	0	32
118407	2020-08-15 20:17:21	2020-08-15	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	16613	pick-up	0	22
118408	2020-08-15 20:18:06	2020-08-15	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	22804	delivery	5	26
118409	2020-08-15 20:19:14	2020-08-15	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	3222	pick-up	0	21
118410	2020-08-15 20:21:45	2020-08-15	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	20816	delivery	5	25
118411	2020-08-15 20:22:41	2020-08-15	8	[{"id_menu":5,"count":1}]	30089	delivery	5	13
118412	2020-08-15 20:24:05	2020-08-15	14	[{"id_menu":2,"count":1}]	29367	delivery	5	19
118413	2020-08-15 20:24:33	2020-08-15	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	122	pick-up	0	31
118414	2020-08-15 20:25:08	2020-08-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	43119	delivery	5	28
118415	2020-08-15 20:31:25	2020-08-15	9	[{"id_menu":6,"count":1}]	45009	delivery	5	14
118416	2020-08-15 20:38:51	2020-08-15	12	[{"id_menu":1,"count":1}]	11407	delivery	5	17
118417	2020-08-15 20:43:18	2020-08-15	17	[{"id_menu":4,"count":1}]	45061	pick-up	0	17
118418	2020-08-15 20:43:31	2020-08-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	13236	delivery	5	28
118419	2020-08-15 20:47:15	2020-08-15	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	27227	delivery	5	39
118420	2020-08-15 20:48:49	2020-08-15	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	38940	delivery	5	34
118421	2020-08-15 20:50:29	2020-08-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44979	delivery	5	23
118422	2020-08-15 20:51:47	2020-08-15	9	[{"id_menu":7,"count":1}]	10153	pick-up	0	9
118423	2020-08-15 20:56:23	2020-08-15	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	16521	delivery	5	26
118424	2020-08-15 20:57:07	2020-08-15	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	4592	delivery	5	26
118425	2020-08-15 20:57:15	2020-08-15	9	[{"id_menu":7,"count":1}]	638	pick-up	0	9
118426	2020-08-15 21:00:22	2020-08-15	17	[{"id_menu":4,"count":2}]	5506	pick-up	0	17
118427	2020-08-15 21:02:38	2020-08-15	9	[{"id_menu":6,"count":1}]	45011	delivery	5	14
118428	2020-08-15 21:07:12	2020-08-15	9	[{"id_menu":6,"count":1}]	14260	delivery	5	14
118429	2020-08-15 21:07:47	2020-08-15	9	[{"id_menu":6,"count":1}]	45111	delivery	5	14
118430	2020-08-15 21:09:34	2020-08-15	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	45080	delivery	5	26
118431	2020-08-15 21:12:16	2020-08-15	14	[{"id_menu":2,"count":1}]	6341	delivery	5	19
118432	2020-08-15 21:12:54	2020-08-15	9	[{"id_menu":6,"count":1}]	44980	delivery	5	14
118433	2020-08-15 21:14:23	2020-08-15	17	[{"id_menu":4,"count":1}]	34168	delivery	5	22
118434	2020-08-15 21:14:43	2020-08-15	9	[{"id_menu":6,"count":1}]	45124	delivery	5	14
118435	2020-08-15 21:17:06	2020-08-15	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	17392	pick-up	0	31
118436	2020-08-15 21:21:15	2020-08-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8949	delivery	5	31
118437	2020-08-15 21:21:25	2020-08-15	9	[{"id_menu":6,"count":2}]	22173	delivery	5	14
118438	2020-08-15 21:21:33	2020-08-15	17	[{"id_menu":4,"count":1}]	10518	delivery	5	22
118439	2020-08-15 21:24:14	2020-08-15	9	[{"id_menu":6,"count":1}]	44996	delivery	5	14
118440	2020-08-15 21:28:28	2020-08-15	14	[{"id_menu":2,"count":1}]	4075	pick-up	0	14
118441	2020-08-15 21:30:45	2020-08-15	14	[{"id_menu":2,"count":1}]	6463	delivery	5	19
118442	2020-08-15 21:31:23	2020-08-15	17	[{"id_menu":4,"count":1}]	45125	delivery	5	22
118443	2020-08-15 21:32:26	2020-08-15	14	[{"id_menu":2,"count":2}]	3077	delivery	5	19
118444	2020-08-15 21:32:41	2020-08-15	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9001	delivery	5	22
118445	2020-08-15 21:32:54	2020-08-15	12	[{"id_menu":1,"count":1}]	4994	delivery	5	17
118446	2020-08-15 21:33:50	2020-08-15	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":2}]	24282	delivery	5	28
118447	2020-08-15 21:34:09	2020-08-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39123	delivery	5	23
118448	2020-08-15 21:34:23	2020-08-15	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	42721	delivery	5	45
118449	2020-08-15 21:35:04	2020-08-15	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	45110	delivery	5	31
118450	2020-08-15 21:37:28	2020-08-15	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	45005	delivery	5	28
118451	2020-08-15 21:37:56	2020-08-15	9	[{"id_menu":6,"count":1}]	8683	delivery	5	14
118452	2020-08-15 21:38:54	2020-08-15	17	[{"id_menu":4,"count":1}]	16852	delivery	5	22
118453	2020-08-15 21:39:44	2020-08-15	17	[{"id_menu":4,"count":1}]	3547	pick-up	0	17
118454	2020-08-15 21:40:11	2020-08-15	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	12582	pick-up	0	31
118455	2020-08-15 21:40:35	2020-08-15	8	[{"id_menu":5,"count":1}]	19063	pick-up	0	8
118456	2020-08-15 21:46:40	2020-08-15	9	[{"id_menu":7,"count":1}]	45175	delivery	5	14
118457	2020-08-15 21:47:50	2020-08-15	17	[{"id_menu":4,"count":1}]	30490	delivery	5	22
118458	2020-08-15 21:48:49	2020-08-15	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10401	delivery	5	36
118459	2020-08-15 21:49:21	2020-08-15	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	45209	delivery	5	40
118460	2020-08-15 21:52:47	2020-08-15	9	[{"id_menu":6,"count":1}]	45052	pick-up	0	9
118461	2020-08-15 21:53:22	2020-08-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	41223	delivery	5	23
118462	2020-08-15 21:57:05	2020-08-15	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	12067	delivery	5	40
118463	2020-08-15 21:57:21	2020-08-15	9	[{"id_menu":6,"count":1}]	44893	delivery	5	14
118464	2020-08-15 21:57:42	2020-08-15	9	[{"id_menu":6,"count":1}]	45076	delivery	5	14
118465	2020-08-15 22:05:48	2020-08-15	9	[{"id_menu":7,"count":1}]	45079	pick-up	0	9
118466	2020-08-15 22:06:18	2020-08-15	12	[{"id_menu":1,"count":1}]	44993	pick-up	0	12
118467	2020-08-15 22:06:30	2020-08-15	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	45215	delivery	5	27
118468	2020-08-15 22:06:32	2020-08-15	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	42987	delivery	5	46
118469	2020-08-15 22:20:51	2020-08-15	17	[{"id_menu":4,"count":1}]	22207	pick-up	0	17
118470	2020-08-15 22:21:35	2020-08-15	17	[{"id_menu":4,"count":1}]	30955	pick-up	0	17
118471	2020-08-15 22:22:45	2020-08-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	45118	delivery	5	23
118472	2020-08-15 22:25:35	2020-08-15	14	[{"id_menu":2,"count":1}]	15032	delivery	5	19
118473	2020-08-15 22:25:42	2020-08-15	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	7162	delivery	5	39
118474	2020-08-15 22:25:53	2020-08-15	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	9565	delivery	5	26
118475	2020-08-15 22:25:56	2020-08-15	8	[{"id_menu":5,"count":1}]	13723	delivery	5	13
118476	2020-08-15 22:29:00	2020-08-15	14	[{"id_menu":2,"count":1}]	45171	delivery	5	19
118477	2020-08-15 22:31:16	2020-08-15	8	[{"id_menu":5,"count":1}]	37443	delivery	5	13
118478	2020-08-15 22:32:22	2020-08-15	17	[{"id_menu":4,"count":1}]	1941	pick-up	0	17
118479	2020-08-15 22:32:36	2020-08-15	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	38771	pick-up	0	29
118480	2020-08-15 22:34:54	2020-08-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	45003	delivery	5	23
118481	2020-08-15 22:35:20	2020-08-15	17	[{"id_menu":4,"count":1}]	17304	delivery	5	22
118482	2020-08-15 22:39:44	2020-08-15	9	[{"id_menu":7,"count":1}]	21562	delivery	5	14
118483	2020-08-15 22:40:53	2020-08-15	9	[{"id_menu":7,"count":1}]	5994	delivery	5	14
118484	2020-08-15 22:41:08	2020-08-15	12	[{"id_menu":3,"count":1}]	15022	delivery	5	17
118485	2020-08-15 22:43:09	2020-08-15	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31975	delivery	5	34
118486	2020-08-15 22:44:16	2020-08-15	9	[{"id_menu":7,"count":1}]	4067	delivery	5	14
118487	2020-08-15 22:44:49	2020-08-15	12	[{"id_menu":1,"count":1}]	29348	pick-up	0	12
118488	2020-08-15 22:45:18	2020-08-15	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	45085	delivery	5	31
118489	2020-08-15 22:45:38	2020-08-15	17	[{"id_menu":4,"count":1}]	10581	delivery	5	22
118490	2020-08-15 22:47:40	2020-08-15	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	29127	delivery	5	31
118491	2020-08-15 22:50:36	2020-08-15	12	[{"id_menu":3,"count":1}]	21636	delivery	5	17
118492	2020-08-15 22:50:48	2020-08-15	9	[{"id_menu":6,"count":1}]	45067	delivery	5	14
118493	2020-08-15 22:51:30	2020-08-15	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11596	delivery	5	45
118494	2020-08-15 22:52:17	2020-08-15	14	[{"id_menu":2,"count":1}]	1528	delivery	5	19
118495	2020-08-15 22:53:27	2020-08-15	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	45201	pick-up	0	29
118496	2020-08-15 22:56:25	2020-08-15	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25790	delivery	5	40
118497	2020-08-15 22:58:56	2020-08-15	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	42271	delivery	5	28
118498	2020-08-15 23:01:19	2020-08-15	12	[{"id_menu":3,"count":1}]	45103	delivery	5	17
118499	2020-08-15 23:01:43	2020-08-15	9	[{"id_menu":7,"count":2}]	45154	delivery	5	14
118500	2020-08-15 23:03:33	2020-08-15	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	33789	delivery	5	36
118501	2020-08-15 23:04:18	2020-08-15	8	[{"id_menu":5,"count":1}]	36917	delivery	5	13
118502	2020-08-15 23:07:22	2020-08-15	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	43245	pick-up	0	31
118503	2020-08-15 23:08:13	2020-08-15	12	[{"id_menu":3,"count":1}]	45006	delivery	5	17
118504	2020-08-15 23:08:50	2020-08-15	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14885	pick-up	0	41
118505	2020-08-15 23:12:14	2020-08-15	12	[{"id_menu":1,"count":1}]	38450	pick-up	0	12
118506	2020-08-15 23:13:09	2020-08-15	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	45032	delivery	5	26
118507	2020-08-15 23:13:54	2020-08-15	9	[{"id_menu":6,"count":3}]	45064	delivery	5	14
118508	2020-08-15 23:14:34	2020-08-15	9	[{"id_menu":7,"count":1}]	44743	delivery	5	14
118509	2020-08-15 23:16:11	2020-08-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	45115	delivery	5	23
118510	2020-08-15 23:17:21	2020-08-15	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	45084	delivery	5	28
118511	2020-08-15 23:18:59	2020-08-15	12	[{"id_menu":1,"count":1}]	45180	delivery	5	17
118512	2020-08-15 23:19:00	2020-08-15	9	[{"id_menu":7,"count":1}]	45045	delivery	5	14
118513	2020-08-15 23:19:20	2020-08-15	17	[{"id_menu":4,"count":1}]	30555	delivery	5	22
118514	2020-08-15 23:21:01	2020-08-15	17	[{"id_menu":4,"count":1}]	12352	pick-up	0	17
118515	2020-08-15 23:24:02	2020-08-15	9	[{"id_menu":6,"count":1}]	45049	delivery	5	14
118516	2020-08-15 23:25:33	2020-08-15	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	18061	delivery	5	31
118517	2020-08-15 23:26:19	2020-08-15	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	11039	delivery	5	31
118518	2020-08-15 23:27:45	2020-08-15	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18307	delivery	5	34
118519	2020-08-15 23:30:21	2020-08-15	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	45001	delivery	5	44
118520	2020-08-15 23:32:01	2020-08-15	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	42680	delivery	5	42
118521	2020-08-15 23:32:51	2020-08-15	14	[{"id_menu":2,"count":1}]	6506	delivery	5	19
118522	2020-08-15 23:34:13	2020-08-15	8	[{"id_menu":5,"count":1}]	45004	delivery	5	13
118523	2020-08-15 23:35:10	2020-08-15	8	[{"id_menu":5,"count":1}]	45104	delivery	5	13
118524	2020-08-15 23:35:11	2020-08-15	17	[{"id_menu":4,"count":1}]	12566	delivery	5	22
118525	2020-08-15 23:39:30	2020-08-15	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	31405	delivery	5	23
118526	2020-08-15 23:40:05	2020-08-15	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	44987	delivery	5	44
118527	2020-08-15 23:40:12	2020-08-15	9	[{"id_menu":6,"count":1}]	39574	delivery	5	14
118528	2020-08-15 23:42:01	2020-08-15	41	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	8034	delivery	5	46
118529	2020-08-15 23:47:34	2020-08-15	9	[{"id_menu":7,"count":1}]	23044	delivery	5	14
118530	2020-08-15 23:48:50	2020-08-15	12	[{"id_menu":3,"count":1}]	26556	delivery	5	17
118531	2020-08-15 23:49:05	2020-08-15	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	24284	pick-up	0	22
118532	2020-08-15 23:51:27	2020-08-15	9	[{"id_menu":6,"count":1}]	14852	delivery	5	14
118533	2020-08-15 23:52:06	2020-08-15	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	45094	delivery	5	40
118534	2020-08-15 23:55:51	2020-08-15	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5180	pick-up	0	43
118535	2020-08-15 23:59:20	2020-08-15	12	[{"id_menu":3,"count":1}]	2548	pick-up	0	12
118536	2020-08-16 00:00:04	2020-08-16	9	[{"id_menu":7,"count":1}]	45296	delivery	5	14
118537	2020-08-16 00:01:40	2020-08-16	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	41946	delivery	5	40
118538	2020-08-16 00:08:42	2020-08-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	45430	delivery	5	31
118539	2020-08-16 00:08:48	2020-08-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	5496	delivery	5	28
118540	2020-08-16 00:09:57	2020-08-16	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	30697	pick-up	0	29
118541	2020-08-16 00:11:46	2020-08-16	8	[{"id_menu":5,"count":1}]	41326	delivery	5	13
118542	2020-08-16 00:14:33	2020-08-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	45322	delivery	5	23
118543	2020-08-16 00:14:54	2020-08-16	12	[{"id_menu":1,"count":2}]	10320	delivery	5	17
118544	2020-08-16 00:15:58	2020-08-16	14	[{"id_menu":2,"count":1}]	20136	pick-up	0	14
118545	2020-08-16 00:18:53	2020-08-16	12	[{"id_menu":3,"count":1}]	6003	pick-up	0	12
118546	2020-08-16 00:19:33	2020-08-16	14	[{"id_menu":2,"count":1}]	45395	delivery	5	19
118547	2020-08-16 00:20:37	2020-08-16	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6399	pick-up	0	38
118548	2020-08-16 00:20:55	2020-08-16	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39952	delivery	5	22
118549	2020-08-16 00:21:16	2020-08-16	8	[{"id_menu":5,"count":1}]	45471	delivery	5	13
118550	2020-08-16 00:22:46	2020-08-16	9	[{"id_menu":7,"count":1}]	4250	pick-up	0	9
118551	2020-08-16 00:24:01	2020-08-16	14	[{"id_menu":2,"count":1}]	33189	delivery	5	19
118552	2020-08-16 00:25:26	2020-08-16	8	[{"id_menu":5,"count":1}]	38411	delivery	5	13
118553	2020-08-16 00:25:50	2020-08-16	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	20972	delivery	5	45
118554	2020-08-16 00:25:53	2020-08-16	17	[{"id_menu":4,"count":1}]	45146	pick-up	0	17
118555	2020-08-16 00:26:16	2020-08-16	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	32810	pick-up	0	34
118556	2020-08-16 00:26:22	2020-08-16	9	[{"id_menu":6,"count":1}]	45250	delivery	5	14
118557	2020-08-16 00:27:19	2020-08-16	14	[{"id_menu":2,"count":1}]	5286	pick-up	0	14
118558	2020-08-16 00:29:38	2020-08-16	9	[{"id_menu":6,"count":1}]	12729	delivery	5	14
118559	2020-08-16 00:31:14	2020-08-16	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	33672	delivery	5	51
118560	2020-08-16 00:31:39	2020-08-16	9	[{"id_menu":7,"count":1}]	5817	delivery	5	14
118561	2020-08-16 00:33:09	2020-08-16	9	[{"id_menu":6,"count":1}]	45240	delivery	5	14
118562	2020-08-16 00:35:29	2020-08-16	9	[{"id_menu":7,"count":1}]	44621	delivery	5	14
118563	2020-08-16 00:38:15	2020-08-16	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	3106	delivery	5	36
118564	2020-08-16 00:39:27	2020-08-16	14	[{"id_menu":2,"count":1}]	8757	delivery	5	19
118565	2020-08-16 00:39:38	2020-08-16	12	[{"id_menu":1,"count":1}]	13439	delivery	5	17
118566	2020-08-16 00:39:43	2020-08-16	8	[{"id_menu":5,"count":1}]	27119	delivery	5	13
118567	2020-08-16 00:39:45	2020-08-16	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	37612	delivery	5	23
118568	2020-08-16 00:40:39	2020-08-16	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	33971	delivery	5	26
118569	2020-08-16 00:43:30	2020-08-16	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	45343	delivery	5	45
118570	2020-08-16 00:43:38	2020-08-16	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	74	delivery	5	34
118571	2020-08-16 00:43:47	2020-08-16	9	[{"id_menu":6,"count":1}]	45473	delivery	5	14
118572	2020-08-16 00:43:58	2020-08-16	9	[{"id_menu":6,"count":1}]	30070	delivery	5	14
118573	2020-08-16 00:45:32	2020-08-16	9	[{"id_menu":6,"count":1}]	45428	delivery	5	14
118574	2020-08-16 00:48:28	2020-08-16	8	[{"id_menu":5,"count":1}]	327	pick-up	0	8
118575	2020-08-16 00:48:40	2020-08-16	9	[{"id_menu":7,"count":1}]	25810	delivery	5	14
118576	2020-08-16 00:48:44	2020-08-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	15872	delivery	5	23
118577	2020-08-16 00:54:14	2020-08-16	14	[{"id_menu":2,"count":1}]	37537	delivery	5	19
118578	2020-08-16 00:56:58	2020-08-16	14	[{"id_menu":2,"count":1}]	2050	delivery	5	19
118579	2020-08-16 00:58:40	2020-08-16	9	[{"id_menu":7,"count":1}]	35797	delivery	5	14
118580	2020-08-16 01:01:09	2020-08-16	17	[{"id_menu":4,"count":1}]	27870	delivery	5	22
118581	2020-08-16 01:01:39	2020-08-16	14	[{"id_menu":2,"count":1}]	9356	pick-up	0	14
118582	2020-08-16 01:04:26	2020-08-16	8	[{"id_menu":5,"count":1}]	45347	delivery	5	13
118583	2020-08-16 01:05:13	2020-08-16	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	42000	delivery	5	23
118584	2020-08-16 01:07:03	2020-08-16	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	45291	pick-up	0	31
118585	2020-08-16 01:07:29	2020-08-16	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	19481	delivery	5	27
118586	2020-08-16 01:08:48	2020-08-16	9	[{"id_menu":7,"count":2}]	45467	pick-up	0	9
118587	2020-08-16 01:14:27	2020-08-16	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	45464	delivery	5	45
118588	2020-08-16 01:14:28	2020-08-16	17	[{"id_menu":4,"count":1}]	1627	pick-up	0	17
118589	2020-08-16 01:15:16	2020-08-16	17	[{"id_menu":4,"count":1}]	16913	pick-up	0	17
118590	2020-08-16 01:15:46	2020-08-16	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10094	delivery	5	53
118591	2020-08-16 01:19:54	2020-08-16	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15188	delivery	5	55
118592	2020-08-16 01:20:20	2020-08-16	14	[{"id_menu":2,"count":1}]	2735	pick-up	0	14
118593	2020-08-16 01:20:55	2020-08-16	17	[{"id_menu":4,"count":1}]	34196	delivery	5	22
118594	2020-08-16 01:26:09	2020-08-16	17	[{"id_menu":4,"count":1}]	932	pick-up	0	17
118595	2020-08-16 01:29:00	2020-08-16	14	[{"id_menu":2,"count":1}]	1509	pick-up	0	14
118596	2020-08-16 01:30:02	2020-08-16	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1460	delivery	5	26
118597	2020-08-16 01:30:16	2020-08-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	7395	delivery	5	23
118598	2020-08-16 01:34:26	2020-08-16	9	[{"id_menu":7,"count":1}]	17502	delivery	5	14
118599	2020-08-16 01:35:37	2020-08-16	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	45082	delivery	5	39
118600	2020-08-16 01:36:17	2020-08-16	14	[{"id_menu":2,"count":1}]	45482	pick-up	0	14
118601	2020-08-16 01:38:29	2020-08-16	9	[{"id_menu":7,"count":1}]	16498	delivery	5	14
118602	2020-08-16 01:40:26	2020-08-16	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	45447	delivery	5	38
118603	2020-08-16 01:42:20	2020-08-16	12	[{"id_menu":1,"count":1}]	16386	delivery	5	17
118604	2020-08-16 01:42:22	2020-08-16	9	[{"id_menu":6,"count":1}]	45469	delivery	5	14
118605	2020-08-16 01:42:42	2020-08-16	8	[{"id_menu":5,"count":1}]	32947	delivery	5	13
118606	2020-08-16 01:46:12	2020-08-16	9	[{"id_menu":7,"count":1}]	26617	delivery	5	14
118607	2020-08-16 01:49:06	2020-08-16	9	[{"id_menu":7,"count":1}]	16926	pick-up	0	9
118608	2020-08-16 01:49:14	2020-08-16	8	[{"id_menu":5,"count":1}]	12139	pick-up	0	8
118609	2020-08-16 01:49:22	2020-08-16	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	40476	delivery	5	25
118610	2020-08-16 01:49:41	2020-08-16	8	[{"id_menu":5,"count":1}]	6212	delivery	5	13
118611	2020-08-16 01:50:32	2020-08-16	9	[{"id_menu":7,"count":1}]	10899	delivery	5	14
118612	2020-08-16 01:55:03	2020-08-16	9	[{"id_menu":7,"count":2}]	45484	delivery	5	14
118613	2020-08-16 01:55:08	2020-08-16	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	41610	delivery	5	22
118614	2020-08-16 01:55:49	2020-08-16	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	45359	delivery	5	35
118615	2020-08-16 01:56:38	2020-08-16	29	[{"id_menu":3,"count":3},{"id_menu":4,"count":1}]	5612	delivery	5	34
118616	2020-08-16 01:56:55	2020-08-16	9	[{"id_menu":7,"count":1}]	4411	pick-up	0	9
118617	2020-08-16 01:58:34	2020-08-16	9	[{"id_menu":6,"count":1}]	45414	delivery	5	14
118618	2020-08-16 02:00:35	2020-08-16	12	[{"id_menu":3,"count":1}]	21934	delivery	5	17
118619	2020-08-16 02:02:32	2020-08-16	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4113	delivery	5	39
118620	2020-08-16 02:02:35	2020-08-16	12	[{"id_menu":1,"count":1}]	45231	delivery	5	17
118621	2020-08-16 02:06:13	2020-08-16	14	[{"id_menu":2,"count":1}]	20196	delivery	5	19
118622	2020-08-16 02:07:26	2020-08-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	45488	delivery	5	22
118623	2020-08-16 02:07:46	2020-08-16	9	[{"id_menu":6,"count":1}]	31817	delivery	5	14
118624	2020-08-16 02:08:13	2020-08-16	12	[{"id_menu":1,"count":1}]	17695	pick-up	0	12
118625	2020-08-16 02:08:37	2020-08-16	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	45324	delivery	5	57
118626	2020-08-16 02:08:44	2020-08-16	12	[{"id_menu":1,"count":1}]	40468	pick-up	0	12
118627	2020-08-16 02:09:14	2020-08-16	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	45244	delivery	5	31
118628	2020-08-16 02:10:09	2020-08-16	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	17338	delivery	5	31
118629	2020-08-16 02:12:36	2020-08-16	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	19300	pick-up	0	29
118630	2020-08-16 02:13:35	2020-08-16	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	36891	delivery	5	40
118631	2020-08-16 02:15:01	2020-08-16	17	[{"id_menu":4,"count":1}]	31509	delivery	5	22
118632	2020-08-16 02:15:02	2020-08-16	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	16839	delivery	5	30
118633	2020-08-16 02:15:42	2020-08-16	9	[{"id_menu":6,"count":1}]	3054	pick-up	0	9
118634	2020-08-16 02:15:54	2020-08-16	9	[{"id_menu":7,"count":2}]	20528	delivery	5	14
118635	2020-08-16 02:17:25	2020-08-16	17	[{"id_menu":4,"count":1}]	832	pick-up	0	17
118636	2020-08-16 02:18:40	2020-08-16	46	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	45252	delivery	5	51
118637	2020-08-16 02:20:16	2020-08-16	12	[{"id_menu":1,"count":1}]	45327	delivery	5	17
118638	2020-08-16 02:21:18	2020-08-16	14	[{"id_menu":2,"count":1}]	22845	delivery	5	19
118639	2020-08-16 02:21:30	2020-08-16	9	[{"id_menu":6,"count":1}]	30369	delivery	5	14
118640	2020-08-16 02:21:52	2020-08-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	28833	delivery	5	26
118641	2020-08-16 02:22:34	2020-08-16	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13506	delivery	5	48
118642	2020-08-16 02:24:22	2020-08-16	8	[{"id_menu":5,"count":1}]	40294	delivery	5	13
118643	2020-08-16 02:27:25	2020-08-16	9	[{"id_menu":6,"count":1}]	45444	delivery	5	14
118644	2020-08-16 02:27:43	2020-08-16	17	[{"id_menu":4,"count":1}]	45337	delivery	5	22
118645	2020-08-16 02:29:14	2020-08-16	17	[{"id_menu":4,"count":1}]	45419	delivery	5	22
118646	2020-08-16 02:29:47	2020-08-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	32881	delivery	5	31
118647	2020-08-16 02:33:35	2020-08-16	9	[{"id_menu":7,"count":1}]	8099	delivery	5	14
118648	2020-08-16 02:34:32	2020-08-16	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	8849	delivery	5	29
118649	2020-08-16 02:35:46	2020-08-16	14	[{"id_menu":2,"count":1}]	45317	delivery	5	19
118650	2020-08-16 02:36:48	2020-08-16	17	[{"id_menu":4,"count":1}]	8847	delivery	5	22
118651	2020-08-16 02:43:29	2020-08-16	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	45497	delivery	5	31
118652	2020-08-16 02:43:29	2020-08-16	17	[{"id_menu":4,"count":1}]	45442	delivery	5	22
118653	2020-08-16 02:44:00	2020-08-16	30	[{"id_menu":1,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10359	delivery	5	35
118654	2020-08-16 02:44:06	2020-08-16	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	33946	delivery	5	31
118655	2020-08-16 02:45:55	2020-08-16	17	[{"id_menu":4,"count":1}]	35582	pick-up	0	17
118656	2020-08-16 02:46:10	2020-08-16	9	[{"id_menu":7,"count":1}]	45445	delivery	5	14
118657	2020-08-16 02:46:30	2020-08-16	9	[{"id_menu":6,"count":1}]	9563	delivery	5	14
118658	2020-08-16 02:47:45	2020-08-16	14	[{"id_menu":2,"count":1}]	10284	delivery	5	19
118659	2020-08-16 02:50:59	2020-08-16	9	[{"id_menu":7,"count":1}]	15099	delivery	5	14
118660	2020-08-16 02:52:12	2020-08-16	9	[{"id_menu":6,"count":1}]	35581	delivery	5	14
118661	2020-08-16 02:52:58	2020-08-16	17	[{"id_menu":4,"count":1}]	45453	delivery	5	22
118662	2020-08-16 02:53:48	2020-08-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	33501	delivery	5	28
118663	2020-08-16 02:57:06	2020-08-16	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	25811	delivery	5	25
118664	2020-08-16 02:58:22	2020-08-16	17	[{"id_menu":4,"count":1}]	45305	delivery	5	22
118665	2020-08-16 03:00:33	2020-08-16	14	[{"id_menu":2,"count":1}]	27777	pick-up	0	14
118666	2020-08-16 03:00:40	2020-08-16	9	[{"id_menu":6,"count":1}]	37692	delivery	5	14
118667	2020-08-16 03:01:35	2020-08-16	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5016	delivery	5	45
118668	2020-08-16 03:03:03	2020-08-16	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	22699	delivery	5	22
118669	2020-08-16 03:04:01	2020-08-16	9	[{"id_menu":6,"count":1}]	16443	delivery	5	14
118670	2020-08-16 03:04:19	2020-08-16	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	287	pick-up	0	22
118671	2020-08-16 03:07:37	2020-08-16	12	[{"id_menu":3,"count":1}]	38367	pick-up	0	12
118672	2020-08-16 03:10:55	2020-08-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	45377	delivery	5	22
118673	2020-08-16 03:12:29	2020-08-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1244	pick-up	0	17
118674	2020-08-16 03:13:08	2020-08-16	9	[{"id_menu":6,"count":1}]	31269	delivery	5	14
118675	2020-08-16 03:14:03	2020-08-16	14	[{"id_menu":2,"count":1}]	10498	delivery	5	19
118676	2020-08-16 03:14:49	2020-08-16	9	[{"id_menu":6,"count":1}]	45451	delivery	5	14
118677	2020-08-16 03:15:55	2020-08-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	16465	delivery	5	28
118678	2020-08-16 03:20:21	2020-08-16	9	[{"id_menu":7,"count":1}]	12319	delivery	5	14
118679	2020-08-16 03:21:23	2020-08-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1044	pick-up	0	23
118680	2020-08-16 03:24:34	2020-08-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	9466	pick-up	0	23
118681	2020-08-16 03:27:52	2020-08-16	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	45454	delivery	5	38
118682	2020-08-16 03:29:06	2020-08-16	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3374	delivery	5	54
118683	2020-08-16 03:29:44	2020-08-16	8	[{"id_menu":5,"count":1}]	41492	delivery	5	13
118684	2020-08-16 03:30:16	2020-08-16	8	[{"id_menu":5,"count":1}]	14845	pick-up	0	8
118685	2020-08-16 03:30:38	2020-08-16	17	[{"id_menu":4,"count":1}]	26341	delivery	5	22
118686	2020-08-16 03:30:45	2020-08-16	9	[{"id_menu":6,"count":1}]	25644	delivery	5	14
118687	2020-08-16 03:31:28	2020-08-16	9	[{"id_menu":7,"count":1}]	29815	delivery	5	14
118688	2020-08-16 03:34:39	2020-08-16	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	45371	delivery	5	43
118689	2020-08-16 03:35:57	2020-08-16	9	[{"id_menu":6,"count":1}]	45427	delivery	5	14
118690	2020-08-16 03:36:55	2020-08-16	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	17268	delivery	5	26
118691	2020-08-16 03:37:03	2020-08-16	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	19093	delivery	5	25
118692	2020-08-16 03:37:14	2020-08-16	17	[{"id_menu":4,"count":1}]	3825	delivery	5	22
118693	2020-08-16 03:37:35	2020-08-16	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	9804	delivery	5	34
118694	2020-08-16 03:38:51	2020-08-16	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	5180	pick-up	0	31
118695	2020-08-16 03:39:08	2020-08-16	9	[{"id_menu":6,"count":1}]	6431	delivery	5	14
118696	2020-08-16 03:41:07	2020-08-16	9	[{"id_menu":6,"count":1}]	1736	pick-up	0	9
118697	2020-08-16 03:45:07	2020-08-16	14	[{"id_menu":2,"count":1}]	10062	pick-up	0	14
118698	2020-08-16 03:47:13	2020-08-16	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	45415	delivery	5	40
118699	2020-08-16 03:47:19	2020-08-16	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	19428	delivery	5	38
118700	2020-08-16 03:48:25	2020-08-16	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	20241	delivery	5	27
118701	2020-08-16 03:48:34	2020-08-16	9	[{"id_menu":7,"count":1}]	45362	delivery	5	14
118702	2020-08-16 03:48:53	2020-08-16	9	[{"id_menu":6,"count":1}]	31132	delivery	5	14
118703	2020-08-16 03:49:15	2020-08-16	29	[{"id_menu":3,"count":3},{"id_menu":4,"count":1}]	10008	pick-up	0	29
118704	2020-08-16 03:49:22	2020-08-16	9	[{"id_menu":6,"count":1}]	45235	delivery	5	14
118705	2020-08-16 03:51:58	2020-08-16	9	[{"id_menu":7,"count":1}]	6179	delivery	5	14
118706	2020-08-16 03:54:43	2020-08-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	17049	delivery	5	28
118707	2020-08-16 03:55:40	2020-08-16	12	[{"id_menu":1,"count":1}]	43008	delivery	5	17
118708	2020-08-16 03:57:45	2020-08-16	14	[{"id_menu":2,"count":1}]	45319	delivery	5	19
118709	2020-08-16 03:58:20	2020-08-16	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2968	pick-up	0	25
118710	2020-08-16 03:58:59	2020-08-16	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	45367	delivery	5	43
118711	2020-08-16 04:00:12	2020-08-16	8	[{"id_menu":5,"count":1}]	9014	delivery	5	13
118712	2020-08-16 04:01:44	2020-08-16	17	[{"id_menu":4,"count":1}]	23133	pick-up	0	17
118713	2020-08-16 04:02:48	2020-08-16	17	[{"id_menu":4,"count":1}]	12538	delivery	5	22
118714	2020-08-16 04:03:18	2020-08-16	17	[{"id_menu":4,"count":1}]	19610	delivery	5	22
118715	2020-08-16 04:03:38	2020-08-16	14	[{"id_menu":2,"count":1}]	33035	delivery	5	19
118716	2020-08-16 04:05:49	2020-08-16	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	2293	delivery	5	26
118717	2020-08-16 04:08:01	2020-08-16	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	41216	pick-up	0	26
118718	2020-08-16 04:11:50	2020-08-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	28928	delivery	5	31
118719	2020-08-16 04:12:22	2020-08-16	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	18576	pick-up	0	31
118720	2020-08-16 04:12:48	2020-08-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1890	pick-up	0	26
118721	2020-08-16 04:12:59	2020-08-16	9	[{"id_menu":7,"count":1}]	45312	delivery	5	14
118722	2020-08-16 04:14:17	2020-08-16	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	592	pick-up	0	29
118723	2020-08-16 04:14:28	2020-08-16	9	[{"id_menu":7,"count":1}]	45411	delivery	5	14
118724	2020-08-16 04:14:30	2020-08-16	14	[{"id_menu":2,"count":1}]	31567	delivery	5	19
118725	2020-08-16 04:15:54	2020-08-16	17	[{"id_menu":4,"count":1}]	37485	delivery	5	22
118726	2020-08-16 04:18:14	2020-08-16	9	[{"id_menu":6,"count":1}]	45248	delivery	5	14
118727	2020-08-16 04:20:15	2020-08-16	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	41010	delivery	5	38
118728	2020-08-16 04:20:17	2020-08-16	8	[{"id_menu":5,"count":1}]	42948	delivery	5	13
118729	2020-08-16 04:21:26	2020-08-16	8	[{"id_menu":5,"count":1}]	14287	delivery	5	13
118730	2020-08-16 04:22:19	2020-08-16	12	[{"id_menu":1,"count":1}]	18194	delivery	5	17
118731	2020-08-16 04:28:28	2020-08-16	8	[{"id_menu":5,"count":1}]	1012	pick-up	0	8
118732	2020-08-16 04:32:23	2020-08-16	8	[{"id_menu":5,"count":1}]	45386	delivery	5	13
118733	2020-08-16 04:32:45	2020-08-16	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	45268	delivery	5	23
118734	2020-08-16 04:35:14	2020-08-16	17	[{"id_menu":4,"count":1}]	43245	delivery	5	22
118735	2020-08-16 04:39:51	2020-08-16	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17036	delivery	5	35
118736	2020-08-16 04:40:55	2020-08-16	14	[{"id_menu":2,"count":1}]	24018	pick-up	0	14
118737	2020-08-16 04:41:38	2020-08-16	8	[{"id_menu":5,"count":1}]	45433	delivery	5	13
118738	2020-08-16 04:42:27	2020-08-16	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":2}]	45325	delivery	5	27
118739	2020-08-16 04:42:50	2020-08-16	8	[{"id_menu":5,"count":1}]	45344	delivery	5	13
118740	2020-08-16 04:45:33	2020-08-16	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	35807	delivery	5	26
118741	2020-08-16 04:45:57	2020-08-16	12	[{"id_menu":3,"count":1}]	15827	pick-up	0	12
118742	2020-08-16 04:46:18	2020-08-16	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	17594	pick-up	0	31
118743	2020-08-16 04:48:18	2020-08-16	9	[{"id_menu":6,"count":1}]	22126	delivery	5	14
118744	2020-08-16 04:49:13	2020-08-16	12	[{"id_menu":3,"count":1}]	45472	delivery	5	17
118745	2020-08-16 04:50:54	2020-08-16	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	39408	delivery	5	25
118746	2020-08-16 04:52:27	2020-08-16	9	[{"id_menu":6,"count":1}]	45286	delivery	5	14
118747	2020-08-16 04:55:02	2020-08-16	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	21	pick-up	0	20
118748	2020-08-16 04:56:06	2020-08-16	17	[{"id_menu":4,"count":1}]	29333	delivery	5	22
118749	2020-08-16 04:56:14	2020-08-16	9	[{"id_menu":7,"count":1}]	27838	delivery	5	14
118750	2020-08-16 04:58:12	2020-08-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	45408	delivery	5	28
118751	2020-08-16 04:59:49	2020-08-16	8	[{"id_menu":5,"count":1}]	45239	delivery	5	13
118752	2020-08-16 04:59:52	2020-08-16	17	[{"id_menu":4,"count":1}]	8706	pick-up	0	17
118753	2020-08-16 05:00:58	2020-08-16	12	[{"id_menu":3,"count":1}]	38200	delivery	5	17
118754	2020-08-16 05:04:11	2020-08-16	14	[{"id_menu":2,"count":1}]	28091	pick-up	0	14
118755	2020-08-16 05:05:10	2020-08-16	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	8071	pick-up	0	26
118756	2020-08-16 05:05:22	2020-08-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	45421	delivery	5	26
118757	2020-08-16 05:06:46	2020-08-16	9	[{"id_menu":6,"count":1}]	32025	delivery	5	14
118758	2020-08-16 05:06:48	2020-08-16	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	35195	delivery	5	31
118759	2020-08-16 05:06:59	2020-08-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9312	delivery	5	22
118760	2020-08-16 05:08:42	2020-08-16	12	[{"id_menu":1,"count":1}]	15576	delivery	5	17
118761	2020-08-16 05:10:28	2020-08-16	8	[{"id_menu":5,"count":1}]	29757	delivery	5	13
118762	2020-08-16 05:11:01	2020-08-16	12	[{"id_menu":1,"count":1}]	45311	delivery	5	17
118763	2020-08-16 05:12:55	2020-08-16	17	[{"id_menu":4,"count":1}]	2897	pick-up	0	17
118764	2020-08-16 05:13:33	2020-08-16	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	45234	delivery	5	40
118765	2020-08-16 05:15:11	2020-08-16	9	[{"id_menu":6,"count":1}]	18260	delivery	5	14
118766	2020-08-16 05:16:50	2020-08-16	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	21210	delivery	5	45
118767	2020-08-16 05:16:52	2020-08-16	8	[{"id_menu":5,"count":1}]	2559	delivery	5	13
118768	2020-08-16 05:17:56	2020-08-16	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	18174	delivery	5	40
118769	2020-08-16 05:18:30	2020-08-16	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	8564	delivery	5	34
118770	2020-08-16 05:18:57	2020-08-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	26004	delivery	5	31
118771	2020-08-16 05:20:22	2020-08-16	14	[{"id_menu":2,"count":1}]	5648	delivery	5	19
118772	2020-08-16 05:20:58	2020-08-16	12	[{"id_menu":3,"count":1}]	35455	delivery	5	17
118773	2020-08-16 05:21:25	2020-08-16	9	[{"id_menu":7,"count":1}]	45355	delivery	5	14
118774	2020-08-16 05:22:46	2020-08-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	45336	delivery	5	31
118775	2020-08-16 05:25:28	2020-08-16	8	[{"id_menu":5,"count":1}]	1829	delivery	5	13
118776	2020-08-16 05:27:32	2020-08-16	12	[{"id_menu":1,"count":1}]	2242	pick-up	0	12
118777	2020-08-16 05:28:55	2020-08-16	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	22850	delivery	5	40
118778	2020-08-16 05:29:01	2020-08-16	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	45309	delivery	5	39
118779	2020-08-16 05:31:00	2020-08-16	12	[{"id_menu":1,"count":1}]	5473	delivery	5	17
118780	2020-08-16 05:32:52	2020-08-16	12	[{"id_menu":1,"count":1}]	31100	delivery	5	17
118781	2020-08-16 05:33:31	2020-08-16	12	[{"id_menu":1,"count":1}]	28375	delivery	5	17
118782	2020-08-16 05:34:50	2020-08-16	9	[{"id_menu":6,"count":1}]	32054	delivery	5	14
118783	2020-08-16 05:36:25	2020-08-16	8	[{"id_menu":5,"count":1}]	30790	delivery	5	13
118784	2020-08-16 05:37:50	2020-08-16	17	[{"id_menu":4,"count":1}]	30469	pick-up	0	17
118785	2020-08-16 05:38:46	2020-08-16	14	[{"id_menu":2,"count":1}]	45251	delivery	5	19
118786	2020-08-16 05:39:11	2020-08-16	17	[{"id_menu":4,"count":2}]	22104	delivery	5	22
118787	2020-08-16 05:40:02	2020-08-16	8	[{"id_menu":5,"count":1}]	23500	pick-up	0	8
118788	2020-08-16 05:40:37	2020-08-16	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	45352	delivery	5	31
118789	2020-08-16 05:41:58	2020-08-16	9	[{"id_menu":6,"count":1}]	39411	delivery	5	14
118790	2020-08-16 05:42:13	2020-08-16	14	[{"id_menu":2,"count":1}]	45316	pick-up	0	14
118791	2020-08-16 05:43:12	2020-08-16	12	[{"id_menu":3,"count":1}]	33580	pick-up	0	12
118792	2020-08-16 05:44:36	2020-08-16	14	[{"id_menu":2,"count":1}]	17482	delivery	5	19
118793	2020-08-16 05:46:04	2020-08-16	9	[{"id_menu":6,"count":1}]	35871	delivery	5	14
118794	2020-08-16 05:46:55	2020-08-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	13980	delivery	5	23
118795	2020-08-16 05:48:01	2020-08-16	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	13291	delivery	5	40
118796	2020-08-16 05:48:03	2020-08-16	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	21345	pick-up	0	21
118797	2020-08-16 05:50:04	2020-08-16	8	[{"id_menu":5,"count":1}]	41920	pick-up	0	8
118798	2020-08-16 05:53:16	2020-08-16	14	[{"id_menu":2,"count":1}]	45491	delivery	5	19
118799	2020-08-16 05:53:29	2020-08-16	9	[{"id_menu":7,"count":2}]	18858	delivery	5	14
118800	2020-08-16 05:53:41	2020-08-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	36606	delivery	5	31
118801	2020-08-16 05:53:44	2020-08-16	12	[{"id_menu":3,"count":1}]	3285	pick-up	0	12
118802	2020-08-16 05:54:35	2020-08-16	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	45477	delivery	5	26
118803	2020-08-16 05:55:45	2020-08-16	12	[{"id_menu":1,"count":1}]	25941	delivery	5	17
118804	2020-08-16 05:57:27	2020-08-16	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37043	delivery	5	37
118805	2020-08-16 05:58:14	2020-08-16	9	[{"id_menu":6,"count":3}]	36369	delivery	5	14
118806	2020-08-16 05:59:14	2020-08-16	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	45256	delivery	5	36
118807	2020-08-16 06:01:18	2020-08-16	9	[{"id_menu":6,"count":1}]	14382	delivery	5	14
118808	2020-08-16 06:01:51	2020-08-16	9	[{"id_menu":6,"count":1}]	45302	delivery	5	14
118809	2020-08-16 06:05:22	2020-08-16	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	9627	pick-up	0	21
118810	2020-08-16 06:08:34	2020-08-16	17	[{"id_menu":4,"count":1}]	41989	delivery	5	22
118811	2020-08-16 06:09:16	2020-08-16	12	[{"id_menu":1,"count":1}]	33022	pick-up	0	12
118812	2020-08-16 06:11:00	2020-08-16	17	[{"id_menu":4,"count":1}]	1501	delivery	5	22
118813	2020-08-16 06:14:07	2020-08-16	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	45339	delivery	5	34
118814	2020-08-16 06:14:36	2020-08-16	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	12306	delivery	5	26
118815	2020-08-16 06:15:07	2020-08-16	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	13029	delivery	5	30
118816	2020-08-16 06:15:14	2020-08-16	14	[{"id_menu":2,"count":1}]	626	pick-up	0	14
118817	2020-08-16 06:15:48	2020-08-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12338	delivery	5	31
118818	2020-08-16 06:16:29	2020-08-16	9	[{"id_menu":7,"count":1}]	45438	delivery	5	14
118819	2020-08-16 06:18:05	2020-08-16	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	45455	delivery	5	26
118820	2020-08-16 06:18:26	2020-08-16	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	42241	delivery	5	30
118821	2020-08-16 06:19:54	2020-08-16	9	[{"id_menu":6,"count":1}]	4079	delivery	5	14
118822	2020-08-16 06:21:43	2020-08-16	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	31997	pick-up	0	20
118823	2020-08-16 06:22:15	2020-08-16	14	[{"id_menu":2,"count":1}]	33550	delivery	5	19
118824	2020-08-16 06:25:43	2020-08-16	9	[{"id_menu":7,"count":1}]	8640	delivery	5	14
118825	2020-08-16 06:25:48	2020-08-16	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19479	delivery	5	39
118826	2020-08-16 06:26:46	2020-08-16	8	[{"id_menu":5,"count":1}]	21196	delivery	5	13
118827	2020-08-16 06:26:52	2020-08-16	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	27660	delivery	5	36
118828	2020-08-16 06:28:59	2020-08-16	14	[{"id_menu":2,"count":1}]	21761	delivery	5	19
118829	2020-08-16 06:29:43	2020-08-16	9	[{"id_menu":6,"count":1}]	38374	delivery	5	14
118830	2020-08-16 06:31:18	2020-08-16	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5201	pick-up	0	25
118831	2020-08-16 06:33:17	2020-08-16	9	[{"id_menu":6,"count":1}]	22014	delivery	5	14
118832	2020-08-16 06:37:04	2020-08-16	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	44984	delivery	5	26
118833	2020-08-16 06:41:50	2020-08-16	12	[{"id_menu":3,"count":1}]	37110	delivery	5	17
118834	2020-08-16 06:41:51	2020-08-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16562	delivery	5	22
118835	2020-08-16 06:43:58	2020-08-16	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	45370	delivery	5	22
118836	2020-08-16 06:44:03	2020-08-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10254	delivery	5	23
118837	2020-08-16 06:44:48	2020-08-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4205	delivery	5	28
118838	2020-08-16 06:45:51	2020-08-16	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	21020	pick-up	0	20
118839	2020-08-16 06:47:05	2020-08-16	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	43353	delivery	5	39
118840	2020-08-16 06:51:46	2020-08-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	31137	delivery	5	28
118841	2020-08-16 06:57:33	2020-08-16	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	42117	delivery	5	22
118842	2020-08-16 07:00:16	2020-08-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	26292	delivery	5	28
118843	2020-08-16 07:00:48	2020-08-16	14	[{"id_menu":2,"count":1}]	45259	delivery	5	19
118844	2020-08-16 07:01:50	2020-08-16	14	[{"id_menu":2,"count":1}]	45483	delivery	5	19
118845	2020-08-16 07:10:47	2020-08-16	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	42919	delivery	5	35
118846	2020-08-16 07:12:49	2020-08-16	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	10333	delivery	5	26
118847	2020-08-16 07:13:43	2020-08-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	14433	delivery	5	28
118848	2020-08-16 07:14:41	2020-08-16	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7156	pick-up	0	43
118849	2020-08-16 07:15:23	2020-08-16	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	45326	delivery	5	49
118850	2020-08-16 07:16:39	2020-08-16	14	[{"id_menu":2,"count":1}]	4414	delivery	5	19
118851	2020-08-16 07:16:53	2020-08-16	8	[{"id_menu":5,"count":1}]	45285	delivery	5	13
118852	2020-08-16 07:18:25	2020-08-16	14	[{"id_menu":2,"count":1}]	19688	delivery	5	19
118853	2020-08-16 07:19:17	2020-08-16	9	[{"id_menu":6,"count":1}]	45218	delivery	5	14
118854	2020-08-16 07:19:42	2020-08-16	17	[{"id_menu":4,"count":1}]	4073	delivery	5	22
118855	2020-08-16 07:19:59	2020-08-16	14	[{"id_menu":2,"count":1}]	5461	pick-up	0	14
118856	2020-08-16 07:20:02	2020-08-16	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	45390	delivery	5	25
118857	2020-08-16 07:20:12	2020-08-16	9	[{"id_menu":7,"count":2}]	45396	delivery	5	14
118858	2020-08-16 07:25:44	2020-08-16	17	[{"id_menu":4,"count":1}]	41990	pick-up	0	17
118859	2020-08-16 07:27:43	2020-08-16	8	[{"id_menu":5,"count":1}]	25346	pick-up	0	8
118860	2020-08-16 07:29:49	2020-08-16	9	[{"id_menu":6,"count":1}]	37597	delivery	5	14
118861	2020-08-16 07:30:43	2020-08-16	17	[{"id_menu":4,"count":1}]	39673	pick-up	0	17
118862	2020-08-16 07:32:50	2020-08-16	9	[{"id_menu":6,"count":1}]	41428	delivery	5	14
118863	2020-08-16 07:33:10	2020-08-16	9	[{"id_menu":7,"count":1}]	3146	pick-up	0	9
118864	2020-08-16 07:35:43	2020-08-16	8	[{"id_menu":5,"count":1}]	45219	pick-up	0	8
118865	2020-08-16 07:36:17	2020-08-16	12	[{"id_menu":3,"count":1}]	36591	delivery	5	17
118866	2020-08-16 07:36:50	2020-08-16	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1948	delivery	5	39
118867	2020-08-16 07:37:11	2020-08-16	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	20380	delivery	5	36
118868	2020-08-16 07:39:19	2020-08-16	8	[{"id_menu":5,"count":1}]	45429	delivery	5	13
118869	2020-08-16 07:40:43	2020-08-16	9	[{"id_menu":7,"count":1}]	32093	delivery	5	14
118870	2020-08-16 07:40:51	2020-08-16	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	24089	delivery	5	25
118871	2020-08-16 07:41:03	2020-08-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4831	delivery	5	23
118872	2020-08-16 07:42:59	2020-08-16	17	[{"id_menu":4,"count":1}]	2762	delivery	5	22
118873	2020-08-16 07:46:19	2020-08-16	9	[{"id_menu":7,"count":1}]	6173	pick-up	0	9
118874	2020-08-16 07:47:43	2020-08-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11610	delivery	5	31
118875	2020-08-16 07:51:25	2020-08-16	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	29329	delivery	5	36
118876	2020-08-16 07:51:35	2020-08-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	24676	delivery	5	26
118877	2020-08-16 07:52:43	2020-08-16	12	[{"id_menu":1,"count":1}]	45164	delivery	5	17
118878	2020-08-16 07:56:04	2020-08-16	9	[{"id_menu":7,"count":1}]	19339	delivery	5	14
118879	2020-08-16 07:56:55	2020-08-16	9	[{"id_menu":7,"count":1}]	44348	delivery	5	14
118880	2020-08-16 07:58:48	2020-08-16	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	772	pick-up	0	29
118881	2020-08-16 07:59:56	2020-08-16	9	[{"id_menu":6,"count":1}]	45382	delivery	5	14
118882	2020-08-16 08:00:48	2020-08-16	9	[{"id_menu":6,"count":1}]	45431	delivery	5	14
118883	2020-08-16 08:02:03	2020-08-16	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	45272	delivery	5	36
118884	2020-08-16 08:04:01	2020-08-16	17	[{"id_menu":4,"count":1}]	372	pick-up	0	17
118885	2020-08-16 08:04:15	2020-08-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	10993	delivery	5	31
118886	2020-08-16 08:07:42	2020-08-16	14	[{"id_menu":2,"count":1}]	45284	pick-up	0	14
118887	2020-08-16 08:08:44	2020-08-16	17	[{"id_menu":4,"count":1}]	8813	delivery	5	22
118888	2020-08-16 08:09:29	2020-08-16	17	[{"id_menu":4,"count":1}]	27185	delivery	5	22
118889	2020-08-16 08:11:27	2020-08-16	8	[{"id_menu":5,"count":1}]	32923	delivery	5	13
118890	2020-08-16 08:12:07	2020-08-16	14	[{"id_menu":2,"count":1}]	14110	delivery	5	19
118891	2020-08-16 08:14:26	2020-08-16	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2959	pick-up	0	20
118892	2020-08-16 08:14:35	2020-08-16	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	16481	pick-up	0	20
118893	2020-08-16 08:16:19	2020-08-16	8	[{"id_menu":5,"count":1}]	30377	delivery	5	13
118894	2020-08-16 08:17:09	2020-08-16	8	[{"id_menu":5,"count":1}]	21850	delivery	5	13
118895	2020-08-16 08:18:09	2020-08-16	12	[{"id_menu":1,"count":1}]	32838	pick-up	0	12
118896	2020-08-16 08:19:17	2020-08-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43407	delivery	5	23
118897	2020-08-16 08:21:04	2020-08-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26407	delivery	5	23
118898	2020-08-16 08:21:54	2020-08-16	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	45418	delivery	5	40
118899	2020-08-16 08:23:37	2020-08-16	14	[{"id_menu":2,"count":1}]	45249	delivery	5	19
118900	2020-08-16 08:24:37	2020-08-16	14	[{"id_menu":2,"count":1}]	32084	delivery	5	19
118901	2020-08-16 08:24:39	2020-08-16	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	14921	pick-up	0	51
118902	2020-08-16 08:26:24	2020-08-16	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	45364	delivery	5	29
118903	2020-08-16 08:26:33	2020-08-16	8	[{"id_menu":5,"count":1}]	45246	delivery	5	13
118904	2020-08-16 08:31:55	2020-08-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7670	delivery	5	31
118905	2020-08-16 08:33:26	2020-08-16	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7917	delivery	5	40
118906	2020-08-16 08:35:58	2020-08-16	14	[{"id_menu":2,"count":1}]	45399	delivery	5	19
118907	2020-08-16 08:36:46	2020-08-16	9	[{"id_menu":6,"count":1}]	45468	delivery	5	14
118908	2020-08-16 08:37:32	2020-08-16	8	[{"id_menu":5,"count":1}]	45254	delivery	5	13
118909	2020-08-16 08:39:47	2020-08-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	13918	delivery	5	31
118910	2020-08-16 08:42:14	2020-08-16	9	[{"id_menu":6,"count":1}]	31850	delivery	5	14
118911	2020-08-16 08:43:53	2020-08-16	9	[{"id_menu":7,"count":1}]	20492	delivery	5	14
118912	2020-08-16 08:44:54	2020-08-16	9	[{"id_menu":7,"count":1}]	17393	delivery	5	14
118913	2020-08-16 08:45:06	2020-08-16	8	[{"id_menu":5,"count":1}]	15560	delivery	5	13
118914	2020-08-16 08:45:35	2020-08-16	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	31620	pick-up	0	34
118915	2020-08-16 08:46:26	2020-08-16	17	[{"id_menu":4,"count":1}]	11287	pick-up	0	17
118916	2020-08-16 08:48:54	2020-08-16	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2809	pick-up	0	52
118917	2020-08-16 08:50:26	2020-08-16	12	[{"id_menu":1,"count":1}]	45226	delivery	5	17
118918	2020-08-16 08:52:03	2020-08-16	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	31346	delivery	5	38
118919	2020-08-16 08:52:27	2020-08-16	17	[{"id_menu":4,"count":1}]	44154	delivery	5	22
118920	2020-08-16 08:53:15	2020-08-16	8	[{"id_menu":5,"count":1}]	32633	delivery	5	13
118921	2020-08-16 08:54:26	2020-08-16	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	19753	delivery	5	31
118922	2020-08-16 08:55:31	2020-08-16	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3247	delivery	5	34
118923	2020-08-16 08:55:52	2020-08-16	8	[{"id_menu":5,"count":1}]	45409	delivery	5	13
118924	2020-08-16 08:56:09	2020-08-16	9	[{"id_menu":7,"count":1}]	22755	delivery	5	14
118925	2020-08-16 08:56:12	2020-08-16	8	[{"id_menu":5,"count":1}]	19327	delivery	5	13
118926	2020-08-16 08:57:18	2020-08-16	12	[{"id_menu":1,"count":1}]	45334	delivery	5	17
118927	2020-08-16 08:57:24	2020-08-16	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	19135	delivery	5	45
118928	2020-08-16 08:58:18	2020-08-16	9	[{"id_menu":6,"count":1}]	45368	delivery	5	14
118929	2020-08-16 08:59:49	2020-08-16	14	[{"id_menu":2,"count":1}]	39103	pick-up	0	14
118930	2020-08-16 09:00:12	2020-08-16	8	[{"id_menu":5,"count":1}]	7069	pick-up	0	8
118931	2020-08-16 09:00:44	2020-08-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	42292	delivery	5	22
118932	2020-08-16 09:01:38	2020-08-16	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	39537	delivery	5	36
118933	2020-08-16 09:03:07	2020-08-16	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	44731	delivery	5	22
118934	2020-08-16 09:04:16	2020-08-16	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	31183	delivery	5	23
118935	2020-08-16 09:05:32	2020-08-16	12	[{"id_menu":1,"count":1}]	45413	delivery	5	17
118936	2020-08-16 09:05:58	2020-08-16	9	[{"id_menu":7,"count":1}]	4368	pick-up	0	9
118937	2020-08-16 09:07:47	2020-08-16	17	[{"id_menu":4,"count":1}]	24070	delivery	5	22
118938	2020-08-16 09:08:05	2020-08-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	45496	delivery	5	28
118939	2020-08-16 09:09:40	2020-08-16	17	[{"id_menu":4,"count":1}]	39317	pick-up	0	17
118940	2020-08-16 09:10:53	2020-08-16	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	17086	delivery	5	22
118941	2020-08-16 09:11:58	2020-08-16	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	45221	pick-up	0	30
118942	2020-08-16 09:12:33	2020-08-16	12	[{"id_menu":3,"count":1}]	4634	pick-up	0	12
118943	2020-08-16 09:14:29	2020-08-16	9	[{"id_menu":7,"count":1}]	44526	delivery	5	14
118944	2020-08-16 09:14:54	2020-08-16	8	[{"id_menu":5,"count":1}]	2472	delivery	5	13
118945	2020-08-16 09:15:20	2020-08-16	8	[{"id_menu":5,"count":1}]	45294	delivery	5	13
118946	2020-08-16 09:16:06	2020-08-16	14	[{"id_menu":2,"count":1}]	45253	delivery	5	19
118947	2020-08-16 09:19:22	2020-08-16	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	735	pick-up	0	25
118948	2020-08-16 09:20:08	2020-08-16	12	[{"id_menu":3,"count":1}]	9402	delivery	5	17
118949	2020-08-16 09:21:13	2020-08-16	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	993	pick-up	0	21
118950	2020-08-16 09:25:42	2020-08-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	36161	delivery	5	26
118951	2020-08-16 09:26:11	2020-08-16	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	26783	delivery	5	44
118952	2020-08-16 09:28:56	2020-08-16	17	[{"id_menu":4,"count":1}]	26686	delivery	5	22
118953	2020-08-16 09:29:38	2020-08-16	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	41560	delivery	5	39
118954	2020-08-16 09:30:57	2020-08-16	8	[{"id_menu":5,"count":1}]	43583	delivery	5	13
118955	2020-08-16 09:34:13	2020-08-16	9	[{"id_menu":6,"count":1}]	37608	delivery	5	14
118956	2020-08-16 09:35:06	2020-08-16	17	[{"id_menu":4,"count":1}]	33305	delivery	5	22
118957	2020-08-16 09:35:16	2020-08-16	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	28819	delivery	5	26
118958	2020-08-16 09:36:02	2020-08-16	9	[{"id_menu":7,"count":1}]	42577	pick-up	0	9
118959	2020-08-16 09:38:02	2020-08-16	8	[{"id_menu":5,"count":1}]	45273	delivery	5	13
118960	2020-08-16 09:38:31	2020-08-16	8	[{"id_menu":5,"count":1}]	2799	pick-up	0	8
118961	2020-08-16 09:38:48	2020-08-16	9	[{"id_menu":7,"count":1}]	13289	pick-up	0	9
118962	2020-08-16 09:39:25	2020-08-16	14	[{"id_menu":2,"count":1}]	9991	delivery	5	19
118963	2020-08-16 09:41:04	2020-08-16	12	[{"id_menu":3,"count":2}]	2153	pick-up	0	12
118964	2020-08-16 09:43:19	2020-08-16	9	[{"id_menu":6,"count":1}]	45255	delivery	5	14
118965	2020-08-16 09:44:54	2020-08-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7898	pick-up	0	26
118966	2020-08-16 09:45:44	2020-08-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	40443	delivery	5	26
118967	2020-08-16 09:47:35	2020-08-16	9	[{"id_menu":7,"count":1}]	45406	pick-up	0	9
118968	2020-08-16 09:49:36	2020-08-16	17	[{"id_menu":4,"count":1}]	15798	pick-up	0	17
118969	2020-08-16 09:50:57	2020-08-16	9	[{"id_menu":7,"count":1}]	1525	pick-up	0	9
118970	2020-08-16 09:52:36	2020-08-16	14	[{"id_menu":2,"count":1}]	27723	delivery	5	19
118971	2020-08-16 09:54:04	2020-08-16	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	29204	delivery	5	22
118972	2020-08-16 09:55:18	2020-08-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16720	delivery	5	22
118973	2020-08-16 10:01:01	2020-08-16	8	[{"id_menu":5,"count":1}]	1818	delivery	5	13
118974	2020-08-16 10:02:07	2020-08-16	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	45276	delivery	5	35
118975	2020-08-16 10:02:26	2020-08-16	8	[{"id_menu":5,"count":1}]	8984	delivery	5	13
118976	2020-08-16 10:02:31	2020-08-16	17	[{"id_menu":4,"count":1}]	9003	delivery	5	22
118977	2020-08-16 10:06:55	2020-08-16	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	25313	delivery	5	22
118978	2020-08-16 10:07:20	2020-08-16	9	[{"id_menu":6,"count":1}]	2641	pick-up	0	9
118979	2020-08-16 10:08:17	2020-08-16	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	45264	delivery	5	34
118980	2020-08-16 10:09:41	2020-08-16	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	32767	delivery	5	43
118981	2020-08-16 10:09:49	2020-08-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	40960	delivery	5	31
118982	2020-08-16 10:11:08	2020-08-16	14	[{"id_menu":2,"count":1}]	4164	pick-up	0	14
118983	2020-08-16 10:16:55	2020-08-16	9	[{"id_menu":7,"count":1}]	25835	delivery	5	14
118984	2020-08-16 10:18:06	2020-08-16	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	24922	delivery	5	44
118985	2020-08-16 10:21:39	2020-08-16	9	[{"id_menu":7,"count":1}]	5886	delivery	5	14
118986	2020-08-16 10:22:06	2020-08-16	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	37326	delivery	5	36
118987	2020-08-16 10:23:39	2020-08-16	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5644	delivery	5	35
118988	2020-08-16 10:24:20	2020-08-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	21322	pick-up	0	26
118989	2020-08-16 10:24:46	2020-08-16	9	[{"id_menu":6,"count":1}]	39064	pick-up	0	9
118990	2020-08-16 10:25:53	2020-08-16	12	[{"id_menu":1,"count":1}]	26271	delivery	5	17
118991	2020-08-16 10:26:22	2020-08-16	9	[{"id_menu":7,"count":1}]	36098	delivery	5	14
118992	2020-08-16 10:26:48	2020-08-16	12	[{"id_menu":1,"count":1}]	45486	delivery	5	17
118993	2020-08-16 10:27:51	2020-08-16	9	[{"id_menu":7,"count":1}]	44127	pick-up	0	9
118994	2020-08-16 10:28:37	2020-08-16	12	[{"id_menu":1,"count":1}]	45340	delivery	5	17
118995	2020-08-16 10:29:09	2020-08-16	9	[{"id_menu":6,"count":1}]	10442	delivery	5	14
118996	2020-08-16 10:32:12	2020-08-16	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	45247	delivery	5	48
118997	2020-08-16 10:34:43	2020-08-16	14	[{"id_menu":2,"count":1}]	18702	delivery	5	19
118998	2020-08-16 10:35:01	2020-08-16	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	45348	delivery	5	22
118999	2020-08-16 10:35:45	2020-08-16	12	[{"id_menu":1,"count":1}]	45410	delivery	5	17
119000	2020-08-16 10:36:25	2020-08-16	14	[{"id_menu":2,"count":1}]	27685	pick-up	0	14
119001	2020-08-16 10:37:11	2020-08-16	12	[{"id_menu":3,"count":1}]	34644	delivery	5	17
119002	2020-08-16 10:37:52	2020-08-16	12	[{"id_menu":1,"count":1}]	2659	delivery	5	17
119003	2020-08-16 10:39:49	2020-08-16	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	44711	delivery	5	39
119004	2020-08-16 10:41:54	2020-08-16	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	45481	delivery	5	46
119005	2020-08-16 10:42:46	2020-08-16	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	35438	delivery	5	37
119006	2020-08-16 10:43:09	2020-08-16	9	[{"id_menu":7,"count":1}]	14666	pick-up	0	9
119007	2020-08-16 10:43:11	2020-08-16	9	[{"id_menu":7,"count":1}]	11956	delivery	5	14
119008	2020-08-16 10:43:19	2020-08-16	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6489	pick-up	0	31
119009	2020-08-16 10:44:25	2020-08-16	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	37941	delivery	5	43
119010	2020-08-16 10:44:28	2020-08-16	17	[{"id_menu":4,"count":1}]	16343	delivery	5	22
119011	2020-08-16 10:46:19	2020-08-16	12	[{"id_menu":1,"count":1}]	31013	delivery	5	17
119012	2020-08-16 10:46:39	2020-08-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	22688	delivery	5	31
119013	2020-08-16 10:48:03	2020-08-16	9	[{"id_menu":7,"count":1}]	25777	delivery	5	14
119014	2020-08-16 10:49:40	2020-08-16	9	[{"id_menu":6,"count":2}]	45423	pick-up	0	9
119015	2020-08-16 10:49:41	2020-08-16	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	16626	delivery	5	36
119016	2020-08-16 10:50:37	2020-08-16	12	[{"id_menu":3,"count":1}]	1183	pick-up	0	12
119017	2020-08-16 10:53:18	2020-08-16	12	[{"id_menu":1,"count":1}]	10717	pick-up	0	12
119018	2020-08-16 10:53:22	2020-08-16	12	[{"id_menu":3,"count":1}]	3581	pick-up	0	12
119019	2020-08-16 10:53:39	2020-08-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6916	pick-up	0	17
119020	2020-08-16 10:55:18	2020-08-16	8	[{"id_menu":5,"count":1}]	11896	pick-up	0	8
119021	2020-08-16 10:56:10	2020-08-16	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	45397	delivery	5	36
119022	2020-08-16 10:57:41	2020-08-16	9	[{"id_menu":6,"count":1}]	45452	delivery	5	14
119023	2020-08-16 10:58:25	2020-08-16	12	[{"id_menu":1,"count":1}]	11146	delivery	5	17
119024	2020-08-16 11:00:35	2020-08-16	8	[{"id_menu":5,"count":1}]	11465	pick-up	0	8
119025	2020-08-16 11:00:41	2020-08-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	45333	delivery	5	31
119026	2020-08-16 11:00:48	2020-08-16	14	[{"id_menu":2,"count":1}]	4287	delivery	5	19
119027	2020-08-16 11:02:16	2020-08-16	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	45320	delivery	5	34
119028	2020-08-16 11:04:01	2020-08-16	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	754	pick-up	0	29
119029	2020-08-16 11:04:29	2020-08-16	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	45422	delivery	5	42
119030	2020-08-16 11:04:39	2020-08-16	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	45323	delivery	5	30
119031	2020-08-16 11:07:13	2020-08-16	12	[{"id_menu":3,"count":1}]	45280	delivery	5	17
119032	2020-08-16 11:09:27	2020-08-16	9	[{"id_menu":6,"count":1}]	40812	delivery	5	14
119033	2020-08-16 11:09:52	2020-08-16	14	[{"id_menu":2,"count":1}]	21105	delivery	5	19
119034	2020-08-16 11:10:35	2020-08-16	9	[{"id_menu":6,"count":1}]	21060	delivery	5	14
119035	2020-08-16 11:10:55	2020-08-16	17	[{"id_menu":4,"count":1}]	10536	delivery	5	22
119036	2020-08-16 11:11:52	2020-08-16	9	[{"id_menu":7,"count":1}]	45426	delivery	5	14
119037	2020-08-16 11:12:00	2020-08-16	9	[{"id_menu":6,"count":1}]	14133	pick-up	0	9
119038	2020-08-16 11:13:09	2020-08-16	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14465	delivery	5	22
119039	2020-08-16 11:14:56	2020-08-16	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	45420	delivery	5	45
119040	2020-08-16 11:17:30	2020-08-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	45434	delivery	5	22
119041	2020-08-16 11:18:39	2020-08-16	9	[{"id_menu":7,"count":1}]	9531	delivery	5	14
119042	2020-08-16 11:18:46	2020-08-16	8	[{"id_menu":5,"count":1}]	45313	delivery	5	13
119043	2020-08-16 11:19:17	2020-08-16	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	19760	delivery	5	42
119044	2020-08-16 11:21:42	2020-08-16	9	[{"id_menu":6,"count":1}]	45331	delivery	5	14
119045	2020-08-16 11:22:11	2020-08-16	9	[{"id_menu":7,"count":1}]	39558	delivery	5	14
119046	2020-08-16 11:23:55	2020-08-16	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	45392	delivery	5	34
119047	2020-08-16 11:24:16	2020-08-16	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	45303	delivery	5	37
119048	2020-08-16 11:25:02	2020-08-16	17	[{"id_menu":4,"count":1}]	45402	delivery	5	22
119049	2020-08-16 11:25:04	2020-08-16	17	[{"id_menu":4,"count":1}]	45387	delivery	5	22
119050	2020-08-16 11:25:35	2020-08-16	17	[{"id_menu":4,"count":1}]	35685	delivery	5	22
119051	2020-08-16 11:30:14	2020-08-16	12	[{"id_menu":1,"count":2}]	31756	pick-up	0	12
119052	2020-08-16 11:30:43	2020-08-16	12	[{"id_menu":1,"count":1}]	2176	pick-up	0	12
119053	2020-08-16 11:32:01	2020-08-16	9	[{"id_menu":6,"count":1}]	42568	delivery	5	14
119054	2020-08-16 11:32:20	2020-08-16	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	45398	delivery	5	26
119055	2020-08-16 11:32:58	2020-08-16	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38860	delivery	5	52
119056	2020-08-16 11:36:22	2020-08-16	12	[{"id_menu":1,"count":1}]	32846	pick-up	0	12
119057	2020-08-16 11:39:02	2020-08-16	12	[{"id_menu":3,"count":1}]	3507	pick-up	0	12
119058	2020-08-16 11:39:45	2020-08-16	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38055	delivery	5	31
119059	2020-08-16 11:41:42	2020-08-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	817	pick-up	0	26
119060	2020-08-16 11:41:45	2020-08-16	17	[{"id_menu":4,"count":1}]	45242	delivery	5	22
119061	2020-08-16 11:41:46	2020-08-16	9	[{"id_menu":6,"count":1}]	7741	pick-up	0	9
119062	2020-08-16 11:46:29	2020-08-16	9	[{"id_menu":7,"count":1}]	42154	delivery	5	14
119063	2020-08-16 11:47:22	2020-08-16	12	[{"id_menu":1,"count":2}]	13897	delivery	5	17
119064	2020-08-16 11:47:25	2020-08-16	9	[{"id_menu":6,"count":1}]	34330	delivery	5	14
119065	2020-08-16 11:53:39	2020-08-16	9	[{"id_menu":7,"count":2}]	4893	delivery	5	14
119066	2020-08-16 11:55:16	2020-08-16	8	[{"id_menu":5,"count":1}]	45357	delivery	5	13
119067	2020-08-16 11:58:33	2020-08-16	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	4434	delivery	5	22
119068	2020-08-16 11:59:22	2020-08-16	9	[{"id_menu":6,"count":1}]	32010	delivery	5	14
119069	2020-08-16 11:59:37	2020-08-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10404	delivery	5	22
119070	2020-08-16 12:00:28	2020-08-16	9	[{"id_menu":6,"count":1}]	13487	delivery	5	14
119071	2020-08-16 12:04:50	2020-08-16	14	[{"id_menu":2,"count":1}]	41900	delivery	5	19
119072	2020-08-16 12:07:53	2020-08-16	8	[{"id_menu":5,"count":1}]	14661	pick-up	0	8
119073	2020-08-16 12:08:47	2020-08-16	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4380	delivery	5	39
119074	2020-08-16 12:08:54	2020-08-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	45425	delivery	5	23
119075	2020-08-16 12:09:28	2020-08-16	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	16680	delivery	5	30
119076	2020-08-16 12:11:40	2020-08-16	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	40727	delivery	5	38
119077	2020-08-16 12:11:44	2020-08-16	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	29339	delivery	5	27
119078	2020-08-16 12:13:51	2020-08-16	14	[{"id_menu":2,"count":1}]	9621	delivery	5	19
119079	2020-08-16 12:14:07	2020-08-16	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	40265	delivery	5	40
119080	2020-08-16 12:14:53	2020-08-16	12	[{"id_menu":3,"count":1}]	21273	pick-up	0	12
119081	2020-08-16 12:16:32	2020-08-16	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	6396	pick-up	0	26
119082	2020-08-16 12:18:46	2020-08-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43798	delivery	5	23
119083	2020-08-16 12:19:13	2020-08-16	9	[{"id_menu":7,"count":1}]	3081	pick-up	0	9
119084	2020-08-16 12:21:38	2020-08-16	14	[{"id_menu":2,"count":1}]	45310	pick-up	0	14
119085	2020-08-16 12:22:14	2020-08-16	9	[{"id_menu":6,"count":1}]	7067	delivery	5	14
119086	2020-08-16 12:24:42	2020-08-16	12	[{"id_menu":3,"count":1}]	2320	pick-up	0	12
119087	2020-08-16 12:25:18	2020-08-16	9	[{"id_menu":6,"count":1}]	45245	delivery	5	14
119088	2020-08-16 12:26:14	2020-08-16	9	[{"id_menu":6,"count":2}]	45289	delivery	5	14
119089	2020-08-16 12:26:32	2020-08-16	9	[{"id_menu":6,"count":1}]	25703	delivery	5	14
119090	2020-08-16 12:27:30	2020-08-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	45374	delivery	5	23
119091	2020-08-16 12:28:10	2020-08-16	12	[{"id_menu":3,"count":1}]	45476	delivery	5	17
119092	2020-08-16 12:28:52	2020-08-16	8	[{"id_menu":5,"count":1}]	4020	pick-up	0	8
119093	2020-08-16 12:29:25	2020-08-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	39421	delivery	5	28
119094	2020-08-16 12:30:18	2020-08-16	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5478	pick-up	0	39
119095	2020-08-16 12:31:56	2020-08-16	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	45360	delivery	5	36
119096	2020-08-16 12:32:07	2020-08-16	9	[{"id_menu":6,"count":1}]	6058	delivery	5	14
119097	2020-08-16 12:34:10	2020-08-16	12	[{"id_menu":3,"count":1}]	28202	delivery	5	17
119098	2020-08-16 12:34:37	2020-08-16	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	43702	delivery	5	39
119099	2020-08-16 12:37:46	2020-08-16	9	[{"id_menu":7,"count":1}]	45384	delivery	5	14
119100	2020-08-16 12:38:12	2020-08-16	9	[{"id_menu":7,"count":1}]	1994	pick-up	0	9
119101	2020-08-16 12:41:11	2020-08-16	17	[{"id_menu":4,"count":1}]	8547	delivery	5	22
119102	2020-08-16 12:42:22	2020-08-16	12	[{"id_menu":3,"count":2}]	8145	pick-up	0	12
119103	2020-08-16 12:43:24	2020-08-16	8	[{"id_menu":5,"count":1}]	34710	pick-up	0	8
119104	2020-08-16 12:43:28	2020-08-16	14	[{"id_menu":2,"count":1}]	45366	pick-up	0	14
119105	2020-08-16 12:43:28	2020-08-16	9	[{"id_menu":7,"count":1}]	31847	delivery	5	14
119106	2020-08-16 12:43:35	2020-08-16	9	[{"id_menu":7,"count":1}]	45277	delivery	5	14
119107	2020-08-16 12:44:28	2020-08-16	8	[{"id_menu":5,"count":1}]	3540	delivery	5	13
119108	2020-08-16 12:47:44	2020-08-16	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	38219	delivery	5	40
119109	2020-08-16 12:50:11	2020-08-16	17	[{"id_menu":4,"count":1}]	45233	delivery	5	22
119110	2020-08-16 12:51:10	2020-08-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	36476	delivery	5	28
119111	2020-08-16 12:51:16	2020-08-16	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	3456	delivery	5	45
119112	2020-08-16 12:51:37	2020-08-16	9	[{"id_menu":7,"count":1}]	16783	delivery	5	14
119113	2020-08-16 12:52:06	2020-08-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	45282	delivery	5	31
119114	2020-08-16 12:52:45	2020-08-16	12	[{"id_menu":1,"count":1}]	19119	delivery	5	17
119115	2020-08-16 12:56:19	2020-08-16	12	[{"id_menu":3,"count":1}]	27822	delivery	5	17
119116	2020-08-16 12:57:30	2020-08-16	9	[{"id_menu":7,"count":1}]	41	delivery	5	14
119117	2020-08-16 12:59:07	2020-08-16	9	[{"id_menu":6,"count":1}]	32393	delivery	5	14
119118	2020-08-16 12:59:33	2020-08-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7673	delivery	5	31
119119	2020-08-16 12:59:36	2020-08-16	9	[{"id_menu":7,"count":1}]	24261	delivery	5	14
119120	2020-08-16 12:59:44	2020-08-16	14	[{"id_menu":2,"count":1}]	34999	pick-up	0	14
119121	2020-08-16 13:01:55	2020-08-16	8	[{"id_menu":5,"count":1}]	40619	delivery	5	13
119122	2020-08-16 13:02:10	2020-08-16	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	29151	delivery	5	52
119123	2020-08-16 13:02:29	2020-08-16	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	45459	delivery	5	31
119124	2020-08-16 13:02:48	2020-08-16	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	482	delivery	5	39
119125	2020-08-16 13:03:50	2020-08-16	9	[{"id_menu":7,"count":1}]	8520	delivery	5	14
119126	2020-08-16 13:05:38	2020-08-16	12	[{"id_menu":3,"count":1}]	22116	pick-up	0	12
119127	2020-08-16 13:06:38	2020-08-16	17	[{"id_menu":4,"count":1}]	972	delivery	5	22
119128	2020-08-16 13:07:03	2020-08-16	14	[{"id_menu":2,"count":1}]	10890	pick-up	0	14
119129	2020-08-16 13:08:40	2020-08-16	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32723	delivery	5	39
119130	2020-08-16 13:10:53	2020-08-16	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	21973	delivery	5	37
119131	2020-08-16 13:12:01	2020-08-16	8	[{"id_menu":5,"count":1}]	37550	pick-up	0	8
119132	2020-08-16 13:12:12	2020-08-16	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4737	delivery	5	43
119133	2020-08-16 13:12:17	2020-08-16	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17212	delivery	5	43
119134	2020-08-16 13:17:39	2020-08-16	9	[{"id_menu":7,"count":1}]	45304	delivery	5	14
119135	2020-08-16 13:19:12	2020-08-16	23	[{"id_menu":2,"count":3},{"id_menu":6,"count":1}]	39557	delivery	5	28
119136	2020-08-16 13:19:39	2020-08-16	14	[{"id_menu":2,"count":1}]	45237	delivery	5	19
119137	2020-08-16 13:20:46	2020-08-16	9	[{"id_menu":7,"count":1}]	45449	delivery	5	14
119138	2020-08-16 13:21:32	2020-08-16	9	[{"id_menu":6,"count":1}]	9404	pick-up	0	9
119139	2020-08-16 13:22:09	2020-08-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	31940	delivery	5	22
119140	2020-08-16 13:23:58	2020-08-16	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39861	delivery	5	40
119141	2020-08-16 13:24:50	2020-08-16	9	[{"id_menu":6,"count":2}]	39312	delivery	5	14
119142	2020-08-16 13:25:57	2020-08-16	12	[{"id_menu":3,"count":1}]	2237	delivery	5	17
119143	2020-08-16 13:27:05	2020-08-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	701	pick-up	0	26
119144	2020-08-16 13:29:14	2020-08-16	9	[{"id_menu":6,"count":1}]	45350	delivery	5	14
119145	2020-08-16 13:30:14	2020-08-16	9	[{"id_menu":7,"count":2}]	45378	delivery	5	14
119146	2020-08-16 13:30:25	2020-08-16	17	[{"id_menu":4,"count":1}]	45416	delivery	5	22
119147	2020-08-16 13:31:27	2020-08-16	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	45306	delivery	5	31
119148	2020-08-16 13:32:24	2020-08-16	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	638	pick-up	0	41
119149	2020-08-16 13:33:14	2020-08-16	9	[{"id_menu":6,"count":1}]	1931	delivery	5	14
119150	2020-08-16 13:39:42	2020-08-16	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37673	pick-up	0	30
119151	2020-08-16 13:40:46	2020-08-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	8323	pick-up	0	23
119152	2020-08-16 13:42:03	2020-08-16	12	[{"id_menu":1,"count":1}]	45435	delivery	5	17
119153	2020-08-16 13:43:17	2020-08-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	32099	delivery	5	31
119154	2020-08-16 13:43:18	2020-08-16	9	[{"id_menu":6,"count":1}]	43899	delivery	5	14
119155	2020-08-16 13:43:57	2020-08-16	9	[{"id_menu":6,"count":1}]	41463	delivery	5	14
119156	2020-08-16 13:44:37	2020-08-16	14	[{"id_menu":2,"count":2}]	45388	delivery	5	19
119157	2020-08-16 13:44:39	2020-08-16	17	[{"id_menu":4,"count":1}]	45220	pick-up	0	17
119158	2020-08-16 13:45:05	2020-08-16	12	[{"id_menu":3,"count":1}]	35441	delivery	5	17
119159	2020-08-16 13:45:54	2020-08-16	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	45223	delivery	5	34
119160	2020-08-16 13:47:35	2020-08-16	14	[{"id_menu":2,"count":1}]	25324	pick-up	0	14
119161	2020-08-16 13:47:48	2020-08-16	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	45432	delivery	5	40
119162	2020-08-16 13:49:26	2020-08-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4490	delivery	5	28
119163	2020-08-16 13:49:34	2020-08-16	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10618	delivery	5	22
119164	2020-08-16 13:51:52	2020-08-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20364	delivery	5	22
119165	2020-08-16 13:52:05	2020-08-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	45229	delivery	5	22
119166	2020-08-16 13:52:08	2020-08-16	14	[{"id_menu":2,"count":1}]	45261	delivery	5	19
119167	2020-08-16 13:52:44	2020-08-16	14	[{"id_menu":2,"count":1}]	17209	pick-up	0	14
119168	2020-08-16 13:53:55	2020-08-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	45412	delivery	5	23
119169	2020-08-16 13:54:13	2020-08-16	12	[{"id_menu":1,"count":1}]	21505	delivery	5	17
119170	2020-08-16 13:56:14	2020-08-16	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	45493	delivery	5	34
119171	2020-08-16 13:57:49	2020-08-16	8	[{"id_menu":5,"count":1}]	5149	delivery	5	13
119172	2020-08-16 13:59:16	2020-08-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	38797	delivery	5	31
119173	2020-08-16 14:01:06	2020-08-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	9061	pick-up	0	23
119174	2020-08-16 14:02:14	2020-08-16	14	[{"id_menu":2,"count":1}]	45300	pick-up	0	14
119175	2020-08-16 14:02:39	2020-08-16	14	[{"id_menu":2,"count":1}]	45341	delivery	5	19
119176	2020-08-16 14:03:29	2020-08-16	12	[{"id_menu":1,"count":1}]	36123	delivery	5	17
119177	2020-08-16 14:03:40	2020-08-16	9	[{"id_menu":7,"count":1}]	25869	delivery	5	14
119178	2020-08-16 14:03:47	2020-08-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	45298	delivery	5	28
119179	2020-08-16 14:04:28	2020-08-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	36547	pick-up	0	26
119180	2020-08-16 14:05:17	2020-08-16	17	[{"id_menu":4,"count":1}]	3040	delivery	5	22
119181	2020-08-16 14:06:03	2020-08-16	12	[{"id_menu":1,"count":1}]	45222	delivery	5	17
119249	2020-08-16 15:36:55	2020-08-16	9	[{"id_menu":6,"count":1}]	37500	delivery	5	14
119182	2020-08-16 14:06:37	2020-08-16	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	19144	pick-up	0	38
119183	2020-08-16 14:06:45	2020-08-16	14	[{"id_menu":2,"count":1}]	22369	delivery	5	19
119184	2020-08-16 14:07:22	2020-08-16	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	45332	delivery	5	40
119185	2020-08-16 14:10:29	2020-08-16	9	[{"id_menu":7,"count":1}]	45283	delivery	5	14
119186	2020-08-16 14:13:21	2020-08-16	12	[{"id_menu":1,"count":2}]	2866	pick-up	0	12
119187	2020-08-16 14:16:25	2020-08-16	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	28147	delivery	5	30
119188	2020-08-16 14:17:49	2020-08-16	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31133	delivery	5	36
119189	2020-08-16 14:19:25	2020-08-16	17	[{"id_menu":4,"count":1}]	4976	delivery	5	22
119190	2020-08-16 14:19:49	2020-08-16	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	45232	delivery	5	42
119191	2020-08-16 14:22:50	2020-08-16	12	[{"id_menu":3,"count":1}]	45270	delivery	5	17
119192	2020-08-16 14:23:24	2020-08-16	9	[{"id_menu":7,"count":1}]	38510	pick-up	0	9
119193	2020-08-16 14:24:37	2020-08-16	14	[{"id_menu":2,"count":1}]	12401	delivery	5	19
119194	2020-08-16 14:24:38	2020-08-16	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	30281	delivery	5	26
119195	2020-08-16 14:25:25	2020-08-16	12	[{"id_menu":1,"count":1}]	45405	delivery	5	17
119196	2020-08-16 14:26:14	2020-08-16	9	[{"id_menu":6,"count":1}]	11761	delivery	5	14
119197	2020-08-16 14:27:47	2020-08-16	14	[{"id_menu":2,"count":1}]	13267	pick-up	0	14
119198	2020-08-16 14:27:54	2020-08-16	8	[{"id_menu":5,"count":1}]	15977	delivery	5	13
119199	2020-08-16 14:29:20	2020-08-16	14	[{"id_menu":2,"count":1}]	8791	pick-up	0	14
119200	2020-08-16 14:31:41	2020-08-16	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24510	delivery	5	36
119201	2020-08-16 14:32:16	2020-08-16	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12546	delivery	5	31
119202	2020-08-16 14:32:48	2020-08-16	12	[{"id_menu":1,"count":1}]	26451	delivery	5	17
119203	2020-08-16 14:36:13	2020-08-16	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13743	delivery	5	53
119204	2020-08-16 14:37:28	2020-08-16	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	40238	delivery	5	45
119205	2020-08-16 14:38:07	2020-08-16	9	[{"id_menu":6,"count":1}]	25061	delivery	5	14
119206	2020-08-16 14:38:34	2020-08-16	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	45393	delivery	5	26
119207	2020-08-16 14:38:42	2020-08-16	14	[{"id_menu":2,"count":1}]	45466	delivery	5	19
119208	2020-08-16 14:41:52	2020-08-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	27763	delivery	5	31
119209	2020-08-16 14:44:05	2020-08-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	32475	delivery	5	28
119210	2020-08-16 14:44:23	2020-08-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	20803	delivery	5	31
119211	2020-08-16 14:45:49	2020-08-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	45328	delivery	5	22
119212	2020-08-16 14:48:18	2020-08-16	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	7690	delivery	5	27
119213	2020-08-16 14:53:50	2020-08-16	8	[{"id_menu":5,"count":1}]	138	delivery	5	13
119214	2020-08-16 14:54:08	2020-08-16	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	39778	delivery	5	31
119215	2020-08-16 14:56:40	2020-08-16	9	[{"id_menu":7,"count":1}]	45462	delivery	5	14
119216	2020-08-16 14:58:50	2020-08-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	43096	pick-up	0	17
119217	2020-08-16 14:59:16	2020-08-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17644	delivery	5	23
119218	2020-08-16 14:59:18	2020-08-16	9	[{"id_menu":7,"count":1}]	19969	delivery	5	14
119219	2020-08-16 14:59:30	2020-08-16	9	[{"id_menu":6,"count":1}]	18325	delivery	5	14
119220	2020-08-16 15:01:54	2020-08-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	23719	delivery	5	28
119221	2020-08-16 15:03:22	2020-08-16	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	45225	delivery	5	22
119222	2020-08-16 15:04:51	2020-08-16	9	[{"id_menu":6,"count":1}]	6055	delivery	5	14
119223	2020-08-16 15:05:19	2020-08-16	8	[{"id_menu":5,"count":2}]	16018	pick-up	0	8
119224	2020-08-16 15:05:26	2020-08-16	9	[{"id_menu":6,"count":1}]	45458	delivery	5	14
119225	2020-08-16 15:07:12	2020-08-16	12	[{"id_menu":1,"count":1}]	45436	delivery	5	17
119226	2020-08-16 15:07:21	2020-08-16	9	[{"id_menu":7,"count":1}]	45308	delivery	5	14
119227	2020-08-16 15:08:23	2020-08-16	9	[{"id_menu":7,"count":1}]	536	pick-up	0	9
119228	2020-08-16 15:10:49	2020-08-16	14	[{"id_menu":2,"count":1}]	1887	pick-up	0	14
119229	2020-08-16 15:10:55	2020-08-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	45391	delivery	5	28
119230	2020-08-16 15:11:32	2020-08-16	9	[{"id_menu":7,"count":1}]	41507	pick-up	0	9
119231	2020-08-16 15:11:39	2020-08-16	12	[{"id_menu":1,"count":1}]	15829	pick-up	0	12
119232	2020-08-16 15:12:50	2020-08-16	9	[{"id_menu":7,"count":1}]	2923	delivery	5	14
119233	2020-08-16 15:15:05	2020-08-16	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	25505	delivery	5	26
119234	2020-08-16 15:15:32	2020-08-16	14	[{"id_menu":2,"count":1}]	8666	delivery	5	19
119235	2020-08-16 15:16:11	2020-08-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	8064	delivery	5	28
119236	2020-08-16 15:17:03	2020-08-16	9	[{"id_menu":6,"count":1}]	45266	pick-up	0	9
119237	2020-08-16 15:17:45	2020-08-16	9	[{"id_menu":7,"count":1}]	28288	delivery	5	14
119238	2020-08-16 15:17:46	2020-08-16	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	45290	delivery	5	40
119239	2020-08-16 15:21:06	2020-08-16	9	[{"id_menu":6,"count":1}]	45314	delivery	5	14
119240	2020-08-16 15:22:26	2020-08-16	8	[{"id_menu":5,"count":1}]	45385	delivery	5	13
119241	2020-08-16 15:22:31	2020-08-16	12	[{"id_menu":1,"count":1}]	30674	delivery	5	17
119242	2020-08-16 15:26:25	2020-08-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	39454	delivery	5	31
119243	2020-08-16 15:28:08	2020-08-16	9	[{"id_menu":6,"count":1}]	45474	delivery	5	14
119244	2020-08-16 15:28:39	2020-08-16	17	[{"id_menu":4,"count":1}]	8788	delivery	5	22
119245	2020-08-16 15:31:56	2020-08-16	14	[{"id_menu":2,"count":1}]	37203	delivery	5	19
119246	2020-08-16 15:34:08	2020-08-16	12	[{"id_menu":1,"count":1}]	15834	delivery	5	17
119247	2020-08-16 15:34:22	2020-08-16	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18179	delivery	5	34
119248	2020-08-16 15:36:35	2020-08-16	9	[{"id_menu":6,"count":1}]	17194	pick-up	0	9
119250	2020-08-16 15:37:41	2020-08-16	8	[{"id_menu":5,"count":1}]	45031	delivery	5	13
119251	2020-08-16 15:39:53	2020-08-16	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	44489	delivery	5	30
119252	2020-08-16 15:40:20	2020-08-16	9	[{"id_menu":6,"count":1}]	45401	delivery	5	14
119253	2020-08-16 15:40:31	2020-08-16	9	[{"id_menu":7,"count":1}]	15672	delivery	5	14
119254	2020-08-16 15:41:15	2020-08-16	14	[{"id_menu":2,"count":1}]	45381	delivery	5	19
119255	2020-08-16 15:41:50	2020-08-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	28781	delivery	5	31
119256	2020-08-16 15:42:56	2020-08-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	45400	delivery	5	26
119257	2020-08-16 15:43:28	2020-08-16	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	36245	delivery	5	34
119258	2020-08-16 15:44:22	2020-08-16	9	[{"id_menu":6,"count":1}]	45329	delivery	5	14
119259	2020-08-16 15:47:31	2020-08-16	8	[{"id_menu":5,"count":1}]	27722	delivery	5	13
119260	2020-08-16 15:48:13	2020-08-16	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	33191	delivery	5	57
119261	2020-08-16 15:50:49	2020-08-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	34402	delivery	5	31
119262	2020-08-16 15:50:54	2020-08-16	9	[{"id_menu":6,"count":1}]	35720	delivery	5	14
119263	2020-08-16 15:52:20	2020-08-16	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	16902	delivery	5	28
119264	2020-08-16 15:52:29	2020-08-16	9	[{"id_menu":6,"count":1}]	285	pick-up	0	9
119265	2020-08-16 15:53:47	2020-08-16	9	[{"id_menu":7,"count":1}]	8382	delivery	5	14
119266	2020-08-16 15:54:33	2020-08-16	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	34368	pick-up	0	20
119267	2020-08-16 15:55:27	2020-08-16	12	[{"id_menu":1,"count":1}]	40585	delivery	5	17
119268	2020-08-16 15:57:59	2020-08-16	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	45498	delivery	5	40
119269	2020-08-16 15:59:00	2020-08-16	9	[{"id_menu":7,"count":2}]	45379	delivery	5	14
119270	2020-08-16 15:59:15	2020-08-16	9	[{"id_menu":7,"count":1}]	11262	delivery	5	14
119271	2020-08-16 15:59:15	2020-08-16	55	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	10076	delivery	5	60
119272	2020-08-16 16:02:13	2020-08-16	8	[{"id_menu":5,"count":1}]	45407	delivery	5	13
119273	2020-08-16 16:03:28	2020-08-16	9	[{"id_menu":6,"count":1}]	9325	delivery	5	14
119274	2020-08-16 16:03:29	2020-08-16	8	[{"id_menu":5,"count":1}]	45297	delivery	5	13
119275	2020-08-16 16:04:43	2020-08-16	17	[{"id_menu":4,"count":1}]	45461	delivery	5	22
119276	2020-08-16 16:05:31	2020-08-16	17	[{"id_menu":4,"count":1}]	12808	pick-up	0	17
119277	2020-08-16 16:07:08	2020-08-16	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	24485	delivery	5	55
119278	2020-08-16 16:08:51	2020-08-16	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	45489	delivery	5	23
119279	2020-08-16 16:09:33	2020-08-16	17	[{"id_menu":4,"count":1}]	45227	delivery	5	22
119280	2020-08-16 16:11:54	2020-08-16	17	[{"id_menu":4,"count":1}]	45330	delivery	5	22
119281	2020-08-16 16:12:53	2020-08-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	29576	delivery	5	28
119282	2020-08-16 16:13:58	2020-08-16	14	[{"id_menu":2,"count":1}]	26445	pick-up	0	14
119283	2020-08-16 16:16:21	2020-08-16	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	45437	delivery	5	31
119284	2020-08-16 16:17:29	2020-08-16	12	[{"id_menu":1,"count":1}]	9104	pick-up	0	12
119285	2020-08-16 16:28:14	2020-08-16	12	[{"id_menu":1,"count":1}]	25571	pick-up	0	12
119286	2020-08-16 16:28:30	2020-08-16	17	[{"id_menu":4,"count":1}]	22079	delivery	5	22
119287	2020-08-16 16:32:16	2020-08-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	31586	delivery	5	22
119288	2020-08-16 16:32:19	2020-08-16	14	[{"id_menu":2,"count":1}]	12263	pick-up	0	14
119289	2020-08-16 16:33:21	2020-08-16	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	33789	delivery	5	26
119290	2020-08-16 16:33:35	2020-08-16	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	36478	delivery	5	34
119291	2020-08-16 16:34:23	2020-08-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	45274	delivery	5	23
119292	2020-08-16 16:35:14	2020-08-16	14	[{"id_menu":2,"count":1}]	17791	delivery	5	19
119293	2020-08-16 16:35:28	2020-08-16	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	44534	delivery	5	43
119294	2020-08-16 16:37:08	2020-08-16	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	15109	pick-up	0	20
119295	2020-08-16 16:37:51	2020-08-16	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	31160	delivery	5	31
119296	2020-08-16 16:37:51	2020-08-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	6553	delivery	5	28
119297	2020-08-16 16:38:01	2020-08-16	9	[{"id_menu":6,"count":1}]	40245	delivery	5	14
119298	2020-08-16 16:38:16	2020-08-16	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	38664	delivery	5	40
119299	2020-08-16 16:38:29	2020-08-16	9	[{"id_menu":6,"count":1}]	11635	delivery	5	14
119300	2020-08-16 16:38:47	2020-08-16	8	[{"id_menu":5,"count":1}]	2274	pick-up	0	8
119301	2020-08-16 16:39:24	2020-08-16	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	41229	delivery	5	36
119302	2020-08-16 16:39:52	2020-08-16	9	[{"id_menu":7,"count":1}]	44611	delivery	5	14
119303	2020-08-16 16:40:54	2020-08-16	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19443	delivery	5	49
119304	2020-08-16 16:41:32	2020-08-16	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	11686	delivery	5	48
119305	2020-08-16 16:44:02	2020-08-16	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	37927	delivery	5	45
119306	2020-08-16 16:47:59	2020-08-16	14	[{"id_menu":2,"count":1}]	20610	delivery	5	19
119307	2020-08-16 16:48:48	2020-08-16	14	[{"id_menu":2,"count":1}]	25679	pick-up	0	14
119308	2020-08-16 16:50:55	2020-08-16	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	45299	pick-up	0	20
119309	2020-08-16 16:51:19	2020-08-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	38563	delivery	5	22
119310	2020-08-16 16:51:33	2020-08-16	8	[{"id_menu":5,"count":1}]	19259	delivery	5	13
119311	2020-08-16 16:54:05	2020-08-16	8	[{"id_menu":5,"count":1}]	45260	delivery	5	13
119312	2020-08-16 16:54:51	2020-08-16	9	[{"id_menu":7,"count":1}]	26959	delivery	5	14
119313	2020-08-16 16:56:33	2020-08-16	9	[{"id_menu":6,"count":1}]	45238	delivery	5	14
119314	2020-08-16 16:57:03	2020-08-16	12	[{"id_menu":1,"count":1}]	2855	pick-up	0	12
119315	2020-08-16 16:57:18	2020-08-16	9	[{"id_menu":6,"count":1}]	45369	delivery	5	14
119316	2020-08-16 16:58:42	2020-08-16	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4275	pick-up	0	35
119317	2020-08-16 16:59:20	2020-08-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	1079	delivery	5	28
119318	2020-08-16 17:01:33	2020-08-16	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	45463	delivery	5	40
119319	2020-08-16 17:06:27	2020-08-16	9	[{"id_menu":6,"count":1}]	30455	pick-up	0	9
119320	2020-08-16 17:09:03	2020-08-16	9	[{"id_menu":6,"count":1}]	44854	delivery	5	14
119321	2020-08-16 17:09:14	2020-08-16	12	[{"id_menu":3,"count":1}]	45275	delivery	5	17
119322	2020-08-16 17:12:33	2020-08-16	12	[{"id_menu":3,"count":1}]	45338	delivery	5	17
119323	2020-08-16 17:12:35	2020-08-16	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	37427	delivery	5	36
119324	2020-08-16 17:13:03	2020-08-16	12	[{"id_menu":3,"count":1}]	45262	delivery	5	17
119325	2020-08-16 17:13:26	2020-08-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	44717	delivery	5	28
119326	2020-08-16 17:15:32	2020-08-16	17	[{"id_menu":4,"count":1}]	45417	delivery	5	22
119327	2020-08-16 17:17:21	2020-08-16	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	30262	delivery	5	27
119328	2020-08-16 17:20:57	2020-08-16	9	[{"id_menu":7,"count":1}]	25504	pick-up	0	9
119329	2020-08-16 17:22:44	2020-08-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8586	delivery	5	22
119330	2020-08-16 17:23:51	2020-08-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	40672	pick-up	0	26
119331	2020-08-16 17:31:04	2020-08-16	9	[{"id_menu":7,"count":2}]	45342	delivery	5	14
119332	2020-08-16 17:31:39	2020-08-16	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	45321	delivery	5	34
119333	2020-08-16 17:33:31	2020-08-16	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	30028	delivery	5	26
119334	2020-08-16 17:34:55	2020-08-16	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	34458	pick-up	0	29
119335	2020-08-16 17:35:21	2020-08-16	17	[{"id_menu":4,"count":1}]	45380	delivery	5	22
119336	2020-08-16 17:36:39	2020-08-16	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7222	delivery	5	46
119337	2020-08-16 17:37:07	2020-08-16	9	[{"id_menu":7,"count":1}]	44049	delivery	5	14
119338	2020-08-16 17:37:12	2020-08-16	9	[{"id_menu":7,"count":1}]	18720	delivery	5	14
119339	2020-08-16 17:37:13	2020-08-16	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	708	pick-up	0	32
119340	2020-08-16 17:38:13	2020-08-16	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	45485	delivery	5	48
119341	2020-08-16 17:40:01	2020-08-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21368	delivery	5	22
119342	2020-08-16 17:42:49	2020-08-16	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	26225	delivery	5	36
119343	2020-08-16 17:42:53	2020-08-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	45345	delivery	5	31
119344	2020-08-16 17:44:53	2020-08-16	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	45243	delivery	5	26
119345	2020-08-16 17:46:56	2020-08-16	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	41154	delivery	5	45
119346	2020-08-16 17:48:01	2020-08-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	45318	delivery	5	31
119347	2020-08-16 17:48:27	2020-08-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	31853	delivery	5	31
119348	2020-08-16 17:52:09	2020-08-16	12	[{"id_menu":1,"count":1}]	16084	pick-up	0	12
119349	2020-08-16 17:53:05	2020-08-16	12	[{"id_menu":1,"count":1}]	26743	delivery	5	17
119350	2020-08-16 17:53:17	2020-08-16	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	28574	delivery	5	31
119351	2020-08-16 17:54:49	2020-08-16	17	[{"id_menu":4,"count":1}]	45346	delivery	5	22
119352	2020-08-16 17:57:13	2020-08-16	9	[{"id_menu":7,"count":1}]	3483	delivery	5	14
119353	2020-08-16 17:58:29	2020-08-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	38523	delivery	5	22
119354	2020-08-16 17:59:04	2020-08-16	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	33997	delivery	5	34
119355	2020-08-16 17:59:31	2020-08-16	12	[{"id_menu":1,"count":1}]	25652	delivery	5	17
119356	2020-08-16 17:59:48	2020-08-16	17	[{"id_menu":4,"count":1}]	21930	delivery	5	22
119357	2020-08-16 18:02:00	2020-08-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	45492	delivery	5	26
119358	2020-08-16 18:06:53	2020-08-16	9	[{"id_menu":6,"count":1}]	6537	delivery	5	14
119359	2020-08-16 18:11:30	2020-08-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28774	delivery	5	23
119360	2020-08-16 18:11:48	2020-08-16	17	[{"id_menu":4,"count":1}]	8341	delivery	5	22
119361	2020-08-16 18:13:33	2020-08-16	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	34512	delivery	5	39
119362	2020-08-16 18:13:53	2020-08-16	17	[{"id_menu":4,"count":1}]	13648	delivery	5	22
119363	2020-08-16 18:15:38	2020-08-16	17	[{"id_menu":4,"count":1}]	33732	pick-up	0	17
119364	2020-08-16 18:16:57	2020-08-16	9	[{"id_menu":6,"count":1}]	29899	delivery	5	14
119365	2020-08-16 18:18:20	2020-08-16	14	[{"id_menu":2,"count":1}]	42841	pick-up	0	14
119366	2020-08-16 18:18:22	2020-08-16	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	45279	delivery	5	56
119367	2020-08-16 18:19:52	2020-08-16	12	[{"id_menu":3,"count":1}]	26308	delivery	5	17
119368	2020-08-16 18:21:13	2020-08-16	9	[{"id_menu":7,"count":1}]	28333	delivery	5	14
119369	2020-08-16 18:23:34	2020-08-16	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	17685	delivery	5	26
119370	2020-08-16 18:24:28	2020-08-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	43094	delivery	5	31
119371	2020-08-16 18:25:42	2020-08-16	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16883	delivery	5	43
119372	2020-08-16 18:26:20	2020-08-16	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	39982	delivery	5	30
119373	2020-08-16 18:30:15	2020-08-16	9	[{"id_menu":7,"count":1}]	2088	delivery	5	14
119374	2020-08-16 18:30:39	2020-08-16	12	[{"id_menu":3,"count":1}]	27012	delivery	5	17
119375	2020-08-16 18:31:31	2020-08-16	12	[{"id_menu":3,"count":1}]	11976	delivery	5	17
119376	2020-08-16 18:31:53	2020-08-16	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	36392	delivery	5	28
119377	2020-08-16 18:35:11	2020-08-16	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	45448	delivery	5	40
119378	2020-08-16 18:36:32	2020-08-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	38675	delivery	5	22
119379	2020-08-16 18:36:45	2020-08-16	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	39484	delivery	5	25
119380	2020-08-16 18:40:13	2020-08-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1922	delivery	5	23
119381	2020-08-16 18:43:41	2020-08-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	45228	delivery	5	23
119382	2020-08-16 18:44:46	2020-08-16	8	[{"id_menu":5,"count":1}]	41066	delivery	5	13
119383	2020-08-16 18:45:45	2020-08-16	12	[{"id_menu":3,"count":2}]	34850	delivery	5	17
119384	2020-08-16 18:45:47	2020-08-16	17	[{"id_menu":4,"count":1}]	35956	delivery	5	22
119385	2020-08-16 18:48:12	2020-08-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	34016	delivery	5	31
119386	2020-08-16 18:49:29	2020-08-16	12	[{"id_menu":3,"count":1}]	33745	delivery	5	17
119387	2020-08-16 18:50:47	2020-08-16	17	[{"id_menu":4,"count":1}]	7261	delivery	5	22
119388	2020-08-16 18:51:04	2020-08-16	9	[{"id_menu":7,"count":1}]	37554	delivery	5	14
119389	2020-08-16 18:53:22	2020-08-16	14	[{"id_menu":2,"count":2}]	18759	delivery	5	19
119390	2020-08-16 18:53:24	2020-08-16	12	[{"id_menu":3,"count":1}]	45295	pick-up	0	12
119391	2020-08-16 18:57:24	2020-08-16	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	3155	delivery	5	34
119392	2020-08-16 18:57:52	2020-08-16	17	[{"id_menu":4,"count":1}]	31571	delivery	5	22
119393	2020-08-16 18:59:49	2020-08-16	9	[{"id_menu":6,"count":1}]	2870	delivery	5	14
119394	2020-08-16 18:59:58	2020-08-16	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	17350	delivery	5	34
119395	2020-08-16 19:03:18	2020-08-16	14	[{"id_menu":2,"count":1}]	37097	delivery	5	19
119396	2020-08-16 19:04:42	2020-08-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	5571	delivery	5	26
119397	2020-08-16 19:05:01	2020-08-16	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	45480	delivery	5	48
119398	2020-08-16 19:11:04	2020-08-16	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	29871	delivery	5	39
119399	2020-08-16 19:14:44	2020-08-16	17	[{"id_menu":4,"count":2}]	2992	delivery	5	22
119400	2020-08-16 19:18:06	2020-08-16	9	[{"id_menu":6,"count":1}]	45375	delivery	5	14
119401	2020-08-16 19:18:20	2020-08-16	9	[{"id_menu":7,"count":1}]	7711	delivery	5	14
119402	2020-08-16 19:18:34	2020-08-16	8	[{"id_menu":5,"count":1}]	1168	pick-up	0	8
119403	2020-08-16 19:19:34	2020-08-16	8	[{"id_menu":5,"count":1}]	2317	pick-up	0	8
119404	2020-08-16 19:20:16	2020-08-16	12	[{"id_menu":3,"count":2}]	42953	delivery	5	17
119405	2020-08-16 19:23:00	2020-08-16	8	[{"id_menu":5,"count":1}]	45358	delivery	5	13
119406	2020-08-16 19:25:42	2020-08-16	9	[{"id_menu":6,"count":1}]	3925	pick-up	0	9
119407	2020-08-16 19:25:57	2020-08-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26624	delivery	5	23
119408	2020-08-16 19:27:21	2020-08-16	9	[{"id_menu":6,"count":2}]	45457	delivery	5	14
119409	2020-08-16 19:27:31	2020-08-16	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15968	pick-up	0	17
119410	2020-08-16 19:29:22	2020-08-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15671	delivery	5	31
119411	2020-08-16 19:29:41	2020-08-16	12	[{"id_menu":1,"count":1}]	10222	delivery	5	17
119412	2020-08-16 19:31:34	2020-08-16	8	[{"id_menu":5,"count":1}]	3749	delivery	5	13
119413	2020-08-16 19:32:41	2020-08-16	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	39931	delivery	5	26
119414	2020-08-16 19:33:07	2020-08-16	14	[{"id_menu":2,"count":1}]	408	pick-up	0	14
119415	2020-08-16 19:33:13	2020-08-16	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	9107	pick-up	0	21
119416	2020-08-16 19:34:07	2020-08-16	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3430	pick-up	0	21
119417	2020-08-16 19:37:06	2020-08-16	9	[{"id_menu":6,"count":1}]	9976	delivery	5	14
119418	2020-08-16 19:38:07	2020-08-16	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	37834	delivery	5	34
119419	2020-08-16 19:42:23	2020-08-16	12	[{"id_menu":1,"count":1}]	41701	delivery	5	17
119420	2020-08-16 19:42:26	2020-08-16	14	[{"id_menu":2,"count":2}]	34366	pick-up	0	14
119421	2020-08-16 19:43:43	2020-08-16	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2491	delivery	5	40
119422	2020-08-16 19:46:02	2020-08-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9313	delivery	5	23
119423	2020-08-16 19:47:22	2020-08-16	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	32598	delivery	5	23
119424	2020-08-16 19:48:05	2020-08-16	8	[{"id_menu":5,"count":1}]	26125	delivery	5	13
119425	2020-08-16 19:48:44	2020-08-16	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	44012	delivery	5	39
119426	2020-08-16 19:50:17	2020-08-16	12	[{"id_menu":1,"count":1}]	7196	delivery	5	17
119427	2020-08-16 19:50:45	2020-08-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2882	delivery	5	31
119428	2020-08-16 19:55:03	2020-08-16	9	[{"id_menu":7,"count":1}]	14524	pick-up	0	9
119429	2020-08-16 19:58:12	2020-08-16	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	126	pick-up	0	25
119430	2020-08-16 20:00:18	2020-08-16	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	45439	delivery	5	22
119431	2020-08-16 20:02:16	2020-08-16	8	[{"id_menu":5,"count":1}]	15317	delivery	5	13
119432	2020-08-16 20:06:07	2020-08-16	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	45373	delivery	5	36
119433	2020-08-16 20:07:25	2020-08-16	14	[{"id_menu":2,"count":1}]	32277	delivery	5	19
119434	2020-08-16 20:07:37	2020-08-16	8	[{"id_menu":5,"count":1}]	39465	pick-up	0	8
119435	2020-08-16 20:07:48	2020-08-16	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23159	delivery	5	48
119436	2020-08-16 20:08:04	2020-08-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	37873	delivery	5	22
119437	2020-08-16 20:08:57	2020-08-16	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	41354	delivery	5	34
119438	2020-08-16 20:09:43	2020-08-16	12	[{"id_menu":3,"count":1}]	31040	delivery	5	17
119439	2020-08-16 20:11:39	2020-08-16	12	[{"id_menu":1,"count":1}]	4578	pick-up	0	12
119440	2020-08-16 20:11:46	2020-08-16	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36277	delivery	5	48
119441	2020-08-16 20:13:37	2020-08-16	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	25430	delivery	5	36
119442	2020-08-16 20:14:31	2020-08-16	14	[{"id_menu":2,"count":1}]	45278	delivery	5	19
119443	2020-08-16 20:20:45	2020-08-16	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	24803	delivery	5	27
119444	2020-08-16 20:22:17	2020-08-16	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	656	delivery	5	27
119445	2020-08-16 20:23:22	2020-08-16	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	45307	delivery	5	31
119446	2020-08-16 20:24:39	2020-08-16	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	43535	delivery	5	26
119447	2020-08-16 20:25:32	2020-08-16	12	[{"id_menu":3,"count":1}]	11803	delivery	5	17
119448	2020-08-16 20:27:03	2020-08-16	17	[{"id_menu":4,"count":1}]	45271	delivery	5	22
119449	2020-08-16 20:27:45	2020-08-16	9	[{"id_menu":7,"count":1}]	36574	pick-up	0	9
119450	2020-08-16 20:28:56	2020-08-16	14	[{"id_menu":2,"count":2}]	22053	delivery	5	19
119451	2020-08-16 20:29:01	2020-08-16	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	45424	delivery	5	48
119452	2020-08-16 20:29:44	2020-08-16	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4125	delivery	5	31
119453	2020-08-16 20:30:16	2020-08-16	17	[{"id_menu":4,"count":1}]	45441	delivery	5	22
119454	2020-08-16 20:32:30	2020-08-16	17	[{"id_menu":4,"count":1}]	7383	pick-up	0	17
119455	2020-08-16 20:32:32	2020-08-16	14	[{"id_menu":2,"count":1}]	14025	pick-up	0	14
119456	2020-08-16 20:32:35	2020-08-16	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	41889	delivery	5	29
119457	2020-08-16 20:33:53	2020-08-16	9	[{"id_menu":6,"count":1}]	11201	delivery	5	14
119458	2020-08-16 20:33:56	2020-08-16	12	[{"id_menu":1,"count":1}]	2401	pick-up	0	12
119459	2020-08-16 20:35:04	2020-08-16	17	[{"id_menu":4,"count":1}]	5152	delivery	5	22
119460	2020-08-16 20:38:02	2020-08-16	9	[{"id_menu":7,"count":1}]	24129	pick-up	0	9
119461	2020-08-16 20:38:43	2020-08-16	12	[{"id_menu":1,"count":3}]	13508	delivery	5	17
119462	2020-08-16 20:44:40	2020-08-16	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23166	delivery	5	22
119463	2020-08-16 20:46:08	2020-08-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	26994	delivery	5	26
119464	2020-08-16 20:47:14	2020-08-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	27698	delivery	5	31
119465	2020-08-16 20:48:14	2020-08-16	17	[{"id_menu":4,"count":1}]	45495	delivery	5	22
119466	2020-08-16 20:49:32	2020-08-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	45446	delivery	5	31
119467	2020-08-16 20:49:55	2020-08-16	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	9750	pick-up	0	43
119468	2020-08-16 20:51:44	2020-08-16	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	30709	delivery	5	36
119469	2020-08-16 20:52:20	2020-08-16	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	33802	delivery	5	34
119470	2020-08-16 20:53:13	2020-08-16	12	[{"id_menu":1,"count":1}]	45263	delivery	5	17
119471	2020-08-16 20:53:16	2020-08-16	12	[{"id_menu":1,"count":1}]	15929	delivery	5	17
119472	2020-08-16 20:54:51	2020-08-16	12	[{"id_menu":1,"count":1}]	45440	delivery	5	17
119473	2020-08-16 20:55:24	2020-08-16	8	[{"id_menu":5,"count":1}]	16064	delivery	5	13
119474	2020-08-16 20:56:32	2020-08-16	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	30683	delivery	5	36
119475	2020-08-16 20:57:29	2020-08-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	11792	delivery	5	31
119476	2020-08-16 20:58:51	2020-08-16	14	[{"id_menu":2,"count":1}]	45376	delivery	5	19
119477	2020-08-16 21:00:47	2020-08-16	17	[{"id_menu":4,"count":1}]	45490	pick-up	0	17
119478	2020-08-16 21:02:41	2020-08-16	8	[{"id_menu":5,"count":1}]	7342	delivery	5	13
119479	2020-08-16 21:03:00	2020-08-16	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	14972	delivery	5	34
119480	2020-08-16 21:03:13	2020-08-16	9	[{"id_menu":6,"count":1}]	45383	pick-up	0	9
119481	2020-08-16 21:04:42	2020-08-16	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27164	delivery	5	31
119482	2020-08-16 21:05:36	2020-08-16	12	[{"id_menu":3,"count":1}]	30106	delivery	5	17
119483	2020-08-16 21:06:28	2020-08-16	9	[{"id_menu":7,"count":1}]	26752	delivery	5	14
119484	2020-08-16 21:06:50	2020-08-16	8	[{"id_menu":5,"count":1}]	10425	delivery	5	13
119485	2020-08-16 21:09:34	2020-08-16	12	[{"id_menu":1,"count":1}]	21377	delivery	5	17
119486	2020-08-16 21:10:58	2020-08-16	14	[{"id_menu":2,"count":1}]	26386	delivery	5	19
119487	2020-08-16 21:11:51	2020-08-16	14	[{"id_menu":2,"count":1}]	24284	pick-up	0	14
119488	2020-08-16 21:14:24	2020-08-16	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4479	pick-up	0	33
119489	2020-08-16 21:16:59	2020-08-16	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	45269	delivery	5	31
119490	2020-08-16 21:17:03	2020-08-16	14	[{"id_menu":2,"count":1}]	2110	delivery	5	19
119491	2020-08-16 21:18:39	2020-08-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	45494	delivery	5	31
119492	2020-08-16 21:25:32	2020-08-16	12	[{"id_menu":1,"count":1}]	45450	delivery	5	17
119493	2020-08-16 21:27:55	2020-08-16	14	[{"id_menu":2,"count":1}]	6408	delivery	5	19
119494	2020-08-16 21:28:53	2020-08-16	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	45315	delivery	5	35
119495	2020-08-16 21:30:53	2020-08-16	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4459	delivery	5	43
119496	2020-08-16 21:33:25	2020-08-16	9	[{"id_menu":6,"count":1}]	45267	delivery	5	14
119497	2020-08-16 21:33:27	2020-08-16	12	[{"id_menu":3,"count":1}]	25556	delivery	5	17
119498	2020-08-16 21:34:25	2020-08-16	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	45403	delivery	5	28
119499	2020-08-16 21:35:23	2020-08-16	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	9021	delivery	5	34
119500	2020-08-16 21:36:38	2020-08-16	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	44809	pick-up	0	21
119501	2020-08-16 21:36:49	2020-08-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	6243	delivery	5	26
119502	2020-08-16 21:37:39	2020-08-16	9	[{"id_menu":6,"count":4}]	44480	delivery	5	14
119503	2020-08-16 21:38:25	2020-08-16	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	45217	delivery	5	26
119504	2020-08-16 21:38:45	2020-08-16	14	[{"id_menu":2,"count":1}]	45475	delivery	5	19
119505	2020-08-16 21:39:06	2020-08-16	14	[{"id_menu":2,"count":1}]	45301	delivery	5	19
119506	2020-08-16 21:41:43	2020-08-16	9	[{"id_menu":6,"count":3}]	45224	delivery	5	14
119507	2020-08-16 21:42:26	2020-08-16	14	[{"id_menu":2,"count":1}]	45356	delivery	5	19
119508	2020-08-16 21:43:02	2020-08-16	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	31641	pick-up	0	31
119509	2020-08-16 21:44:32	2020-08-16	9	[{"id_menu":6,"count":2}]	27054	delivery	5	14
119510	2020-08-16 21:44:34	2020-08-16	9	[{"id_menu":6,"count":1}]	42691	delivery	5	14
119511	2020-08-16 21:45:28	2020-08-16	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	30246	delivery	5	43
119512	2020-08-16 21:46:47	2020-08-16	14	[{"id_menu":2,"count":1}]	2524	pick-up	0	14
119513	2020-08-16 21:46:49	2020-08-16	12	[{"id_menu":1,"count":2}]	45354	delivery	5	17
119514	2020-08-16 21:47:55	2020-08-16	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	45389	delivery	5	40
119515	2020-08-16 21:48:23	2020-08-16	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16755	delivery	5	51
119516	2020-08-16 21:49:54	2020-08-16	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	23751	delivery	5	22
119517	2020-08-16 21:51:37	2020-08-16	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	27783	delivery	5	27
119518	2020-08-16 21:54:24	2020-08-16	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	45353	delivery	5	29
119519	2020-08-16 21:58:34	2020-08-16	12	[{"id_menu":3,"count":1}]	23253	pick-up	0	12
119520	2020-08-16 21:58:57	2020-08-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	45335	delivery	5	31
119521	2020-08-16 21:59:30	2020-08-16	9	[{"id_menu":7,"count":1}]	29809	delivery	5	14
119522	2020-08-16 22:00:11	2020-08-16	12	[{"id_menu":1,"count":1}]	27214	delivery	5	17
119523	2020-08-16 22:03:49	2020-08-16	12	[{"id_menu":1,"count":1}]	31827	delivery	5	17
119524	2020-08-16 22:04:23	2020-08-16	9	[{"id_menu":6,"count":1}]	30856	delivery	5	14
119525	2020-08-16 22:04:57	2020-08-16	9	[{"id_menu":6,"count":1}]	19748	delivery	5	14
119526	2020-08-16 22:05:34	2020-08-16	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	45241	delivery	5	25
119527	2020-08-16 22:05:41	2020-08-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	45116	delivery	5	26
119528	2020-08-16 22:05:43	2020-08-16	8	[{"id_menu":5,"count":1}]	45288	delivery	5	13
119529	2020-08-16 22:05:58	2020-08-16	9	[{"id_menu":7,"count":1}]	17046	pick-up	0	9
119530	2020-08-16 22:06:36	2020-08-16	17	[{"id_menu":4,"count":1}]	42585	pick-up	0	17
119531	2020-08-16 22:07:52	2020-08-16	12	[{"id_menu":1,"count":1}]	9763	delivery	5	17
119532	2020-08-16 22:08:01	2020-08-16	14	[{"id_menu":2,"count":1}]	27538	pick-up	0	14
119533	2020-08-16 22:09:19	2020-08-16	12	[{"id_menu":3,"count":1}]	30406	pick-up	0	12
119534	2020-08-16 22:09:43	2020-08-16	9	[{"id_menu":7,"count":1}]	12599	delivery	5	14
119535	2020-08-16 22:13:41	2020-08-16	9	[{"id_menu":7,"count":1}]	36118	delivery	5	14
119536	2020-08-16 22:19:27	2020-08-16	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	45349	pick-up	0	30
119537	2020-08-16 22:19:32	2020-08-16	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	22319	delivery	5	31
119538	2020-08-16 22:20:26	2020-08-16	14	[{"id_menu":2,"count":1}]	5414	delivery	5	19
119539	2020-08-16 22:20:36	2020-08-16	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	45236	delivery	5	35
119540	2020-08-16 22:22:46	2020-08-16	9	[{"id_menu":6,"count":1}]	9837	delivery	5	14
119541	2020-08-16 22:23:47	2020-08-16	8	[{"id_menu":5,"count":1}]	45404	delivery	5	13
119542	2020-08-16 22:25:26	2020-08-16	17	[{"id_menu":4,"count":1}]	34504	delivery	5	22
119543	2020-08-16 22:27:55	2020-08-16	9	[{"id_menu":6,"count":1}]	45479	delivery	5	14
119544	2020-08-16 22:29:26	2020-08-16	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20438	delivery	5	34
119545	2020-08-16 22:30:28	2020-08-16	14	[{"id_menu":2,"count":1}]	9043	pick-up	0	14
119546	2020-08-16 22:33:40	2020-08-16	17	[{"id_menu":4,"count":1}]	45465	pick-up	0	17
119547	2020-08-16 22:34:33	2020-08-16	12	[{"id_menu":3,"count":1}]	15973	delivery	5	17
119548	2020-08-16 22:37:11	2020-08-16	9	[{"id_menu":7,"count":1}]	45443	delivery	5	14
119549	2020-08-16 22:37:32	2020-08-16	14	[{"id_menu":2,"count":1}]	2468	pick-up	0	14
119550	2020-08-16 22:39:46	2020-08-16	12	[{"id_menu":1,"count":1}]	45372	delivery	5	17
119551	2020-08-16 22:40:13	2020-08-16	17	[{"id_menu":4,"count":1}]	23233	delivery	5	22
119552	2020-08-16 22:42:16	2020-08-16	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1031	delivery	5	53
119553	2020-08-16 22:43:24	2020-08-16	9	[{"id_menu":6,"count":1}]	45456	delivery	5	14
119554	2020-08-16 22:44:07	2020-08-16	14	[{"id_menu":2,"count":1}]	4996	pick-up	0	14
119555	2020-08-16 22:45:12	2020-08-16	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	33889	delivery	5	31
119556	2020-08-16 22:45:30	2020-08-16	17	[{"id_menu":4,"count":1}]	45478	delivery	5	22
119557	2020-08-16 22:48:25	2020-08-16	8	[{"id_menu":5,"count":1}]	45257	delivery	5	13
119558	2020-08-16 22:52:08	2020-08-16	12	[{"id_menu":1,"count":2}]	45365	delivery	5	17
119559	2020-08-16 22:52:18	2020-08-16	12	[{"id_menu":3,"count":1}]	4049	delivery	5	17
119560	2020-08-16 22:52:27	2020-08-16	12	[{"id_menu":3,"count":1}]	44085	delivery	5	17
119561	2020-08-16 22:53:01	2020-08-16	9	[{"id_menu":6,"count":1}]	508	delivery	5	14
119562	2020-08-16 22:53:20	2020-08-16	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	44522	delivery	5	36
119563	2020-08-16 22:55:05	2020-08-16	17	[{"id_menu":4,"count":1}]	17671	delivery	5	22
119564	2020-08-16 22:55:20	2020-08-16	9	[{"id_menu":7,"count":2}]	41700	pick-up	0	9
119565	2020-08-16 22:55:49	2020-08-16	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	45230	delivery	5	48
119566	2020-08-16 22:56:47	2020-08-16	9	[{"id_menu":6,"count":1}]	43908	delivery	5	14
119567	2020-08-16 22:56:56	2020-08-16	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4735	delivery	5	27
119568	2020-08-16 22:57:59	2020-08-16	12	[{"id_menu":1,"count":1}]	32105	delivery	5	17
119569	2020-08-16 23:00:49	2020-08-16	9	[{"id_menu":6,"count":1}]	45258	delivery	5	14
119570	2020-08-16 23:01:37	2020-08-16	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	16557	delivery	5	22
119571	2020-08-16 23:02:40	2020-08-16	14	[{"id_menu":2,"count":1}]	32172	pick-up	0	14
119572	2020-08-16 23:05:25	2020-08-16	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	45363	delivery	5	43
119573	2020-08-16 23:06:02	2020-08-16	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	44853	delivery	5	42
119574	2020-08-16 23:14:07	2020-08-16	9	[{"id_menu":7,"count":1}]	17352	pick-up	0	9
119575	2020-08-16 23:15:35	2020-08-16	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	30139	delivery	5	39
119576	2020-08-16 23:16:31	2020-08-16	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	45281	delivery	5	42
119577	2020-08-16 23:17:16	2020-08-16	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	45361	delivery	5	40
119578	2020-08-16 23:17:19	2020-08-16	12	[{"id_menu":3,"count":1}]	45351	delivery	5	17
119579	2020-08-16 23:17:20	2020-08-16	8	[{"id_menu":5,"count":1}]	25930	pick-up	0	8
119580	2020-08-16 23:18:17	2020-08-16	9	[{"id_menu":7,"count":1}]	1754	pick-up	0	9
119581	2020-08-16 23:19:34	2020-08-16	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	20018	delivery	5	34
119582	2020-08-16 23:22:55	2020-08-16	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7438	delivery	5	22
119583	2020-08-16 23:27:02	2020-08-16	17	[{"id_menu":4,"count":1}]	32079	pick-up	0	17
119584	2020-08-16 23:28:02	2020-08-16	17	[{"id_menu":4,"count":1}]	6533	pick-up	0	17
119585	2020-08-16 23:31:37	2020-08-16	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	5004	delivery	5	26
119586	2020-08-16 23:34:14	2020-08-16	9	[{"id_menu":7,"count":1}]	6291	delivery	5	14
119587	2020-08-16 23:34:54	2020-08-16	12	[{"id_menu":3,"count":1}]	22181	delivery	5	17
119588	2020-08-16 23:37:09	2020-08-16	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3012	delivery	5	36
119589	2020-08-16 23:40:57	2020-08-16	12	[{"id_menu":1,"count":1}]	7084	delivery	5	17
119590	2020-08-16 23:41:16	2020-08-16	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	9846	pick-up	0	20
119591	2020-08-16 23:41:54	2020-08-16	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25248	delivery	5	40
119592	2020-08-16 23:42:11	2020-08-16	17	[{"id_menu":4,"count":1}]	5840	delivery	5	22
119593	2020-08-16 23:42:44	2020-08-16	9	[{"id_menu":6,"count":1}]	40112	delivery	5	14
119594	2020-08-16 23:43:37	2020-08-16	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	7498	delivery	5	31
119595	2020-08-16 23:44:11	2020-08-16	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	45487	delivery	5	31
119596	2020-08-16 23:45:23	2020-08-16	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	45394	delivery	5	31
119597	2020-08-16 23:45:53	2020-08-16	9	[{"id_menu":6,"count":1}]	20070	delivery	5	14
119598	2020-08-16 23:47:04	2020-08-16	9	[{"id_menu":7,"count":1}]	6781	delivery	5	14
119599	2020-08-16 23:47:33	2020-08-16	12	[{"id_menu":3,"count":1}]	813	pick-up	0	12
119600	2020-08-16 23:48:23	2020-08-16	17	[{"id_menu":4,"count":1}]	40056	delivery	5	22
119601	2020-08-16 23:50:59	2020-08-16	12	[{"id_menu":3,"count":1}]	39415	delivery	5	17
119602	2020-08-16 23:53:04	2020-08-16	9	[{"id_menu":7,"count":1}]	11764	pick-up	0	9
119603	2020-08-16 23:53:06	2020-08-16	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	24006	delivery	5	31
119604	2020-08-16 23:53:46	2020-08-16	12	[{"id_menu":3,"count":1}]	32316	delivery	5	17
119605	2020-08-16 23:54:46	2020-08-16	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	45460	delivery	5	26
119606	2020-08-16 23:56:17	2020-08-16	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	33313	delivery	5	39
119607	2020-08-16 23:57:25	2020-08-16	17	[{"id_menu":4,"count":1}]	30429	delivery	5	22
119608	2020-08-16 23:57:39	2020-08-16	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	3863	pick-up	0	29
119609	2020-08-16 23:59:34	2020-08-16	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	45293	pick-up	0	17
119610	2020-08-16 23:59:37	2020-08-16	9	[{"id_menu":7,"count":1}]	5621	delivery	5	14
119611	2020-08-17 00:01:43	2020-08-17	14	[{"id_menu":2,"count":1}]	2622	pick-up	0	14
119612	2020-08-17 00:06:53	2020-08-17	17	[{"id_menu":4,"count":1}]	44190	delivery	5	22
119613	2020-08-17 00:07:47	2020-08-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	45624	delivery	5	23
119614	2020-08-17 00:11:12	2020-08-17	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38225	delivery	5	40
119615	2020-08-17 00:14:24	2020-08-17	9	[{"id_menu":7,"count":1}]	45594	pick-up	0	9
119616	2020-08-17 00:20:03	2020-08-17	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	45728	delivery	5	37
119617	2020-08-17 00:25:15	2020-08-17	8	[{"id_menu":5,"count":1}]	38316	pick-up	0	8
119618	2020-08-17 00:27:09	2020-08-17	9	[{"id_menu":6,"count":2}]	45765	delivery	5	14
119619	2020-08-17 00:27:50	2020-08-17	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	23636	delivery	5	28
119620	2020-08-17 00:31:37	2020-08-17	17	[{"id_menu":4,"count":1}]	20216	pick-up	0	17
119621	2020-08-17 00:32:06	2020-08-17	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	26377	pick-up	0	17
119622	2020-08-17 00:33:58	2020-08-17	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	22771	pick-up	0	34
119623	2020-08-17 00:38:40	2020-08-17	9	[{"id_menu":6,"count":1}]	14683	delivery	5	14
119624	2020-08-17 00:47:43	2020-08-17	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	45504	delivery	5	35
119625	2020-08-17 00:48:01	2020-08-17	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	24858	delivery	5	26
119626	2020-08-17 00:50:31	2020-08-17	9	[{"id_menu":7,"count":1}]	29715	delivery	5	14
119627	2020-08-17 00:51:27	2020-08-17	8	[{"id_menu":5,"count":1}]	14025	pick-up	0	8
119628	2020-08-17 00:55:09	2020-08-17	9	[{"id_menu":7,"count":2}]	41008	delivery	5	14
119629	2020-08-17 00:56:15	2020-08-17	8	[{"id_menu":5,"count":1}]	36692	delivery	5	13
119630	2020-08-17 00:58:24	2020-08-17	12	[{"id_menu":1,"count":1}]	29873	delivery	5	17
119631	2020-08-17 00:58:26	2020-08-17	9	[{"id_menu":6,"count":1}]	23858	delivery	5	14
119632	2020-08-17 00:58:51	2020-08-17	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":2}]	45735	delivery	5	27
119633	2020-08-17 01:01:33	2020-08-17	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13753	delivery	5	43
119634	2020-08-17 01:16:09	2020-08-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	40754	delivery	5	28
119635	2020-08-17 01:16:44	2020-08-17	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9352	delivery	5	22
119636	2020-08-17 01:17:09	2020-08-17	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	12774	delivery	5	40
119637	2020-08-17 01:18:07	2020-08-17	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	37889	delivery	5	34
119638	2020-08-17 01:25:10	2020-08-17	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	27577	delivery	5	26
119639	2020-08-17 01:32:22	2020-08-17	9	[{"id_menu":6,"count":2}]	45553	delivery	5	14
119640	2020-08-17 01:35:17	2020-08-17	9	[{"id_menu":7,"count":2}]	6811	delivery	5	14
119641	2020-08-17 01:37:10	2020-08-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	45639	delivery	5	28
119642	2020-08-17 01:39:09	2020-08-17	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	17304	delivery	5	42
119643	2020-08-17 01:39:48	2020-08-17	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	32334	delivery	5	26
119644	2020-08-17 01:40:30	2020-08-17	9	[{"id_menu":7,"count":1}]	5839	delivery	5	14
119645	2020-08-17 01:41:36	2020-08-17	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	45715	delivery	5	23
119646	2020-08-17 01:42:21	2020-08-17	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13097	delivery	5	45
119647	2020-08-17 01:43:02	2020-08-17	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	3783	delivery	5	26
119648	2020-08-17 01:43:18	2020-08-17	9	[{"id_menu":6,"count":1}]	25944	delivery	5	14
119649	2020-08-17 01:49:27	2020-08-17	12	[{"id_menu":1,"count":1}]	4453	pick-up	0	12
119650	2020-08-17 01:50:23	2020-08-17	12	[{"id_menu":1,"count":1}]	2735	pick-up	0	12
119651	2020-08-17 01:52:34	2020-08-17	12	[{"id_menu":3,"count":1}]	14229	delivery	5	17
119652	2020-08-17 01:55:30	2020-08-17	12	[{"id_menu":1,"count":1}]	20020	pick-up	0	12
119653	2020-08-17 01:55:58	2020-08-17	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	45563	delivery	5	31
119654	2020-08-17 01:57:44	2020-08-17	9	[{"id_menu":6,"count":1}]	45635	delivery	5	14
119655	2020-08-17 02:00:39	2020-08-17	14	[{"id_menu":2,"count":1}]	45568	delivery	5	19
119656	2020-08-17 02:01:59	2020-08-17	14	[{"id_menu":2,"count":1}]	45605	pick-up	0	14
119657	2020-08-17 02:21:15	2020-08-17	9	[{"id_menu":7,"count":1}]	45524	delivery	5	14
119658	2020-08-17 02:31:53	2020-08-17	12	[{"id_menu":1,"count":1}]	439	delivery	5	17
119659	2020-08-17 02:35:10	2020-08-17	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	11150	delivery	5	38
119660	2020-08-17 02:40:07	2020-08-17	17	[{"id_menu":4,"count":1}]	23914	delivery	5	22
119661	2020-08-17 02:43:04	2020-08-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25360	pick-up	0	18
119662	2020-08-17 02:43:42	2020-08-17	9	[{"id_menu":7,"count":1}]	3119	delivery	5	14
119663	2020-08-17 02:44:56	2020-08-17	8	[{"id_menu":5,"count":1}]	26520	delivery	5	13
119664	2020-08-17 02:47:29	2020-08-17	14	[{"id_menu":2,"count":1}]	42694	pick-up	0	14
119665	2020-08-17 02:54:37	2020-08-17	14	[{"id_menu":2,"count":1}]	45597	delivery	5	19
119666	2020-08-17 02:54:39	2020-08-17	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	45646	delivery	5	26
119667	2020-08-17 02:54:48	2020-08-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":3}]	45505	delivery	5	28
119668	2020-08-17 02:56:20	2020-08-17	12	[{"id_menu":3,"count":1}]	45777	delivery	5	17
119669	2020-08-17 03:01:08	2020-08-17	17	[{"id_menu":4,"count":1}]	18593	delivery	5	22
119670	2020-08-17 03:03:09	2020-08-17	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	45514	delivery	5	55
119671	2020-08-17 03:07:53	2020-08-17	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23576	delivery	5	54
119672	2020-08-17 03:14:21	2020-08-17	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	45599	delivery	5	34
119673	2020-08-17 03:18:51	2020-08-17	12	[{"id_menu":1,"count":1}]	42936	delivery	5	17
119674	2020-08-17 03:22:46	2020-08-17	9	[{"id_menu":6,"count":1}]	8317	delivery	5	14
119675	2020-08-17 03:24:05	2020-08-17	12	[{"id_menu":3,"count":1}]	17122	delivery	5	17
119676	2020-08-17 03:24:17	2020-08-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5087	delivery	5	31
119677	2020-08-17 03:24:44	2020-08-17	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	7835	pick-up	0	26
119678	2020-08-17 03:25:17	2020-08-17	12	[{"id_menu":3,"count":1}]	2392	delivery	5	17
119679	2020-08-17 03:25:44	2020-08-17	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14446	delivery	5	31
119680	2020-08-17 03:27:02	2020-08-17	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	26622	delivery	5	31
119681	2020-08-17 03:29:35	2020-08-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	38638	delivery	5	28
119682	2020-08-17 03:30:29	2020-08-17	9	[{"id_menu":7,"count":1}]	37986	delivery	5	14
119683	2020-08-17 03:31:48	2020-08-17	17	[{"id_menu":4,"count":1}]	37099	pick-up	0	17
119684	2020-08-17 03:33:07	2020-08-17	14	[{"id_menu":2,"count":1}]	4132	pick-up	0	14
119685	2020-08-17 03:33:17	2020-08-17	12	[{"id_menu":3,"count":1}]	41824	pick-up	0	12
119686	2020-08-17 03:33:35	2020-08-17	14	[{"id_menu":2,"count":1}]	45606	pick-up	0	14
119687	2020-08-17 03:34:39	2020-08-17	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	45640	pick-up	0	26
119688	2020-08-17 03:39:22	2020-08-17	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	1860	pick-up	0	31
119689	2020-08-17 03:45:52	2020-08-17	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1262	pick-up	0	17
119690	2020-08-17 03:46:01	2020-08-17	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	45041	delivery	5	31
119691	2020-08-17 03:49:18	2020-08-17	12	[{"id_menu":1,"count":1}]	45674	pick-up	0	12
119692	2020-08-17 03:49:23	2020-08-17	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	43520	pick-up	0	29
119693	2020-08-17 03:53:07	2020-08-17	9	[{"id_menu":6,"count":1}]	8229	delivery	5	14
119694	2020-08-17 03:54:52	2020-08-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	16191	delivery	5	28
119695	2020-08-17 03:58:25	2020-08-17	8	[{"id_menu":5,"count":1}]	27592	delivery	5	13
119696	2020-08-17 03:58:29	2020-08-17	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":2}]	39026	delivery	5	31
119697	2020-08-17 03:58:37	2020-08-17	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	20787	delivery	5	43
119698	2020-08-17 04:03:43	2020-08-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	45672	delivery	5	31
119699	2020-08-17 04:03:54	2020-08-17	17	[{"id_menu":4,"count":1}]	45517	delivery	5	22
119700	2020-08-17 04:05:43	2020-08-17	9	[{"id_menu":7,"count":1}]	4398	delivery	5	14
119701	2020-08-17 04:09:12	2020-08-17	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	45750	delivery	5	22
119702	2020-08-17 04:10:09	2020-08-17	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	12652	delivery	5	22
119703	2020-08-17 04:12:47	2020-08-17	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	45668	delivery	5	26
119704	2020-08-17 04:15:40	2020-08-17	9	[{"id_menu":7,"count":1}]	14539	delivery	5	14
119705	2020-08-17 04:17:03	2020-08-17	8	[{"id_menu":5,"count":1}]	19836	delivery	5	13
119706	2020-08-17 04:20:02	2020-08-17	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	45513	delivery	5	30
119707	2020-08-17 04:20:35	2020-08-17	9	[{"id_menu":6,"count":1}]	29714	delivery	5	14
119708	2020-08-17 04:21:18	2020-08-17	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	29225	pick-up	0	20
119709	2020-08-17 04:24:14	2020-08-17	12	[{"id_menu":3,"count":1}]	45733	delivery	5	17
119710	2020-08-17 04:29:45	2020-08-17	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	8311	delivery	5	26
119711	2020-08-17 04:34:10	2020-08-17	9	[{"id_menu":6,"count":1}]	45671	delivery	5	14
119712	2020-08-17 04:36:18	2020-08-17	9	[{"id_menu":7,"count":1}]	19256	delivery	5	14
119713	2020-08-17 04:48:02	2020-08-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	26667	delivery	5	28
119714	2020-08-17 04:52:35	2020-08-17	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2098	delivery	5	37
119715	2020-08-17 04:54:07	2020-08-17	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	45002	delivery	5	35
119716	2020-08-17 04:54:32	2020-08-17	17	[{"id_menu":4,"count":1}]	45533	delivery	5	22
119717	2020-08-17 04:54:47	2020-08-17	9	[{"id_menu":7,"count":1}]	23028	delivery	5	14
119718	2020-08-17 05:01:53	2020-08-17	17	[{"id_menu":4,"count":1}]	43744	delivery	5	22
119719	2020-08-17 05:02:43	2020-08-17	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	41691	delivery	5	26
119720	2020-08-17 05:03:15	2020-08-17	12	[{"id_menu":1,"count":1}]	1431	pick-up	0	12
119721	2020-08-17 05:03:38	2020-08-17	8	[{"id_menu":5,"count":1}]	22686	delivery	5	13
119722	2020-08-17 05:07:57	2020-08-17	12	[{"id_menu":3,"count":1}]	7836	delivery	5	17
119723	2020-08-17 05:13:42	2020-08-17	9	[{"id_menu":7,"count":1}]	45771	delivery	5	14
119724	2020-08-17 05:14:31	2020-08-17	12	[{"id_menu":3,"count":1}]	45083	delivery	5	17
119725	2020-08-17 05:16:44	2020-08-17	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	15828	delivery	5	31
119726	2020-08-17 05:18:43	2020-08-17	8	[{"id_menu":5,"count":2}]	45558	delivery	5	13
119727	2020-08-17 05:19:15	2020-08-17	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	41926	delivery	5	25
119728	2020-08-17 05:20:37	2020-08-17	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	32797	delivery	5	27
119729	2020-08-17 05:22:27	2020-08-17	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2526	delivery	5	48
119730	2020-08-17 05:28:46	2020-08-17	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	26089	delivery	5	44
119731	2020-08-17 05:29:48	2020-08-17	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10344	delivery	5	46
119732	2020-08-17 05:29:55	2020-08-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28712	pick-up	0	18
119733	2020-08-17 05:33:23	2020-08-17	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	45650	delivery	5	42
119734	2020-08-17 05:40:35	2020-08-17	9	[{"id_menu":6,"count":1}]	26419	delivery	5	14
119735	2020-08-17 05:45:44	2020-08-17	8	[{"id_menu":5,"count":1}]	45578	delivery	5	13
119736	2020-08-17 05:46:45	2020-08-17	12	[{"id_menu":3,"count":1}]	45503	delivery	5	17
119737	2020-08-17 05:49:37	2020-08-17	12	[{"id_menu":1,"count":1}]	45707	delivery	5	17
119738	2020-08-17 05:55:44	2020-08-17	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	12772	delivery	5	26
119739	2020-08-17 05:55:44	2020-08-17	12	[{"id_menu":1,"count":1}]	1360	pick-up	0	12
119740	2020-08-17 05:57:37	2020-08-17	9	[{"id_menu":6,"count":1}]	10200	pick-up	0	9
119741	2020-08-17 06:01:47	2020-08-17	12	[{"id_menu":1,"count":1}]	45528	delivery	5	17
119742	2020-08-17 06:05:13	2020-08-17	8	[{"id_menu":5,"count":1}]	26154	delivery	5	13
119743	2020-08-17 06:05:40	2020-08-17	14	[{"id_menu":2,"count":1}]	3382	pick-up	0	14
119744	2020-08-17 06:07:58	2020-08-17	9	[{"id_menu":7,"count":1}]	45576	delivery	5	14
119745	2020-08-17 06:14:22	2020-08-17	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	27575	delivery	5	40
119746	2020-08-17 06:18:52	2020-08-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	45586	delivery	5	28
119747	2020-08-17 06:21:05	2020-08-17	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	45531	delivery	5	22
119748	2020-08-17 06:21:33	2020-08-17	9	[{"id_menu":6,"count":1}]	746	pick-up	0	9
119749	2020-08-17 06:26:52	2020-08-17	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	38909	delivery	5	40
119750	2020-08-17 06:28:02	2020-08-17	17	[{"id_menu":4,"count":1}]	16645	delivery	5	22
119751	2020-08-17 06:38:17	2020-08-17	55	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	45785	delivery	5	60
119752	2020-08-17 06:40:27	2020-08-17	9	[{"id_menu":7,"count":1}]	29	pick-up	0	9
119753	2020-08-17 06:40:47	2020-08-17	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	45552	delivery	5	43
119754	2020-08-17 06:43:50	2020-08-17	17	[{"id_menu":4,"count":1}]	43501	pick-up	0	17
119755	2020-08-17 06:44:27	2020-08-17	9	[{"id_menu":7,"count":2}]	21617	pick-up	0	9
119756	2020-08-17 06:49:54	2020-08-17	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	45591	delivery	5	54
119757	2020-08-17 06:51:16	2020-08-17	14	[{"id_menu":2,"count":1}]	31351	delivery	5	19
119758	2020-08-17 06:51:55	2020-08-17	9	[{"id_menu":6,"count":1}]	45542	delivery	5	14
119759	2020-08-17 07:00:00	2020-08-17	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	45532	delivery	5	34
119760	2020-08-17 07:00:14	2020-08-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	28401	pick-up	0	23
119761	2020-08-17 07:01:30	2020-08-17	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7782	delivery	5	22
119762	2020-08-17 07:02:32	2020-08-17	12	[{"id_menu":1,"count":1}]	45499	delivery	5	17
119763	2020-08-17 07:04:36	2020-08-17	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	18203	delivery	5	34
119764	2020-08-17 07:07:59	2020-08-17	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	32110	delivery	5	40
119765	2020-08-17 07:16:22	2020-08-17	12	[{"id_menu":3,"count":1}]	45546	delivery	5	17
119766	2020-08-17 07:20:47	2020-08-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39596	delivery	5	23
119767	2020-08-17 07:24:51	2020-08-17	14	[{"id_menu":2,"count":1}]	15385	delivery	5	19
119768	2020-08-17 07:25:08	2020-08-17	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	33503	delivery	5	48
119769	2020-08-17 07:25:12	2020-08-17	8	[{"id_menu":5,"count":1}]	1529	delivery	5	13
119770	2020-08-17 07:30:47	2020-08-17	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	45612	delivery	5	31
119771	2020-08-17 07:36:30	2020-08-17	9	[{"id_menu":7,"count":1}]	45699	delivery	5	14
119772	2020-08-17 07:38:17	2020-08-17	9	[{"id_menu":7,"count":1}]	17457	pick-up	0	9
119773	2020-08-17 07:38:40	2020-08-17	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20460	delivery	5	39
119774	2020-08-17 07:40:08	2020-08-17	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	45724	delivery	5	34
119775	2020-08-17 07:41:39	2020-08-17	17	[{"id_menu":4,"count":1}]	25212	delivery	5	22
119776	2020-08-17 07:41:52	2020-08-17	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	45510	delivery	5	29
119777	2020-08-17 07:49:04	2020-08-17	17	[{"id_menu":4,"count":1}]	45700	pick-up	0	17
119778	2020-08-17 07:52:55	2020-08-17	9	[{"id_menu":6,"count":1}]	26947	delivery	5	14
119779	2020-08-17 08:00:21	2020-08-17	8	[{"id_menu":5,"count":1}]	7086	pick-up	0	8
119780	2020-08-17 08:02:47	2020-08-17	9	[{"id_menu":7,"count":1}]	45551	delivery	5	14
119781	2020-08-17 08:11:07	2020-08-17	14	[{"id_menu":2,"count":3}]	45737	delivery	5	19
119782	2020-08-17 08:21:46	2020-08-17	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	42420	delivery	5	37
119783	2020-08-17 08:23:24	2020-08-17	9	[{"id_menu":7,"count":1}]	45545	delivery	5	14
119784	2020-08-17 08:23:57	2020-08-17	9	[{"id_menu":7,"count":2}]	37410	delivery	5	14
119785	2020-08-17 08:25:02	2020-08-17	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	13508	delivery	5	26
119786	2020-08-17 08:29:30	2020-08-17	14	[{"id_menu":2,"count":2}]	45633	delivery	5	19
119787	2020-08-17 08:30:53	2020-08-17	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	45620	delivery	5	36
119788	2020-08-17 08:33:24	2020-08-17	9	[{"id_menu":7,"count":1}]	45793	delivery	5	14
119789	2020-08-17 08:35:56	2020-08-17	14	[{"id_menu":2,"count":1}]	2077	pick-up	0	14
119790	2020-08-17 08:39:08	2020-08-17	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27674	delivery	5	34
119791	2020-08-17 08:42:21	2020-08-17	17	[{"id_menu":4,"count":1}]	45652	delivery	5	22
119792	2020-08-17 08:43:56	2020-08-17	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10479	delivery	5	22
119793	2020-08-17 08:44:27	2020-08-17	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	45556	delivery	5	31
119794	2020-08-17 08:52:05	2020-08-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	23215	delivery	5	28
119795	2020-08-17 08:56:05	2020-08-17	8	[{"id_menu":5,"count":1}]	13256	delivery	5	13
119796	2020-08-17 08:56:18	2020-08-17	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	45615	delivery	5	40
119797	2020-08-17 08:58:12	2020-08-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	45697	delivery	5	28
119798	2020-08-17 09:02:07	2020-08-17	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":2}]	31601	delivery	5	31
119799	2020-08-17 09:04:42	2020-08-17	17	[{"id_menu":4,"count":1}]	42633	delivery	5	22
119800	2020-08-17 09:08:21	2020-08-17	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	25834	delivery	5	23
119801	2020-08-17 09:12:27	2020-08-17	9	[{"id_menu":7,"count":1}]	45644	delivery	5	14
119802	2020-08-17 09:24:17	2020-08-17	12	[{"id_menu":1,"count":1}]	29084	pick-up	0	12
119803	2020-08-17 09:30:32	2020-08-17	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33101	delivery	5	31
119804	2020-08-17 09:32:53	2020-08-17	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	16755	delivery	5	31
119805	2020-08-17 09:34:30	2020-08-17	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	45601	delivery	5	36
119806	2020-08-17 09:34:41	2020-08-17	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1044	pick-up	0	26
119807	2020-08-17 09:36:01	2020-08-17	17	[{"id_menu":4,"count":1}]	33780	delivery	5	22
119808	2020-08-17 09:36:09	2020-08-17	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	42277	delivery	5	35
119809	2020-08-17 09:38:19	2020-08-17	9	[{"id_menu":6,"count":1}]	9073	delivery	5	14
119810	2020-08-17 09:39:16	2020-08-17	17	[{"id_menu":4,"count":1}]	232	pick-up	0	17
119811	2020-08-17 09:39:34	2020-08-17	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	33070	delivery	5	34
119812	2020-08-17 09:41:50	2020-08-17	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	45501	delivery	5	36
119813	2020-08-17 09:42:14	2020-08-17	12	[{"id_menu":3,"count":1}]	33235	pick-up	0	12
119814	2020-08-17 09:44:26	2020-08-17	12	[{"id_menu":3,"count":1}]	29042	pick-up	0	12
119815	2020-08-17 09:45:50	2020-08-17	9	[{"id_menu":6,"count":1}]	45731	pick-up	0	9
119816	2020-08-17 09:46:11	2020-08-17	12	[{"id_menu":3,"count":1}]	32063	delivery	5	17
119817	2020-08-17 09:49:36	2020-08-17	9	[{"id_menu":7,"count":1}]	45792	delivery	5	14
119818	2020-08-17 09:51:31	2020-08-17	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	28157	delivery	5	43
119819	2020-08-17 09:51:57	2020-08-17	14	[{"id_menu":2,"count":1}]	45590	delivery	5	19
119820	2020-08-17 09:53:23	2020-08-17	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	45706	delivery	5	35
119821	2020-08-17 09:54:45	2020-08-17	12	[{"id_menu":1,"count":1}]	19212	pick-up	0	12
119822	2020-08-17 10:00:28	2020-08-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	45659	delivery	5	23
119823	2020-08-17 10:04:07	2020-08-17	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	45637	delivery	5	36
119824	2020-08-17 10:04:32	2020-08-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	45754	delivery	5	23
119825	2020-08-17 10:07:14	2020-08-17	12	[{"id_menu":1,"count":1}]	45623	delivery	5	17
119826	2020-08-17 10:09:28	2020-08-17	8	[{"id_menu":5,"count":1}]	45625	delivery	5	13
119827	2020-08-17 10:12:46	2020-08-17	9	[{"id_menu":7,"count":1}]	10262	delivery	5	14
119828	2020-08-17 10:13:08	2020-08-17	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	31371	delivery	5	36
119829	2020-08-17 10:13:15	2020-08-17	9	[{"id_menu":6,"count":2}]	45509	delivery	5	14
119830	2020-08-17 10:13:28	2020-08-17	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	31184	delivery	5	26
119831	2020-08-17 10:13:39	2020-08-17	14	[{"id_menu":2,"count":1}]	45596	delivery	5	19
119832	2020-08-17 10:15:06	2020-08-17	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	20209	delivery	5	25
119833	2020-08-17 10:15:22	2020-08-17	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	2059	pick-up	0	30
119834	2020-08-17 10:30:28	2020-08-17	9	[{"id_menu":7,"count":1}]	45764	delivery	5	14
119835	2020-08-17 10:30:51	2020-08-17	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	33946	delivery	5	39
119836	2020-08-17 10:31:53	2020-08-17	12	[{"id_menu":3,"count":1}]	45762	delivery	5	17
119837	2020-08-17 10:32:30	2020-08-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	39979	delivery	5	28
119838	2020-08-17 10:32:53	2020-08-17	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	24274	delivery	5	36
119839	2020-08-17 10:35:43	2020-08-17	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	37868	delivery	5	30
119840	2020-08-17 10:36:38	2020-08-17	12	[{"id_menu":1,"count":1}]	20549	pick-up	0	12
119841	2020-08-17 10:39:10	2020-08-17	9	[{"id_menu":7,"count":1}]	33313	delivery	5	14
119842	2020-08-17 10:39:34	2020-08-17	9	[{"id_menu":7,"count":1}]	21024	delivery	5	14
119843	2020-08-17 10:45:42	2020-08-17	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	38394	pick-up	0	34
119844	2020-08-17 10:50:00	2020-08-17	8	[{"id_menu":5,"count":1}]	21262	delivery	5	13
119845	2020-08-17 10:51:43	2020-08-17	17	[{"id_menu":4,"count":1}]	26452	delivery	5	22
119846	2020-08-17 10:54:46	2020-08-17	8	[{"id_menu":5,"count":1}]	30190	delivery	5	13
119847	2020-08-17 10:58:58	2020-08-17	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19817	delivery	5	48
119848	2020-08-17 11:07:48	2020-08-17	9	[{"id_menu":6,"count":1}]	45768	delivery	5	14
119849	2020-08-17 11:09:04	2020-08-17	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	35287	pick-up	0	29
119850	2020-08-17 11:23:02	2020-08-17	9	[{"id_menu":7,"count":1}]	30493	pick-up	0	9
119851	2020-08-17 11:24:30	2020-08-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25537	delivery	5	23
119852	2020-08-17 11:25:26	2020-08-17	12	[{"id_menu":3,"count":1}]	29202	pick-up	0	12
119853	2020-08-17 11:30:22	2020-08-17	9	[{"id_menu":7,"count":1}]	30112	delivery	5	14
119854	2020-08-17 11:32:40	2020-08-17	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	39332	delivery	5	40
119855	2020-08-17 11:36:02	2020-08-17	12	[{"id_menu":3,"count":1}]	15475	pick-up	0	12
119856	2020-08-17 11:43:20	2020-08-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	45655	delivery	5	31
119857	2020-08-17 11:44:07	2020-08-17	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	20705	delivery	5	40
119858	2020-08-17 11:54:18	2020-08-17	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23379	delivery	5	39
119859	2020-08-17 11:56:57	2020-08-17	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	38689	delivery	5	31
119860	2020-08-17 12:02:55	2020-08-17	14	[{"id_menu":2,"count":1}]	45677	delivery	5	19
119861	2020-08-17 12:05:20	2020-08-17	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	9934	delivery	5	26
119862	2020-08-17 12:14:30	2020-08-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1645	pick-up	0	26
119863	2020-08-17 12:15:51	2020-08-17	9	[{"id_menu":6,"count":1}]	2980	pick-up	0	9
119864	2020-08-17 12:21:14	2020-08-17	14	[{"id_menu":2,"count":1}]	45676	delivery	5	19
119865	2020-08-17 12:21:23	2020-08-17	30	[{"id_menu":1,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17142	delivery	5	35
119866	2020-08-17 12:26:04	2020-08-17	12	[{"id_menu":1,"count":1}]	45685	delivery	5	17
119867	2020-08-17 12:37:02	2020-08-17	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	45583	delivery	5	22
119868	2020-08-17 12:37:04	2020-08-17	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13332	delivery	5	39
119869	2020-08-17 12:38:10	2020-08-17	14	[{"id_menu":2,"count":1}]	42900	delivery	5	19
119870	2020-08-17 12:40:16	2020-08-17	8	[{"id_menu":5,"count":1}]	40893	delivery	5	13
119871	2020-08-17 12:48:04	2020-08-17	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	14979	delivery	5	26
119872	2020-08-17 12:48:17	2020-08-17	9	[{"id_menu":7,"count":1}]	9111	pick-up	0	9
119873	2020-08-17 12:53:16	2020-08-17	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	207	pick-up	0	26
119874	2020-08-17 12:56:38	2020-08-17	9	[{"id_menu":7,"count":1}]	45786	delivery	5	14
119875	2020-08-17 13:04:53	2020-08-17	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	32926	delivery	5	31
119876	2020-08-17 13:05:13	2020-08-17	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	45680	delivery	5	45
119877	2020-08-17 13:06:41	2020-08-17	9	[{"id_menu":6,"count":1}]	28058	delivery	5	14
119878	2020-08-17 13:06:54	2020-08-17	14	[{"id_menu":2,"count":1}]	45511	delivery	5	19
119879	2020-08-17 13:09:43	2020-08-17	9	[{"id_menu":7,"count":2}]	35736	delivery	5	14
119880	2020-08-17 13:10:55	2020-08-17	9	[{"id_menu":6,"count":2}]	45766	delivery	5	14
119881	2020-08-17 13:11:02	2020-08-17	12	[{"id_menu":3,"count":1}]	6051	delivery	5	17
119882	2020-08-17 13:12:03	2020-08-17	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	39350	delivery	5	44
119883	2020-08-17 13:13:45	2020-08-17	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	45664	delivery	5	43
119884	2020-08-17 13:16:13	2020-08-17	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":2}]	26019	delivery	5	28
119885	2020-08-17 13:16:42	2020-08-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	23267	delivery	5	31
119886	2020-08-17 13:16:53	2020-08-17	12	[{"id_menu":3,"count":1}]	23108	delivery	5	17
119887	2020-08-17 13:18:48	2020-08-17	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	45626	delivery	5	45
119888	2020-08-17 13:22:56	2020-08-17	17	[{"id_menu":4,"count":1}]	3419	pick-up	0	17
119889	2020-08-17 13:24:31	2020-08-17	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33203	delivery	5	35
119890	2020-08-17 13:28:19	2020-08-17	14	[{"id_menu":2,"count":1}]	27144	delivery	5	19
119891	2020-08-17 13:31:09	2020-08-17	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	25125	delivery	5	26
119892	2020-08-17 13:32:19	2020-08-17	20	[{"id_menu":1,"count":3},{"id_menu":5,"count":1}]	40633	delivery	5	25
119893	2020-08-17 13:32:43	2020-08-17	9	[{"id_menu":7,"count":1}]	45530	delivery	5	14
119894	2020-08-17 13:34:41	2020-08-17	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	45665	delivery	5	39
119895	2020-08-17 13:39:06	2020-08-17	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14306	delivery	5	57
119896	2020-08-17 13:44:35	2020-08-17	17	[{"id_menu":4,"count":1}]	716	delivery	5	22
119897	2020-08-17 13:45:33	2020-08-17	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	45521	delivery	5	35
119898	2020-08-17 13:47:54	2020-08-17	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	12670	delivery	5	31
119899	2020-08-17 13:48:37	2020-08-17	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	8292	delivery	5	22
119900	2020-08-17 13:53:21	2020-08-17	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	45780	delivery	5	38
119901	2020-08-17 13:54:44	2020-08-17	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29361	delivery	5	36
119902	2020-08-17 13:57:53	2020-08-17	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	41242	delivery	5	56
119903	2020-08-17 13:57:57	2020-08-17	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	22375	delivery	5	36
119904	2020-08-17 13:58:41	2020-08-17	9	[{"id_menu":6,"count":1}]	2404	pick-up	0	9
119905	2020-08-17 14:02:20	2020-08-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	30882	delivery	5	23
119906	2020-08-17 14:02:27	2020-08-17	8	[{"id_menu":5,"count":2}]	31091	delivery	5	13
119907	2020-08-17 14:03:58	2020-08-17	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":2}]	28613	delivery	5	28
119908	2020-08-17 14:08:19	2020-08-17	12	[{"id_menu":3,"count":1}]	4390	delivery	5	17
119909	2020-08-17 14:12:04	2020-08-17	12	[{"id_menu":1,"count":1}]	18733	pick-up	0	12
119910	2020-08-17 14:18:56	2020-08-17	9	[{"id_menu":6,"count":1}]	45630	delivery	5	14
119911	2020-08-17 14:24:24	2020-08-17	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	31405	delivery	5	30
119912	2020-08-17 14:24:31	2020-08-17	9	[{"id_menu":6,"count":1}]	11215	delivery	5	14
119913	2020-08-17 14:25:11	2020-08-17	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	24470	delivery	5	23
119914	2020-08-17 14:28:39	2020-08-17	9	[{"id_menu":7,"count":1}]	45797	delivery	5	14
119915	2020-08-17 14:33:12	2020-08-17	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	17268	delivery	5	26
119916	2020-08-17 14:37:23	2020-08-17	14	[{"id_menu":2,"count":1}]	45688	delivery	5	19
119917	2020-08-17 14:40:18	2020-08-17	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	45574	delivery	5	31
119918	2020-08-17 14:40:29	2020-08-17	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	45527	delivery	5	39
119919	2020-08-17 14:40:47	2020-08-17	8	[{"id_menu":5,"count":1}]	9231	delivery	5	13
119920	2020-08-17 14:46:49	2020-08-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	45622	delivery	5	28
119921	2020-08-17 14:52:18	2020-08-17	8	[{"id_menu":5,"count":1}]	18253	pick-up	0	8
119922	2020-08-17 14:55:35	2020-08-17	12	[{"id_menu":1,"count":1}]	45687	delivery	5	17
119923	2020-08-17 14:57:04	2020-08-17	8	[{"id_menu":5,"count":1}]	27567	delivery	5	13
119924	2020-08-17 14:58:15	2020-08-17	17	[{"id_menu":4,"count":1}]	15926	delivery	5	22
119925	2020-08-17 14:59:34	2020-08-17	9	[{"id_menu":6,"count":1}]	1223	pick-up	0	9
119926	2020-08-17 15:01:40	2020-08-17	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":3}]	25410	delivery	5	22
119927	2020-08-17 15:02:04	2020-08-17	12	[{"id_menu":3,"count":2}]	37084	pick-up	0	12
119928	2020-08-17 15:07:10	2020-08-17	12	[{"id_menu":3,"count":2}]	31268	delivery	5	17
119929	2020-08-17 15:13:02	2020-08-17	8	[{"id_menu":5,"count":1}]	45538	delivery	5	13
119930	2020-08-17 15:19:40	2020-08-17	12	[{"id_menu":1,"count":1}]	23729	pick-up	0	12
119931	2020-08-17 15:20:35	2020-08-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23355	delivery	5	23
119932	2020-08-17 15:20:44	2020-08-17	9	[{"id_menu":7,"count":1}]	44946	delivery	5	14
119933	2020-08-17 15:21:33	2020-08-17	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1344	pick-up	0	21
119934	2020-08-17 15:36:29	2020-08-17	9	[{"id_menu":6,"count":1}]	38544	delivery	5	14
119935	2020-08-17 15:40:32	2020-08-17	12	[{"id_menu":3,"count":1}]	42617	delivery	5	17
119936	2020-08-17 15:41:46	2020-08-17	8	[{"id_menu":5,"count":1}]	17424	pick-up	0	8
119937	2020-08-17 15:42:52	2020-08-17	14	[{"id_menu":2,"count":1}]	44920	pick-up	0	14
119938	2020-08-17 15:49:03	2020-08-17	9	[{"id_menu":7,"count":1}]	38020	delivery	5	14
119939	2020-08-17 15:50:14	2020-08-17	12	[{"id_menu":1,"count":1}]	7574	pick-up	0	12
119940	2020-08-17 15:52:00	2020-08-17	12	[{"id_menu":1,"count":1}]	42298	delivery	5	17
119941	2020-08-17 15:52:08	2020-08-17	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	11384	delivery	5	48
119942	2020-08-17 15:54:45	2020-08-17	14	[{"id_menu":2,"count":2}]	37365	delivery	5	19
119943	2020-08-17 15:55:58	2020-08-17	39	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	3444	pick-up	0	39
119944	2020-08-17 15:57:35	2020-08-17	9	[{"id_menu":6,"count":1}]	8185	pick-up	0	9
119945	2020-08-17 15:57:59	2020-08-17	12	[{"id_menu":3,"count":1}]	45695	pick-up	0	12
119946	2020-08-17 15:58:40	2020-08-17	9	[{"id_menu":6,"count":1}]	45587	delivery	5	14
119947	2020-08-17 15:59:56	2020-08-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	28544	delivery	5	28
119948	2020-08-17 16:03:08	2020-08-17	17	[{"id_menu":4,"count":1}]	39130	pick-up	0	17
119949	2020-08-17 16:03:46	2020-08-17	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20800	delivery	5	46
119950	2020-08-17 16:04:51	2020-08-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39579	delivery	5	23
119951	2020-08-17 16:07:47	2020-08-17	8	[{"id_menu":5,"count":1}]	33006	delivery	5	13
119952	2020-08-17 16:08:36	2020-08-17	9	[{"id_menu":7,"count":1}]	45638	delivery	5	14
119953	2020-08-17 16:14:46	2020-08-17	8	[{"id_menu":5,"count":1}]	9511	delivery	5	13
119954	2020-08-17 16:15:39	2020-08-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	45703	delivery	5	28
119955	2020-08-17 16:17:26	2020-08-17	17	[{"id_menu":4,"count":1}]	39611	delivery	5	22
119956	2020-08-17 16:21:50	2020-08-17	17	[{"id_menu":4,"count":1}]	32289	delivery	5	22
119957	2020-08-17 16:28:13	2020-08-17	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	36290	delivery	5	34
119958	2020-08-17 16:31:03	2020-08-17	12	[{"id_menu":3,"count":1}]	45573	pick-up	0	12
119959	2020-08-17 16:31:41	2020-08-17	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	36839	pick-up	0	26
119960	2020-08-17 16:32:09	2020-08-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	45760	delivery	5	23
119961	2020-08-17 16:37:29	2020-08-17	9	[{"id_menu":7,"count":1}]	30660	delivery	5	14
119962	2020-08-17 16:37:53	2020-08-17	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	45547	delivery	5	39
119963	2020-08-17 16:38:59	2020-08-17	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2571	delivery	5	34
119964	2020-08-17 16:48:21	2020-08-17	9	[{"id_menu":7,"count":1}]	45712	delivery	5	14
119965	2020-08-17 16:50:10	2020-08-17	9	[{"id_menu":6,"count":2}]	35850	delivery	5	14
119966	2020-08-17 16:59:30	2020-08-17	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	32465	delivery	5	26
119967	2020-08-17 17:00:42	2020-08-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32968	delivery	5	23
119968	2020-08-17 17:01:51	2020-08-17	17	[{"id_menu":4,"count":1}]	35397	delivery	5	22
119969	2020-08-17 17:04:17	2020-08-17	14	[{"id_menu":2,"count":1}]	17752	delivery	5	19
119970	2020-08-17 17:04:19	2020-08-17	9	[{"id_menu":7,"count":1}]	34729	delivery	5	14
119971	2020-08-17 17:04:28	2020-08-17	9	[{"id_menu":6,"count":1}]	14124	delivery	5	14
119972	2020-08-17 17:06:39	2020-08-17	14	[{"id_menu":2,"count":1}]	45571	delivery	5	19
119973	2020-08-17 17:07:13	2020-08-17	9	[{"id_menu":6,"count":1}]	4305	delivery	5	14
119974	2020-08-17 17:09:12	2020-08-17	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32599	delivery	5	43
119975	2020-08-17 17:12:32	2020-08-17	14	[{"id_menu":2,"count":1}]	7591	pick-up	0	14
119976	2020-08-17 17:13:14	2020-08-17	14	[{"id_menu":2,"count":1}]	5813	delivery	5	19
119977	2020-08-17 17:13:29	2020-08-17	14	[{"id_menu":2,"count":1}]	41741	delivery	5	19
119978	2020-08-17 17:15:38	2020-08-17	9	[{"id_menu":7,"count":1}]	11501	delivery	5	14
119979	2020-08-17 17:17:47	2020-08-17	12	[{"id_menu":3,"count":1}]	45739	delivery	5	17
119980	2020-08-17 17:19:33	2020-08-17	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	10188	delivery	5	36
119981	2020-08-17 17:20:07	2020-08-17	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	18494	delivery	5	31
119982	2020-08-17 17:22:08	2020-08-17	14	[{"id_menu":2,"count":1}]	45541	delivery	5	19
119983	2020-08-17 17:24:20	2020-08-17	8	[{"id_menu":5,"count":1}]	37319	delivery	5	13
119984	2020-08-17 17:25:38	2020-08-17	9	[{"id_menu":7,"count":1}]	45788	delivery	5	14
119985	2020-08-17 17:28:26	2020-08-17	14	[{"id_menu":2,"count":1}]	14410	pick-up	0	14
119986	2020-08-17 17:29:50	2020-08-17	14	[{"id_menu":2,"count":1}]	45481	delivery	5	19
119987	2020-08-17 17:34:22	2020-08-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3132	pick-up	0	23
119988	2020-08-17 17:40:10	2020-08-17	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	45790	delivery	5	49
119989	2020-08-17 17:40:49	2020-08-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	13371	delivery	5	23
119990	2020-08-17 17:44:31	2020-08-17	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	29236	delivery	5	26
119991	2020-08-17 17:49:57	2020-08-17	8	[{"id_menu":5,"count":1}]	45729	delivery	5	13
119992	2020-08-17 17:52:13	2020-08-17	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	45598	delivery	5	42
119993	2020-08-17 17:52:57	2020-08-17	9	[{"id_menu":6,"count":1}]	37273	pick-up	0	9
119994	2020-08-17 17:57:24	2020-08-17	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	39526	delivery	5	22
119995	2020-08-17 17:58:42	2020-08-17	17	[{"id_menu":4,"count":1}]	44732	pick-up	0	17
119996	2020-08-17 18:01:26	2020-08-17	12	[{"id_menu":1,"count":1}]	39049	delivery	5	17
119997	2020-08-17 18:06:57	2020-08-17	9	[{"id_menu":6,"count":1}]	45738	delivery	5	14
119998	2020-08-17 18:10:13	2020-08-17	8	[{"id_menu":5,"count":1}]	38747	delivery	5	13
119999	2020-08-17 18:12:24	2020-08-17	9	[{"id_menu":6,"count":1}]	30960	delivery	5	14
120000	2020-08-17 18:13:32	2020-08-17	12	[{"id_menu":3,"count":1}]	45642	pick-up	0	12
120001	2020-08-17 18:15:01	2020-08-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	8946	delivery	5	28
120002	2020-08-17 18:15:17	2020-08-17	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	45569	delivery	5	26
120003	2020-08-17 18:17:31	2020-08-17	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	27804	pick-up	0	26
120004	2020-08-17 18:20:50	2020-08-17	12	[{"id_menu":1,"count":1}]	7690	delivery	5	17
120005	2020-08-17 18:32:20	2020-08-17	17	[{"id_menu":4,"count":1}]	45743	delivery	5	22
120006	2020-08-17 18:32:57	2020-08-17	9	[{"id_menu":7,"count":1}]	45769	delivery	5	14
120007	2020-08-17 18:34:30	2020-08-17	8	[{"id_menu":5,"count":1}]	24591	delivery	5	13
120008	2020-08-17 18:35:10	2020-08-17	9	[{"id_menu":6,"count":1}]	45704	delivery	5	14
120009	2020-08-17 18:40:50	2020-08-17	12	[{"id_menu":1,"count":1}]	45535	delivery	5	17
120010	2020-08-17 18:42:03	2020-08-17	9	[{"id_menu":7,"count":1}]	45618	delivery	5	14
120011	2020-08-17 18:43:03	2020-08-17	9	[{"id_menu":6,"count":1}]	45544	delivery	5	14
120012	2020-08-17 18:50:04	2020-08-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	16455	delivery	5	28
120013	2020-08-17 18:50:42	2020-08-17	8	[{"id_menu":5,"count":1}]	3616	delivery	5	13
120014	2020-08-17 18:56:55	2020-08-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	41506	delivery	5	28
120015	2020-08-17 18:57:11	2020-08-17	9	[{"id_menu":6,"count":1}]	45725	delivery	5	14
120016	2020-08-17 18:59:32	2020-08-17	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18840	delivery	5	22
120017	2020-08-17 19:00:42	2020-08-17	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	45641	delivery	5	25
120018	2020-08-17 19:01:02	2020-08-17	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	45588	delivery	5	26
120019	2020-08-17 19:01:26	2020-08-17	8	[{"id_menu":5,"count":1}]	25941	delivery	5	13
120020	2020-08-17 19:02:25	2020-08-17	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	45770	pick-up	0	29
120021	2020-08-17 19:05:39	2020-08-17	9	[{"id_menu":6,"count":1}]	45621	delivery	5	14
120022	2020-08-17 19:06:16	2020-08-17	12	[{"id_menu":3,"count":1}]	45682	delivery	5	17
120023	2020-08-17 19:16:33	2020-08-17	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27376	delivery	5	22
120024	2020-08-17 19:17:01	2020-08-17	9	[{"id_menu":6,"count":1}]	45747	delivery	5	14
120025	2020-08-17 19:18:50	2020-08-17	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	12225	delivery	5	31
120026	2020-08-17 19:19:26	2020-08-17	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	4124	delivery	5	26
120027	2020-08-17 19:19:43	2020-08-17	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	38739	delivery	5	37
120028	2020-08-17 19:19:58	2020-08-17	12	[{"id_menu":1,"count":1}]	678	delivery	5	17
120029	2020-08-17 19:24:43	2020-08-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	38339	delivery	5	23
120030	2020-08-17 19:24:59	2020-08-17	17	[{"id_menu":4,"count":1}]	45753	delivery	5	22
120031	2020-08-17 19:25:11	2020-08-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	964	delivery	5	23
120032	2020-08-17 19:27:39	2020-08-17	17	[{"id_menu":4,"count":1}]	3350	delivery	5	22
120033	2020-08-17 19:32:59	2020-08-17	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	45683	delivery	5	31
120034	2020-08-17 19:33:01	2020-08-17	17	[{"id_menu":4,"count":1}]	8411	delivery	5	22
120035	2020-08-17 19:33:15	2020-08-17	17	[{"id_menu":4,"count":1}]	29907	delivery	5	22
120036	2020-08-17 19:33:56	2020-08-17	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1844	pick-up	0	31
120037	2020-08-17 19:36:23	2020-08-17	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	9273	delivery	5	31
120038	2020-08-17 19:42:48	2020-08-17	14	[{"id_menu":2,"count":1}]	5354	delivery	5	19
120039	2020-08-17 19:43:02	2020-08-17	14	[{"id_menu":2,"count":2}]	45742	delivery	5	19
120040	2020-08-17 19:44:26	2020-08-17	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	45798	delivery	5	28
120041	2020-08-17 19:49:49	2020-08-17	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	39493	delivery	5	25
120042	2020-08-17 19:50:45	2020-08-17	14	[{"id_menu":2,"count":1}]	45550	delivery	5	19
120043	2020-08-17 19:50:47	2020-08-17	14	[{"id_menu":2,"count":1}]	3730	pick-up	0	14
120044	2020-08-17 19:51:03	2020-08-17	8	[{"id_menu":5,"count":1}]	33631	pick-up	0	8
120045	2020-08-17 19:52:58	2020-08-17	17	[{"id_menu":4,"count":1}]	29198	pick-up	0	17
120046	2020-08-17 19:56:04	2020-08-17	12	[{"id_menu":3,"count":1}]	45702	delivery	5	17
120047	2020-08-17 19:57:40	2020-08-17	12	[{"id_menu":3,"count":1}]	45679	delivery	5	17
120048	2020-08-17 20:02:59	2020-08-17	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	10308	delivery	5	26
120049	2020-08-17 20:03:07	2020-08-17	17	[{"id_menu":4,"count":1}]	45575	delivery	5	22
120050	2020-08-17 20:04:32	2020-08-17	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	4031	pick-up	0	43
120051	2020-08-17 20:05:43	2020-08-17	14	[{"id_menu":2,"count":1}]	20524	delivery	5	19
120052	2020-08-17 20:15:10	2020-08-17	9	[{"id_menu":7,"count":1}]	19931	pick-up	0	9
120053	2020-08-17 20:19:33	2020-08-17	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	29301	delivery	5	45
120054	2020-08-17 20:21:12	2020-08-17	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	5420	delivery	5	34
120055	2020-08-17 20:21:15	2020-08-17	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39500	delivery	5	37
120056	2020-08-17 20:23:00	2020-08-17	9	[{"id_menu":6,"count":2}]	45654	delivery	5	14
120057	2020-08-17 20:27:06	2020-08-17	9	[{"id_menu":7,"count":2}]	45694	delivery	5	14
120058	2020-08-17 20:27:18	2020-08-17	12	[{"id_menu":1,"count":1}]	8262	delivery	5	17
120059	2020-08-17 20:29:31	2020-08-17	17	[{"id_menu":4,"count":1}]	7387	delivery	5	22
120060	2020-08-17 20:33:31	2020-08-17	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13729	delivery	5	40
120061	2020-08-17 20:36:52	2020-08-17	14	[{"id_menu":2,"count":1}]	45740	delivery	5	19
120062	2020-08-17 20:37:16	2020-08-17	9	[{"id_menu":6,"count":1}]	42817	delivery	5	14
120063	2020-08-17 20:41:39	2020-08-17	12	[{"id_menu":3,"count":1}]	14925	delivery	5	17
120064	2020-08-17 20:43:12	2020-08-17	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	931	pick-up	0	31
120065	2020-08-17 20:43:33	2020-08-17	9	[{"id_menu":7,"count":1}]	30595	delivery	5	14
120066	2020-08-17 20:44:35	2020-08-17	14	[{"id_menu":2,"count":1}]	33708	pick-up	0	14
120067	2020-08-17 20:45:17	2020-08-17	9	[{"id_menu":6,"count":1}]	45051	delivery	5	14
120068	2020-08-17 20:48:17	2020-08-17	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	45690	delivery	5	43
120069	2020-08-17 20:48:44	2020-08-17	9	[{"id_menu":6,"count":1}]	5288	delivery	5	14
120070	2020-08-17 20:52:25	2020-08-17	14	[{"id_menu":2,"count":1}]	34226	delivery	5	19
120071	2020-08-17 20:54:26	2020-08-17	12	[{"id_menu":1,"count":1}]	45570	delivery	5	17
120072	2020-08-17 20:55:25	2020-08-17	14	[{"id_menu":2,"count":1}]	1289	delivery	5	19
120073	2020-08-17 20:57:03	2020-08-17	14	[{"id_menu":2,"count":1}]	42690	delivery	5	19
120074	2020-08-17 21:00:46	2020-08-17	9	[{"id_menu":6,"count":1}]	45557	delivery	5	14
120075	2020-08-17 21:01:26	2020-08-17	12	[{"id_menu":3,"count":1}]	2056	pick-up	0	12
120076	2020-08-17 21:04:12	2020-08-17	9	[{"id_menu":6,"count":1}]	45523	delivery	5	14
120077	2020-08-17 21:08:42	2020-08-17	9	[{"id_menu":7,"count":2}]	38969	delivery	5	14
120078	2020-08-17 21:09:18	2020-08-17	14	[{"id_menu":2,"count":1}]	8518	delivery	5	19
120079	2020-08-17 21:11:07	2020-08-17	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	45667	delivery	5	45
120080	2020-08-17 21:11:14	2020-08-17	12	[{"id_menu":1,"count":1}]	4874	pick-up	0	12
120081	2020-08-17 21:12:40	2020-08-17	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	29477	delivery	5	39
120082	2020-08-17 21:19:37	2020-08-17	12	[{"id_menu":3,"count":1}]	30199	delivery	5	17
120083	2020-08-17 21:23:17	2020-08-17	12	[{"id_menu":1,"count":1}]	9717	delivery	5	17
120084	2020-08-17 21:23:53	2020-08-17	14	[{"id_menu":2,"count":1}]	19270	pick-up	0	14
120085	2020-08-17 21:28:55	2020-08-17	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	22332	delivery	5	45
120086	2020-08-17 21:34:41	2020-08-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14896	delivery	5	23
120087	2020-08-17 21:37:45	2020-08-17	8	[{"id_menu":5,"count":1}]	44954	pick-up	0	8
120088	2020-08-17 21:47:24	2020-08-17	9	[{"id_menu":7,"count":1}]	39394	delivery	5	14
120089	2020-08-17 21:48:44	2020-08-17	17	[{"id_menu":4,"count":1}]	9181	delivery	5	22
120090	2020-08-17 21:51:53	2020-08-17	14	[{"id_menu":2,"count":1}]	45776	delivery	5	19
120091	2020-08-17 21:53:00	2020-08-17	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1306	delivery	5	22
120092	2020-08-17 21:57:53	2020-08-17	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	45506	delivery	5	37
120093	2020-08-17 21:59:20	2020-08-17	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	45648	delivery	5	37
120094	2020-08-17 22:00:42	2020-08-17	17	[{"id_menu":4,"count":1}]	45628	delivery	5	22
120095	2020-08-17 22:00:49	2020-08-17	14	[{"id_menu":2,"count":1}]	3994	delivery	5	19
120096	2020-08-17 22:06:54	2020-08-17	12	[{"id_menu":3,"count":1}]	45632	delivery	5	17
120097	2020-08-17 22:08:06	2020-08-17	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	43211	delivery	5	28
120098	2020-08-17 22:10:11	2020-08-17	9	[{"id_menu":6,"count":1}]	21690	delivery	5	14
120099	2020-08-17 22:13:56	2020-08-17	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	33388	delivery	5	31
120100	2020-08-17 22:14:54	2020-08-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44158	pick-up	0	18
120101	2020-08-17 22:19:51	2020-08-17	8	[{"id_menu":5,"count":1}]	7686	delivery	5	13
120102	2020-08-17 22:20:29	2020-08-17	17	[{"id_menu":4,"count":1}]	45536	delivery	5	22
120103	2020-08-17 22:22:01	2020-08-17	9	[{"id_menu":6,"count":1}]	42441	delivery	5	14
120104	2020-08-17 22:25:10	2020-08-17	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	45736	delivery	5	34
120105	2020-08-17 22:25:51	2020-08-17	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	45734	delivery	5	48
120106	2020-08-17 22:30:47	2020-08-17	8	[{"id_menu":5,"count":1}]	22277	delivery	5	13
120107	2020-08-17 22:34:37	2020-08-17	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":3}]	38466	delivery	5	23
120108	2020-08-17 22:35:50	2020-08-17	17	[{"id_menu":4,"count":1}]	5755	delivery	5	22
120109	2020-08-17 22:38:55	2020-08-17	12	[{"id_menu":1,"count":1}]	5612	delivery	5	17
120110	2020-08-17 22:40:01	2020-08-17	9	[{"id_menu":6,"count":1}]	45727	delivery	5	14
120111	2020-08-17 22:45:10	2020-08-17	8	[{"id_menu":5,"count":1}]	45519	delivery	5	13
120112	2020-08-17 22:45:45	2020-08-17	9	[{"id_menu":6,"count":3}]	45686	delivery	5	14
120113	2020-08-17 23:03:27	2020-08-17	9	[{"id_menu":7,"count":1}]	4060	delivery	5	14
120114	2020-08-17 23:04:45	2020-08-17	8	[{"id_menu":5,"count":3}]	45508	delivery	5	13
120115	2020-08-17 23:05:16	2020-08-17	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27199	delivery	5	31
120116	2020-08-17 23:06:08	2020-08-17	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	45613	delivery	5	43
120117	2020-08-17 23:07:50	2020-08-17	9	[{"id_menu":7,"count":1}]	45691	delivery	5	14
120118	2020-08-17 23:08:01	2020-08-17	12	[{"id_menu":1,"count":1}]	45572	delivery	5	17
120119	2020-08-17 23:08:15	2020-08-17	23	[{"id_menu":2,"count":3},{"id_menu":7,"count":1}]	8489	delivery	5	28
120120	2020-08-17 23:16:00	2020-08-17	14	[{"id_menu":2,"count":1}]	36952	delivery	5	19
120121	2020-08-17 23:23:01	2020-08-17	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	44867	delivery	5	44
120122	2020-08-17 23:25:06	2020-08-17	9	[{"id_menu":6,"count":1}]	18500	delivery	5	14
120123	2020-08-17 23:26:39	2020-08-17	9	[{"id_menu":6,"count":1}]	45539	delivery	5	14
120124	2020-08-17 23:27:33	2020-08-17	9	[{"id_menu":7,"count":1}]	10441	pick-up	0	9
120125	2020-08-17 23:28:10	2020-08-17	14	[{"id_menu":2,"count":1}]	38219	delivery	5	19
120126	2020-08-17 23:29:35	2020-08-17	14	[{"id_menu":2,"count":1}]	8363	pick-up	0	14
120127	2020-08-17 23:32:29	2020-08-17	17	[{"id_menu":4,"count":1}]	17641	pick-up	0	17
120128	2020-08-17 23:43:20	2020-08-17	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15594	pick-up	0	26
120129	2020-08-17 23:45:40	2020-08-17	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	45669	delivery	5	38
120130	2020-08-17 23:50:07	2020-08-17	17	[{"id_menu":4,"count":1}]	45643	delivery	5	22
120131	2020-08-17 23:50:44	2020-08-17	8	[{"id_menu":5,"count":1}]	27135	delivery	5	13
120132	2020-08-17 23:52:19	2020-08-17	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1985	delivery	5	34
120133	2020-08-17 23:53:16	2020-08-17	14	[{"id_menu":2,"count":1}]	2283	pick-up	0	14
120134	2020-08-17 23:53:57	2020-08-17	14	[{"id_menu":2,"count":1}]	45595	delivery	5	19
120135	2020-08-17 23:54:14	2020-08-17	12	[{"id_menu":3,"count":1}]	2333	pick-up	0	12
120136	2020-08-17 23:56:47	2020-08-17	17	[{"id_menu":4,"count":1}]	37247	pick-up	0	17
120137	2020-08-17 23:58:11	2020-08-17	14	[{"id_menu":2,"count":1}]	21063	delivery	5	19
120138	2020-08-18 00:05:03	2020-08-18	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	45884	delivery	5	40
120139	2020-08-18 00:06:01	2020-08-18	9	[{"id_menu":6,"count":1}]	46015	delivery	5	14
120140	2020-08-18 00:06:23	2020-08-18	9	[{"id_menu":7,"count":1}]	45963	delivery	5	14
120141	2020-08-18 00:09:00	2020-08-18	14	[{"id_menu":2,"count":1}]	20711	delivery	5	19
120142	2020-08-18 00:13:00	2020-08-18	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	45838	delivery	5	26
120143	2020-08-18 00:14:57	2020-08-18	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	13497	pick-up	0	21
120144	2020-08-18 00:18:18	2020-08-18	14	[{"id_menu":2,"count":1}]	41316	pick-up	0	14
120145	2020-08-18 00:23:44	2020-08-18	12	[{"id_menu":3,"count":1}]	27544	pick-up	0	12
120146	2020-08-18 00:26:22	2020-08-18	17	[{"id_menu":4,"count":1}]	25226	pick-up	0	17
120147	2020-08-18 00:28:06	2020-08-18	12	[{"id_menu":1,"count":1}]	32129	delivery	5	17
120148	2020-08-18 00:30:58	2020-08-18	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	34257	delivery	5	36
120149	2020-08-18 00:32:31	2020-08-18	9	[{"id_menu":6,"count":1}]	19386	delivery	5	14
120150	2020-08-18 00:34:04	2020-08-18	9	[{"id_menu":7,"count":1}]	30000	pick-up	0	9
120151	2020-08-18 00:35:14	2020-08-18	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	46018	delivery	5	45
120152	2020-08-18 00:42:29	2020-08-18	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17862	delivery	5	45
120153	2020-08-18 00:43:27	2020-08-18	9	[{"id_menu":7,"count":1}]	34704	delivery	5	14
120154	2020-08-18 00:44:07	2020-08-18	8	[{"id_menu":5,"count":1}]	38326	delivery	5	13
120155	2020-08-18 00:46:06	2020-08-18	17	[{"id_menu":4,"count":1}]	45868	delivery	5	22
120156	2020-08-18 00:46:16	2020-08-18	14	[{"id_menu":2,"count":1}]	5136	delivery	5	19
120157	2020-08-18 00:49:14	2020-08-18	8	[{"id_menu":5,"count":1}]	45841	delivery	5	13
120158	2020-08-18 00:49:44	2020-08-18	8	[{"id_menu":5,"count":1}]	39255	pick-up	0	8
120159	2020-08-18 00:53:35	2020-08-18	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24718	pick-up	0	17
120160	2020-08-18 00:55:00	2020-08-18	9	[{"id_menu":7,"count":2}]	32886	delivery	5	14
120161	2020-08-18 00:58:30	2020-08-18	8	[{"id_menu":5,"count":1}]	9622	delivery	5	13
120162	2020-08-18 00:59:34	2020-08-18	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	11300	delivery	5	25
120163	2020-08-18 01:02:40	2020-08-18	8	[{"id_menu":5,"count":1}]	7190	pick-up	0	8
120164	2020-08-18 01:10:14	2020-08-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	45859	delivery	5	23
120165	2020-08-18 01:11:14	2020-08-18	9	[{"id_menu":7,"count":1}]	45829	delivery	5	14
120166	2020-08-18 01:12:36	2020-08-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	13326	delivery	5	28
120167	2020-08-18 01:16:43	2020-08-18	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	8098	pick-up	0	20
120168	2020-08-18 01:19:52	2020-08-18	8	[{"id_menu":5,"count":1}]	45818	delivery	5	13
120169	2020-08-18 01:23:05	2020-08-18	9	[{"id_menu":6,"count":1}]	21770	delivery	5	14
120170	2020-08-18 01:23:36	2020-08-18	43	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2526	pick-up	0	43
120171	2020-08-18 01:26:58	2020-08-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":3}]	29757	delivery	5	28
120172	2020-08-18 01:29:43	2020-08-18	17	[{"id_menu":4,"count":1}]	4576	delivery	5	22
120173	2020-08-18 01:30:00	2020-08-18	14	[{"id_menu":2,"count":1}]	12384	delivery	5	19
120174	2020-08-18 01:34:36	2020-08-18	12	[{"id_menu":3,"count":1}]	30512	delivery	5	17
120175	2020-08-18 01:34:56	2020-08-18	12	[{"id_menu":3,"count":1}]	628	delivery	5	17
120176	2020-08-18 01:35:43	2020-08-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	45854	delivery	5	28
120177	2020-08-18 01:42:00	2020-08-18	9	[{"id_menu":6,"count":1}]	46001	delivery	5	14
120178	2020-08-18 01:45:24	2020-08-18	14	[{"id_menu":2,"count":1}]	19534	delivery	5	19
120179	2020-08-18 01:46:54	2020-08-18	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	46037	delivery	5	31
120180	2020-08-18 01:50:22	2020-08-18	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	13855	pick-up	0	34
120181	2020-08-18 01:50:28	2020-08-18	17	[{"id_menu":4,"count":1}]	16829	pick-up	0	17
120182	2020-08-18 01:52:09	2020-08-18	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	34266	delivery	5	31
120183	2020-08-18 02:06:00	2020-08-18	8	[{"id_menu":5,"count":1}]	45962	delivery	5	13
120184	2020-08-18 02:10:37	2020-08-18	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	45897	delivery	5	40
120185	2020-08-18 02:12:17	2020-08-18	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	45976	delivery	5	31
120186	2020-08-18 02:12:37	2020-08-18	17	[{"id_menu":4,"count":1}]	8048	pick-up	0	17
120187	2020-08-18 02:17:39	2020-08-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	13951	pick-up	0	23
120188	2020-08-18 02:21:53	2020-08-18	17	[{"id_menu":4,"count":1}]	46030	delivery	5	22
120189	2020-08-18 02:27:31	2020-08-18	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	8676	delivery	5	40
120190	2020-08-18 02:32:51	2020-08-18	12	[{"id_menu":3,"count":1}]	45833	delivery	5	17
120191	2020-08-18 02:33:31	2020-08-18	9	[{"id_menu":6,"count":1}]	24918	delivery	5	14
120192	2020-08-18 02:34:25	2020-08-18	8	[{"id_menu":5,"count":1}]	25795	pick-up	0	8
120193	2020-08-18 02:37:10	2020-08-18	17	[{"id_menu":4,"count":1}]	26373	pick-up	0	17
120194	2020-08-18 02:37:28	2020-08-18	9	[{"id_menu":6,"count":1}]	22967	delivery	5	14
120195	2020-08-18 02:39:09	2020-08-18	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	46011	delivery	5	22
120196	2020-08-18 02:40:02	2020-08-18	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	45873	delivery	5	39
120197	2020-08-18 02:45:37	2020-08-18	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	45978	delivery	5	39
120198	2020-08-18 02:54:33	2020-08-18	14	[{"id_menu":2,"count":1}]	32711	pick-up	0	14
120199	2020-08-18 02:57:02	2020-08-18	14	[{"id_menu":2,"count":1}]	45939	delivery	5	19
120200	2020-08-18 02:57:42	2020-08-18	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	29847	delivery	5	36
120201	2020-08-18 02:58:07	2020-08-18	14	[{"id_menu":2,"count":1}]	2052	pick-up	0	14
120202	2020-08-18 02:59:01	2020-08-18	12	[{"id_menu":3,"count":1}]	33152	delivery	5	17
120203	2020-08-18 02:59:32	2020-08-18	12	[{"id_menu":1,"count":1}]	30976	delivery	5	17
120204	2020-08-18 02:59:40	2020-08-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	45899	delivery	5	28
120205	2020-08-18 03:00:17	2020-08-18	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31206	delivery	5	31
120206	2020-08-18 03:02:08	2020-08-18	9	[{"id_menu":6,"count":1}]	3410	delivery	5	14
120207	2020-08-18 03:02:17	2020-08-18	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39280	delivery	5	31
120208	2020-08-18 03:08:18	2020-08-18	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	9175	delivery	5	26
120209	2020-08-18 03:08:23	2020-08-18	9	[{"id_menu":6,"count":1}]	40132	delivery	5	14
120210	2020-08-18 03:09:22	2020-08-18	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	44549	delivery	5	25
120211	2020-08-18 03:10:49	2020-08-18	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	45856	delivery	5	43
120212	2020-08-18 03:11:35	2020-08-18	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	18729	delivery	5	27
120213	2020-08-18 03:16:26	2020-08-18	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	2130	delivery	5	31
120214	2020-08-18 03:19:00	2020-08-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	45938	delivery	5	22
120215	2020-08-18 03:26:41	2020-08-18	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	45862	delivery	5	23
120216	2020-08-18 03:30:13	2020-08-18	14	[{"id_menu":2,"count":1}]	20592	delivery	5	19
120217	2020-08-18 03:33:20	2020-08-18	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	45949	delivery	5	35
120218	2020-08-18 03:33:22	2020-08-18	12	[{"id_menu":1,"count":1}]	31927	delivery	5	17
120219	2020-08-18 03:36:38	2020-08-18	12	[{"id_menu":3,"count":1}]	43812	delivery	5	17
120220	2020-08-18 03:38:14	2020-08-18	14	[{"id_menu":2,"count":1}]	46028	delivery	5	19
120221	2020-08-18 03:38:26	2020-08-18	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	45866	delivery	5	36
120222	2020-08-18 03:40:34	2020-08-18	12	[{"id_menu":1,"count":1}]	2466	delivery	5	17
120223	2020-08-18 03:49:01	2020-08-18	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7063	delivery	5	34
120224	2020-08-18 04:05:22	2020-08-18	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	13460	delivery	5	43
120225	2020-08-18 04:10:18	2020-08-18	17	[{"id_menu":4,"count":1}]	33829	delivery	5	22
120226	2020-08-18 04:11:27	2020-08-18	8	[{"id_menu":5,"count":1}]	31120	delivery	5	13
120227	2020-08-18 04:11:30	2020-08-18	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8390	delivery	5	54
120228	2020-08-18 04:13:14	2020-08-18	8	[{"id_menu":5,"count":1}]	45811	delivery	5	13
120229	2020-08-18 04:13:41	2020-08-18	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	30259	delivery	5	22
120230	2020-08-18 04:15:52	2020-08-18	12	[{"id_menu":3,"count":1}]	25975	pick-up	0	12
120231	2020-08-18 04:19:12	2020-08-18	17	[{"id_menu":4,"count":1}]	29134	pick-up	0	17
120232	2020-08-18 04:27:08	2020-08-18	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	14356	delivery	5	34
120233	2020-08-18 04:28:00	2020-08-18	9	[{"id_menu":7,"count":1}]	34466	delivery	5	14
120234	2020-08-18 04:28:13	2020-08-18	8	[{"id_menu":5,"count":1}]	35027	pick-up	0	8
120235	2020-08-18 04:29:45	2020-08-18	12	[{"id_menu":3,"count":1}]	44428	delivery	5	17
120236	2020-08-18 04:36:51	2020-08-18	8	[{"id_menu":5,"count":1}]	29740	delivery	5	13
120237	2020-08-18 04:40:10	2020-08-18	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24733	delivery	5	51
120238	2020-08-18 04:40:52	2020-08-18	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	39925	delivery	5	39
120239	2020-08-18 04:47:55	2020-08-18	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	46024	delivery	5	36
120240	2020-08-18 04:50:44	2020-08-18	9	[{"id_menu":7,"count":1}]	45961	delivery	5	14
120241	2020-08-18 04:50:50	2020-08-18	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	16044	delivery	5	36
120242	2020-08-18 04:52:30	2020-08-18	8	[{"id_menu":5,"count":1}]	14592	delivery	5	13
120243	2020-08-18 04:53:50	2020-08-18	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	42640	pick-up	0	21
120244	2020-08-18 05:01:28	2020-08-18	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	45917	delivery	5	34
120245	2020-08-18 05:02:10	2020-08-18	17	[{"id_menu":4,"count":1}]	4195	delivery	5	22
120246	2020-08-18 05:02:35	2020-08-18	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	41832	delivery	5	26
120247	2020-08-18 05:04:45	2020-08-18	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	45918	delivery	5	37
120248	2020-08-18 05:05:54	2020-08-18	12	[{"id_menu":1,"count":1}]	44	pick-up	0	12
120249	2020-08-18 05:07:18	2020-08-18	8	[{"id_menu":5,"count":1}]	30942	delivery	5	13
120250	2020-08-18 05:08:01	2020-08-18	8	[{"id_menu":5,"count":1}]	33782	delivery	5	13
120251	2020-08-18 05:08:07	2020-08-18	17	[{"id_menu":4,"count":1}]	45865	delivery	5	22
120252	2020-08-18 05:11:07	2020-08-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3546	delivery	5	23
120253	2020-08-18 05:13:16	2020-08-18	9	[{"id_menu":7,"count":2}]	33243	delivery	5	14
120254	2020-08-18 05:14:55	2020-08-18	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	36569	delivery	5	31
120255	2020-08-18 05:20:06	2020-08-18	8	[{"id_menu":5,"count":1}]	1694	pick-up	0	8
120256	2020-08-18 05:22:26	2020-08-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	45987	pick-up	0	23
120257	2020-08-18 05:22:42	2020-08-18	14	[{"id_menu":2,"count":1}]	802	pick-up	0	14
120258	2020-08-18 05:22:55	2020-08-18	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17337	delivery	5	31
120259	2020-08-18 05:25:51	2020-08-18	14	[{"id_menu":2,"count":1}]	2619	pick-up	0	14
120260	2020-08-18 05:26:48	2020-08-18	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	46021	delivery	5	26
120261	2020-08-18 05:31:24	2020-08-18	14	[{"id_menu":2,"count":1}]	766	pick-up	0	14
120262	2020-08-18 05:35:56	2020-08-18	9	[{"id_menu":6,"count":2}]	42372	delivery	5	14
120263	2020-08-18 05:41:24	2020-08-18	9	[{"id_menu":6,"count":1}]	37565	delivery	5	14
120264	2020-08-18 05:44:11	2020-08-18	9	[{"id_menu":6,"count":1}]	11807	delivery	5	14
120265	2020-08-18 05:49:25	2020-08-18	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	46017	delivery	5	26
120266	2020-08-18 05:50:29	2020-08-18	9	[{"id_menu":7,"count":1}]	2176	delivery	5	14
120267	2020-08-18 05:52:04	2020-08-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	40831	delivery	5	28
120268	2020-08-18 05:56:36	2020-08-18	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	45839	delivery	5	40
120269	2020-08-18 05:59:23	2020-08-18	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	18852	delivery	5	29
120270	2020-08-18 06:00:43	2020-08-18	9	[{"id_menu":6,"count":1}]	45831	pick-up	0	9
120271	2020-08-18 06:01:11	2020-08-18	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	38138	delivery	5	34
120272	2020-08-18 06:02:04	2020-08-18	8	[{"id_menu":5,"count":1}]	29854	delivery	5	13
120273	2020-08-18 06:02:52	2020-08-18	14	[{"id_menu":2,"count":1}]	31738	pick-up	0	14
120274	2020-08-18 06:04:16	2020-08-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	45993	delivery	5	28
120275	2020-08-18 06:06:44	2020-08-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	26739	pick-up	0	23
120276	2020-08-18 06:06:55	2020-08-18	9	[{"id_menu":7,"count":1}]	6769	pick-up	0	9
120277	2020-08-18 06:07:58	2020-08-18	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	33899	delivery	5	39
120278	2020-08-18 06:11:12	2020-08-18	9	[{"id_menu":6,"count":1}]	45317	delivery	5	14
120279	2020-08-18 06:11:41	2020-08-18	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	45869	delivery	5	34
120280	2020-08-18 06:13:23	2020-08-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	44223	pick-up	0	23
120281	2020-08-18 06:14:30	2020-08-18	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	15101	delivery	5	31
120282	2020-08-18 06:20:09	2020-08-18	8	[{"id_menu":5,"count":1}]	43243	delivery	5	13
120283	2020-08-18 06:21:37	2020-08-18	9	[{"id_menu":7,"count":1}]	232	pick-up	0	9
120284	2020-08-18 06:22:36	2020-08-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21430	delivery	5	23
120285	2020-08-18 06:23:30	2020-08-18	9	[{"id_menu":7,"count":1}]	45853	pick-up	0	9
120286	2020-08-18 06:25:25	2020-08-18	8	[{"id_menu":5,"count":1}]	1432	pick-up	0	8
120287	2020-08-18 06:26:35	2020-08-18	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15313	delivery	5	46
120288	2020-08-18 06:28:06	2020-08-18	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	7604	delivery	5	27
120289	2020-08-18 06:29:20	2020-08-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25274	delivery	5	23
120290	2020-08-18 06:33:03	2020-08-18	12	[{"id_menu":1,"count":1}]	6678	delivery	5	17
120291	2020-08-18 06:35:00	2020-08-18	9	[{"id_menu":6,"count":1}]	45954	delivery	5	14
120292	2020-08-18 06:35:48	2020-08-18	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	45941	delivery	5	27
120293	2020-08-18 06:37:19	2020-08-18	9	[{"id_menu":6,"count":1}]	45850	delivery	5	14
120294	2020-08-18 06:40:59	2020-08-18	17	[{"id_menu":4,"count":1}]	46023	delivery	5	22
120295	2020-08-18 06:42:59	2020-08-18	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	45891	delivery	5	26
120296	2020-08-18 06:44:19	2020-08-18	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	25190	pick-up	0	31
120297	2020-08-18 06:46:13	2020-08-18	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	33037	delivery	5	40
120298	2020-08-18 06:46:24	2020-08-18	9	[{"id_menu":7,"count":1}]	43606	pick-up	0	9
120299	2020-08-18 06:46:46	2020-08-18	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	32403	delivery	5	25
120300	2020-08-18 06:47:05	2020-08-18	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	45965	delivery	5	52
120301	2020-08-18 06:48:01	2020-08-18	8	[{"id_menu":5,"count":1}]	23099	delivery	5	13
120302	2020-08-18 06:49:01	2020-08-18	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	45977	delivery	5	28
120303	2020-08-18 06:49:11	2020-08-18	12	[{"id_menu":3,"count":1}]	23040	pick-up	0	12
120304	2020-08-18 06:49:24	2020-08-18	17	[{"id_menu":4,"count":1}]	45803	delivery	5	22
120305	2020-08-18 06:50:48	2020-08-18	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8240	pick-up	0	17
120306	2020-08-18 06:53:17	2020-08-18	8	[{"id_menu":5,"count":1}]	19628	delivery	5	13
120307	2020-08-18 06:54:14	2020-08-18	8	[{"id_menu":5,"count":1}]	35464	delivery	5	13
120308	2020-08-18 06:55:59	2020-08-18	9	[{"id_menu":7,"count":1}]	15794	delivery	5	14
120309	2020-08-18 06:56:52	2020-08-18	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19511	delivery	5	47
120310	2020-08-18 06:57:17	2020-08-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14539	delivery	5	23
120311	2020-08-18 06:57:38	2020-08-18	8	[{"id_menu":5,"count":1}]	45921	delivery	5	13
120312	2020-08-18 07:00:49	2020-08-18	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	45163	delivery	5	36
120313	2020-08-18 07:03:33	2020-08-18	9	[{"id_menu":7,"count":2}]	42773	delivery	5	14
120314	2020-08-18 07:03:35	2020-08-18	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	33476	delivery	5	26
120315	2020-08-18 07:04:36	2020-08-18	9	[{"id_menu":7,"count":1}]	46020	delivery	5	14
120316	2020-08-18 07:06:23	2020-08-18	14	[{"id_menu":2,"count":1}]	5626	delivery	5	19
120317	2020-08-18 07:08:01	2020-08-18	9	[{"id_menu":7,"count":1}]	29931	delivery	5	14
120318	2020-08-18 07:11:43	2020-08-18	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	45940	delivery	5	22
120319	2020-08-18 07:12:53	2020-08-18	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	45912	delivery	5	27
120320	2020-08-18 07:13:14	2020-08-18	17	[{"id_menu":4,"count":1}]	34301	delivery	5	22
120321	2020-08-18 07:16:59	2020-08-18	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	31441	delivery	5	26
120322	2020-08-18 07:19:40	2020-08-18	9	[{"id_menu":6,"count":2}]	43075	delivery	5	14
120323	2020-08-18 07:22:00	2020-08-18	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13422	delivery	5	36
120324	2020-08-18 07:22:23	2020-08-18	17	[{"id_menu":4,"count":1}]	45236	delivery	5	22
120325	2020-08-18 07:28:12	2020-08-18	9	[{"id_menu":6,"count":1}]	28731	delivery	5	14
120326	2020-08-18 07:30:06	2020-08-18	14	[{"id_menu":2,"count":1}]	45887	pick-up	0	14
120327	2020-08-18 07:37:35	2020-08-18	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	568	delivery	5	43
120328	2020-08-18 07:37:37	2020-08-18	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	24618	delivery	5	40
120329	2020-08-18 07:37:55	2020-08-18	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	9236	delivery	5	36
120330	2020-08-18 07:39:56	2020-08-18	9	[{"id_menu":6,"count":1}]	23835	delivery	5	14
120331	2020-08-18 07:42:37	2020-08-18	17	[{"id_menu":4,"count":1}]	1314	pick-up	0	17
120332	2020-08-18 07:42:48	2020-08-18	9	[{"id_menu":6,"count":1}]	45871	delivery	5	14
120333	2020-08-18 07:43:04	2020-08-18	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	45807	delivery	5	52
120334	2020-08-18 07:44:25	2020-08-18	14	[{"id_menu":2,"count":1}]	3776	delivery	5	19
120335	2020-08-18 07:47:09	2020-08-18	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	45973	delivery	5	34
120336	2020-08-18 07:52:32	2020-08-18	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	37505	delivery	5	34
120337	2020-08-18 07:54:38	2020-08-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	22893	delivery	5	28
120338	2020-08-18 07:58:19	2020-08-18	14	[{"id_menu":2,"count":1}]	6301	pick-up	0	14
120339	2020-08-18 08:02:00	2020-08-18	9	[{"id_menu":7,"count":1}]	19366	delivery	5	14
120340	2020-08-18 08:09:04	2020-08-18	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	36200	delivery	5	48
120341	2020-08-18 08:10:21	2020-08-18	17	[{"id_menu":4,"count":1}]	16978	delivery	5	22
120342	2020-08-18 08:14:22	2020-08-18	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	33148	delivery	5	35
120343	2020-08-18 08:15:07	2020-08-18	17	[{"id_menu":4,"count":1}]	28847	delivery	5	22
120344	2020-08-18 08:17:36	2020-08-18	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	27937	delivery	5	40
120345	2020-08-18 08:18:20	2020-08-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	14556	delivery	5	28
120346	2020-08-18 08:18:22	2020-08-18	14	[{"id_menu":2,"count":1}]	45907	delivery	5	19
120347	2020-08-18 08:19:42	2020-08-18	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	27046	delivery	5	34
120348	2020-08-18 08:25:10	2020-08-18	9	[{"id_menu":6,"count":1}]	15054	delivery	5	14
120349	2020-08-18 08:26:16	2020-08-18	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18402	delivery	5	48
120350	2020-08-18 08:27:20	2020-08-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	45964	delivery	5	28
120351	2020-08-18 08:34:23	2020-08-18	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43829	delivery	5	52
120352	2020-08-18 08:34:35	2020-08-18	12	[{"id_menu":3,"count":1}]	6495	pick-up	0	12
120353	2020-08-18 08:35:18	2020-08-18	8	[{"id_menu":5,"count":1}]	1635	delivery	5	13
120354	2020-08-18 08:40:19	2020-08-18	12	[{"id_menu":1,"count":1}]	45943	delivery	5	17
120355	2020-08-18 08:43:46	2020-08-18	12	[{"id_menu":1,"count":1}]	29613	delivery	5	17
120356	2020-08-18 08:45:59	2020-08-18	17	[{"id_menu":4,"count":1}]	13731	pick-up	0	17
120357	2020-08-18 08:51:38	2020-08-18	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	15434	delivery	5	31
120358	2020-08-18 08:51:42	2020-08-18	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	45998	pick-up	0	29
120359	2020-08-18 08:52:05	2020-08-18	17	[{"id_menu":4,"count":1}]	15249	delivery	5	22
120360	2020-08-18 08:57:46	2020-08-18	9	[{"id_menu":7,"count":1}]	22214	pick-up	0	9
120361	2020-08-18 09:01:13	2020-08-18	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	21031	delivery	5	36
120362	2020-08-18 09:04:05	2020-08-18	17	[{"id_menu":4,"count":1}]	19602	pick-up	0	17
120363	2020-08-18 09:04:36	2020-08-18	8	[{"id_menu":5,"count":1}]	46009	delivery	5	13
120364	2020-08-18 09:06:50	2020-08-18	17	[{"id_menu":4,"count":1}]	15921	pick-up	0	17
120365	2020-08-18 09:06:51	2020-08-18	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39464	delivery	5	31
120366	2020-08-18 09:12:56	2020-08-18	9	[{"id_menu":7,"count":1}]	6806	delivery	5	14
120367	2020-08-18 09:14:13	2020-08-18	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	22516	pick-up	0	31
120368	2020-08-18 09:17:04	2020-08-18	12	[{"id_menu":3,"count":1}]	41851	delivery	5	17
120369	2020-08-18 09:19:53	2020-08-18	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6602	delivery	5	36
120370	2020-08-18 09:27:12	2020-08-18	9	[{"id_menu":6,"count":3}]	37165	delivery	5	14
120371	2020-08-18 09:32:01	2020-08-18	9	[{"id_menu":6,"count":1}]	39531	delivery	5	14
120372	2020-08-18 09:32:28	2020-08-18	12	[{"id_menu":3,"count":1}]	30068	delivery	5	17
120373	2020-08-18 09:32:43	2020-08-18	17	[{"id_menu":4,"count":1}]	2351	pick-up	0	17
120374	2020-08-18 09:35:32	2020-08-18	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	46019	delivery	5	57
120375	2020-08-18 09:40:00	2020-08-18	14	[{"id_menu":2,"count":1}]	10151	pick-up	0	14
120376	2020-08-18 09:55:12	2020-08-18	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	37015	delivery	5	53
120377	2020-08-18 09:58:42	2020-08-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	10205	delivery	5	28
120378	2020-08-18 09:59:06	2020-08-18	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	23551	delivery	5	39
120379	2020-08-18 10:01:18	2020-08-18	12	[{"id_menu":3,"count":1}]	27303	pick-up	0	12
120380	2020-08-18 10:03:26	2020-08-18	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	45910	delivery	5	27
120381	2020-08-18 10:03:59	2020-08-18	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	45966	delivery	5	34
120382	2020-08-18 10:06:24	2020-08-18	9	[{"id_menu":7,"count":1}]	45937	delivery	5	14
120383	2020-08-18 10:07:17	2020-08-18	9	[{"id_menu":6,"count":1}]	39031	delivery	5	14
120384	2020-08-18 10:10:18	2020-08-18	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	6015	delivery	5	40
120385	2020-08-18 10:10:22	2020-08-18	8	[{"id_menu":5,"count":1}]	22990	delivery	5	13
120386	2020-08-18 10:12:39	2020-08-18	9	[{"id_menu":7,"count":2}]	39539	delivery	5	14
120387	2020-08-18 10:12:46	2020-08-18	17	[{"id_menu":4,"count":1}]	608	pick-up	0	17
120388	2020-08-18 10:13:52	2020-08-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	35239	delivery	5	28
120389	2020-08-18 10:14:01	2020-08-18	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	45920	delivery	5	51
120390	2020-08-18 10:14:20	2020-08-18	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	25499	delivery	5	26
120391	2020-08-18 10:17:05	2020-08-18	17	[{"id_menu":4,"count":1}]	24981	delivery	5	22
120392	2020-08-18 10:17:27	2020-08-18	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	5272	delivery	5	30
120393	2020-08-18 10:18:49	2020-08-18	9	[{"id_menu":7,"count":1}]	43016	pick-up	0	9
120394	2020-08-18 10:19:10	2020-08-18	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	8234	delivery	5	23
120395	2020-08-18 10:23:06	2020-08-18	9	[{"id_menu":6,"count":1}]	45969	pick-up	0	9
120396	2020-08-18 10:23:51	2020-08-18	8	[{"id_menu":5,"count":1}]	45908	delivery	5	13
120397	2020-08-18 10:24:07	2020-08-18	9	[{"id_menu":7,"count":1}]	44157	delivery	5	14
120398	2020-08-18 10:24:54	2020-08-18	14	[{"id_menu":2,"count":2}]	45890	delivery	5	19
120399	2020-08-18 10:26:41	2020-08-18	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	45882	pick-up	0	21
120400	2020-08-18 10:37:17	2020-08-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	12089	delivery	5	23
120401	2020-08-18 10:37:21	2020-08-18	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	46008	delivery	5	43
120402	2020-08-18 10:41:45	2020-08-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	42315	delivery	5	28
120403	2020-08-18 10:46:02	2020-08-18	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	20198	delivery	5	34
120404	2020-08-18 10:46:09	2020-08-18	12	[{"id_menu":3,"count":1}]	45878	delivery	5	17
120405	2020-08-18 10:47:44	2020-08-18	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	37381	delivery	5	26
120406	2020-08-18 10:59:03	2020-08-18	9	[{"id_menu":6,"count":1}]	43730	delivery	5	14
120407	2020-08-18 11:09:22	2020-08-18	9	[{"id_menu":6,"count":1}]	847	pick-up	0	9
120408	2020-08-18 11:17:18	2020-08-18	9	[{"id_menu":6,"count":1}]	45852	delivery	5	14
120409	2020-08-18 11:19:38	2020-08-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5227	delivery	5	23
120410	2020-08-18 11:22:09	2020-08-18	8	[{"id_menu":5,"count":1}]	28662	delivery	5	13
120411	2020-08-18 11:24:16	2020-08-18	12	[{"id_menu":3,"count":1}]	22987	pick-up	0	12
120412	2020-08-18 11:30:54	2020-08-18	17	[{"id_menu":4,"count":1}]	44279	pick-up	0	17
120413	2020-08-18 11:35:51	2020-08-18	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	29570	delivery	5	31
120414	2020-08-18 11:40:21	2020-08-18	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	44208	delivery	5	27
120415	2020-08-18 11:41:46	2020-08-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11288	delivery	5	22
120416	2020-08-18 11:42:01	2020-08-18	14	[{"id_menu":2,"count":1}]	36193	pick-up	0	14
120417	2020-08-18 11:44:00	2020-08-18	12	[{"id_menu":3,"count":1}]	45800	delivery	5	17
120418	2020-08-18 11:45:39	2020-08-18	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	45930	delivery	5	40
120419	2020-08-18 11:47:33	2020-08-18	8	[{"id_menu":5,"count":1}]	28776	delivery	5	13
120420	2020-08-18 11:49:23	2020-08-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	41660	delivery	5	22
120421	2020-08-18 11:58:43	2020-08-18	17	[{"id_menu":4,"count":1}]	5286	pick-up	0	17
120422	2020-08-18 12:00:47	2020-08-18	12	[{"id_menu":3,"count":1}]	44212	delivery	5	17
120423	2020-08-18 12:01:23	2020-08-18	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	466	delivery	5	26
120424	2020-08-18 12:04:07	2020-08-18	9	[{"id_menu":6,"count":1}]	6790	delivery	5	14
120425	2020-08-18 12:06:10	2020-08-18	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	34535	delivery	5	45
120426	2020-08-18 12:07:14	2020-08-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	37071	delivery	5	28
120427	2020-08-18 12:11:21	2020-08-18	8	[{"id_menu":5,"count":1}]	41700	pick-up	0	8
120428	2020-08-18 12:11:24	2020-08-18	12	[{"id_menu":1,"count":1}]	18271	delivery	5	17
120429	2020-08-18 12:18:24	2020-08-18	9	[{"id_menu":7,"count":1}]	29988	delivery	5	14
120430	2020-08-18 12:19:48	2020-08-18	14	[{"id_menu":2,"count":1}]	45826	delivery	5	19
120431	2020-08-18 12:20:38	2020-08-18	17	[{"id_menu":4,"count":1}]	22726	delivery	5	22
120432	2020-08-18 12:20:41	2020-08-18	9	[{"id_menu":7,"count":1}]	19685	delivery	5	14
120433	2020-08-18 12:20:53	2020-08-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	45928	delivery	5	23
120434	2020-08-18 12:20:53	2020-08-18	8	[{"id_menu":5,"count":1}]	18952	delivery	5	13
120435	2020-08-18 12:21:43	2020-08-18	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8966	delivery	5	30
120436	2020-08-18 12:22:15	2020-08-18	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":3}]	20542	delivery	5	27
120437	2020-08-18 12:24:42	2020-08-18	9	[{"id_menu":7,"count":1}]	19444	delivery	5	14
120438	2020-08-18 12:28:58	2020-08-18	9	[{"id_menu":7,"count":1}]	23988	delivery	5	14
120439	2020-08-18 12:39:43	2020-08-18	12	[{"id_menu":3,"count":1}]	31936	delivery	5	17
120440	2020-08-18 12:42:13	2020-08-18	12	[{"id_menu":3,"count":1}]	3451	pick-up	0	12
120441	2020-08-18 12:44:44	2020-08-18	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	37366	delivery	5	22
120442	2020-08-18 12:45:22	2020-08-18	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	45836	delivery	5	27
120443	2020-08-18 12:47:59	2020-08-18	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	46016	delivery	5	40
120444	2020-08-18 12:50:32	2020-08-18	9	[{"id_menu":6,"count":1}]	39285	delivery	5	14
120445	2020-08-18 12:54:10	2020-08-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	45885	delivery	5	23
120446	2020-08-18 12:54:13	2020-08-18	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	25827	pick-up	0	35
120447	2020-08-18 12:55:15	2020-08-18	8	[{"id_menu":5,"count":1}]	4223	pick-up	0	8
120448	2020-08-18 12:57:40	2020-08-18	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3835	delivery	5	26
120449	2020-08-18 12:58:56	2020-08-18	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":2}]	45970	delivery	5	28
120450	2020-08-18 12:59:19	2020-08-18	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	154	pick-up	0	26
120451	2020-08-18 13:00:13	2020-08-18	12	[{"id_menu":1,"count":1}]	30154	pick-up	0	12
120452	2020-08-18 13:01:05	2020-08-18	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12003	delivery	5	43
120453	2020-08-18 13:02:24	2020-08-18	14	[{"id_menu":2,"count":1}]	46002	delivery	5	19
120454	2020-08-18 13:03:00	2020-08-18	8	[{"id_menu":5,"count":1}]	14077	delivery	5	13
120455	2020-08-18 13:05:07	2020-08-18	8	[{"id_menu":5,"count":1}]	1656	delivery	5	13
120456	2020-08-18 13:05:41	2020-08-18	12	[{"id_menu":1,"count":1}]	21982	pick-up	0	12
120457	2020-08-18 13:11:27	2020-08-18	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":2}]	19729	delivery	5	26
120458	2020-08-18 13:13:07	2020-08-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	46029	delivery	5	23
120459	2020-08-18 13:15:00	2020-08-18	14	[{"id_menu":2,"count":1}]	18917	delivery	5	19
120460	2020-08-18 13:18:24	2020-08-18	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1809	pick-up	0	22
120461	2020-08-18 13:18:43	2020-08-18	14	[{"id_menu":2,"count":1}]	44392	delivery	5	19
120462	2020-08-18 13:21:07	2020-08-18	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":2}]	45914	delivery	5	27
120463	2020-08-18 13:23:59	2020-08-18	9	[{"id_menu":6,"count":1}]	45923	delivery	5	14
120464	2020-08-18 13:27:22	2020-08-18	9	[{"id_menu":7,"count":1}]	27661	delivery	5	14
120465	2020-08-18 13:28:16	2020-08-18	8	[{"id_menu":5,"count":1}]	42347	delivery	5	13
120466	2020-08-18 13:37:16	2020-08-18	14	[{"id_menu":2,"count":1}]	45945	delivery	5	19
120467	2020-08-18 13:40:29	2020-08-18	9	[{"id_menu":6,"count":1}]	3781	delivery	5	14
120468	2020-08-18 13:41:02	2020-08-18	9	[{"id_menu":6,"count":1}]	42600	pick-up	0	9
120469	2020-08-18 13:43:30	2020-08-18	9	[{"id_menu":6,"count":1}]	5431	delivery	5	14
120470	2020-08-18 13:43:49	2020-08-18	9	[{"id_menu":7,"count":1}]	3869	delivery	5	14
120471	2020-08-18 13:47:11	2020-08-18	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	12912	pick-up	0	26
120472	2020-08-18 13:57:54	2020-08-18	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	45957	delivery	5	26
120473	2020-08-18 14:00:26	2020-08-18	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1582	delivery	5	40
120474	2020-08-18 14:01:36	2020-08-18	12	[{"id_menu":3,"count":1}]	45888	delivery	5	17
120475	2020-08-18 14:01:38	2020-08-18	14	[{"id_menu":2,"count":1}]	42317	delivery	5	19
120476	2020-08-18 14:02:17	2020-08-18	12	[{"id_menu":3,"count":1}]	1468	delivery	5	17
120477	2020-08-18 14:02:21	2020-08-18	9	[{"id_menu":7,"count":1}]	45995	delivery	5	14
120478	2020-08-18 14:08:09	2020-08-18	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	24778	delivery	5	31
120479	2020-08-18 14:11:27	2020-08-18	9	[{"id_menu":6,"count":1}]	2282	pick-up	0	9
120480	2020-08-18 14:14:46	2020-08-18	8	[{"id_menu":5,"count":1}]	45858	delivery	5	13
120481	2020-08-18 14:22:27	2020-08-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	33303	delivery	5	28
120482	2020-08-18 14:22:36	2020-08-18	9	[{"id_menu":7,"count":1}]	24534	pick-up	0	9
120483	2020-08-18 14:23:02	2020-08-18	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	35763	delivery	5	48
120484	2020-08-18 14:25:54	2020-08-18	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	45948	pick-up	0	40
120485	2020-08-18 14:33:28	2020-08-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	45967	delivery	5	22
120486	2020-08-18 14:38:50	2020-08-18	9	[{"id_menu":6,"count":1}]	46010	delivery	5	14
120487	2020-08-18 14:38:56	2020-08-18	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	12275	delivery	5	40
120488	2020-08-18 14:41:00	2020-08-18	9	[{"id_menu":6,"count":1}]	25808	delivery	5	14
120489	2020-08-18 14:43:51	2020-08-18	12	[{"id_menu":3,"count":1}]	536	pick-up	0	12
120490	2020-08-18 14:51:33	2020-08-18	9	[{"id_menu":7,"count":1}]	18409	pick-up	0	9
120491	2020-08-18 14:53:11	2020-08-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	46032	delivery	5	22
120492	2020-08-18 14:55:14	2020-08-18	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	42702	delivery	5	26
120493	2020-08-18 14:58:35	2020-08-18	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	44425	pick-up	0	29
120494	2020-08-18 15:01:30	2020-08-18	9	[{"id_menu":7,"count":1}]	44090	delivery	5	14
120495	2020-08-18 15:02:38	2020-08-18	14	[{"id_menu":2,"count":1}]	45835	delivery	5	19
120496	2020-08-18 15:07:28	2020-08-18	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	45860	delivery	5	42
120497	2020-08-18 15:11:36	2020-08-18	8	[{"id_menu":5,"count":1}]	18418	delivery	5	13
120498	2020-08-18 15:11:47	2020-08-18	14	[{"id_menu":2,"count":1}]	45816	delivery	5	19
120499	2020-08-18 15:12:14	2020-08-18	17	[{"id_menu":4,"count":1}]	45861	delivery	5	22
120500	2020-08-18 15:13:58	2020-08-18	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	45904	delivery	5	40
120501	2020-08-18 15:15:35	2020-08-18	12	[{"id_menu":3,"count":1}]	42050	pick-up	0	12
120502	2020-08-18 15:16:18	2020-08-18	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	45935	delivery	5	22
120503	2020-08-18 15:17:26	2020-08-18	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":2}]	40640	delivery	5	22
120504	2020-08-18 15:23:09	2020-08-18	9	[{"id_menu":6,"count":2}]	5627	delivery	5	14
120505	2020-08-18 15:30:19	2020-08-18	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	8981	pick-up	0	21
120506	2020-08-18 15:33:18	2020-08-18	12	[{"id_menu":1,"count":1}]	13858	delivery	5	17
120507	2020-08-18 15:35:13	2020-08-18	9	[{"id_menu":6,"count":1}]	10880	pick-up	0	9
120508	2020-08-18 15:42:45	2020-08-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13251	delivery	5	23
120509	2020-08-18 15:47:56	2020-08-18	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2995	delivery	5	26
120510	2020-08-18 15:48:50	2020-08-18	17	[{"id_menu":4,"count":1}]	39234	delivery	5	22
120511	2020-08-18 15:49:25	2020-08-18	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	45936	delivery	5	43
120512	2020-08-18 15:50:04	2020-08-18	12	[{"id_menu":3,"count":1}]	45867	delivery	5	17
120513	2020-08-18 15:50:16	2020-08-18	37	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	12808	pick-up	0	37
120514	2020-08-18 15:51:14	2020-08-18	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29504	delivery	5	39
120515	2020-08-18 15:52:25	2020-08-18	14	[{"id_menu":2,"count":1}]	46013	delivery	5	19
120516	2020-08-18 15:52:25	2020-08-18	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	33472	delivery	5	31
120517	2020-08-18 15:54:54	2020-08-18	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	25910	delivery	5	39
120518	2020-08-18 15:58:37	2020-08-18	8	[{"id_menu":5,"count":1}]	14386	delivery	5	13
120519	2020-08-18 16:00:03	2020-08-18	9	[{"id_menu":7,"count":1}]	3332	delivery	5	14
120520	2020-08-18 16:11:47	2020-08-18	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	43248	pick-up	0	24
120521	2020-08-18 16:13:37	2020-08-18	9	[{"id_menu":6,"count":1}]	5639	pick-up	0	9
120522	2020-08-18 16:15:12	2020-08-18	12	[{"id_menu":3,"count":1}]	3808	delivery	5	17
120523	2020-08-18 16:16:53	2020-08-18	12	[{"id_menu":3,"count":1}]	45815	delivery	5	17
120524	2020-08-18 16:18:00	2020-08-18	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	45979	delivery	5	35
120525	2020-08-18 16:20:02	2020-08-18	14	[{"id_menu":2,"count":1}]	45892	delivery	5	19
120526	2020-08-18 16:21:02	2020-08-18	9	[{"id_menu":6,"count":1}]	45924	pick-up	0	9
120527	2020-08-18 16:27:55	2020-08-18	12	[{"id_menu":1,"count":1}]	25867	delivery	5	17
120528	2020-08-18 16:28:33	2020-08-18	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	13881	delivery	5	30
120529	2020-08-18 16:29:24	2020-08-18	12	[{"id_menu":1,"count":1}]	11822	delivery	5	17
120530	2020-08-18 16:30:28	2020-08-18	12	[{"id_menu":3,"count":1}]	45840	delivery	5	17
120531	2020-08-18 16:38:31	2020-08-18	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	28087	delivery	5	36
120532	2020-08-18 16:41:54	2020-08-18	8	[{"id_menu":5,"count":1}]	46014	delivery	5	13
120533	2020-08-18 16:46:26	2020-08-18	14	[{"id_menu":2,"count":1}]	45893	pick-up	0	14
120534	2020-08-18 16:47:34	2020-08-18	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	7969	delivery	5	39
120535	2020-08-18 16:48:08	2020-08-18	12	[{"id_menu":3,"count":1}]	10593	pick-up	0	12
120536	2020-08-18 16:49:52	2020-08-18	8	[{"id_menu":5,"count":1}]	24987	delivery	5	13
120537	2020-08-18 16:50:54	2020-08-18	9	[{"id_menu":7,"count":1}]	35222	delivery	5	14
120538	2020-08-18 16:51:57	2020-08-18	12	[{"id_menu":3,"count":1}]	45990	delivery	5	17
120539	2020-08-18 16:52:14	2020-08-18	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	44684	delivery	5	28
120540	2020-08-18 16:58:42	2020-08-18	38	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	6983	delivery	5	43
120541	2020-08-18 17:03:33	2020-08-18	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	25010	delivery	5	36
120542	2020-08-18 17:07:51	2020-08-18	14	[{"id_menu":2,"count":1}]	12688	pick-up	0	14
120543	2020-08-18 17:09:41	2020-08-18	12	[{"id_menu":1,"count":1}]	45863	delivery	5	17
120544	2020-08-18 17:10:57	2020-08-18	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3760	delivery	5	26
120545	2020-08-18 17:13:12	2020-08-18	9	[{"id_menu":7,"count":1}]	43953	delivery	5	14
120546	2020-08-18 17:17:15	2020-08-18	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	19583	delivery	5	31
120547	2020-08-18 17:23:52	2020-08-18	9	[{"id_menu":6,"count":1}]	25801	pick-up	0	9
120548	2020-08-18 17:33:30	2020-08-18	14	[{"id_menu":2,"count":1}]	37438	delivery	5	19
120549	2020-08-18 17:43:13	2020-08-18	14	[{"id_menu":2,"count":1}]	45901	delivery	5	19
120550	2020-08-18 17:43:22	2020-08-18	9	[{"id_menu":6,"count":1}]	46034	delivery	5	14
120551	2020-08-18 17:46:20	2020-08-18	12	[{"id_menu":1,"count":1}]	45876	delivery	5	17
120552	2020-08-18 17:49:02	2020-08-18	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	12841	delivery	5	43
120553	2020-08-18 17:49:19	2020-08-18	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	12814	delivery	5	27
120554	2020-08-18 17:49:23	2020-08-18	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	44688	delivery	5	43
120555	2020-08-18 17:52:16	2020-08-18	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	12954	delivery	5	22
120556	2020-08-18 17:52:24	2020-08-18	9	[{"id_menu":6,"count":1}]	21303	delivery	5	14
120557	2020-08-18 17:53:59	2020-08-18	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	44853	delivery	5	34
120558	2020-08-18 17:55:18	2020-08-18	8	[{"id_menu":5,"count":1}]	46036	pick-up	0	8
120559	2020-08-18 17:55:42	2020-08-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32128	delivery	5	22
120560	2020-08-18 17:58:58	2020-08-18	9	[{"id_menu":7,"count":1}]	45824	delivery	5	14
120561	2020-08-18 18:04:08	2020-08-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	45922	delivery	5	22
120562	2020-08-18 18:06:29	2020-08-18	9	[{"id_menu":6,"count":1}]	19030	delivery	5	14
120563	2020-08-18 18:06:58	2020-08-18	17	[{"id_menu":4,"count":1}]	19277	delivery	5	22
120564	2020-08-18 18:07:00	2020-08-18	9	[{"id_menu":6,"count":1}]	4804	pick-up	0	9
120565	2020-08-18 18:10:28	2020-08-18	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	35660	delivery	5	25
120566	2020-08-18 18:11:22	2020-08-18	8	[{"id_menu":5,"count":1}]	45951	delivery	5	13
120567	2020-08-18 18:13:25	2020-08-18	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	46038	delivery	5	22
120568	2020-08-18 18:13:57	2020-08-18	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	34820	delivery	5	31
120569	2020-08-18 18:14:42	2020-08-18	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	18942	delivery	5	56
120570	2020-08-18 18:14:48	2020-08-18	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18979	delivery	5	39
120571	2020-08-18 18:15:22	2020-08-18	14	[{"id_menu":2,"count":1}]	45933	delivery	5	19
120572	2020-08-18 18:16:20	2020-08-18	9	[{"id_menu":7,"count":1}]	45913	delivery	5	14
120573	2020-08-18 18:18:29	2020-08-18	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	13555	pick-up	0	17
120574	2020-08-18 18:21:04	2020-08-18	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	13088	delivery	5	40
120575	2020-08-18 18:23:36	2020-08-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	14001	delivery	5	23
120576	2020-08-18 18:26:41	2020-08-18	12	[{"id_menu":1,"count":1}]	45911	delivery	5	17
120577	2020-08-18 18:29:54	2020-08-18	17	[{"id_menu":4,"count":1}]	10870	pick-up	0	17
120578	2020-08-18 18:33:02	2020-08-18	9	[{"id_menu":7,"count":1}]	45919	delivery	5	14
120579	2020-08-18 18:33:26	2020-08-18	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	28431	pick-up	0	29
120580	2020-08-18 18:35:01	2020-08-18	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	41810	delivery	5	36
120581	2020-08-18 18:35:03	2020-08-18	8	[{"id_menu":5,"count":1}]	36313	delivery	5	13
120582	2020-08-18 18:36:19	2020-08-18	9	[{"id_menu":6,"count":1}]	45348	delivery	5	14
120583	2020-08-18 18:37:31	2020-08-18	17	[{"id_menu":4,"count":1}]	45999	pick-up	0	17
120584	2020-08-18 18:39:07	2020-08-18	12	[{"id_menu":1,"count":1}]	45825	pick-up	0	12
120585	2020-08-18 18:39:18	2020-08-18	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	45950	delivery	5	40
120586	2020-08-18 18:40:01	2020-08-18	9	[{"id_menu":7,"count":1}]	10954	delivery	5	14
120587	2020-08-18 18:41:01	2020-08-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	46012	delivery	5	28
120588	2020-08-18 18:43:39	2020-08-18	8	[{"id_menu":5,"count":1}]	45808	pick-up	0	8
120589	2020-08-18 18:47:31	2020-08-18	12	[{"id_menu":1,"count":1}]	45827	pick-up	0	12
120590	2020-08-18 18:58:00	2020-08-18	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	43587	delivery	5	40
120591	2020-08-18 18:59:15	2020-08-18	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	36449	delivery	5	40
120592	2020-08-18 19:00:36	2020-08-18	9	[{"id_menu":6,"count":1}]	4062	pick-up	0	9
120593	2020-08-18 19:05:31	2020-08-18	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":3}]	31364	pick-up	0	21
120594	2020-08-18 19:07:00	2020-08-18	14	[{"id_menu":2,"count":1}]	20460	delivery	5	19
120595	2020-08-18 19:07:14	2020-08-18	12	[{"id_menu":1,"count":2}]	35034	delivery	5	17
120596	2020-08-18 19:09:42	2020-08-18	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	10019	pick-up	0	24
120597	2020-08-18 19:10:05	2020-08-18	9	[{"id_menu":7,"count":1}]	26565	pick-up	0	9
120598	2020-08-18 19:11:31	2020-08-18	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	45817	pick-up	0	23
120599	2020-08-18 19:11:56	2020-08-18	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	14516	delivery	5	30
120600	2020-08-18 19:17:26	2020-08-18	12	[{"id_menu":1,"count":1}]	11183	pick-up	0	12
120601	2020-08-18 19:17:56	2020-08-18	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	38296	delivery	5	37
120602	2020-08-18 19:25:08	2020-08-18	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	92	pick-up	0	29
120603	2020-08-18 19:31:32	2020-08-18	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18936	delivery	5	37
120604	2020-08-18 19:33:51	2020-08-18	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	12239	delivery	5	22
120605	2020-08-18 19:34:48	2020-08-18	9	[{"id_menu":6,"count":1}]	33371	delivery	5	14
120606	2020-08-18 19:35:26	2020-08-18	14	[{"id_menu":2,"count":1}]	40092	pick-up	0	14
120607	2020-08-18 19:36:19	2020-08-18	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	37839	pick-up	0	37
120608	2020-08-18 19:36:33	2020-08-18	9	[{"id_menu":6,"count":1}]	45896	delivery	5	14
120609	2020-08-18 19:46:09	2020-08-18	8	[{"id_menu":5,"count":1}]	4899	delivery	5	13
120610	2020-08-18 19:46:46	2020-08-18	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	12355	delivery	5	34
120611	2020-08-18 19:49:30	2020-08-18	12	[{"id_menu":3,"count":1}]	36578	delivery	5	17
120612	2020-08-18 19:50:47	2020-08-18	9	[{"id_menu":7,"count":1}]	26363	delivery	5	14
120613	2020-08-18 19:50:54	2020-08-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	30693	delivery	5	28
120614	2020-08-18 19:54:07	2020-08-18	17	[{"id_menu":4,"count":1}]	16992	delivery	5	22
120615	2020-08-18 19:55:09	2020-08-18	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7854	pick-up	0	31
120616	2020-08-18 19:55:22	2020-08-18	9	[{"id_menu":6,"count":1}]	35587	pick-up	0	9
120617	2020-08-18 19:57:47	2020-08-18	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	5064	delivery	5	26
120618	2020-08-18 19:58:59	2020-08-18	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	32450	delivery	5	39
120619	2020-08-18 20:00:04	2020-08-18	14	[{"id_menu":2,"count":1}]	12	pick-up	0	14
120620	2020-08-18 20:05:47	2020-08-18	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	68	delivery	5	25
120621	2020-08-18 20:08:24	2020-08-18	14	[{"id_menu":2,"count":1}]	45996	delivery	5	19
120622	2020-08-18 20:09:06	2020-08-18	17	[{"id_menu":4,"count":1}]	28419	pick-up	0	17
120623	2020-08-18 20:09:51	2020-08-18	9	[{"id_menu":6,"count":1}]	45985	delivery	5	14
120624	2020-08-18 20:13:52	2020-08-18	8	[{"id_menu":5,"count":1}]	45284	pick-up	0	8
120625	2020-08-18 20:18:47	2020-08-18	8	[{"id_menu":5,"count":1}]	34450	delivery	5	13
120626	2020-08-18 20:21:13	2020-08-18	9	[{"id_menu":7,"count":1}]	45906	delivery	5	14
120627	2020-08-18 20:22:52	2020-08-18	9	[{"id_menu":7,"count":1}]	35272	delivery	5	14
120628	2020-08-18 20:24:59	2020-08-18	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29979	delivery	5	43
120629	2020-08-18 20:28:39	2020-08-18	9	[{"id_menu":6,"count":1}]	45809	delivery	5	14
120630	2020-08-18 20:29:11	2020-08-18	12	[{"id_menu":1,"count":1}]	29252	delivery	5	17
120631	2020-08-18 20:29:36	2020-08-18	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1101	pick-up	0	21
120632	2020-08-18 20:30:28	2020-08-18	14	[{"id_menu":2,"count":1}]	27429	pick-up	0	14
120633	2020-08-18 20:30:53	2020-08-18	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	45847	pick-up	0	25
120634	2020-08-18 20:31:11	2020-08-18	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39537	delivery	5	37
120635	2020-08-18 20:34:04	2020-08-18	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11150	delivery	5	46
120636	2020-08-18 20:37:48	2020-08-18	9	[{"id_menu":6,"count":1}]	11389	delivery	5	14
120637	2020-08-18 20:42:51	2020-08-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	46004	delivery	5	28
120638	2020-08-18 20:47:46	2020-08-18	14	[{"id_menu":2,"count":1}]	42249	pick-up	0	14
120639	2020-08-18 20:48:25	2020-08-18	12	[{"id_menu":1,"count":1}]	10785	pick-up	0	12
120640	2020-08-18 20:50:42	2020-08-18	9	[{"id_menu":6,"count":1}]	18214	delivery	5	14
120641	2020-08-18 20:51:10	2020-08-18	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	35541	delivery	5	31
120642	2020-08-18 20:51:26	2020-08-18	12	[{"id_menu":3,"count":2}]	13797	delivery	5	17
120643	2020-08-18 20:58:05	2020-08-18	9	[{"id_menu":6,"count":1}]	17003	delivery	5	14
120644	2020-08-18 20:59:23	2020-08-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38731	delivery	5	23
120645	2020-08-18 20:59:43	2020-08-18	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	24698	delivery	5	45
120646	2020-08-18 21:00:13	2020-08-18	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	4166	pick-up	0	26
120647	2020-08-18 21:02:32	2020-08-18	14	[{"id_menu":2,"count":1}]	8501	pick-up	0	14
120648	2020-08-18 21:07:49	2020-08-18	9	[{"id_menu":6,"count":1}]	41285	delivery	5	14
120649	2020-08-18 21:09:58	2020-08-18	14	[{"id_menu":2,"count":1}]	5306	pick-up	0	14
120650	2020-08-18 21:13:48	2020-08-18	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	19056	delivery	5	28
120651	2020-08-18 21:15:58	2020-08-18	14	[{"id_menu":2,"count":1}]	31374	delivery	5	19
120652	2020-08-18 21:16:06	2020-08-18	9	[{"id_menu":6,"count":1}]	35479	delivery	5	14
120653	2020-08-18 21:16:41	2020-08-18	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	45926	delivery	5	35
120654	2020-08-18 21:18:47	2020-08-18	8	[{"id_menu":5,"count":1}]	1012	pick-up	0	8
120655	2020-08-18 21:19:09	2020-08-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	45801	delivery	5	23
120656	2020-08-18 21:21:56	2020-08-18	14	[{"id_menu":2,"count":1}]	4012	pick-up	0	14
120657	2020-08-18 21:23:13	2020-08-18	14	[{"id_menu":2,"count":1}]	29361	delivery	5	19
120658	2020-08-18 21:23:49	2020-08-18	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	45810	delivery	5	43
120659	2020-08-18 21:25:44	2020-08-18	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	11093	delivery	5	40
120660	2020-08-18 21:26:10	2020-08-18	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	45881	delivery	5	45
120661	2020-08-18 21:27:04	2020-08-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7284	pick-up	0	18
120662	2020-08-18 21:29:09	2020-08-18	8	[{"id_menu":5,"count":1}]	18115	delivery	5	13
120663	2020-08-18 21:30:06	2020-08-18	12	[{"id_menu":1,"count":1}]	39632	pick-up	0	12
120664	2020-08-18 21:34:51	2020-08-18	8	[{"id_menu":5,"count":1}]	31520	delivery	5	13
120665	2020-08-18 21:36:58	2020-08-18	9	[{"id_menu":7,"count":1}]	2631	delivery	5	14
120666	2020-08-18 21:39:24	2020-08-18	14	[{"id_menu":2,"count":1}]	36264	delivery	5	19
120667	2020-08-18 21:40:05	2020-08-18	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	17788	pick-up	0	21
120668	2020-08-18 21:41:01	2020-08-18	9	[{"id_menu":7,"count":1}]	24044	delivery	5	14
120669	2020-08-18 21:45:13	2020-08-18	9	[{"id_menu":7,"count":2}]	8307	delivery	5	14
120670	2020-08-18 21:47:53	2020-08-18	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	10915	delivery	5	34
120671	2020-08-18 21:48:02	2020-08-18	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8880	delivery	5	43
120672	2020-08-18 21:48:51	2020-08-18	9	[{"id_menu":6,"count":1}]	43985	delivery	5	14
120673	2020-08-18 21:51:37	2020-08-18	12	[{"id_menu":1,"count":1}]	2168	pick-up	0	12
120674	2020-08-18 21:53:17	2020-08-18	49	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	45895	delivery	5	54
120675	2020-08-18 21:55:48	2020-08-18	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	45984	delivery	5	28
120676	2020-08-18 22:00:45	2020-08-18	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	45992	delivery	5	34
120677	2020-08-18 22:03:56	2020-08-18	14	[{"id_menu":2,"count":1}]	45902	pick-up	0	14
120678	2020-08-18 22:07:59	2020-08-18	17	[{"id_menu":4,"count":1}]	26945	delivery	5	22
120679	2020-08-18 22:15:30	2020-08-18	14	[{"id_menu":2,"count":1}]	45806	delivery	5	19
120680	2020-08-18 22:15:53	2020-08-18	17	[{"id_menu":4,"count":1}]	25717	delivery	5	22
120681	2020-08-18 22:16:41	2020-08-18	14	[{"id_menu":2,"count":3}]	39456	delivery	5	19
120682	2020-08-18 22:19:02	2020-08-18	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	39793	delivery	5	26
120683	2020-08-18 22:19:11	2020-08-18	9	[{"id_menu":7,"count":1}]	143	pick-up	0	9
120684	2020-08-18 22:21:40	2020-08-18	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2082	pick-up	0	26
120685	2020-08-18 22:27:14	2020-08-18	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	9747	delivery	5	36
120686	2020-08-18 22:27:22	2020-08-18	9	[{"id_menu":7,"count":1}]	39654	delivery	5	14
120687	2020-08-18 22:33:24	2020-08-18	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	37169	delivery	5	43
120688	2020-08-18 22:35:28	2020-08-18	17	[{"id_menu":4,"count":1}]	12889	pick-up	0	17
120689	2020-08-18 22:38:02	2020-08-18	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	21702	delivery	5	27
120690	2020-08-18 22:38:44	2020-08-18	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	38952	delivery	5	36
120691	2020-08-18 22:39:37	2020-08-18	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	27575	delivery	5	40
120692	2020-08-18 22:42:07	2020-08-18	9	[{"id_menu":6,"count":1}]	14189	pick-up	0	9
120693	2020-08-18 22:43:29	2020-08-18	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	45830	delivery	5	22
120694	2020-08-18 22:49:32	2020-08-18	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	3507	pick-up	0	21
120695	2020-08-18 22:51:34	2020-08-18	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	5154	pick-up	0	21
120696	2020-08-18 22:53:11	2020-08-18	12	[{"id_menu":3,"count":1}]	31747	delivery	5	17
120697	2020-08-18 22:53:27	2020-08-18	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	20091	delivery	5	26
120698	2020-08-18 22:55:35	2020-08-18	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	13148	pick-up	0	24
120699	2020-08-18 22:56:25	2020-08-18	9	[{"id_menu":7,"count":1}]	28281	delivery	5	14
120700	2020-08-18 23:00:31	2020-08-18	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	45968	delivery	5	39
120701	2020-08-18 23:00:42	2020-08-18	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	20402	delivery	5	28
120702	2020-08-18 23:03:17	2020-08-18	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	19691	delivery	5	43
120703	2020-08-18 23:04:45	2020-08-18	9	[{"id_menu":7,"count":1}]	21566	delivery	5	14
120704	2020-08-18 23:10:16	2020-08-18	17	[{"id_menu":4,"count":1}]	38871	delivery	5	22
120705	2020-08-18 23:10:18	2020-08-18	9	[{"id_menu":7,"count":1}]	43770	delivery	5	14
120706	2020-08-18 23:12:50	2020-08-18	9	[{"id_menu":6,"count":1}]	38131	delivery	5	14
120707	2020-08-18 23:15:40	2020-08-18	12	[{"id_menu":3,"count":1}]	5721	pick-up	0	12
120708	2020-08-18 23:19:27	2020-08-18	14	[{"id_menu":2,"count":1}]	45994	delivery	5	19
120709	2020-08-18 23:35:40	2020-08-18	17	[{"id_menu":4,"count":1}]	42903	delivery	5	22
120710	2020-08-18 23:38:59	2020-08-18	12	[{"id_menu":3,"count":1}]	8822	delivery	5	17
120711	2020-08-18 23:39:01	2020-08-18	12	[{"id_menu":1,"count":1}]	43821	delivery	5	17
120712	2020-08-18 23:40:06	2020-08-18	17	[{"id_menu":4,"count":1}]	37280	pick-up	0	17
120713	2020-08-18 23:40:16	2020-08-18	12	[{"id_menu":3,"count":1}]	14970	pick-up	0	12
120714	2020-08-18 23:41:33	2020-08-18	17	[{"id_menu":4,"count":1}]	16466	pick-up	0	17
120715	2020-08-18 23:42:14	2020-08-18	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35529	delivery	5	23
120716	2020-08-18 23:43:35	2020-08-18	12	[{"id_menu":1,"count":1}]	45828	delivery	5	17
120717	2020-08-18 23:47:54	2020-08-18	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	20636	delivery	5	27
120718	2020-08-18 23:52:59	2020-08-18	9	[{"id_menu":6,"count":1}]	44596	delivery	5	14
120719	2020-08-18 23:54:40	2020-08-18	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	4731	delivery	5	31
120720	2020-08-18 23:55:14	2020-08-18	14	[{"id_menu":2,"count":1}]	45802	delivery	5	19
120721	2020-08-18 23:57:32	2020-08-18	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20911	delivery	5	22
120722	2020-08-18 23:57:41	2020-08-18	9	[{"id_menu":6,"count":1}]	41439	delivery	5	14
120723	2020-08-19 00:00:40	2020-08-19	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	46054	delivery	5	43
120724	2020-08-19 00:01:37	2020-08-19	8	[{"id_menu":5,"count":1}]	26983	pick-up	0	8
120725	2020-08-19 00:03:02	2020-08-19	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	34787	delivery	5	43
120726	2020-08-19 00:09:20	2020-08-19	12	[{"id_menu":1,"count":1}]	42894	delivery	5	17
120727	2020-08-19 00:09:25	2020-08-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12675	pick-up	0	17
120728	2020-08-19 00:09:25	2020-08-19	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	17580	delivery	5	38
120729	2020-08-19 00:11:04	2020-08-19	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	35766	delivery	5	26
120730	2020-08-19 00:13:06	2020-08-19	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	46227	delivery	5	31
120731	2020-08-19 00:14:18	2020-08-19	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	17855	delivery	5	42
120732	2020-08-19 00:15:40	2020-08-19	9	[{"id_menu":7,"count":1}]	46092	pick-up	0	9
120733	2020-08-19 00:20:53	2020-08-19	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	41548	pick-up	0	21
120734	2020-08-19 00:20:57	2020-08-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	46095	delivery	5	31
120735	2020-08-19 00:21:10	2020-08-19	9	[{"id_menu":7,"count":1}]	25900	delivery	5	14
120736	2020-08-19 00:22:16	2020-08-19	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	35472	delivery	5	31
120737	2020-08-19 00:22:37	2020-08-19	12	[{"id_menu":1,"count":1}]	46237	delivery	5	17
120738	2020-08-19 00:23:39	2020-08-19	12	[{"id_menu":3,"count":1}]	1282	pick-up	0	12
120739	2020-08-19 00:28:11	2020-08-19	12	[{"id_menu":1,"count":1}]	36885	delivery	5	17
120740	2020-08-19 00:34:45	2020-08-19	8	[{"id_menu":5,"count":1}]	5485	delivery	5	13
120741	2020-08-19 00:40:36	2020-08-19	12	[{"id_menu":1,"count":1}]	15645	pick-up	0	12
120742	2020-08-19 00:41:22	2020-08-19	9	[{"id_menu":7,"count":1}]	37673	pick-up	0	9
120743	2020-08-19 00:43:02	2020-08-19	12	[{"id_menu":1,"count":1}]	31759	delivery	5	17
120744	2020-08-19 00:44:16	2020-08-19	17	[{"id_menu":4,"count":1}]	37557	delivery	5	22
120745	2020-08-19 00:44:20	2020-08-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39723	delivery	5	22
120746	2020-08-19 00:44:29	2020-08-19	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	22242	pick-up	0	22
120747	2020-08-19 00:44:53	2020-08-19	12	[{"id_menu":3,"count":1}]	16018	delivery	5	17
120748	2020-08-19 00:45:15	2020-08-19	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	9319	delivery	5	26
120749	2020-08-19 00:48:35	2020-08-19	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	2788	delivery	5	29
120750	2020-08-19 00:48:49	2020-08-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	46096	delivery	5	22
120751	2020-08-19 00:49:23	2020-08-19	14	[{"id_menu":2,"count":1}]	44552	delivery	5	19
120752	2020-08-19 00:50:06	2020-08-19	12	[{"id_menu":3,"count":1}]	30110	delivery	5	17
120753	2020-08-19 00:52:46	2020-08-19	12	[{"id_menu":3,"count":1}]	12393	pick-up	0	12
120754	2020-08-19 00:53:23	2020-08-19	17	[{"id_menu":4,"count":1}]	1317	delivery	5	22
120755	2020-08-19 00:53:26	2020-08-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13308	delivery	5	22
120756	2020-08-19 00:54:06	2020-08-19	12	[{"id_menu":3,"count":1}]	27	delivery	5	17
120757	2020-08-19 00:54:28	2020-08-19	12	[{"id_menu":1,"count":1}]	40606	delivery	5	17
120758	2020-08-19 00:55:50	2020-08-19	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	13765	delivery	5	26
120759	2020-08-19 01:01:03	2020-08-19	9	[{"id_menu":6,"count":1}]	3034	pick-up	0	9
120760	2020-08-19 01:02:20	2020-08-19	12	[{"id_menu":3,"count":1}]	16641	delivery	5	17
120761	2020-08-19 01:06:22	2020-08-19	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	46187	delivery	5	31
120762	2020-08-19 01:10:32	2020-08-19	17	[{"id_menu":4,"count":1}]	16429	delivery	5	22
120763	2020-08-19 01:14:37	2020-08-19	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	20803	delivery	5	26
120764	2020-08-19 01:14:39	2020-08-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	43961	delivery	5	28
120765	2020-08-19 01:14:47	2020-08-19	9	[{"id_menu":6,"count":1}]	1555	pick-up	0	9
120766	2020-08-19 01:15:16	2020-08-19	8	[{"id_menu":5,"count":1}]	3372	pick-up	0	8
120767	2020-08-19 01:16:18	2020-08-19	14	[{"id_menu":2,"count":1}]	46131	delivery	5	19
120768	2020-08-19 01:17:41	2020-08-19	9	[{"id_menu":6,"count":1}]	19270	pick-up	0	9
120769	2020-08-19 01:17:47	2020-08-19	14	[{"id_menu":2,"count":2}]	18087	delivery	5	19
120770	2020-08-19 01:18:42	2020-08-19	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4822	delivery	5	52
120771	2020-08-19 01:20:28	2020-08-19	12	[{"id_menu":1,"count":1}]	42149	pick-up	0	12
120772	2020-08-19 01:21:26	2020-08-19	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	46058	delivery	5	57
120773	2020-08-19 01:22:54	2020-08-19	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	46170	delivery	5	38
120774	2020-08-19 01:23:02	2020-08-19	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	23863	delivery	5	26
120775	2020-08-19 01:24:46	2020-08-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	18192	delivery	5	22
120776	2020-08-19 01:25:21	2020-08-19	9	[{"id_menu":7,"count":1}]	23133	pick-up	0	9
120777	2020-08-19 01:26:59	2020-08-19	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	28002	delivery	5	45
120778	2020-08-19 01:27:51	2020-08-19	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	28132	delivery	5	31
120779	2020-08-19 01:27:54	2020-08-19	12	[{"id_menu":3,"count":1}]	46115	pick-up	0	12
120780	2020-08-19 01:28:12	2020-08-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	45647	delivery	5	28
120781	2020-08-19 01:31:21	2020-08-19	9	[{"id_menu":7,"count":1}]	43086	delivery	5	14
120782	2020-08-19 01:31:58	2020-08-19	9	[{"id_menu":6,"count":1}]	46266	delivery	5	14
120783	2020-08-19 01:32:55	2020-08-19	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36380	delivery	5	40
120784	2020-08-19 01:34:32	2020-08-19	12	[{"id_menu":3,"count":1}]	26042	delivery	5	17
120785	2020-08-19 01:34:41	2020-08-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	24579	delivery	5	22
120786	2020-08-19 01:35:58	2020-08-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	12671	delivery	5	36
120787	2020-08-19 01:37:16	2020-08-19	8	[{"id_menu":5,"count":1}]	18074	delivery	5	13
120788	2020-08-19 01:38:30	2020-08-19	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	5650	pick-up	0	26
120789	2020-08-19 01:39:02	2020-08-19	14	[{"id_menu":2,"count":1}]	30624	delivery	5	19
120790	2020-08-19 01:43:22	2020-08-19	12	[{"id_menu":3,"count":1}]	6156	delivery	5	17
120791	2020-08-19 01:44:59	2020-08-19	9	[{"id_menu":6,"count":1}]	33339	delivery	5	14
120792	2020-08-19 01:45:24	2020-08-19	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	46281	delivery	5	35
120793	2020-08-19 01:47:21	2020-08-19	17	[{"id_menu":4,"count":1}]	35058	pick-up	0	17
120794	2020-08-19 01:52:58	2020-08-19	9	[{"id_menu":6,"count":1}]	14761	delivery	5	14
120795	2020-08-19 01:56:56	2020-08-19	17	[{"id_menu":4,"count":1}]	35287	delivery	5	22
120796	2020-08-19 01:58:07	2020-08-19	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	27989	delivery	5	36
120797	2020-08-19 02:01:03	2020-08-19	8	[{"id_menu":5,"count":1}]	46125	delivery	5	13
120798	2020-08-19 02:01:17	2020-08-19	14	[{"id_menu":2,"count":1}]	22465	delivery	5	19
120799	2020-08-19 02:03:28	2020-08-19	17	[{"id_menu":4,"count":1}]	13229	pick-up	0	17
120800	2020-08-19 02:04:35	2020-08-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	33945	delivery	5	22
120801	2020-08-19 02:05:30	2020-08-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	19986	delivery	5	36
120802	2020-08-19 02:05:38	2020-08-19	9	[{"id_menu":7,"count":1}]	26449	pick-up	0	9
120803	2020-08-19 02:07:25	2020-08-19	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	27208	delivery	5	40
120804	2020-08-19 02:07:55	2020-08-19	9	[{"id_menu":6,"count":1}]	31025	delivery	5	14
120805	2020-08-19 02:08:15	2020-08-19	9	[{"id_menu":7,"count":1}]	15007	delivery	5	14
120806	2020-08-19 02:08:52	2020-08-19	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	21417	delivery	5	31
120807	2020-08-19 02:11:15	2020-08-19	14	[{"id_menu":2,"count":1}]	46194	delivery	5	19
120808	2020-08-19 02:12:37	2020-08-19	8	[{"id_menu":5,"count":1}]	32141	pick-up	0	8
120809	2020-08-19 02:16:02	2020-08-19	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1115	pick-up	0	21
120810	2020-08-19 02:17:09	2020-08-19	8	[{"id_menu":5,"count":1}]	46138	delivery	5	13
120811	2020-08-19 02:19:49	2020-08-19	17	[{"id_menu":4,"count":1}]	46263	delivery	5	22
120812	2020-08-19 02:22:40	2020-08-19	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	37991	delivery	5	34
120813	2020-08-19 02:23:56	2020-08-19	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	46085	delivery	5	26
120814	2020-08-19 02:26:45	2020-08-19	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	16456	delivery	5	25
120815	2020-08-19 02:28:56	2020-08-19	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	32571	delivery	5	31
120816	2020-08-19 02:35:42	2020-08-19	8	[{"id_menu":5,"count":1}]	8022	delivery	5	13
120817	2020-08-19 02:36:15	2020-08-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	45863	delivery	5	23
120818	2020-08-19 02:36:53	2020-08-19	12	[{"id_menu":3,"count":1}]	46275	delivery	5	17
120819	2020-08-19 02:37:17	2020-08-19	9	[{"id_menu":6,"count":1}]	22519	pick-up	0	9
120820	2020-08-19 02:39:41	2020-08-19	8	[{"id_menu":5,"count":1}]	46200	delivery	5	13
120821	2020-08-19 02:39:59	2020-08-19	9	[{"id_menu":6,"count":1}]	33126	pick-up	0	9
120822	2020-08-19 02:46:36	2020-08-19	9	[{"id_menu":6,"count":1}]	46093	pick-up	0	9
120823	2020-08-19 02:47:34	2020-08-19	8	[{"id_menu":5,"count":1}]	46286	delivery	5	13
120824	2020-08-19 02:50:09	2020-08-19	9	[{"id_menu":6,"count":1}]	40385	delivery	5	14
120825	2020-08-19 02:51:10	2020-08-19	9	[{"id_menu":7,"count":1}]	5416	delivery	5	14
120826	2020-08-19 02:51:27	2020-08-19	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	11534	pick-up	0	26
120827	2020-08-19 02:51:46	2020-08-19	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	46114	delivery	5	34
120828	2020-08-19 02:53:03	2020-08-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	46146	delivery	5	22
120829	2020-08-19 02:53:49	2020-08-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	46047	delivery	5	23
120830	2020-08-19 02:55:52	2020-08-19	8	[{"id_menu":5,"count":1}]	46086	delivery	5	13
120831	2020-08-19 02:56:11	2020-08-19	9	[{"id_menu":6,"count":1}]	46048	delivery	5	14
120832	2020-08-19 02:59:39	2020-08-19	12	[{"id_menu":1,"count":1}]	26035	pick-up	0	12
120833	2020-08-19 03:02:49	2020-08-19	17	[{"id_menu":4,"count":1}]	1657	delivery	5	22
120834	2020-08-19 03:04:08	2020-08-19	8	[{"id_menu":5,"count":1}]	46159	delivery	5	13
120835	2020-08-19 03:06:34	2020-08-19	9	[{"id_menu":7,"count":1}]	44965	delivery	5	14
120836	2020-08-19 03:10:46	2020-08-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	41093	delivery	5	28
120837	2020-08-19 03:17:20	2020-08-19	9	[{"id_menu":7,"count":3}]	29732	delivery	5	14
120838	2020-08-19 03:18:29	2020-08-19	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	6213	delivery	5	36
120839	2020-08-19 03:19:50	2020-08-19	9	[{"id_menu":7,"count":1}]	3471	delivery	5	14
120840	2020-08-19 03:21:02	2020-08-19	17	[{"id_menu":4,"count":1}]	37839	pick-up	0	17
120841	2020-08-19 03:22:01	2020-08-19	12	[{"id_menu":1,"count":1}]	26901	delivery	5	17
120842	2020-08-19 03:22:33	2020-08-19	14	[{"id_menu":2,"count":2}]	28367	pick-up	0	14
120843	2020-08-19 03:31:09	2020-08-19	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	46072	delivery	5	34
120844	2020-08-19 03:32:42	2020-08-19	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	34456	delivery	5	55
120845	2020-08-19 03:36:04	2020-08-19	14	[{"id_menu":2,"count":1}]	778	pick-up	0	14
120846	2020-08-19 03:36:58	2020-08-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3909	pick-up	0	26
120847	2020-08-19 03:38:04	2020-08-19	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":2}]	39710	delivery	5	22
120848	2020-08-19 03:44:34	2020-08-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	6276	delivery	5	28
120849	2020-08-19 03:44:57	2020-08-19	12	[{"id_menu":1,"count":1}]	2557	delivery	5	17
120850	2020-08-19 03:49:16	2020-08-19	14	[{"id_menu":2,"count":1}]	46222	pick-up	0	14
120851	2020-08-19 03:51:09	2020-08-19	9	[{"id_menu":7,"count":1}]	46124	delivery	5	14
120852	2020-08-19 03:53:51	2020-08-19	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	36624	delivery	5	31
120853	2020-08-19 03:56:00	2020-08-19	9	[{"id_menu":7,"count":2}]	21629	delivery	5	14
120854	2020-08-19 03:56:36	2020-08-19	12	[{"id_menu":1,"count":1}]	35804	pick-up	0	12
120855	2020-08-19 03:58:15	2020-08-19	9	[{"id_menu":6,"count":1}]	43128	delivery	5	14
120856	2020-08-19 04:00:01	2020-08-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	41324	delivery	5	28
120857	2020-08-19 04:03:45	2020-08-19	9	[{"id_menu":6,"count":2}]	1529	pick-up	0	9
120858	2020-08-19 04:07:03	2020-08-19	9	[{"id_menu":7,"count":1}]	46164	delivery	5	14
120859	2020-08-19 04:08:12	2020-08-19	9	[{"id_menu":6,"count":1}]	2396	pick-up	0	9
120860	2020-08-19 04:12:53	2020-08-19	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29795	delivery	5	34
120861	2020-08-19 04:13:07	2020-08-19	9	[{"id_menu":7,"count":1}]	8874	delivery	5	14
120862	2020-08-19 04:14:12	2020-08-19	9	[{"id_menu":7,"count":1}]	32305	delivery	5	14
120863	2020-08-19 04:17:41	2020-08-19	12	[{"id_menu":3,"count":1}]	881	pick-up	0	12
120864	2020-08-19 04:18:02	2020-08-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	46186	delivery	5	36
120865	2020-08-19 04:20:02	2020-08-19	9	[{"id_menu":6,"count":1}]	20925	delivery	5	14
120866	2020-08-19 04:23:03	2020-08-19	14	[{"id_menu":2,"count":1}]	12299	delivery	5	19
120867	2020-08-19 04:32:59	2020-08-19	9	[{"id_menu":6,"count":1}]	24382	delivery	5	14
120868	2020-08-19 04:35:02	2020-08-19	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	634	pick-up	0	26
120869	2020-08-19 04:35:36	2020-08-19	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	8663	delivery	5	43
120870	2020-08-19 04:40:51	2020-08-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	46282	delivery	5	22
120871	2020-08-19 04:49:06	2020-08-19	12	[{"id_menu":1,"count":2}]	16023	delivery	5	17
120872	2020-08-19 04:50:05	2020-08-19	9	[{"id_menu":7,"count":1}]	21223	delivery	5	14
120873	2020-08-19 04:51:20	2020-08-19	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	46136	delivery	5	38
120874	2020-08-19 04:52:28	2020-08-19	9	[{"id_menu":6,"count":1}]	35792	delivery	5	14
120875	2020-08-19 04:53:40	2020-08-19	9	[{"id_menu":7,"count":1}]	13547	pick-up	0	9
120876	2020-08-19 04:54:25	2020-08-19	9	[{"id_menu":7,"count":1}]	5839	pick-up	0	9
120877	2020-08-19 04:54:48	2020-08-19	8	[{"id_menu":5,"count":1}]	7247	pick-up	0	8
120878	2020-08-19 04:56:58	2020-08-19	9	[{"id_menu":6,"count":1}]	28869	delivery	5	14
120879	2020-08-19 04:58:44	2020-08-19	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	46242	delivery	5	45
120880	2020-08-19 05:00:09	2020-08-19	8	[{"id_menu":5,"count":1}]	2838	pick-up	0	8
120881	2020-08-19 05:04:48	2020-08-19	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	46140	delivery	5	40
120882	2020-08-19 05:04:58	2020-08-19	9	[{"id_menu":6,"count":1}]	25685	delivery	5	14
120883	2020-08-19 05:06:02	2020-08-19	17	[{"id_menu":4,"count":1}]	25941	delivery	5	22
120884	2020-08-19 05:06:15	2020-08-19	9	[{"id_menu":7,"count":1}]	46106	delivery	5	14
120885	2020-08-19 05:10:00	2020-08-19	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	38768	delivery	5	29
120886	2020-08-19 05:12:36	2020-08-19	17	[{"id_menu":4,"count":1}]	21631	delivery	5	22
120887	2020-08-19 05:13:45	2020-08-19	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	46208	delivery	5	29
120888	2020-08-19 05:14:08	2020-08-19	9	[{"id_menu":6,"count":1}]	38844	pick-up	0	9
120889	2020-08-19 05:17:08	2020-08-19	17	[{"id_menu":4,"count":1}]	6968	pick-up	0	17
120890	2020-08-19 05:19:44	2020-08-19	12	[{"id_menu":1,"count":1}]	10819	pick-up	0	12
120891	2020-08-19 05:23:49	2020-08-19	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	17427	delivery	5	40
120892	2020-08-19 05:25:13	2020-08-19	17	[{"id_menu":4,"count":1}]	46128	delivery	5	22
120893	2020-08-19 05:30:00	2020-08-19	9	[{"id_menu":6,"count":1}]	46183	delivery	5	14
120894	2020-08-19 05:32:10	2020-08-19	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	16139	delivery	5	31
120895	2020-08-19 05:32:22	2020-08-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	25847	delivery	5	22
120896	2020-08-19 05:33:35	2020-08-19	14	[{"id_menu":2,"count":1}]	46267	delivery	5	19
120897	2020-08-19 05:33:50	2020-08-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	26275	delivery	5	36
120898	2020-08-19 05:35:05	2020-08-19	9	[{"id_menu":6,"count":1}]	28038	delivery	5	14
120899	2020-08-19 05:35:12	2020-08-19	17	[{"id_menu":4,"count":1}]	5253	pick-up	0	17
120900	2020-08-19 05:38:44	2020-08-19	14	[{"id_menu":2,"count":1}]	36713	delivery	5	19
120901	2020-08-19 05:38:47	2020-08-19	9	[{"id_menu":6,"count":1}]	39145	delivery	5	14
120902	2020-08-19 05:40:07	2020-08-19	14	[{"id_menu":2,"count":1}]	6519	delivery	5	19
120903	2020-08-19 05:40:10	2020-08-19	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	36472	pick-up	0	21
120904	2020-08-19 05:43:36	2020-08-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	34463	delivery	5	22
120905	2020-08-19 05:44:45	2020-08-19	9	[{"id_menu":7,"count":1}]	46088	delivery	5	14
120906	2020-08-19 05:45:55	2020-08-19	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":3}]	11864	delivery	5	26
120907	2020-08-19 05:47:32	2020-08-19	12	[{"id_menu":1,"count":2}]	2615	pick-up	0	12
120908	2020-08-19 05:49:01	2020-08-19	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	46147	delivery	5	34
120909	2020-08-19 05:50:25	2020-08-19	9	[{"id_menu":7,"count":1}]	46255	delivery	5	14
120910	2020-08-19 05:50:43	2020-08-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	46130	delivery	5	28
120911	2020-08-19 05:51:56	2020-08-19	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3864	pick-up	0	30
120912	2020-08-19 05:52:59	2020-08-19	14	[{"id_menu":2,"count":1}]	17405	delivery	5	19
120913	2020-08-19 06:02:13	2020-08-19	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	46218	pick-up	0	21
120914	2020-08-19 06:04:07	2020-08-19	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	12578	pick-up	0	23
120915	2020-08-19 06:05:25	2020-08-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	46270	delivery	5	23
120916	2020-08-19 06:09:00	2020-08-19	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	4425	delivery	5	39
120917	2020-08-19 06:10:11	2020-08-19	8	[{"id_menu":5,"count":1}]	13529	delivery	5	13
120918	2020-08-19 06:10:32	2020-08-19	9	[{"id_menu":7,"count":1}]	4875	delivery	5	14
120919	2020-08-19 06:13:39	2020-08-19	8	[{"id_menu":5,"count":1}]	8301	delivery	5	13
120920	2020-08-19 06:15:06	2020-08-19	9	[{"id_menu":7,"count":2}]	46289	delivery	5	14
120921	2020-08-19 06:20:29	2020-08-19	9	[{"id_menu":6,"count":1}]	46241	delivery	5	14
120922	2020-08-19 06:21:21	2020-08-19	8	[{"id_menu":5,"count":1}]	41549	delivery	5	13
120923	2020-08-19 06:21:23	2020-08-19	8	[{"id_menu":5,"count":1}]	37699	delivery	5	13
120924	2020-08-19 06:26:48	2020-08-19	17	[{"id_menu":4,"count":1}]	46169	delivery	5	22
120925	2020-08-19 06:28:17	2020-08-19	9	[{"id_menu":6,"count":1}]	993	delivery	5	14
120926	2020-08-19 06:33:06	2020-08-19	17	[{"id_menu":4,"count":1}]	43834	pick-up	0	17
120927	2020-08-19 06:34:33	2020-08-19	8	[{"id_menu":5,"count":1}]	4794	delivery	5	13
120928	2020-08-19 06:36:38	2020-08-19	12	[{"id_menu":1,"count":1}]	3942	delivery	5	17
120929	2020-08-19 06:37:27	2020-08-19	14	[{"id_menu":2,"count":1}]	46129	delivery	5	19
120930	2020-08-19 06:37:31	2020-08-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8569	delivery	5	22
120931	2020-08-19 06:38:55	2020-08-19	12	[{"id_menu":3,"count":1}]	30873	delivery	5	17
120932	2020-08-19 06:40:16	2020-08-19	9	[{"id_menu":7,"count":2}]	44068	delivery	5	14
120933	2020-08-19 06:40:19	2020-08-19	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	46149	delivery	5	37
120934	2020-08-19 06:41:50	2020-08-19	9	[{"id_menu":7,"count":1}]	40882	delivery	5	14
120935	2020-08-19 06:48:52	2020-08-19	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	46107	delivery	5	48
120936	2020-08-19 06:49:11	2020-08-19	9	[{"id_menu":6,"count":1}]	1800	pick-up	0	9
120937	2020-08-19 06:50:46	2020-08-19	9	[{"id_menu":7,"count":1}]	32915	pick-up	0	9
120938	2020-08-19 06:57:52	2020-08-19	17	[{"id_menu":4,"count":1}]	2769	delivery	5	22
120939	2020-08-19 06:59:54	2020-08-19	8	[{"id_menu":5,"count":1}]	46226	delivery	5	13
120940	2020-08-19 07:00:46	2020-08-19	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	40410	delivery	5	22
120941	2020-08-19 07:02:50	2020-08-19	12	[{"id_menu":3,"count":1}]	17987	delivery	5	17
120942	2020-08-19 07:12:01	2020-08-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	46042	pick-up	0	23
120943	2020-08-19 07:12:21	2020-08-19	14	[{"id_menu":2,"count":1}]	46204	delivery	5	19
120944	2020-08-19 07:13:43	2020-08-19	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16344	delivery	5	35
120945	2020-08-19 07:18:54	2020-08-19	12	[{"id_menu":3,"count":1}]	46269	delivery	5	17
120946	2020-08-19 07:20:43	2020-08-19	12	[{"id_menu":3,"count":1}]	11083	pick-up	0	12
120947	2020-08-19 07:21:40	2020-08-19	14	[{"id_menu":2,"count":1}]	21048	delivery	5	19
120948	2020-08-19 07:21:58	2020-08-19	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	36970	delivery	5	22
120949	2020-08-19 07:23:32	2020-08-19	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	46078	delivery	5	34
120950	2020-08-19 07:23:41	2020-08-19	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	12123	delivery	5	34
120951	2020-08-19 07:24:28	2020-08-19	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	46221	delivery	5	34
120952	2020-08-19 07:27:47	2020-08-19	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	40794	delivery	5	43
120953	2020-08-19 07:28:39	2020-08-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	41851	delivery	5	28
120954	2020-08-19 07:32:30	2020-08-19	14	[{"id_menu":2,"count":1}]	41030	delivery	5	19
120955	2020-08-19 07:33:02	2020-08-19	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	35693	pick-up	0	26
120956	2020-08-19 07:33:26	2020-08-19	9	[{"id_menu":7,"count":1}]	46172	delivery	5	14
120957	2020-08-19 07:36:36	2020-08-19	17	[{"id_menu":4,"count":1}]	46224	delivery	5	22
120958	2020-08-19 07:37:12	2020-08-19	12	[{"id_menu":1,"count":1}]	38908	delivery	5	17
120959	2020-08-19 07:39:23	2020-08-19	12	[{"id_menu":1,"count":1}]	46097	delivery	5	17
120960	2020-08-19 07:40:19	2020-08-19	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	28851	delivery	5	37
120961	2020-08-19 07:43:12	2020-08-19	9	[{"id_menu":7,"count":2}]	36478	delivery	5	14
120962	2020-08-19 07:43:24	2020-08-19	14	[{"id_menu":2,"count":1}]	15232	delivery	5	19
120963	2020-08-19 07:44:10	2020-08-19	12	[{"id_menu":3,"count":1}]	28289	delivery	5	17
120964	2020-08-19 07:44:52	2020-08-19	9	[{"id_menu":6,"count":1}]	42964	delivery	5	14
120965	2020-08-19 07:45:41	2020-08-19	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	46117	delivery	5	35
120966	2020-08-19 07:45:44	2020-08-19	14	[{"id_menu":2,"count":1}]	292	delivery	5	19
120967	2020-08-19 07:45:44	2020-08-19	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	30933	delivery	5	43
120968	2020-08-19 07:45:50	2020-08-19	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	46041	delivery	5	40
120969	2020-08-19 07:46:07	2020-08-19	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1656	pick-up	0	21
120970	2020-08-19 07:46:44	2020-08-19	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	3926	pick-up	0	26
120971	2020-08-19 07:46:54	2020-08-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	26721	delivery	5	36
120972	2020-08-19 07:47:55	2020-08-19	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1477	delivery	5	29
120973	2020-08-19 07:53:52	2020-08-19	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	46277	delivery	5	40
120974	2020-08-19 07:54:22	2020-08-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	46193	delivery	5	22
120975	2020-08-19 07:57:08	2020-08-19	17	[{"id_menu":4,"count":2}]	24980	delivery	5	22
120976	2020-08-19 07:58:42	2020-08-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	26407	delivery	5	22
120977	2020-08-19 08:00:57	2020-08-19	12	[{"id_menu":3,"count":1}]	32144	pick-up	0	12
120978	2020-08-19 08:01:34	2020-08-19	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	46293	delivery	5	30
120979	2020-08-19 08:02:25	2020-08-19	9	[{"id_menu":6,"count":1}]	34979	delivery	5	14
120980	2020-08-19 08:03:25	2020-08-19	9	[{"id_menu":7,"count":1}]	46253	delivery	5	14
120981	2020-08-19 08:06:07	2020-08-19	8	[{"id_menu":5,"count":1}]	26359	delivery	5	13
120982	2020-08-19 08:07:22	2020-08-19	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	37098	delivery	5	31
120983	2020-08-19 08:08:11	2020-08-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	11582	delivery	5	28
120984	2020-08-19 08:08:36	2020-08-19	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	46135	delivery	5	36
120985	2020-08-19 08:09:17	2020-08-19	9	[{"id_menu":7,"count":1}]	18476	delivery	5	14
120986	2020-08-19 08:09:50	2020-08-19	12	[{"id_menu":1,"count":1}]	40304	pick-up	0	12
120987	2020-08-19 08:13:53	2020-08-19	9	[{"id_menu":7,"count":1}]	4048	delivery	5	14
120988	2020-08-19 08:19:18	2020-08-19	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	38417	pick-up	0	30
120989	2020-08-19 08:21:23	2020-08-19	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	26596	delivery	5	40
120990	2020-08-19 08:22:15	2020-08-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	38962	pick-up	0	17
120991	2020-08-19 08:24:02	2020-08-19	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	46229	delivery	5	40
120992	2020-08-19 08:24:02	2020-08-19	8	[{"id_menu":5,"count":1}]	1780	delivery	5	13
120993	2020-08-19 08:25:25	2020-08-19	9	[{"id_menu":7,"count":1}]	42423	delivery	5	14
120994	2020-08-19 08:25:58	2020-08-19	9	[{"id_menu":6,"count":1}]	46040	delivery	5	14
120995	2020-08-19 08:26:02	2020-08-19	9	[{"id_menu":7,"count":1}]	40605	pick-up	0	9
120996	2020-08-19 08:30:50	2020-08-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29639	delivery	5	22
120997	2020-08-19 08:31:39	2020-08-19	12	[{"id_menu":1,"count":1}]	30259	delivery	5	17
120998	2020-08-19 08:32:47	2020-08-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	46171	delivery	5	36
120999	2020-08-19 08:34:43	2020-08-19	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	36992	pick-up	0	21
121000	2020-08-19 08:34:54	2020-08-19	9	[{"id_menu":7,"count":1}]	28967	delivery	5	14
121001	2020-08-19 08:37:39	2020-08-19	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	13955	delivery	5	26
121002	2020-08-19 08:42:37	2020-08-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	46155	delivery	5	28
121003	2020-08-19 08:45:45	2020-08-19	14	[{"id_menu":2,"count":1}]	46065	pick-up	0	14
121004	2020-08-19 08:48:14	2020-08-19	9	[{"id_menu":6,"count":1}]	46177	pick-up	0	9
121005	2020-08-19 08:51:11	2020-08-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	46091	delivery	5	23
121006	2020-08-19 08:52:32	2020-08-19	14	[{"id_menu":2,"count":1}]	1527	pick-up	0	14
121007	2020-08-19 08:52:44	2020-08-19	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	3224	pick-up	0	21
121008	2020-08-19 08:57:38	2020-08-19	14	[{"id_menu":2,"count":1}]	46272	delivery	5	19
121009	2020-08-19 09:00:18	2020-08-19	9	[{"id_menu":7,"count":2}]	46292	pick-up	0	9
121010	2020-08-19 09:02:12	2020-08-19	12	[{"id_menu":1,"count":1}]	41710	delivery	5	17
121011	2020-08-19 09:04:37	2020-08-19	8	[{"id_menu":5,"count":1}]	45097	delivery	5	13
121012	2020-08-19 09:05:04	2020-08-19	14	[{"id_menu":2,"count":1}]	8071	pick-up	0	14
121013	2020-08-19 09:06:26	2020-08-19	12	[{"id_menu":3,"count":1}]	46296	delivery	5	17
121014	2020-08-19 09:06:53	2020-08-19	14	[{"id_menu":2,"count":1}]	15261	delivery	5	19
121015	2020-08-19 09:08:45	2020-08-19	9	[{"id_menu":6,"count":1}]	39410	delivery	5	14
121016	2020-08-19 09:09:37	2020-08-19	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	15965	delivery	5	46
121017	2020-08-19 09:15:49	2020-08-19	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16181	delivery	5	31
121018	2020-08-19 09:16:31	2020-08-19	9	[{"id_menu":6,"count":1}]	17760	delivery	5	14
121019	2020-08-19 09:19:01	2020-08-19	8	[{"id_menu":5,"count":1}]	20049	delivery	5	13
121020	2020-08-19 09:19:19	2020-08-19	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	37622	delivery	5	31
121021	2020-08-19 09:23:02	2020-08-19	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	27896	delivery	5	39
121022	2020-08-19 09:23:36	2020-08-19	12	[{"id_menu":1,"count":1}]	22332	delivery	5	17
121023	2020-08-19 09:25:23	2020-08-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	27020	delivery	5	36
121024	2020-08-19 09:26:59	2020-08-19	9	[{"id_menu":7,"count":1}]	46184	delivery	5	14
121025	2020-08-19 09:27:22	2020-08-19	12	[{"id_menu":3,"count":1}]	46134	pick-up	0	12
121026	2020-08-19 09:27:49	2020-08-19	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	46202	delivery	5	35
121027	2020-08-19 09:33:00	2020-08-19	9	[{"id_menu":6,"count":1}]	17475	delivery	5	14
121028	2020-08-19 09:33:28	2020-08-19	9	[{"id_menu":7,"count":1}]	10870	pick-up	0	9
121029	2020-08-19 09:37:49	2020-08-19	12	[{"id_menu":3,"count":1}]	14081	delivery	5	17
121030	2020-08-19 09:41:46	2020-08-19	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	34009	delivery	5	40
121031	2020-08-19 09:43:56	2020-08-19	9	[{"id_menu":7,"count":1}]	42415	delivery	5	14
121032	2020-08-19 09:43:57	2020-08-19	9	[{"id_menu":6,"count":1}]	880	delivery	5	14
121033	2020-08-19 09:46:31	2020-08-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	25598	delivery	5	22
121034	2020-08-19 09:49:36	2020-08-19	9	[{"id_menu":6,"count":1}]	4771	pick-up	0	9
121035	2020-08-19 09:49:52	2020-08-19	12	[{"id_menu":3,"count":1}]	46101	delivery	5	17
121036	2020-08-19 09:50:01	2020-08-19	12	[{"id_menu":1,"count":1}]	46168	delivery	5	17
121037	2020-08-19 09:53:09	2020-08-19	12	[{"id_menu":3,"count":1}]	46256	delivery	5	17
121038	2020-08-19 09:54:33	2020-08-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	171	delivery	5	28
121039	2020-08-19 09:55:40	2020-08-19	8	[{"id_menu":5,"count":1}]	46133	delivery	5	13
121040	2020-08-19 09:59:11	2020-08-19	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	46162	delivery	5	40
121041	2020-08-19 09:59:15	2020-08-19	17	[{"id_menu":4,"count":1}]	34534	pick-up	0	17
121042	2020-08-19 10:09:31	2020-08-19	17	[{"id_menu":4,"count":1}]	46248	delivery	5	22
121043	2020-08-19 10:13:12	2020-08-19	9	[{"id_menu":7,"count":1}]	1030	pick-up	0	9
121044	2020-08-19 10:13:39	2020-08-19	9	[{"id_menu":7,"count":1}]	46211	delivery	5	14
121045	2020-08-19 10:15:25	2020-08-19	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	35010	delivery	5	40
121046	2020-08-19 10:15:51	2020-08-19	12	[{"id_menu":1,"count":1}]	12944	delivery	5	17
121047	2020-08-19 10:17:00	2020-08-19	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	46076	delivery	5	39
121048	2020-08-19 10:17:23	2020-08-19	17	[{"id_menu":4,"count":1}]	13136	pick-up	0	17
121049	2020-08-19 10:17:25	2020-08-19	12	[{"id_menu":1,"count":1}]	46225	delivery	5	17
121050	2020-08-19 10:19:24	2020-08-19	17	[{"id_menu":4,"count":1}]	12519	delivery	5	22
121051	2020-08-19 10:20:51	2020-08-19	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	23583	delivery	5	40
121052	2020-08-19 10:23:42	2020-08-19	17	[{"id_menu":4,"count":1}]	12236	delivery	5	22
121053	2020-08-19 10:24:57	2020-08-19	14	[{"id_menu":2,"count":1}]	19514	pick-up	0	14
121054	2020-08-19 10:25:15	2020-08-19	9	[{"id_menu":6,"count":1}]	32449	delivery	5	14
121055	2020-08-19 10:25:35	2020-08-19	12	[{"id_menu":3,"count":1}]	835	pick-up	0	12
121056	2020-08-19 10:26:16	2020-08-19	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	20852	delivery	5	34
121057	2020-08-19 10:29:00	2020-08-19	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	46141	delivery	5	39
121058	2020-08-19 10:29:41	2020-08-19	17	[{"id_menu":4,"count":1}]	7206	pick-up	0	17
121059	2020-08-19 10:30:00	2020-08-19	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	46210	delivery	5	26
121060	2020-08-19 10:30:14	2020-08-19	14	[{"id_menu":2,"count":1}]	8145	delivery	5	19
121061	2020-08-19 10:30:52	2020-08-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	46240	delivery	5	31
121062	2020-08-19 10:31:59	2020-08-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	46189	delivery	5	28
121063	2020-08-19 10:32:47	2020-08-19	9	[{"id_menu":6,"count":1}]	46216	delivery	5	14
121064	2020-08-19 10:38:22	2020-08-19	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	10101	delivery	5	34
121065	2020-08-19 10:40:05	2020-08-19	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	46157	pick-up	0	26
121066	2020-08-19 10:41:09	2020-08-19	12	[{"id_menu":3,"count":1}]	4421	delivery	5	17
121067	2020-08-19 10:43:26	2020-08-19	9	[{"id_menu":6,"count":1}]	10281	pick-up	0	9
121068	2020-08-19 10:44:33	2020-08-19	9	[{"id_menu":6,"count":1}]	46259	delivery	5	14
121069	2020-08-19 10:47:40	2020-08-19	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	46284	delivery	5	31
121070	2020-08-19 10:47:56	2020-08-19	9	[{"id_menu":6,"count":1}]	46207	delivery	5	14
121071	2020-08-19 10:48:33	2020-08-19	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39272	delivery	5	31
121072	2020-08-19 10:50:50	2020-08-19	9	[{"id_menu":7,"count":1}]	46062	delivery	5	14
121073	2020-08-19 10:50:56	2020-08-19	9	[{"id_menu":7,"count":1}]	11391	delivery	5	14
121074	2020-08-19 10:52:27	2020-08-19	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	45734	delivery	5	39
121075	2020-08-19 10:53:14	2020-08-19	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22124	delivery	5	31
121076	2020-08-19 10:53:59	2020-08-19	8	[{"id_menu":5,"count":1}]	20161	delivery	5	13
121077	2020-08-19 10:54:08	2020-08-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	46260	delivery	5	36
121078	2020-08-19 10:55:42	2020-08-19	14	[{"id_menu":2,"count":1}]	6342	pick-up	0	14
121079	2020-08-19 10:57:35	2020-08-19	9	[{"id_menu":6,"count":1}]	46271	delivery	5	14
121080	2020-08-19 11:00:45	2020-08-19	9	[{"id_menu":7,"count":1}]	42527	delivery	5	14
121081	2020-08-19 11:06:43	2020-08-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	46252	delivery	5	28
121082	2020-08-19 11:07:12	2020-08-19	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11873	delivery	5	36
121083	2020-08-19 11:07:46	2020-08-19	9	[{"id_menu":6,"count":3}]	46246	delivery	5	14
121084	2020-08-19 11:10:47	2020-08-19	9	[{"id_menu":6,"count":1}]	33015	delivery	5	14
121085	2020-08-19 11:12:05	2020-08-19	8	[{"id_menu":5,"count":1}]	8030	pick-up	0	8
121086	2020-08-19 11:14:31	2020-08-19	12	[{"id_menu":1,"count":1}]	46105	delivery	5	17
121087	2020-08-19 11:20:40	2020-08-19	9	[{"id_menu":6,"count":1}]	27137	delivery	5	14
121088	2020-08-19 11:20:57	2020-08-19	9	[{"id_menu":7,"count":1}]	43468	delivery	5	14
121089	2020-08-19 11:28:39	2020-08-19	17	[{"id_menu":4,"count":1}]	9141	delivery	5	22
121090	2020-08-19 11:29:16	2020-08-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13752	delivery	5	22
121091	2020-08-19 11:29:33	2020-08-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	46244	delivery	5	23
121092	2020-08-19 11:31:20	2020-08-19	14	[{"id_menu":2,"count":1}]	46179	delivery	5	19
121093	2020-08-19 11:34:39	2020-08-19	12	[{"id_menu":1,"count":1}]	21345	delivery	5	17
121094	2020-08-19 11:34:51	2020-08-19	14	[{"id_menu":2,"count":1}]	46174	delivery	5	19
121095	2020-08-19 11:37:18	2020-08-19	12	[{"id_menu":3,"count":2}]	6070	delivery	5	17
121096	2020-08-19 11:41:34	2020-08-19	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	37456	delivery	5	44
121097	2020-08-19 11:42:57	2020-08-19	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	33560	delivery	5	30
121098	2020-08-19 11:43:41	2020-08-19	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	46043	delivery	5	26
121099	2020-08-19 11:48:19	2020-08-19	8	[{"id_menu":5,"count":1}]	3507	delivery	5	13
121100	2020-08-19 11:49:12	2020-08-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	46087	delivery	5	31
121101	2020-08-19 11:50:47	2020-08-19	12	[{"id_menu":3,"count":1}]	40332	delivery	5	17
121102	2020-08-19 11:54:34	2020-08-19	14	[{"id_menu":2,"count":1}]	4836	delivery	5	19
121103	2020-08-19 11:54:39	2020-08-19	9	[{"id_menu":7,"count":1}]	23482	delivery	5	14
121104	2020-08-19 12:02:00	2020-08-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	46080	pick-up	0	17
121105	2020-08-19 12:03:14	2020-08-19	8	[{"id_menu":5,"count":1}]	12536	delivery	5	13
121106	2020-08-19 12:03:59	2020-08-19	17	[{"id_menu":4,"count":1}]	32187	delivery	5	22
121107	2020-08-19 12:06:41	2020-08-19	8	[{"id_menu":5,"count":1}]	43460	delivery	5	13
121108	2020-08-19 12:15:04	2020-08-19	12	[{"id_menu":1,"count":1}]	46215	delivery	5	17
121109	2020-08-19 12:16:21	2020-08-19	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2094	pick-up	0	35
121110	2020-08-19 12:17:31	2020-08-19	12	[{"id_menu":1,"count":1}]	22560	delivery	5	17
121111	2020-08-19 12:22:39	2020-08-19	9	[{"id_menu":6,"count":3}]	40727	delivery	5	14
121112	2020-08-19 12:25:28	2020-08-19	9	[{"id_menu":7,"count":2}]	27013	delivery	5	14
121113	2020-08-19 12:25:33	2020-08-19	12	[{"id_menu":1,"count":1}]	18392	delivery	5	17
121114	2020-08-19 12:26:59	2020-08-19	8	[{"id_menu":5,"count":1}]	43358	delivery	5	13
121115	2020-08-19 12:31:38	2020-08-19	12	[{"id_menu":1,"count":1}]	45853	delivery	5	17
121116	2020-08-19 12:31:43	2020-08-19	8	[{"id_menu":5,"count":1}]	23900	delivery	5	13
121117	2020-08-19 12:34:47	2020-08-19	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	388	delivery	5	37
121118	2020-08-19 12:37:01	2020-08-19	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	46127	delivery	5	29
121119	2020-08-19 12:37:53	2020-08-19	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	20792	delivery	5	45
121120	2020-08-19 12:41:03	2020-08-19	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	46245	delivery	5	40
121121	2020-08-19 12:41:30	2020-08-19	8	[{"id_menu":5,"count":1}]	30704	delivery	5	13
121122	2020-08-19 12:42:37	2020-08-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	26411	delivery	5	28
121123	2020-08-19 12:46:50	2020-08-19	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	17003	delivery	5	35
121124	2020-08-19 12:49:26	2020-08-19	9	[{"id_menu":6,"count":1}]	1407	pick-up	0	9
121125	2020-08-19 13:00:22	2020-08-19	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	46102	delivery	5	34
121126	2020-08-19 13:01:20	2020-08-19	12	[{"id_menu":1,"count":1}]	23399	delivery	5	17
121127	2020-08-19 13:02:07	2020-08-19	9	[{"id_menu":7,"count":1}]	43089	delivery	5	14
121128	2020-08-19 13:06:11	2020-08-19	12	[{"id_menu":3,"count":1}]	14410	pick-up	0	12
121129	2020-08-19 13:09:01	2020-08-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	30841	delivery	5	28
121130	2020-08-19 13:10:45	2020-08-19	17	[{"id_menu":4,"count":1}]	5306	delivery	5	22
121131	2020-08-19 13:11:40	2020-08-19	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	25550	delivery	5	31
121132	2020-08-19 13:13:37	2020-08-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6097	pick-up	0	18
121133	2020-08-19 13:19:59	2020-08-19	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	46182	delivery	5	25
121134	2020-08-19 13:20:47	2020-08-19	17	[{"id_menu":4,"count":1}]	12905	pick-up	0	17
121135	2020-08-19 13:25:19	2020-08-19	17	[{"id_menu":4,"count":1}]	25115	delivery	5	22
121136	2020-08-19 13:27:53	2020-08-19	17	[{"id_menu":4,"count":1}]	46243	delivery	5	22
121137	2020-08-19 13:30:29	2020-08-19	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	27620	delivery	5	31
121138	2020-08-19 13:32:32	2020-08-19	9	[{"id_menu":7,"count":1}]	9009	delivery	5	14
121139	2020-08-19 13:33:58	2020-08-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	46083	delivery	5	22
121140	2020-08-19 13:34:07	2020-08-19	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	13188	delivery	5	31
121141	2020-08-19 13:34:28	2020-08-19	14	[{"id_menu":2,"count":1}]	575	pick-up	0	14
121142	2020-08-19 13:36:02	2020-08-19	17	[{"id_menu":4,"count":1}]	46206	delivery	5	22
121143	2020-08-19 13:36:13	2020-08-19	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	17920	delivery	5	26
121144	2020-08-19 13:42:08	2020-08-19	9	[{"id_menu":7,"count":1}]	33221	delivery	5	14
121145	2020-08-19 13:43:14	2020-08-19	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37577	delivery	5	52
121146	2020-08-19 13:43:22	2020-08-19	9	[{"id_menu":6,"count":1}]	21165	delivery	5	14
121147	2020-08-19 13:45:15	2020-08-19	8	[{"id_menu":5,"count":1}]	11652	pick-up	0	8
121148	2020-08-19 13:47:10	2020-08-19	9	[{"id_menu":6,"count":1}]	46118	delivery	5	14
121149	2020-08-19 13:47:24	2020-08-19	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	46175	delivery	5	36
121150	2020-08-19 13:48:04	2020-08-19	9	[{"id_menu":7,"count":1}]	46052	delivery	5	14
121151	2020-08-19 13:48:54	2020-08-19	12	[{"id_menu":3,"count":1}]	46213	delivery	5	17
121152	2020-08-19 13:52:11	2020-08-19	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	29797	delivery	5	45
121153	2020-08-19 13:53:07	2020-08-19	14	[{"id_menu":2,"count":1}]	33453	pick-up	0	14
121154	2020-08-19 13:53:11	2020-08-19	9	[{"id_menu":7,"count":1}]	46209	delivery	5	14
121155	2020-08-19 13:59:45	2020-08-19	17	[{"id_menu":4,"count":1}]	39702	delivery	5	22
121156	2020-08-19 14:02:56	2020-08-19	8	[{"id_menu":5,"count":1}]	40298	delivery	5	13
121157	2020-08-19 14:04:00	2020-08-19	12	[{"id_menu":1,"count":1}]	18177	delivery	5	17
121158	2020-08-19 14:06:13	2020-08-19	17	[{"id_menu":4,"count":1}]	28413	delivery	5	22
121159	2020-08-19 14:09:08	2020-08-19	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14025	delivery	5	40
121160	2020-08-19 14:09:24	2020-08-19	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	40115	delivery	5	43
121161	2020-08-19 14:10:00	2020-08-19	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30154	delivery	5	52
121162	2020-08-19 14:10:27	2020-08-19	12	[{"id_menu":3,"count":1}]	44655	pick-up	0	12
121163	2020-08-19 14:11:51	2020-08-19	14	[{"id_menu":2,"count":1}]	5949	delivery	5	19
121164	2020-08-19 14:12:27	2020-08-19	8	[{"id_menu":5,"count":1}]	11287	pick-up	0	8
121165	2020-08-19 14:15:30	2020-08-19	8	[{"id_menu":5,"count":1}]	46113	pick-up	0	8
121166	2020-08-19 14:17:31	2020-08-19	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	46217	delivery	5	40
121167	2020-08-19 14:17:52	2020-08-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	21515	pick-up	0	23
121168	2020-08-19 14:19:17	2020-08-19	12	[{"id_menu":1,"count":1}]	228	pick-up	0	12
121169	2020-08-19 14:20:50	2020-08-19	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	45998	delivery	5	31
121170	2020-08-19 14:21:50	2020-08-19	14	[{"id_menu":2,"count":2}]	11239	pick-up	0	14
121171	2020-08-19 14:30:29	2020-08-19	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	46126	delivery	5	30
121172	2020-08-19 14:30:52	2020-08-19	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	38815	pick-up	0	26
121173	2020-08-19 14:31:37	2020-08-19	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39044	delivery	5	45
121174	2020-08-19 14:32:14	2020-08-19	12	[{"id_menu":1,"count":1}]	22320	pick-up	0	12
121175	2020-08-19 14:32:36	2020-08-19	8	[{"id_menu":5,"count":3}]	44274	delivery	5	13
121176	2020-08-19 14:32:46	2020-08-19	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	6990	delivery	5	34
121177	2020-08-19 14:32:53	2020-08-19	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	31822	delivery	5	26
121178	2020-08-19 14:36:13	2020-08-19	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	46181	delivery	5	52
121179	2020-08-19 14:38:27	2020-08-19	9	[{"id_menu":7,"count":1}]	15282	delivery	5	14
121180	2020-08-19 14:38:32	2020-08-19	9	[{"id_menu":6,"count":1}]	46262	delivery	5	14
121181	2020-08-19 14:39:10	2020-08-19	9	[{"id_menu":6,"count":1}]	46176	delivery	5	14
121182	2020-08-19 14:41:25	2020-08-19	12	[{"id_menu":1,"count":1}]	15563	delivery	5	17
121183	2020-08-19 14:42:41	2020-08-19	9	[{"id_menu":6,"count":1}]	10882	pick-up	0	9
121184	2020-08-19 14:43:39	2020-08-19	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	33282	delivery	5	31
121185	2020-08-19 14:44:58	2020-08-19	12	[{"id_menu":1,"count":1}]	2299	delivery	5	17
121186	2020-08-19 14:45:25	2020-08-19	17	[{"id_menu":4,"count":1}]	44114	pick-up	0	17
121187	2020-08-19 14:50:41	2020-08-19	8	[{"id_menu":5,"count":1}]	1700	pick-up	0	8
121188	2020-08-19 14:51:18	2020-08-19	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":2}]	46198	delivery	5	22
121189	2020-08-19 14:52:53	2020-08-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	39103	pick-up	0	23
121190	2020-08-19 14:53:45	2020-08-19	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	691	delivery	5	39
121191	2020-08-19 14:54:06	2020-08-19	9	[{"id_menu":6,"count":1}]	6376	delivery	5	14
121192	2020-08-19 14:57:27	2020-08-19	9	[{"id_menu":6,"count":1}]	11756	delivery	5	14
121193	2020-08-19 14:57:45	2020-08-19	9	[{"id_menu":7,"count":1}]	2022	pick-up	0	9
121194	2020-08-19 15:00:41	2020-08-19	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	544	delivery	5	37
121195	2020-08-19 15:01:58	2020-08-19	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	46150	delivery	5	54
121196	2020-08-19 15:02:46	2020-08-19	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	4411	delivery	5	26
121197	2020-08-19 15:05:56	2020-08-19	9	[{"id_menu":6,"count":1}]	11147	delivery	5	14
121198	2020-08-19 15:06:52	2020-08-19	12	[{"id_menu":3,"count":2}]	12849	delivery	5	17
121199	2020-08-19 15:11:05	2020-08-19	12	[{"id_menu":1,"count":1}]	46122	delivery	5	17
121200	2020-08-19 15:11:17	2020-08-19	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	43826	delivery	5	30
121201	2020-08-19 15:12:40	2020-08-19	12	[{"id_menu":3,"count":1}]	31581	delivery	5	17
121202	2020-08-19 15:19:00	2020-08-19	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	40862	delivery	5	43
121203	2020-08-19 15:21:48	2020-08-19	9	[{"id_menu":6,"count":1}]	46050	delivery	5	14
121204	2020-08-19 15:23:23	2020-08-19	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	45324	delivery	5	25
121205	2020-08-19 15:24:00	2020-08-19	12	[{"id_menu":3,"count":1}]	3449	pick-up	0	12
121206	2020-08-19 15:24:33	2020-08-19	9	[{"id_menu":7,"count":1}]	46067	delivery	5	14
121207	2020-08-19 15:25:10	2020-08-19	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	32067	pick-up	0	21
121208	2020-08-19 15:25:39	2020-08-19	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	12606	delivery	5	25
121209	2020-08-19 15:28:43	2020-08-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	16004	delivery	5	22
121210	2020-08-19 15:29:18	2020-08-19	17	[{"id_menu":4,"count":1}]	15571	delivery	5	22
121211	2020-08-19 15:33:43	2020-08-19	9	[{"id_menu":7,"count":1}]	46178	pick-up	0	9
121212	2020-08-19 15:33:50	2020-08-19	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	27231	delivery	5	26
121213	2020-08-19 15:36:47	2020-08-19	9	[{"id_menu":7,"count":1}]	28756	delivery	5	14
121214	2020-08-19 15:36:59	2020-08-19	14	[{"id_menu":2,"count":1}]	5758	pick-up	0	14
121215	2020-08-19 15:38:05	2020-08-19	17	[{"id_menu":4,"count":1}]	314	pick-up	0	17
121216	2020-08-19 15:40:14	2020-08-19	8	[{"id_menu":5,"count":1}]	11760	delivery	5	13
121217	2020-08-19 15:41:05	2020-08-19	12	[{"id_menu":3,"count":1}]	19488	delivery	5	17
121218	2020-08-19 15:41:07	2020-08-19	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	24355	delivery	5	40
121219	2020-08-19 15:41:46	2020-08-19	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	25441	delivery	5	26
121220	2020-08-19 15:42:00	2020-08-19	9	[{"id_menu":6,"count":1}]	46165	delivery	5	14
121221	2020-08-19 15:42:03	2020-08-19	8	[{"id_menu":5,"count":1}]	260	pick-up	0	8
121222	2020-08-19 15:42:32	2020-08-19	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	25157	delivery	5	26
121223	2020-08-19 15:45:10	2020-08-19	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	46203	delivery	5	22
121224	2020-08-19 15:45:22	2020-08-19	9	[{"id_menu":6,"count":1}]	30070	delivery	5	14
121225	2020-08-19 15:46:53	2020-08-19	9	[{"id_menu":7,"count":1}]	46274	delivery	5	14
121226	2020-08-19 15:47:08	2020-08-19	17	[{"id_menu":4,"count":1}]	26252	pick-up	0	17
121227	2020-08-19 15:50:49	2020-08-19	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	37437	delivery	5	51
121228	2020-08-19 15:52:17	2020-08-19	9	[{"id_menu":6,"count":1}]	34750	delivery	5	14
121229	2020-08-19 15:54:24	2020-08-19	9	[{"id_menu":7,"count":1}]	46265	delivery	5	14
121230	2020-08-19 15:55:12	2020-08-19	9	[{"id_menu":6,"count":1}]	46074	delivery	5	14
121231	2020-08-19 15:57:56	2020-08-19	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	10723	delivery	5	31
121232	2020-08-19 16:00:40	2020-08-19	12	[{"id_menu":1,"count":1}]	2149	pick-up	0	12
121233	2020-08-19 16:04:02	2020-08-19	9	[{"id_menu":7,"count":1}]	19056	delivery	5	14
121234	2020-08-19 16:04:47	2020-08-19	9	[{"id_menu":6,"count":1}]	10764	delivery	5	14
121235	2020-08-19 16:08:40	2020-08-19	9	[{"id_menu":7,"count":1}]	15788	delivery	5	14
121236	2020-08-19 16:12:04	2020-08-19	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	482	delivery	5	40
121237	2020-08-19 16:15:17	2020-08-19	9	[{"id_menu":6,"count":1}]	46089	delivery	5	14
121238	2020-08-19 16:16:44	2020-08-19	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	12612	delivery	5	40
121239	2020-08-19 16:18:07	2020-08-19	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	28959	delivery	5	48
121240	2020-08-19 16:19:31	2020-08-19	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	46119	delivery	5	48
121241	2020-08-19 16:19:52	2020-08-19	14	[{"id_menu":2,"count":1}]	38909	delivery	5	19
121242	2020-08-19 16:22:27	2020-08-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	12145	delivery	5	28
121243	2020-08-19 16:24:42	2020-08-19	17	[{"id_menu":4,"count":1}]	1040	pick-up	0	17
121244	2020-08-19 16:26:36	2020-08-19	8	[{"id_menu":5,"count":1}]	3431	delivery	5	13
121245	2020-08-19 16:30:37	2020-08-19	14	[{"id_menu":2,"count":1}]	22748	delivery	5	19
121246	2020-08-19 16:31:43	2020-08-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	46108	delivery	5	31
121247	2020-08-19 16:33:06	2020-08-19	9	[{"id_menu":6,"count":1}]	10260	delivery	5	14
121248	2020-08-19 16:33:30	2020-08-19	12	[{"id_menu":1,"count":1}]	6909	delivery	5	17
121249	2020-08-19 16:34:45	2020-08-19	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	46053	delivery	5	40
121250	2020-08-19 16:36:53	2020-08-19	12	[{"id_menu":3,"count":1}]	18736	delivery	5	17
121251	2020-08-19 16:43:05	2020-08-19	9	[{"id_menu":6,"count":1}]	46235	delivery	5	14
121252	2020-08-19 16:46:26	2020-08-19	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	9847	pick-up	0	43
121253	2020-08-19 16:46:47	2020-08-19	14	[{"id_menu":2,"count":1}]	46212	delivery	5	19
121254	2020-08-19 16:47:18	2020-08-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16718	delivery	5	22
121255	2020-08-19 16:49:38	2020-08-19	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	27950	delivery	5	43
121256	2020-08-19 16:49:50	2020-08-19	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20742	delivery	5	40
121257	2020-08-19 16:50:31	2020-08-19	12	[{"id_menu":3,"count":1}]	7388	delivery	5	17
121258	2020-08-19 16:52:57	2020-08-19	9	[{"id_menu":6,"count":1}]	20705	delivery	5	14
121259	2020-08-19 16:55:48	2020-08-19	9	[{"id_menu":6,"count":3}]	16046	delivery	5	14
121260	2020-08-19 16:55:54	2020-08-19	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	45014	delivery	5	25
121261	2020-08-19 16:56:05	2020-08-19	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	32344	delivery	5	25
121262	2020-08-19 16:57:17	2020-08-19	17	[{"id_menu":4,"count":1}]	7749	delivery	5	22
121263	2020-08-19 16:58:47	2020-08-19	14	[{"id_menu":2,"count":1}]	6410	pick-up	0	14
121264	2020-08-19 16:59:38	2020-08-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	46154	pick-up	0	26
121265	2020-08-19 17:02:21	2020-08-19	12	[{"id_menu":3,"count":1}]	46061	delivery	5	17
121266	2020-08-19 17:03:00	2020-08-19	17	[{"id_menu":4,"count":1}]	32649	delivery	5	22
121267	2020-08-19 17:03:06	2020-08-19	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	25580	pick-up	0	26
121268	2020-08-19 17:03:54	2020-08-19	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20811	delivery	5	45
121269	2020-08-19 17:04:31	2020-08-19	8	[{"id_menu":5,"count":1}]	12490	delivery	5	13
121270	2020-08-19 17:04:52	2020-08-19	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	46098	pick-up	0	25
121271	2020-08-19 17:05:14	2020-08-19	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	46167	delivery	5	31
121272	2020-08-19 17:06:53	2020-08-19	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	46110	delivery	5	39
121273	2020-08-19 17:06:59	2020-08-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	41906	delivery	5	28
121274	2020-08-19 17:09:24	2020-08-19	8	[{"id_menu":5,"count":1}]	6343	delivery	5	13
121275	2020-08-19 17:11:13	2020-08-19	9	[{"id_menu":7,"count":1}]	46044	delivery	5	14
121276	2020-08-19 17:12:44	2020-08-19	9	[{"id_menu":7,"count":1}]	16362	pick-up	0	9
121277	2020-08-19 17:16:21	2020-08-19	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	46156	delivery	5	31
121278	2020-08-19 17:22:37	2020-08-19	9	[{"id_menu":7,"count":1}]	1387	delivery	5	14
121279	2020-08-19 17:23:01	2020-08-19	8	[{"id_menu":5,"count":1}]	38627	delivery	5	13
121280	2020-08-19 17:23:35	2020-08-19	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	46161	delivery	5	43
121281	2020-08-19 17:27:19	2020-08-19	9	[{"id_menu":6,"count":1}]	491	pick-up	0	9
121282	2020-08-19 17:28:48	2020-08-19	9	[{"id_menu":7,"count":1}]	46099	delivery	5	14
121283	2020-08-19 17:33:13	2020-08-19	9	[{"id_menu":6,"count":1}]	46278	delivery	5	14
121284	2020-08-19 17:36:32	2020-08-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	46273	delivery	5	22
121285	2020-08-19 17:37:57	2020-08-19	12	[{"id_menu":3,"count":1}]	45202	delivery	5	17
121286	2020-08-19 17:40:30	2020-08-19	12	[{"id_menu":3,"count":1}]	12841	delivery	5	17
121287	2020-08-19 17:40:43	2020-08-19	9	[{"id_menu":7,"count":1}]	46079	delivery	5	14
121288	2020-08-19 17:42:13	2020-08-19	12	[{"id_menu":3,"count":2}]	12031	delivery	5	17
121289	2020-08-19 17:42:21	2020-08-19	9	[{"id_menu":7,"count":1}]	23521	pick-up	0	9
121290	2020-08-19 17:45:17	2020-08-19	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	5421	pick-up	0	26
121291	2020-08-19 17:48:04	2020-08-19	8	[{"id_menu":5,"count":1}]	42074	delivery	5	13
121292	2020-08-19 17:49:33	2020-08-19	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	46230	delivery	5	26
121293	2020-08-19 17:50:35	2020-08-19	17	[{"id_menu":4,"count":1}]	35703	pick-up	0	17
121294	2020-08-19 17:50:38	2020-08-19	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	46268	delivery	5	26
121295	2020-08-19 17:52:16	2020-08-19	9	[{"id_menu":6,"count":2}]	11254	delivery	5	14
121296	2020-08-19 17:52:49	2020-08-19	9	[{"id_menu":6,"count":1}]	30710	delivery	5	14
121297	2020-08-19 17:54:43	2020-08-19	17	[{"id_menu":4,"count":1}]	46068	delivery	5	22
121298	2020-08-19 17:57:31	2020-08-19	34	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	46046	delivery	5	39
121299	2020-08-19 17:59:28	2020-08-19	9	[{"id_menu":6,"count":1}]	32673	delivery	5	14
121300	2020-08-19 18:00:39	2020-08-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	27694	delivery	5	36
121301	2020-08-19 18:02:05	2020-08-19	12	[{"id_menu":1,"count":1}]	46238	delivery	5	17
121302	2020-08-19 18:06:27	2020-08-19	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":2}]	46070	delivery	5	31
121303	2020-08-19 18:08:08	2020-08-19	9	[{"id_menu":6,"count":1}]	46249	delivery	5	14
121304	2020-08-19 18:10:53	2020-08-19	9	[{"id_menu":7,"count":1}]	32402	pick-up	0	9
121305	2020-08-19 18:11:38	2020-08-19	9	[{"id_menu":7,"count":2}]	29702	pick-up	0	9
121306	2020-08-19 18:12:25	2020-08-19	12	[{"id_menu":3,"count":1}]	15812	delivery	5	17
121307	2020-08-19 18:12:47	2020-08-19	12	[{"id_menu":3,"count":1}]	34157	delivery	5	17
121308	2020-08-19 18:13:14	2020-08-19	14	[{"id_menu":2,"count":1}]	43334	delivery	5	19
121309	2020-08-19 18:24:58	2020-08-19	12	[{"id_menu":1,"count":1}]	46094	delivery	5	17
121310	2020-08-19 18:25:15	2020-08-19	9	[{"id_menu":7,"count":1}]	46152	delivery	5	14
121311	2020-08-19 18:25:45	2020-08-19	9	[{"id_menu":6,"count":1}]	807	pick-up	0	9
121312	2020-08-19 18:26:05	2020-08-19	12	[{"id_menu":3,"count":1}]	2045	delivery	5	17
121313	2020-08-19 18:26:46	2020-08-19	8	[{"id_menu":5,"count":1}]	40068	delivery	5	13
121314	2020-08-19 18:27:32	2020-08-19	9	[{"id_menu":7,"count":1}]	24890	pick-up	0	9
121315	2020-08-19 18:29:09	2020-08-19	17	[{"id_menu":4,"count":1}]	46276	pick-up	0	17
121316	2020-08-19 18:31:21	2020-08-19	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	36207	pick-up	0	26
121317	2020-08-19 18:31:42	2020-08-19	9	[{"id_menu":7,"count":1}]	25141	pick-up	0	9
121318	2020-08-19 18:32:50	2020-08-19	17	[{"id_menu":4,"count":1}]	15744	delivery	5	22
121319	2020-08-19 18:34:50	2020-08-19	8	[{"id_menu":5,"count":1}]	26603	pick-up	0	8
121320	2020-08-19 18:37:11	2020-08-19	12	[{"id_menu":1,"count":1}]	46111	delivery	5	17
121321	2020-08-19 18:40:08	2020-08-19	9	[{"id_menu":6,"count":1}]	45236	delivery	5	14
121322	2020-08-19 18:40:43	2020-08-19	9	[{"id_menu":6,"count":1}]	1072	pick-up	0	9
121323	2020-08-19 18:41:11	2020-08-19	9	[{"id_menu":6,"count":1}]	29198	pick-up	0	9
121324	2020-08-19 18:43:24	2020-08-19	17	[{"id_menu":4,"count":1}]	15191	delivery	5	22
121325	2020-08-19 18:45:19	2020-08-19	8	[{"id_menu":5,"count":1}]	22778	delivery	5	13
121326	2020-08-19 18:47:51	2020-08-19	12	[{"id_menu":3,"count":1}]	46264	delivery	5	17
121327	2020-08-19 18:49:12	2020-08-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3604	delivery	5	28
121328	2020-08-19 18:56:11	2020-08-19	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	46166	delivery	5	36
121329	2020-08-19 18:56:12	2020-08-19	8	[{"id_menu":5,"count":2}]	33085	delivery	5	13
121330	2020-08-19 18:59:11	2020-08-19	9	[{"id_menu":6,"count":2}]	27825	delivery	5	14
121331	2020-08-19 18:59:27	2020-08-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	46239	delivery	5	31
121332	2020-08-19 18:59:43	2020-08-19	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16137	delivery	5	45
121333	2020-08-19 19:00:53	2020-08-19	9	[{"id_menu":6,"count":1}]	16531	delivery	5	14
121334	2020-08-19 19:00:58	2020-08-19	9	[{"id_menu":7,"count":1}]	10901	delivery	5	14
121335	2020-08-19 19:02:58	2020-08-19	12	[{"id_menu":3,"count":1}]	33144	delivery	5	17
121336	2020-08-19 19:03:49	2020-08-19	14	[{"id_menu":2,"count":2}]	24827	delivery	5	19
121337	2020-08-19 19:07:09	2020-08-19	9	[{"id_menu":6,"count":2}]	1085	pick-up	0	9
121338	2020-08-19 19:07:55	2020-08-19	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	25180	delivery	5	40
121339	2020-08-19 19:12:31	2020-08-19	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	46191	delivery	5	26
121340	2020-08-19 19:13:04	2020-08-19	9	[{"id_menu":7,"count":1}]	46066	delivery	5	14
121341	2020-08-19 19:17:48	2020-08-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	36541	delivery	5	22
121342	2020-08-19 19:19:18	2020-08-19	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	13466	delivery	5	43
121343	2020-08-19 19:20:41	2020-08-19	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	32283	delivery	5	25
121344	2020-08-19 19:20:48	2020-08-19	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	45873	delivery	5	25
121345	2020-08-19 19:21:00	2020-08-19	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	46291	delivery	5	38
121346	2020-08-19 19:23:04	2020-08-19	9	[{"id_menu":6,"count":1}]	43447	delivery	5	14
121347	2020-08-19 19:29:42	2020-08-19	9	[{"id_menu":7,"count":1}]	19978	delivery	5	14
121348	2020-08-19 19:30:48	2020-08-19	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	46220	delivery	5	31
121349	2020-08-19 19:34:42	2020-08-19	8	[{"id_menu":5,"count":2}]	46257	delivery	5	13
121350	2020-08-19 19:35:11	2020-08-19	9	[{"id_menu":6,"count":1}]	46064	delivery	5	14
121351	2020-08-19 19:41:09	2020-08-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	274	pick-up	0	17
121352	2020-08-19 19:42:01	2020-08-19	17	[{"id_menu":4,"count":1}]	16905	delivery	5	22
121353	2020-08-19 19:42:25	2020-08-19	14	[{"id_menu":2,"count":1}]	6399	delivery	5	19
121354	2020-08-19 19:42:52	2020-08-19	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12196	delivery	5	34
121355	2020-08-19 19:46:00	2020-08-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	5570	delivery	5	28
121356	2020-08-19 19:46:19	2020-08-19	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	16031	delivery	5	56
121357	2020-08-19 19:49:47	2020-08-19	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11150	delivery	5	35
121358	2020-08-19 19:51:55	2020-08-19	17	[{"id_menu":4,"count":1}]	46109	pick-up	0	17
121359	2020-08-19 19:56:35	2020-08-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6959	delivery	5	22
121360	2020-08-19 19:57:05	2020-08-19	12	[{"id_menu":1,"count":1}]	33767	delivery	5	17
121361	2020-08-19 19:57:13	2020-08-19	9	[{"id_menu":7,"count":1}]	1562	pick-up	0	9
121362	2020-08-19 20:06:24	2020-08-19	8	[{"id_menu":5,"count":1}]	46290	delivery	5	13
121363	2020-08-19 20:06:29	2020-08-19	12	[{"id_menu":3,"count":1}]	46214	delivery	5	17
121364	2020-08-19 20:08:47	2020-08-19	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	38169	delivery	5	31
121365	2020-08-19 20:11:06	2020-08-19	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	36451	delivery	5	51
121366	2020-08-19 20:11:41	2020-08-19	14	[{"id_menu":2,"count":1}]	45032	delivery	5	19
121367	2020-08-19 20:15:23	2020-08-19	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	3324	pick-up	0	23
121368	2020-08-19 20:17:19	2020-08-19	9	[{"id_menu":6,"count":1}]	1633	delivery	5	14
121369	2020-08-19 20:17:47	2020-08-19	9	[{"id_menu":7,"count":1}]	16644	delivery	5	14
121370	2020-08-19 20:18:04	2020-08-19	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	46144	delivery	5	26
121371	2020-08-19 20:18:25	2020-08-19	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	26867	delivery	5	43
121372	2020-08-19 20:25:43	2020-08-19	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	43252	delivery	5	34
121373	2020-08-19 20:25:53	2020-08-19	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	14105	pick-up	0	24
121374	2020-08-19 20:26:14	2020-08-19	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	44743	delivery	5	25
121375	2020-08-19 20:27:17	2020-08-19	12	[{"id_menu":3,"count":1}]	46055	delivery	5	17
121376	2020-08-19 20:27:51	2020-08-19	17	[{"id_menu":4,"count":1}]	638	pick-up	0	17
121377	2020-08-19 20:29:36	2020-08-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9517	delivery	5	22
121378	2020-08-19 20:30:47	2020-08-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	46056	delivery	5	31
121379	2020-08-19 20:31:56	2020-08-19	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	31880	delivery	5	57
121380	2020-08-19 20:33:05	2020-08-19	17	[{"id_menu":4,"count":1}]	6715	pick-up	0	17
121381	2020-08-19 20:34:45	2020-08-19	14	[{"id_menu":2,"count":1}]	46223	delivery	5	19
121382	2020-08-19 20:35:02	2020-08-19	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	10518	delivery	5	31
121383	2020-08-19 20:36:29	2020-08-19	12	[{"id_menu":1,"count":1}]	37026	delivery	5	17
121384	2020-08-19 20:36:53	2020-08-19	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	46231	delivery	5	40
121385	2020-08-19 20:38:00	2020-08-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	46082	delivery	5	23
121386	2020-08-19 20:38:04	2020-08-19	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	40358	delivery	5	36
121387	2020-08-19 20:41:58	2020-08-19	14	[{"id_menu":2,"count":1}]	46205	delivery	5	19
121388	2020-08-19 20:46:44	2020-08-19	9	[{"id_menu":7,"count":1}]	29246	delivery	5	14
121389	2020-08-19 20:47:16	2020-08-19	8	[{"id_menu":5,"count":1}]	28426	delivery	5	13
121390	2020-08-19 20:47:51	2020-08-19	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	3820	pick-up	0	21
121391	2020-08-19 20:49:32	2020-08-19	17	[{"id_menu":4,"count":1}]	14558	pick-up	0	17
121392	2020-08-19 20:50:03	2020-08-19	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19628	delivery	5	35
121393	2020-08-19 20:50:42	2020-08-19	9	[{"id_menu":7,"count":1}]	24585	pick-up	0	9
121394	2020-08-19 20:57:08	2020-08-19	12	[{"id_menu":3,"count":1}]	35932	delivery	5	17
121395	2020-08-19 21:00:23	2020-08-19	17	[{"id_menu":4,"count":1}]	46258	pick-up	0	17
121396	2020-08-19 21:10:15	2020-08-19	17	[{"id_menu":4,"count":1}]	46247	delivery	5	22
121397	2020-08-19 21:15:36	2020-08-19	12	[{"id_menu":1,"count":2}]	46071	delivery	5	17
121398	2020-08-19 21:18:41	2020-08-19	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	29222	delivery	5	31
121399	2020-08-19 21:20:24	2020-08-19	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	32750	delivery	5	43
121400	2020-08-19 21:21:56	2020-08-19	9	[{"id_menu":7,"count":1}]	2719	delivery	5	14
121401	2020-08-19 21:23:50	2020-08-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	44739	delivery	5	22
121402	2020-08-19 21:24:12	2020-08-19	12	[{"id_menu":1,"count":1}]	10598	pick-up	0	12
121403	2020-08-19 21:30:09	2020-08-19	9	[{"id_menu":7,"count":1}]	10802	delivery	5	14
121404	2020-08-19 21:40:34	2020-08-19	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	44640	delivery	5	57
121405	2020-08-19 21:45:23	2020-08-19	8	[{"id_menu":5,"count":1}]	40114	delivery	5	13
121406	2020-08-19 21:45:38	2020-08-19	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21536	delivery	5	35
121407	2020-08-19 21:46:42	2020-08-19	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":2}]	46142	delivery	5	26
121408	2020-08-19 21:48:09	2020-08-19	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	18659	delivery	5	27
121409	2020-08-19 21:52:56	2020-08-19	8	[{"id_menu":5,"count":1}]	46073	delivery	5	13
121410	2020-08-19 21:53:23	2020-08-19	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	44146	delivery	5	26
121411	2020-08-19 21:57:46	2020-08-19	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41460	delivery	5	31
121412	2020-08-19 21:59:14	2020-08-19	12	[{"id_menu":1,"count":1}]	46261	delivery	5	17
121413	2020-08-19 21:59:15	2020-08-19	9	[{"id_menu":6,"count":1}]	37215	delivery	5	14
121414	2020-08-19 22:01:29	2020-08-19	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	42101	pick-up	0	26
121415	2020-08-19 22:01:33	2020-08-19	12	[{"id_menu":3,"count":1}]	1344	pick-up	0	12
121416	2020-08-19 22:03:22	2020-08-19	14	[{"id_menu":2,"count":1}]	46139	delivery	5	19
121417	2020-08-19 22:06:53	2020-08-19	12	[{"id_menu":1,"count":1}]	2916	delivery	5	17
121418	2020-08-19 22:14:09	2020-08-19	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	38942	delivery	5	30
121419	2020-08-19 22:14:26	2020-08-19	12	[{"id_menu":1,"count":1}]	41797	pick-up	0	12
121420	2020-08-19 22:15:27	2020-08-19	8	[{"id_menu":5,"count":1}]	33745	delivery	5	13
121421	2020-08-19 22:17:01	2020-08-19	9	[{"id_menu":7,"count":1}]	46075	delivery	5	14
121422	2020-08-19 22:18:29	2020-08-19	12	[{"id_menu":3,"count":1}]	28619	delivery	5	17
121423	2020-08-19 22:19:25	2020-08-19	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	32808	pick-up	0	35
121424	2020-08-19 22:20:32	2020-08-19	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	9023	delivery	5	28
121425	2020-08-19 22:22:24	2020-08-19	9	[{"id_menu":6,"count":1}]	6219	delivery	5	14
121426	2020-08-19 22:22:26	2020-08-19	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	46090	delivery	5	48
121427	2020-08-19 22:22:46	2020-08-19	9	[{"id_menu":7,"count":1}]	2290	delivery	5	14
121428	2020-08-19 22:25:46	2020-08-19	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	32263	delivery	5	31
121429	2020-08-19 22:27:37	2020-08-19	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":3}]	12835	delivery	5	26
121430	2020-08-19 22:27:58	2020-08-19	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	2552	delivery	5	36
121431	2020-08-19 22:28:09	2020-08-19	12	[{"id_menu":1,"count":1}]	12563	delivery	5	17
121432	2020-08-19 22:28:26	2020-08-19	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	33980	delivery	5	31
121433	2020-08-19 22:29:05	2020-08-19	12	[{"id_menu":1,"count":1}]	25525	delivery	5	17
121434	2020-08-19 22:30:19	2020-08-19	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	46236	delivery	5	22
121435	2020-08-19 22:31:42	2020-08-19	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	46120	delivery	5	48
121436	2020-08-19 22:36:01	2020-08-19	14	[{"id_menu":2,"count":1}]	340	pick-up	0	14
121437	2020-08-19 22:38:31	2020-08-19	14	[{"id_menu":2,"count":1}]	4511	delivery	5	19
121438	2020-08-19 22:41:12	2020-08-19	9	[{"id_menu":6,"count":2}]	21786	delivery	5	14
121439	2020-08-19 22:41:46	2020-08-19	9	[{"id_menu":6,"count":1}]	46081	delivery	5	14
121440	2020-08-19 22:44:05	2020-08-19	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	10276	delivery	5	34
121441	2020-08-19 22:44:37	2020-08-19	9	[{"id_menu":7,"count":1}]	46250	delivery	5	14
121442	2020-08-19 22:45:04	2020-08-19	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	37209	delivery	5	26
121443	2020-08-19 22:49:39	2020-08-19	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	46153	delivery	5	42
121444	2020-08-19 22:49:55	2020-08-19	14	[{"id_menu":2,"count":1}]	27673	delivery	5	19
121445	2020-08-19 22:50:12	2020-08-19	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	40867	delivery	5	25
121446	2020-08-19 22:53:48	2020-08-19	8	[{"id_menu":5,"count":1}]	36611	pick-up	0	8
121447	2020-08-19 22:55:25	2020-08-19	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32316	delivery	5	34
121448	2020-08-19 22:55:41	2020-08-19	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8560	delivery	5	45
121449	2020-08-19 22:57:32	2020-08-19	12	[{"id_menu":1,"count":1}]	266	pick-up	0	12
121450	2020-08-19 22:58:57	2020-08-19	30	[{"id_menu":3,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40731	delivery	5	35
121451	2020-08-19 23:00:24	2020-08-19	8	[{"id_menu":5,"count":1}]	30867	delivery	5	13
121452	2020-08-19 23:04:40	2020-08-19	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	46192	pick-up	0	21
121453	2020-08-19 23:06:07	2020-08-19	12	[{"id_menu":1,"count":1}]	11390	pick-up	0	12
121454	2020-08-19 23:08:38	2020-08-19	9	[{"id_menu":7,"count":1}]	27071	delivery	5	14
121455	2020-08-19 23:09:06	2020-08-19	9	[{"id_menu":7,"count":1}]	46045	delivery	5	14
121456	2020-08-19 23:09:59	2020-08-19	8	[{"id_menu":5,"count":1}]	46069	delivery	5	13
121457	2020-08-19 23:10:12	2020-08-19	12	[{"id_menu":1,"count":1}]	6929	pick-up	0	12
121458	2020-08-19 23:10:40	2020-08-19	12	[{"id_menu":1,"count":1}]	2064	delivery	5	17
121459	2020-08-19 23:11:41	2020-08-19	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14881	delivery	5	23
121460	2020-08-19 23:13:01	2020-08-19	9	[{"id_menu":6,"count":1}]	46279	delivery	5	14
121461	2020-08-19 23:16:23	2020-08-19	9	[{"id_menu":6,"count":1}]	35265	pick-up	0	9
121462	2020-08-19 23:16:28	2020-08-19	17	[{"id_menu":4,"count":1}]	2191	pick-up	0	17
121463	2020-08-19 23:16:47	2020-08-19	8	[{"id_menu":5,"count":1}]	19653	delivery	5	13
121464	2020-08-19 23:20:37	2020-08-19	9	[{"id_menu":6,"count":1}]	45349	pick-up	0	9
121465	2020-08-19 23:21:12	2020-08-19	12	[{"id_menu":3,"count":1}]	4963	pick-up	0	12
121466	2020-08-19 23:25:57	2020-08-19	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	25097	delivery	5	34
121467	2020-08-19 23:26:16	2020-08-19	12	[{"id_menu":3,"count":1}]	40145	delivery	5	17
121468	2020-08-19 23:27:32	2020-08-19	8	[{"id_menu":5,"count":1}]	5572	delivery	5	13
121469	2020-08-19 23:29:12	2020-08-19	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	34098	delivery	5	31
121470	2020-08-19 23:31:17	2020-08-19	8	[{"id_menu":5,"count":2}]	15913	delivery	5	13
121471	2020-08-19 23:31:41	2020-08-19	14	[{"id_menu":2,"count":1}]	10151	pick-up	0	14
121472	2020-08-19 23:33:56	2020-08-19	8	[{"id_menu":5,"count":1}]	856	pick-up	0	8
121473	2020-08-19 23:34:11	2020-08-19	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19282	delivery	5	52
121474	2020-08-19 23:43:05	2020-08-19	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	46180	delivery	5	27
121475	2020-08-19 23:43:21	2020-08-19	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8622	delivery	5	35
121476	2020-08-19 23:45:25	2020-08-19	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24883	delivery	5	51
121477	2020-08-19 23:45:44	2020-08-19	17	[{"id_menu":4,"count":1}]	42472	delivery	5	22
121478	2020-08-19 23:46:55	2020-08-19	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	34026	delivery	5	22
121479	2020-08-19 23:48:53	2020-08-19	12	[{"id_menu":1,"count":2}]	46228	delivery	5	17
121480	2020-08-19 23:50:14	2020-08-19	8	[{"id_menu":5,"count":1}]	2575	delivery	5	13
121481	2020-08-19 23:51:39	2020-08-19	8	[{"id_menu":5,"count":1}]	46254	pick-up	0	8
121482	2020-08-19 23:52:11	2020-08-19	9	[{"id_menu":7,"count":1}]	46145	delivery	5	14
121483	2020-08-19 23:53:43	2020-08-19	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33514	delivery	5	49
121484	2020-08-19 23:54:30	2020-08-19	8	[{"id_menu":5,"count":2}]	11713	delivery	5	13
121485	2020-08-19 23:55:10	2020-08-19	9	[{"id_menu":7,"count":1}]	16603	delivery	5	14
121486	2020-08-19 23:56:09	2020-08-19	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	32295	delivery	5	37
121487	2020-08-19 23:57:20	2020-08-19	12	[{"id_menu":1,"count":2}]	31555	pick-up	0	12
121488	2020-08-19 23:59:50	2020-08-19	12	[{"id_menu":1,"count":1}]	2089	pick-up	0	12
121489	2020-08-20 00:02:25	2020-08-20	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	46531	delivery	5	45
121490	2020-08-20 00:03:40	2020-08-20	14	[{"id_menu":2,"count":2}]	46547	delivery	5	19
121491	2020-08-20 00:06:17	2020-08-20	9	[{"id_menu":7,"count":1}]	46472	delivery	5	14
121558	2020-08-20 02:02:54	2020-08-20	14	[{"id_menu":2,"count":1}]	41326	pick-up	0	14
121492	2020-08-20 00:09:15	2020-08-20	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	46404	delivery	5	45
121493	2020-08-20 00:11:45	2020-08-20	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	46498	delivery	5	22
121494	2020-08-20 00:12:07	2020-08-20	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	46386	delivery	5	30
121495	2020-08-20 00:12:44	2020-08-20	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	27840	delivery	5	36
121496	2020-08-20 00:12:45	2020-08-20	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	46457	delivery	5	34
121497	2020-08-20 00:12:52	2020-08-20	12	[{"id_menu":1,"count":1}]	11138	delivery	5	17
121498	2020-08-20 00:13:03	2020-08-20	14	[{"id_menu":2,"count":1}]	24714	pick-up	0	14
121499	2020-08-20 00:14:25	2020-08-20	12	[{"id_menu":1,"count":1}]	4770	pick-up	0	12
121500	2020-08-20 00:19:37	2020-08-20	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	46528	delivery	5	40
121501	2020-08-20 00:19:43	2020-08-20	8	[{"id_menu":5,"count":1}]	10877	delivery	5	13
121502	2020-08-20 00:20:02	2020-08-20	9	[{"id_menu":7,"count":1}]	45360	delivery	5	14
121503	2020-08-20 00:20:30	2020-08-20	9	[{"id_menu":7,"count":1}]	46477	delivery	5	14
121504	2020-08-20 00:22:36	2020-08-20	9	[{"id_menu":6,"count":1}]	35487	delivery	5	14
121505	2020-08-20 00:22:53	2020-08-20	12	[{"id_menu":3,"count":1}]	170	pick-up	0	12
121506	2020-08-20 00:23:03	2020-08-20	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	41400	delivery	5	53
121507	2020-08-20 00:23:21	2020-08-20	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	44489	delivery	5	38
121508	2020-08-20 00:23:43	2020-08-20	12	[{"id_menu":1,"count":1}]	5353	delivery	5	17
121509	2020-08-20 00:24:10	2020-08-20	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	13939	pick-up	0	26
121510	2020-08-20 00:27:49	2020-08-20	14	[{"id_menu":2,"count":1}]	36187	delivery	5	19
121511	2020-08-20 00:30:17	2020-08-20	17	[{"id_menu":4,"count":1}]	31201	delivery	5	22
121512	2020-08-20 00:33:21	2020-08-20	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	15042	delivery	5	26
121513	2020-08-20 00:34:00	2020-08-20	17	[{"id_menu":4,"count":1}]	46304	delivery	5	22
121514	2020-08-20 00:34:41	2020-08-20	17	[{"id_menu":4,"count":1}]	46392	delivery	5	22
121515	2020-08-20 00:35:27	2020-08-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28070	delivery	5	23
121516	2020-08-20 00:37:53	2020-08-20	9	[{"id_menu":7,"count":1}]	10904	delivery	5	14
121517	2020-08-20 00:43:39	2020-08-20	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	46373	delivery	5	35
121518	2020-08-20 00:44:32	2020-08-20	12	[{"id_menu":3,"count":1}]	44553	delivery	5	17
121519	2020-08-20 00:48:34	2020-08-20	9	[{"id_menu":6,"count":1}]	46550	delivery	5	14
121520	2020-08-20 00:51:36	2020-08-20	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27519	delivery	5	40
121521	2020-08-20 00:52:08	2020-08-20	9	[{"id_menu":6,"count":1}]	7689	pick-up	0	9
121522	2020-08-20 00:53:25	2020-08-20	12	[{"id_menu":3,"count":1}]	42513	pick-up	0	12
121523	2020-08-20 00:54:44	2020-08-20	8	[{"id_menu":5,"count":1}]	6033	pick-up	0	8
121524	2020-08-20 01:00:07	2020-08-20	8	[{"id_menu":5,"count":1}]	36522	delivery	5	13
121525	2020-08-20 01:01:31	2020-08-20	14	[{"id_menu":2,"count":1}]	9423	pick-up	0	14
121526	2020-08-20 01:01:57	2020-08-20	9	[{"id_menu":6,"count":1}]	1569	pick-up	0	9
121527	2020-08-20 01:05:30	2020-08-20	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	12952	delivery	5	34
121528	2020-08-20 01:06:49	2020-08-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	46433	delivery	5	28
121529	2020-08-20 01:09:49	2020-08-20	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	46524	delivery	5	31
121530	2020-08-20 01:13:13	2020-08-20	12	[{"id_menu":1,"count":1}]	45234	delivery	5	17
121531	2020-08-20 01:16:11	2020-08-20	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	44236	delivery	5	34
121532	2020-08-20 01:16:39	2020-08-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	46324	delivery	5	22
121533	2020-08-20 01:18:01	2020-08-20	14	[{"id_menu":2,"count":1}]	46454	delivery	5	19
121534	2020-08-20 01:18:12	2020-08-20	12	[{"id_menu":3,"count":1}]	46514	delivery	5	17
121535	2020-08-20 01:19:49	2020-08-20	8	[{"id_menu":5,"count":1}]	11794	delivery	5	13
121536	2020-08-20 01:20:05	2020-08-20	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	46536	delivery	5	34
121537	2020-08-20 01:23:09	2020-08-20	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	37791	delivery	5	23
121538	2020-08-20 01:24:17	2020-08-20	12	[{"id_menu":1,"count":1}]	33809	delivery	5	17
121539	2020-08-20 01:24:28	2020-08-20	17	[{"id_menu":4,"count":1}]	24418	delivery	5	22
121540	2020-08-20 01:29:10	2020-08-20	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	43698	pick-up	0	29
121541	2020-08-20 01:30:03	2020-08-20	14	[{"id_menu":2,"count":1}]	46553	delivery	5	19
121542	2020-08-20 01:35:04	2020-08-20	9	[{"id_menu":7,"count":1}]	37333	delivery	5	14
121543	2020-08-20 01:36:14	2020-08-20	8	[{"id_menu":5,"count":2}]	46495	delivery	5	13
121544	2020-08-20 01:36:17	2020-08-20	12	[{"id_menu":1,"count":1}]	46529	delivery	5	17
121545	2020-08-20 01:36:23	2020-08-20	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	32810	pick-up	0	22
121546	2020-08-20 01:41:05	2020-08-20	14	[{"id_menu":2,"count":1}]	46393	delivery	5	19
121547	2020-08-20 01:42:29	2020-08-20	9	[{"id_menu":6,"count":1}]	46522	delivery	5	14
121548	2020-08-20 01:43:48	2020-08-20	17	[{"id_menu":4,"count":1}]	46362	delivery	5	22
121549	2020-08-20 01:45:02	2020-08-20	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	46427	pick-up	0	34
121550	2020-08-20 01:46:16	2020-08-20	17	[{"id_menu":4,"count":1}]	46336	delivery	5	22
121551	2020-08-20 01:50:58	2020-08-20	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	11555	delivery	5	40
121552	2020-08-20 01:51:58	2020-08-20	9	[{"id_menu":6,"count":1}]	5375	delivery	5	14
121553	2020-08-20 01:52:10	2020-08-20	12	[{"id_menu":1,"count":1}]	46421	delivery	5	17
121554	2020-08-20 01:54:51	2020-08-20	9	[{"id_menu":7,"count":1}]	46512	delivery	5	14
121555	2020-08-20 01:55:38	2020-08-20	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	46430	delivery	5	26
121556	2020-08-20 01:57:02	2020-08-20	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	46468	delivery	5	26
121557	2020-08-20 01:59:24	2020-08-20	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	24547	pick-up	0	26
121559	2020-08-20 02:03:04	2020-08-20	12	[{"id_menu":1,"count":1}]	13176	delivery	5	17
121560	2020-08-20 02:06:09	2020-08-20	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	46438	delivery	5	49
121561	2020-08-20 02:12:51	2020-08-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18512	delivery	5	22
121562	2020-08-20 02:15:51	2020-08-20	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	38810	delivery	5	22
121563	2020-08-20 02:19:44	2020-08-20	8	[{"id_menu":5,"count":1}]	46340	delivery	5	13
121564	2020-08-20 02:22:14	2020-08-20	9	[{"id_menu":6,"count":1}]	28581	delivery	5	14
121565	2020-08-20 02:23:29	2020-08-20	9	[{"id_menu":7,"count":1}]	24838	delivery	5	14
121566	2020-08-20 02:23:52	2020-08-20	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17342	delivery	5	31
121567	2020-08-20 02:25:40	2020-08-20	9	[{"id_menu":6,"count":1}]	46394	delivery	5	14
121568	2020-08-20 02:27:45	2020-08-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	33680	delivery	5	23
121569	2020-08-20 02:30:14	2020-08-20	8	[{"id_menu":5,"count":1}]	36118	delivery	5	13
121570	2020-08-20 02:30:51	2020-08-20	9	[{"id_menu":7,"count":1}]	46516	delivery	5	14
121571	2020-08-20 02:33:18	2020-08-20	12	[{"id_menu":3,"count":1}]	34986	delivery	5	17
121572	2020-08-20 02:38:46	2020-08-20	12	[{"id_menu":3,"count":1}]	42682	delivery	5	17
121573	2020-08-20 02:40:19	2020-08-20	14	[{"id_menu":2,"count":1}]	36622	delivery	5	19
121574	2020-08-20 02:41:31	2020-08-20	14	[{"id_menu":2,"count":1}]	46486	delivery	5	19
121575	2020-08-20 02:42:50	2020-08-20	8	[{"id_menu":5,"count":1}]	30949	delivery	5	13
121576	2020-08-20 02:44:23	2020-08-20	12	[{"id_menu":3,"count":1}]	46420	delivery	5	17
121577	2020-08-20 02:46:30	2020-08-20	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	46441	delivery	5	22
121578	2020-08-20 02:50:06	2020-08-20	9	[{"id_menu":7,"count":1}]	46451	delivery	5	14
121579	2020-08-20 02:53:08	2020-08-20	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17669	delivery	5	52
121580	2020-08-20 03:00:10	2020-08-20	17	[{"id_menu":4,"count":1}]	45868	pick-up	0	17
121581	2020-08-20 03:01:04	2020-08-20	9	[{"id_menu":6,"count":1}]	46375	delivery	5	14
121582	2020-08-20 03:01:33	2020-08-20	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19616	delivery	5	36
121583	2020-08-20 03:05:57	2020-08-20	8	[{"id_menu":5,"count":1}]	26007	pick-up	0	8
121584	2020-08-20 03:06:06	2020-08-20	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	46455	delivery	5	48
121585	2020-08-20 03:08:00	2020-08-20	17	[{"id_menu":4,"count":1}]	407	pick-up	0	17
121586	2020-08-20 03:08:28	2020-08-20	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	46405	delivery	5	39
121587	2020-08-20 03:09:48	2020-08-20	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	45385	delivery	5	29
121588	2020-08-20 03:10:24	2020-08-20	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	46499	delivery	5	26
121589	2020-08-20 03:11:41	2020-08-20	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1048	delivery	5	26
121590	2020-08-20 03:19:57	2020-08-20	12	[{"id_menu":1,"count":1}]	6666	delivery	5	17
121591	2020-08-20 03:20:33	2020-08-20	9	[{"id_menu":6,"count":1}]	10039	delivery	5	14
121592	2020-08-20 03:23:32	2020-08-20	9	[{"id_menu":6,"count":1}]	46503	delivery	5	14
121593	2020-08-20 03:25:01	2020-08-20	8	[{"id_menu":5,"count":1}]	33811	delivery	5	13
121594	2020-08-20 03:25:35	2020-08-20	12	[{"id_menu":1,"count":2}]	3669	pick-up	0	12
121595	2020-08-20 03:26:05	2020-08-20	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	40881	delivery	5	22
121596	2020-08-20 03:29:22	2020-08-20	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	9370	delivery	5	31
121597	2020-08-20 03:31:08	2020-08-20	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	45711	delivery	5	40
121598	2020-08-20 03:31:31	2020-08-20	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16822	pick-up	0	40
121599	2020-08-20 03:34:08	2020-08-20	17	[{"id_menu":4,"count":1}]	8071	pick-up	0	17
121600	2020-08-20 03:35:48	2020-08-20	9	[{"id_menu":7,"count":1}]	2416	pick-up	0	9
121601	2020-08-20 03:36:56	2020-08-20	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	46320	delivery	5	31
121602	2020-08-20 03:41:33	2020-08-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	16152	delivery	5	28
121603	2020-08-20 03:42:10	2020-08-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	42289	delivery	5	22
121604	2020-08-20 03:45:40	2020-08-20	12	[{"id_menu":3,"count":1}]	33783	delivery	5	17
121605	2020-08-20 03:46:14	2020-08-20	12	[{"id_menu":1,"count":1}]	38839	delivery	5	17
121606	2020-08-20 03:46:50	2020-08-20	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32784	delivery	5	31
121607	2020-08-20 03:47:08	2020-08-20	9	[{"id_menu":6,"count":1}]	27448	delivery	5	14
121608	2020-08-20 03:47:49	2020-08-20	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	46501	delivery	5	31
121609	2020-08-20 03:48:08	2020-08-20	14	[{"id_menu":2,"count":2}]	3852	pick-up	0	14
121610	2020-08-20 03:52:33	2020-08-20	9	[{"id_menu":7,"count":1}]	21949	delivery	5	14
121611	2020-08-20 03:55:13	2020-08-20	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	31571	pick-up	0	21
121612	2020-08-20 03:57:05	2020-08-20	9	[{"id_menu":7,"count":1}]	24918	delivery	5	14
121613	2020-08-20 03:58:58	2020-08-20	9	[{"id_menu":7,"count":1}]	44233	delivery	5	14
121614	2020-08-20 04:01:03	2020-08-20	17	[{"id_menu":4,"count":1}]	3224	pick-up	0	17
121615	2020-08-20 04:02:37	2020-08-20	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	46338	delivery	5	31
121616	2020-08-20 04:04:44	2020-08-20	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	46217	delivery	5	31
121617	2020-08-20 04:04:52	2020-08-20	17	[{"id_menu":4,"count":1}]	24887	pick-up	0	17
121618	2020-08-20 04:06:18	2020-08-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4277	delivery	5	28
121619	2020-08-20 04:11:01	2020-08-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":3}]	46343	delivery	5	28
121620	2020-08-20 04:11:33	2020-08-20	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	29874	delivery	5	31
121621	2020-08-20 04:13:39	2020-08-20	8	[{"id_menu":5,"count":1}]	5875	pick-up	0	8
121622	2020-08-20 04:14:26	2020-08-20	12	[{"id_menu":3,"count":1}]	30618	pick-up	0	12
121623	2020-08-20 04:14:36	2020-08-20	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1468	pick-up	0	21
121624	2020-08-20 04:16:43	2020-08-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	46464	pick-up	0	23
121625	2020-08-20 04:16:52	2020-08-20	9	[{"id_menu":7,"count":1}]	24749	delivery	5	14
121626	2020-08-20 04:19:28	2020-08-20	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	34812	delivery	5	28
121627	2020-08-20 04:19:51	2020-08-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	18170	pick-up	0	23
121628	2020-08-20 04:19:55	2020-08-20	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	12476	delivery	5	42
121629	2020-08-20 04:22:26	2020-08-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	46491	delivery	5	28
121630	2020-08-20 04:22:55	2020-08-20	14	[{"id_menu":2,"count":1}]	12169	delivery	5	19
121631	2020-08-20 04:29:30	2020-08-20	9	[{"id_menu":6,"count":3}]	31700	delivery	5	14
121632	2020-08-20 04:31:15	2020-08-20	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	16967	pick-up	0	21
121633	2020-08-20 04:33:50	2020-08-20	9	[{"id_menu":7,"count":1}]	32594	delivery	5	14
121634	2020-08-20 04:34:08	2020-08-20	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	45267	delivery	5	57
121635	2020-08-20 04:34:17	2020-08-20	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11081	delivery	5	31
121636	2020-08-20 04:34:39	2020-08-20	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1880	delivery	5	36
121637	2020-08-20 04:37:04	2020-08-20	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37331	delivery	5	37
121638	2020-08-20 04:38:15	2020-08-20	12	[{"id_menu":3,"count":1}]	2729	delivery	5	17
121639	2020-08-20 04:41:50	2020-08-20	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4164	delivery	5	48
121640	2020-08-20 04:43:24	2020-08-20	17	[{"id_menu":4,"count":2}]	10718	delivery	5	22
121641	2020-08-20 04:44:21	2020-08-20	8	[{"id_menu":5,"count":1}]	42362	delivery	5	13
121642	2020-08-20 04:46:25	2020-08-20	14	[{"id_menu":2,"count":1}]	29678	delivery	5	19
121643	2020-08-20 04:51:57	2020-08-20	12	[{"id_menu":3,"count":1}]	46358	delivery	5	17
121644	2020-08-20 04:52:13	2020-08-20	9	[{"id_menu":7,"count":1}]	8448	pick-up	0	9
121645	2020-08-20 04:55:06	2020-08-20	12	[{"id_menu":1,"count":1}]	31689	delivery	5	17
121646	2020-08-20 04:55:56	2020-08-20	12	[{"id_menu":3,"count":1}]	38857	pick-up	0	12
121647	2020-08-20 04:56:06	2020-08-20	9	[{"id_menu":6,"count":1}]	22305	delivery	5	14
121648	2020-08-20 04:56:45	2020-08-20	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	46318	delivery	5	27
121649	2020-08-20 04:57:58	2020-08-20	9	[{"id_menu":6,"count":3}]	9685	delivery	5	14
121650	2020-08-20 04:58:50	2020-08-20	12	[{"id_menu":1,"count":1}]	41386	pick-up	0	12
121651	2020-08-20 04:59:14	2020-08-20	38	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	6221	pick-up	0	38
121652	2020-08-20 05:00:03	2020-08-20	9	[{"id_menu":6,"count":1}]	39447	delivery	5	14
121653	2020-08-20 05:00:53	2020-08-20	9	[{"id_menu":6,"count":1}]	22270	delivery	5	14
121654	2020-08-20 05:02:31	2020-08-20	12	[{"id_menu":3,"count":1}]	19005	delivery	5	17
121655	2020-08-20 05:04:49	2020-08-20	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	20308	delivery	5	35
121656	2020-08-20 05:06:50	2020-08-20	12	[{"id_menu":1,"count":1}]	26765	delivery	5	17
121657	2020-08-20 05:11:10	2020-08-20	12	[{"id_menu":3,"count":1}]	44750	delivery	5	17
121658	2020-08-20 05:12:10	2020-08-20	9	[{"id_menu":6,"count":1}]	8988	delivery	5	14
121659	2020-08-20 05:12:27	2020-08-20	8	[{"id_menu":5,"count":1}]	18542	delivery	5	13
121660	2020-08-20 05:13:12	2020-08-20	9	[{"id_menu":7,"count":1}]	16850	delivery	5	14
121661	2020-08-20 05:18:34	2020-08-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	26349	delivery	5	28
121662	2020-08-20 05:20:26	2020-08-20	8	[{"id_menu":5,"count":1}]	21074	delivery	5	13
121663	2020-08-20 05:21:53	2020-08-20	9	[{"id_menu":6,"count":1}]	42307	delivery	5	14
121664	2020-08-20 05:24:41	2020-08-20	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	378	pick-up	0	26
121665	2020-08-20 05:26:32	2020-08-20	9	[{"id_menu":7,"count":1}]	15343	delivery	5	14
121666	2020-08-20 05:26:54	2020-08-20	17	[{"id_menu":4,"count":1}]	13495	pick-up	0	17
121667	2020-08-20 05:28:14	2020-08-20	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	30777	delivery	5	25
121668	2020-08-20 05:29:18	2020-08-20	17	[{"id_menu":4,"count":1}]	19233	delivery	5	22
121669	2020-08-20 05:39:33	2020-08-20	9	[{"id_menu":7,"count":1}]	29397	delivery	5	14
121670	2020-08-20 05:40:06	2020-08-20	14	[{"id_menu":2,"count":1}]	46488	pick-up	0	14
121671	2020-08-20 05:43:08	2020-08-20	9	[{"id_menu":6,"count":1}]	46317	delivery	5	14
121672	2020-08-20 05:46:23	2020-08-20	12	[{"id_menu":3,"count":1}]	28562	delivery	5	17
121673	2020-08-20 05:46:35	2020-08-20	9	[{"id_menu":7,"count":1}]	43186	delivery	5	14
121674	2020-08-20 05:46:54	2020-08-20	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	46353	pick-up	0	22
121675	2020-08-20 05:47:27	2020-08-20	9	[{"id_menu":7,"count":1}]	826	pick-up	0	9
121676	2020-08-20 05:51:19	2020-08-20	12	[{"id_menu":3,"count":2}]	46417	delivery	5	17
121677	2020-08-20 05:55:14	2020-08-20	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	46406	delivery	5	31
121678	2020-08-20 05:58:09	2020-08-20	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	31536	delivery	5	31
121679	2020-08-20 05:58:14	2020-08-20	12	[{"id_menu":3,"count":1}]	46350	pick-up	0	12
121680	2020-08-20 05:58:35	2020-08-20	9	[{"id_menu":7,"count":1}]	21062	delivery	5	14
121681	2020-08-20 06:00:17	2020-08-20	9	[{"id_menu":6,"count":1}]	29042	pick-up	0	9
121682	2020-08-20 06:00:20	2020-08-20	9	[{"id_menu":6,"count":1}]	29918	pick-up	0	9
121683	2020-08-20 06:03:55	2020-08-20	12	[{"id_menu":1,"count":1}]	3575	delivery	5	17
121684	2020-08-20 06:11:39	2020-08-20	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	33610	delivery	5	22
121685	2020-08-20 06:11:45	2020-08-20	12	[{"id_menu":1,"count":1}]	40239	delivery	5	17
121686	2020-08-20 06:12:27	2020-08-20	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	46463	delivery	5	51
121687	2020-08-20 06:19:51	2020-08-20	8	[{"id_menu":5,"count":2}]	46365	delivery	5	13
121688	2020-08-20 06:23:21	2020-08-20	17	[{"id_menu":4,"count":2}]	236	pick-up	0	17
121689	2020-08-20 06:24:08	2020-08-20	9	[{"id_menu":7,"count":1}]	8595	delivery	5	14
121690	2020-08-20 06:26:59	2020-08-20	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	24792	delivery	5	31
121691	2020-08-20 06:28:47	2020-08-20	8	[{"id_menu":5,"count":1}]	44368	delivery	5	13
121692	2020-08-20 06:29:36	2020-08-20	9	[{"id_menu":6,"count":1}]	14012	pick-up	0	9
121693	2020-08-20 06:32:18	2020-08-20	9	[{"id_menu":7,"count":1}]	1507	pick-up	0	9
121694	2020-08-20 06:34:56	2020-08-20	9	[{"id_menu":6,"count":1}]	7987	delivery	5	14
121695	2020-08-20 06:37:55	2020-08-20	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38736	delivery	5	31
121696	2020-08-20 06:38:51	2020-08-20	9	[{"id_menu":7,"count":1}]	16426	delivery	5	14
121697	2020-08-20 06:39:00	2020-08-20	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23264	delivery	5	51
121698	2020-08-20 06:39:23	2020-08-20	9	[{"id_menu":6,"count":1}]	30976	pick-up	0	9
121699	2020-08-20 06:39:43	2020-08-20	17	[{"id_menu":4,"count":1}]	25254	pick-up	0	17
121700	2020-08-20 06:45:52	2020-08-20	9	[{"id_menu":7,"count":2}]	40232	pick-up	0	9
121701	2020-08-20 06:47:15	2020-08-20	9	[{"id_menu":6,"count":1}]	41667	delivery	5	14
121702	2020-08-20 06:50:19	2020-08-20	9	[{"id_menu":6,"count":2}]	9529	delivery	5	14
121703	2020-08-20 06:50:48	2020-08-20	12	[{"id_menu":3,"count":1}]	4189	delivery	5	17
121704	2020-08-20 06:52:20	2020-08-20	9	[{"id_menu":7,"count":1}]	14520	delivery	5	14
121705	2020-08-20 06:54:09	2020-08-20	9	[{"id_menu":6,"count":1}]	46448	delivery	5	14
121706	2020-08-20 06:54:25	2020-08-20	12	[{"id_menu":3,"count":1}]	2051	delivery	5	17
121707	2020-08-20 06:58:10	2020-08-20	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	9836	delivery	5	26
121708	2020-08-20 06:58:52	2020-08-20	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	29067	delivery	5	26
121709	2020-08-20 06:59:09	2020-08-20	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	46439	delivery	5	37
121710	2020-08-20 06:59:29	2020-08-20	8	[{"id_menu":5,"count":1}]	31783	delivery	5	13
121711	2020-08-20 07:00:48	2020-08-20	17	[{"id_menu":4,"count":1}]	43865	pick-up	0	17
121712	2020-08-20 07:02:27	2020-08-20	9	[{"id_menu":7,"count":1}]	6168	delivery	5	14
121713	2020-08-20 07:02:40	2020-08-20	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	7557	delivery	5	25
121714	2020-08-20 07:03:33	2020-08-20	12	[{"id_menu":1,"count":1}]	21256	delivery	5	17
121715	2020-08-20 07:04:44	2020-08-20	9	[{"id_menu":7,"count":2}]	46326	delivery	5	14
121716	2020-08-20 07:09:59	2020-08-20	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15236	delivery	5	53
121717	2020-08-20 07:10:12	2020-08-20	14	[{"id_menu":2,"count":1}]	21502	pick-up	0	14
121718	2020-08-20 07:14:42	2020-08-20	14	[{"id_menu":2,"count":1}]	46476	delivery	5	19
121719	2020-08-20 07:16:06	2020-08-20	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15544	delivery	5	35
121720	2020-08-20 07:16:53	2020-08-20	9	[{"id_menu":6,"count":1}]	41142	delivery	5	14
121721	2020-08-20 07:16:55	2020-08-20	9	[{"id_menu":7,"count":3}]	13353	delivery	5	14
121722	2020-08-20 07:18:24	2020-08-20	9	[{"id_menu":7,"count":2}]	31331	delivery	5	14
121723	2020-08-20 07:18:49	2020-08-20	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10006	delivery	5	22
121724	2020-08-20 07:20:07	2020-08-20	9	[{"id_menu":6,"count":1}]	22116	delivery	5	14
121725	2020-08-20 07:24:51	2020-08-20	9	[{"id_menu":6,"count":1}]	46497	delivery	5	14
121726	2020-08-20 07:26:47	2020-08-20	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	3618	delivery	5	35
121727	2020-08-20 07:26:51	2020-08-20	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	35456	pick-up	0	26
121728	2020-08-20 07:26:52	2020-08-20	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	39322	delivery	5	26
121729	2020-08-20 07:28:00	2020-08-20	14	[{"id_menu":2,"count":1}]	7638	delivery	5	19
121730	2020-08-20 07:28:42	2020-08-20	14	[{"id_menu":2,"count":1}]	19805	pick-up	0	14
121731	2020-08-20 07:31:21	2020-08-20	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	23017	delivery	5	27
121732	2020-08-20 07:32:00	2020-08-20	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	19434	pick-up	0	35
121733	2020-08-20 07:34:11	2020-08-20	8	[{"id_menu":5,"count":1}]	46310	delivery	5	13
121734	2020-08-20 07:40:31	2020-08-20	17	[{"id_menu":4,"count":1}]	46370	delivery	5	22
121735	2020-08-20 07:41:50	2020-08-20	12	[{"id_menu":3,"count":1}]	28476	delivery	5	17
121736	2020-08-20 07:42:20	2020-08-20	9	[{"id_menu":6,"count":1}]	12282	delivery	5	14
121737	2020-08-20 07:43:40	2020-08-20	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	46372	delivery	5	25
121738	2020-08-20 07:48:09	2020-08-20	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	46549	delivery	5	40
121739	2020-08-20 07:51:44	2020-08-20	9	[{"id_menu":6,"count":1}]	28376	delivery	5	14
121740	2020-08-20 07:51:56	2020-08-20	8	[{"id_menu":5,"count":1}]	46445	delivery	5	13
121741	2020-08-20 07:52:52	2020-08-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	34052	pick-up	0	17
121742	2020-08-20 07:55:12	2020-08-20	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	46494	delivery	5	35
121743	2020-08-20 07:56:07	2020-08-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	46402	delivery	5	23
121744	2020-08-20 07:57:06	2020-08-20	12	[{"id_menu":1,"count":1}]	34111	delivery	5	17
121745	2020-08-20 07:58:24	2020-08-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31318	pick-up	0	18
121746	2020-08-20 07:59:45	2020-08-20	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	46377	delivery	5	31
121747	2020-08-20 08:01:42	2020-08-20	14	[{"id_menu":2,"count":1}]	22900	delivery	5	19
121748	2020-08-20 08:03:21	2020-08-20	9	[{"id_menu":7,"count":1}]	46337	delivery	5	14
121749	2020-08-20 08:03:58	2020-08-20	17	[{"id_menu":4,"count":2}]	28770	delivery	5	22
121750	2020-08-20 08:04:39	2020-08-20	9	[{"id_menu":6,"count":2}]	46325	delivery	5	14
121751	2020-08-20 08:08:17	2020-08-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13948	delivery	5	22
121752	2020-08-20 08:08:51	2020-08-20	9	[{"id_menu":6,"count":1}]	9701	delivery	5	14
121753	2020-08-20 08:08:52	2020-08-20	9	[{"id_menu":6,"count":2}]	46381	delivery	5	14
121754	2020-08-20 08:12:23	2020-08-20	17	[{"id_menu":4,"count":2}]	46391	delivery	5	22
121755	2020-08-20 08:13:30	2020-08-20	12	[{"id_menu":1,"count":1}]	30263	delivery	5	17
121756	2020-08-20 08:15:59	2020-08-20	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	39981	delivery	5	31
121757	2020-08-20 08:16:04	2020-08-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	46507	delivery	5	22
121758	2020-08-20 08:17:19	2020-08-20	17	[{"id_menu":4,"count":1}]	46515	pick-up	0	17
121759	2020-08-20 08:17:54	2020-08-20	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":3}]	46534	delivery	5	26
121760	2020-08-20 08:18:19	2020-08-20	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	46384	delivery	5	26
121761	2020-08-20 08:19:55	2020-08-20	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	37278	delivery	5	48
121762	2020-08-20 08:20:07	2020-08-20	8	[{"id_menu":5,"count":1}]	11767	delivery	5	13
121763	2020-08-20 08:21:35	2020-08-20	17	[{"id_menu":4,"count":1}]	21402	delivery	5	22
121764	2020-08-20 08:21:54	2020-08-20	14	[{"id_menu":2,"count":1}]	21276	delivery	5	19
121765	2020-08-20 08:22:07	2020-08-20	12	[{"id_menu":1,"count":1}]	42798	pick-up	0	12
121766	2020-08-20 08:22:26	2020-08-20	12	[{"id_menu":1,"count":1}]	38715	delivery	5	17
121767	2020-08-20 08:24:31	2020-08-20	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4295	pick-up	0	35
121768	2020-08-20 08:27:30	2020-08-20	14	[{"id_menu":2,"count":2}]	19270	pick-up	0	14
121769	2020-08-20 08:27:46	2020-08-20	9	[{"id_menu":6,"count":1}]	1096	pick-up	0	9
121770	2020-08-20 08:29:39	2020-08-20	9	[{"id_menu":6,"count":1}]	18046	delivery	5	14
121771	2020-08-20 08:30:38	2020-08-20	8	[{"id_menu":5,"count":1}]	24097	delivery	5	13
121772	2020-08-20 08:31:02	2020-08-20	17	[{"id_menu":4,"count":1}]	46552	delivery	5	22
121773	2020-08-20 08:32:46	2020-08-20	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9404	pick-up	0	29
121774	2020-08-20 08:33:16	2020-08-20	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	46541	pick-up	0	34
121775	2020-08-20 08:39:27	2020-08-20	12	[{"id_menu":3,"count":1}]	4592	delivery	5	17
121776	2020-08-20 08:43:13	2020-08-20	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	46369	pick-up	0	26
121777	2020-08-20 08:43:57	2020-08-20	9	[{"id_menu":6,"count":1}]	5061	delivery	5	14
121778	2020-08-20 08:44:41	2020-08-20	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	46520	delivery	5	30
121779	2020-08-20 08:48:03	2020-08-20	14	[{"id_menu":2,"count":1}]	14613	delivery	5	19
121780	2020-08-20 08:50:28	2020-08-20	9	[{"id_menu":6,"count":1}]	8683	delivery	5	14
121781	2020-08-20 09:02:05	2020-08-20	8	[{"id_menu":5,"count":1}]	46466	delivery	5	13
121782	2020-08-20 09:03:02	2020-08-20	9	[{"id_menu":7,"count":1}]	46480	delivery	5	14
121783	2020-08-20 09:13:05	2020-08-20	9	[{"id_menu":7,"count":1}]	20640	delivery	5	14
121784	2020-08-20 09:13:32	2020-08-20	12	[{"id_menu":1,"count":1}]	35186	delivery	5	17
121785	2020-08-20 09:16:07	2020-08-20	17	[{"id_menu":4,"count":1}]	177	pick-up	0	17
121786	2020-08-20 09:17:12	2020-08-20	17	[{"id_menu":4,"count":1}]	30519	pick-up	0	17
121787	2020-08-20 09:26:05	2020-08-20	14	[{"id_menu":2,"count":1}]	33667	pick-up	0	14
121788	2020-08-20 09:26:05	2020-08-20	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	28831	delivery	5	45
121789	2020-08-20 09:26:12	2020-08-20	9	[{"id_menu":6,"count":1}]	42911	delivery	5	14
121790	2020-08-20 09:28:16	2020-08-20	14	[{"id_menu":2,"count":1}]	2015	pick-up	0	14
121791	2020-08-20 09:31:31	2020-08-20	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39492	delivery	5	37
121792	2020-08-20 09:31:34	2020-08-20	17	[{"id_menu":4,"count":1}]	7877	delivery	5	22
121793	2020-08-20 09:32:01	2020-08-20	9	[{"id_menu":6,"count":2}]	1306	pick-up	0	9
121794	2020-08-20 09:38:40	2020-08-20	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15437	delivery	5	36
121795	2020-08-20 09:41:12	2020-08-20	9	[{"id_menu":6,"count":1}]	9631	pick-up	0	9
121796	2020-08-20 09:41:13	2020-08-20	30	[{"id_menu":3,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5497	delivery	5	35
121797	2020-08-20 09:43:25	2020-08-20	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	38759	delivery	5	26
121798	2020-08-20 09:43:44	2020-08-20	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	22529	delivery	5	31
121799	2020-08-20 09:47:58	2020-08-20	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	40945	delivery	5	31
121800	2020-08-20 09:49:11	2020-08-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28315	delivery	5	22
121801	2020-08-20 09:51:35	2020-08-20	9	[{"id_menu":7,"count":2}]	46527	pick-up	0	9
121802	2020-08-20 09:53:46	2020-08-20	12	[{"id_menu":3,"count":1}]	21139	delivery	5	17
121803	2020-08-20 09:57:01	2020-08-20	9	[{"id_menu":6,"count":1}]	29174	delivery	5	14
121804	2020-08-20 09:57:50	2020-08-20	8	[{"id_menu":5,"count":1}]	38601	pick-up	0	8
121805	2020-08-20 10:05:57	2020-08-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	25470	delivery	5	28
121806	2020-08-20 10:06:12	2020-08-20	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25473	delivery	5	40
121807	2020-08-20 10:07:14	2020-08-20	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	18870	delivery	5	36
121808	2020-08-20 10:09:46	2020-08-20	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	46416	delivery	5	25
121809	2020-08-20 10:20:19	2020-08-20	14	[{"id_menu":2,"count":1}]	26947	delivery	5	19
121810	2020-08-20 10:20:34	2020-08-20	12	[{"id_menu":1,"count":1}]	42820	delivery	5	17
121811	2020-08-20 10:22:54	2020-08-20	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22201	delivery	5	31
121812	2020-08-20 10:24:53	2020-08-20	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	45308	delivery	5	31
121813	2020-08-20 10:26:49	2020-08-20	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	20912	delivery	5	44
121814	2020-08-20 10:27:32	2020-08-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31183	delivery	5	23
121815	2020-08-20 10:28:47	2020-08-20	9	[{"id_menu":7,"count":1}]	23427	delivery	5	14
121816	2020-08-20 10:30:55	2020-08-20	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	28629	pick-up	0	29
121817	2020-08-20 10:31:02	2020-08-20	12	[{"id_menu":3,"count":1}]	28276	delivery	5	17
121818	2020-08-20 10:32:17	2020-08-20	17	[{"id_menu":4,"count":1}]	42427	pick-up	0	17
121819	2020-08-20 10:35:26	2020-08-20	9	[{"id_menu":7,"count":2}]	28243	pick-up	0	9
121820	2020-08-20 10:35:53	2020-08-20	14	[{"id_menu":2,"count":1}]	46361	delivery	5	19
121821	2020-08-20 10:37:13	2020-08-20	37	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	22445	pick-up	0	37
121822	2020-08-20 10:37:21	2020-08-20	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	46302	delivery	5	36
121823	2020-08-20 10:38:11	2020-08-20	14	[{"id_menu":2,"count":1}]	44285	delivery	5	19
121824	2020-08-20 10:39:53	2020-08-20	9	[{"id_menu":6,"count":1}]	24766	pick-up	0	9
121825	2020-08-20 10:43:17	2020-08-20	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	837	pick-up	0	38
121826	2020-08-20 10:43:41	2020-08-20	8	[{"id_menu":5,"count":1}]	46474	delivery	5	13
121827	2020-08-20 10:43:58	2020-08-20	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	16344	delivery	5	26
121828	2020-08-20 10:46:00	2020-08-20	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	46347	delivery	5	31
121829	2020-08-20 10:46:31	2020-08-20	17	[{"id_menu":4,"count":1}]	46311	delivery	5	22
121830	2020-08-20 10:47:22	2020-08-20	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	27736	delivery	5	25
121831	2020-08-20 10:50:25	2020-08-20	37	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	46504	delivery	5	42
121832	2020-08-20 10:52:35	2020-08-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	25320	pick-up	0	23
121833	2020-08-20 10:55:15	2020-08-20	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	19321	pick-up	0	20
121834	2020-08-20 10:58:01	2020-08-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22942	delivery	5	22
121835	2020-08-20 10:58:52	2020-08-20	8	[{"id_menu":5,"count":1}]	8741	delivery	5	13
121836	2020-08-20 11:02:28	2020-08-20	9	[{"id_menu":6,"count":1}]	2839	pick-up	0	9
121837	2020-08-20 11:03:26	2020-08-20	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	46316	delivery	5	40
121838	2020-08-20 11:04:34	2020-08-20	14	[{"id_menu":2,"count":1}]	2028	delivery	5	19
121839	2020-08-20 11:07:58	2020-08-20	12	[{"id_menu":3,"count":1}]	37497	delivery	5	17
121840	2020-08-20 11:10:47	2020-08-20	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	46307	delivery	5	43
121841	2020-08-20 11:12:27	2020-08-20	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	15214	delivery	5	26
121842	2020-08-20 11:14:40	2020-08-20	9	[{"id_menu":7,"count":1}]	1079	delivery	5	14
121843	2020-08-20 11:18:36	2020-08-20	9	[{"id_menu":6,"count":1}]	10365	delivery	5	14
121844	2020-08-20 11:18:41	2020-08-20	12	[{"id_menu":3,"count":1}]	39471	pick-up	0	12
121845	2020-08-20 11:20:44	2020-08-20	9	[{"id_menu":7,"count":1}]	10974	delivery	5	14
121846	2020-08-20 11:23:36	2020-08-20	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	3300	delivery	5	39
121847	2020-08-20 11:23:43	2020-08-20	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	33805	delivery	5	43
121848	2020-08-20 11:25:16	2020-08-20	9	[{"id_menu":7,"count":1}]	14256	delivery	5	14
121849	2020-08-20 11:32:27	2020-08-20	12	[{"id_menu":1,"count":1}]	10807	delivery	5	17
121850	2020-08-20 11:33:25	2020-08-20	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	41607	delivery	5	48
121851	2020-08-20 11:36:19	2020-08-20	17	[{"id_menu":4,"count":1}]	20843	delivery	5	22
121852	2020-08-20 11:37:08	2020-08-20	14	[{"id_menu":2,"count":1}]	39923	delivery	5	19
121853	2020-08-20 11:42:54	2020-08-20	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	37149	delivery	5	34
121854	2020-08-20 11:45:00	2020-08-20	9	[{"id_menu":7,"count":1}]	45993	delivery	5	14
121855	2020-08-20 11:48:12	2020-08-20	12	[{"id_menu":3,"count":1}]	396	pick-up	0	12
121856	2020-08-20 11:48:28	2020-08-20	14	[{"id_menu":2,"count":1}]	15189	delivery	5	19
121857	2020-08-20 11:53:06	2020-08-20	12	[{"id_menu":3,"count":1}]	46492	delivery	5	17
121858	2020-08-20 11:58:13	2020-08-20	9	[{"id_menu":6,"count":1}]	46478	pick-up	0	9
121859	2020-08-20 11:58:19	2020-08-20	9	[{"id_menu":6,"count":2}]	46482	delivery	5	14
121860	2020-08-20 11:58:51	2020-08-20	12	[{"id_menu":3,"count":1}]	46354	pick-up	0	12
121861	2020-08-20 11:59:53	2020-08-20	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	46459	delivery	5	34
121862	2020-08-20 12:01:17	2020-08-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	28091	pick-up	0	23
121863	2020-08-20 12:02:15	2020-08-20	9	[{"id_menu":6,"count":1}]	3402	delivery	5	14
121864	2020-08-20 12:03:04	2020-08-20	12	[{"id_menu":1,"count":2}]	16450	delivery	5	17
121865	2020-08-20 12:05:19	2020-08-20	9	[{"id_menu":6,"count":1}]	46539	delivery	5	14
121866	2020-08-20 12:06:24	2020-08-20	9	[{"id_menu":6,"count":1}]	46349	pick-up	0	9
121867	2020-08-20 12:08:37	2020-08-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	389	pick-up	0	23
121868	2020-08-20 12:09:55	2020-08-20	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	9993	delivery	5	26
121869	2020-08-20 12:10:35	2020-08-20	9	[{"id_menu":7,"count":1}]	46461	delivery	5	14
121870	2020-08-20 12:12:06	2020-08-20	8	[{"id_menu":5,"count":1}]	10731	delivery	5	13
121871	2020-08-20 12:14:57	2020-08-20	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	46306	delivery	5	42
121872	2020-08-20 12:26:22	2020-08-20	8	[{"id_menu":5,"count":1}]	31210	delivery	5	13
121873	2020-08-20 12:27:01	2020-08-20	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	46517	delivery	5	43
121874	2020-08-20 12:27:03	2020-08-20	9	[{"id_menu":7,"count":1}]	46366	delivery	5	14
121875	2020-08-20 12:27:38	2020-08-20	12	[{"id_menu":1,"count":2}]	6866	delivery	5	17
121876	2020-08-20 12:32:11	2020-08-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	46429	delivery	5	22
121877	2020-08-20 12:34:58	2020-08-20	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	36549	delivery	5	52
121878	2020-08-20 12:39:11	2020-08-20	9	[{"id_menu":6,"count":1}]	640	pick-up	0	9
121879	2020-08-20 12:39:20	2020-08-20	12	[{"id_menu":3,"count":2}]	28106	delivery	5	17
121880	2020-08-20 12:41:24	2020-08-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1630	pick-up	0	18
121881	2020-08-20 12:41:27	2020-08-20	9	[{"id_menu":6,"count":1}]	43081	delivery	5	14
121882	2020-08-20 12:41:48	2020-08-20	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	9933	delivery	5	48
121883	2020-08-20 12:43:26	2020-08-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	46544	delivery	5	28
121884	2020-08-20 12:43:48	2020-08-20	8	[{"id_menu":5,"count":1}]	38682	delivery	5	13
121885	2020-08-20 12:44:56	2020-08-20	9	[{"id_menu":6,"count":1}]	46323	delivery	5	14
121886	2020-08-20 12:48:57	2020-08-20	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	46551	delivery	5	36
121887	2020-08-20 12:50:10	2020-08-20	9	[{"id_menu":6,"count":1}]	8347	pick-up	0	9
121888	2020-08-20 12:51:05	2020-08-20	12	[{"id_menu":3,"count":1}]	19566	delivery	5	17
121889	2020-08-20 12:56:29	2020-08-20	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	46303	delivery	5	26
121890	2020-08-20 12:58:52	2020-08-20	49	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	46400	delivery	5	54
121891	2020-08-20 12:59:24	2020-08-20	8	[{"id_menu":5,"count":1}]	3752	pick-up	0	8
121892	2020-08-20 13:00:32	2020-08-20	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	25991	delivery	5	43
121893	2020-08-20 13:00:54	2020-08-20	12	[{"id_menu":1,"count":1}]	287	pick-up	0	12
121894	2020-08-20 13:02:34	2020-08-20	17	[{"id_menu":4,"count":1}]	46546	delivery	5	22
121895	2020-08-20 13:04:09	2020-08-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28813	delivery	5	23
121896	2020-08-20 13:06:20	2020-08-20	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	39598	delivery	5	30
121897	2020-08-20 13:08:56	2020-08-20	8	[{"id_menu":5,"count":1}]	4800	delivery	5	13
121898	2020-08-20 13:09:49	2020-08-20	9	[{"id_menu":6,"count":1}]	35335	pick-up	0	9
121899	2020-08-20 13:11:59	2020-08-20	9	[{"id_menu":7,"count":1}]	15604	delivery	5	14
121900	2020-08-20 13:21:51	2020-08-20	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	46521	delivery	5	39
121901	2020-08-20 13:24:29	2020-08-20	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	46548	delivery	5	39
121902	2020-08-20 13:25:02	2020-08-20	17	[{"id_menu":4,"count":1}]	46322	delivery	5	22
121903	2020-08-20 13:26:04	2020-08-20	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	46346	delivery	5	26
121904	2020-08-20 13:26:55	2020-08-20	17	[{"id_menu":4,"count":1}]	21308	pick-up	0	17
121905	2020-08-20 13:28:21	2020-08-20	17	[{"id_menu":4,"count":1}]	527	pick-up	0	17
121906	2020-08-20 13:35:22	2020-08-20	14	[{"id_menu":2,"count":1}]	2080	pick-up	0	14
121907	2020-08-20 13:35:38	2020-08-20	8	[{"id_menu":5,"count":1}]	40071	delivery	5	13
121908	2020-08-20 13:38:26	2020-08-20	8	[{"id_menu":5,"count":1}]	46425	delivery	5	13
121909	2020-08-20 13:39:36	2020-08-20	14	[{"id_menu":2,"count":1}]	46506	delivery	5	19
121910	2020-08-20 13:40:28	2020-08-20	17	[{"id_menu":4,"count":1}]	31636	delivery	5	22
121911	2020-08-20 13:40:39	2020-08-20	12	[{"id_menu":1,"count":1}]	3570	pick-up	0	12
121912	2020-08-20 13:42:44	2020-08-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	26392	delivery	5	22
121913	2020-08-20 13:45:41	2020-08-20	9	[{"id_menu":6,"count":1}]	46319	delivery	5	14
121914	2020-08-20 13:45:58	2020-08-20	9	[{"id_menu":6,"count":1}]	3332	pick-up	0	9
121915	2020-08-20 13:46:37	2020-08-20	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	40377	delivery	5	39
121916	2020-08-20 13:47:21	2020-08-20	14	[{"id_menu":2,"count":1}]	35565	delivery	5	19
121917	2020-08-20 13:50:11	2020-08-20	17	[{"id_menu":4,"count":1}]	27076	delivery	5	22
121918	2020-08-20 13:50:49	2020-08-20	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	46401	delivery	5	42
121919	2020-08-20 13:50:58	2020-08-20	12	[{"id_menu":1,"count":1}]	29688	delivery	5	17
121920	2020-08-20 13:59:49	2020-08-20	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	25458	delivery	5	28
121921	2020-08-20 14:00:02	2020-08-20	17	[{"id_menu":4,"count":1}]	22082	delivery	5	22
121922	2020-08-20 14:03:15	2020-08-20	8	[{"id_menu":5,"count":1}]	46385	pick-up	0	8
121923	2020-08-20 14:07:13	2020-08-20	9	[{"id_menu":7,"count":1}]	19457	delivery	5	14
121924	2020-08-20 14:10:57	2020-08-20	14	[{"id_menu":2,"count":2}]	7128	pick-up	0	14
121925	2020-08-20 14:13:00	2020-08-20	12	[{"id_menu":1,"count":1}]	29494	delivery	5	17
121926	2020-08-20 14:14:14	2020-08-20	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	46398	delivery	5	23
121927	2020-08-20 14:15:50	2020-08-20	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	4363	delivery	5	26
121928	2020-08-20 14:16:37	2020-08-20	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	46407	pick-up	0	22
121929	2020-08-20 14:19:21	2020-08-20	14	[{"id_menu":2,"count":1}]	46437	pick-up	0	14
121930	2020-08-20 14:19:38	2020-08-20	17	[{"id_menu":4,"count":2}]	46357	pick-up	0	17
121931	2020-08-20 14:19:53	2020-08-20	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	22351	pick-up	0	26
121932	2020-08-20 14:20:46	2020-08-20	17	[{"id_menu":4,"count":1}]	27804	pick-up	0	17
121933	2020-08-20 14:25:19	2020-08-20	8	[{"id_menu":5,"count":1}]	24771	delivery	5	13
121934	2020-08-20 14:25:25	2020-08-20	9	[{"id_menu":6,"count":1}]	4114	delivery	5	14
121935	2020-08-20 14:27:20	2020-08-20	17	[{"id_menu":4,"count":1}]	15892	delivery	5	22
121936	2020-08-20 14:29:04	2020-08-20	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	46435	delivery	5	43
121937	2020-08-20 14:30:35	2020-08-20	17	[{"id_menu":4,"count":1}]	38377	pick-up	0	17
121938	2020-08-20 14:33:35	2020-08-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	46383	delivery	5	28
121939	2020-08-20 14:35:48	2020-08-20	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5399	delivery	5	45
121940	2020-08-20 14:37:17	2020-08-20	9	[{"id_menu":7,"count":1}]	38236	delivery	5	14
121941	2020-08-20 14:38:28	2020-08-20	14	[{"id_menu":2,"count":1}]	46413	delivery	5	19
121942	2020-08-20 14:39:26	2020-08-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	10707	delivery	5	28
121943	2020-08-20 14:40:30	2020-08-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	22259	delivery	5	28
121944	2020-08-20 14:45:03	2020-08-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11393	delivery	5	22
121945	2020-08-20 14:46:59	2020-08-20	14	[{"id_menu":2,"count":1}]	5232	pick-up	0	14
121946	2020-08-20 14:49:23	2020-08-20	17	[{"id_menu":4,"count":1}]	20554	pick-up	0	17
121947	2020-08-20 14:54:44	2020-08-20	12	[{"id_menu":3,"count":1}]	46453	delivery	5	17
121948	2020-08-20 14:54:48	2020-08-20	9	[{"id_menu":6,"count":1}]	11992	pick-up	0	9
121949	2020-08-20 15:00:26	2020-08-20	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	36536	pick-up	0	26
121950	2020-08-20 15:01:39	2020-08-20	14	[{"id_menu":2,"count":1}]	15155	delivery	5	19
121951	2020-08-20 15:04:22	2020-08-20	17	[{"id_menu":4,"count":1}]	38978	delivery	5	22
121952	2020-08-20 15:06:41	2020-08-20	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	24021	delivery	5	43
121953	2020-08-20 15:07:19	2020-08-20	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	46443	delivery	5	45
121954	2020-08-20 15:10:22	2020-08-20	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	39578	delivery	5	31
121955	2020-08-20 15:11:08	2020-08-20	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	46335	delivery	5	39
121956	2020-08-20 15:12:03	2020-08-20	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	21614	delivery	5	26
121957	2020-08-20 15:13:49	2020-08-20	9	[{"id_menu":7,"count":1}]	19596	delivery	5	14
121958	2020-08-20 15:14:23	2020-08-20	8	[{"id_menu":5,"count":1}]	25968	delivery	5	13
121959	2020-08-20 15:17:16	2020-08-20	17	[{"id_menu":4,"count":1}]	37099	pick-up	0	17
121960	2020-08-20 15:17:30	2020-08-20	9	[{"id_menu":7,"count":1}]	6203	delivery	5	14
121961	2020-08-20 15:20:11	2020-08-20	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	46465	delivery	5	43
121962	2020-08-20 15:20:16	2020-08-20	9	[{"id_menu":7,"count":1}]	27252	delivery	5	14
121963	2020-08-20 15:20:18	2020-08-20	8	[{"id_menu":5,"count":1}]	46328	delivery	5	13
121964	2020-08-20 15:21:33	2020-08-20	14	[{"id_menu":2,"count":1}]	19001	delivery	5	19
121965	2020-08-20 15:22:27	2020-08-20	8	[{"id_menu":5,"count":1}]	23241	delivery	5	13
121966	2020-08-20 15:22:37	2020-08-20	12	[{"id_menu":3,"count":1}]	46447	delivery	5	17
121967	2020-08-20 15:25:37	2020-08-20	17	[{"id_menu":4,"count":1}]	46533	delivery	5	22
121968	2020-08-20 15:30:10	2020-08-20	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	46444	delivery	5	43
121969	2020-08-20 15:30:36	2020-08-20	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	6326	delivery	5	25
121970	2020-08-20 15:31:13	2020-08-20	12	[{"id_menu":3,"count":1}]	42257	delivery	5	17
121971	2020-08-20 15:37:24	2020-08-20	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1536	pick-up	0	26
121972	2020-08-20 15:37:52	2020-08-20	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29358	delivery	5	51
121973	2020-08-20 15:39:06	2020-08-20	9	[{"id_menu":6,"count":1}]	46367	delivery	5	14
121974	2020-08-20 15:40:22	2020-08-20	8	[{"id_menu":5,"count":2}]	26284	delivery	5	13
121975	2020-08-20 15:45:18	2020-08-20	9	[{"id_menu":6,"count":1}]	46301	delivery	5	14
121976	2020-08-20 15:46:05	2020-08-20	17	[{"id_menu":4,"count":1}]	46388	pick-up	0	17
121977	2020-08-20 15:46:58	2020-08-20	17	[{"id_menu":4,"count":1}]	12506	pick-up	0	17
121978	2020-08-20 15:47:02	2020-08-20	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	26387	delivery	5	30
121979	2020-08-20 15:51:30	2020-08-20	9	[{"id_menu":7,"count":1}]	46510	delivery	5	14
121980	2020-08-20 15:52:53	2020-08-20	9	[{"id_menu":6,"count":1}]	42290	delivery	5	14
121981	2020-08-20 15:57:30	2020-08-20	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	46294	delivery	5	36
121982	2020-08-20 15:59:13	2020-08-20	12	[{"id_menu":3,"count":1}]	2891	pick-up	0	12
121983	2020-08-20 15:59:14	2020-08-20	14	[{"id_menu":2,"count":1}]	45894	delivery	5	19
121984	2020-08-20 15:59:25	2020-08-20	14	[{"id_menu":2,"count":1}]	21535	delivery	5	19
121985	2020-08-20 16:00:37	2020-08-20	12	[{"id_menu":1,"count":1}]	19039	delivery	5	17
121986	2020-08-20 16:00:52	2020-08-20	8	[{"id_menu":5,"count":1}]	1834	pick-up	0	8
121987	2020-08-20 16:01:07	2020-08-20	12	[{"id_menu":1,"count":1}]	12599	delivery	5	17
121988	2020-08-20 16:02:05	2020-08-20	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	46518	delivery	5	43
121989	2020-08-20 16:05:37	2020-08-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":3}]	6695	delivery	5	28
121990	2020-08-20 16:05:58	2020-08-20	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	43113	pick-up	0	31
121991	2020-08-20 16:05:59	2020-08-20	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16181	delivery	5	54
121992	2020-08-20 16:07:41	2020-08-20	12	[{"id_menu":1,"count":1}]	46299	delivery	5	17
121993	2020-08-20 16:08:24	2020-08-20	9	[{"id_menu":7,"count":1}]	13950	pick-up	0	9
121994	2020-08-20 16:09:42	2020-08-20	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	18312	delivery	5	30
121995	2020-08-20 16:13:16	2020-08-20	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	15406	delivery	5	25
121996	2020-08-20 16:13:43	2020-08-20	9	[{"id_menu":6,"count":1}]	23225	pick-up	0	9
121997	2020-08-20 16:14:16	2020-08-20	9	[{"id_menu":7,"count":1}]	5870	delivery	5	14
121998	2020-08-20 16:15:42	2020-08-20	8	[{"id_menu":5,"count":2}]	10143	delivery	5	13
121999	2020-08-20 16:18:07	2020-08-20	9	[{"id_menu":7,"count":1}]	14358	pick-up	0	9
122000	2020-08-20 16:19:08	2020-08-20	8	[{"id_menu":5,"count":1}]	7392	delivery	5	13
122001	2020-08-20 16:19:35	2020-08-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22260	delivery	5	22
122002	2020-08-20 16:19:39	2020-08-20	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	46389	delivery	5	26
122003	2020-08-20 16:20:45	2020-08-20	8	[{"id_menu":5,"count":1}]	9065	pick-up	0	8
122004	2020-08-20 16:21:40	2020-08-20	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	46490	delivery	5	36
122005	2020-08-20 16:22:23	2020-08-20	14	[{"id_menu":2,"count":1}]	12180	delivery	5	19
122006	2020-08-20 16:24:37	2020-08-20	9	[{"id_menu":7,"count":1}]	18452	delivery	5	14
122007	2020-08-20 16:25:12	2020-08-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	44321	delivery	5	22
122008	2020-08-20 16:25:39	2020-08-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	46364	delivery	5	22
122009	2020-08-20 16:30:26	2020-08-20	17	[{"id_menu":4,"count":1}]	2311	pick-up	0	17
122010	2020-08-20 16:31:05	2020-08-20	12	[{"id_menu":1,"count":1}]	40339	delivery	5	17
122011	2020-08-20 16:32:32	2020-08-20	9	[{"id_menu":7,"count":1}]	34688	delivery	5	14
122012	2020-08-20 16:32:39	2020-08-20	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	46308	delivery	5	26
122013	2020-08-20 16:33:30	2020-08-20	9	[{"id_menu":6,"count":1}]	31756	delivery	5	14
122014	2020-08-20 16:36:05	2020-08-20	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	24789	delivery	5	40
122015	2020-08-20 16:36:31	2020-08-20	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	42703	delivery	5	40
122016	2020-08-20 16:37:03	2020-08-20	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41923	delivery	5	54
122017	2020-08-20 16:37:18	2020-08-20	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	23805	delivery	5	27
122018	2020-08-20 16:37:39	2020-08-20	9	[{"id_menu":7,"count":1}]	19157	delivery	5	14
122019	2020-08-20 16:39:14	2020-08-20	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4970	delivery	5	37
122020	2020-08-20 16:43:32	2020-08-20	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	46341	delivery	5	36
122021	2020-08-20 16:43:39	2020-08-20	9	[{"id_menu":7,"count":1}]	45565	delivery	5	14
122022	2020-08-20 16:44:10	2020-08-20	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	9543	delivery	5	25
122023	2020-08-20 16:45:16	2020-08-20	17	[{"id_menu":4,"count":1}]	13535	delivery	5	22
122024	2020-08-20 16:45:20	2020-08-20	8	[{"id_menu":5,"count":1}]	46508	delivery	5	13
122025	2020-08-20 16:45:58	2020-08-20	12	[{"id_menu":3,"count":1}]	9533	delivery	5	17
122026	2020-08-20 16:47:01	2020-08-20	12	[{"id_menu":3,"count":1}]	16346	delivery	5	17
122027	2020-08-20 16:47:19	2020-08-20	17	[{"id_menu":4,"count":1}]	38409	delivery	5	22
122028	2020-08-20 16:47:59	2020-08-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	20512	delivery	5	22
122029	2020-08-20 16:50:05	2020-08-20	9	[{"id_menu":6,"count":2}]	43148	delivery	5	14
122030	2020-08-20 16:50:59	2020-08-20	17	[{"id_menu":4,"count":1}]	11534	delivery	5	22
122031	2020-08-20 16:55:02	2020-08-20	8	[{"id_menu":5,"count":1}]	18671	delivery	5	13
122032	2020-08-20 16:56:24	2020-08-20	14	[{"id_menu":2,"count":1}]	2333	delivery	5	19
122033	2020-08-20 16:57:31	2020-08-20	14	[{"id_menu":2,"count":1}]	13874	pick-up	0	14
122034	2020-08-20 16:59:03	2020-08-20	14	[{"id_menu":2,"count":1}]	15962	delivery	5	19
122035	2020-08-20 16:59:24	2020-08-20	17	[{"id_menu":4,"count":1}]	39705	pick-up	0	17
122036	2020-08-20 17:00:06	2020-08-20	9	[{"id_menu":6,"count":1}]	46368	delivery	5	14
122037	2020-08-20 17:00:37	2020-08-20	9	[{"id_menu":6,"count":2}]	46298	pick-up	0	9
122038	2020-08-20 17:02:09	2020-08-20	12	[{"id_menu":1,"count":1}]	46359	delivery	5	17
122039	2020-08-20 17:04:18	2020-08-20	8	[{"id_menu":5,"count":1}]	15512	delivery	5	13
122040	2020-08-20 17:05:23	2020-08-20	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	44490	delivery	5	43
122041	2020-08-20 17:08:18	2020-08-20	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	46327	delivery	5	43
122042	2020-08-20 17:09:42	2020-08-20	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7822	delivery	5	43
122043	2020-08-20 17:12:34	2020-08-20	8	[{"id_menu":5,"count":1}]	8726	delivery	5	13
122044	2020-08-20 17:12:46	2020-08-20	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	46312	delivery	5	52
122045	2020-08-20 17:14:10	2020-08-20	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	721	delivery	5	36
122046	2020-08-20 17:15:03	2020-08-20	14	[{"id_menu":2,"count":1}]	46436	delivery	5	19
122047	2020-08-20 17:18:31	2020-08-20	9	[{"id_menu":7,"count":1}]	14696	delivery	5	14
122048	2020-08-20 17:21:04	2020-08-20	12	[{"id_menu":3,"count":1}]	31171	delivery	5	17
122049	2020-08-20 17:22:05	2020-08-20	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	32598	delivery	5	45
122050	2020-08-20 17:22:56	2020-08-20	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	19668	delivery	5	40
122051	2020-08-20 17:24:22	2020-08-20	17	[{"id_menu":4,"count":1}]	11515	delivery	5	22
122052	2020-08-20 17:27:28	2020-08-20	17	[{"id_menu":4,"count":1}]	15388	delivery	5	22
122053	2020-08-20 17:27:32	2020-08-20	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	43288	pick-up	0	29
122054	2020-08-20 17:28:56	2020-08-20	9	[{"id_menu":7,"count":1}]	20817	delivery	5	14
122055	2020-08-20 17:33:37	2020-08-20	8	[{"id_menu":5,"count":1}]	1017	pick-up	0	8
122056	2020-08-20 17:34:14	2020-08-20	14	[{"id_menu":2,"count":1}]	33359	pick-up	0	14
122057	2020-08-20 17:35:33	2020-08-20	14	[{"id_menu":2,"count":1}]	19172	delivery	5	19
122058	2020-08-20 17:37:35	2020-08-20	9	[{"id_menu":7,"count":1}]	46395	delivery	5	14
122059	2020-08-20 17:38:07	2020-08-20	17	[{"id_menu":4,"count":2}]	46505	delivery	5	22
122060	2020-08-20 17:42:28	2020-08-20	9	[{"id_menu":6,"count":1}]	15369	delivery	5	14
122061	2020-08-20 17:42:59	2020-08-20	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	46297	delivery	5	22
122062	2020-08-20 17:45:10	2020-08-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	46456	delivery	5	22
122063	2020-08-20 17:46:23	2020-08-20	14	[{"id_menu":2,"count":1}]	46473	delivery	5	19
122064	2020-08-20 17:49:08	2020-08-20	14	[{"id_menu":2,"count":1}]	17906	pick-up	0	14
122065	2020-08-20 17:50:12	2020-08-20	9	[{"id_menu":6,"count":1}]	22865	delivery	5	14
122066	2020-08-20 17:51:24	2020-08-20	14	[{"id_menu":2,"count":1}]	46493	delivery	5	19
122067	2020-08-20 17:52:35	2020-08-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	36887	delivery	5	28
122068	2020-08-20 17:52:35	2020-08-20	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	46314	delivery	5	25
122069	2020-08-20 17:52:39	2020-08-20	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	32557	delivery	5	31
122070	2020-08-20 17:55:41	2020-08-20	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	46484	delivery	5	25
122071	2020-08-20 18:01:40	2020-08-20	8	[{"id_menu":5,"count":1}]	9477	delivery	5	13
122072	2020-08-20 18:04:49	2020-08-20	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	46390	delivery	5	40
122073	2020-08-20 18:06:21	2020-08-20	17	[{"id_menu":4,"count":1}]	46334	pick-up	0	17
122074	2020-08-20 18:07:52	2020-08-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	37163	delivery	5	22
122075	2020-08-20 18:07:54	2020-08-20	12	[{"id_menu":3,"count":2}]	44590	delivery	5	17
122076	2020-08-20 18:12:07	2020-08-20	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	27541	pick-up	0	35
122077	2020-08-20 18:12:59	2020-08-20	12	[{"id_menu":1,"count":1}]	46356	delivery	5	17
122078	2020-08-20 18:15:10	2020-08-20	9	[{"id_menu":6,"count":1}]	10385	pick-up	0	9
122079	2020-08-20 18:16:30	2020-08-20	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	46376	pick-up	0	29
122080	2020-08-20 18:22:05	2020-08-20	14	[{"id_menu":2,"count":1}]	32108	delivery	5	19
122081	2020-08-20 18:26:15	2020-08-20	9	[{"id_menu":6,"count":1}]	46339	delivery	5	14
122082	2020-08-20 18:27:42	2020-08-20	17	[{"id_menu":4,"count":1}]	35427	pick-up	0	17
122083	2020-08-20 18:39:32	2020-08-20	9	[{"id_menu":7,"count":1}]	39878	delivery	5	14
122084	2020-08-20 18:41:33	2020-08-20	17	[{"id_menu":4,"count":1}]	46004	delivery	5	22
122085	2020-08-20 18:46:01	2020-08-20	12	[{"id_menu":1,"count":1}]	32678	delivery	5	17
122086	2020-08-20 18:52:58	2020-08-20	9	[{"id_menu":7,"count":1}]	46526	delivery	5	14
122087	2020-08-20 18:54:56	2020-08-20	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1296	pick-up	0	26
122088	2020-08-20 18:58:16	2020-08-20	9	[{"id_menu":6,"count":1}]	15769	pick-up	0	9
122089	2020-08-20 18:58:50	2020-08-20	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	45099	delivery	5	31
122090	2020-08-20 18:59:18	2020-08-20	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	46475	delivery	5	27
122091	2020-08-20 19:01:56	2020-08-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	1963	pick-up	0	17
122092	2020-08-20 19:03:17	2020-08-20	12	[{"id_menu":3,"count":1}]	46513	delivery	5	17
122093	2020-08-20 19:04:43	2020-08-20	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	46330	delivery	5	39
122094	2020-08-20 19:07:27	2020-08-20	12	[{"id_menu":1,"count":1}]	31694	delivery	5	17
122095	2020-08-20 19:10:37	2020-08-20	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	42381	delivery	5	55
122096	2020-08-20 19:10:53	2020-08-20	9	[{"id_menu":6,"count":1}]	6177	pick-up	0	9
122097	2020-08-20 19:12:58	2020-08-20	14	[{"id_menu":2,"count":1}]	10580	delivery	5	19
122098	2020-08-20 19:15:15	2020-08-20	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	29127	pick-up	0	17
122099	2020-08-20 19:16:57	2020-08-20	8	[{"id_menu":5,"count":1}]	8024	delivery	5	13
122100	2020-08-20 19:17:53	2020-08-20	8	[{"id_menu":5,"count":1}]	15855	delivery	5	13
122101	2020-08-20 19:18:27	2020-08-20	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":2}]	37399	delivery	5	31
122102	2020-08-20 19:19:27	2020-08-20	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	883	pick-up	0	31
122103	2020-08-20 19:19:36	2020-08-20	12	[{"id_menu":1,"count":1}]	46313	delivery	5	17
122104	2020-08-20 19:23:23	2020-08-20	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	46409	delivery	5	31
122105	2020-08-20 19:24:14	2020-08-20	12	[{"id_menu":1,"count":1}]	27300	delivery	5	17
122106	2020-08-20 19:28:44	2020-08-20	8	[{"id_menu":5,"count":1}]	34656	delivery	5	13
122107	2020-08-20 19:33:53	2020-08-20	17	[{"id_menu":4,"count":1}]	44353	delivery	5	22
122108	2020-08-20 19:34:19	2020-08-20	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	5962	pick-up	0	21
122109	2020-08-20 19:34:36	2020-08-20	8	[{"id_menu":5,"count":1}]	46408	delivery	5	13
122110	2020-08-20 19:41:36	2020-08-20	14	[{"id_menu":2,"count":1}]	46329	delivery	5	19
122111	2020-08-20 19:44:21	2020-08-20	9	[{"id_menu":7,"count":1}]	2806	delivery	5	14
122112	2020-08-20 19:53:20	2020-08-20	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	32680	delivery	5	22
122113	2020-08-20 19:55:10	2020-08-20	9	[{"id_menu":7,"count":1}]	46379	delivery	5	14
122114	2020-08-20 19:57:13	2020-08-20	9	[{"id_menu":7,"count":1}]	46556	delivery	5	14
122115	2020-08-20 19:57:14	2020-08-20	14	[{"id_menu":2,"count":1}]	33409	delivery	5	19
122116	2020-08-20 19:57:47	2020-08-20	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	46423	delivery	5	26
122117	2020-08-20 19:58:10	2020-08-20	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	46412	delivery	5	34
122118	2020-08-20 20:01:53	2020-08-20	8	[{"id_menu":5,"count":1}]	35933	pick-up	0	8
122119	2020-08-20 20:02:00	2020-08-20	17	[{"id_menu":4,"count":1}]	46532	pick-up	0	17
122120	2020-08-20 20:04:38	2020-08-20	9	[{"id_menu":7,"count":1}]	46467	delivery	5	14
122121	2020-08-20 20:05:54	2020-08-20	14	[{"id_menu":2,"count":1}]	21611	delivery	5	19
122122	2020-08-20 20:07:31	2020-08-20	12	[{"id_menu":1,"count":1}]	3579	delivery	5	17
122123	2020-08-20 20:08:17	2020-08-20	8	[{"id_menu":5,"count":1}]	46509	delivery	5	13
122124	2020-08-20 20:08:20	2020-08-20	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	14491	delivery	5	34
122125	2020-08-20 20:11:12	2020-08-20	12	[{"id_menu":3,"count":1}]	7007	delivery	5	17
122126	2020-08-20 20:12:13	2020-08-20	14	[{"id_menu":2,"count":1}]	37978	delivery	5	19
122127	2020-08-20 20:13:01	2020-08-20	17	[{"id_menu":4,"count":1}]	46397	delivery	5	22
122128	2020-08-20 20:16:05	2020-08-20	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	32468	delivery	5	31
122129	2020-08-20 20:16:35	2020-08-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	21467	delivery	5	28
122130	2020-08-20 20:18:11	2020-08-20	9	[{"id_menu":7,"count":1}]	31811	delivery	5	14
122131	2020-08-20 20:18:18	2020-08-20	12	[{"id_menu":1,"count":1}]	4020	pick-up	0	12
122132	2020-08-20 20:22:16	2020-08-20	17	[{"id_menu":4,"count":1}]	1559	pick-up	0	17
122133	2020-08-20 20:23:41	2020-08-20	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	17456	delivery	5	30
122134	2020-08-20 20:23:55	2020-08-20	12	[{"id_menu":1,"count":1}]	10436	pick-up	0	12
122135	2020-08-20 20:24:18	2020-08-20	17	[{"id_menu":4,"count":1}]	9414	pick-up	0	17
122136	2020-08-20 20:31:10	2020-08-20	14	[{"id_menu":2,"count":1}]	17657	delivery	5	19
122137	2020-08-20 20:32:36	2020-08-20	12	[{"id_menu":3,"count":1}]	39144	delivery	5	17
122138	2020-08-20 20:33:01	2020-08-20	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	7143	delivery	5	25
122139	2020-08-20 20:33:50	2020-08-20	12	[{"id_menu":3,"count":1}]	7806	pick-up	0	12
122140	2020-08-20 20:34:10	2020-08-20	9	[{"id_menu":7,"count":1}]	46483	delivery	5	14
122141	2020-08-20 20:34:29	2020-08-20	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	37004	delivery	5	34
122142	2020-08-20 20:46:14	2020-08-20	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	46450	delivery	5	22
122143	2020-08-20 20:46:16	2020-08-20	9	[{"id_menu":6,"count":1}]	13036	delivery	5	14
122144	2020-08-20 20:48:19	2020-08-20	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	44508	delivery	5	56
122145	2020-08-20 20:48:43	2020-08-20	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	45007	delivery	5	54
122146	2020-08-20 20:49:43	2020-08-20	9	[{"id_menu":6,"count":2}]	33989	delivery	5	14
122147	2020-08-20 20:50:06	2020-08-20	17	[{"id_menu":4,"count":1}]	46555	delivery	5	22
122148	2020-08-20 20:51:12	2020-08-20	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	29429	delivery	5	25
122149	2020-08-20 20:51:35	2020-08-20	17	[{"id_menu":4,"count":1}]	29095	delivery	5	22
122150	2020-08-20 20:52:11	2020-08-20	9	[{"id_menu":6,"count":1}]	18271	delivery	5	14
122151	2020-08-20 20:52:32	2020-08-20	9	[{"id_menu":6,"count":1}]	46410	delivery	5	14
122152	2020-08-20 20:54:39	2020-08-20	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12867	delivery	5	36
122153	2020-08-20 20:55:43	2020-08-20	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	11681	pick-up	0	21
122154	2020-08-20 20:55:44	2020-08-20	12	[{"id_menu":1,"count":1}]	1670	pick-up	0	12
122155	2020-08-20 20:55:51	2020-08-20	14	[{"id_menu":2,"count":1}]	3741	delivery	5	19
122156	2020-08-20 21:08:15	2020-08-20	14	[{"id_menu":2,"count":1}]	23679	pick-up	0	14
122157	2020-08-20 21:09:06	2020-08-20	8	[{"id_menu":5,"count":1}]	19507	delivery	5	13
122158	2020-08-20 21:09:08	2020-08-20	9	[{"id_menu":6,"count":1}]	46371	delivery	5	14
122159	2020-08-20 21:09:10	2020-08-20	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	46360	delivery	5	39
122228	2020-08-20 22:55:22	2020-08-20	14	[{"id_menu":2,"count":1}]	40178	delivery	5	19
122160	2020-08-20 21:09:10	2020-08-20	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	121	pick-up	0	42
122161	2020-08-20 21:09:26	2020-08-20	17	[{"id_menu":4,"count":1}]	4482	delivery	5	22
122162	2020-08-20 21:12:08	2020-08-20	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":2}]	30910	delivery	5	28
122163	2020-08-20 21:12:12	2020-08-20	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	7814	pick-up	0	20
122164	2020-08-20 21:12:50	2020-08-20	9	[{"id_menu":6,"count":1}]	30233	delivery	5	14
122165	2020-08-20 21:13:47	2020-08-20	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	19811	delivery	5	31
122166	2020-08-20 21:15:03	2020-08-20	9	[{"id_menu":7,"count":1}]	1521	delivery	5	14
122167	2020-08-20 21:16:31	2020-08-20	12	[{"id_menu":1,"count":1}]	34318	delivery	5	17
122168	2020-08-20 21:18:00	2020-08-20	17	[{"id_menu":4,"count":1}]	15583	delivery	5	22
122169	2020-08-20 21:18:27	2020-08-20	9	[{"id_menu":7,"count":1}]	4184	pick-up	0	9
122170	2020-08-20 21:18:45	2020-08-20	14	[{"id_menu":2,"count":1}]	28375	delivery	5	19
122171	2020-08-20 21:19:29	2020-08-20	12	[{"id_menu":1,"count":1}]	46496	delivery	5	17
122172	2020-08-20 21:22:21	2020-08-20	14	[{"id_menu":2,"count":1}]	15847	pick-up	0	14
122173	2020-08-20 21:23:32	2020-08-20	12	[{"id_menu":1,"count":1}]	24326	pick-up	0	12
122174	2020-08-20 21:26:42	2020-08-20	9	[{"id_menu":7,"count":1}]	46540	delivery	5	14
122175	2020-08-20 21:28:25	2020-08-20	9	[{"id_menu":7,"count":1}]	46519	delivery	5	14
122176	2020-08-20 21:29:05	2020-08-20	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	31822	delivery	5	26
122177	2020-08-20 21:30:51	2020-08-20	9	[{"id_menu":6,"count":1}]	154	delivery	5	14
122178	2020-08-20 21:31:07	2020-08-20	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2527	pick-up	0	17
122179	2020-08-20 21:31:46	2020-08-20	9	[{"id_menu":6,"count":1}]	46352	delivery	5	14
122180	2020-08-20 21:32:32	2020-08-20	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	22643	pick-up	0	38
122181	2020-08-20 21:33:16	2020-08-20	9	[{"id_menu":7,"count":1}]	38421	delivery	5	14
122182	2020-08-20 21:36:12	2020-08-20	9	[{"id_menu":6,"count":1}]	30614	pick-up	0	9
122183	2020-08-20 21:39:07	2020-08-20	14	[{"id_menu":2,"count":1}]	7799	delivery	5	19
122184	2020-08-20 21:40:11	2020-08-20	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	44051	delivery	5	39
122185	2020-08-20 21:44:27	2020-08-20	14	[{"id_menu":2,"count":1}]	37970	delivery	5	19
122186	2020-08-20 21:45:24	2020-08-20	8	[{"id_menu":5,"count":1}]	14726	delivery	5	13
122187	2020-08-20 21:47:01	2020-08-20	14	[{"id_menu":2,"count":1}]	27313	delivery	5	19
122188	2020-08-20 21:48:16	2020-08-20	17	[{"id_menu":4,"count":1}]	46309	delivery	5	22
122189	2020-08-20 21:51:25	2020-08-20	12	[{"id_menu":3,"count":1}]	36844	pick-up	0	12
122190	2020-08-20 21:51:42	2020-08-20	9	[{"id_menu":6,"count":2}]	46415	delivery	5	14
122191	2020-08-20 21:54:40	2020-08-20	9	[{"id_menu":6,"count":1}]	46525	delivery	5	14
122192	2020-08-20 21:55:34	2020-08-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	46351	delivery	5	28
122193	2020-08-20 21:57:09	2020-08-20	12	[{"id_menu":1,"count":2}]	46403	delivery	5	17
122194	2020-08-20 21:59:30	2020-08-20	12	[{"id_menu":3,"count":1}]	18325	delivery	5	17
122195	2020-08-20 22:03:57	2020-08-20	9	[{"id_menu":6,"count":1}]	32760	delivery	5	14
122196	2020-08-20 22:05:08	2020-08-20	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	46315	delivery	5	30
122197	2020-08-20 22:07:07	2020-08-20	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	18940	delivery	5	26
122198	2020-08-20 22:08:21	2020-08-20	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	5473	delivery	5	45
122199	2020-08-20 22:08:57	2020-08-20	17	[{"id_menu":4,"count":1}]	11930	delivery	5	22
122200	2020-08-20 22:09:24	2020-08-20	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	46460	delivery	5	53
122201	2020-08-20 22:12:18	2020-08-20	14	[{"id_menu":2,"count":1}]	28738	delivery	5	19
122202	2020-08-20 22:12:45	2020-08-20	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	11038	delivery	5	23
122203	2020-08-20 22:14:19	2020-08-20	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	39657	delivery	5	26
122204	2020-08-20 22:14:36	2020-08-20	12	[{"id_menu":3,"count":1}]	5125	delivery	5	17
122205	2020-08-20 22:14:43	2020-08-20	12	[{"id_menu":3,"count":1}]	11913	delivery	5	17
122206	2020-08-20 22:16:21	2020-08-20	9	[{"id_menu":6,"count":1}]	46535	delivery	5	14
122207	2020-08-20 22:16:39	2020-08-20	17	[{"id_menu":4,"count":1}]	27739	delivery	5	22
122208	2020-08-20 22:16:50	2020-08-20	9	[{"id_menu":7,"count":1}]	13787	delivery	5	14
122209	2020-08-20 22:18:46	2020-08-20	30	[{"id_menu":1,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	46305	delivery	5	35
122210	2020-08-20 22:18:53	2020-08-20	9	[{"id_menu":6,"count":1}]	23261	delivery	5	14
122211	2020-08-20 22:19:20	2020-08-20	12	[{"id_menu":3,"count":1}]	36732	delivery	5	17
122212	2020-08-20 22:19:49	2020-08-20	12	[{"id_menu":1,"count":1}]	21978	pick-up	0	12
122213	2020-08-20 22:20:46	2020-08-20	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39813	pick-up	0	32
122214	2020-08-20 22:22:01	2020-08-20	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	43571	delivery	5	27
122215	2020-08-20 22:24:27	2020-08-20	14	[{"id_menu":2,"count":1}]	46537	delivery	5	19
122216	2020-08-20 22:25:01	2020-08-20	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	46431	delivery	5	27
122217	2020-08-20 22:29:45	2020-08-20	9	[{"id_menu":6,"count":1}]	37505	delivery	5	14
122218	2020-08-20 22:29:58	2020-08-20	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	46469	delivery	5	30
122219	2020-08-20 22:31:52	2020-08-20	14	[{"id_menu":2,"count":1}]	14304	delivery	5	19
122220	2020-08-20 22:34:36	2020-08-20	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	24989	pick-up	0	21
122221	2020-08-20 22:35:02	2020-08-20	12	[{"id_menu":1,"count":1}]	270	pick-up	0	12
122222	2020-08-20 22:38:27	2020-08-20	9	[{"id_menu":6,"count":1}]	10326	pick-up	0	9
122223	2020-08-20 22:41:17	2020-08-20	14	[{"id_menu":2,"count":1}]	1118	pick-up	0	14
122224	2020-08-20 22:43:12	2020-08-20	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	2935	delivery	5	31
122225	2020-08-20 22:43:38	2020-08-20	9	[{"id_menu":7,"count":1}]	1233	pick-up	0	9
122226	2020-08-20 22:44:48	2020-08-20	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	46458	delivery	5	36
122227	2020-08-20 22:52:42	2020-08-20	12	[{"id_menu":1,"count":1}]	26872	pick-up	0	12
122229	2020-08-20 22:57:15	2020-08-20	14	[{"id_menu":2,"count":1}]	46342	delivery	5	19
122230	2020-08-20 22:58:59	2020-08-20	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13602	delivery	5	34
122231	2020-08-20 23:00:04	2020-08-20	12	[{"id_menu":1,"count":1}]	46442	delivery	5	17
122232	2020-08-20 23:00:26	2020-08-20	14	[{"id_menu":2,"count":1}]	46554	delivery	5	19
122233	2020-08-20 23:02:52	2020-08-20	8	[{"id_menu":5,"count":1}]	46538	delivery	5	13
122234	2020-08-20 23:03:03	2020-08-20	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	9406	delivery	5	31
122235	2020-08-20 23:03:20	2020-08-20	9	[{"id_menu":7,"count":1}]	46422	pick-up	0	9
122236	2020-08-20 23:03:53	2020-08-20	14	[{"id_menu":2,"count":1}]	46426	delivery	5	19
122237	2020-08-20 23:07:33	2020-08-20	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	8560	delivery	5	40
122238	2020-08-20 23:09:53	2020-08-20	8	[{"id_menu":5,"count":2}]	46348	delivery	5	13
122239	2020-08-20 23:10:05	2020-08-20	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	18275	delivery	5	37
122240	2020-08-20 23:11:59	2020-08-20	17	[{"id_menu":4,"count":1}]	39023	delivery	5	22
122241	2020-08-20 23:15:00	2020-08-20	14	[{"id_menu":2,"count":1}]	11807	delivery	5	19
122242	2020-08-20 23:15:13	2020-08-20	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	7098	pick-up	0	20
122243	2020-08-20 23:16:06	2020-08-20	12	[{"id_menu":1,"count":1}]	12165	delivery	5	17
122244	2020-08-20 23:16:50	2020-08-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	46500	delivery	5	28
122245	2020-08-20 23:17:28	2020-08-20	12	[{"id_menu":1,"count":1}]	46545	delivery	5	17
122246	2020-08-20 23:18:57	2020-08-20	9	[{"id_menu":6,"count":1}]	46530	pick-up	0	9
122247	2020-08-20 23:21:39	2020-08-20	9	[{"id_menu":6,"count":1}]	46344	delivery	5	14
122248	2020-08-20 23:24:28	2020-08-20	17	[{"id_menu":4,"count":1}]	45793	delivery	5	22
122249	2020-08-20 23:26:05	2020-08-20	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	46479	delivery	5	39
122250	2020-08-20 23:26:15	2020-08-20	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	365	delivery	5	37
122251	2020-08-20 23:26:53	2020-08-20	14	[{"id_menu":2,"count":1}]	46471	delivery	5	19
122252	2020-08-20 23:28:19	2020-08-20	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	5383	pick-up	0	23
122253	2020-08-20 23:28:23	2020-08-20	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	22704	delivery	5	26
122254	2020-08-20 23:30:03	2020-08-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	16231	delivery	5	28
122255	2020-08-20 23:32:21	2020-08-20	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	46523	delivery	5	36
122256	2020-08-20 23:34:26	2020-08-20	8	[{"id_menu":5,"count":1}]	37877	delivery	5	13
122257	2020-08-20 23:34:56	2020-08-20	9	[{"id_menu":7,"count":1}]	14644	delivery	5	14
122258	2020-08-20 23:36:19	2020-08-20	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	32759	delivery	5	26
122259	2020-08-20 23:37:44	2020-08-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	44740	pick-up	0	18
122260	2020-08-20 23:38:00	2020-08-20	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	46432	delivery	5	40
122261	2020-08-20 23:38:09	2020-08-20	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36516	delivery	5	23
122262	2020-08-20 23:40:24	2020-08-20	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	8796	delivery	5	31
122263	2020-08-20 23:45:32	2020-08-20	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	17063	pick-up	0	23
122264	2020-08-20 23:45:37	2020-08-20	12	[{"id_menu":3,"count":1}]	376	pick-up	0	12
122265	2020-08-20 23:45:51	2020-08-20	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6642	delivery	5	43
122266	2020-08-20 23:46:24	2020-08-20	8	[{"id_menu":5,"count":1}]	37457	delivery	5	13
122267	2020-08-20 23:46:50	2020-08-20	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	21606	pick-up	0	29
122268	2020-08-20 23:48:01	2020-08-20	9	[{"id_menu":6,"count":1}]	40277	delivery	5	14
122269	2020-08-20 23:57:10	2020-08-20	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	14110	delivery	5	28
122270	2020-08-20 23:58:33	2020-08-20	12	[{"id_menu":3,"count":1}]	5833	delivery	5	17
122271	2020-08-20 23:58:46	2020-08-20	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12315	delivery	5	51
122272	2020-08-20 23:59:18	2020-08-20	9	[{"id_menu":7,"count":1}]	12124	delivery	5	14
122273	2020-08-21 00:00:51	2020-08-21	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	44870	delivery	5	43
122274	2020-08-21 00:01:22	2020-08-21	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":2}]	22443	delivery	5	28
122275	2020-08-21 00:08:29	2020-08-21	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	41765	pick-up	0	26
122276	2020-08-21 00:10:32	2020-08-21	14	[{"id_menu":2,"count":2}]	17318	delivery	5	19
122277	2020-08-21 00:13:49	2020-08-21	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	17789	delivery	5	40
122278	2020-08-21 00:14:18	2020-08-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	46558	delivery	5	22
122279	2020-08-21 00:15:56	2020-08-21	14	[{"id_menu":2,"count":1}]	16243	delivery	5	19
122280	2020-08-21 00:17:02	2020-08-21	8	[{"id_menu":5,"count":1}]	33734	delivery	5	13
122281	2020-08-21 00:20:48	2020-08-21	14	[{"id_menu":2,"count":1}]	37388	delivery	5	19
122282	2020-08-21 00:22:16	2020-08-21	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	46716	delivery	5	43
122283	2020-08-21 00:22:38	2020-08-21	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	43796	delivery	5	48
122284	2020-08-21 00:22:48	2020-08-21	9	[{"id_menu":6,"count":1}]	16127	pick-up	0	9
122285	2020-08-21 00:23:54	2020-08-21	12	[{"id_menu":3,"count":1}]	46789	pick-up	0	12
122286	2020-08-21 00:26:02	2020-08-21	14	[{"id_menu":2,"count":1}]	46679	delivery	5	19
122287	2020-08-21 00:27:08	2020-08-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	4794	delivery	5	23
122288	2020-08-21 00:28:49	2020-08-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12100	delivery	5	22
122289	2020-08-21 00:29:47	2020-08-21	14	[{"id_menu":2,"count":1}]	42991	delivery	5	19
122290	2020-08-21 00:30:16	2020-08-21	12	[{"id_menu":3,"count":1}]	32247	pick-up	0	12
122291	2020-08-21 00:34:16	2020-08-21	9	[{"id_menu":7,"count":1}]	46591	delivery	5	14
122292	2020-08-21 00:34:18	2020-08-21	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	46579	delivery	5	26
122293	2020-08-21 00:36:03	2020-08-21	9	[{"id_menu":6,"count":1}]	39064	pick-up	0	9
122294	2020-08-21 00:36:58	2020-08-21	12	[{"id_menu":1,"count":1}]	44486	delivery	5	17
122295	2020-08-21 00:39:04	2020-08-21	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	24590	delivery	5	23
122296	2020-08-21 00:42:29	2020-08-21	9	[{"id_menu":6,"count":1}]	46604	delivery	5	14
122297	2020-08-21 00:43:37	2020-08-21	14	[{"id_menu":2,"count":1}]	17744	delivery	5	19
122298	2020-08-21 00:51:13	2020-08-21	12	[{"id_menu":3,"count":1}]	6066	delivery	5	17
122299	2020-08-21 00:52:09	2020-08-21	8	[{"id_menu":5,"count":1}]	37803	delivery	5	13
122300	2020-08-21 00:52:23	2020-08-21	9	[{"id_menu":7,"count":1}]	46577	delivery	5	14
122301	2020-08-21 00:52:58	2020-08-21	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	46571	delivery	5	23
122302	2020-08-21 00:54:13	2020-08-21	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	37514	delivery	5	39
122303	2020-08-21 00:54:18	2020-08-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1306	delivery	5	31
122304	2020-08-21 00:57:10	2020-08-21	9	[{"id_menu":7,"count":1}]	46703	pick-up	0	9
122305	2020-08-21 00:57:28	2020-08-21	9	[{"id_menu":7,"count":1}]	21256	pick-up	0	9
122306	2020-08-21 00:57:28	2020-08-21	9	[{"id_menu":7,"count":2}]	23126	pick-up	0	9
122307	2020-08-21 00:58:46	2020-08-21	12	[{"id_menu":1,"count":1}]	46723	delivery	5	17
122308	2020-08-21 00:59:23	2020-08-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	29852	delivery	5	31
122309	2020-08-21 01:03:11	2020-08-21	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	36899	delivery	5	57
122310	2020-08-21 01:03:29	2020-08-21	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	46660	delivery	5	39
122311	2020-08-21 01:04:47	2020-08-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14824	delivery	5	31
122312	2020-08-21 01:17:49	2020-08-21	9	[{"id_menu":6,"count":1}]	46757	delivery	5	14
122313	2020-08-21 01:19:20	2020-08-21	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	46622	delivery	5	45
122314	2020-08-21 01:20:21	2020-08-21	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	46578	delivery	5	31
122315	2020-08-21 01:20:30	2020-08-21	17	[{"id_menu":4,"count":1}]	2233	pick-up	0	17
122316	2020-08-21 01:20:31	2020-08-21	14	[{"id_menu":2,"count":1}]	284	delivery	5	19
122317	2020-08-21 01:22:16	2020-08-21	9	[{"id_menu":6,"count":2}]	40383	delivery	5	14
122318	2020-08-21 01:23:40	2020-08-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17508	delivery	5	22
122319	2020-08-21 01:29:16	2020-08-21	17	[{"id_menu":4,"count":1}]	32312	delivery	5	22
122320	2020-08-21 01:30:21	2020-08-21	8	[{"id_menu":5,"count":1}]	45210	delivery	5	13
122321	2020-08-21 01:32:28	2020-08-21	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	38585	delivery	5	30
122322	2020-08-21 01:33:32	2020-08-21	8	[{"id_menu":5,"count":1}]	39956	delivery	5	13
122323	2020-08-21 01:33:36	2020-08-21	12	[{"id_menu":1,"count":1}]	46495	delivery	5	17
122324	2020-08-21 01:33:40	2020-08-21	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	45442	delivery	5	26
122325	2020-08-21 01:35:05	2020-08-21	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	46688	delivery	5	26
122326	2020-08-21 01:36:46	2020-08-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	12623	pick-up	0	26
122327	2020-08-21 01:37:18	2020-08-21	17	[{"id_menu":4,"count":1}]	23521	pick-up	0	17
122328	2020-08-21 01:38:54	2020-08-21	9	[{"id_menu":7,"count":1}]	18760	delivery	5	14
122329	2020-08-21 01:43:28	2020-08-21	30	[{"id_menu":1,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22342	delivery	5	35
122330	2020-08-21 01:43:44	2020-08-21	8	[{"id_menu":5,"count":1}]	10876	delivery	5	13
122331	2020-08-21 01:44:26	2020-08-21	9	[{"id_menu":7,"count":1}]	33639	delivery	5	14
122332	2020-08-21 01:45:10	2020-08-21	8	[{"id_menu":5,"count":1}]	9830	pick-up	0	8
122333	2020-08-21 01:45:16	2020-08-21	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	2538	pick-up	0	20
122334	2020-08-21 01:45:31	2020-08-21	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	19341	delivery	5	38
122335	2020-08-21 01:48:53	2020-08-21	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	37579	delivery	5	36
122336	2020-08-21 01:49:05	2020-08-21	9	[{"id_menu":7,"count":1}]	46744	delivery	5	14
122337	2020-08-21 01:49:37	2020-08-21	14	[{"id_menu":2,"count":2}]	18746	pick-up	0	14
122338	2020-08-21 01:49:56	2020-08-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	10802	delivery	5	31
122339	2020-08-21 01:52:33	2020-08-21	17	[{"id_menu":4,"count":1}]	734	pick-up	0	17
122340	2020-08-21 01:53:21	2020-08-21	14	[{"id_menu":2,"count":1}]	44332	delivery	5	19
122341	2020-08-21 01:59:15	2020-08-21	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	28772	delivery	5	37
122342	2020-08-21 01:59:46	2020-08-21	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	21339	delivery	5	26
122343	2020-08-21 02:02:55	2020-08-21	12	[{"id_menu":3,"count":1}]	46740	delivery	5	17
122344	2020-08-21 02:04:45	2020-08-21	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	32665	pick-up	0	40
122345	2020-08-21 02:05:31	2020-08-21	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12331	delivery	5	39
122346	2020-08-21 02:11:52	2020-08-21	8	[{"id_menu":5,"count":1}]	30304	pick-up	0	8
122347	2020-08-21 02:12:25	2020-08-21	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	18451	delivery	5	26
122348	2020-08-21 02:13:12	2020-08-21	9	[{"id_menu":6,"count":1}]	37491	delivery	5	14
122349	2020-08-21 02:14:37	2020-08-21	9	[{"id_menu":7,"count":1}]	46616	delivery	5	14
122350	2020-08-21 02:15:59	2020-08-21	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	46725	pick-up	0	21
122351	2020-08-21 02:16:09	2020-08-21	8	[{"id_menu":5,"count":1}]	45167	delivery	5	13
122352	2020-08-21 02:16:30	2020-08-21	8	[{"id_menu":5,"count":1}]	7782	pick-up	0	8
122353	2020-08-21 02:16:59	2020-08-21	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":2}]	46733	delivery	5	26
122354	2020-08-21 02:18:15	2020-08-21	12	[{"id_menu":1,"count":2}]	6666	pick-up	0	12
122355	2020-08-21 02:19:02	2020-08-21	14	[{"id_menu":2,"count":1}]	42715	pick-up	0	14
122356	2020-08-21 02:21:08	2020-08-21	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19432	delivery	5	37
122357	2020-08-21 02:22:52	2020-08-21	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	802	pick-up	0	25
122358	2020-08-21 02:29:36	2020-08-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24380	delivery	5	23
122359	2020-08-21 02:30:17	2020-08-21	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	46667	delivery	5	35
122360	2020-08-21 02:31:08	2020-08-21	12	[{"id_menu":3,"count":1}]	23318	delivery	5	17
122361	2020-08-21 02:31:52	2020-08-21	17	[{"id_menu":4,"count":1}]	46697	delivery	5	22
122362	2020-08-21 02:50:02	2020-08-21	17	[{"id_menu":4,"count":1}]	29685	pick-up	0	17
122363	2020-08-21 02:56:52	2020-08-21	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	4370	pick-up	0	21
122364	2020-08-21 02:57:26	2020-08-21	8	[{"id_menu":5,"count":1}]	26191	delivery	5	13
122365	2020-08-21 02:59:21	2020-08-21	9	[{"id_menu":6,"count":1}]	46669	delivery	5	14
122366	2020-08-21 02:59:59	2020-08-21	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	46661	delivery	5	39
122367	2020-08-21 03:00:10	2020-08-21	9	[{"id_menu":7,"count":1}]	2792	delivery	5	14
122368	2020-08-21 03:00:59	2020-08-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	46665	delivery	5	31
122369	2020-08-21 03:02:32	2020-08-21	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	25571	delivery	5	31
122370	2020-08-21 03:02:51	2020-08-21	9	[{"id_menu":6,"count":2}]	5839	pick-up	0	9
122371	2020-08-21 03:03:00	2020-08-21	9	[{"id_menu":7,"count":1}]	634	pick-up	0	9
122372	2020-08-21 03:05:25	2020-08-21	14	[{"id_menu":2,"count":1}]	17941	delivery	5	19
122373	2020-08-21 03:05:57	2020-08-21	14	[{"id_menu":2,"count":1}]	30957	delivery	5	19
122374	2020-08-21 03:08:22	2020-08-21	14	[{"id_menu":2,"count":1}]	46699	delivery	5	19
122375	2020-08-21 03:10:45	2020-08-21	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	39546	delivery	5	30
122376	2020-08-21 03:10:54	2020-08-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	28857	delivery	5	23
122377	2020-08-21 03:12:37	2020-08-21	8	[{"id_menu":5,"count":1}]	37531	pick-up	0	8
122378	2020-08-21 03:13:13	2020-08-21	14	[{"id_menu":2,"count":1}]	46582	delivery	5	19
122379	2020-08-21 03:14:04	2020-08-21	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	9377	delivery	5	34
122380	2020-08-21 03:14:34	2020-08-21	17	[{"id_menu":4,"count":1}]	45870	delivery	5	22
122381	2020-08-21 03:18:03	2020-08-21	9	[{"id_menu":7,"count":1}]	46693	delivery	5	14
122382	2020-08-21 03:19:25	2020-08-21	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	46687	delivery	5	31
122383	2020-08-21 03:21:00	2020-08-21	8	[{"id_menu":5,"count":1}]	2520	delivery	5	13
122384	2020-08-21 03:21:35	2020-08-21	8	[{"id_menu":5,"count":1}]	46701	delivery	5	13
122385	2020-08-21 03:23:12	2020-08-21	17	[{"id_menu":4,"count":1}]	6614	delivery	5	22
122386	2020-08-21 03:27:20	2020-08-21	9	[{"id_menu":7,"count":1}]	33093	delivery	5	14
122387	2020-08-21 03:31:00	2020-08-21	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	25332	delivery	5	26
122388	2020-08-21 03:31:12	2020-08-21	12	[{"id_menu":3,"count":1}]	41234	delivery	5	17
122389	2020-08-21 03:31:31	2020-08-21	9	[{"id_menu":6,"count":1}]	23239	delivery	5	14
122390	2020-08-21 03:31:32	2020-08-21	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	31398	delivery	5	39
122391	2020-08-21 03:32:08	2020-08-21	14	[{"id_menu":2,"count":1}]	17526	pick-up	0	14
122392	2020-08-21 03:35:49	2020-08-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	46751	delivery	5	23
122393	2020-08-21 03:37:12	2020-08-21	17	[{"id_menu":4,"count":1}]	29345	delivery	5	22
122394	2020-08-21 03:38:00	2020-08-21	12	[{"id_menu":3,"count":1}]	43143	delivery	5	17
122395	2020-08-21 03:39:11	2020-08-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	46710	delivery	5	31
122396	2020-08-21 03:40:11	2020-08-21	12	[{"id_menu":3,"count":1}]	4996	delivery	5	17
122397	2020-08-21 03:41:35	2020-08-21	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	7750	delivery	5	43
122398	2020-08-21 03:46:18	2020-08-21	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	46668	delivery	5	34
122399	2020-08-21 03:47:08	2020-08-21	9	[{"id_menu":7,"count":1}]	7189	pick-up	0	9
122400	2020-08-21 03:47:21	2020-08-21	9	[{"id_menu":7,"count":1}]	8951	delivery	5	14
122401	2020-08-21 03:48:33	2020-08-21	9	[{"id_menu":7,"count":1}]	6551	pick-up	0	9
122402	2020-08-21 03:54:52	2020-08-21	9	[{"id_menu":7,"count":1}]	46597	delivery	5	14
122403	2020-08-21 03:56:02	2020-08-21	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	46603	pick-up	0	26
122404	2020-08-21 03:59:03	2020-08-21	9	[{"id_menu":6,"count":1}]	30154	pick-up	0	9
122405	2020-08-21 04:00:52	2020-08-21	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	46629	delivery	5	23
122406	2020-08-21 04:03:01	2020-08-21	9	[{"id_menu":6,"count":1}]	46617	delivery	5	14
122407	2020-08-21 04:03:58	2020-08-21	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	46782	delivery	5	43
122408	2020-08-21 04:05:11	2020-08-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	41746	pick-up	0	26
122409	2020-08-21 04:13:56	2020-08-21	9	[{"id_menu":7,"count":1}]	46568	delivery	5	14
122410	2020-08-21 04:15:16	2020-08-21	12	[{"id_menu":1,"count":1}]	20959	delivery	5	17
122411	2020-08-21 04:15:55	2020-08-21	9	[{"id_menu":6,"count":1}]	38815	pick-up	0	9
122412	2020-08-21 04:17:38	2020-08-21	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	46664	delivery	5	31
122413	2020-08-21 04:20:26	2020-08-21	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7749	delivery	5	35
122414	2020-08-21 04:23:02	2020-08-21	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	27775	pick-up	0	25
122415	2020-08-21 04:25:23	2020-08-21	8	[{"id_menu":5,"count":1}]	43604	delivery	5	13
122416	2020-08-21 04:27:49	2020-08-21	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	46781	pick-up	0	17
122417	2020-08-21 04:28:19	2020-08-21	12	[{"id_menu":3,"count":1}]	46656	delivery	5	17
122418	2020-08-21 04:28:20	2020-08-21	8	[{"id_menu":5,"count":1}]	46670	delivery	5	13
122419	2020-08-21 04:30:35	2020-08-21	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	42121	delivery	5	27
122420	2020-08-21 04:32:59	2020-08-21	14	[{"id_menu":2,"count":1}]	19776	delivery	5	19
122421	2020-08-21 04:33:42	2020-08-21	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	46650	delivery	5	30
122422	2020-08-21 04:36:04	2020-08-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	19913	delivery	5	28
122423	2020-08-21 04:39:38	2020-08-21	9	[{"id_menu":7,"count":1}]	38259	pick-up	0	9
122424	2020-08-21 04:39:57	2020-08-21	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	8217	delivery	5	26
122425	2020-08-21 04:41:17	2020-08-21	9	[{"id_menu":6,"count":1}]	46560	delivery	5	14
122426	2020-08-21 04:41:38	2020-08-21	17	[{"id_menu":4,"count":1}]	46729	delivery	5	22
122427	2020-08-21 04:47:02	2020-08-21	17	[{"id_menu":4,"count":1}]	46649	delivery	5	22
122428	2020-08-21 04:47:12	2020-08-21	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	46707	delivery	5	36
122429	2020-08-21 04:47:47	2020-08-21	9	[{"id_menu":7,"count":1}]	5966	delivery	5	14
122430	2020-08-21 04:49:05	2020-08-21	9	[{"id_menu":6,"count":2}]	36476	delivery	5	14
122431	2020-08-21 04:51:22	2020-08-21	9	[{"id_menu":7,"count":1}]	35445	pick-up	0	9
122432	2020-08-21 04:53:09	2020-08-21	17	[{"id_menu":4,"count":1}]	46651	delivery	5	22
122433	2020-08-21 04:54:29	2020-08-21	17	[{"id_menu":4,"count":1}]	21940	delivery	5	22
122434	2020-08-21 04:57:12	2020-08-21	17	[{"id_menu":4,"count":1}]	18082	pick-up	0	17
122435	2020-08-21 04:57:18	2020-08-21	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	46799	delivery	5	26
122436	2020-08-21 04:59:12	2020-08-21	8	[{"id_menu":5,"count":1}]	39741	delivery	5	13
122437	2020-08-21 04:59:20	2020-08-21	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	4430	pick-up	0	21
122438	2020-08-21 05:01:01	2020-08-21	17	[{"id_menu":4,"count":1}]	46599	delivery	5	22
122439	2020-08-21 05:01:24	2020-08-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	29600	delivery	5	28
122440	2020-08-21 05:03:34	2020-08-21	17	[{"id_menu":4,"count":1}]	497	pick-up	0	17
122441	2020-08-21 05:03:54	2020-08-21	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	46624	delivery	5	38
122442	2020-08-21 05:04:01	2020-08-21	17	[{"id_menu":4,"count":1}]	23703	delivery	5	22
122443	2020-08-21 05:04:36	2020-08-21	14	[{"id_menu":2,"count":1}]	3529	pick-up	0	14
122444	2020-08-21 05:04:48	2020-08-21	8	[{"id_menu":5,"count":1}]	36517	delivery	5	13
122445	2020-08-21 05:06:46	2020-08-21	14	[{"id_menu":2,"count":1}]	34459	delivery	5	19
122446	2020-08-21 05:09:19	2020-08-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1900	pick-up	0	23
122447	2020-08-21 05:17:11	2020-08-21	17	[{"id_menu":4,"count":1}]	40512	delivery	5	22
122448	2020-08-21 05:20:25	2020-08-21	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	15216	delivery	5	34
122449	2020-08-21 05:21:04	2020-08-21	17	[{"id_menu":4,"count":1}]	17324	delivery	5	22
122450	2020-08-21 05:24:10	2020-08-21	12	[{"id_menu":3,"count":1}]	46594	delivery	5	17
122451	2020-08-21 05:28:44	2020-08-21	8	[{"id_menu":5,"count":1}]	41410	delivery	5	13
122452	2020-08-21 05:29:22	2020-08-21	9	[{"id_menu":6,"count":1}]	4248	delivery	5	14
122453	2020-08-21 05:31:14	2020-08-21	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	16248	delivery	5	40
122454	2020-08-21 05:32:12	2020-08-21	12	[{"id_menu":1,"count":1}]	10452	pick-up	0	12
122455	2020-08-21 05:32:28	2020-08-21	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	24975	delivery	5	23
122456	2020-08-21 05:34:46	2020-08-21	8	[{"id_menu":5,"count":1}]	46791	delivery	5	13
122457	2020-08-21 05:34:58	2020-08-21	8	[{"id_menu":5,"count":1}]	35764	pick-up	0	8
122458	2020-08-21 05:38:28	2020-08-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6480	delivery	5	23
122459	2020-08-21 05:38:51	2020-08-21	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	46600	delivery	5	31
122460	2020-08-21 05:40:23	2020-08-21	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	26096	delivery	5	40
122461	2020-08-21 05:40:41	2020-08-21	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	43705	delivery	5	26
122462	2020-08-21 05:50:36	2020-08-21	9	[{"id_menu":6,"count":1}]	39372	delivery	5	14
122463	2020-08-21 05:54:09	2020-08-21	8	[{"id_menu":5,"count":1}]	28962	delivery	5	13
122464	2020-08-21 05:56:30	2020-08-21	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	46654	delivery	5	43
122465	2020-08-21 05:57:43	2020-08-21	9	[{"id_menu":7,"count":1}]	37937	delivery	5	14
122466	2020-08-21 05:58:06	2020-08-21	12	[{"id_menu":3,"count":1}]	12011	pick-up	0	12
122467	2020-08-21 06:02:05	2020-08-21	12	[{"id_menu":1,"count":1}]	46575	delivery	5	17
122468	2020-08-21 06:03:51	2020-08-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	33501	delivery	5	31
122469	2020-08-21 06:03:59	2020-08-21	17	[{"id_menu":4,"count":1}]	46573	delivery	5	22
122470	2020-08-21 06:04:32	2020-08-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	41952	pick-up	0	26
122471	2020-08-21 06:08:36	2020-08-21	17	[{"id_menu":4,"count":1}]	46771	delivery	5	22
122472	2020-08-21 06:08:40	2020-08-21	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3997	delivery	5	26
122473	2020-08-21 06:10:46	2020-08-21	9	[{"id_menu":6,"count":1}]	46695	delivery	5	14
122474	2020-08-21 06:11:03	2020-08-21	8	[{"id_menu":5,"count":1}]	13256	pick-up	0	8
122475	2020-08-21 06:14:02	2020-08-21	17	[{"id_menu":4,"count":1}]	1787	pick-up	0	17
122476	2020-08-21 06:14:33	2020-08-21	9	[{"id_menu":7,"count":1}]	11338	delivery	5	14
122477	2020-08-21 06:14:39	2020-08-21	17	[{"id_menu":4,"count":1}]	41308	delivery	5	22
122478	2020-08-21 06:17:04	2020-08-21	12	[{"id_menu":3,"count":1}]	44522	delivery	5	17
122479	2020-08-21 06:21:01	2020-08-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	46682	delivery	5	22
122480	2020-08-21 06:23:27	2020-08-21	17	[{"id_menu":4,"count":1}]	8494	delivery	5	22
122481	2020-08-21 06:23:55	2020-08-21	9	[{"id_menu":7,"count":1}]	15171	delivery	5	14
122482	2020-08-21 06:25:32	2020-08-21	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	46738	delivery	5	43
122483	2020-08-21 06:26:09	2020-08-21	9	[{"id_menu":6,"count":1}]	34548	delivery	5	14
122484	2020-08-21 06:29:21	2020-08-21	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	43915	delivery	5	26
122485	2020-08-21 06:29:39	2020-08-21	12	[{"id_menu":3,"count":1}]	46764	pick-up	0	12
122486	2020-08-21 06:30:16	2020-08-21	17	[{"id_menu":4,"count":1}]	934	delivery	5	22
122487	2020-08-21 06:30:52	2020-08-21	8	[{"id_menu":5,"count":1}]	46705	delivery	5	13
122488	2020-08-21 06:31:31	2020-08-21	12	[{"id_menu":1,"count":1}]	46588	delivery	5	17
122489	2020-08-21 06:31:40	2020-08-21	14	[{"id_menu":2,"count":1}]	16627	pick-up	0	14
122490	2020-08-21 06:32:24	2020-08-21	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5430	pick-up	0	26
122491	2020-08-21 06:32:28	2020-08-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	26386	delivery	5	28
122492	2020-08-21 06:32:49	2020-08-21	8	[{"id_menu":5,"count":1}]	40998	delivery	5	13
122493	2020-08-21 06:33:31	2020-08-21	9	[{"id_menu":7,"count":1}]	33207	delivery	5	14
122494	2020-08-21 06:36:57	2020-08-21	33	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	30019	delivery	5	38
122495	2020-08-21 06:39:05	2020-08-21	17	[{"id_menu":4,"count":1}]	3148	pick-up	0	17
122496	2020-08-21 06:39:36	2020-08-21	12	[{"id_menu":3,"count":1}]	39719	pick-up	0	12
122497	2020-08-21 06:44:12	2020-08-21	14	[{"id_menu":2,"count":1}]	46678	delivery	5	19
122498	2020-08-21 06:44:22	2020-08-21	12	[{"id_menu":1,"count":1}]	16434	pick-up	0	12
122499	2020-08-21 06:45:19	2020-08-21	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	20907	delivery	5	26
122500	2020-08-21 06:51:38	2020-08-21	12	[{"id_menu":3,"count":1}]	32805	delivery	5	17
122501	2020-08-21 06:53:29	2020-08-21	8	[{"id_menu":5,"count":1}]	16569	delivery	5	13
122502	2020-08-21 07:07:57	2020-08-21	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	46700	delivery	5	43
122503	2020-08-21 07:08:55	2020-08-21	17	[{"id_menu":4,"count":1}]	16469	pick-up	0	17
122504	2020-08-21 07:10:44	2020-08-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8382	delivery	5	31
122505	2020-08-21 07:11:52	2020-08-21	8	[{"id_menu":5,"count":1}]	2799	pick-up	0	8
122506	2020-08-21 07:12:11	2020-08-21	14	[{"id_menu":2,"count":2}]	44765	pick-up	0	14
122507	2020-08-21 07:15:27	2020-08-21	9	[{"id_menu":6,"count":4}]	24573	delivery	5	14
122508	2020-08-21 07:17:00	2020-08-21	14	[{"id_menu":2,"count":1}]	46611	delivery	5	19
122509	2020-08-21 07:17:05	2020-08-21	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	46755	pick-up	0	24
122510	2020-08-21 07:19:33	2020-08-21	17	[{"id_menu":4,"count":1}]	46702	delivery	5	22
122511	2020-08-21 07:20:26	2020-08-21	9	[{"id_menu":6,"count":1}]	1649	delivery	5	14
122512	2020-08-21 07:22:11	2020-08-21	12	[{"id_menu":3,"count":1}]	46614	delivery	5	17
122513	2020-08-21 07:22:29	2020-08-21	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":2}]	32068	delivery	5	22
122514	2020-08-21 07:23:15	2020-08-21	9	[{"id_menu":7,"count":1}]	35652	delivery	5	14
122515	2020-08-21 07:27:00	2020-08-21	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	46750	delivery	5	26
122516	2020-08-21 07:28:12	2020-08-21	12	[{"id_menu":3,"count":2}]	44104	pick-up	0	12
122517	2020-08-21 07:28:45	2020-08-21	12	[{"id_menu":1,"count":1}]	46621	delivery	5	17
122518	2020-08-21 07:29:24	2020-08-21	9	[{"id_menu":7,"count":1}]	7527	pick-up	0	9
122519	2020-08-21 07:38:51	2020-08-21	12	[{"id_menu":1,"count":1}]	2630	delivery	5	17
122520	2020-08-21 07:39:13	2020-08-21	14	[{"id_menu":2,"count":1}]	5520	pick-up	0	14
122521	2020-08-21 07:40:05	2020-08-21	12	[{"id_menu":3,"count":1}]	33015	pick-up	0	12
122522	2020-08-21 07:40:17	2020-08-21	17	[{"id_menu":4,"count":1}]	4176	delivery	5	22
122523	2020-08-21 07:40:56	2020-08-21	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	46694	delivery	5	25
122524	2020-08-21 07:49:10	2020-08-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27283	pick-up	0	18
122525	2020-08-21 07:51:07	2020-08-21	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	46623	delivery	5	34
122526	2020-08-21 07:51:51	2020-08-21	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	15728	delivery	5	36
122527	2020-08-21 07:55:49	2020-08-21	14	[{"id_menu":2,"count":1}]	2511	pick-up	0	14
122528	2020-08-21 07:58:24	2020-08-21	17	[{"id_menu":4,"count":1}]	1813	pick-up	0	17
122529	2020-08-21 08:00:03	2020-08-21	9	[{"id_menu":7,"count":1}]	46772	pick-up	0	9
122530	2020-08-21 08:04:06	2020-08-21	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	36958	delivery	5	27
122531	2020-08-21 08:10:08	2020-08-21	9	[{"id_menu":6,"count":1}]	6416	delivery	5	14
122532	2020-08-21 08:11:34	2020-08-21	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	43818	delivery	5	30
122533	2020-08-21 08:17:21	2020-08-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34295	delivery	5	23
122534	2020-08-21 08:18:23	2020-08-21	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	28441	delivery	5	40
122535	2020-08-21 08:21:10	2020-08-21	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":2}]	45041	delivery	5	31
122536	2020-08-21 08:21:38	2020-08-21	9	[{"id_menu":6,"count":2}]	1957	delivery	5	14
122537	2020-08-21 08:22:02	2020-08-21	9	[{"id_menu":7,"count":2}]	46580	delivery	5	14
122538	2020-08-21 08:23:19	2020-08-21	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	45876	delivery	5	26
122539	2020-08-21 08:23:33	2020-08-21	8	[{"id_menu":5,"count":1}]	14453	delivery	5	13
122540	2020-08-21 08:24:10	2020-08-21	9	[{"id_menu":6,"count":1}]	34552	delivery	5	14
122541	2020-08-21 08:30:07	2020-08-21	9	[{"id_menu":6,"count":1}]	285	delivery	5	14
122542	2020-08-21 08:30:54	2020-08-21	12	[{"id_menu":1,"count":1}]	4986	pick-up	0	12
122543	2020-08-21 08:31:51	2020-08-21	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	46737	delivery	5	45
122544	2020-08-21 08:40:00	2020-08-21	14	[{"id_menu":2,"count":1}]	1127	pick-up	0	14
122545	2020-08-21 08:42:39	2020-08-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24359	delivery	5	23
122546	2020-08-21 08:46:33	2020-08-21	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	32674	pick-up	0	29
122547	2020-08-21 08:47:35	2020-08-21	9	[{"id_menu":6,"count":1}]	46641	delivery	5	14
122548	2020-08-21 08:49:10	2020-08-21	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	31548	delivery	5	43
122549	2020-08-21 08:50:19	2020-08-21	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4287	delivery	5	40
122550	2020-08-21 08:51:55	2020-08-21	9	[{"id_menu":6,"count":1}]	420	pick-up	0	9
122551	2020-08-21 08:52:48	2020-08-21	9	[{"id_menu":6,"count":1}]	46634	delivery	5	14
122552	2020-08-21 08:55:15	2020-08-21	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	30855	pick-up	0	35
122553	2020-08-21 09:06:03	2020-08-21	17	[{"id_menu":4,"count":1}]	31061	delivery	5	22
122554	2020-08-21 09:12:58	2020-08-21	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	10015	delivery	5	38
122555	2020-08-21 09:15:25	2020-08-21	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	46615	delivery	5	39
122556	2020-08-21 09:16:08	2020-08-21	9	[{"id_menu":7,"count":1}]	7355	delivery	5	14
122557	2020-08-21 09:18:22	2020-08-21	9	[{"id_menu":7,"count":1}]	23697	delivery	5	14
122558	2020-08-21 09:18:31	2020-08-21	12	[{"id_menu":3,"count":1}]	14314	pick-up	0	12
122559	2020-08-21 09:19:41	2020-08-21	12	[{"id_menu":3,"count":1}]	19275	delivery	5	17
122560	2020-08-21 09:21:05	2020-08-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	31454	delivery	5	28
122561	2020-08-21 09:23:34	2020-08-21	8	[{"id_menu":5,"count":1}]	46652	delivery	5	13
122562	2020-08-21 09:24:30	2020-08-21	12	[{"id_menu":3,"count":2}]	38324	delivery	5	17
122563	2020-08-21 09:30:07	2020-08-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	40924	delivery	5	28
122564	2020-08-21 09:31:35	2020-08-21	14	[{"id_menu":2,"count":1}]	4311	delivery	5	19
122565	2020-08-21 09:41:01	2020-08-21	9	[{"id_menu":6,"count":1}]	17534	delivery	5	14
122566	2020-08-21 09:42:04	2020-08-21	9	[{"id_menu":7,"count":1}]	3022	delivery	5	14
122567	2020-08-21 09:47:14	2020-08-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	13303	delivery	5	22
122568	2020-08-21 09:50:14	2020-08-21	9	[{"id_menu":6,"count":1}]	15844	delivery	5	14
122569	2020-08-21 09:51:54	2020-08-21	12	[{"id_menu":3,"count":1}]	20697	pick-up	0	12
122570	2020-08-21 09:54:36	2020-08-21	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	37071	delivery	5	48
122571	2020-08-21 09:57:44	2020-08-21	14	[{"id_menu":2,"count":1}]	8447	delivery	5	19
122572	2020-08-21 09:58:06	2020-08-21	14	[{"id_menu":2,"count":1}]	22061	delivery	5	19
122573	2020-08-21 10:00:20	2020-08-21	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	10589	pick-up	0	21
122574	2020-08-21 10:03:17	2020-08-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	30760	delivery	5	31
122575	2020-08-21 10:03:55	2020-08-21	12	[{"id_menu":1,"count":1}]	46715	delivery	5	17
122576	2020-08-21 10:04:04	2020-08-21	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	46663	delivery	5	26
122577	2020-08-21 10:11:06	2020-08-21	12	[{"id_menu":3,"count":1}]	22679	delivery	5	17
122578	2020-08-21 10:11:17	2020-08-21	14	[{"id_menu":2,"count":1}]	1902	pick-up	0	14
122579	2020-08-21 10:14:52	2020-08-21	9	[{"id_menu":6,"count":2}]	3160	pick-up	0	9
122580	2020-08-21 10:18:00	2020-08-21	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	46708	delivery	5	31
122581	2020-08-21 10:18:12	2020-08-21	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	46610	delivery	5	30
122582	2020-08-21 10:18:21	2020-08-21	9	[{"id_menu":6,"count":1}]	17757	delivery	5	14
122583	2020-08-21 10:23:52	2020-08-21	9	[{"id_menu":7,"count":1}]	46686	delivery	5	14
122584	2020-08-21 10:24:18	2020-08-21	17	[{"id_menu":4,"count":1}]	3636	pick-up	0	17
122585	2020-08-21 10:29:37	2020-08-21	17	[{"id_menu":4,"count":1}]	46658	delivery	5	22
122586	2020-08-21 10:29:57	2020-08-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	40436	delivery	5	28
122587	2020-08-21 10:30:49	2020-08-21	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	1762	delivery	5	36
122588	2020-08-21 10:37:53	2020-08-21	14	[{"id_menu":2,"count":1}]	16466	pick-up	0	14
122589	2020-08-21 10:38:18	2020-08-21	17	[{"id_menu":4,"count":1}]	730	pick-up	0	17
122590	2020-08-21 10:38:48	2020-08-21	9	[{"id_menu":7,"count":1}]	26383	delivery	5	14
122591	2020-08-21 10:44:47	2020-08-21	12	[{"id_menu":1,"count":1}]	46637	delivery	5	17
122592	2020-08-21 10:48:12	2020-08-21	17	[{"id_menu":4,"count":1}]	11828	pick-up	0	17
122593	2020-08-21 10:49:38	2020-08-21	8	[{"id_menu":5,"count":1}]	29177	delivery	5	13
122594	2020-08-21 10:49:42	2020-08-21	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	800	delivery	5	27
122595	2020-08-21 10:50:52	2020-08-21	9	[{"id_menu":6,"count":2}]	6429	delivery	5	14
122596	2020-08-21 10:52:11	2020-08-21	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	46389	delivery	5	31
122597	2020-08-21 11:08:54	2020-08-21	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	5358	delivery	5	27
122598	2020-08-21 11:15:15	2020-08-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	21553	delivery	5	31
122599	2020-08-21 11:24:32	2020-08-21	9	[{"id_menu":7,"count":1}]	22708	pick-up	0	9
122600	2020-08-21 11:25:28	2020-08-21	9	[{"id_menu":6,"count":1}]	2172	delivery	5	14
122601	2020-08-21 11:26:44	2020-08-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9816	delivery	5	22
122602	2020-08-21 11:27:05	2020-08-21	14	[{"id_menu":2,"count":1}]	13799	pick-up	0	14
122603	2020-08-21 11:33:24	2020-08-21	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	5308	delivery	5	26
122604	2020-08-21 11:35:13	2020-08-21	17	[{"id_menu":4,"count":2}]	37431	delivery	5	22
122605	2020-08-21 11:42:46	2020-08-21	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	46778	delivery	5	37
122606	2020-08-21 11:45:03	2020-08-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	45283	delivery	5	28
122607	2020-08-21 11:46:01	2020-08-21	17	[{"id_menu":4,"count":1}]	1687	pick-up	0	17
122608	2020-08-21 11:50:25	2020-08-21	12	[{"id_menu":1,"count":1}]	42500	pick-up	0	12
122609	2020-08-21 11:53:23	2020-08-21	12	[{"id_menu":3,"count":1}]	38480	delivery	5	17
122610	2020-08-21 11:54:32	2020-08-21	14	[{"id_menu":2,"count":1}]	36416	delivery	5	19
122611	2020-08-21 11:55:28	2020-08-21	9	[{"id_menu":7,"count":1}]	46765	pick-up	0	9
122612	2020-08-21 11:56:22	2020-08-21	9	[{"id_menu":7,"count":1}]	46564	delivery	5	14
122613	2020-08-21 11:59:04	2020-08-21	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	44574	delivery	5	40
122614	2020-08-21 12:06:10	2020-08-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	46570	delivery	5	31
122615	2020-08-21 12:08:31	2020-08-21	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	46605	delivery	5	30
122616	2020-08-21 12:08:49	2020-08-21	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	46640	pick-up	0	21
122617	2020-08-21 12:10:01	2020-08-21	12	[{"id_menu":3,"count":1}]	1557	pick-up	0	12
122618	2020-08-21 12:10:45	2020-08-21	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	35700	delivery	5	37
122619	2020-08-21 12:12:01	2020-08-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	33520	delivery	5	31
122620	2020-08-21 12:12:17	2020-08-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	20720	delivery	5	28
122621	2020-08-21 12:12:59	2020-08-21	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	16321	delivery	5	34
122622	2020-08-21 12:15:42	2020-08-21	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	39790	delivery	5	27
122623	2020-08-21 12:17:29	2020-08-21	14	[{"id_menu":2,"count":1}]	28499	delivery	5	19
122624	2020-08-21 12:17:47	2020-08-21	14	[{"id_menu":2,"count":1}]	46569	delivery	5	19
122625	2020-08-21 12:20:14	2020-08-21	17	[{"id_menu":4,"count":1}]	46666	delivery	5	22
122626	2020-08-21 12:23:16	2020-08-21	14	[{"id_menu":2,"count":1}]	22489	delivery	5	19
122627	2020-08-21 12:28:51	2020-08-21	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	6038	pick-up	0	26
122628	2020-08-21 12:30:31	2020-08-21	12	[{"id_menu":3,"count":1}]	8640	pick-up	0	12
122629	2020-08-21 12:33:56	2020-08-21	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	46612	delivery	5	31
122630	2020-08-21 12:34:20	2020-08-21	9	[{"id_menu":6,"count":1}]	34287	delivery	5	14
122631	2020-08-21 12:34:44	2020-08-21	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	21884	delivery	5	25
122632	2020-08-21 12:38:35	2020-08-21	9	[{"id_menu":6,"count":1}]	27530	pick-up	0	9
122633	2020-08-21 12:39:50	2020-08-21	12	[{"id_menu":3,"count":1}]	37628	delivery	5	17
122634	2020-08-21 12:45:58	2020-08-21	9	[{"id_menu":7,"count":1}]	46572	delivery	5	14
122635	2020-08-21 12:47:39	2020-08-21	12	[{"id_menu":3,"count":1}]	440	delivery	5	17
122636	2020-08-21 12:48:29	2020-08-21	14	[{"id_menu":2,"count":1}]	9436	delivery	5	19
122637	2020-08-21 12:50:21	2020-08-21	14	[{"id_menu":2,"count":1}]	46675	delivery	5	19
122638	2020-08-21 12:52:24	2020-08-21	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	46784	delivery	5	39
122639	2020-08-21 12:52:27	2020-08-21	12	[{"id_menu":1,"count":1}]	42697	delivery	5	17
122640	2020-08-21 12:52:58	2020-08-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	46636	delivery	5	28
122641	2020-08-21 12:55:59	2020-08-21	12	[{"id_menu":3,"count":1}]	177	pick-up	0	12
122642	2020-08-21 12:58:47	2020-08-21	8	[{"id_menu":5,"count":1}]	46590	delivery	5	13
122643	2020-08-21 13:00:17	2020-08-21	12	[{"id_menu":3,"count":1}]	26005	delivery	5	17
122644	2020-08-21 13:05:38	2020-08-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8574	pick-up	0	18
122645	2020-08-21 13:06:51	2020-08-21	12	[{"id_menu":3,"count":1}]	14261	pick-up	0	12
122646	2020-08-21 13:11:09	2020-08-21	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	46770	delivery	5	34
122647	2020-08-21 13:15:20	2020-08-21	9	[{"id_menu":7,"count":1}]	46645	delivery	5	14
122648	2020-08-21 13:15:50	2020-08-21	14	[{"id_menu":2,"count":1}]	46407	pick-up	0	14
122649	2020-08-21 13:16:29	2020-08-21	12	[{"id_menu":1,"count":1}]	10827	delivery	5	17
122650	2020-08-21 13:21:55	2020-08-21	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	2447	pick-up	0	21
122651	2020-08-21 13:23:20	2020-08-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	15957	delivery	5	23
122652	2020-08-21 13:25:14	2020-08-21	9	[{"id_menu":6,"count":1}]	15860	delivery	5	14
122653	2020-08-21 13:25:42	2020-08-21	9	[{"id_menu":7,"count":1}]	703	delivery	5	14
122654	2020-08-21 13:28:45	2020-08-21	9	[{"id_menu":7,"count":1}]	46741	delivery	5	14
122655	2020-08-21 13:29:10	2020-08-21	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	33717	delivery	5	39
122656	2020-08-21 13:31:05	2020-08-21	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	41105	delivery	5	26
122657	2020-08-21 13:39:21	2020-08-21	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	44130	delivery	5	31
122658	2020-08-21 13:40:35	2020-08-21	8	[{"id_menu":5,"count":1}]	20648	delivery	5	13
122659	2020-08-21 13:51:37	2020-08-21	8	[{"id_menu":5,"count":1}]	46796	delivery	5	13
122660	2020-08-21 13:52:04	2020-08-21	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	17492	delivery	5	26
122661	2020-08-21 13:53:02	2020-08-21	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	20845	delivery	5	40
122662	2020-08-21 13:53:15	2020-08-21	12	[{"id_menu":1,"count":1}]	45998	delivery	5	17
122663	2020-08-21 13:54:31	2020-08-21	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	46747	pick-up	0	25
122664	2020-08-21 13:54:45	2020-08-21	12	[{"id_menu":3,"count":1}]	23870	delivery	5	17
122665	2020-08-21 13:57:25	2020-08-21	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	46602	delivery	5	48
122666	2020-08-21 13:58:26	2020-08-21	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	30099	pick-up	0	38
122667	2020-08-21 13:58:39	2020-08-21	17	[{"id_menu":4,"count":1}]	46794	delivery	5	22
122668	2020-08-21 14:00:51	2020-08-21	17	[{"id_menu":4,"count":1}]	46748	delivery	5	22
122669	2020-08-21 14:01:23	2020-08-21	9	[{"id_menu":6,"count":1}]	16692	delivery	5	14
122670	2020-08-21 14:04:03	2020-08-21	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	43449	delivery	5	35
122671	2020-08-21 14:08:07	2020-08-21	9	[{"id_menu":7,"count":1}]	4498	delivery	5	14
122672	2020-08-21 14:10:11	2020-08-21	9	[{"id_menu":6,"count":1}]	19686	delivery	5	14
122673	2020-08-21 14:10:30	2020-08-21	9	[{"id_menu":6,"count":1}]	9110	delivery	5	14
122674	2020-08-21 14:10:54	2020-08-21	9	[{"id_menu":6,"count":1}]	9368	delivery	5	14
122675	2020-08-21 14:10:59	2020-08-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	39728	delivery	5	22
122676	2020-08-21 14:11:33	2020-08-21	9	[{"id_menu":7,"count":1}]	15913	pick-up	0	9
122677	2020-08-21 14:12:43	2020-08-21	8	[{"id_menu":5,"count":1}]	26277	delivery	5	13
122678	2020-08-21 14:12:56	2020-08-21	9	[{"id_menu":7,"count":1}]	19542	delivery	5	14
122679	2020-08-21 14:19:16	2020-08-21	14	[{"id_menu":2,"count":1}]	34153	delivery	5	19
122680	2020-08-21 14:21:33	2020-08-21	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	29773	delivery	5	43
122681	2020-08-21 14:22:31	2020-08-21	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	46659	delivery	5	43
122682	2020-08-21 14:23:21	2020-08-21	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	46563	delivery	5	27
122683	2020-08-21 14:25:39	2020-08-21	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	5945	pick-up	0	20
122684	2020-08-21 14:26:21	2020-08-21	12	[{"id_menu":1,"count":1}]	44549	pick-up	0	12
122685	2020-08-21 14:29:23	2020-08-21	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4825	delivery	5	45
122686	2020-08-21 14:30:13	2020-08-21	9	[{"id_menu":7,"count":1}]	34366	pick-up	0	9
122687	2020-08-21 14:33:07	2020-08-21	9	[{"id_menu":6,"count":1}]	17650	delivery	5	14
122688	2020-08-21 14:33:35	2020-08-21	17	[{"id_menu":4,"count":1}]	24887	delivery	5	22
122689	2020-08-21 14:35:23	2020-08-21	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	46717	delivery	5	48
122690	2020-08-21 14:35:26	2020-08-21	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":2}]	33798	pick-up	0	21
122691	2020-08-21 14:35:45	2020-08-21	9	[{"id_menu":7,"count":1}]	45189	delivery	5	14
122692	2020-08-21 14:38:58	2020-08-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	46586	pick-up	0	26
122693	2020-08-21 14:40:43	2020-08-21	8	[{"id_menu":5,"count":1}]	34312	delivery	5	13
122694	2020-08-21 14:42:14	2020-08-21	14	[{"id_menu":2,"count":1}]	23748	delivery	5	19
122695	2020-08-21 14:44:29	2020-08-21	14	[{"id_menu":2,"count":1}]	45824	delivery	5	19
122696	2020-08-21 14:44:39	2020-08-21	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	36954	delivery	5	25
122697	2020-08-21 14:49:14	2020-08-21	12	[{"id_menu":3,"count":1}]	46780	delivery	5	17
122698	2020-08-21 14:52:45	2020-08-21	12	[{"id_menu":1,"count":1}]	40238	delivery	5	17
122699	2020-08-21 14:55:35	2020-08-21	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	5350	delivery	5	38
122700	2020-08-21 14:58:27	2020-08-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	41696	delivery	5	22
122701	2020-08-21 15:08:31	2020-08-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	677	pick-up	0	23
122702	2020-08-21 15:14:31	2020-08-21	9	[{"id_menu":6,"count":1}]	13092	delivery	5	14
122703	2020-08-21 15:14:47	2020-08-21	8	[{"id_menu":5,"count":1}]	14738	delivery	5	13
122704	2020-08-21 15:14:55	2020-08-21	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	46626	delivery	5	43
122705	2020-08-21 15:16:39	2020-08-21	9	[{"id_menu":7,"count":1}]	46576	delivery	5	14
122706	2020-08-21 15:18:11	2020-08-21	17	[{"id_menu":4,"count":1}]	1383	pick-up	0	17
122707	2020-08-21 15:19:52	2020-08-21	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2540	pick-up	0	21
122708	2020-08-21 15:23:37	2020-08-21	12	[{"id_menu":3,"count":1}]	46642	pick-up	0	12
122709	2020-08-21 15:23:45	2020-08-21	9	[{"id_menu":6,"count":1}]	13099	delivery	5	14
122710	2020-08-21 15:24:05	2020-08-21	12	[{"id_menu":1,"count":1}]	42264	delivery	5	17
122711	2020-08-21 15:24:51	2020-08-21	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	46562	delivery	5	48
122712	2020-08-21 15:26:03	2020-08-21	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	46625	pick-up	0	43
122713	2020-08-21 15:27:32	2020-08-21	9	[{"id_menu":6,"count":1}]	43954	delivery	5	14
122714	2020-08-21 15:28:31	2020-08-21	8	[{"id_menu":5,"count":2}]	46627	delivery	5	13
122715	2020-08-21 15:29:15	2020-08-21	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	26186	delivery	5	23
122716	2020-08-21 15:31:12	2020-08-21	17	[{"id_menu":4,"count":1}]	15523	delivery	5	22
122717	2020-08-21 15:34:45	2020-08-21	12	[{"id_menu":1,"count":1}]	14326	pick-up	0	12
122718	2020-08-21 15:35:43	2020-08-21	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	46559	delivery	5	26
122719	2020-08-21 15:35:55	2020-08-21	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14003	delivery	5	36
122720	2020-08-21 15:36:14	2020-08-21	12	[{"id_menu":3,"count":1}]	33586	pick-up	0	12
122721	2020-08-21 15:36:49	2020-08-21	9	[{"id_menu":7,"count":1}]	46633	delivery	5	14
122722	2020-08-21 15:38:17	2020-08-21	9	[{"id_menu":6,"count":1}]	44369	delivery	5	14
122723	2020-08-21 15:38:40	2020-08-21	17	[{"id_menu":4,"count":1}]	11335	delivery	5	22
122724	2020-08-21 15:38:45	2020-08-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29401	delivery	5	23
122725	2020-08-21 15:41:19	2020-08-21	9	[{"id_menu":7,"count":1}]	6644	delivery	5	14
122726	2020-08-21 15:43:56	2020-08-21	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	18459	delivery	5	39
122727	2020-08-21 15:45:20	2020-08-21	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	31374	delivery	5	44
122728	2020-08-21 15:50:21	2020-08-21	17	[{"id_menu":4,"count":1}]	28289	pick-up	0	17
122729	2020-08-21 15:52:04	2020-08-21	9	[{"id_menu":6,"count":1}]	24018	pick-up	0	9
122730	2020-08-21 15:57:13	2020-08-21	8	[{"id_menu":5,"count":1}]	46647	delivery	5	13
122731	2020-08-21 15:57:49	2020-08-21	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	45738	delivery	5	26
122732	2020-08-21 15:58:01	2020-08-21	9	[{"id_menu":6,"count":1}]	37791	delivery	5	14
122733	2020-08-21 15:58:55	2020-08-21	17	[{"id_menu":4,"count":1}]	2339	pick-up	0	17
122734	2020-08-21 16:00:58	2020-08-21	9	[{"id_menu":6,"count":1}]	25861	delivery	5	14
122735	2020-08-21 16:01:21	2020-08-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	42584	pick-up	0	26
122736	2020-08-21 16:02:28	2020-08-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	19464	delivery	5	28
122737	2020-08-21 16:04:55	2020-08-21	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19418	delivery	5	37
122738	2020-08-21 16:05:12	2020-08-21	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	43362	delivery	5	39
122739	2020-08-21 16:06:01	2020-08-21	12	[{"id_menu":3,"count":1}]	286	pick-up	0	12
122740	2020-08-21 16:10:50	2020-08-21	12	[{"id_menu":1,"count":1}]	46759	delivery	5	17
122741	2020-08-21 16:19:29	2020-08-21	14	[{"id_menu":2,"count":1}]	46685	delivery	5	19
122742	2020-08-21 16:20:19	2020-08-21	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	5425	delivery	5	26
122743	2020-08-21 16:24:05	2020-08-21	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19033	delivery	5	34
122744	2020-08-21 16:25:04	2020-08-21	14	[{"id_menu":2,"count":1}]	46760	delivery	5	19
122745	2020-08-21 16:27:08	2020-08-21	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	46635	delivery	5	37
122746	2020-08-21 16:27:11	2020-08-21	17	[{"id_menu":4,"count":1}]	7378	delivery	5	22
122747	2020-08-21 16:27:30	2020-08-21	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	37725	delivery	5	26
122748	2020-08-21 16:27:43	2020-08-21	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	46768	delivery	5	43
122749	2020-08-21 16:30:43	2020-08-21	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	709	delivery	5	26
122750	2020-08-21 16:34:31	2020-08-21	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	46648	delivery	5	31
122751	2020-08-21 16:38:16	2020-08-21	12	[{"id_menu":1,"count":1}]	4622	delivery	5	17
122752	2020-08-21 16:48:52	2020-08-21	9	[{"id_menu":7,"count":1}]	11393	delivery	5	14
122753	2020-08-21 16:49:27	2020-08-21	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	21322	pick-up	0	35
122754	2020-08-21 16:49:42	2020-08-21	8	[{"id_menu":5,"count":1}]	23696	delivery	5	13
122755	2020-08-21 16:52:49	2020-08-21	9	[{"id_menu":7,"count":1}]	46736	delivery	5	14
122756	2020-08-21 16:53:19	2020-08-21	17	[{"id_menu":4,"count":1}]	26548	delivery	5	22
122757	2020-08-21 16:57:21	2020-08-21	8	[{"id_menu":5,"count":1}]	46739	delivery	5	13
122758	2020-08-21 17:00:04	2020-08-21	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	46769	delivery	5	26
122759	2020-08-21 17:00:33	2020-08-21	9	[{"id_menu":6,"count":1}]	8016	delivery	5	14
122760	2020-08-21 17:01:57	2020-08-21	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43085	delivery	5	31
122761	2020-08-21 17:02:30	2020-08-21	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	46646	delivery	5	54
122762	2020-08-21 17:04:02	2020-08-21	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	36273	delivery	5	36
122763	2020-08-21 17:07:16	2020-08-21	41	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	38016	delivery	5	46
122764	2020-08-21 17:08:35	2020-08-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35023	delivery	5	23
122765	2020-08-21 17:09:39	2020-08-21	12	[{"id_menu":3,"count":1}]	13225	delivery	5	17
122766	2020-08-21 17:13:36	2020-08-21	17	[{"id_menu":4,"count":1}]	13064	delivery	5	22
122767	2020-08-21 17:15:58	2020-08-21	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	3065	pick-up	0	26
122768	2020-08-21 17:17:28	2020-08-21	17	[{"id_menu":4,"count":1}]	831	delivery	5	22
122769	2020-08-21 17:17:56	2020-08-21	12	[{"id_menu":1,"count":1}]	15960	delivery	5	17
122770	2020-08-21 17:19:33	2020-08-21	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	15028	delivery	5	31
122771	2020-08-21 17:19:40	2020-08-21	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	13817	delivery	5	36
122772	2020-08-21 17:22:06	2020-08-21	17	[{"id_menu":4,"count":1}]	22724	pick-up	0	17
122773	2020-08-21 17:30:29	2020-08-21	8	[{"id_menu":5,"count":1}]	32180	delivery	5	13
122774	2020-08-21 17:32:05	2020-08-21	17	[{"id_menu":4,"count":1}]	38751	delivery	5	22
122775	2020-08-21 17:32:14	2020-08-21	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32799	delivery	5	34
122776	2020-08-21 17:33:36	2020-08-21	9	[{"id_menu":6,"count":1}]	7832	pick-up	0	9
122777	2020-08-21 17:35:01	2020-08-21	17	[{"id_menu":4,"count":1}]	2739	pick-up	0	17
122778	2020-08-21 17:37:29	2020-08-21	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	40722	delivery	5	26
122779	2020-08-21 17:42:38	2020-08-21	17	[{"id_menu":4,"count":1}]	46728	delivery	5	22
122780	2020-08-21 17:42:55	2020-08-21	8	[{"id_menu":5,"count":1}]	7582	pick-up	0	8
122781	2020-08-21 17:45:59	2020-08-21	17	[{"id_menu":4,"count":1}]	26255	pick-up	0	17
122782	2020-08-21 17:46:33	2020-08-21	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	38809	pick-up	0	21
122783	2020-08-21 17:47:00	2020-08-21	12	[{"id_menu":1,"count":1}]	46706	delivery	5	17
122784	2020-08-21 17:51:04	2020-08-21	9	[{"id_menu":7,"count":1}]	46638	delivery	5	14
122785	2020-08-21 17:51:19	2020-08-21	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	8746	pick-up	0	31
122786	2020-08-21 17:54:05	2020-08-21	12	[{"id_menu":1,"count":1}]	21839	delivery	5	17
122787	2020-08-21 17:56:49	2020-08-21	17	[{"id_menu":4,"count":1}]	27423	pick-up	0	17
122788	2020-08-21 17:56:56	2020-08-21	9	[{"id_menu":6,"count":1}]	25703	delivery	5	14
122789	2020-08-21 17:59:50	2020-08-21	9	[{"id_menu":6,"count":1}]	8747	pick-up	0	9
122790	2020-08-21 18:02:24	2020-08-21	14	[{"id_menu":2,"count":1}]	28641	delivery	5	19
122791	2020-08-21 18:05:54	2020-08-21	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	24744	delivery	5	57
122792	2020-08-21 18:08:12	2020-08-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	18070	delivery	5	31
122793	2020-08-21 18:12:58	2020-08-21	17	[{"id_menu":4,"count":1}]	19909	delivery	5	22
122794	2020-08-21 18:15:01	2020-08-21	9	[{"id_menu":6,"count":1}]	46690	pick-up	0	9
122795	2020-08-21 18:15:11	2020-08-21	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	45284	pick-up	0	44
122796	2020-08-21 18:16:37	2020-08-21	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	5666	delivery	5	26
122797	2020-08-21 18:16:48	2020-08-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":3}]	33670	delivery	5	28
122798	2020-08-21 18:18:25	2020-08-21	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	24994	delivery	5	34
122799	2020-08-21 18:25:30	2020-08-21	55	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	40272	delivery	5	60
122800	2020-08-21 18:26:23	2020-08-21	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30038	delivery	5	37
122801	2020-08-21 18:28:40	2020-08-21	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	45886	delivery	5	26
122802	2020-08-21 18:30:21	2020-08-21	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9582	delivery	5	36
122803	2020-08-21 18:33:11	2020-08-21	17	[{"id_menu":4,"count":1}]	16270	pick-up	0	17
122804	2020-08-21 18:37:35	2020-08-21	17	[{"id_menu":4,"count":1}]	46377	pick-up	0	17
122805	2020-08-21 18:41:11	2020-08-21	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	19143	delivery	5	25
122806	2020-08-21 18:45:18	2020-08-21	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	27550	delivery	5	26
122807	2020-08-21 18:46:29	2020-08-21	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16720	delivery	5	48
122808	2020-08-21 18:49:46	2020-08-21	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	30127	delivery	5	34
122809	2020-08-21 18:49:56	2020-08-21	9	[{"id_menu":7,"count":1}]	13068	delivery	5	14
122810	2020-08-21 18:51:15	2020-08-21	14	[{"id_menu":2,"count":1}]	46589	delivery	5	19
122811	2020-08-21 18:51:45	2020-08-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	46712	delivery	5	28
122812	2020-08-21 18:52:17	2020-08-21	9	[{"id_menu":6,"count":3}]	36693	delivery	5	14
122813	2020-08-21 18:52:37	2020-08-21	14	[{"id_menu":2,"count":1}]	8303	pick-up	0	14
122814	2020-08-21 18:53:12	2020-08-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	44257	delivery	5	28
122815	2020-08-21 18:53:24	2020-08-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	46613	delivery	5	22
122816	2020-08-21 18:56:27	2020-08-21	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	37607	delivery	5	39
122817	2020-08-21 18:56:58	2020-08-21	12	[{"id_menu":1,"count":1}]	8374	pick-up	0	12
122818	2020-08-21 18:57:00	2020-08-21	9	[{"id_menu":7,"count":1}]	46746	pick-up	0	9
122819	2020-08-21 18:57:49	2020-08-21	9	[{"id_menu":7,"count":1}]	37730	pick-up	0	9
122820	2020-08-21 18:58:16	2020-08-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39596	delivery	5	23
122821	2020-08-21 18:59:50	2020-08-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	17168	delivery	5	28
122822	2020-08-21 18:59:53	2020-08-21	8	[{"id_menu":5,"count":1}]	30614	pick-up	0	8
122823	2020-08-21 19:02:17	2020-08-21	12	[{"id_menu":3,"count":1}]	10598	pick-up	0	12
122824	2020-08-21 19:04:19	2020-08-21	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	21038	delivery	5	30
122825	2020-08-21 19:05:19	2020-08-21	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1155	delivery	5	40
122826	2020-08-21 19:06:37	2020-08-21	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	46584	delivery	5	29
122827	2020-08-21 19:10:33	2020-08-21	9	[{"id_menu":7,"count":1}]	32133	delivery	5	14
122828	2020-08-21 19:15:49	2020-08-21	8	[{"id_menu":5,"count":1}]	46598	pick-up	0	8
122829	2020-08-21 19:17:32	2020-08-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	31333	delivery	5	28
122830	2020-08-21 19:17:49	2020-08-21	12	[{"id_menu":3,"count":1}]	34575	pick-up	0	12
122831	2020-08-21 19:19:43	2020-08-21	9	[{"id_menu":6,"count":1}]	34393	delivery	5	14
122832	2020-08-21 19:23:50	2020-08-21	12	[{"id_menu":1,"count":1}]	570	pick-up	0	12
122833	2020-08-21 19:24:41	2020-08-21	14	[{"id_menu":2,"count":1}]	3570	pick-up	0	14
122834	2020-08-21 19:32:31	2020-08-21	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	46727	delivery	5	34
122835	2020-08-21 19:33:54	2020-08-21	12	[{"id_menu":1,"count":1}]	46691	delivery	5	17
122836	2020-08-21 19:36:12	2020-08-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1733	pick-up	0	17
122837	2020-08-21 19:37:09	2020-08-21	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	46713	delivery	5	43
122838	2020-08-21 19:42:21	2020-08-21	9	[{"id_menu":6,"count":1}]	36561	delivery	5	14
122839	2020-08-21 19:43:17	2020-08-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	45720	delivery	5	22
122840	2020-08-21 19:44:02	2020-08-21	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	29896	pick-up	0	34
122841	2020-08-21 19:47:06	2020-08-21	9	[{"id_menu":6,"count":2}]	36836	delivery	5	14
122842	2020-08-21 19:48:53	2020-08-21	9	[{"id_menu":6,"count":1}]	21290	pick-up	0	9
122843	2020-08-21 19:49:56	2020-08-21	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	16746	delivery	5	31
122844	2020-08-21 19:52:08	2020-08-21	9	[{"id_menu":6,"count":1}]	46574	delivery	5	14
122845	2020-08-21 19:52:49	2020-08-21	14	[{"id_menu":2,"count":1}]	46555	delivery	5	19
122846	2020-08-21 19:56:40	2020-08-21	9	[{"id_menu":7,"count":1}]	21630	delivery	5	14
122847	2020-08-21 20:04:27	2020-08-21	14	[{"id_menu":2,"count":1}]	8270	delivery	5	19
122848	2020-08-21 20:04:59	2020-08-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	46673	pick-up	0	26
122849	2020-08-21 20:05:02	2020-08-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44348	delivery	5	23
122850	2020-08-21 20:05:18	2020-08-21	8	[{"id_menu":5,"count":1}]	1627	pick-up	0	8
122851	2020-08-21 20:05:53	2020-08-21	12	[{"id_menu":3,"count":1}]	30265	delivery	5	17
122852	2020-08-21 20:07:16	2020-08-21	9	[{"id_menu":7,"count":1}]	42484	delivery	5	14
122853	2020-08-21 20:07:22	2020-08-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	21071	delivery	5	28
122854	2020-08-21 20:11:37	2020-08-21	12	[{"id_menu":1,"count":1}]	2619	delivery	5	17
122855	2020-08-21 20:12:15	2020-08-21	17	[{"id_menu":4,"count":1}]	40634	delivery	5	22
122856	2020-08-21 20:12:31	2020-08-21	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":2}]	39775	delivery	5	22
122857	2020-08-21 20:15:27	2020-08-21	9	[{"id_menu":6,"count":1}]	46606	delivery	5	14
122858	2020-08-21 20:15:53	2020-08-21	12	[{"id_menu":3,"count":1}]	46607	pick-up	0	12
122859	2020-08-21 20:18:23	2020-08-21	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	40917	pick-up	0	26
122860	2020-08-21 20:19:32	2020-08-21	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	38712	delivery	5	34
122861	2020-08-21 20:23:49	2020-08-21	17	[{"id_menu":4,"count":1}]	46561	delivery	5	22
122862	2020-08-21 20:30:09	2020-08-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	46676	delivery	5	31
122863	2020-08-21 20:31:07	2020-08-21	9	[{"id_menu":7,"count":1}]	26874	delivery	5	14
122864	2020-08-21 20:31:44	2020-08-21	14	[{"id_menu":2,"count":1}]	46779	delivery	5	19
122865	2020-08-21 20:33:40	2020-08-21	12	[{"id_menu":1,"count":1}]	6966	delivery	5	17
122866	2020-08-21 20:35:32	2020-08-21	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	26024	delivery	5	45
122867	2020-08-21 20:38:49	2020-08-21	9	[{"id_menu":6,"count":2}]	11260	pick-up	0	9
122868	2020-08-21 20:40:05	2020-08-21	14	[{"id_menu":2,"count":1}]	46749	delivery	5	19
122869	2020-08-21 20:41:41	2020-08-21	12	[{"id_menu":1,"count":1}]	24429	delivery	5	17
122870	2020-08-21 20:46:51	2020-08-21	12	[{"id_menu":3,"count":1}]	20982	delivery	5	17
122871	2020-08-21 20:49:15	2020-08-21	12	[{"id_menu":1,"count":2}]	46762	delivery	5	17
122872	2020-08-21 20:49:29	2020-08-21	9	[{"id_menu":6,"count":1}]	46677	delivery	5	14
122873	2020-08-21 20:56:23	2020-08-21	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	5131	delivery	5	26
122874	2020-08-21 21:02:10	2020-08-21	12	[{"id_menu":1,"count":1}]	21659	delivery	5	17
122875	2020-08-21 21:02:54	2020-08-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	17753	delivery	5	31
122876	2020-08-21 21:03:17	2020-08-21	8	[{"id_menu":5,"count":1}]	24894	delivery	5	13
122877	2020-08-21 21:06:34	2020-08-21	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	40933	delivery	5	39
122878	2020-08-21 21:09:03	2020-08-21	9	[{"id_menu":6,"count":1}]	25047	delivery	5	14
122879	2020-08-21 21:10:54	2020-08-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17988	delivery	5	23
122880	2020-08-21 21:11:02	2020-08-21	9	[{"id_menu":6,"count":1}]	8307	delivery	5	14
122881	2020-08-21 21:11:49	2020-08-21	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	1400	pick-up	0	26
122882	2020-08-21 21:15:45	2020-08-21	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	37953	delivery	5	28
122883	2020-08-21 21:19:50	2020-08-21	9	[{"id_menu":6,"count":1}]	46758	delivery	5	14
122884	2020-08-21 21:19:56	2020-08-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1507	pick-up	0	26
122885	2020-08-21 21:23:16	2020-08-21	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	46704	delivery	5	40
122886	2020-08-21 21:24:03	2020-08-21	9	[{"id_menu":6,"count":1}]	12651	delivery	5	14
122887	2020-08-21 21:25:09	2020-08-21	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	31574	delivery	5	23
122888	2020-08-21 21:31:26	2020-08-21	17	[{"id_menu":4,"count":1}]	4802	delivery	5	22
122889	2020-08-21 21:33:41	2020-08-21	9	[{"id_menu":6,"count":1}]	14781	delivery	5	14
122890	2020-08-21 21:34:16	2020-08-21	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	20957	delivery	5	34
122891	2020-08-21 21:35:13	2020-08-21	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	18522	pick-up	0	22
122892	2020-08-21 21:35:46	2020-08-21	9	[{"id_menu":7,"count":1}]	45712	delivery	5	14
122893	2020-08-21 21:39:19	2020-08-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	46754	pick-up	0	23
122894	2020-08-21 21:46:31	2020-08-21	9	[{"id_menu":6,"count":1}]	46720	delivery	5	14
122895	2020-08-21 21:48:17	2020-08-21	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	3172	delivery	5	25
122896	2020-08-21 21:52:16	2020-08-21	12	[{"id_menu":1,"count":1}]	46763	delivery	5	17
122897	2020-08-21 21:53:20	2020-08-21	12	[{"id_menu":3,"count":1}]	16607	delivery	5	17
122898	2020-08-21 22:00:11	2020-08-21	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	982	delivery	5	23
122899	2020-08-21 22:01:30	2020-08-21	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	18227	delivery	5	31
122900	2020-08-21 22:02:09	2020-08-21	9	[{"id_menu":6,"count":1}]	46632	delivery	5	14
122901	2020-08-21 22:02:28	2020-08-21	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	46761	delivery	5	39
122902	2020-08-21 22:04:17	2020-08-21	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	46734	delivery	5	29
122903	2020-08-21 22:05:18	2020-08-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	17511	delivery	5	22
122904	2020-08-21 22:05:31	2020-08-21	9	[{"id_menu":6,"count":2}]	16817	delivery	5	14
122905	2020-08-21 22:06:29	2020-08-21	17	[{"id_menu":4,"count":1}]	35130	delivery	5	22
122906	2020-08-21 22:07:20	2020-08-21	9	[{"id_menu":7,"count":1}]	46766	delivery	5	14
122907	2020-08-21 22:08:29	2020-08-21	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23322	delivery	5	36
122908	2020-08-21 22:11:36	2020-08-21	8	[{"id_menu":5,"count":1}]	38627	delivery	5	13
122909	2020-08-21 22:15:21	2020-08-21	12	[{"id_menu":1,"count":1}]	37716	pick-up	0	12
122910	2020-08-21 22:18:13	2020-08-21	9	[{"id_menu":7,"count":1}]	28894	delivery	5	14
122911	2020-08-21 22:21:42	2020-08-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13614	delivery	5	22
122912	2020-08-21 22:21:43	2020-08-21	9	[{"id_menu":7,"count":1}]	33100	delivery	5	14
122913	2020-08-21 22:24:09	2020-08-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	46745	delivery	5	28
122914	2020-08-21 22:24:44	2020-08-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	46773	delivery	5	22
122915	2020-08-21 22:27:02	2020-08-21	12	[{"id_menu":1,"count":1}]	37968	pick-up	0	12
122916	2020-08-21 22:27:48	2020-08-21	9	[{"id_menu":7,"count":1}]	46692	delivery	5	14
122917	2020-08-21 22:27:51	2020-08-21	9	[{"id_menu":6,"count":1}]	10580	pick-up	0	9
122918	2020-08-21 22:29:30	2020-08-21	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	21212	delivery	5	45
122919	2020-08-21 22:31:42	2020-08-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18095	delivery	5	22
122920	2020-08-21 22:32:33	2020-08-21	9	[{"id_menu":7,"count":2}]	46585	delivery	5	14
122921	2020-08-21 22:34:49	2020-08-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	46742	delivery	5	28
122922	2020-08-21 22:40:05	2020-08-21	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4166	pick-up	0	29
122923	2020-08-21 22:40:51	2020-08-21	9	[{"id_menu":7,"count":1}]	33534	delivery	5	14
122924	2020-08-21 22:41:35	2020-08-21	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	45266	pick-up	0	26
122925	2020-08-21 22:43:00	2020-08-21	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	37201	pick-up	0	23
122926	2020-08-21 22:43:10	2020-08-21	9	[{"id_menu":7,"count":1}]	46566	pick-up	0	9
122927	2020-08-21 22:47:39	2020-08-21	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	46674	delivery	5	45
122928	2020-08-21 22:52:20	2020-08-21	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	169	pick-up	0	17
122929	2020-08-21 22:53:49	2020-08-21	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	14796	delivery	5	31
122930	2020-08-21 22:54:33	2020-08-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	15909	delivery	5	28
122931	2020-08-21 22:55:24	2020-08-21	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	46730	delivery	5	40
122932	2020-08-21 22:57:40	2020-08-21	17	[{"id_menu":4,"count":1}]	22376	pick-up	0	17
122933	2020-08-21 23:02:43	2020-08-21	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	31125	delivery	5	45
122934	2020-08-21 23:08:32	2020-08-21	9	[{"id_menu":7,"count":1}]	30486	delivery	5	14
122935	2020-08-21 23:09:47	2020-08-21	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4974	delivery	5	30
122936	2020-08-21 23:13:16	2020-08-21	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7094	delivery	5	30
122937	2020-08-21 23:13:23	2020-08-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	46718	delivery	5	22
122938	2020-08-21 23:22:39	2020-08-21	17	[{"id_menu":4,"count":1}]	46592	delivery	5	22
122939	2020-08-21 23:22:57	2020-08-21	8	[{"id_menu":5,"count":1}]	1095	delivery	5	13
122940	2020-08-21 23:24:32	2020-08-21	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	10850	pick-up	0	23
122941	2020-08-21 23:28:46	2020-08-21	9	[{"id_menu":6,"count":1}]	46753	delivery	5	14
122942	2020-08-21 23:29:43	2020-08-21	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	44853	delivery	5	30
122943	2020-08-21 23:30:48	2020-08-21	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	15186	delivery	5	26
122944	2020-08-21 23:35:57	2020-08-21	9	[{"id_menu":7,"count":1}]	46567	delivery	5	14
122945	2020-08-21 23:36:26	2020-08-21	17	[{"id_menu":4,"count":1}]	46777	pick-up	0	17
122946	2020-08-21 23:37:20	2020-08-21	8	[{"id_menu":5,"count":1}]	7156	pick-up	0	8
122947	2020-08-21 23:39:27	2020-08-21	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	46630	delivery	5	34
122948	2020-08-21 23:40:37	2020-08-21	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11543	delivery	5	22
122949	2020-08-21 23:42:17	2020-08-21	9	[{"id_menu":6,"count":1}]	46294	delivery	5	14
122950	2020-08-21 23:45:06	2020-08-21	12	[{"id_menu":1,"count":1}]	46721	delivery	5	17
122951	2020-08-21 23:46:59	2020-08-21	9	[{"id_menu":6,"count":1}]	6670	delivery	5	14
122952	2020-08-21 23:47:05	2020-08-21	14	[{"id_menu":2,"count":1}]	46655	delivery	5	19
122953	2020-08-21 23:48:36	2020-08-21	9	[{"id_menu":6,"count":1}]	29143	delivery	5	14
122954	2020-08-21 23:48:43	2020-08-21	9	[{"id_menu":7,"count":1}]	34892	delivery	5	14
122955	2020-08-21 23:49:34	2020-08-21	8	[{"id_menu":5,"count":1}]	46557	delivery	5	13
122956	2020-08-21 23:50:22	2020-08-21	12	[{"id_menu":3,"count":2}]	5210	delivery	5	17
122957	2020-08-21 23:52:59	2020-08-21	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14410	pick-up	0	34
122958	2020-08-21 23:57:59	2020-08-21	9	[{"id_menu":6,"count":1}]	46587	delivery	5	14
122959	2020-08-22 00:00:22	2020-08-22	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3784	delivery	5	31
122960	2020-08-22 00:02:48	2020-08-22	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8841	delivery	5	31
122961	2020-08-22 00:02:52	2020-08-22	17	[{"id_menu":4,"count":1}]	47017	delivery	5	22
122962	2020-08-22 00:04:03	2020-08-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20794	delivery	5	23
122963	2020-08-22 00:04:20	2020-08-22	12	[{"id_menu":3,"count":2}]	46811	delivery	5	17
122964	2020-08-22 00:06:14	2020-08-22	8	[{"id_menu":5,"count":1}]	7582	pick-up	0	8
122965	2020-08-22 00:07:25	2020-08-22	9	[{"id_menu":6,"count":2}]	46913	delivery	5	14
122966	2020-08-22 00:09:53	2020-08-22	12	[{"id_menu":1,"count":1}]	31082	delivery	5	17
122967	2020-08-22 00:09:58	2020-08-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	11240	delivery	5	36
122968	2020-08-22 00:11:07	2020-08-22	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	41949	delivery	5	31
122969	2020-08-22 00:11:20	2020-08-22	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	47015	delivery	5	34
122970	2020-08-22 00:12:36	2020-08-22	9	[{"id_menu":7,"count":1}]	46996	delivery	5	14
122971	2020-08-22 00:13:39	2020-08-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	25275	delivery	5	28
122972	2020-08-22 00:17:21	2020-08-22	8	[{"id_menu":5,"count":1}]	47051	delivery	5	13
122973	2020-08-22 00:20:27	2020-08-22	17	[{"id_menu":4,"count":1}]	7688	delivery	5	22
122974	2020-08-22 00:20:35	2020-08-22	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	18880	pick-up	0	35
122975	2020-08-22 00:23:06	2020-08-22	17	[{"id_menu":4,"count":2}]	39567	delivery	5	22
122976	2020-08-22 00:23:47	2020-08-22	9	[{"id_menu":7,"count":1}]	46972	delivery	5	14
122977	2020-08-22 00:24:47	2020-08-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32313	delivery	5	22
122978	2020-08-22 00:27:54	2020-08-22	9	[{"id_menu":6,"count":1}]	23169	delivery	5	14
122979	2020-08-22 00:32:07	2020-08-22	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	30073	delivery	5	34
122980	2020-08-22 00:33:11	2020-08-22	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	23090	delivery	5	26
122981	2020-08-22 00:33:18	2020-08-22	17	[{"id_menu":4,"count":1}]	18429	delivery	5	22
122982	2020-08-22 00:36:05	2020-08-22	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	46703	pick-up	0	21
122983	2020-08-22 00:39:44	2020-08-22	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":2}]	46862	delivery	5	26
122984	2020-08-22 00:41:19	2020-08-22	8	[{"id_menu":5,"count":1}]	8784	delivery	5	13
122985	2020-08-22 00:41:31	2020-08-22	9	[{"id_menu":6,"count":1}]	790	pick-up	0	9
122986	2020-08-22 00:41:57	2020-08-22	14	[{"id_menu":2,"count":1}]	47028	delivery	5	19
122987	2020-08-22 00:46:54	2020-08-22	8	[{"id_menu":5,"count":1}]	8071	pick-up	0	8
122988	2020-08-22 00:47:57	2020-08-22	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1451	delivery	5	31
122989	2020-08-22 00:48:15	2020-08-22	8	[{"id_menu":5,"count":1}]	20329	delivery	5	13
122990	2020-08-22 00:48:28	2020-08-22	14	[{"id_menu":2,"count":1}]	3752	delivery	5	19
122991	2020-08-22 00:49:42	2020-08-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3792	delivery	5	23
122992	2020-08-22 00:49:51	2020-08-22	9	[{"id_menu":7,"count":1}]	33625	delivery	5	14
122993	2020-08-22 00:50:33	2020-08-22	9	[{"id_menu":7,"count":1}]	11518	delivery	5	14
122994	2020-08-22 00:50:52	2020-08-22	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	13652	delivery	5	25
122995	2020-08-22 00:52:46	2020-08-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	40614	delivery	5	28
122996	2020-08-22 00:53:26	2020-08-22	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	46916	delivery	5	51
122997	2020-08-22 00:53:47	2020-08-22	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	36099	delivery	5	26
122998	2020-08-22 00:53:53	2020-08-22	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27444	delivery	5	40
122999	2020-08-22 00:54:00	2020-08-22	9	[{"id_menu":7,"count":1}]	47012	delivery	5	14
123000	2020-08-22 00:55:14	2020-08-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	46621	delivery	5	28
123001	2020-08-22 00:55:56	2020-08-22	14	[{"id_menu":2,"count":1}]	47018	pick-up	0	14
123002	2020-08-22 00:56:50	2020-08-22	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	30229	delivery	5	39
123003	2020-08-22 00:58:54	2020-08-22	8	[{"id_menu":5,"count":1}]	46767	pick-up	0	8
123004	2020-08-22 01:01:36	2020-08-22	8	[{"id_menu":5,"count":1}]	46966	delivery	5	13
123005	2020-08-22 01:02:01	2020-08-22	8	[{"id_menu":5,"count":1}]	1414	pick-up	0	8
123006	2020-08-22 01:03:11	2020-08-22	14	[{"id_menu":2,"count":1}]	11232	pick-up	0	14
123007	2020-08-22 01:04:20	2020-08-22	9	[{"id_menu":6,"count":1}]	25571	pick-up	0	9
123008	2020-08-22 01:04:51	2020-08-22	8	[{"id_menu":5,"count":1}]	28984	delivery	5	13
123009	2020-08-22 01:05:39	2020-08-22	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	46818	delivery	5	26
123010	2020-08-22 01:06:05	2020-08-22	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	46940	delivery	5	43
123011	2020-08-22 01:07:18	2020-08-22	9	[{"id_menu":6,"count":1}]	46985	delivery	5	14
123012	2020-08-22 01:11:11	2020-08-22	8	[{"id_menu":5,"count":1}]	18316	delivery	5	13
123013	2020-08-22 01:15:06	2020-08-22	14	[{"id_menu":2,"count":1}]	9728	delivery	5	19
123014	2020-08-22 01:15:54	2020-08-22	14	[{"id_menu":2,"count":1}]	47036	delivery	5	19
123015	2020-08-22 01:18:51	2020-08-22	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	37882	delivery	5	29
123016	2020-08-22 01:19:13	2020-08-22	14	[{"id_menu":2,"count":2}]	12885	delivery	5	19
123017	2020-08-22 01:22:00	2020-08-22	8	[{"id_menu":5,"count":1}]	42167	delivery	5	13
123018	2020-08-22 01:22:17	2020-08-22	17	[{"id_menu":4,"count":1}]	6301	pick-up	0	17
123019	2020-08-22 01:23:32	2020-08-22	14	[{"id_menu":2,"count":1}]	36130	pick-up	0	14
123020	2020-08-22 01:24:51	2020-08-22	14	[{"id_menu":2,"count":1}]	18839	delivery	5	19
123021	2020-08-22 01:25:27	2020-08-22	8	[{"id_menu":5,"count":1}]	25623	delivery	5	13
123022	2020-08-22 01:27:54	2020-08-22	9	[{"id_menu":7,"count":1}]	27742	delivery	5	14
123023	2020-08-22 01:29:16	2020-08-22	9	[{"id_menu":7,"count":1}]	26048	delivery	5	14
123024	2020-08-22 01:30:40	2020-08-22	8	[{"id_menu":5,"count":1}]	18102	delivery	5	13
123025	2020-08-22 01:31:47	2020-08-22	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	21109	pick-up	0	26
123026	2020-08-22 01:33:12	2020-08-22	9	[{"id_menu":7,"count":1}]	38747	delivery	5	14
123027	2020-08-22 01:35:31	2020-08-22	12	[{"id_menu":1,"count":1}]	46993	pick-up	0	12
123028	2020-08-22 01:42:57	2020-08-22	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14499	delivery	5	22
123029	2020-08-22 01:43:52	2020-08-22	9	[{"id_menu":7,"count":1}]	23680	delivery	5	14
123030	2020-08-22 01:45:21	2020-08-22	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	44183	delivery	5	31
123031	2020-08-22 01:46:18	2020-08-22	17	[{"id_menu":4,"count":1}]	46953	delivery	5	22
123032	2020-08-22 01:47:19	2020-08-22	9	[{"id_menu":7,"count":1}]	9595	delivery	5	14
123033	2020-08-22 01:48:50	2020-08-22	9	[{"id_menu":6,"count":1}]	46855	delivery	5	14
123034	2020-08-22 01:49:31	2020-08-22	9	[{"id_menu":7,"count":1}]	27298	delivery	5	14
123035	2020-08-22 01:50:57	2020-08-22	14	[{"id_menu":2,"count":1}]	5762	delivery	5	19
123036	2020-08-22 01:51:50	2020-08-22	14	[{"id_menu":2,"count":1}]	16208	delivery	5	19
123037	2020-08-22 01:52:05	2020-08-22	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	46944	delivery	5	43
123038	2020-08-22 01:52:51	2020-08-22	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	40556	delivery	5	39
123039	2020-08-22 01:54:35	2020-08-22	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	46948	delivery	5	26
123040	2020-08-22 01:54:47	2020-08-22	8	[{"id_menu":5,"count":1}]	16450	delivery	5	13
123041	2020-08-22 01:56:10	2020-08-22	12	[{"id_menu":1,"count":1}]	22409	delivery	5	17
123042	2020-08-22 01:56:10	2020-08-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39703	delivery	5	22
123043	2020-08-22 01:59:49	2020-08-22	14	[{"id_menu":2,"count":1}]	34301	delivery	5	19
123044	2020-08-22 02:04:39	2020-08-22	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17534	delivery	5	54
123045	2020-08-22 02:05:17	2020-08-22	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	46943	delivery	5	31
123046	2020-08-22 02:08:42	2020-08-22	9	[{"id_menu":6,"count":1}]	25946	delivery	5	14
123047	2020-08-22 02:10:25	2020-08-22	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	36967	delivery	5	43
123048	2020-08-22 02:11:02	2020-08-22	8	[{"id_menu":5,"count":1}]	46915	delivery	5	13
123049	2020-08-22 02:12:41	2020-08-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	46858	delivery	5	28
123050	2020-08-22 02:13:08	2020-08-22	9	[{"id_menu":7,"count":1}]	46937	delivery	5	14
123051	2020-08-22 02:13:29	2020-08-22	9	[{"id_menu":6,"count":1}]	8050	delivery	5	14
123052	2020-08-22 02:14:39	2020-08-22	9	[{"id_menu":6,"count":1}]	1736	pick-up	0	9
123053	2020-08-22 02:16:53	2020-08-22	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	15054	delivery	5	40
123054	2020-08-22 02:22:23	2020-08-22	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	3439	delivery	5	25
123055	2020-08-22 02:25:33	2020-08-22	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	46860	delivery	5	22
123056	2020-08-22 02:30:00	2020-08-22	12	[{"id_menu":3,"count":1}]	12183	pick-up	0	12
123057	2020-08-22 02:31:18	2020-08-22	8	[{"id_menu":5,"count":1}]	47008	delivery	5	13
123058	2020-08-22 02:32:46	2020-08-22	14	[{"id_menu":2,"count":2}]	46961	delivery	5	19
123059	2020-08-22 02:35:23	2020-08-22	8	[{"id_menu":5,"count":1}]	6565	pick-up	0	8
123060	2020-08-22 02:35:45	2020-08-22	9	[{"id_menu":6,"count":1}]	46821	pick-up	0	9
123061	2020-08-22 02:39:37	2020-08-22	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	3580	delivery	5	36
123062	2020-08-22 02:42:29	2020-08-22	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	46947	delivery	5	23
123063	2020-08-22 02:43:51	2020-08-22	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	46887	delivery	5	22
123064	2020-08-22 02:45:27	2020-08-22	9	[{"id_menu":6,"count":2}]	11289	delivery	5	14
123065	2020-08-22 02:46:38	2020-08-22	14	[{"id_menu":2,"count":1}]	46808	delivery	5	19
123066	2020-08-22 02:49:33	2020-08-22	9	[{"id_menu":6,"count":1}]	9394	delivery	5	14
123067	2020-08-22 02:58:17	2020-08-22	9	[{"id_menu":6,"count":1}]	46843	pick-up	0	9
123068	2020-08-22 03:00:10	2020-08-22	14	[{"id_menu":2,"count":1}]	14795	delivery	5	19
123069	2020-08-22 03:03:17	2020-08-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	46826	delivery	5	28
123070	2020-08-22 03:03:25	2020-08-22	8	[{"id_menu":5,"count":1}]	29052	delivery	5	13
123071	2020-08-22 03:03:34	2020-08-22	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	22910	delivery	5	40
123072	2020-08-22 03:05:18	2020-08-22	9	[{"id_menu":6,"count":1}]	2897	pick-up	0	9
123073	2020-08-22 03:08:17	2020-08-22	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40917	delivery	5	40
123074	2020-08-22 03:09:02	2020-08-22	12	[{"id_menu":1,"count":1}]	46814	delivery	5	17
123075	2020-08-22 03:09:20	2020-08-22	9	[{"id_menu":6,"count":1}]	36321	delivery	5	14
123076	2020-08-22 03:11:17	2020-08-22	9	[{"id_menu":6,"count":3}]	3558	delivery	5	14
123077	2020-08-22 03:14:29	2020-08-22	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	47032	delivery	5	43
123078	2020-08-22 03:14:46	2020-08-22	9	[{"id_menu":7,"count":1}]	38999	delivery	5	14
123079	2020-08-22 03:14:55	2020-08-22	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	7050	pick-up	0	29
123080	2020-08-22 03:20:31	2020-08-22	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	46980	delivery	5	23
123081	2020-08-22 03:20:51	2020-08-22	9	[{"id_menu":7,"count":1}]	46555	delivery	5	14
123082	2020-08-22 03:22:47	2020-08-22	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	25641	pick-up	0	35
123083	2020-08-22 03:23:03	2020-08-22	14	[{"id_menu":2,"count":1}]	12614	delivery	5	19
123084	2020-08-22 03:25:16	2020-08-22	9	[{"id_menu":6,"count":1}]	46846	delivery	5	14
123085	2020-08-22 03:25:27	2020-08-22	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	40585	delivery	5	36
123086	2020-08-22 03:27:03	2020-08-22	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	46933	delivery	5	34
123087	2020-08-22 03:29:34	2020-08-22	9	[{"id_menu":6,"count":2}]	15959	delivery	5	14
123088	2020-08-22 03:30:31	2020-08-22	14	[{"id_menu":2,"count":1}]	13685	delivery	5	19
123089	2020-08-22 03:31:21	2020-08-22	12	[{"id_menu":3,"count":1}]	46829	pick-up	0	12
123090	2020-08-22 03:31:43	2020-08-22	29	[{"id_menu":3,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	37821	delivery	5	34
123091	2020-08-22 03:33:57	2020-08-22	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9643	delivery	5	22
123092	2020-08-22 03:36:45	2020-08-22	9	[{"id_menu":6,"count":1}]	39557	delivery	5	14
123159	2020-08-22 05:34:33	2020-08-22	12	[{"id_menu":3,"count":1}]	11904	pick-up	0	12
123093	2020-08-22 03:39:20	2020-08-22	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	33234	delivery	5	39
123094	2020-08-22 03:39:34	2020-08-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10716	delivery	5	23
123095	2020-08-22 03:40:01	2020-08-22	8	[{"id_menu":5,"count":2}]	34079	delivery	5	13
123096	2020-08-22 03:41:01	2020-08-22	8	[{"id_menu":5,"count":1}]	47054	delivery	5	13
123097	2020-08-22 03:43:04	2020-08-22	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	13613	pick-up	0	21
123098	2020-08-22 03:46:25	2020-08-22	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	44897	pick-up	0	17
123099	2020-08-22 03:46:52	2020-08-22	8	[{"id_menu":5,"count":1}]	22343	delivery	5	13
123100	2020-08-22 03:47:23	2020-08-22	9	[{"id_menu":6,"count":1}]	46918	delivery	5	14
123101	2020-08-22 03:47:35	2020-08-22	12	[{"id_menu":3,"count":1}]	32194	delivery	5	17
123102	2020-08-22 03:52:20	2020-08-22	12	[{"id_menu":3,"count":1}]	27148	pick-up	0	12
123103	2020-08-22 03:58:16	2020-08-22	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8866	delivery	5	43
123104	2020-08-22 03:58:19	2020-08-22	9	[{"id_menu":7,"count":1}]	46904	delivery	5	14
123105	2020-08-22 03:59:00	2020-08-22	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	36606	delivery	5	26
123106	2020-08-22 03:59:29	2020-08-22	12	[{"id_menu":3,"count":1}]	22464	pick-up	0	12
123107	2020-08-22 03:59:36	2020-08-22	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	41870	delivery	5	25
123108	2020-08-22 04:01:41	2020-08-22	12	[{"id_menu":1,"count":1}]	18312	delivery	5	17
123109	2020-08-22 04:05:43	2020-08-22	14	[{"id_menu":2,"count":1}]	46959	delivery	5	19
123110	2020-08-22 04:07:49	2020-08-22	8	[{"id_menu":5,"count":1}]	36992	delivery	5	13
123111	2020-08-22 04:08:28	2020-08-22	14	[{"id_menu":2,"count":1}]	46920	delivery	5	19
123112	2020-08-22 04:09:33	2020-08-22	9	[{"id_menu":6,"count":1}]	46802	delivery	5	14
123113	2020-08-22 04:12:43	2020-08-22	8	[{"id_menu":5,"count":1}]	14571	delivery	5	13
123114	2020-08-22 04:17:20	2020-08-22	9	[{"id_menu":7,"count":1}]	47016	pick-up	0	9
123115	2020-08-22 04:18:11	2020-08-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	40586	delivery	5	28
123116	2020-08-22 04:19:28	2020-08-22	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2965	delivery	5	48
123117	2020-08-22 04:22:33	2020-08-22	12	[{"id_menu":1,"count":1}]	46970	delivery	5	17
123118	2020-08-22 04:23:54	2020-08-22	9	[{"id_menu":6,"count":1}]	5729	delivery	5	14
123119	2020-08-22 04:26:16	2020-08-22	12	[{"id_menu":1,"count":1}]	41950	delivery	5	17
123120	2020-08-22 04:28:26	2020-08-22	17	[{"id_menu":4,"count":1}]	4577	delivery	5	22
123121	2020-08-22 04:30:23	2020-08-22	9	[{"id_menu":7,"count":1}]	5342	delivery	5	14
123122	2020-08-22 04:31:47	2020-08-22	17	[{"id_menu":4,"count":1}]	6589	pick-up	0	17
123123	2020-08-22 04:34:47	2020-08-22	12	[{"id_menu":1,"count":1}]	11401	delivery	5	17
123124	2020-08-22 04:36:13	2020-08-22	9	[{"id_menu":7,"count":1}]	46839	delivery	5	14
123125	2020-08-22 04:36:31	2020-08-22	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	46978	delivery	5	55
123126	2020-08-22 04:38:18	2020-08-22	12	[{"id_menu":1,"count":1}]	48	delivery	5	17
123127	2020-08-22 04:40:16	2020-08-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	46554	delivery	5	28
123128	2020-08-22 04:41:17	2020-08-22	12	[{"id_menu":1,"count":1}]	1627	pick-up	0	12
123129	2020-08-22 04:44:01	2020-08-22	9	[{"id_menu":7,"count":1}]	32639	delivery	5	14
123130	2020-08-22 04:44:36	2020-08-22	14	[{"id_menu":2,"count":1}]	46856	delivery	5	19
123131	2020-08-22 04:44:49	2020-08-22	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	46804	delivery	5	30
123132	2020-08-22 04:46:00	2020-08-22	12	[{"id_menu":1,"count":1}]	46852	delivery	5	17
123133	2020-08-22 04:47:52	2020-08-22	9	[{"id_menu":7,"count":2}]	46864	delivery	5	14
123134	2020-08-22 04:49:56	2020-08-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	2492	delivery	5	36
123135	2020-08-22 04:51:34	2020-08-22	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	46923	delivery	5	51
123136	2020-08-22 04:57:24	2020-08-22	17	[{"id_menu":4,"count":1}]	47031	pick-up	0	17
123137	2020-08-22 04:58:10	2020-08-22	9	[{"id_menu":6,"count":2}]	39095	delivery	5	14
123138	2020-08-22 04:59:05	2020-08-22	14	[{"id_menu":2,"count":1}]	5740	delivery	5	19
123139	2020-08-22 04:59:57	2020-08-22	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8067	delivery	5	48
123140	2020-08-22 05:01:39	2020-08-22	9	[{"id_menu":6,"count":1}]	44718	delivery	5	14
123141	2020-08-22 05:08:02	2020-08-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	46981	delivery	5	28
123142	2020-08-22 05:08:10	2020-08-22	12	[{"id_menu":3,"count":1}]	43452	delivery	5	17
123143	2020-08-22 05:10:12	2020-08-22	12	[{"id_menu":3,"count":1}]	3111	pick-up	0	12
123144	2020-08-22 05:10:24	2020-08-22	9	[{"id_menu":7,"count":1}]	43935	delivery	5	14
123145	2020-08-22 05:11:46	2020-08-22	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32765	delivery	5	37
123146	2020-08-22 05:12:30	2020-08-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	22784	pick-up	0	23
123147	2020-08-22 05:12:55	2020-08-22	12	[{"id_menu":1,"count":1}]	34135	delivery	5	17
123148	2020-08-22 05:14:51	2020-08-22	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	47057	delivery	5	45
123149	2020-08-22 05:15:10	2020-08-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1115	delivery	5	28
123150	2020-08-22 05:15:50	2020-08-22	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	41225	delivery	5	26
123151	2020-08-22 05:21:12	2020-08-22	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":3}]	15133	delivery	5	30
123152	2020-08-22 05:24:29	2020-08-22	14	[{"id_menu":2,"count":1}]	28760	pick-up	0	14
123153	2020-08-22 05:28:01	2020-08-22	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	33376	delivery	5	27
123154	2020-08-22 05:30:01	2020-08-22	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	16816	delivery	5	31
123155	2020-08-22 05:30:31	2020-08-22	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	1106	pick-up	0	38
123156	2020-08-22 05:33:00	2020-08-22	12	[{"id_menu":1,"count":1}]	46906	delivery	5	17
123157	2020-08-22 05:33:13	2020-08-22	9	[{"id_menu":6,"count":1}]	46881	delivery	5	14
123158	2020-08-22 05:33:24	2020-08-22	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	46987	delivery	5	31
123160	2020-08-22 05:35:32	2020-08-22	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7058	pick-up	0	25
123161	2020-08-22 05:37:13	2020-08-22	14	[{"id_menu":2,"count":1}]	46967	delivery	5	19
123162	2020-08-22 05:37:18	2020-08-22	17	[{"id_menu":4,"count":1}]	43620	delivery	5	22
123163	2020-08-22 05:37:26	2020-08-22	14	[{"id_menu":2,"count":2}]	8240	pick-up	0	14
123164	2020-08-22 05:37:46	2020-08-22	55	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	43995	delivery	5	60
123165	2020-08-22 05:38:19	2020-08-22	9	[{"id_menu":6,"count":1}]	41712	delivery	5	14
123166	2020-08-22 05:38:22	2020-08-22	9	[{"id_menu":6,"count":2}]	46911	delivery	5	14
123167	2020-08-22 05:43:53	2020-08-22	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	43704	delivery	5	31
123168	2020-08-22 05:44:41	2020-08-22	12	[{"id_menu":1,"count":1}]	26903	delivery	5	17
123169	2020-08-22 05:45:21	2020-08-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	42216	delivery	5	28
123170	2020-08-22 05:45:40	2020-08-22	9	[{"id_menu":7,"count":1}]	39836	delivery	5	14
123171	2020-08-22 05:48:26	2020-08-22	12	[{"id_menu":3,"count":1}]	28153	pick-up	0	12
123172	2020-08-22 05:49:13	2020-08-22	17	[{"id_menu":4,"count":1}]	12129	pick-up	0	17
123173	2020-08-22 05:53:02	2020-08-22	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	15393	delivery	5	43
123174	2020-08-22 05:53:32	2020-08-22	9	[{"id_menu":7,"count":1}]	16008	delivery	5	14
123175	2020-08-22 05:54:10	2020-08-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	47001	pick-up	0	23
123176	2020-08-22 05:55:54	2020-08-22	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	28317	delivery	5	23
123177	2020-08-22 05:56:19	2020-08-22	9	[{"id_menu":6,"count":1}]	37189	delivery	5	14
123178	2020-08-22 06:02:09	2020-08-22	17	[{"id_menu":4,"count":1}]	3211	delivery	5	22
123179	2020-08-22 06:03:28	2020-08-22	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	36969	delivery	5	34
123180	2020-08-22 06:07:20	2020-08-22	9	[{"id_menu":7,"count":1}]	25827	pick-up	0	9
123181	2020-08-22 06:09:02	2020-08-22	9	[{"id_menu":7,"count":1}]	1021	delivery	5	14
123182	2020-08-22 06:11:36	2020-08-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	19847	delivery	5	28
123183	2020-08-22 06:11:49	2020-08-22	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	46838	delivery	5	22
123184	2020-08-22 06:12:52	2020-08-22	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	37865	delivery	5	30
123185	2020-08-22 06:12:54	2020-08-22	9	[{"id_menu":7,"count":1}]	5091	delivery	5	14
123186	2020-08-22 06:13:59	2020-08-22	9	[{"id_menu":7,"count":1}]	8877	delivery	5	14
123187	2020-08-22 06:19:18	2020-08-22	9	[{"id_menu":6,"count":1}]	2956	pick-up	0	9
123188	2020-08-22 06:19:24	2020-08-22	9	[{"id_menu":7,"count":1}]	19565	delivery	5	14
123189	2020-08-22 06:20:54	2020-08-22	8	[{"id_menu":5,"count":1}]	46992	delivery	5	13
123190	2020-08-22 06:25:28	2020-08-22	9	[{"id_menu":7,"count":1}]	279	delivery	5	14
123191	2020-08-22 06:25:59	2020-08-22	9	[{"id_menu":6,"count":1}]	31875	pick-up	0	9
123192	2020-08-22 06:26:06	2020-08-22	17	[{"id_menu":4,"count":1}]	46813	delivery	5	22
123193	2020-08-22 06:26:38	2020-08-22	14	[{"id_menu":2,"count":1}]	39064	pick-up	0	14
123194	2020-08-22 06:26:39	2020-08-22	17	[{"id_menu":4,"count":1}]	47043	pick-up	0	17
123195	2020-08-22 06:26:42	2020-08-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	46836	delivery	5	28
123196	2020-08-22 06:28:01	2020-08-22	12	[{"id_menu":1,"count":1}]	10194	pick-up	0	12
123197	2020-08-22 06:28:27	2020-08-22	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	46845	delivery	5	23
123198	2020-08-22 06:30:04	2020-08-22	9	[{"id_menu":7,"count":1}]	21314	delivery	5	14
123199	2020-08-22 06:31:10	2020-08-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	47000	delivery	5	28
123200	2020-08-22 06:32:06	2020-08-22	9	[{"id_menu":7,"count":1}]	23975	delivery	5	14
123201	2020-08-22 06:33:02	2020-08-22	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	4762	delivery	5	39
123202	2020-08-22 06:34:09	2020-08-22	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	14703	delivery	5	39
123203	2020-08-22 06:34:20	2020-08-22	8	[{"id_menu":5,"count":1}]	1932	delivery	5	13
123204	2020-08-22 06:36:41	2020-08-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	30752	delivery	5	22
123205	2020-08-22 06:37:04	2020-08-22	17	[{"id_menu":4,"count":1}]	10288	delivery	5	22
123206	2020-08-22 06:37:36	2020-08-22	9	[{"id_menu":6,"count":1}]	47020	delivery	5	14
123207	2020-08-22 06:39:39	2020-08-22	8	[{"id_menu":5,"count":1}]	2084	pick-up	0	8
123208	2020-08-22 06:40:54	2020-08-22	12	[{"id_menu":3,"count":1}]	31436	delivery	5	17
123209	2020-08-22 06:44:07	2020-08-22	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	32973	delivery	5	34
123210	2020-08-22 06:45:31	2020-08-22	9	[{"id_menu":6,"count":1}]	23148	delivery	5	14
123211	2020-08-22 06:48:20	2020-08-22	9	[{"id_menu":6,"count":1}]	46891	delivery	5	14
123212	2020-08-22 06:48:21	2020-08-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5640	delivery	5	28
123213	2020-08-22 06:48:44	2020-08-22	12	[{"id_menu":1,"count":1}]	42386	pick-up	0	12
123214	2020-08-22 06:53:01	2020-08-22	17	[{"id_menu":4,"count":1}]	46358	delivery	5	22
123215	2020-08-22 06:53:44	2020-08-22	12	[{"id_menu":1,"count":3}]	14954	delivery	5	17
123216	2020-08-22 06:53:49	2020-08-22	9	[{"id_menu":7,"count":1}]	20863	delivery	5	14
123217	2020-08-22 06:53:53	2020-08-22	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3629	delivery	5	26
123218	2020-08-22 06:57:40	2020-08-22	9	[{"id_menu":7,"count":1}]	32697	delivery	5	14
123219	2020-08-22 06:57:40	2020-08-22	8	[{"id_menu":5,"count":1}]	34052	delivery	5	13
123220	2020-08-22 06:58:01	2020-08-22	9	[{"id_menu":7,"count":1}]	2821	delivery	5	14
123221	2020-08-22 06:58:01	2020-08-22	9	[{"id_menu":6,"count":1}]	17472	pick-up	0	9
123222	2020-08-22 06:58:35	2020-08-22	12	[{"id_menu":3,"count":1}]	11554	pick-up	0	12
123223	2020-08-22 06:59:28	2020-08-22	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	32936	pick-up	0	25
123224	2020-08-22 07:00:48	2020-08-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	34458	delivery	5	22
123225	2020-08-22 07:00:55	2020-08-22	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7633	delivery	5	39
123226	2020-08-22 07:02:00	2020-08-22	9	[{"id_menu":6,"count":1}]	46901	delivery	5	14
123227	2020-08-22 07:02:49	2020-08-22	9	[{"id_menu":6,"count":1}]	16670	delivery	5	14
123228	2020-08-22 07:03:08	2020-08-22	17	[{"id_menu":4,"count":1}]	19336	delivery	5	22
123229	2020-08-22 07:07:52	2020-08-22	8	[{"id_menu":5,"count":1}]	46886	delivery	5	13
123230	2020-08-22 07:08:04	2020-08-22	17	[{"id_menu":4,"count":1}]	42387	delivery	5	22
123231	2020-08-22 07:08:45	2020-08-22	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	46945	delivery	5	35
123232	2020-08-22 07:10:38	2020-08-22	8	[{"id_menu":5,"count":1}]	1693	delivery	5	13
123233	2020-08-22 07:14:33	2020-08-22	9	[{"id_menu":6,"count":1}]	46894	pick-up	0	9
123234	2020-08-22 07:15:04	2020-08-22	12	[{"id_menu":1,"count":1}]	351	pick-up	0	12
123235	2020-08-22 07:16:07	2020-08-22	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	8474	delivery	5	26
123236	2020-08-22 07:16:11	2020-08-22	9	[{"id_menu":7,"count":1}]	6113	delivery	5	14
123237	2020-08-22 07:24:35	2020-08-22	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18940	delivery	5	51
123238	2020-08-22 07:25:36	2020-08-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	46975	delivery	5	28
123239	2020-08-22 07:27:23	2020-08-22	17	[{"id_menu":4,"count":1}]	44556	pick-up	0	17
123240	2020-08-22 07:31:34	2020-08-22	8	[{"id_menu":5,"count":1}]	2962	pick-up	0	8
123241	2020-08-22 07:33:35	2020-08-22	9	[{"id_menu":7,"count":2}]	13568	delivery	5	14
123242	2020-08-22 07:34:37	2020-08-22	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3512	pick-up	0	26
123243	2020-08-22 07:35:47	2020-08-22	17	[{"id_menu":4,"count":1}]	18087	delivery	5	22
123244	2020-08-22 07:39:49	2020-08-22	9	[{"id_menu":6,"count":1}]	16692	delivery	5	14
123245	2020-08-22 07:39:52	2020-08-22	8	[{"id_menu":5,"count":1}]	35825	delivery	5	13
123246	2020-08-22 07:41:24	2020-08-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	33896	delivery	5	28
123247	2020-08-22 07:41:52	2020-08-22	9	[{"id_menu":6,"count":1}]	32394	delivery	5	14
123248	2020-08-22 07:43:17	2020-08-22	17	[{"id_menu":4,"count":1}]	12228	delivery	5	22
123249	2020-08-22 07:44:13	2020-08-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	46827	delivery	5	28
123250	2020-08-22 07:44:31	2020-08-22	9	[{"id_menu":6,"count":1}]	12043	pick-up	0	9
123251	2020-08-22 07:44:52	2020-08-22	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	40708	delivery	5	39
123252	2020-08-22 07:45:20	2020-08-22	9	[{"id_menu":6,"count":1}]	11295	delivery	5	14
123253	2020-08-22 07:45:23	2020-08-22	9	[{"id_menu":6,"count":1}]	42660	pick-up	0	9
123254	2020-08-22 07:45:36	2020-08-22	17	[{"id_menu":4,"count":1}]	45999	delivery	5	22
123255	2020-08-22 07:45:43	2020-08-22	12	[{"id_menu":1,"count":1}]	639	delivery	5	17
123256	2020-08-22 07:45:49	2020-08-22	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	47029	delivery	5	40
123257	2020-08-22 07:47:20	2020-08-22	9	[{"id_menu":6,"count":1}]	33230	delivery	5	14
123258	2020-08-22 07:48:35	2020-08-22	9	[{"id_menu":6,"count":1}]	1676	pick-up	0	9
123259	2020-08-22 07:51:06	2020-08-22	17	[{"id_menu":4,"count":1}]	1994	pick-up	0	17
123260	2020-08-22 07:51:14	2020-08-22	17	[{"id_menu":4,"count":1}]	46816	pick-up	0	17
123261	2020-08-22 07:51:18	2020-08-22	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31384	delivery	5	40
123262	2020-08-22 07:51:21	2020-08-22	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	18936	delivery	5	23
123263	2020-08-22 07:53:59	2020-08-22	9	[{"id_menu":7,"count":1}]	27254	delivery	5	14
123264	2020-08-22 07:54:44	2020-08-22	12	[{"id_menu":1,"count":1}]	3780	pick-up	0	12
123265	2020-08-22 07:56:03	2020-08-22	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9833	delivery	5	40
123266	2020-08-22 07:57:53	2020-08-22	14	[{"id_menu":2,"count":1}]	14711	delivery	5	19
123267	2020-08-22 07:58:52	2020-08-22	9	[{"id_menu":6,"count":1}]	5817	delivery	5	14
123268	2020-08-22 08:01:25	2020-08-22	14	[{"id_menu":2,"count":1}]	35350	delivery	5	19
123269	2020-08-22 08:01:46	2020-08-22	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	15018	delivery	5	28
123270	2020-08-22 08:02:00	2020-08-22	9	[{"id_menu":7,"count":2}]	46899	delivery	5	14
123271	2020-08-22 08:03:00	2020-08-22	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28987	delivery	5	34
123272	2020-08-22 08:06:09	2020-08-22	14	[{"id_menu":2,"count":1}]	24437	pick-up	0	14
123273	2020-08-22 08:06:41	2020-08-22	17	[{"id_menu":4,"count":1}]	32701	delivery	5	22
123274	2020-08-22 08:08:12	2020-08-22	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	16676	delivery	5	38
123275	2020-08-22 08:13:50	2020-08-22	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	37077	delivery	5	26
123276	2020-08-22 08:15:08	2020-08-22	12	[{"id_menu":3,"count":1}]	575	pick-up	0	12
123277	2020-08-22 08:15:34	2020-08-22	12	[{"id_menu":3,"count":1}]	42707	delivery	5	17
123278	2020-08-22 08:16:21	2020-08-22	8	[{"id_menu":5,"count":1}]	43715	delivery	5	13
123279	2020-08-22 08:17:58	2020-08-22	9	[{"id_menu":7,"count":1}]	32207	delivery	5	14
123280	2020-08-22 08:18:54	2020-08-22	12	[{"id_menu":3,"count":1}]	20910	delivery	5	17
123281	2020-08-22 08:19:44	2020-08-22	8	[{"id_menu":5,"count":1}]	46960	delivery	5	13
123282	2020-08-22 08:21:23	2020-08-22	8	[{"id_menu":5,"count":1}]	27455	delivery	5	13
123283	2020-08-22 08:22:22	2020-08-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	17664	delivery	5	28
123284	2020-08-22 08:23:15	2020-08-22	9	[{"id_menu":7,"count":1}]	18629	delivery	5	14
123285	2020-08-22 08:27:32	2020-08-22	9	[{"id_menu":6,"count":1}]	2986	delivery	5	14
123286	2020-08-22 08:29:10	2020-08-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	754	pick-up	0	31
123287	2020-08-22 08:31:44	2020-08-22	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	23114	delivery	5	22
123288	2020-08-22 08:32:37	2020-08-22	9	[{"id_menu":6,"count":2}]	9061	pick-up	0	9
123289	2020-08-22 08:36:58	2020-08-22	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	46898	delivery	5	43
123290	2020-08-22 08:45:35	2020-08-22	14	[{"id_menu":2,"count":1}]	30204	pick-up	0	14
123291	2020-08-22 08:46:17	2020-08-22	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	21414	delivery	5	25
123292	2020-08-22 08:48:02	2020-08-22	9	[{"id_menu":7,"count":1}]	44665	pick-up	0	9
123293	2020-08-22 08:49:35	2020-08-22	8	[{"id_menu":5,"count":1}]	46946	delivery	5	13
123294	2020-08-22 08:50:29	2020-08-22	14	[{"id_menu":2,"count":1}]	39006	delivery	5	19
123295	2020-08-22 08:51:54	2020-08-22	14	[{"id_menu":2,"count":1}]	1309	pick-up	0	14
123296	2020-08-22 08:54:49	2020-08-22	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	35096	pick-up	0	29
123297	2020-08-22 08:56:06	2020-08-22	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	46952	delivery	5	26
123298	2020-08-22 08:59:06	2020-08-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	46922	delivery	5	23
123299	2020-08-22 09:02:08	2020-08-22	9	[{"id_menu":6,"count":1}]	46588	delivery	5	14
123300	2020-08-22 09:04:30	2020-08-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	20478	delivery	5	28
123301	2020-08-22 09:06:12	2020-08-22	9	[{"id_menu":7,"count":1}]	10376	delivery	5	14
123302	2020-08-22 09:06:55	2020-08-22	8	[{"id_menu":5,"count":2}]	46870	delivery	5	13
123303	2020-08-22 09:09:11	2020-08-22	8	[{"id_menu":5,"count":1}]	11519	pick-up	0	8
123304	2020-08-22 09:09:23	2020-08-22	12	[{"id_menu":3,"count":1}]	42859	delivery	5	17
123305	2020-08-22 09:14:49	2020-08-22	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5169	pick-up	0	40
123306	2020-08-22 09:18:39	2020-08-22	8	[{"id_menu":5,"count":1}]	46962	delivery	5	13
123307	2020-08-22 09:19:09	2020-08-22	8	[{"id_menu":5,"count":1}]	22127	delivery	5	13
123308	2020-08-22 09:19:47	2020-08-22	9	[{"id_menu":7,"count":1}]	10209	pick-up	0	9
123309	2020-08-22 09:21:14	2020-08-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12106	delivery	5	23
123310	2020-08-22 09:22:59	2020-08-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	46880	delivery	5	23
123311	2020-08-22 09:23:44	2020-08-22	9	[{"id_menu":7,"count":1}]	47050	delivery	5	14
123312	2020-08-22 09:26:20	2020-08-22	8	[{"id_menu":5,"count":1}]	25630	delivery	5	13
123313	2020-08-22 09:28:54	2020-08-22	17	[{"id_menu":4,"count":1}]	35527	delivery	5	22
123314	2020-08-22 09:35:20	2020-08-22	12	[{"id_menu":3,"count":1}]	3227	pick-up	0	12
123315	2020-08-22 09:36:01	2020-08-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	889	delivery	5	28
123316	2020-08-22 09:36:21	2020-08-22	14	[{"id_menu":2,"count":1}]	46954	delivery	5	19
123317	2020-08-22 09:38:20	2020-08-22	8	[{"id_menu":5,"count":1}]	11466	delivery	5	13
123318	2020-08-22 09:38:23	2020-08-22	14	[{"id_menu":2,"count":1}]	45690	delivery	5	19
123319	2020-08-22 09:38:33	2020-08-22	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	17021	delivery	5	27
123320	2020-08-22 09:40:07	2020-08-22	12	[{"id_menu":1,"count":1}]	47027	delivery	5	17
123321	2020-08-22 09:43:39	2020-08-22	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23414	delivery	5	34
123322	2020-08-22 09:45:15	2020-08-22	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	25631	delivery	5	34
123323	2020-08-22 09:45:33	2020-08-22	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	18597	delivery	5	43
123324	2020-08-22 09:46:26	2020-08-22	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	24752	pick-up	0	31
123325	2020-08-22 09:47:55	2020-08-22	12	[{"id_menu":3,"count":1}]	43779	pick-up	0	12
123326	2020-08-22 09:48:49	2020-08-22	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	22099	delivery	5	56
123327	2020-08-22 09:49:49	2020-08-22	14	[{"id_menu":2,"count":1}]	8637	delivery	5	19
123328	2020-08-22 09:50:55	2020-08-22	8	[{"id_menu":5,"count":2}]	20379	delivery	5	13
123329	2020-08-22 09:51:26	2020-08-22	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	18878	delivery	5	30
123330	2020-08-22 09:51:43	2020-08-22	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	47011	delivery	5	34
123331	2020-08-22 09:58:59	2020-08-22	12	[{"id_menu":3,"count":1}]	41364	delivery	5	17
123332	2020-08-22 09:59:09	2020-08-22	12	[{"id_menu":1,"count":1}]	46865	delivery	5	17
123333	2020-08-22 10:02:04	2020-08-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	46819	delivery	5	22
123334	2020-08-22 10:02:24	2020-08-22	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	16475	pick-up	0	20
123335	2020-08-22 10:02:27	2020-08-22	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	46928	delivery	5	26
123336	2020-08-22 10:05:00	2020-08-22	8	[{"id_menu":5,"count":1}]	17793	delivery	5	13
123337	2020-08-22 10:07:05	2020-08-22	8	[{"id_menu":5,"count":1}]	17005	delivery	5	13
123338	2020-08-22 10:10:23	2020-08-22	9	[{"id_menu":6,"count":1}]	24224	delivery	5	14
123339	2020-08-22 10:14:19	2020-08-22	8	[{"id_menu":5,"count":1}]	35882	delivery	5	13
123340	2020-08-22 10:17:32	2020-08-22	12	[{"id_menu":3,"count":1}]	46930	delivery	5	17
123341	2020-08-22 10:22:09	2020-08-22	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	35776	delivery	5	31
123342	2020-08-22 10:22:10	2020-08-22	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	29104	delivery	5	25
123343	2020-08-22 10:23:33	2020-08-22	12	[{"id_menu":3,"count":1}]	2671	pick-up	0	12
123344	2020-08-22 10:24:04	2020-08-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	47034	delivery	5	36
123345	2020-08-22 10:24:30	2020-08-22	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	46849	delivery	5	31
123346	2020-08-22 10:28:45	2020-08-22	17	[{"id_menu":4,"count":1}]	14463	delivery	5	22
123347	2020-08-22 10:29:22	2020-08-22	12	[{"id_menu":1,"count":1}]	46977	delivery	5	17
123348	2020-08-22 10:34:31	2020-08-22	12	[{"id_menu":1,"count":1}]	34421	pick-up	0	12
123349	2020-08-22 10:34:49	2020-08-22	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	46991	delivery	5	54
123350	2020-08-22 10:36:34	2020-08-22	12	[{"id_menu":1,"count":1}]	26184	delivery	5	17
123351	2020-08-22 10:37:16	2020-08-22	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7301	delivery	5	40
123352	2020-08-22 10:37:27	2020-08-22	14	[{"id_menu":2,"count":1}]	44578	pick-up	0	14
123353	2020-08-22 10:39:22	2020-08-22	17	[{"id_menu":4,"count":1}]	46848	delivery	5	22
123354	2020-08-22 10:40:18	2020-08-22	12	[{"id_menu":1,"count":1}]	47055	delivery	5	17
123355	2020-08-22 10:42:31	2020-08-22	9	[{"id_menu":7,"count":1}]	20749	delivery	5	14
123356	2020-08-22 10:43:08	2020-08-22	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	46854	delivery	5	35
123357	2020-08-22 10:47:06	2020-08-22	9	[{"id_menu":6,"count":1}]	32046	delivery	5	14
123358	2020-08-22 10:48:01	2020-08-22	8	[{"id_menu":5,"count":1}]	22013	delivery	5	13
123359	2020-08-22 10:50:24	2020-08-22	9	[{"id_menu":6,"count":1}]	16801	delivery	5	14
123360	2020-08-22 10:53:10	2020-08-22	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	22071	delivery	5	26
123361	2020-08-22 10:56:49	2020-08-22	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	47009	pick-up	0	26
123362	2020-08-22 10:57:08	2020-08-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2253	delivery	5	28
123363	2020-08-22 10:58:18	2020-08-22	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29137	delivery	5	39
123364	2020-08-22 10:59:22	2020-08-22	12	[{"id_menu":3,"count":1}]	44928	delivery	5	17
123365	2020-08-22 10:59:50	2020-08-22	9	[{"id_menu":7,"count":1}]	46968	delivery	5	14
123366	2020-08-22 11:00:27	2020-08-22	17	[{"id_menu":4,"count":1}]	33815	delivery	5	22
123367	2020-08-22 11:01:31	2020-08-22	12	[{"id_menu":1,"count":1}]	28290	delivery	5	17
123368	2020-08-22 11:02:22	2020-08-22	17	[{"id_menu":4,"count":1}]	34808	delivery	5	22
123369	2020-08-22 11:04:54	2020-08-22	9	[{"id_menu":7,"count":1}]	8469	delivery	5	14
123370	2020-08-22 11:05:24	2020-08-22	9	[{"id_menu":6,"count":1}]	46964	delivery	5	14
123371	2020-08-22 11:06:27	2020-08-22	17	[{"id_menu":4,"count":1}]	18987	delivery	5	22
123372	2020-08-22 11:08:06	2020-08-22	8	[{"id_menu":5,"count":1}]	3334	delivery	5	13
123373	2020-08-22 11:12:49	2020-08-22	12	[{"id_menu":1,"count":2}]	46861	delivery	5	17
123374	2020-08-22 11:14:36	2020-08-22	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	27076	delivery	5	40
123375	2020-08-22 11:18:16	2020-08-22	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	47033	delivery	5	30
123376	2020-08-22 11:18:36	2020-08-22	9	[{"id_menu":7,"count":1}]	19931	pick-up	0	9
123377	2020-08-22 11:19:41	2020-08-22	9	[{"id_menu":7,"count":2}]	9098	delivery	5	14
123378	2020-08-22 11:22:58	2020-08-22	9	[{"id_menu":7,"count":1}]	11275	delivery	5	14
123379	2020-08-22 11:26:28	2020-08-22	17	[{"id_menu":4,"count":1}]	32822	delivery	5	22
123380	2020-08-22 11:27:58	2020-08-22	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1914	pick-up	0	35
123381	2020-08-22 11:30:04	2020-08-22	17	[{"id_menu":4,"count":1}]	46878	delivery	5	22
123382	2020-08-22 11:31:09	2020-08-22	9	[{"id_menu":6,"count":1}]	25859	delivery	5	14
123383	2020-08-22 11:32:21	2020-08-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	12709	delivery	5	36
123384	2020-08-22 11:34:39	2020-08-22	9	[{"id_menu":6,"count":1}]	28232	delivery	5	14
123385	2020-08-22 11:36:18	2020-08-22	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	28478	delivery	5	43
123386	2020-08-22 11:39:04	2020-08-22	8	[{"id_menu":5,"count":1}]	47024	delivery	5	13
123387	2020-08-22 11:41:02	2020-08-22	8	[{"id_menu":5,"count":1}]	721	pick-up	0	8
123388	2020-08-22 11:41:56	2020-08-22	8	[{"id_menu":5,"count":1}]	45675	delivery	5	13
123389	2020-08-22 11:46:23	2020-08-22	14	[{"id_menu":2,"count":1}]	46979	delivery	5	19
123390	2020-08-22 11:50:24	2020-08-22	9	[{"id_menu":6,"count":1}]	38295	delivery	5	14
123391	2020-08-22 11:54:35	2020-08-22	9	[{"id_menu":7,"count":1}]	15088	delivery	5	14
123392	2020-08-22 11:56:06	2020-08-22	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	10046	delivery	5	44
123393	2020-08-22 11:56:27	2020-08-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	308	delivery	5	23
123394	2020-08-22 11:56:43	2020-08-22	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	47023	delivery	5	25
123395	2020-08-22 11:56:50	2020-08-22	9	[{"id_menu":6,"count":1}]	46938	delivery	5	14
123396	2020-08-22 11:59:07	2020-08-22	8	[{"id_menu":5,"count":1}]	23682	delivery	5	13
123397	2020-08-22 12:00:23	2020-08-22	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	7796	delivery	5	31
123398	2020-08-22 12:02:26	2020-08-22	9	[{"id_menu":6,"count":1}]	30604	delivery	5	14
123399	2020-08-22 12:03:50	2020-08-22	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	11770	delivery	5	25
123400	2020-08-22 12:04:28	2020-08-22	12	[{"id_menu":3,"count":1}]	4184	delivery	5	17
123401	2020-08-22 12:05:28	2020-08-22	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14223	delivery	5	43
123402	2020-08-22 12:06:23	2020-08-22	17	[{"id_menu":4,"count":1}]	46989	delivery	5	22
123403	2020-08-22 12:07:14	2020-08-22	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	43604	delivery	5	25
123404	2020-08-22 12:08:14	2020-08-22	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	43642	delivery	5	26
123405	2020-08-22 12:10:34	2020-08-22	8	[{"id_menu":5,"count":2}]	46876	delivery	5	13
123406	2020-08-22 12:14:58	2020-08-22	8	[{"id_menu":5,"count":1}]	36244	pick-up	0	8
123407	2020-08-22 12:15:29	2020-08-22	17	[{"id_menu":4,"count":1}]	47045	delivery	5	22
123408	2020-08-22 12:15:52	2020-08-22	14	[{"id_menu":2,"count":1}]	46801	delivery	5	19
123409	2020-08-22 12:18:50	2020-08-22	14	[{"id_menu":2,"count":1}]	11403	delivery	5	19
123410	2020-08-22 12:19:00	2020-08-22	9	[{"id_menu":7,"count":1}]	46837	delivery	5	14
123411	2020-08-22 12:22:17	2020-08-22	9	[{"id_menu":6,"count":1}]	46888	delivery	5	14
123412	2020-08-22 12:23:40	2020-08-22	9	[{"id_menu":7,"count":2}]	1724	delivery	5	14
123413	2020-08-22 12:26:43	2020-08-22	9	[{"id_menu":7,"count":1}]	7814	delivery	5	14
123414	2020-08-22 12:33:36	2020-08-22	8	[{"id_menu":5,"count":1}]	11760	delivery	5	13
123415	2020-08-22 12:37:01	2020-08-22	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	31176	delivery	5	45
123416	2020-08-22 12:37:27	2020-08-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	46807	pick-up	0	23
123417	2020-08-22 12:37:34	2020-08-22	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35530	delivery	5	37
123418	2020-08-22 12:37:34	2020-08-22	12	[{"id_menu":1,"count":1}]	46809	pick-up	0	12
123419	2020-08-22 12:37:42	2020-08-22	9	[{"id_menu":6,"count":2}]	46833	delivery	5	14
123420	2020-08-22 12:38:00	2020-08-22	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	46974	pick-up	0	29
123421	2020-08-22 12:38:37	2020-08-22	12	[{"id_menu":1,"count":1}]	14824	pick-up	0	12
123422	2020-08-22 12:38:44	2020-08-22	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13400	pick-up	0	17
123423	2020-08-22 12:40:31	2020-08-22	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	15400	pick-up	0	32
123424	2020-08-22 12:44:10	2020-08-22	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15143	delivery	5	36
123425	2020-08-22 12:46:50	2020-08-22	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	40488	delivery	5	25
123426	2020-08-22 12:49:02	2020-08-22	8	[{"id_menu":5,"count":1}]	3241	delivery	5	13
123427	2020-08-22 12:49:32	2020-08-22	12	[{"id_menu":1,"count":1}]	14354	delivery	5	17
123428	2020-08-22 12:49:41	2020-08-22	9	[{"id_menu":7,"count":1}]	46965	delivery	5	14
123429	2020-08-22 12:51:13	2020-08-22	14	[{"id_menu":2,"count":1}]	29429	pick-up	0	14
123430	2020-08-22 12:56:02	2020-08-22	12	[{"id_menu":1,"count":1}]	47044	delivery	5	17
123431	2020-08-22 12:58:54	2020-08-22	12	[{"id_menu":1,"count":2}]	6938	delivery	5	17
123432	2020-08-22 12:58:56	2020-08-22	8	[{"id_menu":5,"count":2}]	19738	delivery	5	13
123433	2020-08-22 13:00:39	2020-08-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38819	delivery	5	23
123434	2020-08-22 13:01:10	2020-08-22	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	25255	delivery	5	31
123435	2020-08-22 13:02:56	2020-08-22	9	[{"id_menu":6,"count":1}]	47052	delivery	5	14
123436	2020-08-22 13:05:04	2020-08-22	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	16556	delivery	5	40
123437	2020-08-22 13:06:31	2020-08-22	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	17936	delivery	5	34
123438	2020-08-22 13:07:46	2020-08-22	12	[{"id_menu":1,"count":1}]	46963	delivery	5	17
123439	2020-08-22 13:08:09	2020-08-22	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":3}]	2878	delivery	5	31
123440	2020-08-22 13:10:31	2020-08-22	12	[{"id_menu":3,"count":1}]	11395	delivery	5	17
123441	2020-08-22 13:15:14	2020-08-22	12	[{"id_menu":1,"count":1}]	38731	delivery	5	17
123442	2020-08-22 13:15:25	2020-08-22	8	[{"id_menu":5,"count":1}]	11993	delivery	5	13
123443	2020-08-22 13:17:07	2020-08-22	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	46955	delivery	5	27
123444	2020-08-22 13:17:44	2020-08-22	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	47048	pick-up	0	34
123445	2020-08-22 13:18:46	2020-08-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	22683	delivery	5	28
123446	2020-08-22 13:19:07	2020-08-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	25944	delivery	5	36
123447	2020-08-22 13:20:12	2020-08-22	9	[{"id_menu":6,"count":1}]	44776	delivery	5	14
123448	2020-08-22 13:20:13	2020-08-22	17	[{"id_menu":4,"count":1}]	26194	delivery	5	22
123449	2020-08-22 13:20:35	2020-08-22	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	25200	delivery	5	25
123450	2020-08-22 13:22:55	2020-08-22	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	46949	delivery	5	43
123451	2020-08-22 13:23:48	2020-08-22	9	[{"id_menu":7,"count":1}]	7180	delivery	5	14
123452	2020-08-22 13:24:01	2020-08-22	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	19530	delivery	5	34
123453	2020-08-22 13:24:03	2020-08-22	17	[{"id_menu":4,"count":1}]	26475	delivery	5	22
123454	2020-08-22 13:27:00	2020-08-22	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	46969	delivery	5	23
123455	2020-08-22 13:31:39	2020-08-22	12	[{"id_menu":3,"count":1}]	35331	delivery	5	17
123456	2020-08-22 13:34:14	2020-08-22	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	46905	delivery	5	31
123457	2020-08-22 13:34:59	2020-08-22	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	46869	pick-up	0	24
123458	2020-08-22 13:36:25	2020-08-22	17	[{"id_menu":4,"count":2}]	19300	pick-up	0	17
123459	2020-08-22 13:36:35	2020-08-22	8	[{"id_menu":5,"count":1}]	37986	delivery	5	13
123460	2020-08-22 13:37:16	2020-08-22	12	[{"id_menu":1,"count":1}]	46903	delivery	5	17
123461	2020-08-22 13:39:49	2020-08-22	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	46982	delivery	5	30
123462	2020-08-22 13:40:57	2020-08-22	8	[{"id_menu":5,"count":1}]	46732	delivery	5	13
123463	2020-08-22 13:43:45	2020-08-22	12	[{"id_menu":3,"count":1}]	27124	delivery	5	17
123464	2020-08-22 13:43:46	2020-08-22	8	[{"id_menu":5,"count":1}]	6376	pick-up	0	8
123465	2020-08-22 13:48:48	2020-08-22	14	[{"id_menu":2,"count":1}]	46934	delivery	5	19
123466	2020-08-22 13:50:56	2020-08-22	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	44639	pick-up	0	26
123467	2020-08-22 13:51:19	2020-08-22	12	[{"id_menu":3,"count":1}]	46874	delivery	5	17
123468	2020-08-22 13:51:38	2020-08-22	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	46971	delivery	5	40
123469	2020-08-22 13:53:23	2020-08-22	17	[{"id_menu":4,"count":1}]	10101	delivery	5	22
123470	2020-08-22 13:54:24	2020-08-22	12	[{"id_menu":1,"count":1}]	46824	delivery	5	17
123471	2020-08-22 13:56:04	2020-08-22	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	46910	delivery	5	34
123472	2020-08-22 13:56:58	2020-08-22	9	[{"id_menu":6,"count":2}]	2182	delivery	5	14
123473	2020-08-22 13:57:35	2020-08-22	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	28038	delivery	5	40
123474	2020-08-22 13:58:00	2020-08-22	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	46895	delivery	5	31
123475	2020-08-22 13:59:38	2020-08-22	9	[{"id_menu":7,"count":2}]	29970	delivery	5	14
123476	2020-08-22 14:02:12	2020-08-22	8	[{"id_menu":5,"count":1}]	19183	delivery	5	13
123477	2020-08-22 14:03:21	2020-08-22	14	[{"id_menu":2,"count":1}]	12688	pick-up	0	14
123478	2020-08-22 14:05:31	2020-08-22	9	[{"id_menu":7,"count":1}]	6075	delivery	5	14
123479	2020-08-22 14:06:16	2020-08-22	8	[{"id_menu":5,"count":1}]	34946	delivery	5	13
123480	2020-08-22 14:08:14	2020-08-22	17	[{"id_menu":4,"count":1}]	1090	pick-up	0	17
123481	2020-08-22 14:09:35	2020-08-22	9	[{"id_menu":7,"count":1}]	46822	delivery	5	14
123482	2020-08-22 14:10:06	2020-08-22	9	[{"id_menu":6,"count":1}]	47047	delivery	5	14
123483	2020-08-22 14:14:23	2020-08-22	12	[{"id_menu":1,"count":1}]	6733	delivery	5	17
123484	2020-08-22 14:14:37	2020-08-22	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	46889	delivery	5	34
123485	2020-08-22 14:16:33	2020-08-22	9	[{"id_menu":7,"count":1}]	12270	delivery	5	14
123486	2020-08-22 14:17:04	2020-08-22	14	[{"id_menu":2,"count":1}]	46957	delivery	5	19
123487	2020-08-22 14:17:25	2020-08-22	8	[{"id_menu":5,"count":1}]	41620	delivery	5	13
123488	2020-08-22 14:20:16	2020-08-22	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	47013	pick-up	0	26
123489	2020-08-22 14:24:57	2020-08-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	44155	delivery	5	28
123490	2020-08-22 14:25:54	2020-08-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15484	delivery	5	23
123491	2020-08-22 14:27:10	2020-08-22	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6437	delivery	5	43
123492	2020-08-22 14:29:49	2020-08-22	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	33280	delivery	5	48
123493	2020-08-22 14:30:33	2020-08-22	9	[{"id_menu":7,"count":1}]	36878	delivery	5	14
123494	2020-08-22 14:31:25	2020-08-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	46900	delivery	5	23
123495	2020-08-22 14:36:59	2020-08-22	14	[{"id_menu":2,"count":1}]	46924	delivery	5	19
123496	2020-08-22 14:40:47	2020-08-22	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	46820	delivery	5	45
123497	2020-08-22 14:41:28	2020-08-22	12	[{"id_menu":3,"count":1}]	5045	delivery	5	17
123498	2020-08-22 14:42:53	2020-08-22	14	[{"id_menu":2,"count":1}]	37939	delivery	5	19
123499	2020-08-22 14:43:01	2020-08-22	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6135	delivery	5	55
123500	2020-08-22 14:43:27	2020-08-22	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21485	pick-up	0	34
123501	2020-08-22 14:45:25	2020-08-22	14	[{"id_menu":2,"count":1}]	45030	delivery	5	19
123502	2020-08-22 14:45:44	2020-08-22	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	37031	delivery	5	48
123503	2020-08-22 14:46:14	2020-08-22	12	[{"id_menu":3,"count":1}]	19523	pick-up	0	12
123504	2020-08-22 14:46:52	2020-08-22	9	[{"id_menu":7,"count":2}]	33620	delivery	5	14
123505	2020-08-22 14:48:34	2020-08-22	9	[{"id_menu":6,"count":1}]	46892	delivery	5	14
123506	2020-08-22 14:49:56	2020-08-22	17	[{"id_menu":4,"count":1}]	46866	pick-up	0	17
123507	2020-08-22 14:52:04	2020-08-22	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	46999	pick-up	0	17
123508	2020-08-22 14:53:56	2020-08-22	9	[{"id_menu":7,"count":1}]	46828	delivery	5	14
123509	2020-08-22 14:54:47	2020-08-22	12	[{"id_menu":1,"count":1}]	1135	delivery	5	17
123510	2020-08-22 14:56:06	2020-08-22	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	43915	delivery	5	51
123511	2020-08-22 14:56:42	2020-08-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	16167	delivery	5	22
123512	2020-08-22 14:56:50	2020-08-22	9	[{"id_menu":6,"count":1}]	21811	delivery	5	14
123513	2020-08-22 14:59:17	2020-08-22	8	[{"id_menu":5,"count":1}]	6429	delivery	5	13
123514	2020-08-22 14:59:59	2020-08-22	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	46871	delivery	5	30
123515	2020-08-22 15:00:23	2020-08-22	8	[{"id_menu":5,"count":1}]	46931	delivery	5	13
123516	2020-08-22 15:01:47	2020-08-22	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	26819	delivery	5	31
123517	2020-08-22 15:02:37	2020-08-22	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	46902	delivery	5	43
123518	2020-08-22 15:03:01	2020-08-22	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11969	delivery	5	31
123519	2020-08-22 15:03:52	2020-08-22	12	[{"id_menu":3,"count":1}]	43245	pick-up	0	12
123520	2020-08-22 15:04:21	2020-08-22	9	[{"id_menu":6,"count":1}]	39722	delivery	5	14
123521	2020-08-22 15:05:43	2020-08-22	17	[{"id_menu":4,"count":1}]	46834	pick-up	0	17
123522	2020-08-22 15:06:20	2020-08-22	9	[{"id_menu":7,"count":1}]	47022	delivery	5	14
123523	2020-08-22 15:06:22	2020-08-22	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	46927	delivery	5	40
123524	2020-08-22 15:06:33	2020-08-22	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	47014	delivery	5	30
123525	2020-08-22 15:08:57	2020-08-22	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	45951	delivery	5	31
123526	2020-08-22 15:10:45	2020-08-22	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24010	delivery	5	35
123527	2020-08-22 15:12:12	2020-08-22	12	[{"id_menu":1,"count":1}]	46859	delivery	5	17
123528	2020-08-22 15:12:29	2020-08-22	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	46976	delivery	5	22
123529	2020-08-22 15:13:38	2020-08-22	9	[{"id_menu":6,"count":1}]	37013	delivery	5	14
123530	2020-08-22 15:15:27	2020-08-22	9	[{"id_menu":6,"count":1}]	29702	pick-up	0	9
123531	2020-08-22 15:17:20	2020-08-22	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	5485	delivery	5	31
123532	2020-08-22 15:20:06	2020-08-22	9	[{"id_menu":6,"count":1}]	34546	delivery	5	14
123533	2020-08-22 15:23:22	2020-08-22	8	[{"id_menu":5,"count":1}]	46984	delivery	5	13
123534	2020-08-22 15:23:45	2020-08-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	47010	delivery	5	23
123535	2020-08-22 15:24:24	2020-08-22	9	[{"id_menu":6,"count":1}]	47053	delivery	5	14
123536	2020-08-22 15:24:33	2020-08-22	17	[{"id_menu":4,"count":2}]	3441	delivery	5	22
123537	2020-08-22 15:31:27	2020-08-22	8	[{"id_menu":5,"count":1}]	30880	delivery	5	13
123538	2020-08-22 15:34:25	2020-08-22	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	46884	delivery	5	22
123539	2020-08-22 15:35:02	2020-08-22	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	20196	delivery	5	31
123540	2020-08-22 15:40:42	2020-08-22	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5236	delivery	5	31
123541	2020-08-22 15:45:27	2020-08-22	8	[{"id_menu":5,"count":1}]	47002	delivery	5	13
123542	2020-08-22 15:45:33	2020-08-22	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23559	delivery	5	34
123543	2020-08-22 15:46:59	2020-08-22	14	[{"id_menu":2,"count":1}]	8146	pick-up	0	14
123544	2020-08-22 15:48:49	2020-08-22	17	[{"id_menu":4,"count":1}]	1337	pick-up	0	17
123545	2020-08-22 15:51:51	2020-08-22	17	[{"id_menu":4,"count":1}]	4453	pick-up	0	17
123546	2020-08-22 15:53:23	2020-08-22	12	[{"id_menu":1,"count":1}]	476	pick-up	0	12
123547	2020-08-22 15:57:12	2020-08-22	9	[{"id_menu":7,"count":1}]	37402	delivery	5	14
123548	2020-08-22 15:57:53	2020-08-22	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	33315	delivery	5	34
123549	2020-08-22 15:57:58	2020-08-22	8	[{"id_menu":5,"count":1}]	46842	delivery	5	13
123550	2020-08-22 16:00:13	2020-08-22	17	[{"id_menu":4,"count":1}]	45084	delivery	5	22
123551	2020-08-22 16:02:24	2020-08-22	14	[{"id_menu":2,"count":1}]	46983	pick-up	0	14
123552	2020-08-22 16:02:44	2020-08-22	12	[{"id_menu":3,"count":1}]	39487	pick-up	0	12
123553	2020-08-22 16:03:07	2020-08-22	12	[{"id_menu":1,"count":1}]	10596	delivery	5	17
123554	2020-08-22 16:03:42	2020-08-22	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	26952	delivery	5	36
123555	2020-08-22 16:05:02	2020-08-22	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28209	delivery	5	49
123556	2020-08-22 16:07:26	2020-08-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	46805	pick-up	0	31
123557	2020-08-22 16:08:03	2020-08-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	45308	delivery	5	23
123558	2020-08-22 16:10:49	2020-08-22	8	[{"id_menu":5,"count":1}]	46919	delivery	5	13
123559	2020-08-22 16:10:49	2020-08-22	9	[{"id_menu":6,"count":1}]	3364	delivery	5	14
123560	2020-08-22 16:11:00	2020-08-22	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	11840	delivery	5	30
123561	2020-08-22 16:13:04	2020-08-22	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12844	delivery	5	39
123562	2020-08-22 16:13:34	2020-08-22	12	[{"id_menu":3,"count":1}]	46863	delivery	5	17
123563	2020-08-22 16:14:09	2020-08-22	9	[{"id_menu":7,"count":1}]	10623	delivery	5	14
123564	2020-08-22 16:16:21	2020-08-22	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	42818	delivery	5	40
123565	2020-08-22 16:23:05	2020-08-22	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	46988	delivery	5	22
123566	2020-08-22 16:26:11	2020-08-22	12	[{"id_menu":1,"count":2}]	5336	pick-up	0	12
123567	2020-08-22 16:28:12	2020-08-22	9	[{"id_menu":7,"count":1}]	29876	delivery	5	14
123568	2020-08-22 16:29:27	2020-08-22	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	13172	delivery	5	31
123569	2020-08-22 16:29:35	2020-08-22	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	36597	delivery	5	27
123570	2020-08-22 16:35:37	2020-08-22	9	[{"id_menu":7,"count":1}]	47019	delivery	5	14
123571	2020-08-22 16:37:34	2020-08-22	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	44840	delivery	5	23
123572	2020-08-22 16:37:34	2020-08-22	9	[{"id_menu":6,"count":1}]	18716	delivery	5	14
123573	2020-08-22 16:37:52	2020-08-22	14	[{"id_menu":2,"count":1}]	47007	delivery	5	19
123574	2020-08-22 16:38:07	2020-08-22	12	[{"id_menu":3,"count":1}]	46259	delivery	5	17
123575	2020-08-22 16:45:44	2020-08-22	9	[{"id_menu":7,"count":1}]	46873	delivery	5	14
123576	2020-08-22 16:49:18	2020-08-22	9	[{"id_menu":7,"count":2}]	46812	delivery	5	14
123577	2020-08-22 16:51:30	2020-08-22	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	39946	delivery	5	45
123578	2020-08-22 16:52:21	2020-08-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	46841	delivery	5	36
123579	2020-08-22 16:52:53	2020-08-22	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	31480	delivery	5	26
123580	2020-08-22 16:54:21	2020-08-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2056	pick-up	0	18
123581	2020-08-22 16:54:21	2020-08-22	12	[{"id_menu":3,"count":1}]	1092	pick-up	0	12
123582	2020-08-22 16:58:32	2020-08-22	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	15093	delivery	5	22
123583	2020-08-22 17:03:10	2020-08-22	17	[{"id_menu":4,"count":1}]	31647	delivery	5	22
123584	2020-08-22 17:03:15	2020-08-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	32	pick-up	0	18
123585	2020-08-22 17:04:15	2020-08-22	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1924	pick-up	0	35
123586	2020-08-22 17:04:39	2020-08-22	8	[{"id_menu":5,"count":2}]	47038	delivery	5	13
123587	2020-08-22 17:08:49	2020-08-22	14	[{"id_menu":2,"count":1}]	15515	delivery	5	19
123588	2020-08-22 17:12:56	2020-08-22	9	[{"id_menu":6,"count":1}]	19525	delivery	5	14
123589	2020-08-22 17:18:47	2020-08-22	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	46872	delivery	5	37
123590	2020-08-22 17:21:47	2020-08-22	9	[{"id_menu":6,"count":1}]	9164	delivery	5	14
123591	2020-08-22 17:25:35	2020-08-22	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	46831	delivery	5	23
123592	2020-08-22 17:26:22	2020-08-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	5308	pick-up	0	31
123593	2020-08-22 17:26:44	2020-08-22	17	[{"id_menu":4,"count":1}]	3961	pick-up	0	17
123594	2020-08-22 17:29:38	2020-08-22	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	15042	delivery	5	43
123595	2020-08-22 17:31:14	2020-08-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	17577	delivery	5	28
123596	2020-08-22 17:32:07	2020-08-22	9	[{"id_menu":6,"count":1}]	46939	delivery	5	14
123597	2020-08-22 17:32:28	2020-08-22	9	[{"id_menu":6,"count":1}]	18864	delivery	5	14
123598	2020-08-22 17:33:23	2020-08-22	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2185	pick-up	0	29
123599	2020-08-22 17:34:32	2020-08-22	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	7297	pick-up	0	47
123600	2020-08-22 17:36:04	2020-08-22	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	11876	delivery	5	39
123601	2020-08-22 17:40:52	2020-08-22	12	[{"id_menu":3,"count":1}]	3987	pick-up	0	12
123602	2020-08-22 17:42:37	2020-08-22	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	46867	delivery	5	31
123603	2020-08-22 17:43:16	2020-08-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	47030	delivery	5	28
123604	2020-08-22 17:44:49	2020-08-22	38	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8180	pick-up	0	38
123605	2020-08-22 17:45:25	2020-08-22	8	[{"id_menu":5,"count":1}]	31782	delivery	5	13
123606	2020-08-22 17:45:40	2020-08-22	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	46840	delivery	5	22
123607	2020-08-22 17:48:31	2020-08-22	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	5451	delivery	5	25
123608	2020-08-22 17:48:39	2020-08-22	8	[{"id_menu":5,"count":1}]	33716	delivery	5	13
123609	2020-08-22 17:50:53	2020-08-22	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	8950	delivery	5	29
123610	2020-08-22 17:51:40	2020-08-22	8	[{"id_menu":5,"count":1}]	39544	delivery	5	13
123611	2020-08-22 17:52:19	2020-08-22	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23859	delivery	5	22
123612	2020-08-22 17:54:57	2020-08-22	12	[{"id_menu":3,"count":2}]	34389	delivery	5	17
123613	2020-08-22 17:55:00	2020-08-22	25	[{"id_menu":4,"count":3},{"id_menu":5,"count":1}]	46883	delivery	5	30
123614	2020-08-22 17:55:24	2020-08-22	14	[{"id_menu":2,"count":1}]	38387	delivery	5	19
123615	2020-08-22 17:57:47	2020-08-22	17	[{"id_menu":4,"count":1}]	6977	pick-up	0	17
123616	2020-08-22 18:00:27	2020-08-22	8	[{"id_menu":5,"count":1}]	1513	pick-up	0	8
123617	2020-08-22 18:01:52	2020-08-22	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	39414	delivery	5	26
123618	2020-08-22 18:03:00	2020-08-22	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	45654	delivery	5	31
123619	2020-08-22 18:04:10	2020-08-22	9	[{"id_menu":6,"count":1}]	24804	delivery	5	14
123620	2020-08-22 18:09:36	2020-08-22	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	38875	delivery	5	53
123621	2020-08-22 18:13:47	2020-08-22	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	44383	delivery	5	40
123622	2020-08-22 18:15:07	2020-08-22	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	46929	delivery	5	39
123623	2020-08-22 18:15:26	2020-08-22	14	[{"id_menu":2,"count":1}]	3533	pick-up	0	14
123624	2020-08-22 18:19:44	2020-08-22	12	[{"id_menu":3,"count":1}]	12248	pick-up	0	12
123625	2020-08-22 18:22:38	2020-08-22	14	[{"id_menu":2,"count":1}]	46830	pick-up	0	14
123626	2020-08-22 18:23:27	2020-08-22	14	[{"id_menu":2,"count":1}]	46995	delivery	5	19
123627	2020-08-22 18:25:10	2020-08-22	14	[{"id_menu":2,"count":1}]	13984	pick-up	0	14
123628	2020-08-22 18:25:47	2020-08-22	12	[{"id_menu":1,"count":1}]	20651	pick-up	0	12
123629	2020-08-22 18:26:11	2020-08-22	17	[{"id_menu":4,"count":1}]	19129	delivery	5	22
123630	2020-08-22 18:29:26	2020-08-22	12	[{"id_menu":1,"count":1}]	10200	pick-up	0	12
123631	2020-08-22 18:29:43	2020-08-22	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	6362	delivery	5	34
123632	2020-08-22 18:31:10	2020-08-22	9	[{"id_menu":6,"count":1}]	31117	delivery	5	14
123633	2020-08-22 18:32:22	2020-08-22	17	[{"id_menu":4,"count":1}]	46823	delivery	5	22
123634	2020-08-22 18:32:29	2020-08-22	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	46817	delivery	5	43
123635	2020-08-22 18:32:31	2020-08-22	12	[{"id_menu":1,"count":2}]	47021	delivery	5	17
123636	2020-08-22 18:34:37	2020-08-22	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	46907	delivery	5	27
123637	2020-08-22 18:39:03	2020-08-22	12	[{"id_menu":1,"count":1}]	1810	pick-up	0	12
123638	2020-08-22 18:39:17	2020-08-22	8	[{"id_menu":5,"count":1}]	40817	delivery	5	13
123639	2020-08-22 18:39:24	2020-08-22	14	[{"id_menu":2,"count":1}]	23694	delivery	5	19
123640	2020-08-22 18:40:19	2020-08-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	46941	delivery	5	28
123641	2020-08-22 18:41:20	2020-08-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	38948	pick-up	0	31
123642	2020-08-22 18:41:21	2020-08-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	13950	delivery	5	28
123643	2020-08-22 18:43:09	2020-08-22	8	[{"id_menu":5,"count":1}]	34716	delivery	5	13
123644	2020-08-22 18:43:13	2020-08-22	9	[{"id_menu":6,"count":1}]	39644	delivery	5	14
123645	2020-08-22 18:43:39	2020-08-22	9	[{"id_menu":6,"count":1}]	46932	delivery	5	14
123646	2020-08-22 18:45:52	2020-08-22	14	[{"id_menu":2,"count":1}]	46925	delivery	5	19
123647	2020-08-22 18:47:12	2020-08-22	12	[{"id_menu":3,"count":1}]	44677	pick-up	0	12
123648	2020-08-22 18:50:03	2020-08-22	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	29033	delivery	5	29
123649	2020-08-22 18:51:22	2020-08-22	17	[{"id_menu":4,"count":1}]	16754	delivery	5	22
123650	2020-08-22 18:53:51	2020-08-22	12	[{"id_menu":3,"count":1}]	46908	delivery	5	17
123651	2020-08-22 18:55:24	2020-08-22	9	[{"id_menu":7,"count":1}]	31127	delivery	5	14
123652	2020-08-22 18:55:38	2020-08-22	9	[{"id_menu":7,"count":1}]	46599	pick-up	0	9
123653	2020-08-22 18:55:58	2020-08-22	9	[{"id_menu":6,"count":2}]	33995	delivery	5	14
123654	2020-08-22 18:56:55	2020-08-22	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	21430	delivery	5	34
123655	2020-08-22 18:57:03	2020-08-22	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	39678	delivery	5	36
123656	2020-08-22 18:58:15	2020-08-22	14	[{"id_menu":2,"count":1}]	47042	delivery	5	19
123657	2020-08-22 18:58:36	2020-08-22	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21887	delivery	5	31
123658	2020-08-22 18:58:49	2020-08-22	9	[{"id_menu":7,"count":1}]	18976	pick-up	0	9
123659	2020-08-22 19:04:02	2020-08-22	9	[{"id_menu":6,"count":1}]	46890	delivery	5	14
123660	2020-08-22 19:05:57	2020-08-22	9	[{"id_menu":7,"count":1}]	47040	delivery	5	14
123661	2020-08-22 19:06:43	2020-08-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	46803	delivery	5	28
123662	2020-08-22 19:08:51	2020-08-22	12	[{"id_menu":1,"count":1}]	17658	delivery	5	17
123663	2020-08-22 19:08:53	2020-08-22	17	[{"id_menu":4,"count":1}]	584	delivery	5	22
123664	2020-08-22 19:09:20	2020-08-22	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	26361	delivery	5	51
123665	2020-08-22 19:10:44	2020-08-22	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	19628	delivery	5	27
123666	2020-08-22 19:11:16	2020-08-22	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	40152	delivery	5	34
123667	2020-08-22 19:11:21	2020-08-22	8	[{"id_menu":5,"count":1}]	47056	pick-up	0	8
123668	2020-08-22 19:12:20	2020-08-22	9	[{"id_menu":6,"count":1}]	6609	delivery	5	14
123669	2020-08-22 19:15:48	2020-08-22	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	33990	delivery	5	34
123670	2020-08-22 19:16:58	2020-08-22	8	[{"id_menu":5,"count":1}]	20122	delivery	5	13
123671	2020-08-22 19:18:08	2020-08-22	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	47005	delivery	5	31
123672	2020-08-22 19:18:17	2020-08-22	14	[{"id_menu":2,"count":1}]	22778	delivery	5	19
123673	2020-08-22 19:18:22	2020-08-22	9	[{"id_menu":7,"count":1}]	1596	pick-up	0	9
123674	2020-08-22 19:19:35	2020-08-22	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	20669	delivery	5	31
123675	2020-08-22 19:20:38	2020-08-22	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	46832	delivery	5	48
123676	2020-08-22 19:21:28	2020-08-22	17	[{"id_menu":4,"count":1}]	4080	delivery	5	22
123677	2020-08-22 19:22:40	2020-08-22	12	[{"id_menu":1,"count":1}]	7746	delivery	5	17
123678	2020-08-22 19:23:34	2020-08-22	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	46914	delivery	5	42
123679	2020-08-22 19:26:19	2020-08-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	20451	delivery	5	22
123680	2020-08-22 19:26:38	2020-08-22	8	[{"id_menu":5,"count":1}]	47049	delivery	5	13
123681	2020-08-22 19:26:57	2020-08-22	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	45559	delivery	5	31
123682	2020-08-22 19:28:35	2020-08-22	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	40611	delivery	5	30
123683	2020-08-22 19:30:19	2020-08-22	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39168	delivery	5	35
123684	2020-08-22 19:30:36	2020-08-22	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	46994	delivery	5	35
123685	2020-08-22 19:31:32	2020-08-22	9	[{"id_menu":7,"count":1}]	46844	delivery	5	14
123686	2020-08-22 19:32:35	2020-08-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	46875	delivery	5	22
123687	2020-08-22 19:32:38	2020-08-22	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	46921	delivery	5	26
123688	2020-08-22 19:34:28	2020-08-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	45770	delivery	5	28
123689	2020-08-22 19:35:20	2020-08-22	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	27744	delivery	5	36
123690	2020-08-22 19:35:31	2020-08-22	9	[{"id_menu":7,"count":1}]	46936	delivery	5	14
123691	2020-08-22 19:46:15	2020-08-22	9	[{"id_menu":7,"count":1}]	40045	delivery	5	14
123692	2020-08-22 19:53:26	2020-08-22	17	[{"id_menu":4,"count":1}]	44955	pick-up	0	17
123693	2020-08-22 19:53:41	2020-08-22	9	[{"id_menu":7,"count":2}]	42314	delivery	5	14
123694	2020-08-22 19:54:49	2020-08-22	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	46951	delivery	5	40
123695	2020-08-22 19:57:17	2020-08-22	9	[{"id_menu":7,"count":1}]	46897	delivery	5	14
123696	2020-08-22 19:58:37	2020-08-22	8	[{"id_menu":5,"count":1}]	26635	delivery	5	13
123697	2020-08-22 19:59:27	2020-08-22	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36091	delivery	5	31
123698	2020-08-22 19:59:57	2020-08-22	14	[{"id_menu":2,"count":1}]	46806	delivery	5	19
123699	2020-08-22 20:00:33	2020-08-22	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11105	delivery	5	45
123700	2020-08-22 20:00:38	2020-08-22	17	[{"id_menu":4,"count":1}]	24471	delivery	5	22
123701	2020-08-22 20:01:48	2020-08-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	24833	delivery	5	28
123702	2020-08-22 20:02:50	2020-08-22	8	[{"id_menu":5,"count":1}]	46850	delivery	5	13
123703	2020-08-22 20:04:30	2020-08-22	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	46958	delivery	5	34
123704	2020-08-22 20:05:15	2020-08-22	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	15110	pick-up	0	23
123705	2020-08-22 20:05:45	2020-08-22	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	24734	delivery	5	42
123706	2020-08-22 20:08:54	2020-08-22	9	[{"id_menu":6,"count":1}]	46909	pick-up	0	9
123707	2020-08-22 20:10:04	2020-08-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":3}]	46973	delivery	5	28
123708	2020-08-22 20:11:14	2020-08-22	9	[{"id_menu":6,"count":1}]	7044	delivery	5	14
123709	2020-08-22 20:15:21	2020-08-22	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	46896	delivery	5	48
123710	2020-08-22 20:15:31	2020-08-22	14	[{"id_menu":2,"count":1}]	1032	pick-up	0	14
123711	2020-08-22 20:17:23	2020-08-22	14	[{"id_menu":2,"count":1}]	46956	delivery	5	19
123712	2020-08-22 20:20:29	2020-08-22	9	[{"id_menu":7,"count":1}]	46917	delivery	5	14
123713	2020-08-22 20:21:43	2020-08-22	9	[{"id_menu":6,"count":1}]	44835	pick-up	0	9
123714	2020-08-22 20:22:19	2020-08-22	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1212	pick-up	0	26
123715	2020-08-22 20:24:39	2020-08-22	12	[{"id_menu":3,"count":1}]	16857	delivery	5	17
123716	2020-08-22 20:26:41	2020-08-22	9	[{"id_menu":6,"count":1}]	23325	delivery	5	14
123717	2020-08-22 20:27:03	2020-08-22	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	46857	delivery	5	25
123718	2020-08-22 20:28:03	2020-08-22	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41218	delivery	5	35
123719	2020-08-22 20:28:55	2020-08-22	12	[{"id_menu":3,"count":2}]	11824	pick-up	0	12
123720	2020-08-22 20:29:29	2020-08-22	9	[{"id_menu":7,"count":1}]	47003	delivery	5	14
123721	2020-08-22 20:30:01	2020-08-22	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	657	pick-up	0	23
123722	2020-08-22 20:32:34	2020-08-22	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	6501	delivery	5	29
123723	2020-08-22 20:37:45	2020-08-22	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	25246	delivery	5	34
123724	2020-08-22 20:38:37	2020-08-22	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	41906	delivery	5	36
123725	2020-08-22 20:39:12	2020-08-22	8	[{"id_menu":5,"count":1}]	46815	delivery	5	13
123726	2020-08-22 20:40:41	2020-08-22	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	47041	delivery	5	51
123727	2020-08-22 20:41:05	2020-08-22	8	[{"id_menu":5,"count":1}]	28902	delivery	5	13
123728	2020-08-22 20:43:09	2020-08-22	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	2528	delivery	5	26
123729	2020-08-22 20:46:50	2020-08-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38185	delivery	5	23
123730	2020-08-22 20:48:10	2020-08-22	9	[{"id_menu":6,"count":1}]	11979	delivery	5	14
123731	2020-08-22 20:48:27	2020-08-22	8	[{"id_menu":5,"count":1}]	29226	pick-up	0	8
123732	2020-08-22 20:50:17	2020-08-22	9	[{"id_menu":7,"count":1}]	5426	delivery	5	14
123733	2020-08-22 20:52:03	2020-08-22	9	[{"id_menu":7,"count":1}]	45737	delivery	5	14
123734	2020-08-22 20:53:17	2020-08-22	9	[{"id_menu":7,"count":1}]	21601	pick-up	0	9
123735	2020-08-22 20:55:58	2020-08-22	9	[{"id_menu":6,"count":1}]	11586	delivery	5	14
123736	2020-08-22 20:56:02	2020-08-22	9	[{"id_menu":7,"count":1}]	38931	delivery	5	14
123737	2020-08-22 20:56:55	2020-08-22	9	[{"id_menu":7,"count":1}]	47004	delivery	5	14
123738	2020-08-22 20:57:40	2020-08-22	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	46847	delivery	5	31
123739	2020-08-22 20:59:36	2020-08-22	9	[{"id_menu":7,"count":1}]	47039	pick-up	0	9
123740	2020-08-22 21:01:59	2020-08-22	9	[{"id_menu":7,"count":1}]	1649	delivery	5	14
123741	2020-08-22 21:05:53	2020-08-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10519	delivery	5	22
123742	2020-08-22 21:06:36	2020-08-22	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	46935	delivery	5	22
123743	2020-08-22 21:07:21	2020-08-22	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	46997	delivery	5	31
123744	2020-08-22 21:08:26	2020-08-22	12	[{"id_menu":1,"count":1}]	1820	pick-up	0	12
123745	2020-08-22 21:08:55	2020-08-22	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	46926	pick-up	0	22
123746	2020-08-22 21:10:01	2020-08-22	9	[{"id_menu":7,"count":1}]	6055	delivery	5	14
123747	2020-08-22 21:13:09	2020-08-22	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	27907	delivery	5	22
123748	2020-08-22 21:13:28	2020-08-22	9	[{"id_menu":7,"count":1}]	37141	delivery	5	14
123749	2020-08-22 21:14:20	2020-08-22	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	3341	delivery	5	26
123750	2020-08-22 21:16:34	2020-08-22	9	[{"id_menu":6,"count":1}]	8642	delivery	5	14
123751	2020-08-22 21:16:36	2020-08-22	12	[{"id_menu":3,"count":1}]	46503	delivery	5	17
123752	2020-08-22 21:18:03	2020-08-22	8	[{"id_menu":5,"count":1}]	13507	delivery	5	13
123753	2020-08-22 21:19:04	2020-08-22	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10986	delivery	5	36
123754	2020-08-22 21:19:17	2020-08-22	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	28515	pick-up	0	20
123755	2020-08-22 21:20:59	2020-08-22	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	29121	delivery	5	26
123756	2020-08-22 21:21:53	2020-08-22	12	[{"id_menu":1,"count":1}]	26695	delivery	5	17
123757	2020-08-22 21:22:27	2020-08-22	9	[{"id_menu":6,"count":1}]	15631	delivery	5	14
123758	2020-08-22 21:23:22	2020-08-22	8	[{"id_menu":5,"count":1}]	46893	delivery	5	13
123759	2020-08-22 21:23:32	2020-08-22	12	[{"id_menu":1,"count":1}]	12484	pick-up	0	12
123760	2020-08-22 21:23:33	2020-08-22	9	[{"id_menu":6,"count":1}]	31097	delivery	5	14
123761	2020-08-22 21:26:24	2020-08-22	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	42330	pick-up	0	29
123762	2020-08-22 21:28:02	2020-08-22	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	46835	delivery	5	31
123763	2020-08-22 21:28:42	2020-08-22	17	[{"id_menu":4,"count":1}]	23939	pick-up	0	17
123764	2020-08-22 21:28:49	2020-08-22	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	28999	delivery	5	31
123765	2020-08-22 21:29:52	2020-08-22	12	[{"id_menu":1,"count":1}]	43105	delivery	5	17
123766	2020-08-22 21:29:58	2020-08-22	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28692	delivery	5	34
123767	2020-08-22 21:31:12	2020-08-22	12	[{"id_menu":3,"count":1}]	46998	delivery	5	17
123768	2020-08-22 21:33:50	2020-08-22	12	[{"id_menu":3,"count":1}]	30783	delivery	5	17
123769	2020-08-22 21:34:44	2020-08-22	14	[{"id_menu":2,"count":1}]	32379	delivery	5	19
123770	2020-08-22 21:36:33	2020-08-22	14	[{"id_menu":2,"count":1}]	24703	delivery	5	19
123771	2020-08-22 21:36:53	2020-08-22	9	[{"id_menu":7,"count":1}]	789	delivery	5	14
123772	2020-08-22 21:36:58	2020-08-22	9	[{"id_menu":7,"count":1}]	22084	delivery	5	14
123773	2020-08-22 21:42:16	2020-08-22	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":3}]	42247	delivery	5	26
123774	2020-08-22 21:43:43	2020-08-22	9	[{"id_menu":6,"count":1}]	13413	delivery	5	14
123775	2020-08-22 21:44:57	2020-08-22	12	[{"id_menu":3,"count":1}]	29394	delivery	5	17
123776	2020-08-22 21:45:01	2020-08-22	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":2}]	11666	delivery	5	26
123777	2020-08-22 21:47:34	2020-08-22	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	33946	delivery	5	25
123778	2020-08-22 21:48:43	2020-08-22	12	[{"id_menu":1,"count":1}]	12132	delivery	5	17
123779	2020-08-22 21:52:21	2020-08-22	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	47046	delivery	5	34
123780	2020-08-22 21:55:56	2020-08-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	22740	delivery	5	22
123781	2020-08-22 21:56:58	2020-08-22	14	[{"id_menu":2,"count":1}]	993	pick-up	0	14
123782	2020-08-22 21:58:54	2020-08-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	10279	pick-up	0	17
123783	2020-08-22 22:01:20	2020-08-22	8	[{"id_menu":5,"count":1}]	44047	delivery	5	13
123784	2020-08-22 22:01:52	2020-08-22	8	[{"id_menu":5,"count":1}]	10861	pick-up	0	8
123785	2020-08-22 22:03:13	2020-08-22	9	[{"id_menu":7,"count":1}]	36922	delivery	5	14
123786	2020-08-22 22:10:21	2020-08-22	8	[{"id_menu":5,"count":1}]	38592	delivery	5	13
123787	2020-08-22 22:11:36	2020-08-22	9	[{"id_menu":6,"count":1}]	19881	delivery	5	14
123788	2020-08-22 22:12:24	2020-08-22	12	[{"id_menu":1,"count":1}]	46882	delivery	5	17
123789	2020-08-22 22:14:48	2020-08-22	14	[{"id_menu":2,"count":1}]	3679	delivery	5	19
123790	2020-08-22 22:16:33	2020-08-22	12	[{"id_menu":3,"count":1}]	6191	pick-up	0	12
123791	2020-08-22 22:17:49	2020-08-22	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	46853	delivery	5	26
123792	2020-08-22 22:20:18	2020-08-22	14	[{"id_menu":2,"count":1}]	10483	pick-up	0	14
123793	2020-08-22 22:24:06	2020-08-22	17	[{"id_menu":4,"count":1}]	17077	delivery	5	22
123794	2020-08-22 22:24:34	2020-08-22	12	[{"id_menu":1,"count":1}]	46912	delivery	5	17
123795	2020-08-22 22:26:01	2020-08-22	9	[{"id_menu":6,"count":1}]	47025	delivery	5	14
123796	2020-08-22 22:32:43	2020-08-22	9	[{"id_menu":6,"count":1}]	46877	delivery	5	14
123797	2020-08-22 22:34:11	2020-08-22	8	[{"id_menu":5,"count":1}]	46868	delivery	5	13
123798	2020-08-22 22:34:11	2020-08-22	9	[{"id_menu":6,"count":1}]	41704	delivery	5	14
123799	2020-08-22 22:35:42	2020-08-22	9	[{"id_menu":7,"count":1}]	47037	delivery	5	14
123800	2020-08-22 22:36:04	2020-08-22	14	[{"id_menu":2,"count":1}]	3296	delivery	5	19
123801	2020-08-22 22:37:21	2020-08-22	12	[{"id_menu":3,"count":1}]	31282	delivery	5	17
123802	2020-08-22 22:39:20	2020-08-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	820	pick-up	0	17
123803	2020-08-22 22:41:06	2020-08-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9893	delivery	5	23
123804	2020-08-22 22:41:09	2020-08-22	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	24789	delivery	5	26
123805	2020-08-22 22:41:55	2020-08-22	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":2}]	17545	delivery	5	22
123806	2020-08-22 22:42:50	2020-08-22	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	9610	pick-up	0	29
123807	2020-08-22 22:44:21	2020-08-22	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	46825	delivery	5	26
123808	2020-08-22 22:45:11	2020-08-22	12	[{"id_menu":1,"count":1}]	20097	delivery	5	17
123809	2020-08-22 22:45:42	2020-08-22	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	33645	delivery	5	43
123810	2020-08-22 22:49:47	2020-08-22	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	27646	delivery	5	39
123811	2020-08-22 22:51:26	2020-08-22	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	19816	pick-up	0	29
123812	2020-08-22 22:54:27	2020-08-22	8	[{"id_menu":5,"count":1}]	39676	delivery	5	13
123813	2020-08-22 22:54:39	2020-08-22	9	[{"id_menu":6,"count":1}]	46990	delivery	5	14
123814	2020-08-22 22:58:42	2020-08-22	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	47026	delivery	5	43
123815	2020-08-22 22:58:46	2020-08-22	17	[{"id_menu":4,"count":1}]	14451	delivery	5	22
123816	2020-08-22 23:01:23	2020-08-22	9	[{"id_menu":7,"count":1}]	46885	delivery	5	14
123817	2020-08-22 23:01:53	2020-08-22	14	[{"id_menu":2,"count":2}]	13751	delivery	5	19
123818	2020-08-22 23:02:41	2020-08-22	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	40936	delivery	5	25
123819	2020-08-22 23:02:52	2020-08-22	9	[{"id_menu":7,"count":1}]	47035	delivery	5	14
123820	2020-08-22 23:04:03	2020-08-22	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	46810	delivery	5	26
123821	2020-08-22 23:04:27	2020-08-22	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	22479	delivery	5	26
123822	2020-08-22 23:04:30	2020-08-22	12	[{"id_menu":1,"count":1}]	203	pick-up	0	12
123823	2020-08-22 23:05:03	2020-08-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	46851	delivery	5	22
123824	2020-08-22 23:06:06	2020-08-22	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	25741	pick-up	0	25
123825	2020-08-22 23:06:09	2020-08-22	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	2440	delivery	5	39
123826	2020-08-22 23:07:23	2020-08-22	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25830	delivery	5	22
123827	2020-08-22 23:08:01	2020-08-22	9	[{"id_menu":7,"count":1}]	46942	delivery	5	14
123828	2020-08-22 23:16:07	2020-08-22	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	4482	delivery	5	31
123829	2020-08-22 23:16:09	2020-08-22	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	173	delivery	5	25
123830	2020-08-22 23:16:18	2020-08-22	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	42051	delivery	5	31
123831	2020-08-22 23:22:26	2020-08-22	26	[{"id_menu":1,"count":3},{"id_menu":2,"count":1}]	1406	pick-up	0	26
123832	2020-08-22 23:24:13	2020-08-22	12	[{"id_menu":1,"count":1}]	4139	pick-up	0	12
123833	2020-08-22 23:25:40	2020-08-22	12	[{"id_menu":1,"count":1}]	16463	pick-up	0	12
123834	2020-08-22 23:26:48	2020-08-22	14	[{"id_menu":2,"count":2}]	8655	delivery	5	19
123835	2020-08-22 23:31:29	2020-08-22	9	[{"id_menu":6,"count":1}]	43524	delivery	5	14
123836	2020-08-22 23:35:11	2020-08-22	9	[{"id_menu":7,"count":1}]	46735	pick-up	0	9
123837	2020-08-22 23:35:20	2020-08-22	8	[{"id_menu":5,"count":1}]	16710	pick-up	0	8
123838	2020-08-22 23:38:32	2020-08-22	9	[{"id_menu":7,"count":1}]	17396	delivery	5	14
123839	2020-08-22 23:39:12	2020-08-22	12	[{"id_menu":1,"count":1}]	28137	delivery	5	17
123840	2020-08-22 23:39:30	2020-08-22	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	15961	delivery	5	30
123841	2020-08-22 23:40:46	2020-08-22	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	30516	delivery	5	22
123842	2020-08-22 23:41:22	2020-08-22	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	46986	delivery	5	23
123843	2020-08-22 23:41:41	2020-08-22	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":2}]	46115	pick-up	0	31
123844	2020-08-22 23:41:46	2020-08-22	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17710	delivery	5	37
123845	2020-08-22 23:50:06	2020-08-22	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	37730	delivery	5	25
123846	2020-08-22 23:52:50	2020-08-22	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26332	delivery	5	37
123847	2020-08-22 23:53:33	2020-08-22	9	[{"id_menu":6,"count":1}]	6248	pick-up	0	9
123848	2020-08-22 23:55:57	2020-08-22	8	[{"id_menu":5,"count":2}]	30839	delivery	5	13
123849	2020-08-22 23:57:13	2020-08-22	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	40267	delivery	5	34
123850	2020-08-22 23:57:19	2020-08-22	14	[{"id_menu":2,"count":1}]	22515	pick-up	0	14
123851	2020-08-22 23:57:28	2020-08-22	9	[{"id_menu":7,"count":1}]	46950	pick-up	0	9
123852	2020-08-23 00:00:30	2020-08-23	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3638	delivery	5	48
123853	2020-08-23 00:01:37	2020-08-23	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	26507	delivery	5	35
123854	2020-08-23 00:02:09	2020-08-23	9	[{"id_menu":6,"count":1}]	47079	delivery	5	14
123855	2020-08-23 00:04:05	2020-08-23	9	[{"id_menu":6,"count":1}]	21848	delivery	5	14
123856	2020-08-23 00:08:05	2020-08-23	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	14947	delivery	5	22
123857	2020-08-23 00:10:03	2020-08-23	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2201	delivery	5	34
123858	2020-08-23 00:11:01	2020-08-23	14	[{"id_menu":2,"count":1}]	47222	delivery	5	19
123859	2020-08-23 00:13:19	2020-08-23	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	6871	delivery	5	37
123860	2020-08-23 00:16:12	2020-08-23	17	[{"id_menu":4,"count":1}]	47286	pick-up	0	17
123861	2020-08-23 00:17:39	2020-08-23	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	42414	delivery	5	27
123862	2020-08-23 00:18:38	2020-08-23	17	[{"id_menu":4,"count":1}]	2374	delivery	5	22
123863	2020-08-23 00:19:43	2020-08-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	19903	delivery	5	31
123864	2020-08-23 00:20:11	2020-08-23	14	[{"id_menu":2,"count":1}]	45841	delivery	5	19
123865	2020-08-23 00:23:58	2020-08-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	47100	delivery	5	36
123866	2020-08-23 00:26:04	2020-08-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12460	delivery	5	23
123867	2020-08-23 00:27:32	2020-08-23	12	[{"id_menu":1,"count":1}]	14232	pick-up	0	12
123868	2020-08-23 00:28:34	2020-08-23	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	21457	delivery	5	36
123869	2020-08-23 00:30:01	2020-08-23	12	[{"id_menu":1,"count":1}]	47069	delivery	5	17
123870	2020-08-23 00:30:21	2020-08-23	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	47090	delivery	5	34
123871	2020-08-23 00:32:21	2020-08-23	8	[{"id_menu":5,"count":1}]	440	delivery	5	13
123872	2020-08-23 00:33:16	2020-08-23	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	47059	delivery	5	26
123873	2020-08-23 00:34:11	2020-08-23	9	[{"id_menu":7,"count":1}]	13124	pick-up	0	9
123874	2020-08-23 00:34:12	2020-08-23	9	[{"id_menu":6,"count":1}]	33677	delivery	5	14
123875	2020-08-23 00:34:59	2020-08-23	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	43668	delivery	5	45
123876	2020-08-23 00:35:21	2020-08-23	9	[{"id_menu":7,"count":1}]	47280	delivery	5	14
123877	2020-08-23 00:36:32	2020-08-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11296	delivery	5	31
123878	2020-08-23 00:37:49	2020-08-23	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	13507	delivery	5	31
123879	2020-08-23 00:38:10	2020-08-23	8	[{"id_menu":5,"count":1}]	10620	delivery	5	13
123880	2020-08-23 00:40:12	2020-08-23	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3885	delivery	5	52
123881	2020-08-23 00:41:17	2020-08-23	9	[{"id_menu":7,"count":1}]	28219	pick-up	0	9
123882	2020-08-23 00:41:27	2020-08-23	9	[{"id_menu":6,"count":1}]	47107	delivery	5	14
123883	2020-08-23 00:42:13	2020-08-23	9	[{"id_menu":6,"count":1}]	20792	delivery	5	14
123884	2020-08-23 00:42:14	2020-08-23	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	16010	delivery	5	26
123885	2020-08-23 00:42:14	2020-08-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	10378	delivery	5	31
123886	2020-08-23 00:42:17	2020-08-23	14	[{"id_menu":2,"count":1}]	19711	delivery	5	19
123887	2020-08-23 00:44:42	2020-08-23	14	[{"id_menu":2,"count":1}]	31091	delivery	5	19
123888	2020-08-23 00:45:07	2020-08-23	9	[{"id_menu":6,"count":1}]	38856	delivery	5	14
123889	2020-08-23 00:46:46	2020-08-23	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	47120	delivery	5	22
123890	2020-08-23 00:46:57	2020-08-23	9	[{"id_menu":6,"count":1}]	23181	delivery	5	14
123891	2020-08-23 00:48:49	2020-08-23	17	[{"id_menu":4,"count":1}]	41538	delivery	5	22
123892	2020-08-23 00:50:56	2020-08-23	9	[{"id_menu":6,"count":1}]	27838	delivery	5	14
123893	2020-08-23 00:52:20	2020-08-23	9	[{"id_menu":6,"count":1}]	46455	delivery	5	14
123894	2020-08-23 00:52:34	2020-08-23	14	[{"id_menu":2,"count":1}]	46525	delivery	5	19
123895	2020-08-23 00:52:38	2020-08-23	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	47096	delivery	5	36
123896	2020-08-23 00:54:23	2020-08-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16749	delivery	5	23
123897	2020-08-23 00:55:39	2020-08-23	9	[{"id_menu":7,"count":1}]	47216	delivery	5	14
123898	2020-08-23 00:56:47	2020-08-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	47145	delivery	5	23
123899	2020-08-23 00:57:06	2020-08-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	3198	delivery	5	26
123900	2020-08-23 00:58:11	2020-08-23	8	[{"id_menu":5,"count":2}]	10213	pick-up	0	8
123901	2020-08-23 00:59:31	2020-08-23	12	[{"id_menu":1,"count":1}]	15243	pick-up	0	12
123902	2020-08-23 01:01:02	2020-08-23	9	[{"id_menu":7,"count":1}]	25722	delivery	5	14
123903	2020-08-23 01:03:07	2020-08-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	47184	delivery	5	31
123904	2020-08-23 01:04:24	2020-08-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	47234	delivery	5	26
123905	2020-08-23 01:04:35	2020-08-23	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	10753	delivery	5	23
123906	2020-08-23 01:06:38	2020-08-23	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	47116	delivery	5	34
123907	2020-08-23 01:07:19	2020-08-23	12	[{"id_menu":3,"count":1}]	6176	pick-up	0	12
123908	2020-08-23 01:08:37	2020-08-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	45097	delivery	5	31
123909	2020-08-23 01:10:31	2020-08-23	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	29086	delivery	5	31
123910	2020-08-23 01:11:38	2020-08-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	47233	delivery	5	36
123911	2020-08-23 01:11:51	2020-08-23	12	[{"id_menu":3,"count":1}]	3701	pick-up	0	12
123912	2020-08-23 01:12:06	2020-08-23	12	[{"id_menu":1,"count":1}]	47155	delivery	5	17
123913	2020-08-23 01:13:26	2020-08-23	8	[{"id_menu":5,"count":1}]	47175	delivery	5	13
123914	2020-08-23 01:15:36	2020-08-23	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	47178	delivery	5	30
123915	2020-08-23 01:16:34	2020-08-23	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	47106	pick-up	0	24
123916	2020-08-23 01:16:58	2020-08-23	9	[{"id_menu":6,"count":1}]	47220	delivery	5	14
123917	2020-08-23 01:19:58	2020-08-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	8898	delivery	5	26
123918	2020-08-23 01:20:12	2020-08-23	12	[{"id_menu":1,"count":1}]	42793	delivery	5	17
123919	2020-08-23 01:21:08	2020-08-23	12	[{"id_menu":1,"count":1}]	11244	pick-up	0	12
123920	2020-08-23 01:23:12	2020-08-23	17	[{"id_menu":4,"count":1}]	23407	delivery	5	22
123921	2020-08-23 01:23:54	2020-08-23	9	[{"id_menu":6,"count":1}]	47238	pick-up	0	9
123922	2020-08-23 01:25:22	2020-08-23	12	[{"id_menu":1,"count":1}]	5959	pick-up	0	12
123923	2020-08-23 01:25:49	2020-08-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41299	delivery	5	23
123924	2020-08-23 01:26:16	2020-08-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	30839	pick-up	0	26
123925	2020-08-23 01:27:39	2020-08-23	14	[{"id_menu":2,"count":1}]	2237	delivery	5	19
123926	2020-08-23 01:27:59	2020-08-23	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	4846	pick-up	0	20
123927	2020-08-23 01:29:06	2020-08-23	14	[{"id_menu":2,"count":1}]	203	delivery	5	19
123928	2020-08-23 01:29:49	2020-08-23	12	[{"id_menu":3,"count":1}]	4685	pick-up	0	12
123929	2020-08-23 01:30:38	2020-08-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	41926	pick-up	0	26
123930	2020-08-23 01:30:57	2020-08-23	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	47249	pick-up	0	23
123931	2020-08-23 01:32:38	2020-08-23	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14109	delivery	5	40
123932	2020-08-23 01:32:41	2020-08-23	8	[{"id_menu":5,"count":1}]	47276	delivery	5	13
123933	2020-08-23 01:32:49	2020-08-23	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	47259	delivery	5	40
123934	2020-08-23 01:33:14	2020-08-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34869	delivery	5	23
123935	2020-08-23 01:34:47	2020-08-23	14	[{"id_menu":2,"count":1}]	19522	delivery	5	19
123936	2020-08-23 01:35:40	2020-08-23	8	[{"id_menu":5,"count":1}]	21601	pick-up	0	8
123937	2020-08-23 01:35:50	2020-08-23	9	[{"id_menu":6,"count":3}]	18698	delivery	5	14
123938	2020-08-23 01:36:09	2020-08-23	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29068	delivery	5	47
123939	2020-08-23 01:36:25	2020-08-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	47114	delivery	5	26
123940	2020-08-23 01:36:25	2020-08-23	9	[{"id_menu":6,"count":1}]	9356	pick-up	0	9
123941	2020-08-23 01:38:28	2020-08-23	17	[{"id_menu":4,"count":1}]	11189	pick-up	0	17
123942	2020-08-23 01:38:43	2020-08-23	8	[{"id_menu":5,"count":1}]	32985	delivery	5	13
123943	2020-08-23 01:38:50	2020-08-23	12	[{"id_menu":3,"count":1}]	9107	pick-up	0	12
123944	2020-08-23 01:41:06	2020-08-23	12	[{"id_menu":1,"count":1}]	4353	pick-up	0	12
123945	2020-08-23 01:43:03	2020-08-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	47080	delivery	5	28
123946	2020-08-23 01:43:32	2020-08-23	17	[{"id_menu":4,"count":1}]	16362	delivery	5	22
123947	2020-08-23 01:45:18	2020-08-23	8	[{"id_menu":5,"count":1}]	25141	pick-up	0	8
123948	2020-08-23 01:46:03	2020-08-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	37496	delivery	5	28
123949	2020-08-23 01:47:32	2020-08-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	45559	delivery	5	36
123950	2020-08-23 01:48:32	2020-08-23	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25235	delivery	5	35
123951	2020-08-23 01:51:59	2020-08-23	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13710	delivery	5	43
123952	2020-08-23 01:52:48	2020-08-23	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	47058	delivery	5	31
123953	2020-08-23 01:53:41	2020-08-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	28731	delivery	5	36
123954	2020-08-23 01:54:26	2020-08-23	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4814	delivery	5	40
123955	2020-08-23 01:55:06	2020-08-23	9	[{"id_menu":6,"count":1}]	1088	delivery	5	14
123956	2020-08-23 01:55:41	2020-08-23	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41471	delivery	5	47
123957	2020-08-23 01:55:56	2020-08-23	12	[{"id_menu":3,"count":1}]	9734	pick-up	0	12
123958	2020-08-23 01:56:08	2020-08-23	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	16192	delivery	5	22
123959	2020-08-23 02:02:16	2020-08-23	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	8543	pick-up	0	24
123960	2020-08-23 02:02:56	2020-08-23	9	[{"id_menu":7,"count":1}]	45796	delivery	5	14
123961	2020-08-23 02:06:02	2020-08-23	9	[{"id_menu":6,"count":1}]	34581	delivery	5	14
123962	2020-08-23 02:07:49	2020-08-23	9	[{"id_menu":7,"count":1}]	31089	delivery	5	14
123963	2020-08-23 02:07:55	2020-08-23	17	[{"id_menu":4,"count":1}]	44375	delivery	5	22
123964	2020-08-23 02:09:44	2020-08-23	9	[{"id_menu":7,"count":1}]	47095	delivery	5	14
123965	2020-08-23 02:10:51	2020-08-23	9	[{"id_menu":7,"count":1}]	41629	delivery	5	14
123966	2020-08-23 02:12:20	2020-08-23	12	[{"id_menu":1,"count":1}]	47271	delivery	5	17
123967	2020-08-23 02:12:22	2020-08-23	9	[{"id_menu":7,"count":1}]	6723	delivery	5	14
123968	2020-08-23 02:12:43	2020-08-23	9	[{"id_menu":7,"count":1}]	6026	delivery	5	14
123969	2020-08-23 02:12:54	2020-08-23	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15636	delivery	5	34
123970	2020-08-23 02:14:16	2020-08-23	12	[{"id_menu":1,"count":1}]	47225	pick-up	0	12
123971	2020-08-23 02:21:16	2020-08-23	14	[{"id_menu":2,"count":1}]	47210	delivery	5	19
123972	2020-08-23 02:21:40	2020-08-23	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	47285	pick-up	0	26
123973	2020-08-23 02:22:54	2020-08-23	17	[{"id_menu":4,"count":1}]	17649	pick-up	0	17
123974	2020-08-23 02:23:35	2020-08-23	12	[{"id_menu":1,"count":1}]	32294	pick-up	0	12
123975	2020-08-23 02:23:47	2020-08-23	9	[{"id_menu":6,"count":1}]	42579	delivery	5	14
123976	2020-08-23 02:26:54	2020-08-23	12	[{"id_menu":1,"count":1}]	15686	pick-up	0	12
123977	2020-08-23 02:32:09	2020-08-23	12	[{"id_menu":1,"count":1}]	24670	delivery	5	17
123978	2020-08-23 02:33:25	2020-08-23	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":2}]	47093	delivery	5	29
123979	2020-08-23 02:36:52	2020-08-23	12	[{"id_menu":1,"count":1}]	47150	pick-up	0	12
123980	2020-08-23 02:37:26	2020-08-23	9	[{"id_menu":6,"count":1}]	32363	delivery	5	14
123981	2020-08-23 02:38:30	2020-08-23	12	[{"id_menu":3,"count":1}]	19888	delivery	5	17
123982	2020-08-23 02:38:34	2020-08-23	12	[{"id_menu":3,"count":1}]	23696	delivery	5	17
123983	2020-08-23 02:39:32	2020-08-23	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41030	delivery	5	47
123984	2020-08-23 02:39:42	2020-08-23	12	[{"id_menu":3,"count":1}]	12393	pick-up	0	12
123985	2020-08-23 02:40:54	2020-08-23	9	[{"id_menu":7,"count":1}]	33949	delivery	5	14
123986	2020-08-23 02:40:57	2020-08-23	9	[{"id_menu":7,"count":1}]	47277	delivery	5	14
123987	2020-08-23 02:43:25	2020-08-23	8	[{"id_menu":5,"count":1}]	8092	delivery	5	13
123988	2020-08-23 02:44:55	2020-08-23	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	47088	delivery	5	35
123989	2020-08-23 02:45:46	2020-08-23	17	[{"id_menu":4,"count":1}]	10200	pick-up	0	17
123990	2020-08-23 02:47:45	2020-08-23	9	[{"id_menu":6,"count":1}]	7957	pick-up	0	9
123991	2020-08-23 02:51:53	2020-08-23	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	10102	delivery	5	34
123992	2020-08-23 02:52:48	2020-08-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4010	delivery	5	28
123993	2020-08-23 02:53:29	2020-08-23	9	[{"id_menu":6,"count":1}]	47125	delivery	5	14
123994	2020-08-23 02:54:41	2020-08-23	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7223	delivery	5	37
123995	2020-08-23 02:56:31	2020-08-23	12	[{"id_menu":3,"count":1}]	6916	pick-up	0	12
123996	2020-08-23 02:57:45	2020-08-23	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	47287	delivery	5	52
123997	2020-08-23 02:58:28	2020-08-23	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	8585	delivery	5	43
123998	2020-08-23 03:00:11	2020-08-23	12	[{"id_menu":3,"count":1}]	15829	pick-up	0	12
123999	2020-08-23 03:01:04	2020-08-23	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	42911	delivery	5	40
124000	2020-08-23 03:03:12	2020-08-23	8	[{"id_menu":5,"count":1}]	20905	pick-up	0	8
124001	2020-08-23 03:04:16	2020-08-23	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	47153	delivery	5	23
124002	2020-08-23 03:04:34	2020-08-23	9	[{"id_menu":6,"count":1}]	46178	pick-up	0	9
124003	2020-08-23 03:08:51	2020-08-23	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	47142	delivery	5	25
124004	2020-08-23 03:11:02	2020-08-23	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39108	delivery	5	37
124005	2020-08-23 03:11:30	2020-08-23	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	47165	delivery	5	43
124006	2020-08-23 03:12:02	2020-08-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	21155	pick-up	0	31
124007	2020-08-23 03:12:59	2020-08-23	14	[{"id_menu":2,"count":1}]	21253	delivery	5	19
124008	2020-08-23 03:13:12	2020-08-23	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	6747	delivery	5	27
124009	2020-08-23 03:14:26	2020-08-23	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	41967	delivery	5	31
124010	2020-08-23 03:14:33	2020-08-23	14	[{"id_menu":2,"count":1}]	47065	delivery	5	19
124011	2020-08-23 03:15:02	2020-08-23	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	47295	delivery	5	31
124012	2020-08-23 03:15:41	2020-08-23	12	[{"id_menu":1,"count":1}]	13134	delivery	5	17
124013	2020-08-23 03:16:52	2020-08-23	17	[{"id_menu":4,"count":1}]	21455	delivery	5	22
124014	2020-08-23 03:19:16	2020-08-23	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	226	delivery	5	22
124015	2020-08-23 03:19:36	2020-08-23	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":2}]	19183	delivery	5	36
124016	2020-08-23 03:20:56	2020-08-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	47167	delivery	5	22
124017	2020-08-23 03:22:19	2020-08-23	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	47161	delivery	5	37
124018	2020-08-23 03:22:27	2020-08-23	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	6182	pick-up	0	24
124019	2020-08-23 03:24:53	2020-08-23	9	[{"id_menu":6,"count":1}]	14201	delivery	5	14
124020	2020-08-23 03:25:17	2020-08-23	17	[{"id_menu":4,"count":1}]	1387	delivery	5	22
124021	2020-08-23 03:26:00	2020-08-23	14	[{"id_menu":2,"count":1}]	47110	delivery	5	19
124022	2020-08-23 03:27:19	2020-08-23	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	23200	delivery	5	25
124023	2020-08-23 03:28:51	2020-08-23	12	[{"id_menu":3,"count":1}]	40721	delivery	5	17
124024	2020-08-23 03:30:09	2020-08-23	12	[{"id_menu":1,"count":1}]	46586	pick-up	0	12
124025	2020-08-23 03:34:59	2020-08-23	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	8355	delivery	5	25
124026	2020-08-23 03:35:30	2020-08-23	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23988	delivery	5	22
124027	2020-08-23 03:36:31	2020-08-23	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	2197	pick-up	0	20
124028	2020-08-23 03:38:23	2020-08-23	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	43323	delivery	5	25
124029	2020-08-23 03:39:28	2020-08-23	12	[{"id_menu":1,"count":1}]	29417	delivery	5	17
124030	2020-08-23 03:40:09	2020-08-23	9	[{"id_menu":7,"count":1}]	38680	delivery	5	14
124031	2020-08-23 03:42:07	2020-08-23	9	[{"id_menu":7,"count":1}]	16430	pick-up	0	9
124032	2020-08-23 03:43:40	2020-08-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11783	delivery	5	23
124033	2020-08-23 03:46:03	2020-08-23	17	[{"id_menu":4,"count":1}]	12206	delivery	5	22
124034	2020-08-23 03:46:11	2020-08-23	12	[{"id_menu":1,"count":1}]	47314	pick-up	0	12
124035	2020-08-23 03:46:40	2020-08-23	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	743	pick-up	0	40
124036	2020-08-23 03:49:08	2020-08-23	9	[{"id_menu":6,"count":1}]	46138	delivery	5	14
124037	2020-08-23 03:51:59	2020-08-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	25294	delivery	5	31
124038	2020-08-23 03:52:12	2020-08-23	12	[{"id_menu":3,"count":1}]	43119	delivery	5	17
124039	2020-08-23 03:52:36	2020-08-23	9	[{"id_menu":7,"count":1}]	47205	delivery	5	14
124040	2020-08-23 03:53:21	2020-08-23	9	[{"id_menu":6,"count":1}]	47060	delivery	5	14
124041	2020-08-23 03:53:49	2020-08-23	12	[{"id_menu":1,"count":1}]	47316	delivery	5	17
124042	2020-08-23 03:55:22	2020-08-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5737	delivery	5	23
124043	2020-08-23 03:56:07	2020-08-23	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	47242	delivery	5	26
124044	2020-08-23 03:57:29	2020-08-23	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	28183	delivery	5	26
124045	2020-08-23 03:58:26	2020-08-23	8	[{"id_menu":5,"count":1}]	19701	delivery	5	13
124046	2020-08-23 03:58:26	2020-08-23	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	47221	delivery	5	39
124047	2020-08-23 04:02:06	2020-08-23	9	[{"id_menu":7,"count":1}]	39821	delivery	5	14
124048	2020-08-23 04:02:07	2020-08-23	17	[{"id_menu":4,"count":1}]	7361	pick-up	0	17
124049	2020-08-23 04:04:24	2020-08-23	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	12158	delivery	5	30
124050	2020-08-23 04:04:59	2020-08-23	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	5478	pick-up	0	34
124051	2020-08-23 04:07:58	2020-08-23	17	[{"id_menu":4,"count":1}]	4679	pick-up	0	17
124052	2020-08-23 04:08:49	2020-08-23	17	[{"id_menu":4,"count":2}]	17875	pick-up	0	17
124053	2020-08-23 04:09:00	2020-08-23	17	[{"id_menu":4,"count":1}]	17785	delivery	5	22
124054	2020-08-23 04:10:25	2020-08-23	9	[{"id_menu":7,"count":1}]	33182	delivery	5	14
124055	2020-08-23 04:12:05	2020-08-23	8	[{"id_menu":5,"count":1}]	1308	pick-up	0	8
124056	2020-08-23 04:12:27	2020-08-23	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10936	delivery	5	51
124057	2020-08-23 04:12:33	2020-08-23	14	[{"id_menu":2,"count":1}]	34374	delivery	5	19
124058	2020-08-23 04:13:29	2020-08-23	12	[{"id_menu":3,"count":1}]	2562	pick-up	0	12
124059	2020-08-23 04:13:50	2020-08-23	17	[{"id_menu":4,"count":1}]	42880	delivery	5	22
124060	2020-08-23 04:14:48	2020-08-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1693	pick-up	0	31
124061	2020-08-23 04:15:42	2020-08-23	9	[{"id_menu":6,"count":1}]	2401	delivery	5	14
124062	2020-08-23 04:19:42	2020-08-23	9	[{"id_menu":6,"count":2}]	41804	delivery	5	14
124063	2020-08-23 04:20:51	2020-08-23	9	[{"id_menu":7,"count":1}]	25698	delivery	5	14
124064	2020-08-23 04:23:54	2020-08-23	9	[{"id_menu":6,"count":3}]	47264	delivery	5	14
124065	2020-08-23 04:24:09	2020-08-23	9	[{"id_menu":6,"count":1}]	47232	delivery	5	14
124066	2020-08-23 04:24:18	2020-08-23	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13051	delivery	5	22
124067	2020-08-23 04:24:52	2020-08-23	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	47239	delivery	5	35
124068	2020-08-23 04:27:06	2020-08-23	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15790	delivery	5	22
124069	2020-08-23 04:28:30	2020-08-23	14	[{"id_menu":2,"count":1}]	6263	delivery	5	19
124070	2020-08-23 04:30:54	2020-08-23	9	[{"id_menu":6,"count":1}]	6583	delivery	5	14
124071	2020-08-23 04:32:04	2020-08-23	9	[{"id_menu":7,"count":1}]	47121	delivery	5	14
124072	2020-08-23 04:32:59	2020-08-23	17	[{"id_menu":4,"count":1}]	41261	delivery	5	22
124073	2020-08-23 04:33:30	2020-08-23	12	[{"id_menu":1,"count":1}]	47279	delivery	5	17
124074	2020-08-23 04:34:14	2020-08-23	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	11148	delivery	5	34
124075	2020-08-23 04:34:18	2020-08-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9799	delivery	5	28
124076	2020-08-23 04:35:00	2020-08-23	17	[{"id_menu":4,"count":1}]	29810	delivery	5	22
124077	2020-08-23 04:36:50	2020-08-23	17	[{"id_menu":4,"count":1}]	47115	delivery	5	22
124078	2020-08-23 04:37:13	2020-08-23	9	[{"id_menu":6,"count":1}]	10553	delivery	5	14
124079	2020-08-23 04:39:07	2020-08-23	9	[{"id_menu":6,"count":1}]	47265	delivery	5	14
124080	2020-08-23 04:40:24	2020-08-23	8	[{"id_menu":5,"count":2}]	2790	delivery	5	13
124081	2020-08-23 04:42:18	2020-08-23	8	[{"id_menu":5,"count":1}]	22433	delivery	5	13
124082	2020-08-23 04:43:42	2020-08-23	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	47246	delivery	5	48
124083	2020-08-23 04:43:50	2020-08-23	9	[{"id_menu":7,"count":1}]	30049	delivery	5	14
124084	2020-08-23 04:46:27	2020-08-23	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24510	delivery	5	52
124085	2020-08-23 04:47:57	2020-08-23	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	37461	delivery	5	39
124086	2020-08-23 04:48:39	2020-08-23	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	47240	delivery	5	22
124087	2020-08-23 04:48:52	2020-08-23	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	39340	pick-up	0	26
124088	2020-08-23 04:49:26	2020-08-23	9	[{"id_menu":6,"count":1}]	15282	delivery	5	14
124089	2020-08-23 04:49:31	2020-08-23	12	[{"id_menu":1,"count":1}]	24725	pick-up	0	12
124090	2020-08-23 04:50:21	2020-08-23	8	[{"id_menu":5,"count":1}]	527	delivery	5	13
124091	2020-08-23 04:51:56	2020-08-23	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	47275	delivery	5	23
124092	2020-08-23 04:53:30	2020-08-23	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	46932	delivery	5	39
124093	2020-08-23 04:53:33	2020-08-23	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	2519	pick-up	0	32
124094	2020-08-23 04:56:27	2020-08-23	9	[{"id_menu":6,"count":1}]	1685	pick-up	0	9
124095	2020-08-23 04:57:29	2020-08-23	9	[{"id_menu":7,"count":1}]	11236	delivery	5	14
124096	2020-08-23 05:00:04	2020-08-23	9	[{"id_menu":7,"count":1}]	7953	delivery	5	14
124097	2020-08-23 05:01:01	2020-08-23	9	[{"id_menu":6,"count":1}]	47129	delivery	5	14
124098	2020-08-23 05:01:19	2020-08-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	33477	delivery	5	36
124099	2020-08-23 05:01:19	2020-08-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	47082	delivery	5	23
124100	2020-08-23 05:02:02	2020-08-23	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	74	pick-up	0	44
124101	2020-08-23 05:02:20	2020-08-23	12	[{"id_menu":1,"count":1}]	34495	delivery	5	17
124102	2020-08-23 05:05:05	2020-08-23	17	[{"id_menu":4,"count":1}]	47177	delivery	5	22
124103	2020-08-23 05:07:07	2020-08-23	9	[{"id_menu":7,"count":1}]	47135	delivery	5	14
124104	2020-08-23 05:09:39	2020-08-23	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30814	pick-up	0	35
124105	2020-08-23 05:09:53	2020-08-23	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	6015	delivery	5	26
124106	2020-08-23 05:10:51	2020-08-23	9	[{"id_menu":7,"count":1}]	47188	delivery	5	14
124107	2020-08-23 05:13:07	2020-08-23	9	[{"id_menu":6,"count":1}]	18571	delivery	5	14
124108	2020-08-23 05:14:45	2020-08-23	12	[{"id_menu":1,"count":1}]	19810	pick-up	0	12
124109	2020-08-23 05:15:01	2020-08-23	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	33226	delivery	5	30
124110	2020-08-23 05:15:31	2020-08-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	47104	delivery	5	31
124111	2020-08-23 05:15:39	2020-08-23	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	23976	delivery	5	31
124112	2020-08-23 05:16:27	2020-08-23	9	[{"id_menu":6,"count":1}]	38881	pick-up	0	9
124113	2020-08-23 05:18:12	2020-08-23	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	35010	delivery	5	28
124114	2020-08-23 05:18:12	2020-08-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	47215	pick-up	0	26
124115	2020-08-23 05:20:03	2020-08-23	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24416	delivery	5	22
124116	2020-08-23 05:21:28	2020-08-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5511	delivery	5	28
124117	2020-08-23 05:21:51	2020-08-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25590	pick-up	0	18
124118	2020-08-23 05:22:08	2020-08-23	9	[{"id_menu":6,"count":1}]	19480	delivery	5	14
124119	2020-08-23 05:22:22	2020-08-23	17	[{"id_menu":4,"count":1}]	12690	delivery	5	22
124120	2020-08-23 05:22:31	2020-08-23	9	[{"id_menu":6,"count":1}]	25254	delivery	5	14
124121	2020-08-23 05:27:20	2020-08-23	9	[{"id_menu":7,"count":1}]	1029	pick-up	0	9
124122	2020-08-23 05:28:52	2020-08-23	14	[{"id_menu":2,"count":1}]	7705	pick-up	0	14
124123	2020-08-23 05:31:17	2020-08-23	14	[{"id_menu":2,"count":1}]	6410	pick-up	0	14
124124	2020-08-23 05:34:17	2020-08-23	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	29080	delivery	5	22
124125	2020-08-23 05:37:11	2020-08-23	9	[{"id_menu":7,"count":1}]	47087	delivery	5	14
124126	2020-08-23 05:37:42	2020-08-23	17	[{"id_menu":4,"count":1}]	18889	delivery	5	22
124127	2020-08-23 05:38:42	2020-08-23	8	[{"id_menu":5,"count":1}]	38363	delivery	5	13
124128	2020-08-23 05:42:52	2020-08-23	8	[{"id_menu":5,"count":1}]	35744	delivery	5	13
124129	2020-08-23 05:44:09	2020-08-23	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	233	pick-up	0	38
124130	2020-08-23 05:44:22	2020-08-23	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	39660	delivery	5	34
124131	2020-08-23 05:45:04	2020-08-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	44279	pick-up	0	17
124132	2020-08-23 05:45:10	2020-08-23	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	35807	delivery	5	28
124133	2020-08-23 05:46:15	2020-08-23	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	31282	delivery	5	22
124134	2020-08-23 05:47:40	2020-08-23	17	[{"id_menu":4,"count":1}]	13731	delivery	5	22
124135	2020-08-23 05:47:42	2020-08-23	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	45745	delivery	5	34
124136	2020-08-23 05:49:39	2020-08-23	9	[{"id_menu":7,"count":1}]	42858	delivery	5	14
124137	2020-08-23 05:52:46	2020-08-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	40321	pick-up	0	31
124138	2020-08-23 05:53:04	2020-08-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	4319	delivery	5	28
124139	2020-08-23 05:55:28	2020-08-23	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	27808	delivery	5	39
124140	2020-08-23 05:55:43	2020-08-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	47149	delivery	5	26
124141	2020-08-23 05:55:59	2020-08-23	9	[{"id_menu":6,"count":1}]	156	delivery	5	14
124142	2020-08-23 05:57:20	2020-08-23	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35188	delivery	5	48
124143	2020-08-23 05:58:00	2020-08-23	9	[{"id_menu":7,"count":1}]	26379	delivery	5	14
124144	2020-08-23 05:59:08	2020-08-23	12	[{"id_menu":3,"count":1}]	24950	pick-up	0	12
124145	2020-08-23 06:00:27	2020-08-23	9	[{"id_menu":7,"count":1}]	29682	delivery	5	14
124146	2020-08-23 06:00:35	2020-08-23	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	47182	delivery	5	34
124147	2020-08-23 06:01:17	2020-08-23	8	[{"id_menu":5,"count":1}]	2682	pick-up	0	8
124148	2020-08-23 06:02:23	2020-08-23	17	[{"id_menu":4,"count":1}]	13779	delivery	5	22
124149	2020-08-23 06:02:33	2020-08-23	14	[{"id_menu":2,"count":1}]	5077	delivery	5	19
124150	2020-08-23 06:05:37	2020-08-23	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35937	delivery	5	35
124151	2020-08-23 06:06:59	2020-08-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3796	delivery	5	23
124152	2020-08-23 06:09:09	2020-08-23	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40564	delivery	5	47
124153	2020-08-23 06:10:30	2020-08-23	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9688	pick-up	0	32
124154	2020-08-23 06:11:27	2020-08-23	8	[{"id_menu":5,"count":1}]	20105	delivery	5	13
124155	2020-08-23 06:11:53	2020-08-23	9	[{"id_menu":6,"count":1}]	46670	delivery	5	14
124156	2020-08-23 06:14:57	2020-08-23	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	47209	delivery	5	45
124157	2020-08-23 06:17:06	2020-08-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23129	delivery	5	23
124158	2020-08-23 06:21:54	2020-08-23	8	[{"id_menu":5,"count":1}]	38908	delivery	5	13
124159	2020-08-23 06:24:46	2020-08-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	47229	delivery	5	28
124160	2020-08-23 06:27:14	2020-08-23	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	47181	delivery	5	31
124161	2020-08-23 06:28:40	2020-08-23	8	[{"id_menu":5,"count":1}]	47307	delivery	5	13
124162	2020-08-23 06:29:35	2020-08-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	47192	delivery	5	28
124163	2020-08-23 06:32:46	2020-08-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	31528	delivery	5	28
124164	2020-08-23 06:36:07	2020-08-23	9	[{"id_menu":6,"count":1}]	47200	delivery	5	14
124165	2020-08-23 06:37:29	2020-08-23	14	[{"id_menu":2,"count":1}]	36966	pick-up	0	14
124166	2020-08-23 06:37:54	2020-08-23	9	[{"id_menu":6,"count":1}]	36955	delivery	5	14
124167	2020-08-23 06:39:42	2020-08-23	9	[{"id_menu":6,"count":1}]	8407	pick-up	0	9
124168	2020-08-23 06:39:56	2020-08-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	40259	delivery	5	22
124169	2020-08-23 06:40:17	2020-08-23	9	[{"id_menu":6,"count":1}]	12602	pick-up	0	9
124170	2020-08-23 06:41:31	2020-08-23	17	[{"id_menu":4,"count":1}]	17840	delivery	5	22
124171	2020-08-23 06:42:12	2020-08-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	18304	pick-up	0	26
124172	2020-08-23 06:43:02	2020-08-23	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	15714	delivery	5	25
124173	2020-08-23 06:45:01	2020-08-23	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	20156	delivery	5	43
124174	2020-08-23 06:46:50	2020-08-23	14	[{"id_menu":2,"count":1}]	47311	pick-up	0	14
124175	2020-08-23 06:49:43	2020-08-23	8	[{"id_menu":5,"count":1}]	28982	delivery	5	13
124176	2020-08-23 06:49:45	2020-08-23	12	[{"id_menu":1,"count":1}]	20381	delivery	5	17
124177	2020-08-23 06:50:15	2020-08-23	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	47070	delivery	5	48
124178	2020-08-23 07:00:05	2020-08-23	17	[{"id_menu":4,"count":1}]	14670	delivery	5	22
124179	2020-08-23 07:00:53	2020-08-23	9	[{"id_menu":6,"count":1}]	21341	delivery	5	14
124180	2020-08-23 07:02:08	2020-08-23	9	[{"id_menu":7,"count":2}]	4054	pick-up	0	9
124181	2020-08-23 07:04:20	2020-08-23	9	[{"id_menu":6,"count":1}]	47113	delivery	5	14
124182	2020-08-23 07:04:52	2020-08-23	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	43943	delivery	5	31
124183	2020-08-23 07:06:52	2020-08-23	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	33629	delivery	5	22
124184	2020-08-23 07:06:54	2020-08-23	17	[{"id_menu":4,"count":1}]	39566	delivery	5	22
124185	2020-08-23 07:07:49	2020-08-23	8	[{"id_menu":5,"count":1}]	37323	delivery	5	13
124186	2020-08-23 07:09:28	2020-08-23	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17011	delivery	5	34
124187	2020-08-23 07:09:36	2020-08-23	9	[{"id_menu":7,"count":1}]	47131	delivery	5	14
124188	2020-08-23 07:09:44	2020-08-23	14	[{"id_menu":2,"count":1}]	41641	pick-up	0	14
124189	2020-08-23 07:09:53	2020-08-23	9	[{"id_menu":6,"count":1}]	34383	delivery	5	14
124190	2020-08-23 07:11:15	2020-08-23	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	45498	delivery	5	35
124191	2020-08-23 07:11:24	2020-08-23	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	9071	delivery	5	31
124192	2020-08-23 07:12:19	2020-08-23	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	35425	delivery	5	40
124193	2020-08-23 07:12:45	2020-08-23	9	[{"id_menu":7,"count":1}]	47173	delivery	5	14
124194	2020-08-23 07:13:44	2020-08-23	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":2}]	39857	delivery	5	27
124195	2020-08-23 07:16:19	2020-08-23	12	[{"id_menu":3,"count":1}]	47278	delivery	5	17
124196	2020-08-23 07:16:39	2020-08-23	14	[{"id_menu":2,"count":1}]	47228	delivery	5	19
124197	2020-08-23 07:16:55	2020-08-23	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31112	delivery	5	35
124198	2020-08-23 07:18:04	2020-08-23	9	[{"id_menu":6,"count":1}]	285	pick-up	0	9
124199	2020-08-23 07:18:56	2020-08-23	17	[{"id_menu":4,"count":1}]	18656	delivery	5	22
124200	2020-08-23 07:20:34	2020-08-23	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	47294	delivery	5	36
124201	2020-08-23 07:20:38	2020-08-23	17	[{"id_menu":4,"count":1}]	46644	delivery	5	22
124202	2020-08-23 07:23:52	2020-08-23	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19965	delivery	5	45
124203	2020-08-23 07:26:13	2020-08-23	9	[{"id_menu":6,"count":1}]	25053	pick-up	0	9
124204	2020-08-23 07:26:24	2020-08-23	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	16165	delivery	5	34
124205	2020-08-23 07:26:44	2020-08-23	8	[{"id_menu":5,"count":1}]	41006	delivery	5	13
124206	2020-08-23 07:27:23	2020-08-23	9	[{"id_menu":6,"count":1}]	19510	delivery	5	14
124207	2020-08-23 07:28:42	2020-08-23	14	[{"id_menu":2,"count":1}]	7766	pick-up	0	14
124208	2020-08-23 07:31:03	2020-08-23	9	[{"id_menu":6,"count":1}]	29455	delivery	5	14
124209	2020-08-23 07:31:50	2020-08-23	9	[{"id_menu":7,"count":1}]	2838	delivery	5	14
124210	2020-08-23 07:33:41	2020-08-23	9	[{"id_menu":7,"count":1}]	47123	delivery	5	14
124211	2020-08-23 07:38:01	2020-08-23	17	[{"id_menu":4,"count":1}]	47102	pick-up	0	17
124212	2020-08-23 07:41:17	2020-08-23	12	[{"id_menu":3,"count":1}]	209	delivery	5	17
124213	2020-08-23 07:41:57	2020-08-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	35337	delivery	5	31
124214	2020-08-23 07:43:33	2020-08-23	12	[{"id_menu":1,"count":1}]	31645	delivery	5	17
124215	2020-08-23 07:44:43	2020-08-23	8	[{"id_menu":5,"count":2}]	47124	delivery	5	13
124216	2020-08-23 07:48:43	2020-08-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	47193	delivery	5	28
124217	2020-08-23 07:48:48	2020-08-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14831	delivery	5	23
124218	2020-08-23 07:49:00	2020-08-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	47141	delivery	5	36
124219	2020-08-23 07:49:10	2020-08-23	12	[{"id_menu":3,"count":1}]	8335	pick-up	0	12
124220	2020-08-23 07:49:37	2020-08-23	14	[{"id_menu":2,"count":1}]	3511	pick-up	0	14
124221	2020-08-23 07:51:00	2020-08-23	12	[{"id_menu":1,"count":1}]	17782	delivery	5	17
124222	2020-08-23 07:51:05	2020-08-23	12	[{"id_menu":1,"count":1}]	36670	delivery	5	17
124223	2020-08-23 07:51:21	2020-08-23	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38357	delivery	5	37
124224	2020-08-23 07:53:59	2020-08-23	17	[{"id_menu":4,"count":1}]	47094	delivery	5	22
124225	2020-08-23 07:57:03	2020-08-23	12	[{"id_menu":3,"count":1}]	47132	delivery	5	17
124226	2020-08-23 08:00:28	2020-08-23	12	[{"id_menu":1,"count":1}]	47072	pick-up	0	12
124227	2020-08-23 08:00:29	2020-08-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	27084	delivery	5	31
124228	2020-08-23 08:00:37	2020-08-23	9	[{"id_menu":6,"count":1}]	10365	delivery	5	14
124229	2020-08-23 08:00:43	2020-08-23	17	[{"id_menu":4,"count":1}]	18851	delivery	5	22
124230	2020-08-23 08:01:18	2020-08-23	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	20520	delivery	5	40
124231	2020-08-23 08:02:30	2020-08-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	215	pick-up	0	26
124232	2020-08-23 08:02:46	2020-08-23	12	[{"id_menu":1,"count":1}]	28827	delivery	5	17
124233	2020-08-23 08:03:06	2020-08-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	47103	delivery	5	28
124234	2020-08-23 08:03:50	2020-08-23	9	[{"id_menu":7,"count":1}]	1511	pick-up	0	9
124235	2020-08-23 08:04:04	2020-08-23	8	[{"id_menu":5,"count":3}]	39756	delivery	5	13
124236	2020-08-23 08:04:09	2020-08-23	14	[{"id_menu":2,"count":1}]	24876	delivery	5	19
124237	2020-08-23 08:04:27	2020-08-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	47194	delivery	5	22
124238	2020-08-23 08:06:50	2020-08-23	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	25444	delivery	5	28
124239	2020-08-23 08:06:57	2020-08-23	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	47199	delivery	5	26
124240	2020-08-23 08:08:22	2020-08-23	8	[{"id_menu":5,"count":1}]	47108	delivery	5	13
124241	2020-08-23 08:08:25	2020-08-23	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	6885	pick-up	0	29
124242	2020-08-23 08:09:21	2020-08-23	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	46078	delivery	5	26
124243	2020-08-23 08:10:16	2020-08-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	47143	delivery	5	26
124244	2020-08-23 08:14:55	2020-08-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	36272	delivery	5	31
124245	2020-08-23 08:15:20	2020-08-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	37523	delivery	5	22
124246	2020-08-23 08:15:35	2020-08-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	47230	delivery	5	22
124247	2020-08-23 08:18:10	2020-08-23	14	[{"id_menu":2,"count":1}]	24155	delivery	5	19
124248	2020-08-23 08:18:41	2020-08-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3688	delivery	5	36
124249	2020-08-23 08:18:53	2020-08-23	14	[{"id_menu":2,"count":1}]	30618	pick-up	0	14
124250	2020-08-23 08:19:15	2020-08-23	9	[{"id_menu":7,"count":1}]	37071	delivery	5	14
124251	2020-08-23 08:19:46	2020-08-23	9	[{"id_menu":6,"count":1}]	47202	delivery	5	14
124252	2020-08-23 08:23:14	2020-08-23	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	47274	delivery	5	37
124253	2020-08-23 08:24:24	2020-08-23	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	23288	delivery	5	40
124254	2020-08-23 08:24:49	2020-08-23	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":3}]	33844	delivery	5	26
124255	2020-08-23 08:27:02	2020-08-23	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	47117	delivery	5	25
124256	2020-08-23 08:28:56	2020-08-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	28041	delivery	5	28
124257	2020-08-23 08:29:21	2020-08-23	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	8362	delivery	5	27
124258	2020-08-23 08:29:51	2020-08-23	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	31227	pick-up	0	48
124259	2020-08-23 08:30:37	2020-08-23	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19243	delivery	5	34
124260	2020-08-23 08:31:04	2020-08-23	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	41151	delivery	5	23
124261	2020-08-23 08:31:25	2020-08-23	17	[{"id_menu":4,"count":1}]	47159	delivery	5	22
124262	2020-08-23 08:32:29	2020-08-23	12	[{"id_menu":1,"count":1}]	10451	delivery	5	17
124263	2020-08-23 08:32:46	2020-08-23	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34806	delivery	5	45
124264	2020-08-23 08:34:33	2020-08-23	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	47152	delivery	5	23
124265	2020-08-23 08:35:27	2020-08-23	12	[{"id_menu":1,"count":1}]	11521	pick-up	0	12
124266	2020-08-23 08:36:23	2020-08-23	38	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	41753	delivery	5	43
124267	2020-08-23 08:36:26	2020-08-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	21967	delivery	5	31
124268	2020-08-23 08:37:51	2020-08-23	14	[{"id_menu":2,"count":1}]	35478	delivery	5	19
124269	2020-08-23 08:40:11	2020-08-23	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	15731	pick-up	0	35
124270	2020-08-23 08:40:34	2020-08-23	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	40652	delivery	5	36
124271	2020-08-23 08:40:59	2020-08-23	14	[{"id_menu":2,"count":1}]	3971	delivery	5	19
124272	2020-08-23 08:41:26	2020-08-23	17	[{"id_menu":4,"count":1}]	14735	delivery	5	22
124273	2020-08-23 08:42:22	2020-08-23	9	[{"id_menu":6,"count":1}]	28501	pick-up	0	9
124274	2020-08-23 08:42:52	2020-08-23	9	[{"id_menu":6,"count":2}]	36723	delivery	5	14
124275	2020-08-23 08:43:37	2020-08-23	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	6267	delivery	5	29
124276	2020-08-23 08:46:29	2020-08-23	14	[{"id_menu":2,"count":1}]	42719	pick-up	0	14
124277	2020-08-23 08:46:30	2020-08-23	9	[{"id_menu":7,"count":1}]	22938	delivery	5	14
124278	2020-08-23 08:46:35	2020-08-23	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	22311	delivery	5	26
124279	2020-08-23 08:47:27	2020-08-23	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	47297	delivery	5	52
124280	2020-08-23 08:48:41	2020-08-23	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	4775	delivery	5	39
124281	2020-08-23 08:49:11	2020-08-23	17	[{"id_menu":4,"count":1}]	47288	delivery	5	22
124282	2020-08-23 08:49:14	2020-08-23	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	22411	delivery	5	25
124283	2020-08-23 08:49:38	2020-08-23	9	[{"id_menu":6,"count":1}]	35690	delivery	5	14
124284	2020-08-23 08:51:33	2020-08-23	12	[{"id_menu":3,"count":1}]	36837	delivery	5	17
124285	2020-08-23 08:52:22	2020-08-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24300	delivery	5	22
124286	2020-08-23 08:56:20	2020-08-23	12	[{"id_menu":1,"count":1}]	47317	delivery	5	17
124287	2020-08-23 09:02:14	2020-08-23	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	47302	delivery	5	23
124288	2020-08-23 09:02:59	2020-08-23	9	[{"id_menu":6,"count":1}]	22319	delivery	5	14
124289	2020-08-23 09:03:57	2020-08-23	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	26773	delivery	5	31
124290	2020-08-23 09:05:57	2020-08-23	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15042	delivery	5	45
124291	2020-08-23 09:06:09	2020-08-23	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	47247	delivery	5	30
124292	2020-08-23 09:06:17	2020-08-23	12	[{"id_menu":3,"count":1}]	378	delivery	5	17
124293	2020-08-23 09:11:13	2020-08-23	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	32335	delivery	5	36
124294	2020-08-23 09:11:28	2020-08-23	14	[{"id_menu":2,"count":2}]	46493	pick-up	0	14
124295	2020-08-23 09:12:28	2020-08-23	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	42048	delivery	5	26
124296	2020-08-23 09:13:19	2020-08-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	5817	delivery	5	28
124297	2020-08-23 09:16:26	2020-08-23	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	42667	pick-up	0	21
124298	2020-08-23 09:16:31	2020-08-23	12	[{"id_menu":1,"count":1}]	40477	delivery	5	17
124299	2020-08-23 09:16:57	2020-08-23	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13327	delivery	5	43
124300	2020-08-23 09:17:09	2020-08-23	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	314	delivery	5	40
124301	2020-08-23 09:19:28	2020-08-23	9	[{"id_menu":6,"count":1}]	5811	pick-up	0	9
124302	2020-08-23 09:20:04	2020-08-23	12	[{"id_menu":3,"count":1}]	47289	pick-up	0	12
124303	2020-08-23 09:20:15	2020-08-23	9	[{"id_menu":6,"count":1}]	20182	delivery	5	14
124304	2020-08-23 09:20:46	2020-08-23	9	[{"id_menu":6,"count":1}]	6238	delivery	5	14
124305	2020-08-23 09:20:57	2020-08-23	9	[{"id_menu":6,"count":2}]	24320	delivery	5	14
124306	2020-08-23 09:21:41	2020-08-23	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9171	pick-up	0	29
124307	2020-08-23 09:22:21	2020-08-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	8538	delivery	5	28
124308	2020-08-23 09:22:58	2020-08-23	17	[{"id_menu":4,"count":1}]	47151	delivery	5	22
124309	2020-08-23 09:25:22	2020-08-23	9	[{"id_menu":6,"count":1}]	32649	pick-up	0	9
124310	2020-08-23 09:26:58	2020-08-23	17	[{"id_menu":4,"count":1}]	18157	delivery	5	22
124311	2020-08-23 09:28:35	2020-08-23	9	[{"id_menu":7,"count":1}]	17673	delivery	5	14
124312	2020-08-23 09:29:05	2020-08-23	9	[{"id_menu":7,"count":1}]	17534	delivery	5	14
124313	2020-08-23 09:31:13	2020-08-23	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	24535	delivery	5	31
124314	2020-08-23 09:35:06	2020-08-23	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	47139	delivery	5	26
124315	2020-08-23 09:35:30	2020-08-23	12	[{"id_menu":1,"count":1}]	47157	delivery	5	17
124316	2020-08-23 09:37:21	2020-08-23	9	[{"id_menu":6,"count":1}]	263	delivery	5	14
124317	2020-08-23 09:37:45	2020-08-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	698	delivery	5	26
124318	2020-08-23 09:40:16	2020-08-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	36310	pick-up	0	26
124319	2020-08-23 09:41:11	2020-08-23	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	47168	delivery	5	40
124320	2020-08-23 09:41:17	2020-08-23	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	47126	delivery	5	39
124321	2020-08-23 09:41:22	2020-08-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	33607	delivery	5	22
124322	2020-08-23 09:43:03	2020-08-23	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	9925	delivery	5	27
124323	2020-08-23 09:45:16	2020-08-23	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	38086	delivery	5	48
124324	2020-08-23 09:47:31	2020-08-23	14	[{"id_menu":2,"count":1}]	47154	delivery	5	19
124325	2020-08-23 09:48:09	2020-08-23	9	[{"id_menu":7,"count":1}]	47304	delivery	5	14
124326	2020-08-23 09:49:21	2020-08-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7717	delivery	5	31
124327	2020-08-23 09:49:41	2020-08-23	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	39447	delivery	5	25
124328	2020-08-23 09:49:41	2020-08-23	9	[{"id_menu":6,"count":1}]	3785	delivery	5	14
124329	2020-08-23 09:50:15	2020-08-23	9	[{"id_menu":6,"count":1}]	7647	delivery	5	14
124330	2020-08-23 09:50:21	2020-08-23	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7514	delivery	5	31
124331	2020-08-23 09:50:44	2020-08-23	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	47198	delivery	5	26
124332	2020-08-23 09:51:18	2020-08-23	12	[{"id_menu":1,"count":1}]	37812	delivery	5	17
124333	2020-08-23 09:52:19	2020-08-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	2443	delivery	5	31
124334	2020-08-23 09:55:55	2020-08-23	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	46173	delivery	5	37
124335	2020-08-23 10:00:30	2020-08-23	9	[{"id_menu":6,"count":2}]	33507	delivery	5	14
124336	2020-08-23 10:02:00	2020-08-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	46389	delivery	5	28
124337	2020-08-23 10:02:20	2020-08-23	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	43519	delivery	5	31
124338	2020-08-23 10:03:41	2020-08-23	12	[{"id_menu":3,"count":1}]	7582	pick-up	0	12
124339	2020-08-23 10:05:08	2020-08-23	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	34299	delivery	5	23
124340	2020-08-23 10:06:15	2020-08-23	9	[{"id_menu":6,"count":1}]	47260	delivery	5	14
124341	2020-08-23 10:07:42	2020-08-23	12	[{"id_menu":3,"count":1}]	37808	delivery	5	17
124342	2020-08-23 10:10:05	2020-08-23	17	[{"id_menu":4,"count":1}]	47134	delivery	5	22
124343	2020-08-23 10:12:03	2020-08-23	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	2187	pick-up	0	18
124344	2020-08-23 10:12:48	2020-08-23	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	47160	delivery	5	26
124345	2020-08-23 10:12:54	2020-08-23	17	[{"id_menu":4,"count":1}]	47306	delivery	5	22
124346	2020-08-23 10:13:33	2020-08-23	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	47248	delivery	5	36
124347	2020-08-23 10:14:06	2020-08-23	9	[{"id_menu":6,"count":1}]	28797	delivery	5	14
124348	2020-08-23 10:15:33	2020-08-23	9	[{"id_menu":6,"count":1}]	42714	pick-up	0	9
124349	2020-08-23 10:15:39	2020-08-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	47211	pick-up	0	26
124350	2020-08-23 10:17:17	2020-08-23	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	47266	delivery	5	37
124351	2020-08-23 10:19:07	2020-08-23	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15005	delivery	5	31
124352	2020-08-23 10:21:31	2020-08-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	47112	pick-up	0	17
124353	2020-08-23 10:25:08	2020-08-23	14	[{"id_menu":2,"count":1}]	37176	pick-up	0	14
124354	2020-08-23 10:26:05	2020-08-23	12	[{"id_menu":1,"count":1}]	36726	delivery	5	17
124355	2020-08-23 10:29:45	2020-08-23	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	31573	delivery	5	26
124356	2020-08-23 10:30:59	2020-08-23	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	3351	delivery	5	35
124357	2020-08-23 10:31:57	2020-08-23	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	22689	delivery	5	25
124358	2020-08-23 10:32:53	2020-08-23	9	[{"id_menu":7,"count":1}]	22829	delivery	5	14
124359	2020-08-23 10:33:07	2020-08-23	12	[{"id_menu":3,"count":2}]	47226	delivery	5	17
124360	2020-08-23 10:33:09	2020-08-23	9	[{"id_menu":7,"count":1}]	13062	pick-up	0	9
124361	2020-08-23 10:35:51	2020-08-23	9	[{"id_menu":6,"count":1}]	47212	delivery	5	14
124362	2020-08-23 10:37:44	2020-08-23	38	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	29017	delivery	5	43
124363	2020-08-23 10:38:25	2020-08-23	12	[{"id_menu":3,"count":1}]	17116	delivery	5	17
124364	2020-08-23 10:41:11	2020-08-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	11882	delivery	5	23
124365	2020-08-23 10:41:46	2020-08-23	9	[{"id_menu":7,"count":1}]	47067	delivery	5	14
124366	2020-08-23 10:43:12	2020-08-23	9	[{"id_menu":7,"count":1}]	12463	pick-up	0	9
124367	2020-08-23 10:45:06	2020-08-23	8	[{"id_menu":5,"count":1}]	3996	delivery	5	13
124368	2020-08-23 10:45:57	2020-08-23	9	[{"id_menu":6,"count":1}]	45790	delivery	5	14
124369	2020-08-23 10:46:54	2020-08-23	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	31939	delivery	5	25
124370	2020-08-23 10:48:06	2020-08-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41626	pick-up	0	18
124371	2020-08-23 10:48:32	2020-08-23	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	47133	delivery	5	26
124372	2020-08-23 10:49:05	2020-08-23	17	[{"id_menu":4,"count":1}]	9358	delivery	5	22
124373	2020-08-23 10:51:36	2020-08-23	17	[{"id_menu":4,"count":1}]	47204	pick-up	0	17
124374	2020-08-23 10:52:46	2020-08-23	9	[{"id_menu":7,"count":1}]	30115	delivery	5	14
124375	2020-08-23 10:54:31	2020-08-23	9	[{"id_menu":7,"count":1}]	47128	delivery	5	14
124376	2020-08-23 10:58:12	2020-08-23	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	30376	delivery	5	31
124377	2020-08-23 10:58:48	2020-08-23	9	[{"id_menu":7,"count":1}]	34861	delivery	5	14
124378	2020-08-23 11:00:43	2020-08-23	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12841	delivery	5	36
124379	2020-08-23 11:02:29	2020-08-23	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	30382	delivery	5	29
124380	2020-08-23 11:02:54	2020-08-23	12	[{"id_menu":1,"count":1}]	47263	delivery	5	17
124381	2020-08-23 11:03:57	2020-08-23	12	[{"id_menu":1,"count":1}]	42491	pick-up	0	12
124382	2020-08-23 11:07:46	2020-08-23	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4354	delivery	5	27
124383	2020-08-23 11:08:35	2020-08-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	25572	delivery	5	28
124384	2020-08-23 11:11:24	2020-08-23	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	17867	delivery	5	44
124385	2020-08-23 11:12:13	2020-08-23	9	[{"id_menu":7,"count":1}]	47315	pick-up	0	9
124386	2020-08-23 11:13:01	2020-08-23	9	[{"id_menu":7,"count":1}]	4688	delivery	5	14
124387	2020-08-23 11:13:05	2020-08-23	17	[{"id_menu":4,"count":1}]	1624	pick-up	0	17
124388	2020-08-23 11:13:17	2020-08-23	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	13313	delivery	5	39
124389	2020-08-23 11:15:16	2020-08-23	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13344	delivery	5	34
124390	2020-08-23 11:16:10	2020-08-23	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24271	delivery	5	34
124391	2020-08-23 11:16:48	2020-08-23	9	[{"id_menu":7,"count":1}]	33716	delivery	5	14
124392	2020-08-23 11:18:27	2020-08-23	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	41170	delivery	5	34
124393	2020-08-23 11:19:31	2020-08-23	9	[{"id_menu":6,"count":1}]	2050	pick-up	0	9
124394	2020-08-23 11:19:53	2020-08-23	8	[{"id_menu":5,"count":1}]	40774	delivery	5	13
124395	2020-08-23 11:26:22	2020-08-23	12	[{"id_menu":3,"count":1}]	754	delivery	5	17
124396	2020-08-23 11:26:52	2020-08-23	8	[{"id_menu":5,"count":2}]	38634	delivery	5	13
124397	2020-08-23 11:26:57	2020-08-23	9	[{"id_menu":6,"count":1}]	2780	pick-up	0	9
124398	2020-08-23 11:27:41	2020-08-23	12	[{"id_menu":1,"count":1}]	47144	pick-up	0	12
124399	2020-08-23 11:28:35	2020-08-23	17	[{"id_menu":4,"count":1}]	43539	pick-up	0	17
124400	2020-08-23 11:29:28	2020-08-23	14	[{"id_menu":2,"count":1}]	34743	delivery	5	19
124401	2020-08-23 11:31:12	2020-08-23	8	[{"id_menu":5,"count":1}]	23739	delivery	5	13
124402	2020-08-23 11:31:32	2020-08-23	12	[{"id_menu":3,"count":1}]	47068	delivery	5	17
124403	2020-08-23 11:33:02	2020-08-23	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	38731	delivery	5	40
124404	2020-08-23 11:33:03	2020-08-23	12	[{"id_menu":1,"count":1}]	39996	pick-up	0	12
124405	2020-08-23 11:33:59	2020-08-23	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44038	delivery	5	45
124406	2020-08-23 11:34:45	2020-08-23	8	[{"id_menu":5,"count":1}]	27604	delivery	5	13
124407	2020-08-23 11:36:54	2020-08-23	17	[{"id_menu":4,"count":1}]	6010	delivery	5	22
124408	2020-08-23 11:37:11	2020-08-23	8	[{"id_menu":5,"count":2}]	30991	delivery	5	13
124409	2020-08-23 11:37:55	2020-08-23	8	[{"id_menu":5,"count":2}]	18755	delivery	5	13
124410	2020-08-23 11:39:35	2020-08-23	12	[{"id_menu":3,"count":1}]	29845	delivery	5	17
124411	2020-08-23 11:42:44	2020-08-23	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	38431	delivery	5	31
124412	2020-08-23 11:45:37	2020-08-23	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	47254	pick-up	0	25
124413	2020-08-23 11:45:45	2020-08-23	12	[{"id_menu":3,"count":1}]	41246	delivery	5	17
124414	2020-08-23 11:47:16	2020-08-23	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	10706	pick-up	0	26
124415	2020-08-23 11:49:48	2020-08-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7527	pick-up	0	26
124416	2020-08-23 11:50:14	2020-08-23	17	[{"id_menu":4,"count":1}]	47186	delivery	5	22
124417	2020-08-23 11:52:01	2020-08-23	9	[{"id_menu":6,"count":1}]	33432	delivery	5	14
124418	2020-08-23 11:53:45	2020-08-23	17	[{"id_menu":4,"count":1}]	15048	pick-up	0	17
124419	2020-08-23 11:54:27	2020-08-23	14	[{"id_menu":2,"count":1}]	27161	pick-up	0	14
124420	2020-08-23 11:55:22	2020-08-23	14	[{"id_menu":2,"count":1}]	47244	pick-up	0	14
124421	2020-08-23 11:56:36	2020-08-23	14	[{"id_menu":2,"count":1}]	44753	delivery	5	19
124422	2020-08-23 11:58:00	2020-08-23	14	[{"id_menu":2,"count":1}]	17491	pick-up	0	14
124423	2020-08-23 11:58:06	2020-08-23	12	[{"id_menu":1,"count":1}]	47091	delivery	5	17
124424	2020-08-23 11:59:30	2020-08-23	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	30496	pick-up	0	21
124425	2020-08-23 12:00:11	2020-08-23	9	[{"id_menu":7,"count":1}]	40574	delivery	5	14
124426	2020-08-23 12:00:21	2020-08-23	8	[{"id_menu":5,"count":1}]	47308	pick-up	0	8
124427	2020-08-23 12:00:23	2020-08-23	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	14826	delivery	5	28
124428	2020-08-23 12:01:44	2020-08-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	1064	pick-up	0	23
124429	2020-08-23 12:02:31	2020-08-23	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5692	pick-up	0	30
124430	2020-08-23 12:03:14	2020-08-23	12	[{"id_menu":3,"count":1}]	26602	delivery	5	17
124431	2020-08-23 12:03:23	2020-08-23	9	[{"id_menu":7,"count":1}]	33267	delivery	5	14
124432	2020-08-23 12:05:13	2020-08-23	12	[{"id_menu":3,"count":1}]	13155	delivery	5	17
124433	2020-08-23 12:08:47	2020-08-23	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	47138	delivery	5	57
124434	2020-08-23 12:10:40	2020-08-23	12	[{"id_menu":1,"count":1}]	2951	delivery	5	17
124435	2020-08-23 12:11:35	2020-08-23	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	21068	delivery	5	30
124436	2020-08-23 12:12:09	2020-08-23	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27380	delivery	5	40
124437	2020-08-23 12:13:17	2020-08-23	34	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	3403	pick-up	0	34
124438	2020-08-23 12:15:59	2020-08-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	22363	delivery	5	31
124439	2020-08-23 12:17:25	2020-08-23	9	[{"id_menu":6,"count":1}]	47063	delivery	5	14
124440	2020-08-23 12:17:43	2020-08-23	9	[{"id_menu":6,"count":1}]	47098	delivery	5	14
124441	2020-08-23 12:18:30	2020-08-23	14	[{"id_menu":2,"count":1}]	13662	pick-up	0	14
124442	2020-08-23 12:21:47	2020-08-23	12	[{"id_menu":1,"count":1}]	437	delivery	5	17
124443	2020-08-23 12:22:00	2020-08-23	9	[{"id_menu":6,"count":1}]	14412	delivery	5	14
124444	2020-08-23 12:23:31	2020-08-23	9	[{"id_menu":7,"count":1}]	47207	delivery	5	14
124445	2020-08-23 12:25:25	2020-08-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	47127	delivery	5	31
124446	2020-08-23 12:25:50	2020-08-23	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	5240	delivery	5	25
124447	2020-08-23 12:28:21	2020-08-23	14	[{"id_menu":2,"count":1}]	459	delivery	5	19
124448	2020-08-23 12:28:33	2020-08-23	12	[{"id_menu":1,"count":1}]	14523	delivery	5	17
124449	2020-08-23 12:29:09	2020-08-23	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	20294	delivery	5	39
124450	2020-08-23 12:32:12	2020-08-23	14	[{"id_menu":2,"count":1}]	42756	delivery	5	19
124451	2020-08-23 12:33:22	2020-08-23	12	[{"id_menu":3,"count":1}]	32325	delivery	5	17
124452	2020-08-23 12:35:40	2020-08-23	9	[{"id_menu":7,"count":1}]	7898	pick-up	0	9
124453	2020-08-23 12:36:44	2020-08-23	12	[{"id_menu":3,"count":1}]	7313	pick-up	0	12
124454	2020-08-23 12:41:09	2020-08-23	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	30197	delivery	5	28
124455	2020-08-23 12:41:17	2020-08-23	9	[{"id_menu":6,"count":1}]	29836	delivery	5	14
124456	2020-08-23 12:44:32	2020-08-23	9	[{"id_menu":7,"count":1}]	15855	delivery	5	14
124457	2020-08-23 12:44:37	2020-08-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	12386	pick-up	0	31
124458	2020-08-23 12:46:15	2020-08-23	9	[{"id_menu":6,"count":1}]	17707	delivery	5	14
124459	2020-08-23 12:46:24	2020-08-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	47309	delivery	5	31
124460	2020-08-23 12:49:28	2020-08-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	47241	delivery	5	31
124461	2020-08-23 12:52:19	2020-08-23	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	19052	pick-up	0	21
124462	2020-08-23 12:52:23	2020-08-23	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	36908	delivery	5	28
124463	2020-08-23 12:54:04	2020-08-23	9	[{"id_menu":6,"count":1}]	27297	delivery	5	14
124464	2020-08-23 12:55:02	2020-08-23	9	[{"id_menu":6,"count":1}]	351	pick-up	0	9
124465	2020-08-23 12:56:54	2020-08-23	14	[{"id_menu":2,"count":1}]	46444	delivery	5	19
124466	2020-08-23 12:57:28	2020-08-23	14	[{"id_menu":2,"count":1}]	26994	delivery	5	19
124467	2020-08-23 12:58:34	2020-08-23	17	[{"id_menu":4,"count":1}]	6021	delivery	5	22
124468	2020-08-23 12:59:29	2020-08-23	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12434	delivery	5	31
124469	2020-08-23 13:00:31	2020-08-23	9	[{"id_menu":6,"count":1}]	360	pick-up	0	9
124470	2020-08-23 13:01:15	2020-08-23	14	[{"id_menu":2,"count":1}]	45672	pick-up	0	14
124471	2020-08-23 13:02:33	2020-08-23	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13156	delivery	5	34
124472	2020-08-23 13:05:57	2020-08-23	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	36002	delivery	5	34
124473	2020-08-23 13:11:57	2020-08-23	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	46522	delivery	5	36
124474	2020-08-23 13:14:29	2020-08-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	47282	delivery	5	22
124475	2020-08-23 13:18:07	2020-08-23	9	[{"id_menu":6,"count":1}]	16512	delivery	5	14
124476	2020-08-23 13:18:42	2020-08-23	9	[{"id_menu":7,"count":1}]	44396	delivery	5	14
124477	2020-08-23 13:18:56	2020-08-23	8	[{"id_menu":5,"count":1}]	15798	pick-up	0	8
124478	2020-08-23 13:19:50	2020-08-23	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	47099	delivery	5	23
124479	2020-08-23 13:21:43	2020-08-23	8	[{"id_menu":5,"count":1}]	26717	delivery	5	13
124480	2020-08-23 13:22:03	2020-08-23	12	[{"id_menu":1,"count":1}]	47235	delivery	5	17
124481	2020-08-23 13:23:53	2020-08-23	43	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	47190	delivery	5	48
124482	2020-08-23 13:24:16	2020-08-23	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	19907	delivery	5	40
124549	2020-08-23 14:44:44	2020-08-23	14	[{"id_menu":2,"count":1}]	29689	delivery	5	19
124483	2020-08-23 13:24:27	2020-08-23	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	40630	delivery	5	37
124484	2020-08-23 13:24:34	2020-08-23	8	[{"id_menu":5,"count":1}]	19776	pick-up	0	8
124485	2020-08-23 13:25:03	2020-08-23	17	[{"id_menu":4,"count":1}]	21270	delivery	5	22
124486	2020-08-23 13:25:42	2020-08-23	9	[{"id_menu":7,"count":3}]	40015	delivery	5	14
124487	2020-08-23 13:25:43	2020-08-23	12	[{"id_menu":3,"count":1}]	40583	delivery	5	17
124488	2020-08-23 13:26:16	2020-08-23	9	[{"id_menu":6,"count":1}]	9371	delivery	5	14
124489	2020-08-23 13:28:24	2020-08-23	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	34041	delivery	5	34
124490	2020-08-23 13:29:11	2020-08-23	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	46185	delivery	5	23
124491	2020-08-23 13:29:22	2020-08-23	12	[{"id_menu":1,"count":1}]	47318	delivery	5	17
124492	2020-08-23 13:31:19	2020-08-23	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	47084	delivery	5	40
124493	2020-08-23 13:31:53	2020-08-23	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	23956	delivery	5	26
124494	2020-08-23 13:32:43	2020-08-23	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9621	delivery	5	36
124495	2020-08-23 13:33:55	2020-08-23	14	[{"id_menu":2,"count":1}]	47237	delivery	5	19
124496	2020-08-23 13:35:46	2020-08-23	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	38169	delivery	5	30
124497	2020-08-23 13:36:28	2020-08-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	34297	delivery	5	22
124498	2020-08-23 13:38:16	2020-08-23	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	21003	delivery	5	37
124499	2020-08-23 13:41:45	2020-08-23	37	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	24556	delivery	5	42
124500	2020-08-23 13:42:36	2020-08-23	8	[{"id_menu":5,"count":1}]	135	pick-up	0	8
124501	2020-08-23 13:44:19	2020-08-23	12	[{"id_menu":1,"count":1}]	47303	delivery	5	17
124502	2020-08-23 13:47:35	2020-08-23	14	[{"id_menu":2,"count":1}]	3363	delivery	5	19
124503	2020-08-23 13:50:35	2020-08-23	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	16136	delivery	5	36
124504	2020-08-23 13:52:25	2020-08-23	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	40731	delivery	5	27
124505	2020-08-23 13:53:06	2020-08-23	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	22752	delivery	5	27
124506	2020-08-23 13:53:08	2020-08-23	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	47293	delivery	5	22
124507	2020-08-23 13:54:47	2020-08-23	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	26241	delivery	5	26
124508	2020-08-23 13:56:03	2020-08-23	12	[{"id_menu":3,"count":1}]	47245	delivery	5	17
124509	2020-08-23 13:58:35	2020-08-23	12	[{"id_menu":1,"count":2}]	43476	delivery	5	17
124510	2020-08-23 13:59:50	2020-08-23	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	7026	delivery	5	30
124511	2020-08-23 14:00:46	2020-08-23	12	[{"id_menu":3,"count":1}]	38956	delivery	5	17
124512	2020-08-23 14:00:47	2020-08-23	14	[{"id_menu":2,"count":1}]	45995	pick-up	0	14
124513	2020-08-23 14:00:49	2020-08-23	17	[{"id_menu":4,"count":1}]	30629	delivery	5	22
124514	2020-08-23 14:01:51	2020-08-23	9	[{"id_menu":7,"count":1}]	396	pick-up	0	9
124515	2020-08-23 14:03:36	2020-08-23	9	[{"id_menu":6,"count":2}]	24402	pick-up	0	9
124516	2020-08-23 14:03:38	2020-08-23	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	24033	delivery	5	43
124517	2020-08-23 14:05:36	2020-08-23	14	[{"id_menu":2,"count":2}]	23007	pick-up	0	14
124518	2020-08-23 14:05:52	2020-08-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3238	delivery	5	28
124519	2020-08-23 14:06:14	2020-08-23	9	[{"id_menu":7,"count":1}]	37868	delivery	5	14
124520	2020-08-23 14:08:20	2020-08-23	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	44618	delivery	5	31
124521	2020-08-23 14:08:48	2020-08-23	9	[{"id_menu":7,"count":1}]	5012	delivery	5	14
124522	2020-08-23 14:09:52	2020-08-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	32970	delivery	5	28
124523	2020-08-23 14:10:09	2020-08-23	9	[{"id_menu":6,"count":1}]	2373	delivery	5	14
124524	2020-08-23 14:13:27	2020-08-23	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	37824	delivery	5	30
124525	2020-08-23 14:14:10	2020-08-23	9	[{"id_menu":6,"count":1}]	42341	pick-up	0	9
124526	2020-08-23 14:14:16	2020-08-23	9	[{"id_menu":6,"count":1}]	33000	delivery	5	14
124527	2020-08-23 14:15:31	2020-08-23	17	[{"id_menu":4,"count":1}]	35287	delivery	5	22
124528	2020-08-23 14:15:51	2020-08-23	9	[{"id_menu":6,"count":1}]	38417	pick-up	0	9
124529	2020-08-23 14:16:05	2020-08-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	4870	pick-up	0	21
124530	2020-08-23 14:18:25	2020-08-23	9	[{"id_menu":6,"count":1}]	47290	delivery	5	14
124531	2020-08-23 14:20:15	2020-08-23	9	[{"id_menu":7,"count":1}]	26027	delivery	5	14
124532	2020-08-23 14:21:59	2020-08-23	9	[{"id_menu":7,"count":1}]	4836	delivery	5	14
124533	2020-08-23 14:23:04	2020-08-23	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	12776	delivery	5	25
124534	2020-08-23 14:24:37	2020-08-23	9	[{"id_menu":6,"count":1}]	28192	delivery	5	14
124535	2020-08-23 14:24:49	2020-08-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	38370	pick-up	0	17
124536	2020-08-23 14:26:46	2020-08-23	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	3817	pick-up	0	24
124537	2020-08-23 14:27:48	2020-08-23	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	15350	delivery	5	25
124538	2020-08-23 14:28:07	2020-08-23	9	[{"id_menu":6,"count":1}]	9	pick-up	0	9
124539	2020-08-23 14:33:35	2020-08-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	29839	delivery	5	23
124540	2020-08-23 14:33:59	2020-08-23	12	[{"id_menu":3,"count":1}]	47166	pick-up	0	12
124541	2020-08-23 14:34:25	2020-08-23	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	22259	delivery	5	34
124542	2020-08-23 14:35:25	2020-08-23	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	39636	delivery	5	39
124543	2020-08-23 14:36:09	2020-08-23	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	33662	delivery	5	40
124544	2020-08-23 14:37:25	2020-08-23	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	39257	delivery	5	40
124545	2020-08-23 14:38:55	2020-08-23	9	[{"id_menu":7,"count":1}]	2639	delivery	5	14
124546	2020-08-23 14:42:20	2020-08-23	12	[{"id_menu":3,"count":2}]	40180	delivery	5	17
124547	2020-08-23 14:42:21	2020-08-23	9	[{"id_menu":6,"count":1}]	46587	delivery	5	14
124548	2020-08-23 14:42:27	2020-08-23	9	[{"id_menu":7,"count":1}]	10561	delivery	5	14
124550	2020-08-23 14:45:07	2020-08-23	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	33682	delivery	5	43
124551	2020-08-23 14:46:21	2020-08-23	14	[{"id_menu":2,"count":1}]	1820	delivery	5	19
124552	2020-08-23 14:49:07	2020-08-23	8	[{"id_menu":5,"count":1}]	10254	delivery	5	13
124553	2020-08-23 14:50:55	2020-08-23	9	[{"id_menu":6,"count":1}]	8798	delivery	5	14
124554	2020-08-23 14:51:37	2020-08-23	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	30089	delivery	5	48
124555	2020-08-23 14:51:48	2020-08-23	14	[{"id_menu":2,"count":1}]	16485	pick-up	0	14
124556	2020-08-23 14:55:04	2020-08-23	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	21659	delivery	5	43
124557	2020-08-23 14:55:22	2020-08-23	12	[{"id_menu":3,"count":1}]	30037	delivery	5	17
124558	2020-08-23 14:55:34	2020-08-23	17	[{"id_menu":4,"count":1}]	47101	delivery	5	22
124559	2020-08-23 14:55:42	2020-08-23	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	14161	delivery	5	35
124560	2020-08-23 14:59:34	2020-08-23	9	[{"id_menu":6,"count":1}]	47137	delivery	5	14
124561	2020-08-23 15:02:07	2020-08-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8748	delivery	5	22
124562	2020-08-23 15:04:43	2020-08-23	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	18353	delivery	5	34
124563	2020-08-23 15:05:09	2020-08-23	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	47187	delivery	5	48
124564	2020-08-23 15:05:20	2020-08-23	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	3260	pick-up	0	34
124565	2020-08-23 15:05:58	2020-08-23	12	[{"id_menu":1,"count":1}]	4465	delivery	5	17
124566	2020-08-23 15:06:57	2020-08-23	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	248	pick-up	0	22
124567	2020-08-23 15:07:01	2020-08-23	9	[{"id_menu":6,"count":1}]	24323	delivery	5	14
124568	2020-08-23 15:08:52	2020-08-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	31850	delivery	5	28
124569	2020-08-23 15:09:39	2020-08-23	14	[{"id_menu":2,"count":2}]	26543	delivery	5	19
124570	2020-08-23 15:09:51	2020-08-23	9	[{"id_menu":7,"count":1}]	9125	pick-up	0	9
124571	2020-08-23 15:10:43	2020-08-23	12	[{"id_menu":1,"count":1}]	4081	pick-up	0	12
124572	2020-08-23 15:14:02	2020-08-23	9	[{"id_menu":7,"count":1}]	12989	delivery	5	14
124573	2020-08-23 15:14:08	2020-08-23	8	[{"id_menu":5,"count":1}]	47231	delivery	5	13
124574	2020-08-23 15:14:28	2020-08-23	8	[{"id_menu":5,"count":1}]	3509	pick-up	0	8
124575	2020-08-23 15:18:01	2020-08-23	9	[{"id_menu":6,"count":1}]	7431	delivery	5	14
124576	2020-08-23 15:21:09	2020-08-23	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	62	pick-up	0	29
124577	2020-08-23 15:21:32	2020-08-23	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	15501	delivery	5	40
124578	2020-08-23 15:22:11	2020-08-23	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	47219	delivery	5	34
124579	2020-08-23 15:23:11	2020-08-23	14	[{"id_menu":2,"count":1}]	33446	pick-up	0	14
124580	2020-08-23 15:23:48	2020-08-23	9	[{"id_menu":6,"count":1}]	44610	delivery	5	14
124581	2020-08-23 15:24:06	2020-08-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	33801	delivery	5	22
124582	2020-08-23 15:25:25	2020-08-23	8	[{"id_menu":5,"count":1}]	47183	delivery	5	13
124583	2020-08-23 15:25:46	2020-08-23	9	[{"id_menu":6,"count":1}]	47284	delivery	5	14
124584	2020-08-23 15:30:26	2020-08-23	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12707	delivery	5	31
124585	2020-08-23 15:30:27	2020-08-23	12	[{"id_menu":1,"count":1}]	35607	delivery	5	17
124586	2020-08-23 15:31:47	2020-08-23	9	[{"id_menu":7,"count":1}]	11150	delivery	5	14
124587	2020-08-23 15:32:43	2020-08-23	12	[{"id_menu":1,"count":1}]	23331	delivery	5	17
124588	2020-08-23 15:33:41	2020-08-23	9	[{"id_menu":6,"count":1}]	2367	pick-up	0	9
124589	2020-08-23 15:34:17	2020-08-23	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	8680	delivery	5	27
124590	2020-08-23 15:34:39	2020-08-23	14	[{"id_menu":2,"count":2}]	19197	delivery	5	19
124591	2020-08-23 15:34:56	2020-08-23	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	47147	delivery	5	34
124592	2020-08-23 15:36:55	2020-08-23	14	[{"id_menu":2,"count":1}]	47171	delivery	5	19
124593	2020-08-23 15:37:22	2020-08-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":3}]	9569	delivery	5	28
124594	2020-08-23 15:39:08	2020-08-23	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":3}]	47250	delivery	5	26
124595	2020-08-23 15:40:54	2020-08-23	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	15827	pick-up	0	21
124596	2020-08-23 15:43:03	2020-08-23	9	[{"id_menu":7,"count":1}]	12670	delivery	5	14
124597	2020-08-23 15:43:25	2020-08-23	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	47156	delivery	5	26
124598	2020-08-23 15:45:14	2020-08-23	14	[{"id_menu":2,"count":1}]	47243	delivery	5	19
124599	2020-08-23 15:46:26	2020-08-23	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33998	delivery	5	52
124600	2020-08-23 15:48:01	2020-08-23	8	[{"id_menu":5,"count":1}]	30733	delivery	5	13
124601	2020-08-23 15:48:07	2020-08-23	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1489	pick-up	0	21
124602	2020-08-23 15:48:59	2020-08-23	9	[{"id_menu":6,"count":1}]	36468	delivery	5	14
124603	2020-08-23 15:49:28	2020-08-23	12	[{"id_menu":1,"count":1}]	27076	delivery	5	17
124604	2020-08-23 15:50:58	2020-08-23	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	47213	delivery	5	43
124605	2020-08-23 15:51:50	2020-08-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	22790	delivery	5	28
124606	2020-08-23 15:52:19	2020-08-23	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19720	delivery	5	43
124607	2020-08-23 15:54:04	2020-08-23	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	47169	delivery	5	34
124608	2020-08-23 15:55:11	2020-08-23	12	[{"id_menu":1,"count":1}]	10722	delivery	5	17
124609	2020-08-23 15:55:43	2020-08-23	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	42751	delivery	5	31
124610	2020-08-23 15:59:45	2020-08-23	12	[{"id_menu":3,"count":1}]	11295	delivery	5	17
124611	2020-08-23 16:00:28	2020-08-23	12	[{"id_menu":1,"count":1}]	47164	delivery	5	17
124612	2020-08-23 16:01:05	2020-08-23	14	[{"id_menu":2,"count":1}]	5555	pick-up	0	14
124613	2020-08-23 16:01:16	2020-08-23	9	[{"id_menu":7,"count":1}]	6976	delivery	5	14
124614	2020-08-23 16:02:07	2020-08-23	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	24974	delivery	5	25
124615	2020-08-23 16:03:18	2020-08-23	17	[{"id_menu":4,"count":2}]	3784	delivery	5	22
124616	2020-08-23 16:03:26	2020-08-23	9	[{"id_menu":7,"count":2}]	45770	pick-up	0	9
124617	2020-08-23 16:04:26	2020-08-23	8	[{"id_menu":5,"count":1}]	47256	delivery	5	13
124618	2020-08-23 16:04:56	2020-08-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	47086	delivery	5	31
124619	2020-08-23 16:07:03	2020-08-23	17	[{"id_menu":4,"count":1}]	43310	delivery	5	22
124620	2020-08-23 16:09:23	2020-08-23	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	47267	delivery	5	26
124621	2020-08-23 16:12:55	2020-08-23	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15065	delivery	5	57
124622	2020-08-23 16:14:32	2020-08-23	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	3883	delivery	5	28
124623	2020-08-23 16:14:56	2020-08-23	12	[{"id_menu":1,"count":1}]	47162	delivery	5	17
124624	2020-08-23 16:15:32	2020-08-23	9	[{"id_menu":7,"count":1}]	275	pick-up	0	9
124625	2020-08-23 16:17:17	2020-08-23	8	[{"id_menu":5,"count":1}]	25276	pick-up	0	8
124626	2020-08-23 16:17:42	2020-08-23	12	[{"id_menu":1,"count":1}]	38537	delivery	5	17
124627	2020-08-23 16:19:32	2020-08-23	8	[{"id_menu":5,"count":1}]	47148	delivery	5	13
124628	2020-08-23 16:19:36	2020-08-23	9	[{"id_menu":7,"count":1}]	28700	delivery	5	14
124629	2020-08-23 16:22:56	2020-08-23	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	47270	delivery	5	31
124630	2020-08-23 16:23:23	2020-08-23	17	[{"id_menu":4,"count":1}]	21334	pick-up	0	17
124631	2020-08-23 16:23:29	2020-08-23	14	[{"id_menu":2,"count":1}]	42131	delivery	5	19
124632	2020-08-23 16:24:25	2020-08-23	14	[{"id_menu":2,"count":1}]	2993	delivery	5	19
124633	2020-08-23 16:25:16	2020-08-23	9	[{"id_menu":6,"count":1}]	43554	delivery	5	14
124634	2020-08-23 16:25:23	2020-08-23	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	32571	delivery	5	39
124635	2020-08-23 16:26:21	2020-08-23	12	[{"id_menu":3,"count":1}]	10122	delivery	5	17
124636	2020-08-23 16:27:49	2020-08-23	12	[{"id_menu":1,"count":1}]	33831	delivery	5	17
124637	2020-08-23 16:29:55	2020-08-23	17	[{"id_menu":4,"count":1}]	47185	delivery	5	22
124638	2020-08-23 16:30:45	2020-08-23	9	[{"id_menu":6,"count":2}]	11857	delivery	5	14
124639	2020-08-23 16:31:49	2020-08-23	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7691	pick-up	0	38
124640	2020-08-23 16:33:12	2020-08-23	9	[{"id_menu":6,"count":1}]	40945	pick-up	0	9
124641	2020-08-23 16:33:14	2020-08-23	12	[{"id_menu":1,"count":1}]	33427	pick-up	0	12
124642	2020-08-23 16:33:18	2020-08-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30275	pick-up	0	18
124643	2020-08-23 16:33:30	2020-08-23	17	[{"id_menu":4,"count":1}]	13930	pick-up	0	17
124644	2020-08-23 16:34:02	2020-08-23	9	[{"id_menu":7,"count":1}]	44191	delivery	5	14
124645	2020-08-23 16:35:13	2020-08-23	8	[{"id_menu":5,"count":1}]	12912	pick-up	0	8
124646	2020-08-23 16:36:43	2020-08-23	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8433	delivery	5	55
124647	2020-08-23 16:38:28	2020-08-23	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	47081	delivery	5	34
124648	2020-08-23 16:42:16	2020-08-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	10787	delivery	5	28
124649	2020-08-23 16:42:52	2020-08-23	12	[{"id_menu":3,"count":1}]	47206	delivery	5	17
124650	2020-08-23 16:43:58	2020-08-23	9	[{"id_menu":7,"count":1}]	30185	delivery	5	14
124651	2020-08-23 16:46:34	2020-08-23	8	[{"id_menu":5,"count":1}]	13987	delivery	5	13
124652	2020-08-23 16:47:11	2020-08-23	12	[{"id_menu":3,"count":1}]	10880	delivery	5	17
124653	2020-08-23 16:48:12	2020-08-23	9	[{"id_menu":6,"count":1}]	47136	delivery	5	14
124654	2020-08-23 16:54:07	2020-08-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	20931	delivery	5	28
124655	2020-08-23 16:55:49	2020-08-23	12	[{"id_menu":1,"count":1}]	47075	delivery	5	17
124656	2020-08-23 16:55:55	2020-08-23	9	[{"id_menu":6,"count":1}]	14011	delivery	5	14
124657	2020-08-23 17:00:31	2020-08-23	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	19957	pick-up	0	20
124658	2020-08-23 17:01:06	2020-08-23	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	45543	delivery	5	42
124659	2020-08-23 17:01:55	2020-08-23	9	[{"id_menu":6,"count":1}]	46459	delivery	5	14
124660	2020-08-23 17:02:52	2020-08-23	9	[{"id_menu":6,"count":1}]	47298	delivery	5	14
124661	2020-08-23 17:03:55	2020-08-23	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	42179	delivery	5	26
124662	2020-08-23 17:04:02	2020-08-23	14	[{"id_menu":2,"count":1}]	27709	delivery	5	19
124663	2020-08-23 17:06:53	2020-08-23	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	37631	delivery	5	43
124664	2020-08-23 17:07:13	2020-08-23	8	[{"id_menu":5,"count":1}]	13968	delivery	5	13
124665	2020-08-23 17:07:44	2020-08-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24144	delivery	5	22
124666	2020-08-23 17:08:12	2020-08-23	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27524	delivery	5	35
124667	2020-08-23 17:09:47	2020-08-23	14	[{"id_menu":2,"count":2}]	4453	delivery	5	19
124668	2020-08-23 17:10:09	2020-08-23	9	[{"id_menu":7,"count":1}]	39790	delivery	5	14
124669	2020-08-23 17:10:13	2020-08-23	8	[{"id_menu":5,"count":1}]	2109	delivery	5	13
124670	2020-08-23 17:10:47	2020-08-23	9	[{"id_menu":7,"count":1}]	39096	delivery	5	14
124671	2020-08-23 17:11:37	2020-08-23	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	47176	delivery	5	34
124672	2020-08-23 17:11:56	2020-08-23	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16025	delivery	5	22
124673	2020-08-23 17:13:16	2020-08-23	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	42098	delivery	5	22
124674	2020-08-23 17:17:30	2020-08-23	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	47208	delivery	5	38
124675	2020-08-23 17:17:38	2020-08-23	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	14358	delivery	5	31
124676	2020-08-23 17:19:20	2020-08-23	17	[{"id_menu":4,"count":1}]	11534	delivery	5	22
124677	2020-08-23 17:21:34	2020-08-23	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	13484	delivery	5	30
124678	2020-08-23 17:22:16	2020-08-23	12	[{"id_menu":1,"count":1}]	47189	delivery	5	17
124679	2020-08-23 17:29:24	2020-08-23	12	[{"id_menu":1,"count":1}]	26828	delivery	5	17
124680	2020-08-23 17:29:52	2020-08-23	9	[{"id_menu":7,"count":1}]	909	pick-up	0	9
124681	2020-08-23 17:30:53	2020-08-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	13813	delivery	5	31
124682	2020-08-23 17:33:11	2020-08-23	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	46771	delivery	5	25
124683	2020-08-23 17:33:20	2020-08-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1244	pick-up	0	17
124684	2020-08-23 17:34:04	2020-08-23	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	3221	delivery	5	40
124685	2020-08-23 17:34:18	2020-08-23	17	[{"id_menu":4,"count":1}]	46232	delivery	5	22
124686	2020-08-23 17:34:40	2020-08-23	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1639	delivery	5	34
124687	2020-08-23 17:35:00	2020-08-23	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	35549	delivery	5	27
124688	2020-08-23 17:37:10	2020-08-23	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	46632	delivery	5	37
124689	2020-08-23 17:39:01	2020-08-23	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	14131	delivery	5	31
124690	2020-08-23 17:39:10	2020-08-23	14	[{"id_menu":2,"count":1}]	14283	delivery	5	19
124691	2020-08-23 17:41:08	2020-08-23	12	[{"id_menu":1,"count":1}]	10393	pick-up	0	12
124692	2020-08-23 17:41:27	2020-08-23	8	[{"id_menu":5,"count":1}]	11756	delivery	5	13
124693	2020-08-23 17:42:06	2020-08-23	9	[{"id_menu":7,"count":1}]	9253	pick-up	0	9
124694	2020-08-23 17:42:25	2020-08-23	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	47310	delivery	5	36
124695	2020-08-23 17:42:26	2020-08-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	43446	pick-up	0	26
124696	2020-08-23 17:47:14	2020-08-23	9	[{"id_menu":7,"count":1}]	47283	delivery	5	14
124697	2020-08-23 17:47:46	2020-08-23	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	6046	delivery	5	26
124698	2020-08-23 17:48:48	2020-08-23	9	[{"id_menu":6,"count":1}]	26911	delivery	5	14
124699	2020-08-23 17:49:20	2020-08-23	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	25749	delivery	5	26
124700	2020-08-23 17:51:49	2020-08-23	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	47130	delivery	5	43
124701	2020-08-23 17:51:50	2020-08-23	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	30167	delivery	5	34
124702	2020-08-23 17:52:02	2020-08-23	12	[{"id_menu":1,"count":1}]	19873	delivery	5	17
124703	2020-08-23 17:52:39	2020-08-23	9	[{"id_menu":7,"count":1}]	41559	delivery	5	14
124704	2020-08-23 17:52:46	2020-08-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7472	delivery	5	36
124705	2020-08-23 17:57:49	2020-08-23	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	47272	delivery	5	26
124706	2020-08-23 17:57:58	2020-08-23	14	[{"id_menu":2,"count":1}]	35933	delivery	5	19
124707	2020-08-23 17:58:12	2020-08-23	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	27256	delivery	5	34
124708	2020-08-23 18:00:50	2020-08-23	8	[{"id_menu":5,"count":1}]	47201	delivery	5	13
124709	2020-08-23 18:01:02	2020-08-23	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	38419	pick-up	0	21
124710	2020-08-23 18:02:30	2020-08-23	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24728	delivery	5	36
124711	2020-08-23 18:02:45	2020-08-23	14	[{"id_menu":2,"count":1}]	33332	delivery	5	19
124712	2020-08-23 18:03:52	2020-08-23	12	[{"id_menu":1,"count":1}]	21102	delivery	5	17
124713	2020-08-23 18:03:54	2020-08-23	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	4066	delivery	5	26
124714	2020-08-23 18:06:39	2020-08-23	17	[{"id_menu":4,"count":1}]	42814	delivery	5	22
124715	2020-08-23 18:08:02	2020-08-23	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	42598	delivery	5	27
124716	2020-08-23 18:08:38	2020-08-23	12	[{"id_menu":3,"count":1}]	46353	delivery	5	17
124717	2020-08-23 18:08:44	2020-08-23	12	[{"id_menu":1,"count":1}]	41225	pick-up	0	12
124718	2020-08-23 18:08:55	2020-08-23	8	[{"id_menu":5,"count":1}]	19596	delivery	5	13
124719	2020-08-23 18:10:50	2020-08-23	9	[{"id_menu":6,"count":1}]	32	pick-up	0	9
124720	2020-08-23 18:10:51	2020-08-23	9	[{"id_menu":6,"count":1}]	19136	delivery	5	14
124721	2020-08-23 18:12:01	2020-08-23	9	[{"id_menu":6,"count":1}]	1166	pick-up	0	9
124722	2020-08-23 18:13:39	2020-08-23	8	[{"id_menu":5,"count":1}]	6324	delivery	5	13
124723	2020-08-23 18:14:19	2020-08-23	9	[{"id_menu":7,"count":3}]	20831	delivery	5	14
124724	2020-08-23 18:16:25	2020-08-23	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	15419	delivery	5	26
124725	2020-08-23 18:17:13	2020-08-23	9	[{"id_menu":7,"count":1}]	47062	delivery	5	14
124726	2020-08-23 18:17:23	2020-08-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43666	delivery	5	23
124727	2020-08-23 18:18:02	2020-08-23	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19056	delivery	5	31
124728	2020-08-23 18:18:37	2020-08-23	8	[{"id_menu":5,"count":1}]	47214	delivery	5	13
124729	2020-08-23 18:18:38	2020-08-23	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	47196	delivery	5	48
124730	2020-08-23 18:21:42	2020-08-23	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	47071	delivery	5	26
124731	2020-08-23 18:23:37	2020-08-23	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21574	delivery	5	39
124732	2020-08-23 18:24:05	2020-08-23	9	[{"id_menu":7,"count":1}]	47197	delivery	5	14
124733	2020-08-23 18:25:11	2020-08-23	12	[{"id_menu":3,"count":2}]	153	pick-up	0	12
124734	2020-08-23 18:25:36	2020-08-23	12	[{"id_menu":3,"count":1}]	36713	delivery	5	17
124735	2020-08-23 18:27:29	2020-08-23	17	[{"id_menu":4,"count":1}]	47092	delivery	5	22
124736	2020-08-23 18:28:10	2020-08-23	8	[{"id_menu":5,"count":1}]	19517	delivery	5	13
124737	2020-08-23 18:28:47	2020-08-23	9	[{"id_menu":6,"count":1}]	31084	delivery	5	14
124738	2020-08-23 18:30:42	2020-08-23	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	45308	delivery	5	26
124739	2020-08-23 18:33:11	2020-08-23	9	[{"id_menu":7,"count":1}]	47301	delivery	5	14
124740	2020-08-23 18:33:45	2020-08-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2264	pick-up	0	21
124741	2020-08-23 18:36:22	2020-08-23	8	[{"id_menu":5,"count":1}]	46195	delivery	5	13
124742	2020-08-23 18:37:12	2020-08-23	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	47257	delivery	5	26
124743	2020-08-23 18:40:39	2020-08-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	45939	delivery	5	31
124744	2020-08-23 18:42:28	2020-08-23	17	[{"id_menu":4,"count":1}]	13851	pick-up	0	17
124745	2020-08-23 18:44:56	2020-08-23	12	[{"id_menu":1,"count":1}]	39654	delivery	5	17
124746	2020-08-23 18:48:53	2020-08-23	12	[{"id_menu":3,"count":1}]	24949	delivery	5	17
124747	2020-08-23 18:52:49	2020-08-23	8	[{"id_menu":5,"count":1}]	21461	delivery	5	13
124748	2020-08-23 18:53:07	2020-08-23	14	[{"id_menu":2,"count":1}]	31735	pick-up	0	14
124749	2020-08-23 18:55:31	2020-08-23	8	[{"id_menu":5,"count":1}]	47255	delivery	5	13
124750	2020-08-23 18:56:10	2020-08-23	12	[{"id_menu":1,"count":1}]	47061	delivery	5	17
124751	2020-08-23 18:56:53	2020-08-23	12	[{"id_menu":3,"count":1}]	32070	delivery	5	17
124752	2020-08-23 18:57:52	2020-08-23	12	[{"id_menu":1,"count":1}]	5225	delivery	5	17
124753	2020-08-23 18:58:24	2020-08-23	8	[{"id_menu":5,"count":1}]	33306	delivery	5	13
124754	2020-08-23 18:59:21	2020-08-23	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	19277	pick-up	0	35
124755	2020-08-23 18:59:36	2020-08-23	9	[{"id_menu":6,"count":1}]	6516	pick-up	0	9
124756	2020-08-23 19:02:06	2020-08-23	12	[{"id_menu":1,"count":1}]	33480	delivery	5	17
124757	2020-08-23 19:03:34	2020-08-23	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":2}]	44634	delivery	5	26
124758	2020-08-23 19:03:44	2020-08-23	8	[{"id_menu":5,"count":1}]	29052	pick-up	0	8
124759	2020-08-23 19:05:27	2020-08-23	17	[{"id_menu":4,"count":1}]	42843	delivery	5	22
124760	2020-08-23 19:06:46	2020-08-23	8	[{"id_menu":5,"count":1}]	47140	delivery	5	13
124761	2020-08-23 19:07:16	2020-08-23	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	19279	delivery	5	34
124762	2020-08-23 19:09:21	2020-08-23	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21561	delivery	5	36
124763	2020-08-23 19:10:29	2020-08-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19085	delivery	5	22
124764	2020-08-23 19:12:32	2020-08-23	9	[{"id_menu":6,"count":1}]	28666	delivery	5	14
124765	2020-08-23 19:12:56	2020-08-23	12	[{"id_menu":3,"count":1}]	27	pick-up	0	12
124766	2020-08-23 19:13:12	2020-08-23	9	[{"id_menu":6,"count":1}]	10035	delivery	5	14
124767	2020-08-23 19:15:00	2020-08-23	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	47073	delivery	5	26
124768	2020-08-23 19:17:06	2020-08-23	17	[{"id_menu":4,"count":1}]	11446	pick-up	0	17
124769	2020-08-23 19:17:11	2020-08-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	15563	delivery	5	31
124770	2020-08-23 19:21:22	2020-08-23	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	2995	delivery	5	27
124771	2020-08-23 19:23:26	2020-08-23	8	[{"id_menu":5,"count":1}]	9231	pick-up	0	8
124772	2020-08-23 19:25:57	2020-08-23	9	[{"id_menu":7,"count":1}]	4062	pick-up	0	9
124773	2020-08-23 19:26:25	2020-08-23	9	[{"id_menu":6,"count":1}]	35842	delivery	5	14
124774	2020-08-23 19:26:44	2020-08-23	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	8716	pick-up	0	29
124775	2020-08-23 19:27:44	2020-08-23	9	[{"id_menu":7,"count":1}]	47291	delivery	5	14
124776	2020-08-23 19:28:30	2020-08-23	9	[{"id_menu":7,"count":1}]	27908	delivery	5	14
124777	2020-08-23 19:30:30	2020-08-23	9	[{"id_menu":7,"count":1}]	19791	delivery	5	14
124778	2020-08-23 19:33:05	2020-08-23	9	[{"id_menu":6,"count":1}]	47281	delivery	5	14
124779	2020-08-23 19:34:23	2020-08-23	12	[{"id_menu":3,"count":1}]	27755	pick-up	0	12
124780	2020-08-23 19:34:33	2020-08-23	29	[{"id_menu":3,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	47179	delivery	5	34
124781	2020-08-23 19:35:03	2020-08-23	34	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	47077	delivery	5	39
124782	2020-08-23 19:36:33	2020-08-23	9	[{"id_menu":7,"count":1}]	47163	delivery	5	14
124783	2020-08-23 19:37:25	2020-08-23	9	[{"id_menu":6,"count":1}]	11822	delivery	5	14
124784	2020-08-23 19:38:37	2020-08-23	17	[{"id_menu":4,"count":1}]	47122	delivery	5	22
124785	2020-08-23 19:38:50	2020-08-23	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	47313	delivery	5	31
124786	2020-08-23 19:39:55	2020-08-23	12	[{"id_menu":3,"count":1}]	18344	pick-up	0	12
124787	2020-08-23 19:40:15	2020-08-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5962	pick-up	0	17
124788	2020-08-23 19:40:31	2020-08-23	9	[{"id_menu":6,"count":1}]	16807	delivery	5	14
124789	2020-08-23 19:42:12	2020-08-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	30917	delivery	5	28
124790	2020-08-23 19:43:10	2020-08-23	9	[{"id_menu":6,"count":1}]	47089	delivery	5	14
124791	2020-08-23 19:43:43	2020-08-23	17	[{"id_menu":4,"count":1}]	19657	delivery	5	22
124792	2020-08-23 19:44:25	2020-08-23	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	47218	delivery	5	39
124793	2020-08-23 19:44:57	2020-08-23	8	[{"id_menu":5,"count":1}]	19813	delivery	5	13
124794	2020-08-23 19:47:02	2020-08-23	9	[{"id_menu":6,"count":1}]	2434	pick-up	0	9
124795	2020-08-23 19:49:12	2020-08-23	14	[{"id_menu":2,"count":2}]	8965	delivery	5	19
124796	2020-08-23 19:50:29	2020-08-23	9	[{"id_menu":7,"count":1}]	29823	delivery	5	14
124797	2020-08-23 19:51:37	2020-08-23	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	47261	delivery	5	30
124798	2020-08-23 19:51:55	2020-08-23	12	[{"id_menu":3,"count":1}]	46623	delivery	5	17
124799	2020-08-23 19:52:19	2020-08-23	9	[{"id_menu":7,"count":1}]	47118	delivery	5	14
124800	2020-08-23 19:53:01	2020-08-23	14	[{"id_menu":2,"count":1}]	39116	delivery	5	19
124801	2020-08-23 19:53:17	2020-08-23	55	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1148	pick-up	0	55
124802	2020-08-23 19:54:16	2020-08-23	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	35771	delivery	5	22
124803	2020-08-23 19:54:34	2020-08-23	17	[{"id_menu":4,"count":1}]	3048	delivery	5	22
124804	2020-08-23 19:57:49	2020-08-23	14	[{"id_menu":2,"count":1}]	32285	delivery	5	19
124805	2020-08-23 20:00:18	2020-08-23	8	[{"id_menu":5,"count":2}]	47170	delivery	5	13
124806	2020-08-23 20:01:20	2020-08-23	9	[{"id_menu":6,"count":1}]	47262	delivery	5	14
124807	2020-08-23 20:01:23	2020-08-23	17	[{"id_menu":4,"count":1}]	20271	delivery	5	22
124808	2020-08-23 20:01:28	2020-08-23	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	37090	delivery	5	31
124809	2020-08-23 20:02:44	2020-08-23	17	[{"id_menu":4,"count":1}]	47119	delivery	5	22
124810	2020-08-23 20:03:45	2020-08-23	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	47269	delivery	5	27
124811	2020-08-23 20:04:12	2020-08-23	14	[{"id_menu":2,"count":1}]	4514	delivery	5	19
124812	2020-08-23 20:05:13	2020-08-23	9	[{"id_menu":7,"count":1}]	17503	delivery	5	14
124813	2020-08-23 20:05:19	2020-08-23	9	[{"id_menu":6,"count":1}]	34658	pick-up	0	9
124814	2020-08-23 20:07:13	2020-08-23	9	[{"id_menu":6,"count":1}]	31655	delivery	5	14
124815	2020-08-23 20:07:33	2020-08-23	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	47180	delivery	5	44
124816	2020-08-23 20:16:32	2020-08-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	45554	delivery	5	36
124817	2020-08-23 20:17:58	2020-08-23	12	[{"id_menu":1,"count":1}]	47172	delivery	5	17
124818	2020-08-23 20:19:34	2020-08-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	36826	delivery	5	31
124819	2020-08-23 20:21:30	2020-08-23	9	[{"id_menu":7,"count":1}]	24547	pick-up	0	9
124820	2020-08-23 20:22:22	2020-08-23	8	[{"id_menu":5,"count":1}]	3695	delivery	5	13
124821	2020-08-23 20:25:44	2020-08-23	12	[{"id_menu":3,"count":1}]	47074	delivery	5	17
124822	2020-08-23 20:26:28	2020-08-23	9	[{"id_menu":6,"count":1}]	9081	delivery	5	14
124823	2020-08-23 20:26:37	2020-08-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	31008	delivery	5	31
124824	2020-08-23 20:27:09	2020-08-23	12	[{"id_menu":1,"count":1}]	2715	delivery	5	17
124825	2020-08-23 20:27:32	2020-08-23	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17809	delivery	5	31
124826	2020-08-23 20:27:48	2020-08-23	9	[{"id_menu":7,"count":1}]	38605	delivery	5	14
124827	2020-08-23 20:28:02	2020-08-23	17	[{"id_menu":4,"count":1}]	42593	pick-up	0	17
124828	2020-08-23 20:30:08	2020-08-23	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	11766	delivery	5	27
124829	2020-08-23 20:33:26	2020-08-23	14	[{"id_menu":2,"count":1}]	32375	delivery	5	19
124830	2020-08-23 20:33:35	2020-08-23	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	8620	pick-up	0	21
124831	2020-08-23 20:33:39	2020-08-23	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	37802	delivery	5	30
124832	2020-08-23 20:36:51	2020-08-23	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":3}]	24221	delivery	5	31
124833	2020-08-23 20:38:07	2020-08-23	14	[{"id_menu":2,"count":1}]	44413	pick-up	0	14
124834	2020-08-23 20:39:57	2020-08-23	9	[{"id_menu":7,"count":1}]	47305	delivery	5	14
124835	2020-08-23 20:40:12	2020-08-23	9	[{"id_menu":7,"count":1}]	47217	delivery	5	14
124836	2020-08-23 20:42:48	2020-08-23	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	21205	delivery	5	44
124837	2020-08-23 20:43:27	2020-08-23	8	[{"id_menu":5,"count":1}]	33234	delivery	5	13
124838	2020-08-23 20:46:29	2020-08-23	17	[{"id_menu":4,"count":1}]	44216	delivery	5	22
124839	2020-08-23 20:47:47	2020-08-23	14	[{"id_menu":2,"count":1}]	5729	delivery	5	19
124840	2020-08-23 20:48:14	2020-08-23	12	[{"id_menu":1,"count":2}]	14744	delivery	5	17
124841	2020-08-23 20:48:54	2020-08-23	12	[{"id_menu":1,"count":1}]	43397	delivery	5	17
124842	2020-08-23 20:50:48	2020-08-23	17	[{"id_menu":4,"count":1}]	15265	pick-up	0	17
124843	2020-08-23 20:52:15	2020-08-23	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	47227	delivery	5	39
124844	2020-08-23 20:52:36	2020-08-23	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	32991	delivery	5	31
124845	2020-08-23 20:53:37	2020-08-23	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18306	delivery	5	34
124846	2020-08-23 20:54:20	2020-08-23	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	8347	pick-up	0	21
124847	2020-08-23 20:56:02	2020-08-23	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	47111	delivery	5	39
124848	2020-08-23 20:58:17	2020-08-23	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	47252	delivery	5	34
124849	2020-08-23 20:58:46	2020-08-23	26	[{"id_menu":2,"count":3},{"id_menu":3,"count":1}]	18734	delivery	5	31
124850	2020-08-23 21:00:01	2020-08-23	9	[{"id_menu":6,"count":1}]	45347	delivery	5	14
124851	2020-08-23 21:05:06	2020-08-23	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	15578	delivery	5	26
124852	2020-08-23 21:06:00	2020-08-23	8	[{"id_menu":5,"count":1}]	41563	delivery	5	13
124853	2020-08-23 21:07:24	2020-08-23	8	[{"id_menu":5,"count":1}]	25024	pick-up	0	8
124854	2020-08-23 21:09:17	2020-08-23	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	23680	delivery	5	40
124855	2020-08-23 21:10:05	2020-08-23	8	[{"id_menu":5,"count":1}]	45146	delivery	5	13
124856	2020-08-23 21:10:56	2020-08-23	9	[{"id_menu":6,"count":1}]	47251	delivery	5	14
124857	2020-08-23 21:11:58	2020-08-23	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	47319	delivery	5	26
124858	2020-08-23 21:12:54	2020-08-23	9	[{"id_menu":7,"count":1}]	47236	delivery	5	14
124859	2020-08-23 21:13:23	2020-08-23	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	47223	delivery	5	22
124860	2020-08-23 21:14:54	2020-08-23	9	[{"id_menu":6,"count":1}]	1266	delivery	5	14
124861	2020-08-23 21:15:11	2020-08-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16134	delivery	5	23
124862	2020-08-23 21:18:51	2020-08-23	12	[{"id_menu":3,"count":1}]	47203	delivery	5	17
124863	2020-08-23 21:19:54	2020-08-23	12	[{"id_menu":1,"count":2}]	47078	delivery	5	17
124864	2020-08-23 21:21:43	2020-08-23	12	[{"id_menu":1,"count":1}]	33699	delivery	5	17
124865	2020-08-23 21:21:56	2020-08-23	9	[{"id_menu":7,"count":1}]	47174	delivery	5	14
124866	2020-08-23 21:22:17	2020-08-23	17	[{"id_menu":4,"count":1}]	686	delivery	5	22
124867	2020-08-23 21:22:38	2020-08-23	17	[{"id_menu":4,"count":1}]	28895	pick-up	0	17
124868	2020-08-23 21:23:06	2020-08-23	9	[{"id_menu":6,"count":1}]	40378	pick-up	0	9
124869	2020-08-23 21:23:06	2020-08-23	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	37392	delivery	5	27
124870	2020-08-23 21:24:32	2020-08-23	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	6296	delivery	5	31
124871	2020-08-23 21:25:30	2020-08-23	17	[{"id_menu":4,"count":1}]	18409	pick-up	0	17
124872	2020-08-23 21:25:32	2020-08-23	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	359	delivery	5	22
124873	2020-08-23 21:27:44	2020-08-23	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	36495	delivery	5	30
124874	2020-08-23 21:28:51	2020-08-23	9	[{"id_menu":7,"count":1}]	47066	delivery	5	14
124875	2020-08-23 21:30:55	2020-08-23	9	[{"id_menu":7,"count":1}]	44194	delivery	5	14
124876	2020-08-23 21:34:19	2020-08-23	8	[{"id_menu":5,"count":1}]	47292	delivery	5	13
124877	2020-08-23 21:34:32	2020-08-23	17	[{"id_menu":4,"count":1}]	33022	pick-up	0	17
124878	2020-08-23 21:36:33	2020-08-23	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	23276	delivery	5	31
124879	2020-08-23 21:36:38	2020-08-23	17	[{"id_menu":4,"count":2}]	43865	delivery	5	22
124880	2020-08-23 21:39:35	2020-08-23	9	[{"id_menu":6,"count":1}]	47253	delivery	5	14
124881	2020-08-23 21:42:04	2020-08-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	37439	pick-up	0	21
124882	2020-08-23 21:43:20	2020-08-23	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	42746	delivery	5	23
124883	2020-08-23 21:43:31	2020-08-23	9	[{"id_menu":7,"count":1}]	8705	delivery	5	14
124884	2020-08-23 21:44:17	2020-08-23	9	[{"id_menu":7,"count":1}]	30564	delivery	5	14
124885	2020-08-23 21:45:26	2020-08-23	14	[{"id_menu":2,"count":1}]	38790	delivery	5	19
124886	2020-08-23 21:46:00	2020-08-23	9	[{"id_menu":6,"count":1}]	42141	delivery	5	14
124887	2020-08-23 21:48:45	2020-08-23	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	14020	delivery	5	36
124888	2020-08-23 21:50:19	2020-08-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	40697	pick-up	0	21
124889	2020-08-23 21:51:32	2020-08-23	14	[{"id_menu":2,"count":1}]	40826	delivery	5	19
124890	2020-08-23 21:52:18	2020-08-23	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	13953	delivery	5	38
124891	2020-08-23 21:52:58	2020-08-23	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	36382	delivery	5	45
124892	2020-08-23 21:55:23	2020-08-23	14	[{"id_menu":2,"count":1}]	1118	pick-up	0	14
124893	2020-08-23 21:58:35	2020-08-23	23	[{"id_menu":2,"count":3},{"id_menu":7,"count":1}]	47195	delivery	5	28
124894	2020-08-23 21:58:41	2020-08-23	17	[{"id_menu":4,"count":1}]	41696	delivery	5	22
124895	2020-08-23 22:02:14	2020-08-23	12	[{"id_menu":3,"count":1}]	35019	delivery	5	17
124896	2020-08-23 22:03:15	2020-08-23	9	[{"id_menu":6,"count":1}]	46422	pick-up	0	9
124897	2020-08-23 22:03:39	2020-08-23	8	[{"id_menu":5,"count":1}]	29211	pick-up	0	8
124898	2020-08-23 22:05:22	2020-08-23	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	47146	delivery	5	31
124899	2020-08-23 22:05:39	2020-08-23	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	47312	delivery	5	40
124900	2020-08-23 22:05:53	2020-08-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	32129	delivery	5	28
124901	2020-08-23 22:10:46	2020-08-23	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	46846	delivery	5	23
124902	2020-08-23 22:11:08	2020-08-23	12	[{"id_menu":1,"count":1}]	12699	delivery	5	17
124903	2020-08-23 22:14:27	2020-08-23	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10807	pick-up	0	49
124904	2020-08-23 22:16:29	2020-08-23	12	[{"id_menu":1,"count":1}]	31127	delivery	5	17
124905	2020-08-23 22:17:10	2020-08-23	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	47300	delivery	5	26
124906	2020-08-23 22:18:19	2020-08-23	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	47296	delivery	5	28
124907	2020-08-23 22:18:46	2020-08-23	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	27299	pick-up	0	29
124908	2020-08-23 22:18:52	2020-08-23	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	3173	delivery	5	30
124909	2020-08-23 22:18:55	2020-08-23	9	[{"id_menu":7,"count":1}]	47085	pick-up	0	9
124910	2020-08-23 22:22:45	2020-08-23	14	[{"id_menu":2,"count":1}]	47268	delivery	5	19
124911	2020-08-23 22:23:49	2020-08-23	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	18708	delivery	5	36
124912	2020-08-23 22:25:12	2020-08-23	9	[{"id_menu":6,"count":1}]	35795	delivery	5	14
124913	2020-08-23 22:28:00	2020-08-23	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	47109	delivery	5	27
124914	2020-08-23 22:28:07	2020-08-23	9	[{"id_menu":7,"count":1}]	25487	delivery	5	14
124915	2020-08-23 22:28:17	2020-08-23	9	[{"id_menu":7,"count":1}]	17581	delivery	5	14
124916	2020-08-23 22:29:10	2020-08-23	17	[{"id_menu":4,"count":2}]	3634	delivery	5	22
124917	2020-08-23 22:29:49	2020-08-23	12	[{"id_menu":3,"count":1}]	40480	pick-up	0	12
124918	2020-08-23 22:30:39	2020-08-23	9	[{"id_menu":7,"count":1}]	22686	delivery	5	14
124919	2020-08-23 22:31:37	2020-08-23	17	[{"id_menu":4,"count":1}]	36907	pick-up	0	17
124920	2020-08-23 22:34:23	2020-08-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	44164	delivery	5	23
124921	2020-08-23 22:34:27	2020-08-23	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	30263	pick-up	0	31
124922	2020-08-23 22:35:06	2020-08-23	17	[{"id_menu":4,"count":1}]	47299	delivery	5	22
124923	2020-08-23 22:39:34	2020-08-23	14	[{"id_menu":2,"count":1}]	26256	pick-up	0	14
124924	2020-08-23 22:39:51	2020-08-23	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	38651	delivery	5	31
124925	2020-08-23 22:41:20	2020-08-23	17	[{"id_menu":4,"count":1}]	24421	delivery	5	22
124926	2020-08-23 22:41:40	2020-08-23	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	30251	delivery	5	30
124927	2020-08-23 22:43:41	2020-08-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	35545	delivery	5	26
124928	2020-08-23 22:44:06	2020-08-23	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	19560	pick-up	0	31
124929	2020-08-23 22:44:21	2020-08-23	9	[{"id_menu":7,"count":1}]	807	pick-up	0	9
124930	2020-08-23 22:44:29	2020-08-23	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	47158	delivery	5	35
124931	2020-08-23 22:45:24	2020-08-23	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	47097	delivery	5	31
124932	2020-08-23 22:45:27	2020-08-23	12	[{"id_menu":3,"count":1}]	35511	pick-up	0	12
124933	2020-08-23 22:47:04	2020-08-23	8	[{"id_menu":5,"count":1}]	7878	delivery	5	13
124934	2020-08-23 22:50:16	2020-08-23	9	[{"id_menu":7,"count":3}]	37007	delivery	5	14
124935	2020-08-23 22:50:57	2020-08-23	9	[{"id_menu":6,"count":1}]	32100	delivery	5	14
124936	2020-08-23 22:51:20	2020-08-23	8	[{"id_menu":5,"count":1}]	34184	delivery	5	13
124937	2020-08-23 22:51:52	2020-08-23	12	[{"id_menu":3,"count":1}]	2123	delivery	5	17
124938	2020-08-23 22:52:38	2020-08-23	9	[{"id_menu":6,"count":1}]	47076	delivery	5	14
124939	2020-08-23 22:52:47	2020-08-23	9	[{"id_menu":7,"count":1}]	1023	delivery	5	14
124940	2020-08-23 22:54:20	2020-08-23	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	46492	delivery	5	34
124941	2020-08-23 22:54:40	2020-08-23	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	47083	delivery	5	34
124942	2020-08-23 22:55:17	2020-08-23	9	[{"id_menu":7,"count":1}]	25777	delivery	5	14
124943	2020-08-23 22:56:01	2020-08-23	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	47064	delivery	5	22
124944	2020-08-23 22:56:07	2020-08-23	12	[{"id_menu":1,"count":1}]	1401	pick-up	0	12
124945	2020-08-23 22:57:52	2020-08-23	9	[{"id_menu":7,"count":1}]	38658	delivery	5	14
124946	2020-08-23 22:58:25	2020-08-23	8	[{"id_menu":5,"count":1}]	2364	pick-up	0	8
124947	2020-08-23 22:59:09	2020-08-23	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	47258	delivery	5	35
124948	2020-08-23 23:00:30	2020-08-23	17	[{"id_menu":4,"count":1}]	47224	pick-up	0	17
124949	2020-08-23 23:00:31	2020-08-23	17	[{"id_menu":4,"count":1}]	15044	delivery	5	22
124950	2020-08-23 23:00:43	2020-08-23	8	[{"id_menu":5,"count":1}]	13058	delivery	5	13
124951	2020-08-23 23:02:11	2020-08-23	8	[{"id_menu":5,"count":1}]	29856	delivery	5	13
124952	2020-08-23 23:04:00	2020-08-23	12	[{"id_menu":3,"count":1}]	17842	delivery	5	17
124953	2020-08-23 23:06:30	2020-08-23	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	31006	pick-up	0	29
124954	2020-08-23 23:06:58	2020-08-23	12	[{"id_menu":3,"count":1}]	39628	delivery	5	17
124955	2020-08-23 23:08:39	2020-08-23	9	[{"id_menu":6,"count":1}]	39700	delivery	5	14
124956	2020-08-23 23:09:16	2020-08-23	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	45738	delivery	5	26
124957	2020-08-23 23:12:16	2020-08-23	8	[{"id_menu":5,"count":1}]	1460	pick-up	0	8
124958	2020-08-23 23:17:31	2020-08-23	12	[{"id_menu":1,"count":1}]	9846	pick-up	0	12
124959	2020-08-23 23:17:50	2020-08-23	17	[{"id_menu":4,"count":1}]	31440	delivery	5	22
124960	2020-08-23 23:19:12	2020-08-23	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	47191	delivery	5	42
124961	2020-08-23 23:20:11	2020-08-23	14	[{"id_menu":2,"count":1}]	44300	delivery	5	19
124962	2020-08-23 23:22:52	2020-08-23	9	[{"id_menu":6,"count":1}]	24885	pick-up	0	9
124963	2020-08-23 23:24:48	2020-08-23	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	5416	pick-up	0	26
124964	2020-08-23 23:26:06	2020-08-23	12	[{"id_menu":3,"count":1}]	9544	delivery	5	17
124965	2020-08-23 23:27:25	2020-08-23	9	[{"id_menu":6,"count":1}]	5776	delivery	5	14
124966	2020-08-23 23:28:30	2020-08-23	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13042	delivery	5	23
124967	2020-08-23 23:28:50	2020-08-23	30	[{"id_menu":3,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27917	delivery	5	35
124968	2020-08-23 23:29:27	2020-08-23	17	[{"id_menu":4,"count":1}]	47105	delivery	5	22
124969	2020-08-23 23:30:13	2020-08-23	8	[{"id_menu":5,"count":1}]	7999	pick-up	0	8
124970	2020-08-23 23:30:29	2020-08-23	9	[{"id_menu":6,"count":1}]	26033	delivery	5	14
124971	2020-08-23 23:31:56	2020-08-23	17	[{"id_menu":4,"count":1}]	32755	delivery	5	22
124972	2020-08-23 23:32:37	2020-08-23	14	[{"id_menu":2,"count":1}]	47273	pick-up	0	14
124973	2020-08-23 23:33:27	2020-08-23	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5574	delivery	5	44
124974	2020-08-23 23:36:31	2020-08-23	8	[{"id_menu":5,"count":1}]	45669	delivery	5	13
124975	2020-08-23 23:37:16	2020-08-23	14	[{"id_menu":2,"count":1}]	40510	delivery	5	19
124976	2020-08-23 23:45:12	2020-08-23	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	24024	delivery	5	25
124977	2020-08-23 23:45:44	2020-08-23	8	[{"id_menu":5,"count":2}]	38850	delivery	5	13
124978	2020-08-23 23:46:07	2020-08-23	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	8057	delivery	5	26
124979	2020-08-23 23:47:55	2020-08-23	12	[{"id_menu":3,"count":2}]	15768	delivery	5	17
124980	2020-08-23 23:48:17	2020-08-23	12	[{"id_menu":1,"count":1}]	35804	delivery	5	17
124981	2020-08-23 23:50:57	2020-08-23	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31479	delivery	5	40
124982	2020-08-23 23:52:57	2020-08-23	17	[{"id_menu":4,"count":1}]	24244	pick-up	0	17
124983	2020-08-23 23:56:33	2020-08-23	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	14490	delivery	5	22
124984	2020-08-23 23:56:44	2020-08-23	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	46464	pick-up	0	23
124985	2020-08-23 23:58:32	2020-08-23	14	[{"id_menu":2,"count":1}]	2041	delivery	5	19
124986	2020-08-23 23:58:44	2020-08-23	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	46797	delivery	5	22
124987	2020-08-24 00:00:38	2020-08-24	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26186	delivery	5	35
124988	2020-08-24 00:02:09	2020-08-24	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	47424	delivery	5	31
124989	2020-08-24 00:08:16	2020-08-24	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	47332	delivery	5	27
124990	2020-08-24 00:09:03	2020-08-24	9	[{"id_menu":7,"count":1}]	9125	pick-up	0	9
124991	2020-08-24 00:12:18	2020-08-24	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	47466	delivery	5	23
124992	2020-08-24 00:17:23	2020-08-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	47414	delivery	5	22
124993	2020-08-24 00:18:00	2020-08-24	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	47464	delivery	5	31
124994	2020-08-24 00:20:34	2020-08-24	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33897	delivery	5	31
124995	2020-08-24 00:24:17	2020-08-24	9	[{"id_menu":7,"count":1}]	42481	pick-up	0	9
124996	2020-08-24 00:24:46	2020-08-24	9	[{"id_menu":7,"count":1}]	33080	delivery	5	14
124997	2020-08-24 00:24:49	2020-08-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	47439	delivery	5	28
124998	2020-08-24 00:31:39	2020-08-24	8	[{"id_menu":5,"count":1}]	19094	delivery	5	13
124999	2020-08-24 00:33:25	2020-08-24	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	47504	delivery	5	31
125000	2020-08-24 00:34:17	2020-08-24	9	[{"id_menu":7,"count":1}]	10341	delivery	5	14
125001	2020-08-24 00:35:12	2020-08-24	17	[{"id_menu":4,"count":1}]	6020	pick-up	0	17
125002	2020-08-24 00:35:32	2020-08-24	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	4995	pick-up	0	26
125003	2020-08-24 00:38:12	2020-08-24	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11869	delivery	5	36
125004	2020-08-24 00:38:49	2020-08-24	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	9136	delivery	5	22
125005	2020-08-24 00:44:46	2020-08-24	33	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	9506	delivery	5	38
125006	2020-08-24 00:44:55	2020-08-24	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	38141	delivery	5	34
125007	2020-08-24 00:48:01	2020-08-24	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	4636	pick-up	0	21
125008	2020-08-24 00:50:49	2020-08-24	12	[{"id_menu":1,"count":1}]	946	pick-up	0	12
125009	2020-08-24 00:54:59	2020-08-24	17	[{"id_menu":4,"count":1}]	47511	delivery	5	22
125010	2020-08-24 00:55:26	2020-08-24	12	[{"id_menu":1,"count":1}]	17086	delivery	5	17
125011	2020-08-24 00:55:44	2020-08-24	12	[{"id_menu":3,"count":1}]	7053	delivery	5	17
125012	2020-08-24 00:56:00	2020-08-24	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	36581	delivery	5	26
125013	2020-08-24 00:58:10	2020-08-24	12	[{"id_menu":1,"count":1}]	5369	pick-up	0	12
125014	2020-08-24 01:00:27	2020-08-24	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	30167	delivery	5	26
125015	2020-08-24 01:02:09	2020-08-24	14	[{"id_menu":2,"count":1}]	26809	delivery	5	19
125016	2020-08-24 01:04:45	2020-08-24	17	[{"id_menu":4,"count":1}]	1088	delivery	5	22
125017	2020-08-24 01:05:09	2020-08-24	12	[{"id_menu":3,"count":1}]	47411	delivery	5	17
125018	2020-08-24 01:07:07	2020-08-24	14	[{"id_menu":2,"count":1}]	47462	pick-up	0	14
125019	2020-08-24 01:19:43	2020-08-24	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3945	delivery	5	36
125020	2020-08-24 01:20:45	2020-08-24	8	[{"id_menu":5,"count":1}]	27399	delivery	5	13
125021	2020-08-24 01:24:41	2020-08-24	9	[{"id_menu":6,"count":1}]	18298	delivery	5	14
125022	2020-08-24 01:29:35	2020-08-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	47369	delivery	5	28
125023	2020-08-24 01:31:17	2020-08-24	14	[{"id_menu":2,"count":1}]	21336	delivery	5	19
125024	2020-08-24 01:33:53	2020-08-24	8	[{"id_menu":5,"count":1}]	41181	delivery	5	13
125025	2020-08-24 01:34:39	2020-08-24	12	[{"id_menu":1,"count":1}]	209	delivery	5	17
125026	2020-08-24 01:35:15	2020-08-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	12327	delivery	5	22
125027	2020-08-24 01:37:18	2020-08-24	12	[{"id_menu":3,"count":1}]	7595	pick-up	0	12
125028	2020-08-24 01:41:49	2020-08-24	8	[{"id_menu":5,"count":1}]	38739	delivery	5	13
125029	2020-08-24 01:56:30	2020-08-24	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	14641	delivery	5	36
125030	2020-08-24 01:57:21	2020-08-24	8	[{"id_menu":5,"count":1}]	45350	delivery	5	13
125031	2020-08-24 01:58:56	2020-08-24	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	38813	delivery	5	31
125032	2020-08-24 02:10:47	2020-08-24	14	[{"id_menu":2,"count":1}]	44750	delivery	5	19
125033	2020-08-24 02:12:44	2020-08-24	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	42882	delivery	5	36
125034	2020-08-24 02:14:21	2020-08-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9235	delivery	5	22
125035	2020-08-24 02:19:31	2020-08-24	9	[{"id_menu":6,"count":1}]	30529	delivery	5	14
125036	2020-08-24 02:21:21	2020-08-24	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	47459	delivery	5	26
125037	2020-08-24 02:23:30	2020-08-24	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	47403	pick-up	0	29
125038	2020-08-24 02:27:19	2020-08-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	47351	delivery	5	22
125039	2020-08-24 02:31:13	2020-08-24	9	[{"id_menu":6,"count":1}]	23411	pick-up	0	9
125040	2020-08-24 02:31:34	2020-08-24	14	[{"id_menu":2,"count":3}]	5506	pick-up	0	14
125041	2020-08-24 02:35:53	2020-08-24	9	[{"id_menu":7,"count":1}]	27282	delivery	5	14
125042	2020-08-24 02:46:02	2020-08-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	26874	delivery	5	28
125043	2020-08-24 02:47:55	2020-08-24	14	[{"id_menu":2,"count":2}]	10144	delivery	5	19
125044	2020-08-24 02:49:10	2020-08-24	12	[{"id_menu":3,"count":2}]	13381	delivery	5	17
125045	2020-08-24 02:54:48	2020-08-24	9	[{"id_menu":6,"count":1}]	47410	delivery	5	14
125046	2020-08-24 02:56:06	2020-08-24	14	[{"id_menu":2,"count":1}]	506	delivery	5	19
125047	2020-08-24 02:57:50	2020-08-24	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	47387	delivery	5	49
125048	2020-08-24 02:57:54	2020-08-24	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	40265	delivery	5	34
125049	2020-08-24 03:00:11	2020-08-24	9	[{"id_menu":6,"count":1}]	16760	delivery	5	14
125050	2020-08-24 03:04:55	2020-08-24	9	[{"id_menu":6,"count":1}]	27849	delivery	5	14
125051	2020-08-24 03:18:28	2020-08-24	8	[{"id_menu":5,"count":1}]	25548	delivery	5	13
125052	2020-08-24 03:22:19	2020-08-24	17	[{"id_menu":4,"count":1}]	47487	delivery	5	22
125053	2020-08-24 03:28:13	2020-08-24	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31021	delivery	5	40
125054	2020-08-24 03:32:38	2020-08-24	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	47443	delivery	5	26
125055	2020-08-24 03:32:53	2020-08-24	17	[{"id_menu":4,"count":1}]	9076	delivery	5	22
125056	2020-08-24 03:46:45	2020-08-24	9	[{"id_menu":6,"count":1}]	10620	delivery	5	14
125057	2020-08-24 03:46:46	2020-08-24	30	[{"id_menu":1,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	47442	delivery	5	35
125058	2020-08-24 03:46:57	2020-08-24	12	[{"id_menu":3,"count":1}]	39552	pick-up	0	12
125059	2020-08-24 03:47:19	2020-08-24	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	11604	delivery	5	25
125060	2020-08-24 03:47:37	2020-08-24	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33164	delivery	5	37
125061	2020-08-24 03:50:33	2020-08-24	12	[{"id_menu":1,"count":1}]	215	pick-up	0	12
125062	2020-08-24 03:51:02	2020-08-24	12	[{"id_menu":1,"count":1}]	595	pick-up	0	12
125063	2020-08-24 03:52:23	2020-08-24	17	[{"id_menu":4,"count":1}]	44751	delivery	5	22
125064	2020-08-24 03:56:58	2020-08-24	17	[{"id_menu":4,"count":1}]	36966	pick-up	0	17
125065	2020-08-24 03:59:11	2020-08-24	14	[{"id_menu":2,"count":1}]	36481	delivery	5	19
125066	2020-08-24 03:59:54	2020-08-24	14	[{"id_menu":2,"count":1}]	45508	delivery	5	19
125067	2020-08-24 04:01:57	2020-08-24	12	[{"id_menu":3,"count":1}]	36479	delivery	5	17
125068	2020-08-24 04:02:32	2020-08-24	14	[{"id_menu":2,"count":1}]	47422	delivery	5	19
125069	2020-08-24 04:07:33	2020-08-24	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1473	pick-up	0	17
125070	2020-08-24 04:07:45	2020-08-24	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	47340	delivery	5	48
125071	2020-08-24 04:09:26	2020-08-24	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	47492	delivery	5	46
125072	2020-08-24 04:12:08	2020-08-24	17	[{"id_menu":4,"count":1}]	14428	delivery	5	22
125073	2020-08-24 04:12:40	2020-08-24	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	30252	delivery	5	22
125074	2020-08-24 04:16:03	2020-08-24	14	[{"id_menu":2,"count":1}]	18634	delivery	5	19
125075	2020-08-24 04:18:59	2020-08-24	9	[{"id_menu":6,"count":1}]	35862	delivery	5	14
125076	2020-08-24 04:21:57	2020-08-24	14	[{"id_menu":2,"count":1}]	31780	pick-up	0	14
125077	2020-08-24 04:22:07	2020-08-24	12	[{"id_menu":3,"count":1}]	45794	pick-up	0	12
125078	2020-08-24 04:23:44	2020-08-24	8	[{"id_menu":5,"count":1}]	3237	delivery	5	13
125079	2020-08-24 04:23:53	2020-08-24	8	[{"id_menu":5,"count":1}]	47373	delivery	5	13
125080	2020-08-24 04:30:29	2020-08-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	18781	delivery	5	28
125081	2020-08-24 04:36:26	2020-08-24	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	47480	delivery	5	26
125082	2020-08-24 04:39:20	2020-08-24	9	[{"id_menu":7,"count":1}]	31557	delivery	5	14
125083	2020-08-24 04:40:06	2020-08-24	17	[{"id_menu":4,"count":1}]	47368	delivery	5	22
125084	2020-08-24 04:41:42	2020-08-24	17	[{"id_menu":4,"count":1}]	47358	delivery	5	22
125085	2020-08-24 04:51:13	2020-08-24	9	[{"id_menu":7,"count":1}]	47435	delivery	5	14
125086	2020-08-24 04:51:25	2020-08-24	9	[{"id_menu":6,"count":1}]	29443	delivery	5	14
125087	2020-08-24 04:51:54	2020-08-24	12	[{"id_menu":1,"count":1}]	16774	delivery	5	17
125088	2020-08-24 04:52:19	2020-08-24	12	[{"id_menu":1,"count":1}]	44112	delivery	5	17
125089	2020-08-24 04:52:19	2020-08-24	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	37167	delivery	5	40
125090	2020-08-24 04:55:32	2020-08-24	9	[{"id_menu":7,"count":1}]	47396	delivery	5	14
125091	2020-08-24 04:56:14	2020-08-24	9	[{"id_menu":6,"count":1}]	47432	delivery	5	14
125092	2020-08-24 04:57:09	2020-08-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19913	delivery	5	23
125093	2020-08-24 04:57:25	2020-08-24	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	34301	delivery	5	31
125094	2020-08-24 04:58:16	2020-08-24	8	[{"id_menu":5,"count":1}]	15016	delivery	5	13
125095	2020-08-24 05:07:21	2020-08-24	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	25905	pick-up	0	22
125096	2020-08-24 05:14:16	2020-08-24	9	[{"id_menu":6,"count":1}]	905	delivery	5	14
125097	2020-08-24 05:15:10	2020-08-24	9	[{"id_menu":6,"count":1}]	28659	delivery	5	14
125098	2020-08-24 05:18:20	2020-08-24	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	27961	delivery	5	27
125099	2020-08-24 05:20:52	2020-08-24	12	[{"id_menu":1,"count":1}]	3111	delivery	5	17
125100	2020-08-24 05:20:59	2020-08-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	20414	delivery	5	28
125101	2020-08-24 05:22:48	2020-08-24	17	[{"id_menu":4,"count":1}]	32316	delivery	5	22
125102	2020-08-24 05:31:23	2020-08-24	12	[{"id_menu":1,"count":1}]	2081	delivery	5	17
125103	2020-08-24 05:31:26	2020-08-24	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	4208	pick-up	0	26
125104	2020-08-24 05:34:02	2020-08-24	9	[{"id_menu":7,"count":1}]	47337	delivery	5	14
125105	2020-08-24 05:52:04	2020-08-24	9	[{"id_menu":7,"count":1}]	25064	delivery	5	14
125106	2020-08-24 05:58:45	2020-08-24	9	[{"id_menu":7,"count":1}]	18653	delivery	5	14
125107	2020-08-24 05:58:49	2020-08-24	8	[{"id_menu":5,"count":1}]	1645	pick-up	0	8
125108	2020-08-24 05:59:08	2020-08-24	14	[{"id_menu":2,"count":1}]	7771	delivery	5	19
125109	2020-08-24 06:01:31	2020-08-24	9	[{"id_menu":7,"count":1}]	46326	delivery	5	14
125110	2020-08-24 06:07:56	2020-08-24	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	5109	delivery	5	25
125111	2020-08-24 06:10:28	2020-08-24	9	[{"id_menu":7,"count":1}]	16798	delivery	5	14
125112	2020-08-24 06:13:23	2020-08-24	9	[{"id_menu":6,"count":1}]	47417	delivery	5	14
125113	2020-08-24 06:14:00	2020-08-24	8	[{"id_menu":5,"count":1}]	35975	delivery	5	13
125114	2020-08-24 06:17:47	2020-08-24	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	47441	delivery	5	34
125115	2020-08-24 06:18:24	2020-08-24	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	10150	pick-up	0	20
125116	2020-08-24 06:18:34	2020-08-24	8	[{"id_menu":5,"count":1}]	35016	pick-up	0	8
125117	2020-08-24 06:22:03	2020-08-24	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	47381	delivery	5	36
125118	2020-08-24 06:24:39	2020-08-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	2067	delivery	5	31
125119	2020-08-24 06:31:48	2020-08-24	9	[{"id_menu":7,"count":1}]	47400	delivery	5	14
125120	2020-08-24 06:34:51	2020-08-24	9	[{"id_menu":6,"count":1}]	23976	delivery	5	14
125121	2020-08-24 06:36:03	2020-08-24	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	21662	delivery	5	45
125122	2020-08-24 06:38:07	2020-08-24	14	[{"id_menu":2,"count":1}]	1065	pick-up	0	14
125123	2020-08-24 06:43:17	2020-08-24	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	47456	delivery	5	55
125124	2020-08-24 06:43:18	2020-08-24	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	47503	delivery	5	35
125125	2020-08-24 06:47:03	2020-08-24	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	8252	pick-up	0	31
125126	2020-08-24 06:50:06	2020-08-24	14	[{"id_menu":2,"count":1}]	3435	delivery	5	19
125127	2020-08-24 06:55:10	2020-08-24	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33581	delivery	5	35
125128	2020-08-24 06:55:37	2020-08-24	17	[{"id_menu":4,"count":1}]	1121	pick-up	0	17
125129	2020-08-24 06:55:59	2020-08-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25231	delivery	5	23
125130	2020-08-24 06:58:29	2020-08-24	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	906	pick-up	0	26
125131	2020-08-24 06:58:32	2020-08-24	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	2618	pick-up	0	31
125132	2020-08-24 07:00:45	2020-08-24	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	47333	delivery	5	25
125133	2020-08-24 07:01:24	2020-08-24	8	[{"id_menu":5,"count":1}]	11779	pick-up	0	8
125134	2020-08-24 07:01:58	2020-08-24	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	47475	delivery	5	26
125135	2020-08-24 07:03:51	2020-08-24	9	[{"id_menu":7,"count":1}]	9816	delivery	5	14
125136	2020-08-24 07:04:32	2020-08-24	9	[{"id_menu":7,"count":1}]	47355	delivery	5	14
125137	2020-08-24 07:05:43	2020-08-24	9	[{"id_menu":7,"count":1}]	20155	delivery	5	14
125138	2020-08-24 07:08:38	2020-08-24	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	6161	delivery	5	25
125139	2020-08-24 07:09:13	2020-08-24	12	[{"id_menu":3,"count":1}]	47342	delivery	5	17
125140	2020-08-24 07:11:14	2020-08-24	8	[{"id_menu":5,"count":1}]	42289	delivery	5	13
125141	2020-08-24 07:13:07	2020-08-24	12	[{"id_menu":1,"count":1}]	47426	pick-up	0	12
125142	2020-08-24 07:16:50	2020-08-24	12	[{"id_menu":1,"count":1}]	4132	pick-up	0	12
125143	2020-08-24 07:18:23	2020-08-24	14	[{"id_menu":2,"count":1}]	4641	pick-up	0	14
125144	2020-08-24 07:20:08	2020-08-24	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	32663	delivery	5	39
125145	2020-08-24 07:24:49	2020-08-24	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	47445	delivery	5	26
125146	2020-08-24 07:28:00	2020-08-24	17	[{"id_menu":4,"count":1}]	47349	delivery	5	22
125147	2020-08-24 07:37:00	2020-08-24	12	[{"id_menu":3,"count":1}]	47467	delivery	5	17
125148	2020-08-24 07:40:33	2020-08-24	9	[{"id_menu":7,"count":1}]	22624	delivery	5	14
125149	2020-08-24 07:42:35	2020-08-24	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3705	delivery	5	31
125150	2020-08-24 07:47:40	2020-08-24	9	[{"id_menu":6,"count":1}]	47389	delivery	5	14
125151	2020-08-24 07:48:34	2020-08-24	12	[{"id_menu":3,"count":1}]	43935	delivery	5	17
125152	2020-08-24 07:49:14	2020-08-24	9	[{"id_menu":6,"count":1}]	15497	delivery	5	14
125153	2020-08-24 07:50:06	2020-08-24	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	47341	delivery	5	40
125154	2020-08-24 07:54:06	2020-08-24	12	[{"id_menu":3,"count":1}]	29533	delivery	5	17
125155	2020-08-24 08:00:22	2020-08-24	12	[{"id_menu":1,"count":1}]	6073	delivery	5	17
125156	2020-08-24 08:00:39	2020-08-24	9	[{"id_menu":6,"count":1}]	5579	delivery	5	14
125157	2020-08-24 08:02:48	2020-08-24	9	[{"id_menu":7,"count":1}]	23586	delivery	5	14
125158	2020-08-24 08:03:27	2020-08-24	8	[{"id_menu":5,"count":1}]	34413	delivery	5	13
125159	2020-08-24 08:03:31	2020-08-24	9	[{"id_menu":6,"count":1}]	36081	delivery	5	14
125160	2020-08-24 08:05:37	2020-08-24	12	[{"id_menu":1,"count":1}]	5338	pick-up	0	12
125161	2020-08-24 08:08:39	2020-08-24	12	[{"id_menu":3,"count":1}]	10687	pick-up	0	12
125162	2020-08-24 08:10:26	2020-08-24	9	[{"id_menu":6,"count":1}]	4825	pick-up	0	9
125163	2020-08-24 08:16:19	2020-08-24	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	7899	delivery	5	45
125164	2020-08-24 08:18:22	2020-08-24	12	[{"id_menu":3,"count":2}]	27070	delivery	5	17
125165	2020-08-24 08:23:49	2020-08-24	17	[{"id_menu":4,"count":2}]	2557	delivery	5	22
125166	2020-08-24 08:24:19	2020-08-24	8	[{"id_menu":5,"count":1}]	30805	delivery	5	13
125167	2020-08-24 08:29:36	2020-08-24	14	[{"id_menu":2,"count":1}]	15422	delivery	5	19
125168	2020-08-24 08:29:44	2020-08-24	8	[{"id_menu":5,"count":1}]	47377	delivery	5	13
125169	2020-08-24 08:30:36	2020-08-24	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	40856	delivery	5	34
125170	2020-08-24 08:30:57	2020-08-24	17	[{"id_menu":4,"count":1}]	4593	delivery	5	22
125171	2020-08-24 08:32:37	2020-08-24	12	[{"id_menu":1,"count":1}]	274	delivery	5	17
125172	2020-08-24 08:35:56	2020-08-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	41152	delivery	5	28
125173	2020-08-24 08:36:34	2020-08-24	12	[{"id_menu":1,"count":1}]	24980	pick-up	0	12
125174	2020-08-24 08:38:47	2020-08-24	14	[{"id_menu":2,"count":1}]	47329	delivery	5	19
125175	2020-08-24 08:46:05	2020-08-24	9	[{"id_menu":7,"count":1}]	44308	delivery	5	14
125176	2020-08-24 08:50:07	2020-08-24	9	[{"id_menu":6,"count":1}]	28781	delivery	5	14
125177	2020-08-24 08:55:47	2020-08-24	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	32571	delivery	5	43
125178	2020-08-24 08:57:15	2020-08-24	12	[{"id_menu":3,"count":1}]	4370	delivery	5	17
125179	2020-08-24 08:58:47	2020-08-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	47498	delivery	5	28
125180	2020-08-24 09:09:11	2020-08-24	14	[{"id_menu":2,"count":1}]	28293	pick-up	0	14
125181	2020-08-24 09:11:53	2020-08-24	9	[{"id_menu":6,"count":1}]	31442	pick-up	0	9
125182	2020-08-24 09:11:58	2020-08-24	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	27313	delivery	5	22
125183	2020-08-24 09:14:37	2020-08-24	9	[{"id_menu":6,"count":1}]	41506	delivery	5	14
125184	2020-08-24 09:15:22	2020-08-24	12	[{"id_menu":3,"count":1}]	30063	delivery	5	17
125185	2020-08-24 09:20:40	2020-08-24	9	[{"id_menu":6,"count":1}]	47346	delivery	5	14
125186	2020-08-24 09:20:47	2020-08-24	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	33829	pick-up	0	34
125187	2020-08-24 09:20:49	2020-08-24	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	14488	delivery	5	34
125188	2020-08-24 09:22:15	2020-08-24	9	[{"id_menu":6,"count":2}]	2821	pick-up	0	9
125189	2020-08-24 09:25:51	2020-08-24	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	4395	pick-up	0	21
125190	2020-08-24 09:28:07	2020-08-24	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	21552	delivery	5	26
125191	2020-08-24 09:28:30	2020-08-24	17	[{"id_menu":4,"count":1}]	47452	delivery	5	22
125192	2020-08-24 09:29:55	2020-08-24	9	[{"id_menu":6,"count":1}]	42568	delivery	5	14
125193	2020-08-24 09:30:36	2020-08-24	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	41829	delivery	5	36
125194	2020-08-24 09:32:06	2020-08-24	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	47447	delivery	5	43
125195	2020-08-24 09:37:15	2020-08-24	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	15875	delivery	5	40
125196	2020-08-24 09:38:10	2020-08-24	12	[{"id_menu":1,"count":1}]	22495	delivery	5	17
125197	2020-08-24 09:38:36	2020-08-24	9	[{"id_menu":6,"count":1}]	47512	delivery	5	14
125198	2020-08-24 09:40:28	2020-08-24	9	[{"id_menu":6,"count":1}]	18658	delivery	5	14
125199	2020-08-24 09:43:07	2020-08-24	8	[{"id_menu":5,"count":1}]	30913	delivery	5	13
125200	2020-08-24 09:48:27	2020-08-24	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	47352	pick-up	0	29
125201	2020-08-24 09:54:12	2020-08-24	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	47425	delivery	5	31
125202	2020-08-24 09:56:50	2020-08-24	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	10674	delivery	5	36
125203	2020-08-24 09:58:39	2020-08-24	9	[{"id_menu":7,"count":1}]	5215	pick-up	0	9
125204	2020-08-24 10:03:05	2020-08-24	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	28949	delivery	5	23
125205	2020-08-24 10:05:20	2020-08-24	9	[{"id_menu":6,"count":1}]	13746	delivery	5	14
125206	2020-08-24 10:07:10	2020-08-24	8	[{"id_menu":5,"count":1}]	24882	delivery	5	13
125207	2020-08-24 10:09:07	2020-08-24	9	[{"id_menu":6,"count":1}]	27519	delivery	5	14
125208	2020-08-24 10:11:58	2020-08-24	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	43128	delivery	5	26
125209	2020-08-24 10:14:51	2020-08-24	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	17866	delivery	5	31
125210	2020-08-24 10:16:15	2020-08-24	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	28670	delivery	5	30
125211	2020-08-24 10:20:30	2020-08-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	35132	delivery	5	28
125212	2020-08-24 10:21:01	2020-08-24	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13713	delivery	5	34
125213	2020-08-24 10:23:25	2020-08-24	9	[{"id_menu":6,"count":1}]	17074	pick-up	0	9
125214	2020-08-24 10:25:24	2020-08-24	17	[{"id_menu":4,"count":1}]	26927	delivery	5	22
125215	2020-08-24 10:26:31	2020-08-24	9	[{"id_menu":7,"count":1}]	15286	delivery	5	14
125216	2020-08-24 10:27:15	2020-08-24	9	[{"id_menu":6,"count":1}]	16952	delivery	5	14
125217	2020-08-24 10:28:47	2020-08-24	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	47382	delivery	5	30
125218	2020-08-24 10:30:31	2020-08-24	8	[{"id_menu":5,"count":1}]	11930	pick-up	0	8
125219	2020-08-24 10:31:48	2020-08-24	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	47438	delivery	5	26
125220	2020-08-24 10:32:54	2020-08-24	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	21	pick-up	0	26
125221	2020-08-24 10:33:24	2020-08-24	14	[{"id_menu":2,"count":1}]	2902	pick-up	0	14
125222	2020-08-24 10:42:44	2020-08-24	9	[{"id_menu":6,"count":1}]	1874	pick-up	0	9
125223	2020-08-24 10:51:36	2020-08-24	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	43948	delivery	5	31
125224	2020-08-24 10:55:16	2020-08-24	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	10412	pick-up	0	26
125225	2020-08-24 10:57:54	2020-08-24	9	[{"id_menu":6,"count":1}]	32776	delivery	5	14
125226	2020-08-24 11:02:28	2020-08-24	8	[{"id_menu":5,"count":1}]	33614	pick-up	0	8
125227	2020-08-24 11:03:30	2020-08-24	9	[{"id_menu":7,"count":1}]	424	delivery	5	14
125228	2020-08-24 11:04:18	2020-08-24	14	[{"id_menu":2,"count":2}]	27061	delivery	5	19
125229	2020-08-24 11:09:38	2020-08-24	14	[{"id_menu":2,"count":1}]	1485	pick-up	0	14
125230	2020-08-24 11:19:51	2020-08-24	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	14585	pick-up	0	24
125231	2020-08-24 11:19:56	2020-08-24	17	[{"id_menu":4,"count":1}]	41642	delivery	5	22
125232	2020-08-24 11:22:20	2020-08-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	45362	delivery	5	31
125233	2020-08-24 11:26:38	2020-08-24	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	37458	delivery	5	30
125234	2020-08-24 11:29:29	2020-08-24	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	7253	delivery	5	26
125235	2020-08-24 11:32:55	2020-08-24	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4794	delivery	5	22
125236	2020-08-24 11:33:37	2020-08-24	9	[{"id_menu":7,"count":1}]	21426	delivery	5	14
125237	2020-08-24 11:37:22	2020-08-24	9	[{"id_menu":7,"count":1}]	43245	pick-up	0	9
125238	2020-08-24 11:37:47	2020-08-24	12	[{"id_menu":3,"count":1}]	27749	delivery	5	17
125239	2020-08-24 11:38:00	2020-08-24	9	[{"id_menu":6,"count":1}]	47353	delivery	5	14
125240	2020-08-24 11:40:31	2020-08-24	9	[{"id_menu":7,"count":1}]	47379	delivery	5	14
125241	2020-08-24 11:49:19	2020-08-24	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	45936	delivery	5	34
125242	2020-08-24 11:49:20	2020-08-24	9	[{"id_menu":6,"count":1}]	47428	delivery	5	14
125243	2020-08-24 11:55:29	2020-08-24	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39244	delivery	5	31
125244	2020-08-24 11:55:45	2020-08-24	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	41654	delivery	5	34
125245	2020-08-24 11:57:52	2020-08-24	9	[{"id_menu":7,"count":1}]	3604	pick-up	0	9
125246	2020-08-24 11:58:11	2020-08-24	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	47454	delivery	5	48
125247	2020-08-24 11:58:50	2020-08-24	14	[{"id_menu":2,"count":1}]	23129	delivery	5	19
125248	2020-08-24 12:00:28	2020-08-24	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	23933	delivery	5	26
125249	2020-08-24 12:03:25	2020-08-24	12	[{"id_menu":1,"count":1}]	25997	pick-up	0	12
125250	2020-08-24 12:10:00	2020-08-24	9	[{"id_menu":7,"count":1}]	27256	delivery	5	14
125251	2020-08-24 12:13:18	2020-08-24	8	[{"id_menu":5,"count":1}]	47374	delivery	5	13
125252	2020-08-24 12:13:29	2020-08-24	12	[{"id_menu":3,"count":1}]	21794	delivery	5	17
125253	2020-08-24 12:20:26	2020-08-24	12	[{"id_menu":3,"count":1}]	47338	delivery	5	17
125254	2020-08-24 12:28:16	2020-08-24	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5945	delivery	5	52
125255	2020-08-24 12:28:59	2020-08-24	17	[{"id_menu":4,"count":1}]	42318	pick-up	0	17
125256	2020-08-24 12:34:04	2020-08-24	9	[{"id_menu":6,"count":1}]	38316	pick-up	0	9
125257	2020-08-24 12:40:03	2020-08-24	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	28078	delivery	5	43
125258	2020-08-24 12:45:36	2020-08-24	12	[{"id_menu":3,"count":1}]	47495	delivery	5	17
125259	2020-08-24 12:46:45	2020-08-24	14	[{"id_menu":2,"count":1}]	47344	pick-up	0	14
125260	2020-08-24 12:47:42	2020-08-24	9	[{"id_menu":7,"count":1}]	16452	delivery	5	14
125261	2020-08-24 12:56:06	2020-08-24	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	47390	delivery	5	26
125262	2020-08-24 12:57:44	2020-08-24	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	6923	delivery	5	26
125263	2020-08-24 12:59:40	2020-08-24	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	40711	delivery	5	36
125264	2020-08-24 13:02:21	2020-08-24	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	35209	pick-up	0	26
125265	2020-08-24 13:04:18	2020-08-24	9	[{"id_menu":7,"count":1}]	11858	delivery	5	14
125266	2020-08-24 13:05:04	2020-08-24	9	[{"id_menu":7,"count":1}]	18990	delivery	5	14
125267	2020-08-24 13:08:06	2020-08-24	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18475	delivery	5	35
125268	2020-08-24 13:09:01	2020-08-24	8	[{"id_menu":5,"count":1}]	35972	pick-up	0	8
125269	2020-08-24 13:14:52	2020-08-24	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	36993	delivery	5	36
125270	2020-08-24 13:15:54	2020-08-24	12	[{"id_menu":3,"count":1}]	7528	delivery	5	17
125271	2020-08-24 13:19:47	2020-08-24	14	[{"id_menu":2,"count":1}]	7200	pick-up	0	14
125272	2020-08-24 13:21:37	2020-08-24	9	[{"id_menu":6,"count":1}]	28755	delivery	5	14
125273	2020-08-24 13:25:45	2020-08-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	40658	pick-up	0	23
125274	2020-08-24 13:26:44	2020-08-24	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	47463	delivery	5	35
125275	2020-08-24 13:31:16	2020-08-24	9	[{"id_menu":6,"count":1}]	10103	delivery	5	14
125276	2020-08-24 13:37:59	2020-08-24	9	[{"id_menu":6,"count":1}]	43933	delivery	5	14
125277	2020-08-24 13:40:13	2020-08-24	9	[{"id_menu":6,"count":1}]	30413	delivery	5	14
125278	2020-08-24 13:41:58	2020-08-24	12	[{"id_menu":1,"count":1}]	4274	delivery	5	17
125279	2020-08-24 13:44:59	2020-08-24	17	[{"id_menu":4,"count":1}]	1306	pick-up	0	17
125280	2020-08-24 13:51:26	2020-08-24	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	37855	delivery	5	40
125281	2020-08-24 13:56:10	2020-08-24	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18612	delivery	5	40
125282	2020-08-24 14:03:34	2020-08-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	640	pick-up	0	23
125283	2020-08-24 14:03:49	2020-08-24	12	[{"id_menu":3,"count":1}]	47392	delivery	5	17
125284	2020-08-24 14:11:57	2020-08-24	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43587	delivery	5	37
125285	2020-08-24 14:12:41	2020-08-24	17	[{"id_menu":4,"count":1}]	35804	delivery	5	22
125286	2020-08-24 14:18:15	2020-08-24	12	[{"id_menu":1,"count":1}]	5835	delivery	5	17
125287	2020-08-24 14:18:19	2020-08-24	8	[{"id_menu":5,"count":1}]	40846	delivery	5	13
125288	2020-08-24 14:22:27	2020-08-24	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34456	delivery	5	48
125289	2020-08-24 14:23:40	2020-08-24	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	19295	delivery	5	42
125290	2020-08-24 14:24:23	2020-08-24	9	[{"id_menu":7,"count":1}]	6090	pick-up	0	9
125291	2020-08-24 14:25:15	2020-08-24	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	18646	pick-up	0	25
125292	2020-08-24 14:26:25	2020-08-24	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	47497	delivery	5	25
125293	2020-08-24 14:26:50	2020-08-24	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5975	delivery	5	52
125294	2020-08-24 14:28:50	2020-08-24	14	[{"id_menu":2,"count":1}]	43856	pick-up	0	14
125295	2020-08-24 14:30:25	2020-08-24	8	[{"id_menu":5,"count":1}]	26154	delivery	5	13
125296	2020-08-24 14:33:07	2020-08-24	17	[{"id_menu":4,"count":1}]	4710	pick-up	0	17
125297	2020-08-24 14:33:10	2020-08-24	12	[{"id_menu":1,"count":1}]	7753	delivery	5	17
125298	2020-08-24 14:33:27	2020-08-24	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	7726	pick-up	0	26
125299	2020-08-24 14:34:09	2020-08-24	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	47370	delivery	5	31
125300	2020-08-24 14:34:13	2020-08-24	9	[{"id_menu":6,"count":1}]	39715	delivery	5	14
125301	2020-08-24 14:34:15	2020-08-24	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	46734	delivery	5	34
125302	2020-08-24 14:36:36	2020-08-24	17	[{"id_menu":4,"count":1}]	47357	pick-up	0	17
125303	2020-08-24 14:39:18	2020-08-24	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23975	delivery	5	35
125304	2020-08-24 14:44:13	2020-08-24	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	36480	delivery	5	26
125305	2020-08-24 14:45:11	2020-08-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	27264	delivery	5	31
125306	2020-08-24 14:47:50	2020-08-24	8	[{"id_menu":5,"count":1}]	40025	delivery	5	13
125307	2020-08-24 15:05:36	2020-08-24	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	43008	delivery	5	39
125308	2020-08-24 15:06:35	2020-08-24	17	[{"id_menu":4,"count":1}]	16825	pick-up	0	17
125309	2020-08-24 15:06:54	2020-08-24	14	[{"id_menu":2,"count":1}]	23333	pick-up	0	14
125310	2020-08-24 15:08:13	2020-08-24	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	46380	delivery	5	40
125311	2020-08-24 15:09:12	2020-08-24	12	[{"id_menu":3,"count":1}]	16270	delivery	5	17
125312	2020-08-24 15:10:14	2020-08-24	12	[{"id_menu":1,"count":1}]	8757	pick-up	0	12
125313	2020-08-24 15:10:46	2020-08-24	14	[{"id_menu":2,"count":1}]	13299	delivery	5	19
125314	2020-08-24 15:17:26	2020-08-24	12	[{"id_menu":3,"count":1}]	29277	delivery	5	17
125315	2020-08-24 15:20:10	2020-08-24	8	[{"id_menu":5,"count":1}]	16523	delivery	5	13
125316	2020-08-24 15:23:32	2020-08-24	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	18604	pick-up	0	21
125317	2020-08-24 15:23:47	2020-08-24	9	[{"id_menu":6,"count":1}]	15407	delivery	5	14
125318	2020-08-24 15:29:17	2020-08-24	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	42722	delivery	5	22
125319	2020-08-24 15:30:59	2020-08-24	12	[{"id_menu":3,"count":1}]	44587	delivery	5	17
125320	2020-08-24 15:34:40	2020-08-24	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	33263	delivery	5	42
125321	2020-08-24 15:34:43	2020-08-24	12	[{"id_menu":3,"count":1}]	47427	pick-up	0	12
125322	2020-08-24 15:34:52	2020-08-24	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8779	delivery	5	31
125323	2020-08-24 15:37:25	2020-08-24	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	44149	delivery	5	31
125324	2020-08-24 15:45:56	2020-08-24	17	[{"id_menu":4,"count":1}]	32603	delivery	5	22
125325	2020-08-24 15:48:02	2020-08-24	12	[{"id_menu":1,"count":1}]	47408	pick-up	0	12
125326	2020-08-24 15:52:15	2020-08-24	8	[{"id_menu":5,"count":1}]	47331	delivery	5	13
125327	2020-08-24 15:53:46	2020-08-24	8	[{"id_menu":5,"count":1}]	47401	pick-up	0	8
125328	2020-08-24 15:54:27	2020-08-24	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":3}]	33010	delivery	5	25
125329	2020-08-24 15:54:45	2020-08-24	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	25950	delivery	5	36
125330	2020-08-24 15:57:15	2020-08-24	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	47460	delivery	5	28
125331	2020-08-24 15:58:53	2020-08-24	8	[{"id_menu":5,"count":1}]	8275	delivery	5	13
125332	2020-08-24 16:01:45	2020-08-24	9	[{"id_menu":6,"count":1}]	47494	delivery	5	14
125333	2020-08-24 16:03:20	2020-08-24	9	[{"id_menu":7,"count":1}]	26714	delivery	5	14
125334	2020-08-24 16:08:55	2020-08-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43350	delivery	5	23
125335	2020-08-24 16:09:24	2020-08-24	8	[{"id_menu":5,"count":1}]	34140	pick-up	0	8
125336	2020-08-24 16:10:37	2020-08-24	8	[{"id_menu":5,"count":2}]	14475	delivery	5	13
125337	2020-08-24 16:11:51	2020-08-24	9	[{"id_menu":6,"count":1}]	47405	delivery	5	14
125338	2020-08-24 16:13:18	2020-08-24	14	[{"id_menu":2,"count":1}]	945	pick-up	0	14
125339	2020-08-24 16:13:27	2020-08-24	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1267	pick-up	0	21
125340	2020-08-24 16:15:24	2020-08-24	14	[{"id_menu":2,"count":1}]	47510	delivery	5	19
125341	2020-08-24 16:15:47	2020-08-24	12	[{"id_menu":1,"count":1}]	9252	pick-up	0	12
125342	2020-08-24 16:16:36	2020-08-24	9	[{"id_menu":6,"count":1}]	24943	delivery	5	14
125343	2020-08-24 16:22:08	2020-08-24	12	[{"id_menu":3,"count":1}]	287	pick-up	0	12
125344	2020-08-24 16:28:42	2020-08-24	8	[{"id_menu":5,"count":1}]	47324	delivery	5	13
125345	2020-08-24 16:28:51	2020-08-24	12	[{"id_menu":1,"count":1}]	47489	pick-up	0	12
125346	2020-08-24 16:29:06	2020-08-24	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	17564	delivery	5	57
125347	2020-08-24 16:31:13	2020-08-24	9	[{"id_menu":6,"count":1}]	6328	pick-up	0	9
125348	2020-08-24 16:31:21	2020-08-24	14	[{"id_menu":2,"count":1}]	47367	pick-up	0	14
125349	2020-08-24 16:35:28	2020-08-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	43165	delivery	5	22
125350	2020-08-24 16:38:42	2020-08-24	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	39665	delivery	5	39
125351	2020-08-24 16:41:19	2020-08-24	9	[{"id_menu":6,"count":1}]	16338	delivery	5	14
125352	2020-08-24 16:44:48	2020-08-24	39	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	33414	delivery	5	44
125353	2020-08-24 16:56:41	2020-08-24	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	2300	delivery	5	31
125354	2020-08-24 16:58:34	2020-08-24	9	[{"id_menu":6,"count":1}]	45206	delivery	5	14
125355	2020-08-24 16:58:54	2020-08-24	17	[{"id_menu":4,"count":1}]	23819	delivery	5	22
125356	2020-08-24 17:01:49	2020-08-24	8	[{"id_menu":5,"count":1}]	47326	delivery	5	13
125357	2020-08-24 17:04:30	2020-08-24	9	[{"id_menu":6,"count":1}]	16395	delivery	5	14
125358	2020-08-24 17:07:56	2020-08-24	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1562	pick-up	0	21
125359	2020-08-24 17:08:23	2020-08-24	14	[{"id_menu":2,"count":1}]	21849	pick-up	0	14
125360	2020-08-24 17:10:21	2020-08-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14710	pick-up	0	18
125361	2020-08-24 17:11:54	2020-08-24	17	[{"id_menu":4,"count":1}]	4695	delivery	5	22
125362	2020-08-24 17:12:00	2020-08-24	9	[{"id_menu":7,"count":1}]	47421	delivery	5	14
125363	2020-08-24 17:13:04	2020-08-24	12	[{"id_menu":3,"count":1}]	21496	delivery	5	17
125364	2020-08-24 17:21:32	2020-08-24	9	[{"id_menu":7,"count":1}]	22279	delivery	5	14
125365	2020-08-24 17:22:54	2020-08-24	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	24741	delivery	5	22
125366	2020-08-24 17:30:57	2020-08-24	9	[{"id_menu":6,"count":1}]	29726	delivery	5	14
125367	2020-08-24 17:33:57	2020-08-24	8	[{"id_menu":5,"count":1}]	13547	pick-up	0	8
125368	2020-08-24 17:34:03	2020-08-24	12	[{"id_menu":1,"count":1}]	3289	pick-up	0	12
125369	2020-08-24 17:34:41	2020-08-24	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	4863	pick-up	0	26
125370	2020-08-24 17:36:10	2020-08-24	9	[{"id_menu":6,"count":1}]	46535	delivery	5	14
125371	2020-08-24 17:40:04	2020-08-24	9	[{"id_menu":6,"count":1}]	22784	pick-up	0	9
125372	2020-08-24 17:42:17	2020-08-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	44872	delivery	5	23
125373	2020-08-24 17:56:04	2020-08-24	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	31779	delivery	5	30
125374	2020-08-24 17:57:34	2020-08-24	9	[{"id_menu":7,"count":1}]	47413	delivery	5	14
125375	2020-08-24 18:02:08	2020-08-24	12	[{"id_menu":3,"count":1}]	47502	delivery	5	17
125376	2020-08-24 18:04:20	2020-08-24	8	[{"id_menu":5,"count":1}]	32805	delivery	5	13
125377	2020-08-24 18:04:33	2020-08-24	9	[{"id_menu":6,"count":1}]	3752	pick-up	0	9
125378	2020-08-24 18:14:05	2020-08-24	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	44835	delivery	5	22
125379	2020-08-24 18:19:48	2020-08-24	17	[{"id_menu":4,"count":1}]	47453	delivery	5	22
125380	2020-08-24 18:21:18	2020-08-24	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	47363	delivery	5	27
125381	2020-08-24 18:22:29	2020-08-24	17	[{"id_menu":4,"count":1}]	24427	delivery	5	22
125382	2020-08-24 18:24:58	2020-08-24	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28090	delivery	5	34
125383	2020-08-24 18:28:37	2020-08-24	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	47461	delivery	5	34
125384	2020-08-24 18:31:07	2020-08-24	9	[{"id_menu":7,"count":1}]	40126	delivery	5	14
125385	2020-08-24 18:38:18	2020-08-24	9	[{"id_menu":7,"count":1}]	12894	delivery	5	14
125386	2020-08-24 18:43:58	2020-08-24	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8279	delivery	5	57
125387	2020-08-24 18:44:42	2020-08-24	9	[{"id_menu":7,"count":1}]	31661	pick-up	0	9
125388	2020-08-24 18:47:00	2020-08-24	8	[{"id_menu":5,"count":1}]	26937	pick-up	0	8
125389	2020-08-24 18:59:34	2020-08-24	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	37742	delivery	5	23
125390	2020-08-24 19:02:37	2020-08-24	8	[{"id_menu":5,"count":1}]	47446	delivery	5	13
125391	2020-08-24 19:05:40	2020-08-24	14	[{"id_menu":2,"count":2}]	47415	pick-up	0	14
125392	2020-08-24 19:06:05	2020-08-24	9	[{"id_menu":6,"count":1}]	23646	delivery	5	14
125393	2020-08-24 19:08:18	2020-08-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	47321	delivery	5	28
125394	2020-08-24 19:11:25	2020-08-24	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	45245	delivery	5	31
125395	2020-08-24 19:12:31	2020-08-24	12	[{"id_menu":1,"count":1}]	17041	delivery	5	17
125396	2020-08-24 19:12:40	2020-08-24	9	[{"id_menu":7,"count":1}]	39280	delivery	5	14
125397	2020-08-24 19:13:32	2020-08-24	9	[{"id_menu":6,"count":1}]	34875	delivery	5	14
125398	2020-08-24 19:14:02	2020-08-24	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	41055	delivery	5	43
125399	2020-08-24 19:16:03	2020-08-24	9	[{"id_menu":7,"count":1}]	2666	pick-up	0	9
125400	2020-08-24 19:16:12	2020-08-24	14	[{"id_menu":2,"count":1}]	41156	delivery	5	19
125401	2020-08-24 19:16:57	2020-08-24	17	[{"id_menu":4,"count":1}]	42082	delivery	5	22
125402	2020-08-24 19:17:08	2020-08-24	12	[{"id_menu":1,"count":1}]	39238	pick-up	0	12
125403	2020-08-24 19:18:42	2020-08-24	14	[{"id_menu":2,"count":1}]	22626	delivery	5	19
125404	2020-08-24 19:23:27	2020-08-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	47491	delivery	5	28
125405	2020-08-24 19:35:20	2020-08-24	9	[{"id_menu":7,"count":1}]	14204	delivery	5	14
125406	2020-08-24 19:35:34	2020-08-24	12	[{"id_menu":3,"count":1}]	36064	delivery	5	17
125407	2020-08-24 19:39:03	2020-08-24	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	39850	delivery	5	36
125408	2020-08-24 19:39:16	2020-08-24	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	17685	pick-up	0	35
125409	2020-08-24 19:43:46	2020-08-24	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13099	delivery	5	40
125410	2020-08-24 19:46:12	2020-08-24	14	[{"id_menu":2,"count":1}]	20546	delivery	5	19
125411	2020-08-24 19:50:56	2020-08-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	47334	delivery	5	22
125412	2020-08-24 19:53:52	2020-08-24	17	[{"id_menu":4,"count":1}]	18353	pick-up	0	17
125413	2020-08-24 19:55:03	2020-08-24	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14342	delivery	5	57
125414	2020-08-24 19:57:05	2020-08-24	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	12183	delivery	5	34
125415	2020-08-24 19:59:34	2020-08-24	12	[{"id_menu":1,"count":1}]	3677	delivery	5	17
125482	2020-08-24 23:02:17	2020-08-24	9	[{"id_menu":7,"count":1}]	22938	pick-up	0	9
125416	2020-08-24 20:02:07	2020-08-24	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	47402	delivery	5	40
125417	2020-08-24 20:06:53	2020-08-24	12	[{"id_menu":3,"count":1}]	3540	delivery	5	17
125418	2020-08-24 20:07:06	2020-08-24	17	[{"id_menu":4,"count":2}]	47486	delivery	5	22
125419	2020-08-24 20:07:16	2020-08-24	9	[{"id_menu":6,"count":1}]	46786	delivery	5	14
125420	2020-08-24 20:08:06	2020-08-24	12	[{"id_menu":3,"count":1}]	46943	delivery	5	17
125421	2020-08-24 20:08:41	2020-08-24	12	[{"id_menu":3,"count":1}]	47364	delivery	5	17
125422	2020-08-24 20:12:43	2020-08-24	9	[{"id_menu":7,"count":1}]	2462	delivery	5	14
125423	2020-08-24 20:14:58	2020-08-24	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	26232	pick-up	0	21
125424	2020-08-24 20:22:07	2020-08-24	9	[{"id_menu":7,"count":1}]	43371	delivery	5	14
125425	2020-08-24 20:22:17	2020-08-24	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	47485	delivery	5	40
125426	2020-08-24 20:23:59	2020-08-24	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3153	pick-up	0	26
125427	2020-08-24 20:24:03	2020-08-24	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	47354	pick-up	0	25
125428	2020-08-24 20:25:48	2020-08-24	14	[{"id_menu":2,"count":1}]	18666	delivery	5	19
125429	2020-08-24 20:27:40	2020-08-24	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	38909	delivery	5	40
125430	2020-08-24 20:31:13	2020-08-24	8	[{"id_menu":5,"count":1}]	33265	delivery	5	13
125431	2020-08-24 20:31:17	2020-08-24	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37231	delivery	5	48
125432	2020-08-24 20:37:53	2020-08-24	9	[{"id_menu":7,"count":1}]	2623	pick-up	0	9
125433	2020-08-24 20:39:01	2020-08-24	9	[{"id_menu":7,"count":1}]	47383	delivery	5	14
125434	2020-08-24 20:39:12	2020-08-24	9	[{"id_menu":7,"count":1}]	25267	delivery	5	14
125435	2020-08-24 20:41:02	2020-08-24	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	33584	delivery	5	48
125436	2020-08-24 20:44:38	2020-08-24	8	[{"id_menu":5,"count":1}]	47436	delivery	5	13
125437	2020-08-24 20:44:44	2020-08-24	9	[{"id_menu":6,"count":1}]	28778	delivery	5	14
125438	2020-08-24 20:46:44	2020-08-24	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	47484	delivery	5	43
125439	2020-08-24 20:47:44	2020-08-24	9	[{"id_menu":6,"count":1}]	47323	delivery	5	14
125440	2020-08-24 20:49:27	2020-08-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	42283	delivery	5	28
125441	2020-08-24 20:55:09	2020-08-24	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	47376	delivery	5	22
125442	2020-08-24 20:55:45	2020-08-24	8	[{"id_menu":5,"count":1}]	16812	delivery	5	13
125443	2020-08-24 21:04:04	2020-08-24	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	14130	delivery	5	26
125444	2020-08-24 21:08:35	2020-08-24	12	[{"id_menu":1,"count":1}]	47398	delivery	5	17
125445	2020-08-24 21:12:37	2020-08-24	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2761	delivery	5	31
125446	2020-08-24 21:19:37	2020-08-24	17	[{"id_menu":4,"count":1}]	42809	pick-up	0	17
125447	2020-08-24 21:20:23	2020-08-24	9	[{"id_menu":6,"count":1}]	47418	delivery	5	14
125448	2020-08-24 21:26:06	2020-08-24	9	[{"id_menu":7,"count":1}]	47451	pick-up	0	9
125449	2020-08-24 21:26:37	2020-08-24	9	[{"id_menu":6,"count":1}]	37531	pick-up	0	9
125450	2020-08-24 21:28:34	2020-08-24	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	19143	delivery	5	27
125451	2020-08-24 21:34:09	2020-08-24	12	[{"id_menu":3,"count":1}]	47366	delivery	5	17
125452	2020-08-24 21:38:27	2020-08-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40288	delivery	5	23
125453	2020-08-24 21:43:09	2020-08-24	14	[{"id_menu":2,"count":1}]	2383	pick-up	0	14
125454	2020-08-24 21:45:22	2020-08-24	14	[{"id_menu":2,"count":1}]	37166	delivery	5	19
125455	2020-08-24 21:45:25	2020-08-24	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	10670	delivery	5	42
125456	2020-08-24 21:57:30	2020-08-24	12	[{"id_menu":3,"count":1}]	14348	delivery	5	17
125457	2020-08-24 22:05:31	2020-08-24	9	[{"id_menu":6,"count":1}]	38676	pick-up	0	9
125458	2020-08-24 22:05:41	2020-08-24	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23589	pick-up	0	17
125459	2020-08-24 22:06:18	2020-08-24	9	[{"id_menu":7,"count":1}]	30183	delivery	5	14
125460	2020-08-24 22:08:11	2020-08-24	9	[{"id_menu":6,"count":1}]	7546	pick-up	0	9
125461	2020-08-24 22:10:53	2020-08-24	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	46815	delivery	5	39
125462	2020-08-24 22:13:36	2020-08-24	14	[{"id_menu":2,"count":2}]	43891	delivery	5	19
125463	2020-08-24 22:18:51	2020-08-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	25130	delivery	5	28
125464	2020-08-24 22:21:38	2020-08-24	9	[{"id_menu":6,"count":1}]	30794	delivery	5	14
125465	2020-08-24 22:21:38	2020-08-24	17	[{"id_menu":4,"count":1}]	47327	pick-up	0	17
125466	2020-08-24 22:23:34	2020-08-24	17	[{"id_menu":4,"count":1}]	15929	delivery	5	22
125467	2020-08-24 22:24:42	2020-08-24	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	16520	delivery	5	26
125468	2020-08-24 22:25:42	2020-08-24	9	[{"id_menu":7,"count":2}]	7552	pick-up	0	9
125469	2020-08-24 22:34:36	2020-08-24	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8651	delivery	5	31
125470	2020-08-24 22:36:14	2020-08-24	32	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	20899	delivery	5	37
125471	2020-08-24 22:38:19	2020-08-24	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	35337	delivery	5	43
125472	2020-08-24 22:44:18	2020-08-24	9	[{"id_menu":6,"count":1}]	36334	delivery	5	14
125473	2020-08-24 22:45:06	2020-08-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	47476	delivery	5	28
125474	2020-08-24 22:46:06	2020-08-24	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	27589	delivery	5	34
125475	2020-08-24 22:46:30	2020-08-24	12	[{"id_menu":1,"count":1}]	313	pick-up	0	12
125476	2020-08-24 22:51:54	2020-08-24	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3629	delivery	5	34
125477	2020-08-24 22:53:43	2020-08-24	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	47465	delivery	5	23
125478	2020-08-24 22:55:09	2020-08-24	9	[{"id_menu":7,"count":1}]	45242	delivery	5	14
125479	2020-08-24 22:55:36	2020-08-24	9	[{"id_menu":7,"count":1}]	37422	delivery	5	14
125480	2020-08-24 22:57:31	2020-08-24	12	[{"id_menu":1,"count":1}]	19315	delivery	5	17
125481	2020-08-24 22:58:33	2020-08-24	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	13535	delivery	5	26
125483	2020-08-24 23:02:38	2020-08-24	17	[{"id_menu":4,"count":1}]	34000	delivery	5	22
125484	2020-08-24 23:06:36	2020-08-24	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	22064	delivery	5	28
125485	2020-08-24 23:10:43	2020-08-24	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	5792	delivery	5	26
125486	2020-08-24 23:12:12	2020-08-24	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	17876	delivery	5	34
125487	2020-08-24 23:16:44	2020-08-24	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	13262	delivery	5	28
125488	2020-08-24 23:26:37	2020-08-24	9	[{"id_menu":6,"count":1}]	32584	pick-up	0	9
125489	2020-08-24 23:27:54	2020-08-24	12	[{"id_menu":1,"count":1}]	47440	delivery	5	17
125490	2020-08-24 23:30:25	2020-08-24	9	[{"id_menu":7,"count":1}]	28943	delivery	5	14
125491	2020-08-24 23:32:18	2020-08-24	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6113	delivery	5	39
125492	2020-08-24 23:51:38	2020-08-24	17	[{"id_menu":4,"count":1}]	47397	delivery	5	22
125493	2020-08-24 23:54:53	2020-08-24	8	[{"id_menu":5,"count":1}]	47407	delivery	5	13
125494	2020-08-24 23:55:20	2020-08-24	14	[{"id_menu":2,"count":1}]	12410	delivery	5	19
125495	2020-08-25 00:01:13	2020-08-25	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	34216	delivery	5	34
125496	2020-08-25 00:03:10	2020-08-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	47669	delivery	5	22
125497	2020-08-25 00:03:25	2020-08-25	12	[{"id_menu":3,"count":2}]	38619	delivery	5	17
125498	2020-08-25 00:03:41	2020-08-25	9	[{"id_menu":6,"count":1}]	47589	delivery	5	14
125499	2020-08-25 00:04:16	2020-08-25	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	47590	delivery	5	26
125500	2020-08-25 00:12:14	2020-08-25	8	[{"id_menu":5,"count":1}]	19435	delivery	5	13
125501	2020-08-25 00:15:49	2020-08-25	17	[{"id_menu":4,"count":1}]	21492	delivery	5	22
125502	2020-08-25 00:18:47	2020-08-25	14	[{"id_menu":2,"count":1}]	47527	delivery	5	19
125503	2020-08-25 00:19:18	2020-08-25	9	[{"id_menu":6,"count":1}]	47542	delivery	5	14
125504	2020-08-25 00:22:01	2020-08-25	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	47711	delivery	5	31
125505	2020-08-25 00:22:57	2020-08-25	9	[{"id_menu":6,"count":2}]	47544	delivery	5	14
125506	2020-08-25 00:23:22	2020-08-25	9	[{"id_menu":6,"count":1}]	11268	delivery	5	14
125507	2020-08-25 00:24:06	2020-08-25	9	[{"id_menu":6,"count":1}]	40017	delivery	5	14
125508	2020-08-25 00:24:10	2020-08-25	17	[{"id_menu":4,"count":1}]	45095	pick-up	0	17
125509	2020-08-25 00:25:47	2020-08-25	12	[{"id_menu":3,"count":1}]	47736	delivery	5	17
125510	2020-08-25 00:34:00	2020-08-25	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	31151	delivery	5	22
125511	2020-08-25 00:47:44	2020-08-25	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	35838	delivery	5	26
125512	2020-08-25 00:49:45	2020-08-25	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	43323	delivery	5	28
125513	2020-08-25 00:50:59	2020-08-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9996	delivery	5	28
125514	2020-08-25 00:51:38	2020-08-25	9	[{"id_menu":7,"count":1}]	47516	delivery	5	14
125515	2020-08-25 00:55:18	2020-08-25	12	[{"id_menu":3,"count":1}]	41793	delivery	5	17
125516	2020-08-25 00:55:39	2020-08-25	9	[{"id_menu":7,"count":1}]	47528	delivery	5	14
125517	2020-08-25 00:55:57	2020-08-25	12	[{"id_menu":3,"count":1}]	29760	pick-up	0	12
125518	2020-08-25 00:56:30	2020-08-25	14	[{"id_menu":2,"count":2}]	46427	delivery	5	19
125519	2020-08-25 00:58:57	2020-08-25	17	[{"id_menu":4,"count":1}]	7706	delivery	5	22
125520	2020-08-25 00:59:04	2020-08-25	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	20044	delivery	5	28
125521	2020-08-25 01:00:41	2020-08-25	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	826	delivery	5	22
125522	2020-08-25 01:01:40	2020-08-25	14	[{"id_menu":2,"count":1}]	47567	delivery	5	19
125523	2020-08-25 01:02:42	2020-08-25	9	[{"id_menu":6,"count":1}]	639	pick-up	0	9
125524	2020-08-25 01:05:20	2020-08-25	9	[{"id_menu":6,"count":1}]	47724	delivery	5	14
125525	2020-08-25 01:05:49	2020-08-25	12	[{"id_menu":3,"count":1}]	17460	pick-up	0	12
125526	2020-08-25 01:11:34	2020-08-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32312	delivery	5	22
125527	2020-08-25 01:20:43	2020-08-25	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	47631	delivery	5	26
125528	2020-08-25 01:23:49	2020-08-25	8	[{"id_menu":5,"count":1}]	13902	delivery	5	13
125529	2020-08-25 01:23:58	2020-08-25	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	44833	delivery	5	34
125530	2020-08-25 01:24:06	2020-08-25	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28993	delivery	5	34
125531	2020-08-25 01:24:58	2020-08-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	23147	delivery	5	23
125532	2020-08-25 01:25:30	2020-08-25	17	[{"id_menu":4,"count":1}]	47676	delivery	5	22
125533	2020-08-25 01:25:42	2020-08-25	9	[{"id_menu":6,"count":1}]	47543	delivery	5	14
125534	2020-08-25 01:25:56	2020-08-25	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	7330	pick-up	0	26
125535	2020-08-25 01:27:36	2020-08-25	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	21324	delivery	5	37
125536	2020-08-25 01:35:25	2020-08-25	12	[{"id_menu":3,"count":1}]	7130	delivery	5	17
125537	2020-08-25 01:35:50	2020-08-25	8	[{"id_menu":5,"count":1}]	31757	delivery	5	13
125538	2020-08-25 01:43:59	2020-08-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	12552	pick-up	0	26
125539	2020-08-25 01:44:07	2020-08-25	14	[{"id_menu":2,"count":1}]	33299	delivery	5	19
125540	2020-08-25 01:46:14	2020-08-25	17	[{"id_menu":4,"count":1}]	36197	delivery	5	22
125541	2020-08-25 01:46:21	2020-08-25	14	[{"id_menu":2,"count":1}]	3052	pick-up	0	14
125542	2020-08-25 01:47:41	2020-08-25	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	12411	delivery	5	34
125543	2020-08-25 01:48:48	2020-08-25	14	[{"id_menu":2,"count":1}]	47690	delivery	5	19
125544	2020-08-25 01:49:38	2020-08-25	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	10851	delivery	5	25
125545	2020-08-25 01:55:52	2020-08-25	17	[{"id_menu":4,"count":1}]	43274	delivery	5	22
125546	2020-08-25 01:59:01	2020-08-25	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	16158	delivery	5	34
125547	2020-08-25 02:04:05	2020-08-25	9	[{"id_menu":7,"count":1}]	47717	delivery	5	14
125548	2020-08-25 02:04:08	2020-08-25	17	[{"id_menu":4,"count":1}]	40136	delivery	5	22
125549	2020-08-25 02:06:56	2020-08-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	8731	delivery	5	28
125550	2020-08-25 02:07:16	2020-08-25	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	7119	pick-up	0	31
125551	2020-08-25 02:07:52	2020-08-25	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	19721	delivery	5	26
125552	2020-08-25 02:12:27	2020-08-25	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	47626	delivery	5	42
125553	2020-08-25 02:12:57	2020-08-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	46299	delivery	5	23
125554	2020-08-25 02:14:32	2020-08-25	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3286	delivery	5	36
125555	2020-08-25 02:19:06	2020-08-25	9	[{"id_menu":6,"count":1}]	6733	delivery	5	14
125556	2020-08-25 02:20:29	2020-08-25	12	[{"id_menu":3,"count":1}]	2902	delivery	5	17
125557	2020-08-25 02:24:46	2020-08-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	25332	delivery	5	23
125558	2020-08-25 02:26:29	2020-08-25	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	37678	pick-up	0	24
125559	2020-08-25 02:32:22	2020-08-25	12	[{"id_menu":1,"count":1}]	17910	delivery	5	17
125560	2020-08-25 02:43:02	2020-08-25	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	23780	delivery	5	31
125561	2020-08-25 02:44:33	2020-08-25	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	10676	delivery	5	26
125562	2020-08-25 02:44:41	2020-08-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	47529	delivery	5	23
125563	2020-08-25 02:50:31	2020-08-25	9	[{"id_menu":6,"count":1}]	6662	pick-up	0	9
125564	2020-08-25 02:51:46	2020-08-25	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	9196	delivery	5	22
125565	2020-08-25 02:52:16	2020-08-25	9	[{"id_menu":6,"count":1}]	1562	pick-up	0	9
125566	2020-08-25 02:53:17	2020-08-25	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	47672	delivery	5	29
125567	2020-08-25 02:56:49	2020-08-25	9	[{"id_menu":7,"count":1}]	33877	delivery	5	14
125568	2020-08-25 02:58:12	2020-08-25	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	11394	pick-up	0	21
125569	2020-08-25 03:00:13	2020-08-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	47709	delivery	5	23
125570	2020-08-25 03:05:48	2020-08-25	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	47612	delivery	5	36
125571	2020-08-25 03:08:04	2020-08-25	12	[{"id_menu":1,"count":1}]	27299	delivery	5	17
125572	2020-08-25 03:11:36	2020-08-25	9	[{"id_menu":7,"count":1}]	28624	delivery	5	14
125573	2020-08-25 03:12:45	2020-08-25	12	[{"id_menu":3,"count":1}]	40690	delivery	5	17
125574	2020-08-25 03:21:48	2020-08-25	9	[{"id_menu":7,"count":1}]	47647	delivery	5	14
125575	2020-08-25 03:22:18	2020-08-25	9	[{"id_menu":6,"count":1}]	39415	delivery	5	14
125576	2020-08-25 03:23:04	2020-08-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	20867	delivery	5	28
125577	2020-08-25 03:28:12	2020-08-25	17	[{"id_menu":4,"count":1}]	9190	delivery	5	22
125578	2020-08-25 03:35:23	2020-08-25	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	22404	delivery	5	53
125579	2020-08-25 03:35:57	2020-08-25	9	[{"id_menu":6,"count":1}]	47687	delivery	5	14
125580	2020-08-25 03:37:24	2020-08-25	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	45578	delivery	5	22
125581	2020-08-25 03:37:45	2020-08-25	12	[{"id_menu":1,"count":1}]	26424	delivery	5	17
125582	2020-08-25 03:38:28	2020-08-25	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	47688	delivery	5	43
125583	2020-08-25 03:39:01	2020-08-25	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12022	delivery	5	35
125584	2020-08-25 03:39:01	2020-08-25	12	[{"id_menu":3,"count":1}]	47680	delivery	5	17
125585	2020-08-25 03:40:42	2020-08-25	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3507	pick-up	0	26
125586	2020-08-25 03:41:02	2020-08-25	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	477	pick-up	0	26
125587	2020-08-25 03:42:05	2020-08-25	8	[{"id_menu":5,"count":1}]	47592	pick-up	0	8
125588	2020-08-25 03:42:58	2020-08-25	14	[{"id_menu":2,"count":1}]	38669	delivery	5	19
125589	2020-08-25 03:43:38	2020-08-25	12	[{"id_menu":3,"count":1}]	47701	delivery	5	17
125590	2020-08-25 03:46:31	2020-08-25	8	[{"id_menu":5,"count":1}]	10006	delivery	5	13
125591	2020-08-25 03:46:43	2020-08-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1229	pick-up	0	26
125592	2020-08-25 03:47:16	2020-08-25	9	[{"id_menu":6,"count":1}]	47547	delivery	5	14
125593	2020-08-25 03:47:19	2020-08-25	17	[{"id_menu":4,"count":1}]	16295	delivery	5	22
125594	2020-08-25 03:48:00	2020-08-25	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":3}]	27545	delivery	5	26
125595	2020-08-25 03:49:17	2020-08-25	9	[{"id_menu":7,"count":1}]	11185	delivery	5	14
125596	2020-08-25 03:50:18	2020-08-25	12	[{"id_menu":3,"count":1}]	256	delivery	5	17
125597	2020-08-25 03:53:19	2020-08-25	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	34957	delivery	5	34
125598	2020-08-25 03:54:25	2020-08-25	12	[{"id_menu":1,"count":1}]	34780	delivery	5	17
125599	2020-08-25 03:54:26	2020-08-25	17	[{"id_menu":4,"count":1}]	3236	pick-up	0	17
125600	2020-08-25 03:55:47	2020-08-25	14	[{"id_menu":2,"count":1}]	35193	delivery	5	19
125601	2020-08-25 03:56:12	2020-08-25	14	[{"id_menu":2,"count":1}]	4350	pick-up	0	14
125602	2020-08-25 03:56:50	2020-08-25	9	[{"id_menu":7,"count":1}]	5654	delivery	5	14
125603	2020-08-25 03:58:39	2020-08-25	14	[{"id_menu":2,"count":1}]	4929	pick-up	0	14
125604	2020-08-25 03:59:05	2020-08-25	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	13062	pick-up	0	25
125605	2020-08-25 04:08:00	2020-08-25	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	19657	delivery	5	31
125606	2020-08-25 04:08:14	2020-08-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	43945	delivery	5	22
125607	2020-08-25 04:14:03	2020-08-25	17	[{"id_menu":4,"count":1}]	26846	pick-up	0	17
125608	2020-08-25 04:15:15	2020-08-25	12	[{"id_menu":1,"count":1}]	26644	pick-up	0	12
125609	2020-08-25 04:20:16	2020-08-25	8	[{"id_menu":5,"count":1}]	38354	delivery	5	13
125610	2020-08-25 04:22:04	2020-08-25	9	[{"id_menu":7,"count":1}]	13120	pick-up	0	9
125611	2020-08-25 04:24:00	2020-08-25	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	19387	pick-up	0	33
125612	2020-08-25 04:33:10	2020-08-25	9	[{"id_menu":6,"count":1}]	16995	delivery	5	14
125613	2020-08-25 04:41:20	2020-08-25	9	[{"id_menu":7,"count":1}]	23668	delivery	5	14
125614	2020-08-25 04:41:34	2020-08-25	9	[{"id_menu":6,"count":1}]	15790	delivery	5	14
125615	2020-08-25 04:44:20	2020-08-25	9	[{"id_menu":6,"count":1}]	40614	delivery	5	14
125616	2020-08-25 04:50:10	2020-08-25	8	[{"id_menu":5,"count":1}]	35096	pick-up	0	8
125617	2020-08-25 04:52:55	2020-08-25	17	[{"id_menu":4,"count":2}]	29931	delivery	5	22
125618	2020-08-25 04:56:39	2020-08-25	17	[{"id_menu":4,"count":1}]	7540	delivery	5	22
125619	2020-08-25 05:03:00	2020-08-25	9	[{"id_menu":7,"count":1}]	15947	delivery	5	14
125620	2020-08-25 05:04:02	2020-08-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	47664	delivery	5	22
125621	2020-08-25 05:04:39	2020-08-25	17	[{"id_menu":4,"count":1}]	46835	delivery	5	22
125622	2020-08-25 05:04:49	2020-08-25	14	[{"id_menu":2,"count":2}]	9397	delivery	5	19
125623	2020-08-25 05:05:11	2020-08-25	8	[{"id_menu":5,"count":1}]	1722	pick-up	0	8
125624	2020-08-25 05:08:04	2020-08-25	8	[{"id_menu":5,"count":1}]	47696	delivery	5	13
125625	2020-08-25 05:09:15	2020-08-25	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	36849	delivery	5	57
125626	2020-08-25 05:09:37	2020-08-25	12	[{"id_menu":3,"count":1}]	42203	delivery	5	17
125627	2020-08-25 05:11:15	2020-08-25	17	[{"id_menu":4,"count":1}]	12805	delivery	5	22
125628	2020-08-25 05:13:36	2020-08-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5875	pick-up	0	23
125629	2020-08-25 05:15:31	2020-08-25	8	[{"id_menu":5,"count":1}]	47559	delivery	5	13
125630	2020-08-25 05:17:05	2020-08-25	8	[{"id_menu":5,"count":2}]	47584	pick-up	0	8
125631	2020-08-25 05:18:57	2020-08-25	8	[{"id_menu":5,"count":1}]	18638	delivery	5	13
125632	2020-08-25 05:19:22	2020-08-25	12	[{"id_menu":3,"count":1}]	47665	delivery	5	17
125633	2020-08-25 05:19:48	2020-08-25	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	44695	delivery	5	40
125634	2020-08-25 05:19:57	2020-08-25	12	[{"id_menu":1,"count":1}]	1545	delivery	5	17
125635	2020-08-25 05:22:39	2020-08-25	8	[{"id_menu":5,"count":1}]	47722	delivery	5	13
125636	2020-08-25 05:23:33	2020-08-25	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	29754	delivery	5	31
125637	2020-08-25 05:25:02	2020-08-25	14	[{"id_menu":2,"count":1}]	5570	delivery	5	19
125638	2020-08-25 05:28:12	2020-08-25	9	[{"id_menu":7,"count":1}]	25295	pick-up	0	9
125639	2020-08-25 05:29:24	2020-08-25	9	[{"id_menu":7,"count":1}]	10670	delivery	5	14
125640	2020-08-25 05:30:26	2020-08-25	9	[{"id_menu":7,"count":1}]	5018	delivery	5	14
125641	2020-08-25 05:31:32	2020-08-25	9	[{"id_menu":6,"count":1}]	47629	delivery	5	14
125642	2020-08-25 05:33:07	2020-08-25	12	[{"id_menu":1,"count":1}]	14679	pick-up	0	12
125643	2020-08-25 05:34:32	2020-08-25	8	[{"id_menu":5,"count":1}]	47565	delivery	5	13
125644	2020-08-25 05:34:33	2020-08-25	12	[{"id_menu":1,"count":1}]	46418	delivery	5	17
125645	2020-08-25 05:39:33	2020-08-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	47634	delivery	5	23
125646	2020-08-25 05:39:46	2020-08-25	17	[{"id_menu":4,"count":1}]	25053	pick-up	0	17
125647	2020-08-25 05:40:46	2020-08-25	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	6410	delivery	5	39
125648	2020-08-25 05:45:20	2020-08-25	14	[{"id_menu":2,"count":1}]	4222	delivery	5	19
125649	2020-08-25 05:47:52	2020-08-25	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	26628	pick-up	0	23
125650	2020-08-25 05:53:10	2020-08-25	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	41774	delivery	5	25
125651	2020-08-25 05:54:11	2020-08-25	17	[{"id_menu":4,"count":1}]	36982	delivery	5	22
125652	2020-08-25 05:56:27	2020-08-25	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	6364	pick-up	0	21
125653	2020-08-25 05:57:59	2020-08-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	45209	delivery	5	22
125654	2020-08-25 06:01:25	2020-08-25	12	[{"id_menu":3,"count":1}]	40192	delivery	5	17
125655	2020-08-25 06:03:19	2020-08-25	17	[{"id_menu":4,"count":1}]	29696	delivery	5	22
125656	2020-08-25 06:04:45	2020-08-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	47625	delivery	5	23
125657	2020-08-25 06:08:33	2020-08-25	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	18928	pick-up	0	31
125658	2020-08-25 06:08:51	2020-08-25	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	37744	delivery	5	26
125659	2020-08-25 06:10:56	2020-08-25	8	[{"id_menu":5,"count":1}]	36718	pick-up	0	8
125660	2020-08-25 06:14:09	2020-08-25	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	47582	delivery	5	54
125661	2020-08-25 06:19:38	2020-08-25	9	[{"id_menu":6,"count":1}]	42898	delivery	5	14
125662	2020-08-25 06:22:05	2020-08-25	17	[{"id_menu":4,"count":1}]	16703	delivery	5	22
125663	2020-08-25 06:22:34	2020-08-25	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	27609	delivery	5	27
125664	2020-08-25 06:24:37	2020-08-25	9	[{"id_menu":6,"count":1}]	21097	delivery	5	14
125665	2020-08-25 06:25:40	2020-08-25	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26187	delivery	5	35
125666	2020-08-25 06:26:15	2020-08-25	9	[{"id_menu":7,"count":1}]	14475	delivery	5	14
125667	2020-08-25 06:27:13	2020-08-25	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1726	pick-up	0	21
125668	2020-08-25 06:28:31	2020-08-25	9	[{"id_menu":6,"count":1}]	36150	delivery	5	14
125669	2020-08-25 06:28:41	2020-08-25	14	[{"id_menu":2,"count":1}]	23258	delivery	5	19
125670	2020-08-25 06:30:48	2020-08-25	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7685	delivery	5	22
125671	2020-08-25 06:34:00	2020-08-25	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	22208	delivery	5	43
125672	2020-08-25 06:38:22	2020-08-25	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	4760	pick-up	0	31
125673	2020-08-25 06:41:40	2020-08-25	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	11005	delivery	5	34
125674	2020-08-25 06:42:16	2020-08-25	12	[{"id_menu":1,"count":1}]	18259	delivery	5	17
125675	2020-08-25 06:42:37	2020-08-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	47712	delivery	5	28
125676	2020-08-25 06:46:16	2020-08-25	9	[{"id_menu":6,"count":1}]	11403	delivery	5	14
125677	2020-08-25 06:48:24	2020-08-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	36882	delivery	5	31
125678	2020-08-25 06:50:46	2020-08-25	9	[{"id_menu":6,"count":1}]	26232	pick-up	0	9
125679	2020-08-25 06:51:00	2020-08-25	9	[{"id_menu":6,"count":1}]	31997	pick-up	0	9
125680	2020-08-25 06:57:07	2020-08-25	9	[{"id_menu":6,"count":1}]	6894	delivery	5	14
125681	2020-08-25 07:02:02	2020-08-25	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	38117	delivery	5	25
125682	2020-08-25 07:03:04	2020-08-25	9	[{"id_menu":7,"count":1}]	15267	pick-up	0	9
125683	2020-08-25 07:04:22	2020-08-25	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	27584	delivery	5	34
125684	2020-08-25 07:05:29	2020-08-25	12	[{"id_menu":3,"count":1}]	1095	pick-up	0	12
125685	2020-08-25 07:06:16	2020-08-25	14	[{"id_menu":2,"count":1}]	46429	delivery	5	19
125686	2020-08-25 07:07:47	2020-08-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	47524	delivery	5	28
125687	2020-08-25 07:07:54	2020-08-25	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7013	delivery	5	43
125688	2020-08-25 07:08:06	2020-08-25	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	15768	delivery	5	34
125689	2020-08-25 07:10:25	2020-08-25	9	[{"id_menu":6,"count":3}]	3558	delivery	5	14
125690	2020-08-25 07:14:09	2020-08-25	12	[{"id_menu":1,"count":1}]	42938	delivery	5	17
125691	2020-08-25 07:24:28	2020-08-25	9	[{"id_menu":6,"count":2}]	35847	delivery	5	14
125692	2020-08-25 07:25:06	2020-08-25	9	[{"id_menu":7,"count":1}]	18666	delivery	5	14
125693	2020-08-25 07:28:00	2020-08-25	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39308	delivery	5	43
125694	2020-08-25 07:28:30	2020-08-25	9	[{"id_menu":6,"count":1}]	47570	delivery	5	14
125695	2020-08-25 07:28:55	2020-08-25	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15603	delivery	5	22
125696	2020-08-25 07:29:39	2020-08-25	17	[{"id_menu":4,"count":1}]	47677	pick-up	0	17
125697	2020-08-25 07:29:50	2020-08-25	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	46539	delivery	5	35
125698	2020-08-25 07:38:40	2020-08-25	9	[{"id_menu":7,"count":2}]	32288	delivery	5	14
125699	2020-08-25 07:42:21	2020-08-25	8	[{"id_menu":5,"count":1}]	47679	delivery	5	13
125700	2020-08-25 07:47:46	2020-08-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1802	delivery	5	28
125701	2020-08-25 07:53:23	2020-08-25	12	[{"id_menu":3,"count":1}]	43858	delivery	5	17
125702	2020-08-25 07:54:07	2020-08-25	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13845	delivery	5	22
125703	2020-08-25 07:56:34	2020-08-25	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	39275	delivery	5	23
125704	2020-08-25 07:56:45	2020-08-25	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	36888	delivery	5	28
125705	2020-08-25 07:59:28	2020-08-25	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	47624	delivery	5	40
125706	2020-08-25 08:03:02	2020-08-25	9	[{"id_menu":6,"count":1}]	47556	delivery	5	14
125707	2020-08-25 08:03:34	2020-08-25	12	[{"id_menu":3,"count":1}]	47663	delivery	5	17
125708	2020-08-25 08:06:01	2020-08-25	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	20581	delivery	5	48
125709	2020-08-25 08:14:41	2020-08-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14852	delivery	5	22
125710	2020-08-25 08:17:50	2020-08-25	17	[{"id_menu":4,"count":1}]	31586	delivery	5	22
125711	2020-08-25 08:18:01	2020-08-25	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2250	pick-up	0	22
125712	2020-08-25 08:23:39	2020-08-25	14	[{"id_menu":2,"count":1}]	4846	pick-up	0	14
125713	2020-08-25 08:24:48	2020-08-25	12	[{"id_menu":1,"count":1}]	5392	pick-up	0	12
125714	2020-08-25 08:25:17	2020-08-25	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	47698	delivery	5	38
125715	2020-08-25 08:27:24	2020-08-25	9	[{"id_menu":7,"count":1}]	1769	delivery	5	14
125716	2020-08-25 08:27:25	2020-08-25	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	26283	delivery	5	29
125717	2020-08-25 08:28:20	2020-08-25	14	[{"id_menu":2,"count":1}]	12210	pick-up	0	14
125718	2020-08-25 08:28:47	2020-08-25	9	[{"id_menu":7,"count":1}]	30381	delivery	5	14
125719	2020-08-25 08:34:10	2020-08-25	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	47666	pick-up	0	25
125720	2020-08-25 08:35:36	2020-08-25	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	41159	delivery	5	25
125721	2020-08-25 08:37:16	2020-08-25	17	[{"id_menu":4,"count":1}]	47522	delivery	5	22
125722	2020-08-25 08:37:29	2020-08-25	12	[{"id_menu":3,"count":1}]	12578	delivery	5	17
125723	2020-08-25 08:49:37	2020-08-25	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	42192	delivery	5	26
125724	2020-08-25 08:51:16	2020-08-25	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	8347	delivery	5	36
125725	2020-08-25 08:51:31	2020-08-25	17	[{"id_menu":4,"count":1}]	691	pick-up	0	17
125726	2020-08-25 08:59:20	2020-08-25	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	47595	delivery	5	40
125727	2020-08-25 08:59:58	2020-08-25	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	47575	delivery	5	39
125728	2020-08-25 09:00:07	2020-08-25	12	[{"id_menu":3,"count":1}]	2897	pick-up	0	12
125729	2020-08-25 09:03:55	2020-08-25	9	[{"id_menu":7,"count":1}]	5183	delivery	5	14
125730	2020-08-25 09:06:51	2020-08-25	9	[{"id_menu":6,"count":1}]	47577	delivery	5	14
125731	2020-08-25 09:10:17	2020-08-25	12	[{"id_menu":3,"count":1}]	47518	delivery	5	17
125732	2020-08-25 09:11:48	2020-08-25	17	[{"id_menu":4,"count":1}]	35756	delivery	5	22
125733	2020-08-25 09:12:37	2020-08-25	9	[{"id_menu":7,"count":1}]	17020	delivery	5	14
125734	2020-08-25 09:13:26	2020-08-25	9	[{"id_menu":6,"count":1}]	31926	delivery	5	14
125735	2020-08-25 09:21:20	2020-08-25	9	[{"id_menu":6,"count":3}]	23513	delivery	5	14
125736	2020-08-25 09:28:28	2020-08-25	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	19626	delivery	5	40
125737	2020-08-25 09:31:56	2020-08-25	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	34581	delivery	5	40
125738	2020-08-25 09:34:50	2020-08-25	14	[{"id_menu":2,"count":1}]	13102	delivery	5	19
125739	2020-08-25 09:35:10	2020-08-25	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	47644	delivery	5	31
125740	2020-08-25 09:35:13	2020-08-25	14	[{"id_menu":2,"count":1}]	371	pick-up	0	14
125741	2020-08-25 09:36:13	2020-08-25	14	[{"id_menu":2,"count":1}]	47602	delivery	5	19
125742	2020-08-25 09:36:14	2020-08-25	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	38895	delivery	5	36
125743	2020-08-25 09:37:35	2020-08-25	9	[{"id_menu":6,"count":1}]	33446	pick-up	0	9
125744	2020-08-25 09:38:13	2020-08-25	9	[{"id_menu":6,"count":1}]	7821	delivery	5	14
125745	2020-08-25 09:40:51	2020-08-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	35223	delivery	5	28
125746	2020-08-25 09:43:59	2020-08-25	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	13767	pick-up	0	21
125747	2020-08-25 09:44:38	2020-08-25	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	47545	delivery	5	26
125748	2020-08-25 09:47:07	2020-08-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	47617	delivery	5	31
125749	2020-08-25 09:50:26	2020-08-25	17	[{"id_menu":4,"count":1}]	46171	pick-up	0	17
125750	2020-08-25 09:50:44	2020-08-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	47695	delivery	5	31
125751	2020-08-25 09:51:03	2020-08-25	9	[{"id_menu":6,"count":1}]	46514	delivery	5	14
125752	2020-08-25 09:52:00	2020-08-25	9	[{"id_menu":6,"count":1}]	30052	delivery	5	14
125753	2020-08-25 09:54:03	2020-08-25	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4486	pick-up	0	23
125754	2020-08-25 09:54:08	2020-08-25	9	[{"id_menu":7,"count":1}]	38114	delivery	5	14
125755	2020-08-25 09:57:34	2020-08-25	12	[{"id_menu":1,"count":1}]	11132	delivery	5	17
125756	2020-08-25 09:58:18	2020-08-25	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7084	pick-up	0	26
125757	2020-08-25 09:58:23	2020-08-25	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	47726	delivery	5	39
125758	2020-08-25 09:58:45	2020-08-25	9	[{"id_menu":7,"count":1}]	47578	delivery	5	14
125759	2020-08-25 09:58:57	2020-08-25	12	[{"id_menu":3,"count":1}]	47539	delivery	5	17
125760	2020-08-25 10:00:17	2020-08-25	8	[{"id_menu":5,"count":1}]	31229	delivery	5	13
125761	2020-08-25 10:04:23	2020-08-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7058	pick-up	0	26
125762	2020-08-25 10:05:21	2020-08-25	17	[{"id_menu":4,"count":1}]	2426	pick-up	0	17
125763	2020-08-25 10:06:41	2020-08-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34854	delivery	5	23
125764	2020-08-25 10:07:28	2020-08-25	9	[{"id_menu":6,"count":1}]	7098	pick-up	0	9
125765	2020-08-25 10:07:51	2020-08-25	12	[{"id_menu":1,"count":1}]	18050	delivery	5	17
125766	2020-08-25 10:10:25	2020-08-25	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":3}]	47661	delivery	5	28
125767	2020-08-25 10:13:05	2020-08-25	9	[{"id_menu":6,"count":1}]	3484	delivery	5	14
125768	2020-08-25 10:16:12	2020-08-25	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	16470	delivery	5	34
125769	2020-08-25 10:16:27	2020-08-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	43037	delivery	5	23
125770	2020-08-25 10:16:44	2020-08-25	8	[{"id_menu":5,"count":1}]	10666	delivery	5	13
125771	2020-08-25 10:17:21	2020-08-25	8	[{"id_menu":5,"count":1}]	47673	delivery	5	13
125772	2020-08-25 10:17:25	2020-08-25	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	47682	delivery	5	27
125773	2020-08-25 10:20:05	2020-08-25	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	47650	delivery	5	48
125774	2020-08-25 10:20:15	2020-08-25	12	[{"id_menu":1,"count":1}]	13727	delivery	5	17
125775	2020-08-25 10:22:31	2020-08-25	12	[{"id_menu":1,"count":1}]	31172	delivery	5	17
125776	2020-08-25 10:24:05	2020-08-25	9	[{"id_menu":7,"count":1}]	4868	delivery	5	14
125777	2020-08-25 10:24:42	2020-08-25	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	9743	delivery	5	26
125778	2020-08-25 10:25:52	2020-08-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	45802	delivery	5	31
125779	2020-08-25 10:26:53	2020-08-25	17	[{"id_menu":4,"count":2}]	47691	delivery	5	22
125780	2020-08-25 10:32:56	2020-08-25	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	13406	delivery	5	35
125781	2020-08-25 10:33:42	2020-08-25	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	638	pick-up	0	20
125782	2020-08-25 10:33:57	2020-08-25	9	[{"id_menu":7,"count":1}]	14463	pick-up	0	9
125783	2020-08-25 10:37:07	2020-08-25	12	[{"id_menu":3,"count":1}]	821	pick-up	0	12
125784	2020-08-25 10:38:20	2020-08-25	12	[{"id_menu":3,"count":1}]	7710	delivery	5	17
125785	2020-08-25 10:39:29	2020-08-25	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1713	pick-up	0	31
125786	2020-08-25 10:39:51	2020-08-25	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	3965	delivery	5	46
125787	2020-08-25 10:41:27	2020-08-25	9	[{"id_menu":6,"count":1}]	28056	delivery	5	14
125788	2020-08-25 10:43:35	2020-08-25	12	[{"id_menu":3,"count":1}]	21823	delivery	5	17
125789	2020-08-25 10:47:08	2020-08-25	14	[{"id_menu":2,"count":1}]	27171	delivery	5	19
125790	2020-08-25 10:50:28	2020-08-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	39202	delivery	5	31
125791	2020-08-25 10:56:02	2020-08-25	9	[{"id_menu":7,"count":1}]	47641	delivery	5	14
125792	2020-08-25 10:58:40	2020-08-25	17	[{"id_menu":4,"count":1}]	13165	delivery	5	22
125793	2020-08-25 11:02:35	2020-08-25	9	[{"id_menu":7,"count":1}]	47586	delivery	5	14
125794	2020-08-25 11:02:49	2020-08-25	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	47635	delivery	5	36
125795	2020-08-25 11:07:51	2020-08-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27618	delivery	5	22
125796	2020-08-25 11:09:30	2020-08-25	12	[{"id_menu":1,"count":1}]	23212	delivery	5	17
125797	2020-08-25 11:10:35	2020-08-25	12	[{"id_menu":3,"count":1}]	14002	delivery	5	17
125798	2020-08-25 11:10:44	2020-08-25	9	[{"id_menu":6,"count":1}]	16459	delivery	5	14
125799	2020-08-25 11:15:06	2020-08-25	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	8295	delivery	5	40
125800	2020-08-25 11:15:07	2020-08-25	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	30065	delivery	5	56
125801	2020-08-25 11:15:55	2020-08-25	9	[{"id_menu":7,"count":3}]	22572	delivery	5	14
125802	2020-08-25 11:21:23	2020-08-25	12	[{"id_menu":3,"count":1}]	14133	pick-up	0	12
125803	2020-08-25 11:23:12	2020-08-25	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	42485	delivery	5	31
125804	2020-08-25 11:23:42	2020-08-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	34698	delivery	5	31
125805	2020-08-25 11:24:40	2020-08-25	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	47662	pick-up	0	20
125806	2020-08-25 11:29:12	2020-08-25	9	[{"id_menu":6,"count":1}]	3551	delivery	5	14
125807	2020-08-25 11:32:59	2020-08-25	12	[{"id_menu":3,"count":1}]	3817	pick-up	0	12
125808	2020-08-25 11:33:13	2020-08-25	12	[{"id_menu":1,"count":1}]	27442	delivery	5	17
125809	2020-08-25 11:35:32	2020-08-25	9	[{"id_menu":7,"count":1}]	11252	delivery	5	14
125810	2020-08-25 11:39:04	2020-08-25	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	8942	delivery	5	43
125811	2020-08-25 11:39:08	2020-08-25	8	[{"id_menu":5,"count":1}]	12944	delivery	5	13
125812	2020-08-25 11:41:15	2020-08-25	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	47729	delivery	5	34
125813	2020-08-25 11:41:46	2020-08-25	8	[{"id_menu":5,"count":1}]	39080	delivery	5	13
125814	2020-08-25 11:50:42	2020-08-25	14	[{"id_menu":2,"count":1}]	14281	delivery	5	19
125815	2020-08-25 11:50:55	2020-08-25	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	13948	delivery	5	27
125816	2020-08-25 11:52:13	2020-08-25	8	[{"id_menu":5,"count":1}]	44281	pick-up	0	8
125817	2020-08-25 11:59:29	2020-08-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21010	delivery	5	23
125818	2020-08-25 12:02:16	2020-08-25	17	[{"id_menu":4,"count":1}]	10317	delivery	5	22
125819	2020-08-25 12:05:12	2020-08-25	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	40387	delivery	5	34
125820	2020-08-25 12:08:42	2020-08-25	8	[{"id_menu":5,"count":1}]	44838	delivery	5	13
125821	2020-08-25 12:10:13	2020-08-25	17	[{"id_menu":4,"count":1}]	24950	delivery	5	22
125822	2020-08-25 12:12:23	2020-08-25	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	35487	delivery	5	25
125823	2020-08-25 12:16:11	2020-08-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11669	delivery	5	22
125824	2020-08-25 12:17:11	2020-08-25	9	[{"id_menu":6,"count":2}]	27755	pick-up	0	9
125825	2020-08-25 12:19:30	2020-08-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4982	delivery	5	23
125826	2020-08-25 12:24:43	2020-08-25	17	[{"id_menu":4,"count":1}]	41300	pick-up	0	17
125827	2020-08-25 12:25:04	2020-08-25	9	[{"id_menu":7,"count":1}]	35464	delivery	5	14
125828	2020-08-25 12:25:09	2020-08-25	14	[{"id_menu":2,"count":1}]	36874	pick-up	0	14
125829	2020-08-25 12:25:51	2020-08-25	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	10009	delivery	5	26
125830	2020-08-25 12:28:55	2020-08-25	17	[{"id_menu":4,"count":1}]	17676	delivery	5	22
125831	2020-08-25 12:41:18	2020-08-25	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	47633	delivery	5	37
125832	2020-08-25 12:41:37	2020-08-25	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	20804	pick-up	0	21
125833	2020-08-25 12:41:59	2020-08-25	14	[{"id_menu":2,"count":1}]	24447	delivery	5	19
125834	2020-08-25 12:43:26	2020-08-25	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	19169	delivery	5	26
125835	2020-08-25 12:43:56	2020-08-25	9	[{"id_menu":6,"count":1}]	669	delivery	5	14
125836	2020-08-25 12:48:11	2020-08-25	9	[{"id_menu":7,"count":1}]	30266	delivery	5	14
125837	2020-08-25 12:49:46	2020-08-25	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	42289	delivery	5	34
125838	2020-08-25 12:53:28	2020-08-25	9	[{"id_menu":6,"count":1}]	47674	pick-up	0	9
125839	2020-08-25 12:53:53	2020-08-25	12	[{"id_menu":3,"count":1}]	35726	delivery	5	17
125840	2020-08-25 12:54:24	2020-08-25	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":2}]	28225	pick-up	0	29
125841	2020-08-25 12:57:26	2020-08-25	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1698	pick-up	0	23
125842	2020-08-25 12:57:51	2020-08-25	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	29821	delivery	5	46
125843	2020-08-25 13:00:21	2020-08-25	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	36385	delivery	5	26
125844	2020-08-25 13:01:29	2020-08-25	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13316	delivery	5	48
125845	2020-08-25 13:07:47	2020-08-25	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38229	delivery	5	49
125846	2020-08-25 13:08:04	2020-08-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3564	pick-up	0	23
125847	2020-08-25 13:10:14	2020-08-25	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	27154	delivery	5	48
125848	2020-08-25 13:11:40	2020-08-25	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1402	delivery	5	25
125849	2020-08-25 13:12:57	2020-08-25	9	[{"id_menu":6,"count":2}]	47579	delivery	5	14
125850	2020-08-25 13:14:25	2020-08-25	9	[{"id_menu":6,"count":1}]	24587	delivery	5	14
125851	2020-08-25 13:23:00	2020-08-25	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8626	delivery	5	37
125852	2020-08-25 13:23:12	2020-08-25	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	28320	delivery	5	30
125853	2020-08-25 13:23:38	2020-08-25	12	[{"id_menu":3,"count":2}]	37758	delivery	5	17
125854	2020-08-25 13:30:41	2020-08-25	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	17019	delivery	5	40
125855	2020-08-25 13:31:52	2020-08-25	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	47654	delivery	5	52
125856	2020-08-25 13:33:07	2020-08-25	9	[{"id_menu":7,"count":1}]	18869	delivery	5	14
125857	2020-08-25 13:35:57	2020-08-25	9	[{"id_menu":7,"count":1}]	47640	delivery	5	14
125858	2020-08-25 13:36:43	2020-08-25	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	26099	pick-up	0	26
125859	2020-08-25 13:37:42	2020-08-25	8	[{"id_menu":5,"count":1}]	47615	delivery	5	13
125860	2020-08-25 13:38:34	2020-08-25	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13634	delivery	5	31
125861	2020-08-25 13:40:47	2020-08-25	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	33196	pick-up	0	26
125862	2020-08-25 13:45:38	2020-08-25	8	[{"id_menu":5,"count":1}]	47536	delivery	5	13
125863	2020-08-25 13:46:46	2020-08-25	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1760	pick-up	0	22
125864	2020-08-25 13:52:57	2020-08-25	12	[{"id_menu":1,"count":1}]	47720	delivery	5	17
125865	2020-08-25 13:59:17	2020-08-25	9	[{"id_menu":6,"count":1}]	32362	delivery	5	14
125866	2020-08-25 13:59:29	2020-08-25	9	[{"id_menu":6,"count":1}]	47705	pick-up	0	9
125867	2020-08-25 14:00:35	2020-08-25	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	47555	pick-up	0	17
125868	2020-08-25 14:02:36	2020-08-25	9	[{"id_menu":6,"count":1}]	41569	delivery	5	14
125869	2020-08-25 14:02:45	2020-08-25	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	46754	pick-up	0	29
125870	2020-08-25 14:05:07	2020-08-25	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17341	delivery	5	40
125871	2020-08-25 14:05:50	2020-08-25	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	47533	delivery	5	34
125872	2020-08-25 14:07:13	2020-08-25	14	[{"id_menu":2,"count":2}]	15686	pick-up	0	14
125873	2020-08-25 14:11:04	2020-08-25	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	9776	delivery	5	45
125874	2020-08-25 14:13:50	2020-08-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24071	delivery	5	23
125875	2020-08-25 14:20:06	2020-08-25	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	23169	delivery	5	34
125876	2020-08-25 14:20:41	2020-08-25	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	37791	delivery	5	27
125877	2020-08-25 14:22:17	2020-08-25	9	[{"id_menu":7,"count":1}]	36713	delivery	5	14
125878	2020-08-25 14:25:54	2020-08-25	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	43788	delivery	5	31
125879	2020-08-25 14:32:22	2020-08-25	9	[{"id_menu":7,"count":1}]	21918	delivery	5	14
125880	2020-08-25 14:35:56	2020-08-25	9	[{"id_menu":7,"count":1}]	35795	delivery	5	14
125881	2020-08-25 14:45:13	2020-08-25	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	991	pick-up	0	29
125882	2020-08-25 14:46:04	2020-08-25	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	41578	delivery	5	26
125883	2020-08-25 14:46:14	2020-08-25	9	[{"id_menu":6,"count":1}]	29895	delivery	5	14
125884	2020-08-25 14:46:15	2020-08-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	22930	delivery	5	23
125885	2020-08-25 14:46:28	2020-08-25	17	[{"id_menu":4,"count":1}]	40741	delivery	5	22
125886	2020-08-25 14:49:03	2020-08-25	14	[{"id_menu":2,"count":1}]	47588	delivery	5	19
125887	2020-08-25 14:52:09	2020-08-25	9	[{"id_menu":7,"count":1}]	42318	pick-up	0	9
125888	2020-08-25 14:52:29	2020-08-25	9	[{"id_menu":6,"count":1}]	10244	delivery	5	14
125889	2020-08-25 14:55:44	2020-08-25	9	[{"id_menu":7,"count":1}]	2110	pick-up	0	9
125890	2020-08-25 14:57:06	2020-08-25	12	[{"id_menu":1,"count":1}]	6859	delivery	5	17
125891	2020-08-25 14:58:45	2020-08-25	9	[{"id_menu":6,"count":1}]	44316	delivery	5	14
125892	2020-08-25 15:00:56	2020-08-25	12	[{"id_menu":3,"count":1}]	47563	delivery	5	17
125893	2020-08-25 15:03:47	2020-08-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	6053	delivery	5	22
125894	2020-08-25 15:04:07	2020-08-25	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	28719	delivery	5	22
125895	2020-08-25 15:05:45	2020-08-25	17	[{"id_menu":4,"count":1}]	1684	delivery	5	22
125896	2020-08-25 15:06:39	2020-08-25	9	[{"id_menu":7,"count":1}]	33604	delivery	5	14
125897	2020-08-25 15:08:30	2020-08-25	9	[{"id_menu":7,"count":1}]	19085	delivery	5	14
125898	2020-08-25 15:12:36	2020-08-25	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	36870	delivery	5	27
125899	2020-08-25 15:15:44	2020-08-25	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12541	pick-up	0	31
125900	2020-08-25 15:16:00	2020-08-25	17	[{"id_menu":4,"count":1}]	24105	pick-up	0	17
125901	2020-08-25 15:17:05	2020-08-25	8	[{"id_menu":5,"count":1}]	47651	delivery	5	13
125902	2020-08-25 15:17:25	2020-08-25	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	36752	delivery	5	40
125903	2020-08-25 15:20:39	2020-08-25	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	36290	delivery	5	28
125904	2020-08-25 15:23:24	2020-08-25	17	[{"id_menu":4,"count":1}]	46837	delivery	5	22
125905	2020-08-25 15:25:08	2020-08-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3949	pick-up	0	17
125906	2020-08-25 15:28:46	2020-08-25	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	41242	delivery	5	22
125907	2020-08-25 15:34:44	2020-08-25	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	3363	pick-up	0	26
125908	2020-08-25 15:39:17	2020-08-25	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	47616	delivery	5	45
125909	2020-08-25 15:47:22	2020-08-25	12	[{"id_menu":1,"count":1}]	47523	delivery	5	17
125910	2020-08-25 15:47:58	2020-08-25	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	37638	pick-up	0	29
125911	2020-08-25 15:49:01	2020-08-25	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":3}]	36993	delivery	5	31
125912	2020-08-25 15:50:17	2020-08-25	9	[{"id_menu":6,"count":1}]	47638	delivery	5	14
125913	2020-08-25 15:52:04	2020-08-25	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	47723	delivery	5	39
125914	2020-08-25 15:53:12	2020-08-25	9	[{"id_menu":7,"count":1}]	47703	delivery	5	14
125915	2020-08-25 15:54:06	2020-08-25	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8421	delivery	5	43
125916	2020-08-25 16:01:06	2020-08-25	14	[{"id_menu":2,"count":1}]	22734	delivery	5	19
125917	2020-08-25 16:02:05	2020-08-25	9	[{"id_menu":6,"count":1}]	158	pick-up	0	9
125918	2020-08-25 16:03:29	2020-08-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6129	delivery	5	23
125919	2020-08-25 16:05:18	2020-08-25	9	[{"id_menu":7,"count":1}]	18374	pick-up	0	9
125920	2020-08-25 16:07:43	2020-08-25	12	[{"id_menu":3,"count":1}]	24918	delivery	5	17
125921	2020-08-25 16:10:07	2020-08-25	14	[{"id_menu":2,"count":2}]	9009	delivery	5	19
125922	2020-08-25 16:11:14	2020-08-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	47653	pick-up	0	17
125923	2020-08-25 16:12:45	2020-08-25	9	[{"id_menu":7,"count":1}]	47714	delivery	5	14
125924	2020-08-25 16:16:01	2020-08-25	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	47639	delivery	5	22
125925	2020-08-25 16:24:37	2020-08-25	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	43272	delivery	5	31
125926	2020-08-25 16:26:20	2020-08-25	9	[{"id_menu":6,"count":1}]	47689	delivery	5	14
125927	2020-08-25 16:27:46	2020-08-25	14	[{"id_menu":2,"count":1}]	6247	delivery	5	19
125928	2020-08-25 16:28:49	2020-08-25	8	[{"id_menu":5,"count":1}]	30818	delivery	5	13
125929	2020-08-25 16:32:08	2020-08-25	14	[{"id_menu":2,"count":1}]	6092	pick-up	0	14
125930	2020-08-25 16:36:41	2020-08-25	12	[{"id_menu":1,"count":1}]	15594	delivery	5	17
125931	2020-08-25 16:39:51	2020-08-25	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	47657	delivery	5	55
125932	2020-08-25 16:51:34	2020-08-25	8	[{"id_menu":5,"count":1}]	1351	delivery	5	13
125933	2020-08-25 16:55:09	2020-08-25	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	22002	delivery	5	30
125934	2020-08-25 16:55:31	2020-08-25	9	[{"id_menu":6,"count":1}]	47623	pick-up	0	9
125935	2020-08-25 16:59:36	2020-08-25	12	[{"id_menu":3,"count":1}]	34757	delivery	5	17
125936	2020-08-25 17:00:46	2020-08-25	14	[{"id_menu":2,"count":1}]	9682	pick-up	0	14
125937	2020-08-25 17:01:47	2020-08-25	9	[{"id_menu":7,"count":1}]	47734	pick-up	0	9
125938	2020-08-25 17:05:07	2020-08-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	4945	delivery	5	22
125939	2020-08-25 17:08:43	2020-08-25	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	47733	delivery	5	31
125940	2020-08-25 17:09:32	2020-08-25	8	[{"id_menu":5,"count":1}]	24766	delivery	5	13
125941	2020-08-25 17:10:51	2020-08-25	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	46658	delivery	5	36
125942	2020-08-25 17:11:22	2020-08-25	12	[{"id_menu":1,"count":1}]	1309	pick-up	0	12
125943	2020-08-25 17:14:04	2020-08-25	17	[{"id_menu":4,"count":1}]	23585	delivery	5	22
125944	2020-08-25 17:16:03	2020-08-25	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	47537	delivery	5	34
125945	2020-08-25 17:20:58	2020-08-25	9	[{"id_menu":6,"count":1}]	25440	delivery	5	14
125946	2020-08-25 17:21:07	2020-08-25	17	[{"id_menu":4,"count":1}]	29925	delivery	5	22
125947	2020-08-25 17:24:30	2020-08-25	9	[{"id_menu":7,"count":1}]	34230	delivery	5	14
125948	2020-08-25 17:25:28	2020-08-25	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	34846	delivery	5	30
125949	2020-08-25 17:26:39	2020-08-25	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34305	delivery	5	35
125950	2020-08-25 17:26:45	2020-08-25	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	31146	delivery	5	36
125951	2020-08-25 17:28:30	2020-08-25	12	[{"id_menu":1,"count":1}]	3812	pick-up	0	12
125952	2020-08-25 17:32:15	2020-08-25	12	[{"id_menu":3,"count":1}]	41225	delivery	5	17
125953	2020-08-25 17:34:01	2020-08-25	9	[{"id_menu":6,"count":1}]	359	pick-up	0	9
125954	2020-08-25 17:37:43	2020-08-25	17	[{"id_menu":4,"count":2}]	25336	delivery	5	22
125955	2020-08-25 17:42:41	2020-08-25	9	[{"id_menu":7,"count":1}]	37102	delivery	5	14
125956	2020-08-25 17:42:58	2020-08-25	8	[{"id_menu":5,"count":1}]	20931	delivery	5	13
125957	2020-08-25 17:47:01	2020-08-25	9	[{"id_menu":6,"count":1}]	20798	delivery	5	14
125958	2020-08-25 17:47:44	2020-08-25	12	[{"id_menu":1,"count":1}]	8855	pick-up	0	12
125959	2020-08-25 17:48:53	2020-08-25	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	31032	delivery	5	23
125960	2020-08-25 17:52:43	2020-08-25	12	[{"id_menu":3,"count":1}]	46807	delivery	5	17
125961	2020-08-25 17:53:33	2020-08-25	9	[{"id_menu":7,"count":1}]	15763	delivery	5	14
125962	2020-08-25 17:53:44	2020-08-25	8	[{"id_menu":5,"count":1}]	40391	pick-up	0	8
125963	2020-08-25 17:57:27	2020-08-25	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	47614	delivery	5	26
125964	2020-08-25 17:57:31	2020-08-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2630	pick-up	0	23
125965	2020-08-25 18:01:23	2020-08-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	47660	delivery	5	22
125966	2020-08-25 18:05:49	2020-08-25	9	[{"id_menu":7,"count":1}]	47568	delivery	5	14
125967	2020-08-25 18:09:12	2020-08-25	9	[{"id_menu":7,"count":1}]	1934	pick-up	0	9
125968	2020-08-25 18:09:13	2020-08-25	8	[{"id_menu":5,"count":1}]	11380	pick-up	0	8
125969	2020-08-25 18:10:14	2020-08-25	17	[{"id_menu":4,"count":1}]	9716	pick-up	0	17
125970	2020-08-25 18:26:44	2020-08-25	8	[{"id_menu":5,"count":1}]	28362	delivery	5	13
125971	2020-08-25 18:29:46	2020-08-25	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	47541	delivery	5	26
125972	2020-08-25 18:30:44	2020-08-25	14	[{"id_menu":2,"count":1}]	47596	delivery	5	19
125973	2020-08-25 18:34:49	2020-08-25	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	20483	delivery	5	28
125974	2020-08-25 18:38:35	2020-08-25	12	[{"id_menu":1,"count":1}]	47693	delivery	5	17
125975	2020-08-25 18:39:05	2020-08-25	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	19913	delivery	5	26
125976	2020-08-25 18:39:31	2020-08-25	17	[{"id_menu":4,"count":1}]	41283	delivery	5	22
125977	2020-08-25 18:39:41	2020-08-25	9	[{"id_menu":6,"count":2}]	47562	pick-up	0	9
125978	2020-08-25 18:41:12	2020-08-25	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	45190	delivery	5	22
125979	2020-08-25 18:43:49	2020-08-25	14	[{"id_menu":2,"count":1}]	47646	delivery	5	19
125980	2020-08-25 18:44:15	2020-08-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":3}]	14165	delivery	5	23
125981	2020-08-25 18:46:21	2020-08-25	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	1269	delivery	5	25
125982	2020-08-25 18:49:01	2020-08-25	9	[{"id_menu":7,"count":1}]	14978	delivery	5	14
125983	2020-08-25 18:51:46	2020-08-25	14	[{"id_menu":2,"count":1}]	24534	pick-up	0	14
125984	2020-08-25 18:52:05	2020-08-25	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	47534	delivery	5	31
125985	2020-08-25 18:54:58	2020-08-25	12	[{"id_menu":3,"count":1}]	6473	delivery	5	17
125986	2020-08-25 18:57:39	2020-08-25	12	[{"id_menu":3,"count":1}]	8561	pick-up	0	12
125987	2020-08-25 18:58:39	2020-08-25	9	[{"id_menu":6,"count":1}]	28091	pick-up	0	9
125988	2020-08-25 19:01:49	2020-08-25	12	[{"id_menu":3,"count":1}]	19741	delivery	5	17
125989	2020-08-25 19:05:29	2020-08-25	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	47632	delivery	5	31
125990	2020-08-25 19:07:20	2020-08-25	12	[{"id_menu":3,"count":1}]	19845	pick-up	0	12
125991	2020-08-25 19:09:26	2020-08-25	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	47671	pick-up	0	29
125992	2020-08-25 19:13:25	2020-08-25	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	43745	delivery	5	31
125993	2020-08-25 19:14:38	2020-08-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	31045	delivery	5	31
125994	2020-08-25 19:17:13	2020-08-25	9	[{"id_menu":7,"count":1}]	47659	delivery	5	14
125995	2020-08-25 19:17:43	2020-08-25	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	14982	delivery	5	22
125996	2020-08-25 19:18:50	2020-08-25	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	47684	delivery	5	26
125997	2020-08-25 19:27:45	2020-08-25	9	[{"id_menu":7,"count":1}]	47732	delivery	5	14
125998	2020-08-25 19:28:58	2020-08-25	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	31482	delivery	5	39
125999	2020-08-25 19:32:27	2020-08-25	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	43811	delivery	5	34
126000	2020-08-25 19:34:05	2020-08-25	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	37734	delivery	5	40
126001	2020-08-25 19:34:43	2020-08-25	14	[{"id_menu":2,"count":1}]	4996	pick-up	0	14
126002	2020-08-25 19:37:21	2020-08-25	9	[{"id_menu":7,"count":1}]	11536	delivery	5	14
126003	2020-08-25 19:40:13	2020-08-25	12	[{"id_menu":1,"count":1}]	23874	delivery	5	17
126004	2020-08-25 19:42:10	2020-08-25	9	[{"id_menu":6,"count":1}]	47675	pick-up	0	9
126005	2020-08-25 19:43:14	2020-08-25	9	[{"id_menu":6,"count":1}]	27155	delivery	5	14
126006	2020-08-25 19:49:35	2020-08-25	9	[{"id_menu":7,"count":1}]	40131	delivery	5	14
126007	2020-08-25 19:55:13	2020-08-25	12	[{"id_menu":1,"count":2}]	4393	delivery	5	17
126008	2020-08-25 19:56:23	2020-08-25	8	[{"id_menu":5,"count":2}]	42808	delivery	5	13
126009	2020-08-25 19:59:10	2020-08-25	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9903	delivery	5	22
126010	2020-08-25 19:59:17	2020-08-25	14	[{"id_menu":2,"count":1}]	47597	delivery	5	19
126011	2020-08-25 20:00:14	2020-08-25	12	[{"id_menu":3,"count":1}]	1429	pick-up	0	12
126012	2020-08-25 20:05:39	2020-08-25	14	[{"id_menu":2,"count":2}]	4423	pick-up	0	14
126013	2020-08-25 20:11:39	2020-08-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	47645	delivery	5	28
126014	2020-08-25 20:13:59	2020-08-25	9	[{"id_menu":6,"count":1}]	26977	delivery	5	14
126015	2020-08-25 20:14:54	2020-08-25	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	47731	delivery	5	23
126016	2020-08-25 20:17:25	2020-08-25	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10697	pick-up	0	29
126017	2020-08-25 20:17:41	2020-08-25	8	[{"id_menu":5,"count":1}]	47564	delivery	5	13
126018	2020-08-25 20:22:34	2020-08-25	26	[{"id_menu":2,"count":3},{"id_menu":3,"count":1}]	20329	delivery	5	31
126019	2020-08-25 20:25:34	2020-08-25	17	[{"id_menu":4,"count":1}]	37269	delivery	5	22
126020	2020-08-25 20:27:15	2020-08-25	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14921	delivery	5	36
126021	2020-08-25 20:29:09	2020-08-25	12	[{"id_menu":1,"count":1}]	47628	delivery	5	17
126022	2020-08-25 20:34:23	2020-08-25	8	[{"id_menu":5,"count":1}]	47557	delivery	5	13
126023	2020-08-25 20:35:08	2020-08-25	14	[{"id_menu":2,"count":1}]	13762	pick-up	0	14
126024	2020-08-25 20:41:23	2020-08-25	12	[{"id_menu":3,"count":1}]	4782	pick-up	0	12
126025	2020-08-25 20:41:29	2020-08-25	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	7566	pick-up	0	32
126026	2020-08-25 20:49:20	2020-08-25	12	[{"id_menu":1,"count":1}]	31597	delivery	5	17
126027	2020-08-25 20:49:40	2020-08-25	55	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	17478	pick-up	0	55
126028	2020-08-25 20:51:56	2020-08-25	12	[{"id_menu":3,"count":1}]	21009	pick-up	0	12
126029	2020-08-25 20:53:13	2020-08-25	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	33908	delivery	5	26
126030	2020-08-25 20:53:54	2020-08-25	17	[{"id_menu":4,"count":1}]	40377	delivery	5	22
126031	2020-08-25 20:57:07	2020-08-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	47601	delivery	5	28
126032	2020-08-25 20:58:35	2020-08-25	9	[{"id_menu":6,"count":1}]	6050	pick-up	0	9
126033	2020-08-25 21:01:15	2020-08-25	17	[{"id_menu":4,"count":1}]	47525	delivery	5	22
126034	2020-08-25 21:02:13	2020-08-25	8	[{"id_menu":5,"count":1}]	15745	delivery	5	13
126035	2020-08-25 21:02:49	2020-08-25	14	[{"id_menu":2,"count":2}]	47585	delivery	5	19
126036	2020-08-25 21:08:56	2020-08-25	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	19857	delivery	5	43
126037	2020-08-25 21:09:13	2020-08-25	9	[{"id_menu":7,"count":1}]	34720	delivery	5	14
126038	2020-08-25 21:12:17	2020-08-25	9	[{"id_menu":6,"count":1}]	39589	delivery	5	14
126039	2020-08-25 21:14:28	2020-08-25	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	47521	delivery	5	26
126040	2020-08-25 21:16:16	2020-08-25	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	47383	delivery	5	31
126041	2020-08-25 21:16:18	2020-08-25	14	[{"id_menu":2,"count":1}]	5895	pick-up	0	14
126042	2020-08-25 21:24:41	2020-08-25	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	996	pick-up	0	41
126043	2020-08-25 21:24:43	2020-08-25	9	[{"id_menu":6,"count":2}]	27324	delivery	5	14
126044	2020-08-25 21:27:03	2020-08-25	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	42750	delivery	5	43
126045	2020-08-25 21:33:24	2020-08-25	17	[{"id_menu":4,"count":1}]	3971	pick-up	0	17
126046	2020-08-25 21:33:34	2020-08-25	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16929	delivery	5	35
126047	2020-08-25 21:33:50	2020-08-25	12	[{"id_menu":3,"count":1}]	47707	pick-up	0	12
126048	2020-08-25 21:39:16	2020-08-25	9	[{"id_menu":6,"count":1}]	12873	delivery	5	14
126049	2020-08-25 21:40:05	2020-08-25	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	11869	delivery	5	26
126050	2020-08-25 21:40:20	2020-08-25	12	[{"id_menu":1,"count":1}]	17106	delivery	5	17
126051	2020-08-25 21:43:38	2020-08-25	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	38459	delivery	5	48
126052	2020-08-25 21:45:28	2020-08-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	47581	delivery	5	23
126053	2020-08-25 21:46:16	2020-08-25	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	47611	pick-up	0	33
126054	2020-08-25 21:49:01	2020-08-25	17	[{"id_menu":4,"count":1}]	2706	pick-up	0	17
126055	2020-08-25 21:52:48	2020-08-25	12	[{"id_menu":1,"count":1}]	25173	delivery	5	17
126056	2020-08-25 21:55:28	2020-08-25	14	[{"id_menu":2,"count":1}]	7931	delivery	5	19
126057	2020-08-25 21:59:39	2020-08-25	12	[{"id_menu":1,"count":1}]	11732	pick-up	0	12
126058	2020-08-25 22:08:43	2020-08-25	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	47610	delivery	5	45
126059	2020-08-25 22:11:47	2020-08-25	17	[{"id_menu":5,"count":3},{"id_menu":6,"count":1}]	22707	delivery	5	22
126060	2020-08-25 22:11:56	2020-08-25	9	[{"id_menu":6,"count":1}]	33194	delivery	5	14
126061	2020-08-25 22:16:48	2020-08-25	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	47549	delivery	5	38
126062	2020-08-25 22:21:37	2020-08-25	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	16911	delivery	5	27
126063	2020-08-25 22:22:43	2020-08-25	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	47618	delivery	5	38
126064	2020-08-25 22:23:50	2020-08-25	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	8873	pick-up	0	22
126065	2020-08-25 22:25:36	2020-08-25	9	[{"id_menu":7,"count":1}]	44178	pick-up	0	9
126066	2020-08-25 22:27:15	2020-08-25	9	[{"id_menu":6,"count":1}]	22863	delivery	5	14
126067	2020-08-25 22:40:33	2020-08-25	9	[{"id_menu":6,"count":1}]	9081	delivery	5	14
126068	2020-08-25 22:41:54	2020-08-25	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	47721	delivery	5	38
126069	2020-08-25 22:42:29	2020-08-25	12	[{"id_menu":3,"count":1}]	31894	delivery	5	17
126070	2020-08-25 22:45:56	2020-08-25	9	[{"id_menu":6,"count":1}]	47594	pick-up	0	9
126071	2020-08-25 22:47:12	2020-08-25	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	27242	delivery	5	30
126072	2020-08-25 22:47:51	2020-08-25	12	[{"id_menu":3,"count":1}]	12713	delivery	5	17
126073	2020-08-25 22:48:41	2020-08-25	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	40429	delivery	5	31
126074	2020-08-25 22:52:34	2020-08-25	9	[{"id_menu":6,"count":1}]	21292	delivery	5	14
126075	2020-08-25 22:52:56	2020-08-25	9	[{"id_menu":6,"count":1}]	24093	pick-up	0	9
126076	2020-08-25 22:56:57	2020-08-25	9	[{"id_menu":7,"count":1}]	3284	delivery	5	14
126077	2020-08-25 22:57:17	2020-08-25	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19759	delivery	5	53
126078	2020-08-25 23:00:33	2020-08-25	8	[{"id_menu":5,"count":1}]	47627	delivery	5	13
126079	2020-08-25 23:03:53	2020-08-25	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	7704	delivery	5	40
126080	2020-08-25 23:07:58	2020-08-25	8	[{"id_menu":5,"count":1}]	47716	delivery	5	13
126081	2020-08-25 23:08:19	2020-08-25	8	[{"id_menu":5,"count":1}]	41900	pick-up	0	8
126082	2020-08-25 23:09:46	2020-08-25	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	31936	delivery	5	28
126083	2020-08-25 23:10:06	2020-08-25	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25181	delivery	5	23
126084	2020-08-25 23:12:17	2020-08-25	14	[{"id_menu":2,"count":1}]	46161	pick-up	0	14
126085	2020-08-25 23:18:00	2020-08-25	12	[{"id_menu":1,"count":1}]	47700	delivery	5	17
126086	2020-08-25 23:20:33	2020-08-25	14	[{"id_menu":2,"count":1}]	21575	pick-up	0	14
126087	2020-08-25 23:33:06	2020-08-25	12	[{"id_menu":1,"count":1}]	45529	pick-up	0	12
126088	2020-08-25 23:36:18	2020-08-25	17	[{"id_menu":4,"count":1}]	22130	delivery	5	22
126089	2020-08-25 23:37:40	2020-08-25	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	47699	delivery	5	22
126090	2020-08-25 23:38:19	2020-08-25	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	45974	delivery	5	34
126091	2020-08-25 23:40:16	2020-08-25	12	[{"id_menu":3,"count":1}]	30651	delivery	5	17
126092	2020-08-25 23:42:31	2020-08-25	9	[{"id_menu":6,"count":3}]	22784	pick-up	0	9
126093	2020-08-25 23:42:41	2020-08-25	8	[{"id_menu":5,"count":2}]	47694	delivery	5	13
126094	2020-08-25 23:46:39	2020-08-25	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	38246	delivery	5	56
126095	2020-08-25 23:52:26	2020-08-25	8	[{"id_menu":5,"count":1}]	3077	pick-up	0	8
126096	2020-08-26 00:00:53	2020-08-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1693	pick-up	0	21
126097	2020-08-26 00:03:00	2020-08-26	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	47961	delivery	5	40
126098	2020-08-26 00:04:25	2020-08-26	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	32765	delivery	5	23
126099	2020-08-26 00:06:54	2020-08-26	12	[{"id_menu":1,"count":1}]	8461	delivery	5	17
126100	2020-08-26 00:07:13	2020-08-26	9	[{"id_menu":7,"count":1}]	39623	delivery	5	14
126101	2020-08-26 00:08:16	2020-08-26	14	[{"id_menu":2,"count":1}]	6108	delivery	5	19
126102	2020-08-26 00:12:10	2020-08-26	12	[{"id_menu":3,"count":1}]	9160	pick-up	0	12
126103	2020-08-26 00:14:21	2020-08-26	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	15791	pick-up	0	25
126104	2020-08-26 00:14:28	2020-08-26	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	24241	delivery	5	40
126105	2020-08-26 00:17:10	2020-08-26	12	[{"id_menu":1,"count":1}]	27711	delivery	5	17
126106	2020-08-26 00:18:33	2020-08-26	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13185	delivery	5	36
126107	2020-08-26 00:22:46	2020-08-26	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11886	delivery	5	48
126108	2020-08-26 00:29:52	2020-08-26	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1679	pick-up	0	29
126109	2020-08-26 00:30:25	2020-08-26	9	[{"id_menu":6,"count":1}]	47860	delivery	5	14
126110	2020-08-26 00:31:28	2020-08-26	14	[{"id_menu":2,"count":1}]	14970	delivery	5	19
126111	2020-08-26 00:32:48	2020-08-26	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	23439	delivery	5	37
126112	2020-08-26 00:34:45	2020-08-26	8	[{"id_menu":5,"count":1}]	30578	delivery	5	13
126113	2020-08-26 00:39:51	2020-08-26	9	[{"id_menu":6,"count":1}]	47888	delivery	5	14
126114	2020-08-26 00:40:13	2020-08-26	14	[{"id_menu":2,"count":2}]	38617	delivery	5	19
126115	2020-08-26 00:40:55	2020-08-26	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	31171	delivery	5	40
126116	2020-08-26 00:42:54	2020-08-26	8	[{"id_menu":5,"count":1}]	7836	delivery	5	13
126117	2020-08-26 00:44:07	2020-08-26	14	[{"id_menu":2,"count":1}]	47909	delivery	5	19
126118	2020-08-26 00:44:16	2020-08-26	9	[{"id_menu":6,"count":1}]	47904	delivery	5	14
126119	2020-08-26 00:46:12	2020-08-26	8	[{"id_menu":5,"count":1}]	46305	delivery	5	13
126120	2020-08-26 00:46:38	2020-08-26	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	148	pick-up	0	22
126121	2020-08-26 00:47:12	2020-08-26	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	7835	pick-up	0	26
126122	2020-08-26 00:49:05	2020-08-26	12	[{"id_menu":1,"count":1}]	6349	delivery	5	17
126123	2020-08-26 00:49:46	2020-08-26	14	[{"id_menu":2,"count":1}]	47917	pick-up	0	14
126124	2020-08-26 00:51:01	2020-08-26	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	47842	delivery	5	35
126125	2020-08-26 00:51:56	2020-08-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43027	delivery	5	23
126126	2020-08-26 00:52:07	2020-08-26	17	[{"id_menu":4,"count":1}]	1931	delivery	5	22
126127	2020-08-26 00:52:07	2020-08-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	47780	delivery	5	22
126128	2020-08-26 00:54:04	2020-08-26	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	22969	delivery	5	30
126129	2020-08-26 00:56:14	2020-08-26	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	47788	delivery	5	45
126130	2020-08-26 01:00:23	2020-08-26	9	[{"id_menu":6,"count":1}]	17056	pick-up	0	9
126131	2020-08-26 01:00:42	2020-08-26	9	[{"id_menu":6,"count":2}]	31218	pick-up	0	9
126132	2020-08-26 01:02:32	2020-08-26	12	[{"id_menu":1,"count":1}]	21694	pick-up	0	12
126133	2020-08-26 01:05:32	2020-08-26	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40510	delivery	5	40
126134	2020-08-26 01:10:28	2020-08-26	9	[{"id_menu":7,"count":1}]	39537	delivery	5	14
126135	2020-08-26 01:11:39	2020-08-26	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	39551	delivery	5	36
126136	2020-08-26 01:12:15	2020-08-26	12	[{"id_menu":1,"count":1}]	47923	pick-up	0	12
126137	2020-08-26 01:13:27	2020-08-26	9	[{"id_menu":7,"count":1}]	47899	delivery	5	14
126138	2020-08-26 01:14:51	2020-08-26	14	[{"id_menu":2,"count":1}]	1296	pick-up	0	14
126139	2020-08-26 01:14:59	2020-08-26	8	[{"id_menu":5,"count":1}]	47838	delivery	5	13
126140	2020-08-26 01:15:25	2020-08-26	8	[{"id_menu":5,"count":1}]	1453	pick-up	0	8
126141	2020-08-26 01:15:35	2020-08-26	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41647	delivery	5	43
126142	2020-08-26 01:18:36	2020-08-26	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	21233	delivery	5	45
126143	2020-08-26 01:18:58	2020-08-26	26	[{"id_menu":4,"count":3},{"id_menu":7,"count":1}]	44136	delivery	5	31
126144	2020-08-26 01:19:14	2020-08-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32627	delivery	5	22
126145	2020-08-26 01:19:31	2020-08-26	14	[{"id_menu":2,"count":1}]	47865	pick-up	0	14
126146	2020-08-26 01:19:48	2020-08-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	47761	delivery	5	26
126147	2020-08-26 01:21:02	2020-08-26	12	[{"id_menu":1,"count":1}]	47779	delivery	5	17
126148	2020-08-26 01:22:35	2020-08-26	9	[{"id_menu":6,"count":2}]	41533	delivery	5	14
126149	2020-08-26 01:23:27	2020-08-26	14	[{"id_menu":2,"count":1}]	26784	delivery	5	19
126150	2020-08-26 01:25:02	2020-08-26	9	[{"id_menu":6,"count":2}]	47945	delivery	5	14
126151	2020-08-26 01:27:33	2020-08-26	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	7797	delivery	5	36
126152	2020-08-26 01:27:52	2020-08-26	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	47953	delivery	5	35
126153	2020-08-26 01:28:30	2020-08-26	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	14522	delivery	5	23
126154	2020-08-26 01:30:06	2020-08-26	17	[{"id_menu":4,"count":1}]	14088	pick-up	0	17
126155	2020-08-26 01:32:39	2020-08-26	17	[{"id_menu":4,"count":1}]	4658	delivery	5	22
126156	2020-08-26 01:39:05	2020-08-26	12	[{"id_menu":3,"count":1}]	24397	delivery	5	17
126157	2020-08-26 01:39:39	2020-08-26	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	27161	pick-up	0	29
126158	2020-08-26 01:41:46	2020-08-26	8	[{"id_menu":5,"count":1}]	35749	delivery	5	13
126159	2020-08-26 01:41:52	2020-08-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	4798	pick-up	0	21
126160	2020-08-26 01:43:25	2020-08-26	9	[{"id_menu":6,"count":1}]	4683	delivery	5	14
126161	2020-08-26 01:44:19	2020-08-26	9	[{"id_menu":6,"count":1}]	47802	delivery	5	14
126162	2020-08-26 01:48:33	2020-08-26	12	[{"id_menu":1,"count":1}]	31581	pick-up	0	12
126163	2020-08-26 01:49:17	2020-08-26	9	[{"id_menu":6,"count":1}]	47748	delivery	5	14
126164	2020-08-26 01:53:28	2020-08-26	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	47896	delivery	5	26
126165	2020-08-26 01:56:02	2020-08-26	12	[{"id_menu":1,"count":1}]	4402	delivery	5	17
126166	2020-08-26 01:56:41	2020-08-26	14	[{"id_menu":2,"count":2}]	10694	pick-up	0	14
126167	2020-08-26 01:57:26	2020-08-26	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	24585	pick-up	0	35
126168	2020-08-26 01:57:33	2020-08-26	14	[{"id_menu":2,"count":2}]	22949	delivery	5	19
126169	2020-08-26 01:57:33	2020-08-26	14	[{"id_menu":2,"count":1}]	33732	pick-up	0	14
126170	2020-08-26 01:59:46	2020-08-26	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9171	pick-up	0	38
126171	2020-08-26 02:01:03	2020-08-26	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	12231	delivery	5	40
126172	2020-08-26 02:01:22	2020-08-26	12	[{"id_menu":1,"count":1}]	41624	pick-up	0	12
126173	2020-08-26 02:11:22	2020-08-26	8	[{"id_menu":5,"count":1}]	16190	delivery	5	13
126174	2020-08-26 02:13:10	2020-08-26	9	[{"id_menu":6,"count":1}]	47832	delivery	5	14
126175	2020-08-26 02:13:40	2020-08-26	9	[{"id_menu":6,"count":1}]	7991	delivery	5	14
126176	2020-08-26 02:14:12	2020-08-26	14	[{"id_menu":2,"count":2}]	47895	delivery	5	19
126177	2020-08-26 02:16:49	2020-08-26	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	14692	delivery	5	51
126178	2020-08-26 02:17:34	2020-08-26	9	[{"id_menu":6,"count":1}]	1587	pick-up	0	9
126179	2020-08-26 02:18:20	2020-08-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13848	delivery	5	22
126180	2020-08-26 02:23:58	2020-08-26	9	[{"id_menu":7,"count":2}]	23220	delivery	5	14
126181	2020-08-26 02:23:59	2020-08-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	47892	delivery	5	23
126182	2020-08-26 02:28:07	2020-08-26	9	[{"id_menu":7,"count":2}]	46752	delivery	5	14
126183	2020-08-26 02:30:14	2020-08-26	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	25254	pick-up	0	46
126184	2020-08-26 02:33:33	2020-08-26	9	[{"id_menu":7,"count":1}]	18500	delivery	5	14
126185	2020-08-26 02:33:35	2020-08-26	12	[{"id_menu":3,"count":1}]	47936	delivery	5	17
126186	2020-08-26 02:34:42	2020-08-26	12	[{"id_menu":1,"count":1}]	12035	delivery	5	17
126187	2020-08-26 02:35:31	2020-08-26	17	[{"id_menu":4,"count":1}]	2773	delivery	5	22
126188	2020-08-26 02:41:44	2020-08-26	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	41222	delivery	5	43
126189	2020-08-26 02:43:22	2020-08-26	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	3048	delivery	5	31
126190	2020-08-26 02:43:43	2020-08-26	9	[{"id_menu":7,"count":1}]	47807	delivery	5	14
126191	2020-08-26 02:44:51	2020-08-26	9	[{"id_menu":7,"count":1}]	12000	delivery	5	14
126192	2020-08-26 02:55:20	2020-08-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	47814	delivery	5	23
126193	2020-08-26 02:56:16	2020-08-26	12	[{"id_menu":3,"count":1}]	38895	delivery	5	17
126194	2020-08-26 02:56:59	2020-08-26	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39735	delivery	5	40
126195	2020-08-26 03:01:44	2020-08-26	9	[{"id_menu":7,"count":1}]	43111	delivery	5	14
126196	2020-08-26 03:04:00	2020-08-26	17	[{"id_menu":4,"count":1}]	46287	delivery	5	22
126197	2020-08-26 03:07:04	2020-08-26	12	[{"id_menu":3,"count":1}]	36794	delivery	5	17
126198	2020-08-26 03:07:05	2020-08-26	9	[{"id_menu":6,"count":1}]	47897	delivery	5	14
126199	2020-08-26 03:07:42	2020-08-26	14	[{"id_menu":2,"count":2}]	47755	delivery	5	19
126200	2020-08-26 03:09:16	2020-08-26	8	[{"id_menu":5,"count":1}]	35853	delivery	5	13
126201	2020-08-26 03:09:44	2020-08-26	17	[{"id_menu":4,"count":1}]	47844	pick-up	0	17
126202	2020-08-26 03:10:32	2020-08-26	17	[{"id_menu":4,"count":1}]	7156	delivery	5	22
126203	2020-08-26 03:11:32	2020-08-26	9	[{"id_menu":7,"count":1}]	2358	pick-up	0	9
126204	2020-08-26 03:11:37	2020-08-26	9	[{"id_menu":6,"count":1}]	3062	delivery	5	14
126205	2020-08-26 03:14:36	2020-08-26	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5157	delivery	5	36
126206	2020-08-26 03:15:40	2020-08-26	9	[{"id_menu":6,"count":1}]	47804	delivery	5	14
126207	2020-08-26 03:18:36	2020-08-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	44504	delivery	5	28
126208	2020-08-26 03:20:25	2020-08-26	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	21874	pick-up	0	20
126209	2020-08-26 03:21:26	2020-08-26	17	[{"id_menu":4,"count":1}]	45917	delivery	5	22
126210	2020-08-26 03:21:36	2020-08-26	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	27487	delivery	5	34
126211	2020-08-26 03:22:51	2020-08-26	8	[{"id_menu":5,"count":1}]	35375	delivery	5	13
126212	2020-08-26 03:32:00	2020-08-26	9	[{"id_menu":6,"count":1}]	19717	pick-up	0	9
126213	2020-08-26 03:36:20	2020-08-26	9	[{"id_menu":7,"count":1}]	32980	delivery	5	14
126214	2020-08-26 03:37:13	2020-08-26	9	[{"id_menu":7,"count":1}]	11766	delivery	5	14
126215	2020-08-26 03:38:48	2020-08-26	8	[{"id_menu":5,"count":1}]	47862	delivery	5	13
126216	2020-08-26 03:39:15	2020-08-26	14	[{"id_menu":2,"count":1}]	12890	pick-up	0	14
126217	2020-08-26 03:42:04	2020-08-26	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	47902	delivery	5	51
126218	2020-08-26 03:42:31	2020-08-26	9	[{"id_menu":6,"count":1}]	47738	delivery	5	14
126219	2020-08-26 03:44:01	2020-08-26	12	[{"id_menu":3,"count":1}]	42202	delivery	5	17
126220	2020-08-26 03:44:34	2020-08-26	9	[{"id_menu":7,"count":1}]	1852	delivery	5	14
126221	2020-08-26 03:47:03	2020-08-26	9	[{"id_menu":6,"count":1}]	34615	delivery	5	14
126222	2020-08-26 03:49:18	2020-08-26	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	17470	pick-up	0	20
126223	2020-08-26 03:49:19	2020-08-26	9	[{"id_menu":7,"count":1}]	23875	delivery	5	14
126224	2020-08-26 03:53:21	2020-08-26	12	[{"id_menu":3,"count":1}]	47900	delivery	5	17
126225	2020-08-26 03:59:03	2020-08-26	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	40765	delivery	5	30
126226	2020-08-26 03:59:26	2020-08-26	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":2}]	41779	delivery	5	27
126227	2020-08-26 04:01:40	2020-08-26	14	[{"id_menu":2,"count":2}]	2207	delivery	5	19
126228	2020-08-26 04:03:13	2020-08-26	9	[{"id_menu":7,"count":1}]	1578	delivery	5	14
126229	2020-08-26 04:06:19	2020-08-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20896	delivery	5	22
126230	2020-08-26 04:07:08	2020-08-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	35571	delivery	5	22
126231	2020-08-26 04:08:12	2020-08-26	9	[{"id_menu":7,"count":1}]	47873	delivery	5	14
126232	2020-08-26 04:09:46	2020-08-26	12	[{"id_menu":3,"count":1}]	9688	delivery	5	17
126233	2020-08-26 04:09:49	2020-08-26	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	19657	delivery	5	27
126234	2020-08-26 04:13:14	2020-08-26	17	[{"id_menu":4,"count":1}]	14679	pick-up	0	17
126235	2020-08-26 04:14:42	2020-08-26	9	[{"id_menu":6,"count":1}]	30999	delivery	5	14
126236	2020-08-26 04:15:01	2020-08-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4075	pick-up	0	26
126237	2020-08-26 04:15:23	2020-08-26	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	28377	pick-up	0	18
126238	2020-08-26 04:17:50	2020-08-26	8	[{"id_menu":5,"count":1}]	20723	delivery	5	13
126239	2020-08-26 04:17:58	2020-08-26	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	14029	delivery	5	52
126240	2020-08-26 04:20:42	2020-08-26	9	[{"id_menu":6,"count":1}]	14239	pick-up	0	9
126241	2020-08-26 04:24:31	2020-08-26	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	47787	delivery	5	43
126242	2020-08-26 04:24:39	2020-08-26	14	[{"id_menu":2,"count":1}]	14612	delivery	5	19
126243	2020-08-26 04:27:33	2020-08-26	9	[{"id_menu":6,"count":1}]	47929	pick-up	0	9
126244	2020-08-26 04:32:35	2020-08-26	9	[{"id_menu":7,"count":1}]	46938	delivery	5	14
126245	2020-08-26 04:33:14	2020-08-26	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	37202	delivery	5	25
126246	2020-08-26 04:34:59	2020-08-26	9	[{"id_menu":6,"count":1}]	43770	pick-up	0	9
126247	2020-08-26 04:40:57	2020-08-26	12	[{"id_menu":3,"count":1}]	26970	pick-up	0	12
126248	2020-08-26 04:41:06	2020-08-26	8	[{"id_menu":5,"count":1}]	47774	delivery	5	13
126249	2020-08-26 04:41:06	2020-08-26	8	[{"id_menu":5,"count":1}]	47845	delivery	5	13
126250	2020-08-26 04:42:06	2020-08-26	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	47829	delivery	5	29
126251	2020-08-26 04:42:40	2020-08-26	12	[{"id_menu":1,"count":1}]	1400	pick-up	0	12
126252	2020-08-26 04:44:06	2020-08-26	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	23553	delivery	5	42
126253	2020-08-26 04:44:20	2020-08-26	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	47756	pick-up	0	26
126254	2020-08-26 04:45:00	2020-08-26	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	164	pick-up	0	46
126255	2020-08-26 04:45:20	2020-08-26	17	[{"id_menu":4,"count":1}]	4800	delivery	5	22
126256	2020-08-26 04:45:52	2020-08-26	9	[{"id_menu":6,"count":1}]	14243	delivery	5	14
126257	2020-08-26 04:46:41	2020-08-26	8	[{"id_menu":5,"count":1}]	2527	pick-up	0	8
126258	2020-08-26 04:46:48	2020-08-26	12	[{"id_menu":1,"count":1}]	3442	pick-up	0	12
126259	2020-08-26 04:48:40	2020-08-26	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	44944	delivery	5	40
126260	2020-08-26 04:51:43	2020-08-26	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	13674	delivery	5	29
126261	2020-08-26 04:53:26	2020-08-26	9	[{"id_menu":6,"count":1}]	47863	delivery	5	14
126262	2020-08-26 04:54:59	2020-08-26	9	[{"id_menu":6,"count":1}]	47809	delivery	5	14
126263	2020-08-26 04:55:17	2020-08-26	9	[{"id_menu":7,"count":1}]	33376	delivery	5	14
126264	2020-08-26 04:55:49	2020-08-26	9	[{"id_menu":7,"count":1}]	47920	delivery	5	14
126265	2020-08-26 05:00:42	2020-08-26	12	[{"id_menu":1,"count":1}]	1165	pick-up	0	12
126266	2020-08-26 05:01:27	2020-08-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13089	delivery	5	23
126267	2020-08-26 05:04:08	2020-08-26	9	[{"id_menu":6,"count":1}]	31185	delivery	5	14
126268	2020-08-26 05:06:10	2020-08-26	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	47947	delivery	5	31
126269	2020-08-26 05:06:58	2020-08-26	8	[{"id_menu":5,"count":1}]	3898	pick-up	0	8
126270	2020-08-26 05:07:50	2020-08-26	8	[{"id_menu":5,"count":1}]	47758	delivery	5	13
126271	2020-08-26 05:08:51	2020-08-26	9	[{"id_menu":6,"count":1}]	17790	delivery	5	14
126272	2020-08-26 05:10:50	2020-08-26	12	[{"id_menu":3,"count":1}]	30855	pick-up	0	12
126273	2020-08-26 05:11:59	2020-08-26	9	[{"id_menu":7,"count":1}]	27837	delivery	5	14
126274	2020-08-26 05:14:53	2020-08-26	12	[{"id_menu":3,"count":1}]	10280	delivery	5	17
126275	2020-08-26 05:21:16	2020-08-26	12	[{"id_menu":1,"count":1}]	1055	delivery	5	17
126276	2020-08-26 05:21:33	2020-08-26	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	41403	delivery	5	34
126277	2020-08-26 05:21:35	2020-08-26	9	[{"id_menu":6,"count":1}]	23788	delivery	5	14
126278	2020-08-26 05:22:31	2020-08-26	9	[{"id_menu":6,"count":1}]	26624	delivery	5	14
126279	2020-08-26 05:23:20	2020-08-26	14	[{"id_menu":2,"count":1}]	31987	delivery	5	19
126280	2020-08-26 05:24:57	2020-08-26	14	[{"id_menu":2,"count":1}]	47837	pick-up	0	14
126281	2020-08-26 05:25:55	2020-08-26	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	30951	delivery	5	31
126282	2020-08-26 05:27:28	2020-08-26	9	[{"id_menu":6,"count":1}]	47793	delivery	5	14
126283	2020-08-26 05:29:05	2020-08-26	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	47750	delivery	5	36
126284	2020-08-26 05:32:17	2020-08-26	9	[{"id_menu":6,"count":1}]	17043	delivery	5	14
126285	2020-08-26 05:34:09	2020-08-26	8	[{"id_menu":5,"count":2}]	23353	delivery	5	13
126286	2020-08-26 05:36:01	2020-08-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	32287	delivery	5	22
126287	2020-08-26 05:36:34	2020-08-26	9	[{"id_menu":7,"count":1}]	24485	pick-up	0	9
126288	2020-08-26 05:37:14	2020-08-26	17	[{"id_menu":4,"count":1}]	47797	delivery	5	22
126289	2020-08-26 05:41:24	2020-08-26	8	[{"id_menu":5,"count":1}]	528	delivery	5	13
126290	2020-08-26 05:41:30	2020-08-26	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	32002	delivery	5	25
126291	2020-08-26 05:41:59	2020-08-26	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	28952	delivery	5	34
126292	2020-08-26 05:43:22	2020-08-26	12	[{"id_menu":1,"count":1}]	47910	delivery	5	17
126293	2020-08-26 05:43:41	2020-08-26	12	[{"id_menu":3,"count":1}]	20283	delivery	5	17
126294	2020-08-26 05:44:21	2020-08-26	8	[{"id_menu":5,"count":1}]	14982	pick-up	0	8
126295	2020-08-26 05:44:21	2020-08-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5575	delivery	5	22
126296	2020-08-26 05:50:32	2020-08-26	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	38342	delivery	5	30
126297	2020-08-26 05:53:21	2020-08-26	8	[{"id_menu":5,"count":1}]	14637	delivery	5	13
126298	2020-08-26 05:54:20	2020-08-26	17	[{"id_menu":4,"count":1}]	42341	delivery	5	22
126299	2020-08-26 05:57:19	2020-08-26	12	[{"id_menu":3,"count":1}]	2545	delivery	5	17
126300	2020-08-26 06:06:40	2020-08-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	28269	delivery	5	28
126301	2020-08-26 06:06:55	2020-08-26	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	47890	delivery	5	28
126302	2020-08-26 06:07:37	2020-08-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	47781	delivery	5	28
126303	2020-08-26 06:08:24	2020-08-26	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	4783	delivery	5	23
126304	2020-08-26 06:09:07	2020-08-26	9	[{"id_menu":7,"count":1}]	18836	delivery	5	14
126305	2020-08-26 06:09:24	2020-08-26	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	10362	delivery	5	26
126306	2020-08-26 06:13:23	2020-08-26	8	[{"id_menu":5,"count":1}]	47757	delivery	5	13
126307	2020-08-26 06:16:25	2020-08-26	14	[{"id_menu":2,"count":1}]	47786	delivery	5	19
126308	2020-08-26 06:20:22	2020-08-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	7200	pick-up	0	23
126309	2020-08-26 06:20:55	2020-08-26	12	[{"id_menu":1,"count":1}]	29621	pick-up	0	12
126310	2020-08-26 06:23:13	2020-08-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	47847	delivery	5	22
126311	2020-08-26 06:24:15	2020-08-26	17	[{"id_menu":4,"count":1}]	816	pick-up	0	17
126312	2020-08-26 06:25:30	2020-08-26	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14244	delivery	5	37
126313	2020-08-26 06:33:17	2020-08-26	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	28827	pick-up	0	43
126314	2020-08-26 06:33:48	2020-08-26	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	35937	delivery	5	36
126315	2020-08-26 06:37:23	2020-08-26	9	[{"id_menu":6,"count":1}]	482	delivery	5	14
126316	2020-08-26 06:42:45	2020-08-26	8	[{"id_menu":5,"count":1}]	32441	delivery	5	13
126317	2020-08-26 06:43:57	2020-08-26	12	[{"id_menu":3,"count":1}]	20183	delivery	5	17
126318	2020-08-26 06:46:46	2020-08-26	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	7053	pick-up	0	29
126319	2020-08-26 06:48:13	2020-08-26	9	[{"id_menu":7,"count":1}]	23986	delivery	5	14
126320	2020-08-26 06:49:50	2020-08-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	24246	delivery	5	26
126321	2020-08-26 06:49:57	2020-08-26	9	[{"id_menu":6,"count":1}]	46120	delivery	5	14
126322	2020-08-26 06:50:07	2020-08-26	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	26631	delivery	5	45
126323	2020-08-26 06:50:21	2020-08-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":3}]	38614	delivery	5	22
126324	2020-08-26 06:52:40	2020-08-26	9	[{"id_menu":6,"count":1}]	20716	delivery	5	14
126325	2020-08-26 06:56:42	2020-08-26	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	47884	delivery	5	45
126326	2020-08-26 06:56:45	2020-08-26	17	[{"id_menu":4,"count":1}]	22473	pick-up	0	17
126327	2020-08-26 06:59:51	2020-08-26	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	39819	delivery	5	28
126328	2020-08-26 07:00:06	2020-08-26	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	47850	delivery	5	40
126329	2020-08-26 07:01:48	2020-08-26	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	47870	delivery	5	37
126330	2020-08-26 07:02:50	2020-08-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	31480	delivery	5	28
126331	2020-08-26 07:03:36	2020-08-26	12	[{"id_menu":3,"count":1}]	47819	pick-up	0	12
126332	2020-08-26 07:03:51	2020-08-26	12	[{"id_menu":1,"count":1}]	22152	delivery	5	17
126333	2020-08-26 07:04:28	2020-08-26	8	[{"id_menu":5,"count":1}]	47915	delivery	5	13
126334	2020-08-26 07:05:04	2020-08-26	14	[{"id_menu":2,"count":1}]	22071	pick-up	0	14
126335	2020-08-26 07:08:28	2020-08-26	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3592	delivery	5	36
126336	2020-08-26 07:08:50	2020-08-26	14	[{"id_menu":2,"count":1}]	7631	pick-up	0	14
126337	2020-08-26 07:12:33	2020-08-26	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	12122	delivery	5	31
126338	2020-08-26 07:13:01	2020-08-26	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40998	delivery	5	35
126339	2020-08-26 07:15:25	2020-08-26	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39043	delivery	5	54
126340	2020-08-26 07:15:29	2020-08-26	9	[{"id_menu":7,"count":1}]	47823	delivery	5	14
126341	2020-08-26 07:18:05	2020-08-26	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	21690	delivery	5	45
126342	2020-08-26 07:22:35	2020-08-26	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	6721	pick-up	0	26
126343	2020-08-26 07:22:41	2020-08-26	12	[{"id_menu":1,"count":1}]	47830	delivery	5	17
126344	2020-08-26 07:25:20	2020-08-26	9	[{"id_menu":6,"count":1}]	42352	delivery	5	14
126345	2020-08-26 07:25:45	2020-08-26	12	[{"id_menu":3,"count":1}]	12129	pick-up	0	12
126346	2020-08-26 07:29:12	2020-08-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	47796	delivery	5	26
126347	2020-08-26 07:29:59	2020-08-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	1071	pick-up	0	23
126348	2020-08-26 07:32:08	2020-08-26	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	27058	delivery	5	25
126349	2020-08-26 07:32:18	2020-08-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	359	delivery	5	28
126350	2020-08-26 07:36:40	2020-08-26	9	[{"id_menu":6,"count":1}]	27394	delivery	5	14
126351	2020-08-26 07:36:52	2020-08-26	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	12452	delivery	5	36
126352	2020-08-26 07:42:42	2020-08-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24030	pick-up	0	17
126353	2020-08-26 07:42:44	2020-08-26	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	5298	delivery	5	28
126354	2020-08-26 07:43:10	2020-08-26	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	47834	delivery	5	31
126355	2020-08-26 07:43:30	2020-08-26	17	[{"id_menu":4,"count":1}]	40372	delivery	5	22
126356	2020-08-26 07:44:58	2020-08-26	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":3}]	23862	delivery	5	31
126357	2020-08-26 07:48:54	2020-08-26	14	[{"id_menu":2,"count":1}]	47874	pick-up	0	14
126358	2020-08-26 07:49:49	2020-08-26	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	39280	delivery	5	23
126359	2020-08-26 07:50:22	2020-08-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	17344	delivery	5	23
126360	2020-08-26 07:50:34	2020-08-26	12	[{"id_menu":3,"count":1}]	19916	delivery	5	17
126361	2020-08-26 07:52:55	2020-08-26	12	[{"id_menu":1,"count":1}]	2429	pick-up	0	12
126362	2020-08-26 07:53:57	2020-08-26	17	[{"id_menu":4,"count":1}]	33892	delivery	5	22
126363	2020-08-26 07:55:43	2020-08-26	12	[{"id_menu":3,"count":1}]	15683	pick-up	0	12
126364	2020-08-26 07:56:25	2020-08-26	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	38135	delivery	5	36
126365	2020-08-26 07:57:18	2020-08-26	9	[{"id_menu":6,"count":1}]	18828	pick-up	0	9
126366	2020-08-26 07:58:24	2020-08-26	9	[{"id_menu":6,"count":1}]	9369	delivery	5	14
126367	2020-08-26 08:00:36	2020-08-26	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	27567	delivery	5	22
126368	2020-08-26 08:00:54	2020-08-26	9	[{"id_menu":6,"count":1}]	47743	pick-up	0	9
126369	2020-08-26 08:01:51	2020-08-26	8	[{"id_menu":5,"count":1}]	47871	delivery	5	13
126370	2020-08-26 08:01:51	2020-08-26	12	[{"id_menu":1,"count":1}]	4595	delivery	5	17
126371	2020-08-26 08:01:56	2020-08-26	9	[{"id_menu":7,"count":1}]	47840	delivery	5	14
126372	2020-08-26 08:02:11	2020-08-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24274	pick-up	0	17
126373	2020-08-26 08:04:10	2020-08-26	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	47933	delivery	5	26
126374	2020-08-26 08:05:27	2020-08-26	9	[{"id_menu":6,"count":1}]	20051	delivery	5	14
126375	2020-08-26 08:06:05	2020-08-26	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	27481	delivery	5	40
126376	2020-08-26 08:06:09	2020-08-26	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	10438	delivery	5	31
126377	2020-08-26 08:08:45	2020-08-26	12	[{"id_menu":3,"count":1}]	27191	pick-up	0	12
126378	2020-08-26 08:09:27	2020-08-26	14	[{"id_menu":2,"count":1}]	18602	pick-up	0	14
126379	2020-08-26 08:09:30	2020-08-26	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	47905	delivery	5	42
126380	2020-08-26 08:09:56	2020-08-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	47938	delivery	5	31
126381	2020-08-26 08:12:04	2020-08-26	12	[{"id_menu":3,"count":1}]	12073	delivery	5	17
126382	2020-08-26 08:12:55	2020-08-26	17	[{"id_menu":4,"count":1}]	47767	delivery	5	22
126383	2020-08-26 08:13:38	2020-08-26	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	24616	delivery	5	29
126384	2020-08-26 08:14:05	2020-08-26	9	[{"id_menu":6,"count":1}]	47643	delivery	5	14
126385	2020-08-26 08:15:03	2020-08-26	17	[{"id_menu":4,"count":1}]	33309	delivery	5	22
126386	2020-08-26 08:15:26	2020-08-26	14	[{"id_menu":2,"count":1}]	46603	delivery	5	19
126387	2020-08-26 08:22:10	2020-08-26	12	[{"id_menu":3,"count":1}]	5252	pick-up	0	12
126388	2020-08-26 08:22:37	2020-08-26	17	[{"id_menu":4,"count":1}]	30016	delivery	5	22
126389	2020-08-26 08:24:44	2020-08-26	12	[{"id_menu":1,"count":1}]	37709	delivery	5	17
126390	2020-08-26 08:24:53	2020-08-26	9	[{"id_menu":7,"count":2}]	47926	delivery	5	14
126391	2020-08-26 08:26:47	2020-08-26	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	43782	delivery	5	34
126392	2020-08-26 08:27:58	2020-08-26	9	[{"id_menu":7,"count":1}]	25836	pick-up	0	9
126393	2020-08-26 08:28:15	2020-08-26	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	17210	delivery	5	31
126394	2020-08-26 08:34:01	2020-08-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	1972	delivery	5	28
126395	2020-08-26 08:37:25	2020-08-26	38	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	18927	delivery	5	43
126396	2020-08-26 08:38:02	2020-08-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21763	pick-up	0	18
126397	2020-08-26 08:39:50	2020-08-26	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	37834	pick-up	0	46
126398	2020-08-26 08:43:55	2020-08-26	17	[{"id_menu":4,"count":2}]	13747	delivery	5	22
126399	2020-08-26 08:44:43	2020-08-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	18232	pick-up	0	23
126400	2020-08-26 08:45:05	2020-08-26	17	[{"id_menu":4,"count":1}]	6945	pick-up	0	17
126401	2020-08-26 08:45:18	2020-08-26	14	[{"id_menu":2,"count":1}]	30093	pick-up	0	14
126402	2020-08-26 08:50:53	2020-08-26	8	[{"id_menu":5,"count":1}]	29252	delivery	5	13
126403	2020-08-26 08:50:58	2020-08-26	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	35004	delivery	5	31
126404	2020-08-26 08:51:35	2020-08-26	8	[{"id_menu":5,"count":1}]	23633	delivery	5	13
126405	2020-08-26 08:51:38	2020-08-26	8	[{"id_menu":5,"count":1}]	47954	delivery	5	13
126406	2020-08-26 08:52:11	2020-08-26	9	[{"id_menu":6,"count":1}]	9922	pick-up	0	9
126407	2020-08-26 08:52:35	2020-08-26	9	[{"id_menu":6,"count":1}]	7046	pick-up	0	9
126408	2020-08-26 08:53:21	2020-08-26	8	[{"id_menu":5,"count":1}]	25531	delivery	5	13
126409	2020-08-26 08:56:02	2020-08-26	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	5792	delivery	5	26
126410	2020-08-26 08:56:55	2020-08-26	12	[{"id_menu":1,"count":1}]	26093	delivery	5	17
126411	2020-08-26 09:03:10	2020-08-26	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	25670	delivery	5	46
126412	2020-08-26 09:04:11	2020-08-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31769	delivery	5	22
126413	2020-08-26 09:04:16	2020-08-26	8	[{"id_menu":5,"count":1}]	47889	pick-up	0	8
126414	2020-08-26 09:07:00	2020-08-26	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	47843	delivery	5	53
126415	2020-08-26 09:07:08	2020-08-26	9	[{"id_menu":7,"count":1}]	17669	delivery	5	14
126416	2020-08-26 09:08:45	2020-08-26	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	28056	pick-up	0	21
126417	2020-08-26 09:13:00	2020-08-26	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	20993	delivery	5	22
126418	2020-08-26 09:14:39	2020-08-26	9	[{"id_menu":6,"count":1}]	44266	delivery	5	14
126419	2020-08-26 09:14:45	2020-08-26	8	[{"id_menu":5,"count":1}]	39271	delivery	5	13
126420	2020-08-26 09:16:02	2020-08-26	8	[{"id_menu":5,"count":1}]	6251	delivery	5	13
126421	2020-08-26 09:17:26	2020-08-26	14	[{"id_menu":2,"count":1}]	1893	pick-up	0	14
126422	2020-08-26 09:21:05	2020-08-26	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	47908	delivery	5	34
126423	2020-08-26 09:23:37	2020-08-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3227	pick-up	0	26
126424	2020-08-26 09:26:13	2020-08-26	12	[{"id_menu":3,"count":1}]	47851	pick-up	0	12
126425	2020-08-26 09:26:28	2020-08-26	12	[{"id_menu":3,"count":1}]	28769	delivery	5	17
126426	2020-08-26 09:27:34	2020-08-26	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15027	delivery	5	35
126427	2020-08-26 09:28:33	2020-08-26	12	[{"id_menu":1,"count":1}]	24996	pick-up	0	12
126428	2020-08-26 09:29:43	2020-08-26	17	[{"id_menu":4,"count":1}]	47813	delivery	5	22
126429	2020-08-26 09:29:44	2020-08-26	14	[{"id_menu":2,"count":1}]	149	pick-up	0	14
126430	2020-08-26 09:29:53	2020-08-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	30548	delivery	5	31
126431	2020-08-26 09:34:51	2020-08-26	17	[{"id_menu":4,"count":2}]	33243	delivery	5	22
126432	2020-08-26 09:38:10	2020-08-26	9	[{"id_menu":7,"count":1}]	47950	delivery	5	14
126433	2020-08-26 09:41:08	2020-08-26	9	[{"id_menu":7,"count":1}]	18320	pick-up	0	9
126434	2020-08-26 09:43:44	2020-08-26	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11723	delivery	5	36
126435	2020-08-26 09:44:24	2020-08-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	41518	delivery	5	31
126436	2020-08-26 09:46:47	2020-08-26	9	[{"id_menu":7,"count":1}]	43649	delivery	5	14
126437	2020-08-26 09:50:25	2020-08-26	9	[{"id_menu":7,"count":1}]	9081	delivery	5	14
126438	2020-08-26 09:51:44	2020-08-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	44489	delivery	5	31
126439	2020-08-26 09:52:42	2020-08-26	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	47816	delivery	5	38
126440	2020-08-26 09:53:05	2020-08-26	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8135	delivery	5	43
126441	2020-08-26 09:53:14	2020-08-26	9	[{"id_menu":6,"count":1}]	47939	delivery	5	14
126442	2020-08-26 09:54:45	2020-08-26	12	[{"id_menu":1,"count":1}]	47894	delivery	5	17
126443	2020-08-26 09:55:34	2020-08-26	12	[{"id_menu":3,"count":1}]	41009	delivery	5	17
126444	2020-08-26 09:55:56	2020-08-26	9	[{"id_menu":6,"count":1}]	47348	delivery	5	14
126445	2020-08-26 09:58:05	2020-08-26	12	[{"id_menu":1,"count":1}]	47946	delivery	5	17
126446	2020-08-26 10:01:26	2020-08-26	9	[{"id_menu":7,"count":1}]	30675	pick-up	0	9
126447	2020-08-26 10:02:39	2020-08-26	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19583	delivery	5	37
126448	2020-08-26 10:03:37	2020-08-26	9	[{"id_menu":6,"count":1}]	10179	delivery	5	14
126449	2020-08-26 10:04:08	2020-08-26	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18271	delivery	5	34
126450	2020-08-26 10:05:24	2020-08-26	14	[{"id_menu":2,"count":1}]	6950	pick-up	0	14
126451	2020-08-26 10:07:17	2020-08-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9710	delivery	5	22
126452	2020-08-26 10:09:24	2020-08-26	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3843	delivery	5	27
126453	2020-08-26 10:10:01	2020-08-26	12	[{"id_menu":3,"count":1}]	8298	pick-up	0	12
126454	2020-08-26 10:14:38	2020-08-26	9	[{"id_menu":6,"count":1}]	24726	delivery	5	14
126455	2020-08-26 10:15:48	2020-08-26	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	33961	delivery	5	39
126456	2020-08-26 10:16:05	2020-08-26	12	[{"id_menu":1,"count":1}]	36547	pick-up	0	12
126457	2020-08-26 10:17:04	2020-08-26	9	[{"id_menu":6,"count":1}]	7308	delivery	5	14
126458	2020-08-26 10:18:34	2020-08-26	9	[{"id_menu":6,"count":1}]	47754	delivery	5	14
126459	2020-08-26 10:18:41	2020-08-26	17	[{"id_menu":4,"count":1}]	47798	pick-up	0	17
126460	2020-08-26 10:23:34	2020-08-26	12	[{"id_menu":1,"count":1}]	47765	delivery	5	17
126461	2020-08-26 10:24:52	2020-08-26	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	437	delivery	5	31
126462	2020-08-26 10:26:52	2020-08-26	9	[{"id_menu":6,"count":1}]	37201	delivery	5	14
126463	2020-08-26 10:27:34	2020-08-26	12	[{"id_menu":1,"count":1}]	24978	delivery	5	17
126464	2020-08-26 10:27:51	2020-08-26	14	[{"id_menu":2,"count":1}]	23990	delivery	5	19
126465	2020-08-26 10:27:58	2020-08-26	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	43119	delivery	5	38
126466	2020-08-26 10:30:00	2020-08-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	39424	delivery	5	22
126467	2020-08-26 10:32:26	2020-08-26	12	[{"id_menu":1,"count":1}]	2808	delivery	5	17
126468	2020-08-26 10:35:30	2020-08-26	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	47747	delivery	5	25
126469	2020-08-26 10:36:22	2020-08-26	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	47818	delivery	5	34
126470	2020-08-26 10:42:34	2020-08-26	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	12614	delivery	5	40
126471	2020-08-26 10:42:50	2020-08-26	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	43010	delivery	5	26
126472	2020-08-26 10:54:54	2020-08-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	25637	delivery	5	22
126473	2020-08-26 10:56:10	2020-08-26	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	20060	pick-up	0	20
126474	2020-08-26 10:56:55	2020-08-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	47919	delivery	5	28
126475	2020-08-26 10:59:17	2020-08-26	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	47746	delivery	5	57
126476	2020-08-26 11:02:28	2020-08-26	12	[{"id_menu":1,"count":1}]	9312	delivery	5	17
126477	2020-08-26 11:03:41	2020-08-26	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	27339	delivery	5	31
126478	2020-08-26 11:10:35	2020-08-26	8	[{"id_menu":5,"count":1}]	9657	delivery	5	13
126479	2020-08-26 11:11:15	2020-08-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	19239	delivery	5	26
126480	2020-08-26 11:11:17	2020-08-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	44789	delivery	5	28
126481	2020-08-26 11:11:34	2020-08-26	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	880	delivery	5	51
126482	2020-08-26 11:12:55	2020-08-26	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	28126	delivery	5	31
126483	2020-08-26 11:18:16	2020-08-26	8	[{"id_menu":5,"count":1}]	47760	delivery	5	13
126484	2020-08-26 11:21:47	2020-08-26	9	[{"id_menu":6,"count":1}]	47841	delivery	5	14
126485	2020-08-26 11:23:05	2020-08-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36125	delivery	5	23
126486	2020-08-26 11:24:48	2020-08-26	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24042	delivery	5	39
126487	2020-08-26 11:28:18	2020-08-26	9	[{"id_menu":6,"count":1}]	47935	delivery	5	14
126488	2020-08-26 11:33:27	2020-08-26	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	46054	delivery	5	51
126489	2020-08-26 11:34:35	2020-08-26	9	[{"id_menu":7,"count":1}]	36164	delivery	5	14
126490	2020-08-26 11:35:49	2020-08-26	9	[{"id_menu":6,"count":1}]	47854	pick-up	0	9
126491	2020-08-26 11:38:12	2020-08-26	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25685	delivery	5	51
126492	2020-08-26 11:49:30	2020-08-26	17	[{"id_menu":4,"count":1}]	47825	delivery	5	22
126493	2020-08-26 11:50:10	2020-08-26	14	[{"id_menu":2,"count":1}]	23153	delivery	5	19
126494	2020-08-26 11:53:46	2020-08-26	17	[{"id_menu":4,"count":1}]	47898	delivery	5	22
126495	2020-08-26 11:54:42	2020-08-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	23542	delivery	5	26
126496	2020-08-26 11:55:27	2020-08-26	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	8118	delivery	5	36
126497	2020-08-26 11:59:20	2020-08-26	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	47951	delivery	5	53
126498	2020-08-26 11:59:33	2020-08-26	9	[{"id_menu":7,"count":1}]	47827	delivery	5	14
126499	2020-08-26 11:59:59	2020-08-26	14	[{"id_menu":2,"count":1}]	35731	pick-up	0	14
126500	2020-08-26 12:01:03	2020-08-26	8	[{"id_menu":5,"count":1}]	22478	delivery	5	13
126501	2020-08-26 12:04:48	2020-08-26	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	47831	delivery	5	34
126502	2020-08-26 12:05:36	2020-08-26	12	[{"id_menu":1,"count":1}]	4825	pick-up	0	12
126503	2020-08-26 12:06:34	2020-08-26	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	47805	delivery	5	31
126504	2020-08-26 12:13:08	2020-08-26	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	47752	delivery	5	26
126505	2020-08-26 12:15:01	2020-08-26	29	[{"id_menu":3,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	47766	delivery	5	34
126506	2020-08-26 12:16:53	2020-08-26	9	[{"id_menu":6,"count":1}]	11309	delivery	5	14
126507	2020-08-26 12:17:20	2020-08-26	12	[{"id_menu":3,"count":1}]	47799	delivery	5	17
126508	2020-08-26 12:19:25	2020-08-26	8	[{"id_menu":5,"count":1}]	14178	delivery	5	13
126509	2020-08-26 12:21:30	2020-08-26	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	31736	delivery	5	40
126510	2020-08-26 12:23:42	2020-08-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":3}]	40496	delivery	5	23
126511	2020-08-26 12:27:11	2020-08-26	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36918	delivery	5	31
126512	2020-08-26 12:28:30	2020-08-26	14	[{"id_menu":2,"count":1}]	47866	delivery	5	19
126513	2020-08-26 12:29:06	2020-08-26	9	[{"id_menu":6,"count":1}]	42257	delivery	5	14
126514	2020-08-26 12:29:55	2020-08-26	12	[{"id_menu":3,"count":1}]	47778	delivery	5	17
126515	2020-08-26 12:33:17	2020-08-26	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	11592	delivery	5	44
126516	2020-08-26 12:38:16	2020-08-26	8	[{"id_menu":5,"count":1}]	40195	delivery	5	13
126517	2020-08-26 12:38:33	2020-08-26	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	47745	delivery	5	31
126518	2020-08-26 12:42:01	2020-08-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	27995	delivery	5	22
126519	2020-08-26 12:44:08	2020-08-26	8	[{"id_menu":5,"count":1}]	40478	delivery	5	13
126520	2020-08-26 12:44:49	2020-08-26	14	[{"id_menu":2,"count":1}]	2512	delivery	5	19
126521	2020-08-26 12:46:56	2020-08-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17008	delivery	5	22
126522	2020-08-26 12:50:34	2020-08-26	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36639	delivery	5	54
126523	2020-08-26 12:52:27	2020-08-26	12	[{"id_menu":3,"count":1}]	688	pick-up	0	12
126524	2020-08-26 12:53:13	2020-08-26	8	[{"id_menu":5,"count":1}]	884	pick-up	0	8
126525	2020-08-26 13:00:01	2020-08-26	12	[{"id_menu":1,"count":1}]	8115	pick-up	0	12
126526	2020-08-26 13:00:17	2020-08-26	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1429	delivery	5	38
126527	2020-08-26 13:00:18	2020-08-26	12	[{"id_menu":3,"count":1}]	2857	pick-up	0	12
126528	2020-08-26 13:01:33	2020-08-26	9	[{"id_menu":6,"count":1}]	46149	delivery	5	14
126529	2020-08-26 13:02:26	2020-08-26	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	8852	delivery	5	36
126530	2020-08-26 13:09:21	2020-08-26	17	[{"id_menu":4,"count":1}]	47893	delivery	5	22
126531	2020-08-26 13:11:48	2020-08-26	17	[{"id_menu":4,"count":1}]	1321	pick-up	0	17
126532	2020-08-26 13:12:20	2020-08-26	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	27435	delivery	5	26
126533	2020-08-26 13:18:18	2020-08-26	9	[{"id_menu":6,"count":1}]	47934	delivery	5	14
126534	2020-08-26 13:18:47	2020-08-26	14	[{"id_menu":2,"count":1}]	2158	pick-up	0	14
126535	2020-08-26 13:26:28	2020-08-26	12	[{"id_menu":3,"count":1}]	3153	pick-up	0	12
126536	2020-08-26 13:28:21	2020-08-26	17	[{"id_menu":4,"count":1}]	1507	pick-up	0	17
126537	2020-08-26 13:32:11	2020-08-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	47948	delivery	5	23
126538	2020-08-26 13:37:56	2020-08-26	8	[{"id_menu":5,"count":1}]	36524	delivery	5	13
126539	2020-08-26 13:45:19	2020-08-26	9	[{"id_menu":6,"count":2}]	12678	delivery	5	14
126540	2020-08-26 13:46:16	2020-08-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	20965	delivery	5	26
126541	2020-08-26 13:48:50	2020-08-26	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	39705	pick-up	0	18
126542	2020-08-26 13:49:04	2020-08-26	9	[{"id_menu":6,"count":1}]	29150	delivery	5	14
126543	2020-08-26 13:49:40	2020-08-26	8	[{"id_menu":5,"count":2}]	46328	delivery	5	13
126544	2020-08-26 13:51:58	2020-08-26	9	[{"id_menu":6,"count":1}]	32979	delivery	5	14
126545	2020-08-26 13:53:53	2020-08-26	17	[{"id_menu":4,"count":1}]	44697	delivery	5	22
126546	2020-08-26 13:54:33	2020-08-26	8	[{"id_menu":5,"count":1}]	7442	delivery	5	13
126547	2020-08-26 13:54:57	2020-08-26	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	47383	delivery	5	43
126548	2020-08-26 13:55:13	2020-08-26	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	38625	pick-up	0	26
126549	2020-08-26 13:56:16	2020-08-26	9	[{"id_menu":6,"count":1}]	24865	delivery	5	14
126550	2020-08-26 13:57:45	2020-08-26	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	35566	delivery	5	30
126551	2020-08-26 13:57:49	2020-08-26	8	[{"id_menu":5,"count":1}]	12113	pick-up	0	8
126552	2020-08-26 13:58:08	2020-08-26	17	[{"id_menu":4,"count":1}]	47740	delivery	5	22
126553	2020-08-26 14:00:54	2020-08-26	12	[{"id_menu":3,"count":1}]	43087	delivery	5	17
126554	2020-08-26 14:02:09	2020-08-26	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	47811	delivery	5	36
126555	2020-08-26 14:02:47	2020-08-26	8	[{"id_menu":5,"count":1}]	24175	delivery	5	13
126556	2020-08-26 14:06:10	2020-08-26	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	27488	pick-up	0	35
126557	2020-08-26 14:09:54	2020-08-26	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	22382	delivery	5	53
126558	2020-08-26 14:16:18	2020-08-26	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	43437	delivery	5	43
126559	2020-08-26 14:16:25	2020-08-26	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	42050	pick-up	0	22
126560	2020-08-26 14:21:24	2020-08-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	42025	delivery	5	26
126561	2020-08-26 14:22:26	2020-08-26	14	[{"id_menu":2,"count":1}]	3812	pick-up	0	14
126562	2020-08-26 14:22:52	2020-08-26	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	47800	delivery	5	31
126563	2020-08-26 14:26:49	2020-08-26	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19760	delivery	5	52
126564	2020-08-26 14:28:26	2020-08-26	12	[{"id_menu":1,"count":1}]	47835	delivery	5	17
126565	2020-08-26 14:29:01	2020-08-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	26083	delivery	5	31
126566	2020-08-26 14:36:51	2020-08-26	14	[{"id_menu":2,"count":1}]	15976	pick-up	0	14
126567	2020-08-26 14:37:49	2020-08-26	9	[{"id_menu":7,"count":1}]	10258	delivery	5	14
126568	2020-08-26 14:40:01	2020-08-26	9	[{"id_menu":6,"count":1}]	11946	delivery	5	14
126569	2020-08-26 14:42:16	2020-08-26	9	[{"id_menu":6,"count":1}]	15633	delivery	5	14
126570	2020-08-26 14:42:59	2020-08-26	12	[{"id_menu":1,"count":1}]	47868	delivery	5	17
126571	2020-08-26 14:44:26	2020-08-26	9	[{"id_menu":6,"count":1}]	47911	delivery	5	14
126572	2020-08-26 14:48:38	2020-08-26	8	[{"id_menu":5,"count":1}]	25941	delivery	5	13
126573	2020-08-26 14:50:38	2020-08-26	9	[{"id_menu":7,"count":1}]	14480	pick-up	0	9
126574	2020-08-26 14:54:25	2020-08-26	14	[{"id_menu":2,"count":1}]	2928	pick-up	0	14
126575	2020-08-26 14:55:41	2020-08-26	9	[{"id_menu":6,"count":1}]	16677	delivery	5	14
126576	2020-08-26 14:56:19	2020-08-26	9	[{"id_menu":6,"count":1}]	47820	delivery	5	14
126577	2020-08-26 14:58:01	2020-08-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	6193	delivery	5	26
126578	2020-08-26 14:59:15	2020-08-26	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	47201	delivery	5	31
126579	2020-08-26 15:00:36	2020-08-26	8	[{"id_menu":5,"count":4}]	32274	delivery	5	13
126580	2020-08-26 15:01:19	2020-08-26	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	39520	delivery	5	27
126581	2020-08-26 15:03:19	2020-08-26	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	5110	delivery	5	31
126582	2020-08-26 15:04:58	2020-08-26	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13686	delivery	5	35
126583	2020-08-26 15:09:07	2020-08-26	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	24902	delivery	5	28
126584	2020-08-26 15:09:40	2020-08-26	12	[{"id_menu":1,"count":1}]	2567	pick-up	0	12
126585	2020-08-26 15:09:47	2020-08-26	14	[{"id_menu":2,"count":1}]	1097	pick-up	0	14
126586	2020-08-26 15:10:50	2020-08-26	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25560	delivery	5	31
126587	2020-08-26 15:11:15	2020-08-26	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12058	delivery	5	43
126588	2020-08-26 15:16:09	2020-08-26	14	[{"id_menu":2,"count":1}]	19012	delivery	5	19
126589	2020-08-26 15:22:42	2020-08-26	9	[{"id_menu":6,"count":1}]	5236	delivery	5	14
126590	2020-08-26 15:24:23	2020-08-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	36077	delivery	5	26
126591	2020-08-26 15:26:05	2020-08-26	8	[{"id_menu":5,"count":1}]	28849	delivery	5	13
126592	2020-08-26 15:27:45	2020-08-26	8	[{"id_menu":5,"count":1}]	10798	pick-up	0	8
126593	2020-08-26 15:33:31	2020-08-26	9	[{"id_menu":7,"count":1}]	28283	pick-up	0	9
126594	2020-08-26 15:41:18	2020-08-26	14	[{"id_menu":2,"count":1}]	30423	delivery	5	19
126595	2020-08-26 15:45:58	2020-08-26	9	[{"id_menu":6,"count":1}]	47864	delivery	5	14
126596	2020-08-26 15:45:58	2020-08-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	1119	pick-up	0	21
126597	2020-08-26 15:49:35	2020-08-26	8	[{"id_menu":5,"count":1}]	31359	delivery	5	13
126598	2020-08-26 15:54:55	2020-08-26	17	[{"id_menu":4,"count":1}]	29383	delivery	5	22
126599	2020-08-26 15:54:58	2020-08-26	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	13846	delivery	5	31
126600	2020-08-26 15:55:13	2020-08-26	9	[{"id_menu":7,"count":1}]	10762	delivery	5	14
126601	2020-08-26 15:57:00	2020-08-26	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	18576	pick-up	0	26
126602	2020-08-26 15:57:06	2020-08-26	9	[{"id_menu":6,"count":1}]	45336	delivery	5	14
126603	2020-08-26 15:59:24	2020-08-26	12	[{"id_menu":1,"count":1}]	24673	delivery	5	17
126604	2020-08-26 15:59:33	2020-08-26	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	36295	delivery	5	38
126605	2020-08-26 16:00:46	2020-08-26	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	40619	delivery	5	31
126606	2020-08-26 16:00:59	2020-08-26	14	[{"id_menu":2,"count":1}]	14073	delivery	5	19
126607	2020-08-26 16:03:04	2020-08-26	9	[{"id_menu":6,"count":1}]	21047	delivery	5	14
126608	2020-08-26 16:05:43	2020-08-26	12	[{"id_menu":3,"count":1}]	46333	delivery	5	17
126609	2020-08-26 16:08:20	2020-08-26	9	[{"id_menu":6,"count":1}]	11554	delivery	5	14
126610	2020-08-26 16:11:19	2020-08-26	9	[{"id_menu":6,"count":1}]	22726	delivery	5	14
126611	2020-08-26 16:12:46	2020-08-26	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	47744	delivery	5	34
126612	2020-08-26 16:16:24	2020-08-26	9	[{"id_menu":7,"count":1}]	26708	delivery	5	14
126613	2020-08-26 16:16:54	2020-08-26	9	[{"id_menu":7,"count":1}]	37812	delivery	5	14
126614	2020-08-26 16:17:24	2020-08-26	9	[{"id_menu":7,"count":1}]	47859	delivery	5	14
126615	2020-08-26 16:18:58	2020-08-26	9	[{"id_menu":6,"count":1}]	47791	delivery	5	14
126616	2020-08-26 16:21:03	2020-08-26	12	[{"id_menu":1,"count":1}]	47891	delivery	5	17
126617	2020-08-26 16:21:41	2020-08-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	47768	delivery	5	22
126618	2020-08-26 16:24:04	2020-08-26	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2169	pick-up	0	29
126619	2020-08-26 16:26:58	2020-08-26	12	[{"id_menu":1,"count":1}]	44052	delivery	5	17
126620	2020-08-26 16:27:13	2020-08-26	12	[{"id_menu":1,"count":1}]	37153	delivery	5	17
126621	2020-08-26 16:31:16	2020-08-26	9	[{"id_menu":6,"count":1}]	33452	pick-up	0	9
126622	2020-08-26 16:37:05	2020-08-26	17	[{"id_menu":4,"count":1}]	46493	pick-up	0	17
126623	2020-08-26 16:37:47	2020-08-26	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	47794	delivery	5	34
126624	2020-08-26 16:39:13	2020-08-26	8	[{"id_menu":5,"count":1}]	47853	delivery	5	13
126625	2020-08-26 16:41:46	2020-08-26	8	[{"id_menu":5,"count":1}]	1428	pick-up	0	8
126626	2020-08-26 16:46:31	2020-08-26	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	24635	delivery	5	36
126627	2020-08-26 16:47:49	2020-08-26	14	[{"id_menu":2,"count":1}]	2670	delivery	5	19
126628	2020-08-26 16:50:29	2020-08-26	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	47839	delivery	5	36
126629	2020-08-26 16:50:56	2020-08-26	12	[{"id_menu":1,"count":1}]	1677	pick-up	0	12
126630	2020-08-26 16:51:55	2020-08-26	9	[{"id_menu":7,"count":1}]	11846	delivery	5	14
126631	2020-08-26 16:53:56	2020-08-26	12	[{"id_menu":1,"count":1}]	47886	pick-up	0	12
126632	2020-08-26 16:54:19	2020-08-26	14	[{"id_menu":2,"count":1}]	44729	pick-up	0	14
126633	2020-08-26 16:54:41	2020-08-26	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	30238	delivery	5	36
126634	2020-08-26 16:56:05	2020-08-26	12	[{"id_menu":1,"count":1}]	47775	delivery	5	17
126635	2020-08-26 16:57:07	2020-08-26	9	[{"id_menu":7,"count":2}]	44316	delivery	5	14
126636	2020-08-26 16:58:40	2020-08-26	12	[{"id_menu":1,"count":1}]	9743	delivery	5	17
126637	2020-08-26 16:59:20	2020-08-26	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	12155	delivery	5	31
126638	2020-08-26 17:00:25	2020-08-26	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	39406	delivery	5	31
126639	2020-08-26 17:01:33	2020-08-26	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	21443	delivery	5	43
126640	2020-08-26 17:08:43	2020-08-26	8	[{"id_menu":5,"count":1}]	46560	delivery	5	13
126641	2020-08-26 17:13:14	2020-08-26	17	[{"id_menu":4,"count":1}]	24834	delivery	5	22
126642	2020-08-26 17:15:32	2020-08-26	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	47925	delivery	5	43
126643	2020-08-26 17:17:34	2020-08-26	12	[{"id_menu":1,"count":1}]	29709	pick-up	0	12
126644	2020-08-26 17:20:33	2020-08-26	12	[{"id_menu":3,"count":1}]	16841	pick-up	0	12
126645	2020-08-26 17:22:49	2020-08-26	9	[{"id_menu":7,"count":1}]	9923	delivery	5	14
126646	2020-08-26 17:25:27	2020-08-26	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	24309	delivery	5	43
126647	2020-08-26 17:27:35	2020-08-26	9	[{"id_menu":6,"count":1}]	23312	pick-up	0	9
126648	2020-08-26 17:29:27	2020-08-26	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	9554	delivery	5	37
126649	2020-08-26 17:29:43	2020-08-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	2770	delivery	5	28
126650	2020-08-26 17:29:44	2020-08-26	8	[{"id_menu":5,"count":1}]	26841	delivery	5	13
126651	2020-08-26 17:33:53	2020-08-26	12	[{"id_menu":1,"count":1}]	32756	delivery	5	17
126652	2020-08-26 17:44:44	2020-08-26	12	[{"id_menu":3,"count":1}]	5461	pick-up	0	12
126653	2020-08-26 17:45:28	2020-08-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	5914	delivery	5	28
126654	2020-08-26 17:46:13	2020-08-26	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	20929	delivery	5	40
126655	2020-08-26 17:46:34	2020-08-26	9	[{"id_menu":6,"count":1}]	29020	delivery	5	14
126656	2020-08-26 17:47:57	2020-08-26	9	[{"id_menu":7,"count":1}]	47810	delivery	5	14
126657	2020-08-26 17:48:53	2020-08-26	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3932	delivery	5	57
126658	2020-08-26 17:49:08	2020-08-26	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	37018	delivery	5	34
126659	2020-08-26 17:49:14	2020-08-26	9	[{"id_menu":6,"count":1}]	32752	delivery	5	14
126660	2020-08-26 17:49:27	2020-08-26	14	[{"id_menu":2,"count":1}]	14209	delivery	5	19
126661	2020-08-26 17:51:02	2020-08-26	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	47959	delivery	5	36
126662	2020-08-26 17:51:58	2020-08-26	14	[{"id_menu":2,"count":1}]	4132	pick-up	0	14
126663	2020-08-26 17:52:35	2020-08-26	17	[{"id_menu":4,"count":1}]	17515	pick-up	0	17
126664	2020-08-26 17:55:38	2020-08-26	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	47878	delivery	5	45
126665	2020-08-26 18:01:38	2020-08-26	9	[{"id_menu":6,"count":1}]	18000	delivery	5	14
126666	2020-08-26 18:03:31	2020-08-26	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	44383	delivery	5	27
126667	2020-08-26 18:06:23	2020-08-26	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	47833	pick-up	0	26
126668	2020-08-26 18:10:15	2020-08-26	9	[{"id_menu":7,"count":1}]	47885	delivery	5	14
126669	2020-08-26 18:10:29	2020-08-26	12	[{"id_menu":1,"count":2}]	18057	delivery	5	17
126670	2020-08-26 18:12:09	2020-08-26	9	[{"id_menu":7,"count":1}]	46464	delivery	5	14
126671	2020-08-26 18:13:05	2020-08-26	12	[{"id_menu":1,"count":1}]	23133	pick-up	0	12
126672	2020-08-26 18:13:59	2020-08-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	47852	delivery	5	22
126673	2020-08-26 18:14:45	2020-08-26	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35852	delivery	5	49
126674	2020-08-26 18:17:52	2020-08-26	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13714	delivery	5	37
126675	2020-08-26 18:20:22	2020-08-26	9	[{"id_menu":6,"count":2}]	32687	delivery	5	14
126676	2020-08-26 18:22:19	2020-08-26	8	[{"id_menu":5,"count":1}]	47914	delivery	5	13
126677	2020-08-26 18:24:59	2020-08-26	8	[{"id_menu":5,"count":1}]	47776	delivery	5	13
126678	2020-08-26 18:28:19	2020-08-26	9	[{"id_menu":6,"count":1}]	23074	delivery	5	14
126679	2020-08-26 18:28:22	2020-08-26	12	[{"id_menu":3,"count":1}]	29494	delivery	5	17
126680	2020-08-26 18:28:37	2020-08-26	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	47759	delivery	5	34
126681	2020-08-26 18:29:12	2020-08-26	12	[{"id_menu":3,"count":1}]	33606	pick-up	0	12
126682	2020-08-26 18:31:58	2020-08-26	12	[{"id_menu":3,"count":1}]	47815	pick-up	0	12
126683	2020-08-26 18:32:31	2020-08-26	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	15807	delivery	5	30
126684	2020-08-26 18:33:19	2020-08-26	9	[{"id_menu":7,"count":1}]	33285	delivery	5	14
126685	2020-08-26 18:34:25	2020-08-26	8	[{"id_menu":5,"count":1}]	47912	delivery	5	13
126686	2020-08-26 18:37:15	2020-08-26	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	5878	delivery	5	39
126687	2020-08-26 18:39:59	2020-08-26	8	[{"id_menu":5,"count":2}]	35455	delivery	5	13
126688	2020-08-26 18:41:09	2020-08-26	17	[{"id_menu":4,"count":1}]	47887	delivery	5	22
126689	2020-08-26 18:43:50	2020-08-26	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":3}]	47932	delivery	5	31
126690	2020-08-26 18:46:10	2020-08-26	17	[{"id_menu":4,"count":1}]	32939	pick-up	0	17
126691	2020-08-26 18:46:27	2020-08-26	9	[{"id_menu":6,"count":1}]	42401	delivery	5	14
126692	2020-08-26 18:47:21	2020-08-26	17	[{"id_menu":4,"count":1}]	47956	delivery	5	22
126693	2020-08-26 18:48:36	2020-08-26	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	45275	delivery	5	29
126694	2020-08-26 18:49:34	2020-08-26	8	[{"id_menu":5,"count":1}]	47916	delivery	5	13
126695	2020-08-26 18:54:23	2020-08-26	17	[{"id_menu":4,"count":1}]	47877	delivery	5	22
126696	2020-08-26 18:57:44	2020-08-26	17	[{"id_menu":4,"count":1}]	47957	pick-up	0	17
126697	2020-08-26 18:59:54	2020-08-26	8	[{"id_menu":5,"count":1}]	37975	delivery	5	13
126698	2020-08-26 19:02:59	2020-08-26	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	21139	delivery	5	31
126699	2020-08-26 19:04:43	2020-08-26	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	47822	pick-up	0	29
126700	2020-08-26 19:05:14	2020-08-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	32677	delivery	5	22
126701	2020-08-26 19:05:24	2020-08-26	9	[{"id_menu":6,"count":1}]	17759	delivery	5	14
126702	2020-08-26 19:09:56	2020-08-26	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	14737	delivery	5	38
126703	2020-08-26 19:10:35	2020-08-26	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34147	delivery	5	49
126704	2020-08-26 19:11:33	2020-08-26	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	47928	delivery	5	45
126705	2020-08-26 19:14:25	2020-08-26	8	[{"id_menu":5,"count":1}]	40500	delivery	5	13
126706	2020-08-26 19:17:37	2020-08-26	17	[{"id_menu":4,"count":1}]	47881	delivery	5	22
126707	2020-08-26 19:19:15	2020-08-26	17	[{"id_menu":4,"count":1}]	6600	pick-up	0	17
126708	2020-08-26 19:19:53	2020-08-26	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	45109	delivery	5	39
126709	2020-08-26 19:20:52	2020-08-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3917	delivery	5	28
126710	2020-08-26 19:24:16	2020-08-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3444	delivery	5	28
126711	2020-08-26 19:27:07	2020-08-26	14	[{"id_menu":2,"count":1}]	32426	pick-up	0	14
126712	2020-08-26 19:27:42	2020-08-26	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	34663	delivery	5	30
126713	2020-08-26 19:29:05	2020-08-26	14	[{"id_menu":2,"count":1}]	19798	pick-up	0	14
126714	2020-08-26 19:30:06	2020-08-26	14	[{"id_menu":2,"count":1}]	47960	delivery	5	19
126715	2020-08-26 19:32:57	2020-08-26	9	[{"id_menu":7,"count":1}]	26895	delivery	5	14
126716	2020-08-26 19:32:58	2020-08-26	14	[{"id_menu":2,"count":1}]	8632	delivery	5	19
126717	2020-08-26 19:40:14	2020-08-26	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	41939	pick-up	0	25
126718	2020-08-26 19:40:31	2020-08-26	12	[{"id_menu":3,"count":1}]	2739	delivery	5	17
126719	2020-08-26 19:40:45	2020-08-26	9	[{"id_menu":6,"count":1}]	47777	delivery	5	14
126720	2020-08-26 19:41:41	2020-08-26	14	[{"id_menu":2,"count":1}]	1529	pick-up	0	14
126721	2020-08-26 19:42:17	2020-08-26	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	27835	pick-up	0	26
126722	2020-08-26 19:46:32	2020-08-26	12	[{"id_menu":3,"count":1}]	47803	delivery	5	17
126723	2020-08-26 19:46:45	2020-08-26	9	[{"id_menu":7,"count":1}]	38866	delivery	5	14
126724	2020-08-26 19:50:06	2020-08-26	14	[{"id_menu":2,"count":1}]	30660	pick-up	0	14
126725	2020-08-26 19:51:17	2020-08-26	14	[{"id_menu":2,"count":1}]	47875	delivery	5	19
126726	2020-08-26 19:52:45	2020-08-26	8	[{"id_menu":5,"count":1}]	9859	pick-up	0	8
126727	2020-08-26 19:53:00	2020-08-26	17	[{"id_menu":4,"count":1}]	5550	delivery	5	22
126728	2020-08-26 19:53:24	2020-08-26	14	[{"id_menu":2,"count":1}]	47930	delivery	5	19
126729	2020-08-26 19:53:56	2020-08-26	12	[{"id_menu":1,"count":1}]	24284	pick-up	0	12
126730	2020-08-26 19:54:34	2020-08-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	39848	delivery	5	22
126731	2020-08-26 19:55:52	2020-08-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	47921	delivery	5	23
126732	2020-08-26 19:56:13	2020-08-26	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	47782	delivery	5	27
126733	2020-08-26 19:57:03	2020-08-26	17	[{"id_menu":4,"count":1}]	47942	delivery	5	22
126734	2020-08-26 19:57:03	2020-08-26	8	[{"id_menu":5,"count":1}]	5050	pick-up	0	8
126735	2020-08-26 19:58:33	2020-08-26	9	[{"id_menu":6,"count":1}]	33715	delivery	5	14
126736	2020-08-26 19:59:01	2020-08-26	17	[{"id_menu":4,"count":1}]	1521	pick-up	0	17
126737	2020-08-26 20:00:35	2020-08-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	25710	delivery	5	28
126738	2020-08-26 20:03:15	2020-08-26	14	[{"id_menu":2,"count":1}]	11539	delivery	5	19
126739	2020-08-26 20:06:05	2020-08-26	17	[{"id_menu":4,"count":1}]	41548	delivery	5	22
126740	2020-08-26 20:07:01	2020-08-26	14	[{"id_menu":2,"count":1}]	6080	delivery	5	19
126741	2020-08-26 20:08:30	2020-08-26	14	[{"id_menu":2,"count":1}]	47940	delivery	5	19
126742	2020-08-26 20:08:56	2020-08-26	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18891	delivery	5	48
126743	2020-08-26 20:09:28	2020-08-26	9	[{"id_menu":7,"count":1}]	47377	delivery	5	14
126744	2020-08-26 20:10:04	2020-08-26	9	[{"id_menu":7,"count":3}]	4824	delivery	5	14
126745	2020-08-26 20:10:16	2020-08-26	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	47855	delivery	5	34
126746	2020-08-26 20:11:08	2020-08-26	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	47801	delivery	5	31
126747	2020-08-26 20:22:38	2020-08-26	9	[{"id_menu":6,"count":1}]	33959	delivery	5	14
126748	2020-08-26 20:23:06	2020-08-26	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	47879	delivery	5	42
126749	2020-08-26 20:23:56	2020-08-26	8	[{"id_menu":5,"count":1}]	26333	delivery	5	13
126750	2020-08-26 20:25:18	2020-08-26	9	[{"id_menu":7,"count":1}]	21856	delivery	5	14
126751	2020-08-26 20:25:47	2020-08-26	17	[{"id_menu":4,"count":1}]	45224	delivery	5	22
126752	2020-08-26 20:29:40	2020-08-26	9	[{"id_menu":6,"count":1}]	16157	delivery	5	14
126753	2020-08-26 20:30:27	2020-08-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	14525	delivery	5	26
126754	2020-08-26 20:34:06	2020-08-26	12	[{"id_menu":1,"count":1}]	20892	delivery	5	17
126755	2020-08-26 20:36:43	2020-08-26	8	[{"id_menu":5,"count":1}]	42568	delivery	5	13
126756	2020-08-26 20:45:05	2020-08-26	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	43367	delivery	5	39
126757	2020-08-26 20:48:38	2020-08-26	9	[{"id_menu":7,"count":1}]	35161	delivery	5	14
126758	2020-08-26 20:50:38	2020-08-26	14	[{"id_menu":2,"count":1}]	34300	delivery	5	19
126759	2020-08-26 20:50:55	2020-08-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	47795	delivery	5	22
126760	2020-08-26 20:52:09	2020-08-26	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	47880	delivery	5	34
126761	2020-08-26 20:52:13	2020-08-26	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	47773	delivery	5	56
126762	2020-08-26 20:53:18	2020-08-26	9	[{"id_menu":7,"count":1}]	34376	delivery	5	14
126763	2020-08-26 20:57:25	2020-08-26	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	11169	delivery	5	26
126764	2020-08-26 20:59:11	2020-08-26	9	[{"id_menu":6,"count":1}]	47763	delivery	5	14
126765	2020-08-26 21:00:04	2020-08-26	14	[{"id_menu":2,"count":1}]	47828	delivery	5	19
126766	2020-08-26 21:01:05	2020-08-26	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	28512	delivery	5	26
126767	2020-08-26 21:01:13	2020-08-26	12	[{"id_menu":1,"count":1}]	47808	pick-up	0	12
126768	2020-08-26 21:02:18	2020-08-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	44430	delivery	5	22
126769	2020-08-26 21:02:33	2020-08-26	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	37781	delivery	5	34
126770	2020-08-26 21:03:43	2020-08-26	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20103	delivery	5	54
126771	2020-08-26 21:05:52	2020-08-26	14	[{"id_menu":2,"count":1}]	18228	pick-up	0	14
126772	2020-08-26 21:05:54	2020-08-26	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	47955	delivery	5	34
126773	2020-08-26 21:06:48	2020-08-26	14	[{"id_menu":2,"count":1}]	21349	delivery	5	19
126774	2020-08-26 21:08:51	2020-08-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	3647	pick-up	0	23
126775	2020-08-26 21:09:45	2020-08-26	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	27825	delivery	5	30
126776	2020-08-26 21:11:12	2020-08-26	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	47764	delivery	5	35
126777	2020-08-26 21:13:06	2020-08-26	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25881	delivery	5	54
126778	2020-08-26 21:15:21	2020-08-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15343	delivery	5	23
126779	2020-08-26 21:16:51	2020-08-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	47806	delivery	5	23
126780	2020-08-26 21:17:44	2020-08-26	12	[{"id_menu":3,"count":1}]	18383	delivery	5	17
126781	2020-08-26 21:18:56	2020-08-26	9	[{"id_menu":6,"count":1}]	30924	delivery	5	14
126782	2020-08-26 21:20:11	2020-08-26	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	25781	delivery	5	44
126783	2020-08-26 21:20:55	2020-08-26	14	[{"id_menu":2,"count":1}]	1338	delivery	5	19
126784	2020-08-26 21:22:06	2020-08-26	8	[{"id_menu":5,"count":1}]	35921	pick-up	0	8
126785	2020-08-26 21:23:35	2020-08-26	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	47769	pick-up	0	21
126786	2020-08-26 21:25:22	2020-08-26	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	29632	delivery	5	45
126787	2020-08-26 21:28:37	2020-08-26	9	[{"id_menu":7,"count":1}]	15071	delivery	5	14
126788	2020-08-26 21:31:55	2020-08-26	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22595	delivery	5	31
126789	2020-08-26 21:32:20	2020-08-26	17	[{"id_menu":4,"count":1}]	15605	delivery	5	22
126790	2020-08-26 21:35:17	2020-08-26	9	[{"id_menu":7,"count":1}]	7387	delivery	5	14
126791	2020-08-26 21:35:44	2020-08-26	9	[{"id_menu":7,"count":1}]	7189	pick-up	0	9
126792	2020-08-26 21:37:47	2020-08-26	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	11541	delivery	5	40
126793	2020-08-26 21:38:49	2020-08-26	12	[{"id_menu":3,"count":1}]	47867	delivery	5	17
126794	2020-08-26 21:41:29	2020-08-26	12	[{"id_menu":3,"count":1}]	46213	delivery	5	17
126795	2020-08-26 21:43:00	2020-08-26	12	[{"id_menu":3,"count":1}]	23622	pick-up	0	12
126796	2020-08-26 21:43:16	2020-08-26	9	[{"id_menu":6,"count":1}]	16650	delivery	5	14
126797	2020-08-26 21:43:25	2020-08-26	12	[{"id_menu":3,"count":1}]	11189	pick-up	0	12
126798	2020-08-26 21:43:52	2020-08-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	38787	delivery	5	28
126799	2020-08-26 21:46:00	2020-08-26	9	[{"id_menu":6,"count":2}]	47949	delivery	5	14
126800	2020-08-26 21:46:11	2020-08-26	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	13320	pick-up	0	21
126801	2020-08-26 21:46:30	2020-08-26	9	[{"id_menu":7,"count":1}]	45507	delivery	5	14
126802	2020-08-26 21:47:24	2020-08-26	9	[{"id_menu":6,"count":1}]	41990	pick-up	0	9
126803	2020-08-26 21:48:08	2020-08-26	8	[{"id_menu":5,"count":1}]	4123	delivery	5	13
126804	2020-08-26 21:48:14	2020-08-26	9	[{"id_menu":6,"count":1}]	47876	delivery	5	14
126805	2020-08-26 21:48:59	2020-08-26	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	47749	delivery	5	39
126806	2020-08-26 21:56:32	2020-08-26	9	[{"id_menu":7,"count":1}]	47824	delivery	5	14
126807	2020-08-26 21:56:48	2020-08-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	26577	delivery	5	22
126808	2020-08-26 21:57:00	2020-08-26	9	[{"id_menu":7,"count":1}]	1581	delivery	5	14
126809	2020-08-26 22:01:20	2020-08-26	8	[{"id_menu":5,"count":1}]	18814	delivery	5	13
126810	2020-08-26 22:05:15	2020-08-26	9	[{"id_menu":6,"count":1}]	47751	delivery	5	14
126811	2020-08-26 22:07:34	2020-08-26	9	[{"id_menu":7,"count":1}]	47789	delivery	5	14
126812	2020-08-26 22:07:48	2020-08-26	8	[{"id_menu":5,"count":1}]	23452	delivery	5	13
126813	2020-08-26 22:08:39	2020-08-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	47856	delivery	5	28
126814	2020-08-26 22:10:15	2020-08-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	15275	delivery	5	28
126815	2020-08-26 22:12:24	2020-08-26	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	28362	delivery	5	36
126816	2020-08-26 22:14:39	2020-08-26	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	47952	delivery	5	26
126817	2020-08-26 22:16:57	2020-08-26	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	7360	delivery	5	28
126818	2020-08-26 22:18:47	2020-08-26	12	[{"id_menu":3,"count":1}]	38404	delivery	5	17
126819	2020-08-26 22:23:46	2020-08-26	9	[{"id_menu":7,"count":1}]	44896	delivery	5	14
126820	2020-08-26 22:28:19	2020-08-26	14	[{"id_menu":2,"count":1}]	33358	delivery	5	19
126821	2020-08-26 22:32:47	2020-08-26	8	[{"id_menu":5,"count":1}]	16795	delivery	5	13
126822	2020-08-26 22:37:50	2020-08-26	14	[{"id_menu":2,"count":1}]	30234	pick-up	0	14
126823	2020-08-26 22:41:28	2020-08-26	9	[{"id_menu":7,"count":1}]	2607	pick-up	0	9
126824	2020-08-26 22:43:48	2020-08-26	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":3}]	9567	delivery	5	28
126825	2020-08-26 22:44:12	2020-08-26	8	[{"id_menu":5,"count":1}]	18533	pick-up	0	8
126826	2020-08-26 22:45:11	2020-08-26	9	[{"id_menu":7,"count":1}]	3033	pick-up	0	9
126827	2020-08-26 22:45:59	2020-08-26	9	[{"id_menu":7,"count":1}]	47944	delivery	5	14
126828	2020-08-26 22:49:12	2020-08-26	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	47901	delivery	5	53
126829	2020-08-26 22:49:17	2020-08-26	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	2228	pick-up	0	22
126830	2020-08-26 22:49:47	2020-08-26	9	[{"id_menu":7,"count":1}]	47861	delivery	5	14
126831	2020-08-26 22:53:38	2020-08-26	12	[{"id_menu":3,"count":1}]	7140	pick-up	0	12
126832	2020-08-26 22:54:12	2020-08-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	766	pick-up	0	23
126833	2020-08-26 22:56:27	2020-08-26	12	[{"id_menu":1,"count":2}]	14025	pick-up	0	12
126834	2020-08-26 22:58:24	2020-08-26	8	[{"id_menu":5,"count":1}]	32344	delivery	5	13
126835	2020-08-26 22:59:29	2020-08-26	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	26610	delivery	5	25
126836	2020-08-26 23:01:07	2020-08-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	47869	delivery	5	22
126837	2020-08-26 23:02:52	2020-08-26	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	30458	delivery	5	25
126838	2020-08-26 23:03:48	2020-08-26	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	46132	delivery	5	35
126839	2020-08-26 23:05:42	2020-08-26	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	38278	delivery	5	22
126840	2020-08-26 23:12:14	2020-08-26	12	[{"id_menu":1,"count":1}]	4484	pick-up	0	12
126841	2020-08-26 23:12:52	2020-08-26	14	[{"id_menu":2,"count":1}]	13136	delivery	5	19
126842	2020-08-26 23:12:58	2020-08-26	9	[{"id_menu":6,"count":1}]	1807	delivery	5	14
126843	2020-08-26 23:13:53	2020-08-26	14	[{"id_menu":2,"count":1}]	47785	delivery	5	19
126844	2020-08-26 23:14:04	2020-08-26	9	[{"id_menu":6,"count":1}]	35845	delivery	5	14
126845	2020-08-26 23:16:32	2020-08-26	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	29413	delivery	5	48
126846	2020-08-26 23:25:13	2020-08-26	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	39056	pick-up	0	22
126847	2020-08-26 23:26:58	2020-08-26	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8558	delivery	5	46
126848	2020-08-26 23:27:55	2020-08-26	12	[{"id_menu":3,"count":1}]	37924	delivery	5	17
126849	2020-08-26 23:30:47	2020-08-26	9	[{"id_menu":6,"count":1}]	47883	pick-up	0	9
126850	2020-08-26 23:31:32	2020-08-26	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	40299	delivery	5	44
126851	2020-08-26 23:32:42	2020-08-26	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	32269	delivery	5	28
126852	2020-08-26 23:34:38	2020-08-26	8	[{"id_menu":5,"count":1}]	45083	pick-up	0	8
126853	2020-08-26 23:35:35	2020-08-26	17	[{"id_menu":4,"count":1}]	4841	pick-up	0	17
126854	2020-08-26 23:37:20	2020-08-26	9	[{"id_menu":7,"count":1}]	34918	delivery	5	14
126855	2020-08-26 23:39:25	2020-08-26	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	25021	pick-up	0	29
126856	2020-08-26 23:39:53	2020-08-26	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	1582	pick-up	0	17
126857	2020-08-26 23:42:51	2020-08-26	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":3}]	26173	delivery	5	26
126858	2020-08-26 23:46:40	2020-08-26	9	[{"id_menu":6,"count":1}]	47753	delivery	5	14
126859	2020-08-26 23:49:45	2020-08-26	17	[{"id_menu":4,"count":1}]	20006	delivery	5	22
126860	2020-08-26 23:50:03	2020-08-26	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":3}]	46406	delivery	5	23
126861	2020-08-26 23:53:29	2020-08-26	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	27885	delivery	5	48
126862	2020-08-27 00:05:20	2020-08-27	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	34125	delivery	5	40
126863	2020-08-27 00:07:12	2020-08-27	12	[{"id_menu":1,"count":1}]	24703	delivery	5	17
126864	2020-08-27 00:08:14	2020-08-27	9	[{"id_menu":7,"count":1}]	5869	pick-up	0	9
126865	2020-08-27 00:14:30	2020-08-27	14	[{"id_menu":2,"count":1}]	48071	delivery	5	19
126866	2020-08-27 00:16:59	2020-08-27	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	37102	delivery	5	26
126867	2020-08-27 00:17:42	2020-08-27	8	[{"id_menu":5,"count":1}]	28783	pick-up	0	8
126868	2020-08-27 00:18:36	2020-08-27	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	48064	pick-up	0	26
126869	2020-08-27 00:21:52	2020-08-27	9	[{"id_menu":6,"count":1}]	46033	delivery	5	14
126870	2020-08-27 00:25:48	2020-08-27	14	[{"id_menu":2,"count":1}]	48130	delivery	5	19
126871	2020-08-27 00:28:11	2020-08-27	14	[{"id_menu":2,"count":1}]	41296	pick-up	0	14
126872	2020-08-27 00:28:26	2020-08-27	14	[{"id_menu":2,"count":1}]	11615	pick-up	0	14
126873	2020-08-27 00:28:38	2020-08-27	12	[{"id_menu":1,"count":1}]	32468	pick-up	0	12
126874	2020-08-27 00:28:49	2020-08-27	8	[{"id_menu":5,"count":1}]	48000	delivery	5	13
126875	2020-08-27 00:30:40	2020-08-27	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	48168	delivery	5	40
126876	2020-08-27 00:33:33	2020-08-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	48137	delivery	5	22
126877	2020-08-27 00:34:48	2020-08-27	14	[{"id_menu":2,"count":1}]	48083	delivery	5	19
126878	2020-08-27 00:44:10	2020-08-27	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	308	pick-up	0	26
126879	2020-08-27 00:45:44	2020-08-27	14	[{"id_menu":2,"count":1}]	48029	delivery	5	19
126880	2020-08-27 00:47:53	2020-08-27	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9833	delivery	5	51
126881	2020-08-27 00:52:47	2020-08-27	9	[{"id_menu":6,"count":1}]	8641	delivery	5	14
126882	2020-08-27 01:00:00	2020-08-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2846	delivery	5	28
126883	2020-08-27 01:00:05	2020-08-27	9	[{"id_menu":7,"count":2}]	35258	pick-up	0	9
126884	2020-08-27 01:10:52	2020-08-27	9	[{"id_menu":6,"count":1}]	28458	delivery	5	14
126885	2020-08-27 01:10:54	2020-08-27	12	[{"id_menu":3,"count":1}]	30049	delivery	5	17
126886	2020-08-27 01:11:01	2020-08-27	17	[{"id_menu":4,"count":1}]	26637	pick-up	0	17
126887	2020-08-27 01:12:47	2020-08-27	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	37673	delivery	5	25
126888	2020-08-27 01:13:52	2020-08-27	12	[{"id_menu":3,"count":1}]	47980	pick-up	0	12
126889	2020-08-27 01:14:16	2020-08-27	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	11172	delivery	5	26
126890	2020-08-27 01:14:51	2020-08-27	29	[{"id_menu":3,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	48087	delivery	5	34
126891	2020-08-27 01:15:45	2020-08-27	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	47989	delivery	5	31
126892	2020-08-27 01:16:31	2020-08-27	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	4428	pick-up	0	21
126893	2020-08-27 01:16:36	2020-08-27	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	31957	pick-up	0	25
126894	2020-08-27 01:20:25	2020-08-27	12	[{"id_menu":3,"count":1}]	48133	pick-up	0	12
126895	2020-08-27 01:20:38	2020-08-27	9	[{"id_menu":7,"count":1}]	48027	delivery	5	14
126896	2020-08-27 01:21:09	2020-08-27	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	47976	delivery	5	34
126897	2020-08-27 01:21:09	2020-08-27	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	32200	delivery	5	39
126898	2020-08-27 01:23:06	2020-08-27	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	48042	delivery	5	40
126899	2020-08-27 01:24:59	2020-08-27	14	[{"id_menu":2,"count":1}]	20391	pick-up	0	14
126900	2020-08-27 01:27:01	2020-08-27	12	[{"id_menu":1,"count":1}]	26839	pick-up	0	12
126901	2020-08-27 01:28:27	2020-08-27	9	[{"id_menu":7,"count":1}]	15018	delivery	5	14
126902	2020-08-27 01:33:11	2020-08-27	12	[{"id_menu":3,"count":1}]	19637	pick-up	0	12
126903	2020-08-27 01:36:26	2020-08-27	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44248	delivery	5	37
126904	2020-08-27 01:36:53	2020-08-27	14	[{"id_menu":2,"count":1}]	48028	delivery	5	19
126905	2020-08-27 01:37:00	2020-08-27	17	[{"id_menu":4,"count":1}]	1387	pick-up	0	17
126906	2020-08-27 01:37:50	2020-08-27	9	[{"id_menu":7,"count":1}]	27545	delivery	5	14
126907	2020-08-27 01:38:03	2020-08-27	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	48122	delivery	5	38
126908	2020-08-27 01:39:42	2020-08-27	9	[{"id_menu":6,"count":1}]	48148	delivery	5	14
126909	2020-08-27 01:43:18	2020-08-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	47974	delivery	5	23
126910	2020-08-27 01:44:04	2020-08-27	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5032	delivery	5	34
126911	2020-08-27 01:48:33	2020-08-27	8	[{"id_menu":5,"count":1}]	41900	delivery	5	13
126912	2020-08-27 01:52:53	2020-08-27	9	[{"id_menu":6,"count":1}]	24802	pick-up	0	9
126913	2020-08-27 01:56:38	2020-08-27	9	[{"id_menu":6,"count":1}]	40635	delivery	5	14
126914	2020-08-27 02:01:42	2020-08-27	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	19711	pick-up	0	21
126915	2020-08-27 02:02:58	2020-08-27	12	[{"id_menu":1,"count":1}]	11681	pick-up	0	12
126916	2020-08-27 02:08:45	2020-08-27	12	[{"id_menu":1,"count":1}]	9193	pick-up	0	12
126917	2020-08-27 02:10:16	2020-08-27	8	[{"id_menu":5,"count":1}]	44190	pick-up	0	8
126918	2020-08-27 02:11:42	2020-08-27	9	[{"id_menu":7,"count":1}]	18065	delivery	5	14
126919	2020-08-27 02:23:16	2020-08-27	8	[{"id_menu":5,"count":1}]	47304	delivery	5	13
126920	2020-08-27 02:26:38	2020-08-27	9	[{"id_menu":7,"count":1}]	40750	delivery	5	14
126921	2020-08-27 02:27:54	2020-08-27	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	47977	delivery	5	37
126922	2020-08-27 02:29:11	2020-08-27	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	28394	delivery	5	28
126923	2020-08-27 02:29:41	2020-08-27	12	[{"id_menu":3,"count":1}]	4407	delivery	5	17
126924	2020-08-27 02:31:28	2020-08-27	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	14859	delivery	5	40
126925	2020-08-27 02:33:45	2020-08-27	17	[{"id_menu":4,"count":1}]	8966	pick-up	0	17
126926	2020-08-27 02:35:05	2020-08-27	17	[{"id_menu":4,"count":1}]	48115	delivery	5	22
126927	2020-08-27 02:35:43	2020-08-27	12	[{"id_menu":3,"count":1}]	48048	delivery	5	17
126928	2020-08-27 02:36:11	2020-08-27	14	[{"id_menu":2,"count":1}]	48013	delivery	5	19
126929	2020-08-27 02:39:58	2020-08-27	9	[{"id_menu":7,"count":1}]	48107	delivery	5	14
126930	2020-08-27 02:41:26	2020-08-27	12	[{"id_menu":3,"count":1}]	47967	delivery	5	17
126931	2020-08-27 02:44:43	2020-08-27	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	27066	delivery	5	35
126932	2020-08-27 02:48:08	2020-08-27	14	[{"id_menu":2,"count":1}]	2894	pick-up	0	14
126933	2020-08-27 02:50:14	2020-08-27	9	[{"id_menu":6,"count":1}]	12132	delivery	5	14
126934	2020-08-27 02:50:53	2020-08-27	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7460	delivery	5	28
126935	2020-08-27 02:53:29	2020-08-27	12	[{"id_menu":3,"count":1}]	43245	delivery	5	17
126936	2020-08-27 02:56:33	2020-08-27	9	[{"id_menu":7,"count":3}]	6104	delivery	5	14
126937	2020-08-27 02:59:01	2020-08-27	8	[{"id_menu":5,"count":1}]	2280	pick-up	0	8
126938	2020-08-27 03:02:37	2020-08-27	9	[{"id_menu":6,"count":1}]	42028	delivery	5	14
126939	2020-08-27 03:02:49	2020-08-27	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	143	pick-up	0	46
126940	2020-08-27 03:03:11	2020-08-27	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	5701	pick-up	0	21
126941	2020-08-27 03:05:00	2020-08-27	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	9014	delivery	5	34
126942	2020-08-27 03:07:13	2020-08-27	9	[{"id_menu":6,"count":1}]	15613	delivery	5	14
126943	2020-08-27 03:09:59	2020-08-27	12	[{"id_menu":1,"count":1}]	48043	delivery	5	17
126944	2020-08-27 03:12:03	2020-08-27	12	[{"id_menu":3,"count":1}]	31780	pick-up	0	12
126945	2020-08-27 03:12:32	2020-08-27	8	[{"id_menu":5,"count":1}]	48012	delivery	5	13
126946	2020-08-27 03:13:31	2020-08-27	9	[{"id_menu":6,"count":1}]	48163	delivery	5	14
126947	2020-08-27 03:16:43	2020-08-27	9	[{"id_menu":7,"count":1}]	48076	delivery	5	14
126948	2020-08-27 03:21:08	2020-08-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	13948	delivery	5	28
126949	2020-08-27 03:22:12	2020-08-27	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	13377	delivery	5	34
126950	2020-08-27 03:24:49	2020-08-27	12	[{"id_menu":3,"count":1}]	4934	delivery	5	17
126951	2020-08-27 03:25:09	2020-08-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	17944	delivery	5	28
126952	2020-08-27 03:27:37	2020-08-27	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9366	delivery	5	40
126953	2020-08-27 03:32:44	2020-08-27	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	7653	delivery	5	26
126954	2020-08-27 03:36:14	2020-08-27	9	[{"id_menu":7,"count":1}]	1918	pick-up	0	9
126955	2020-08-27 03:36:23	2020-08-27	14	[{"id_menu":2,"count":1}]	24036	delivery	5	19
126956	2020-08-27 03:39:38	2020-08-27	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8258	delivery	5	43
126957	2020-08-27 03:40:20	2020-08-27	9	[{"id_menu":6,"count":1}]	39802	delivery	5	14
126958	2020-08-27 03:43:41	2020-08-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	12053	delivery	5	36
126959	2020-08-27 03:43:56	2020-08-27	9	[{"id_menu":7,"count":1}]	47956	delivery	5	14
126960	2020-08-27 03:44:52	2020-08-27	9	[{"id_menu":6,"count":1}]	48166	delivery	5	14
126961	2020-08-27 03:51:04	2020-08-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	47990	delivery	5	22
126962	2020-08-27 03:54:42	2020-08-27	17	[{"id_menu":4,"count":1}]	32603	delivery	5	22
126963	2020-08-27 03:56:34	2020-08-27	14	[{"id_menu":2,"count":1}]	47987	delivery	5	19
126964	2020-08-27 03:57:07	2020-08-27	14	[{"id_menu":2,"count":2}]	14316	delivery	5	19
126965	2020-08-27 03:58:52	2020-08-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6166	delivery	5	36
126966	2020-08-27 04:01:04	2020-08-27	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	48081	delivery	5	29
126967	2020-08-27 04:01:33	2020-08-27	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	3936	delivery	5	29
126968	2020-08-27 04:01:57	2020-08-27	17	[{"id_menu":4,"count":1}]	14710	pick-up	0	17
126969	2020-08-27 04:03:16	2020-08-27	12	[{"id_menu":3,"count":1}]	43119	delivery	5	17
126970	2020-08-27 04:03:17	2020-08-27	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	31296	delivery	5	26
126971	2020-08-27 04:06:36	2020-08-27	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11789	delivery	5	39
126972	2020-08-27 04:06:51	2020-08-27	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	31628	delivery	5	26
126973	2020-08-27 04:11:28	2020-08-27	9	[{"id_menu":7,"count":1}]	24895	delivery	5	14
126974	2020-08-27 04:16:22	2020-08-27	17	[{"id_menu":4,"count":1}]	31687	delivery	5	22
126975	2020-08-27 04:16:51	2020-08-27	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15110	delivery	5	22
126976	2020-08-27 04:21:56	2020-08-27	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33125	delivery	5	40
126977	2020-08-27 04:25:08	2020-08-27	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	48173	delivery	5	26
126978	2020-08-27 04:25:12	2020-08-27	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	47964	delivery	5	40
126979	2020-08-27 04:27:07	2020-08-27	33	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	48041	delivery	5	38
126980	2020-08-27 04:27:40	2020-08-27	9	[{"id_menu":7,"count":1}]	8485	pick-up	0	9
126981	2020-08-27 04:28:09	2020-08-27	17	[{"id_menu":4,"count":1}]	48183	delivery	5	22
126982	2020-08-27 04:31:56	2020-08-27	14	[{"id_menu":2,"count":1}]	44987	delivery	5	19
126983	2020-08-27 04:32:31	2020-08-27	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	21628	delivery	5	25
126984	2020-08-27 04:34:16	2020-08-27	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	20033	delivery	5	43
126985	2020-08-27 04:34:35	2020-08-27	9	[{"id_menu":6,"count":1}]	48099	delivery	5	14
126986	2020-08-27 04:35:35	2020-08-27	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	17444	delivery	5	25
126987	2020-08-27 04:36:04	2020-08-27	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	48124	delivery	5	26
126988	2020-08-27 04:36:23	2020-08-27	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	34406	delivery	5	26
126989	2020-08-27 04:37:58	2020-08-27	17	[{"id_menu":4,"count":1}]	31963	pick-up	0	17
126990	2020-08-27 04:39:14	2020-08-27	14	[{"id_menu":2,"count":1}]	28938	delivery	5	19
126991	2020-08-27 04:40:04	2020-08-27	14	[{"id_menu":2,"count":1}]	19952	delivery	5	19
126992	2020-08-27 04:40:26	2020-08-27	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	48037	delivery	5	27
126993	2020-08-27 04:44:30	2020-08-27	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	48104	delivery	5	43
126994	2020-08-27 04:44:51	2020-08-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2473	delivery	5	28
126995	2020-08-27 04:44:54	2020-08-27	12	[{"id_menu":1,"count":1}]	41797	pick-up	0	12
126996	2020-08-27 04:45:17	2020-08-27	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":3}]	13635	delivery	5	31
126997	2020-08-27 04:45:38	2020-08-27	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	6142	delivery	5	25
126998	2020-08-27 04:45:40	2020-08-27	14	[{"id_menu":2,"count":1}]	23673	delivery	5	19
126999	2020-08-27 04:45:53	2020-08-27	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	48147	delivery	5	52
127000	2020-08-27 04:46:23	2020-08-27	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	48044	delivery	5	26
127001	2020-08-27 04:49:32	2020-08-27	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	19422	delivery	5	35
127002	2020-08-27 04:52:27	2020-08-27	9	[{"id_menu":6,"count":1}]	9797	delivery	5	14
127003	2020-08-27 04:57:18	2020-08-27	8	[{"id_menu":5,"count":1}]	821	pick-up	0	8
127004	2020-08-27 05:07:06	2020-08-27	12	[{"id_menu":3,"count":1}]	38837	pick-up	0	12
127005	2020-08-27 05:09:04	2020-08-27	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	3534	delivery	5	34
127006	2020-08-27 05:12:23	2020-08-27	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	48120	delivery	5	30
127007	2020-08-27 05:14:51	2020-08-27	8	[{"id_menu":5,"count":1}]	9752	delivery	5	13
127008	2020-08-27 05:15:53	2020-08-27	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7803	delivery	5	36
127009	2020-08-27 05:16:25	2020-08-27	12	[{"id_menu":3,"count":1}]	31967	delivery	5	17
127010	2020-08-27 05:17:15	2020-08-27	9	[{"id_menu":7,"count":1}]	25555	delivery	5	14
127011	2020-08-27 05:20:30	2020-08-27	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	44498	delivery	5	31
127012	2020-08-27 05:21:45	2020-08-27	12	[{"id_menu":1,"count":1}]	21338	delivery	5	17
127013	2020-08-27 05:22:20	2020-08-27	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16372	delivery	5	22
127014	2020-08-27 05:24:01	2020-08-27	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	48141	delivery	5	28
127015	2020-08-27 05:30:13	2020-08-27	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	3364	delivery	5	26
127016	2020-08-27 05:30:44	2020-08-27	12	[{"id_menu":3,"count":1}]	48033	delivery	5	17
127017	2020-08-27 05:30:52	2020-08-27	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	17988	delivery	5	40
127018	2020-08-27 05:33:38	2020-08-27	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	47973	delivery	5	31
127019	2020-08-27 05:33:44	2020-08-27	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	32410	pick-up	0	24
127020	2020-08-27 05:34:18	2020-08-27	17	[{"id_menu":4,"count":1}]	10200	delivery	5	22
127021	2020-08-27 05:39:40	2020-08-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5735	delivery	5	22
127022	2020-08-27 05:41:30	2020-08-27	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	6567	delivery	5	31
127023	2020-08-27 05:42:36	2020-08-27	14	[{"id_menu":2,"count":1}]	1795	pick-up	0	14
127024	2020-08-27 05:42:46	2020-08-27	9	[{"id_menu":7,"count":1}]	47986	delivery	5	14
127025	2020-08-27 05:43:08	2020-08-27	17	[{"id_menu":4,"count":1}]	48045	delivery	5	22
127026	2020-08-27 05:50:35	2020-08-27	9	[{"id_menu":6,"count":1}]	10968	pick-up	0	9
127027	2020-08-27 05:50:44	2020-08-27	9	[{"id_menu":6,"count":1}]	48080	pick-up	0	9
127028	2020-08-27 05:50:50	2020-08-27	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	42352	delivery	5	30
127029	2020-08-27 05:53:31	2020-08-27	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	38956	delivery	5	22
127030	2020-08-27 06:00:03	2020-08-27	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":2}]	18057	pick-up	0	31
127031	2020-08-27 06:01:47	2020-08-27	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	30758	delivery	5	51
127032	2020-08-27 06:04:36	2020-08-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20992	delivery	5	23
127033	2020-08-27 06:05:14	2020-08-27	9	[{"id_menu":7,"count":1}]	26493	delivery	5	14
127034	2020-08-27 06:05:23	2020-08-27	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	48040	delivery	5	31
127035	2020-08-27 06:05:44	2020-08-27	8	[{"id_menu":5,"count":1}]	29151	delivery	5	13
127036	2020-08-27 06:07:04	2020-08-27	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	48171	delivery	5	26
127037	2020-08-27 06:10:24	2020-08-27	17	[{"id_menu":4,"count":1}]	40917	pick-up	0	17
127038	2020-08-27 06:13:25	2020-08-27	9	[{"id_menu":7,"count":1}]	48144	delivery	5	14
127039	2020-08-27 06:14:00	2020-08-27	12	[{"id_menu":3,"count":1}]	42867	delivery	5	17
127040	2020-08-27 06:16:06	2020-08-27	9	[{"id_menu":6,"count":1}]	48078	delivery	5	14
127041	2020-08-27 06:18:18	2020-08-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	45269	delivery	5	23
127042	2020-08-27 06:18:53	2020-08-27	12	[{"id_menu":1,"count":1}]	43247	delivery	5	17
127043	2020-08-27 06:21:05	2020-08-27	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	3982	pick-up	0	22
127044	2020-08-27 06:23:40	2020-08-27	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	48108	delivery	5	39
127045	2020-08-27 06:23:45	2020-08-27	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	31307	delivery	5	22
127046	2020-08-27 06:24:58	2020-08-27	9	[{"id_menu":7,"count":1}]	256	pick-up	0	9
127047	2020-08-27 06:26:43	2020-08-27	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	26189	delivery	5	45
127048	2020-08-27 06:26:56	2020-08-27	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	11973	delivery	5	28
127049	2020-08-27 06:26:58	2020-08-27	12	[{"id_menu":1,"count":1}]	19270	pick-up	0	12
127050	2020-08-27 06:28:31	2020-08-27	17	[{"id_menu":4,"count":1}]	6480	delivery	5	22
127051	2020-08-27 06:30:13	2020-08-27	17	[{"id_menu":4,"count":1}]	48143	delivery	5	22
127052	2020-08-27 06:31:07	2020-08-27	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	46722	delivery	5	31
127053	2020-08-27 06:31:11	2020-08-27	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	48053	delivery	5	22
127054	2020-08-27 06:32:23	2020-08-27	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	12523	delivery	5	30
127055	2020-08-27 06:33:02	2020-08-27	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	14929	delivery	5	25
127056	2020-08-27 06:33:57	2020-08-27	8	[{"id_menu":5,"count":1}]	6726	delivery	5	13
127057	2020-08-27 06:35:11	2020-08-27	9	[{"id_menu":7,"count":1}]	42800	delivery	5	14
127058	2020-08-27 06:36:28	2020-08-27	9	[{"id_menu":7,"count":1}]	48116	delivery	5	14
127059	2020-08-27 06:38:27	2020-08-27	9	[{"id_menu":7,"count":1}]	18195	delivery	5	14
127060	2020-08-27 06:39:36	2020-08-27	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	43155	delivery	5	36
127061	2020-08-27 06:42:18	2020-08-27	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	13429	delivery	5	26
127062	2020-08-27 06:42:52	2020-08-27	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	48063	delivery	5	26
127063	2020-08-27 06:44:05	2020-08-27	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5850	delivery	5	49
127064	2020-08-27 06:47:01	2020-08-27	12	[{"id_menu":3,"count":1}]	48140	pick-up	0	12
127065	2020-08-27 06:47:53	2020-08-27	12	[{"id_menu":1,"count":1}]	31876	delivery	5	17
127066	2020-08-27 06:48:33	2020-08-27	17	[{"id_menu":4,"count":1}]	38948	pick-up	0	17
127067	2020-08-27 06:51:59	2020-08-27	17	[{"id_menu":4,"count":1}]	1284	delivery	5	22
127068	2020-08-27 06:52:01	2020-08-27	9	[{"id_menu":7,"count":1}]	47966	delivery	5	14
127069	2020-08-27 06:52:16	2020-08-27	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	1649	pick-up	0	21
127070	2020-08-27 06:54:30	2020-08-27	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	18983	delivery	5	45
127071	2020-08-27 06:55:19	2020-08-27	9	[{"id_menu":6,"count":1}]	47988	delivery	5	14
127072	2020-08-27 06:56:15	2020-08-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1910	delivery	5	36
127073	2020-08-27 07:03:27	2020-08-27	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":2}]	26187	delivery	5	31
127074	2020-08-27 07:03:30	2020-08-27	9	[{"id_menu":6,"count":1}]	14948	delivery	5	14
127075	2020-08-27 07:06:11	2020-08-27	8	[{"id_menu":5,"count":1}]	22353	delivery	5	13
127076	2020-08-27 07:17:40	2020-08-27	12	[{"id_menu":3,"count":1}]	44430	delivery	5	17
127077	2020-08-27 07:18:01	2020-08-27	9	[{"id_menu":7,"count":1}]	13344	delivery	5	14
127078	2020-08-27 07:18:20	2020-08-27	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	34250	delivery	5	48
127079	2020-08-27 07:18:58	2020-08-27	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13561	delivery	5	35
127080	2020-08-27 07:24:07	2020-08-27	9	[{"id_menu":6,"count":1}]	41339	delivery	5	14
127081	2020-08-27 07:24:37	2020-08-27	17	[{"id_menu":4,"count":1}]	11314	delivery	5	22
127082	2020-08-27 07:25:31	2020-08-27	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	48073	delivery	5	28
127083	2020-08-27 07:27:35	2020-08-27	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18668	delivery	5	34
127084	2020-08-27 07:28:27	2020-08-27	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	43866	delivery	5	22
127085	2020-08-27 07:29:55	2020-08-27	14	[{"id_menu":2,"count":1}]	20853	delivery	5	19
127086	2020-08-27 07:31:31	2020-08-27	12	[{"id_menu":1,"count":1}]	42715	pick-up	0	12
127087	2020-08-27 07:32:18	2020-08-27	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	32629	delivery	5	40
127088	2020-08-27 07:32:40	2020-08-27	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	15971	delivery	5	38
127089	2020-08-27 07:34:12	2020-08-27	17	[{"id_menu":4,"count":1}]	47995	delivery	5	22
127090	2020-08-27 07:34:23	2020-08-27	9	[{"id_menu":6,"count":1}]	24007	delivery	5	14
127091	2020-08-27 07:37:00	2020-08-27	9	[{"id_menu":7,"count":1}]	7122	delivery	5	14
127092	2020-08-27 07:41:13	2020-08-27	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	26965	delivery	5	36
127093	2020-08-27 07:44:37	2020-08-27	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	43630	delivery	5	31
127094	2020-08-27 07:45:51	2020-08-27	12	[{"id_menu":3,"count":1}]	5106	delivery	5	17
127095	2020-08-27 07:51:52	2020-08-27	9	[{"id_menu":6,"count":1}]	22882	delivery	5	14
127096	2020-08-27 07:52:57	2020-08-27	12	[{"id_menu":3,"count":1}]	28940	delivery	5	17
127097	2020-08-27 07:57:24	2020-08-27	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26963	delivery	5	47
127098	2020-08-27 07:58:14	2020-08-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	36347	delivery	5	28
127099	2020-08-27 07:58:50	2020-08-27	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	43425	delivery	5	31
127100	2020-08-27 08:00:08	2020-08-27	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	45146	delivery	5	45
127101	2020-08-27 08:00:13	2020-08-27	9	[{"id_menu":6,"count":1}]	48025	delivery	5	14
127102	2020-08-27 08:00:24	2020-08-27	12	[{"id_menu":3,"count":1}]	2083	pick-up	0	12
127103	2020-08-27 08:00:46	2020-08-27	17	[{"id_menu":4,"count":1}]	47727	delivery	5	22
127104	2020-08-27 08:03:00	2020-08-27	17	[{"id_menu":4,"count":1}]	1735	delivery	5	22
127105	2020-08-27 08:05:16	2020-08-27	9	[{"id_menu":7,"count":1}]	29394	pick-up	0	9
127106	2020-08-27 08:06:18	2020-08-27	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":2}]	45809	delivery	5	28
127107	2020-08-27 08:07:42	2020-08-27	14	[{"id_menu":2,"count":1}]	2780	pick-up	0	14
127108	2020-08-27 08:09:18	2020-08-27	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	48046	delivery	5	31
127109	2020-08-27 08:10:00	2020-08-27	8	[{"id_menu":5,"count":1}]	26099	pick-up	0	8
127110	2020-08-27 08:14:24	2020-08-27	9	[{"id_menu":7,"count":1}]	14558	pick-up	0	9
127111	2020-08-27 08:18:44	2020-08-27	9	[{"id_menu":7,"count":1}]	2745	delivery	5	14
127112	2020-08-27 08:19:09	2020-08-27	8	[{"id_menu":5,"count":1}]	47979	delivery	5	13
127113	2020-08-27 08:19:16	2020-08-27	12	[{"id_menu":1,"count":2}]	47968	delivery	5	17
127114	2020-08-27 08:20:48	2020-08-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	16505	delivery	5	36
127115	2020-08-27 08:22:19	2020-08-27	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	24583	delivery	5	40
127116	2020-08-27 08:24:31	2020-08-27	14	[{"id_menu":2,"count":1}]	26155	delivery	5	19
127117	2020-08-27 08:26:34	2020-08-27	9	[{"id_menu":6,"count":1}]	46890	delivery	5	14
127118	2020-08-27 08:26:53	2020-08-27	8	[{"id_menu":5,"count":1}]	1523	pick-up	0	8
127119	2020-08-27 08:28:34	2020-08-27	14	[{"id_menu":2,"count":1}]	33348	delivery	5	19
127120	2020-08-27 08:28:40	2020-08-27	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	47971	delivery	5	36
127121	2020-08-27 08:29:19	2020-08-27	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	42841	pick-up	0	22
127122	2020-08-27 08:29:48	2020-08-27	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	48151	delivery	5	27
127123	2020-08-27 08:32:47	2020-08-27	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	47962	delivery	5	28
127124	2020-08-27 08:32:59	2020-08-27	8	[{"id_menu":5,"count":1}]	48051	delivery	5	13
127125	2020-08-27 08:33:53	2020-08-27	9	[{"id_menu":7,"count":1}]	1117	delivery	5	14
127126	2020-08-27 08:35:07	2020-08-27	8	[{"id_menu":5,"count":2}]	48059	delivery	5	13
127127	2020-08-27 08:37:34	2020-08-27	8	[{"id_menu":5,"count":2}]	21742	delivery	5	13
127128	2020-08-27 08:37:48	2020-08-27	14	[{"id_menu":2,"count":1}]	10801	pick-up	0	14
127129	2020-08-27 08:39:02	2020-08-27	9	[{"id_menu":6,"count":1}]	13473	delivery	5	14
127130	2020-08-27 08:41:56	2020-08-27	12	[{"id_menu":3,"count":1}]	13647	delivery	5	17
127131	2020-08-27 08:41:57	2020-08-27	9	[{"id_menu":7,"count":1}]	36944	delivery	5	14
127132	2020-08-27 08:43:51	2020-08-27	9	[{"id_menu":6,"count":3}]	48145	delivery	5	14
127133	2020-08-27 08:46:53	2020-08-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43770	pick-up	0	18
127134	2020-08-27 08:50:36	2020-08-27	9	[{"id_menu":7,"count":1}]	34280	delivery	5	14
127135	2020-08-27 08:51:55	2020-08-27	14	[{"id_menu":2,"count":1}]	39820	delivery	5	19
127136	2020-08-27 08:54:35	2020-08-27	9	[{"id_menu":6,"count":1}]	48125	delivery	5	14
127137	2020-08-27 08:56:15	2020-08-27	8	[{"id_menu":5,"count":1}]	18859	delivery	5	13
127138	2020-08-27 08:56:25	2020-08-27	8	[{"id_menu":5,"count":1}]	26788	delivery	5	13
127139	2020-08-27 08:56:43	2020-08-27	9	[{"id_menu":6,"count":1}]	48113	pick-up	0	9
127140	2020-08-27 08:58:08	2020-08-27	9	[{"id_menu":7,"count":1}]	10989	delivery	5	14
127141	2020-08-27 08:59:01	2020-08-27	17	[{"id_menu":4,"count":1}]	28285	delivery	5	22
127142	2020-08-27 09:01:11	2020-08-27	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10622	delivery	5	54
127143	2020-08-27 09:02:14	2020-08-27	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48112	delivery	5	43
127144	2020-08-27 09:05:25	2020-08-27	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	40667	delivery	5	35
127145	2020-08-27 09:07:25	2020-08-27	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	28532	pick-up	0	21
127146	2020-08-27 09:10:01	2020-08-27	8	[{"id_menu":5,"count":1}]	48074	delivery	5	13
127147	2020-08-27 09:11:36	2020-08-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	25015	pick-up	0	23
127148	2020-08-27 09:11:47	2020-08-27	26	[{"id_menu":4,"count":3},{"id_menu":7,"count":1}]	34369	delivery	5	31
127149	2020-08-27 09:12:27	2020-08-27	12	[{"id_menu":3,"count":1}]	48015	pick-up	0	12
127150	2020-08-27 09:16:58	2020-08-27	14	[{"id_menu":2,"count":1}]	20764	delivery	5	19
127151	2020-08-27 09:17:36	2020-08-27	12	[{"id_menu":3,"count":1}]	3227	pick-up	0	12
127152	2020-08-27 09:19:35	2020-08-27	14	[{"id_menu":2,"count":1}]	42660	pick-up	0	14
127153	2020-08-27 09:20:36	2020-08-27	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	11317	delivery	5	30
127154	2020-08-27 09:21:39	2020-08-27	9	[{"id_menu":6,"count":1}]	15174	delivery	5	14
127155	2020-08-27 09:22:24	2020-08-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48170	delivery	5	23
127156	2020-08-27 09:23:46	2020-08-27	9	[{"id_menu":7,"count":1}]	48158	delivery	5	14
127157	2020-08-27 09:25:34	2020-08-27	14	[{"id_menu":2,"count":1}]	48001	delivery	5	19
127158	2020-08-27 09:30:25	2020-08-27	9	[{"id_menu":6,"count":1}]	12476	delivery	5	14
127159	2020-08-27 09:30:27	2020-08-27	12	[{"id_menu":3,"count":1}]	3147	pick-up	0	12
127160	2020-08-27 09:32:29	2020-08-27	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	47840	delivery	5	38
127161	2020-08-27 09:33:47	2020-08-27	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7217	delivery	5	34
127162	2020-08-27 09:33:57	2020-08-27	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	20573	delivery	5	45
127163	2020-08-27 09:34:08	2020-08-27	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	43673	delivery	5	39
127164	2020-08-27 09:35:35	2020-08-27	9	[{"id_menu":7,"count":1}]	44916	delivery	5	14
127165	2020-08-27 09:37:32	2020-08-27	12	[{"id_menu":1,"count":1}]	31951	delivery	5	17
127166	2020-08-27 09:37:42	2020-08-27	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	33128	delivery	5	22
127167	2020-08-27 09:39:29	2020-08-27	17	[{"id_menu":4,"count":1}]	38508	delivery	5	22
127168	2020-08-27 09:40:59	2020-08-27	9	[{"id_menu":7,"count":1}]	1756	pick-up	0	9
127169	2020-08-27 09:48:43	2020-08-27	12	[{"id_menu":3,"count":1}]	48162	pick-up	0	12
127170	2020-08-27 09:54:50	2020-08-27	12	[{"id_menu":3,"count":2}]	1852	pick-up	0	12
127171	2020-08-27 09:55:01	2020-08-27	14	[{"id_menu":2,"count":1}]	48154	delivery	5	19
127172	2020-08-27 09:57:39	2020-08-27	9	[{"id_menu":7,"count":1}]	33219	delivery	5	14
127173	2020-08-27 09:58:51	2020-08-27	9	[{"id_menu":6,"count":1}]	22564	delivery	5	14
127174	2020-08-27 10:02:49	2020-08-27	8	[{"id_menu":5,"count":1}]	48119	delivery	5	13
127175	2020-08-27 10:03:25	2020-08-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4586	delivery	5	23
127176	2020-08-27 10:03:46	2020-08-27	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	31509	pick-up	0	24
127177	2020-08-27 10:06:15	2020-08-27	9	[{"id_menu":6,"count":1}]	48181	delivery	5	14
127178	2020-08-27 10:06:30	2020-08-27	14	[{"id_menu":2,"count":1}]	16813	delivery	5	19
127179	2020-08-27 10:06:49	2020-08-27	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	44183	delivery	5	26
127180	2020-08-27 10:06:50	2020-08-27	12	[{"id_menu":1,"count":1}]	10784	pick-up	0	12
127181	2020-08-27 10:07:35	2020-08-27	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	48178	delivery	5	34
127182	2020-08-27 10:08:53	2020-08-27	14	[{"id_menu":2,"count":1}]	10087	pick-up	0	14
127183	2020-08-27 10:10:35	2020-08-27	8	[{"id_menu":5,"count":1}]	18135	delivery	5	13
127184	2020-08-27 10:11:22	2020-08-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48159	pick-up	0	18
127185	2020-08-27 10:14:41	2020-08-27	9	[{"id_menu":7,"count":1}]	17973	delivery	5	14
127186	2020-08-27 10:15:58	2020-08-27	8	[{"id_menu":5,"count":1}]	48060	delivery	5	13
127187	2020-08-27 10:16:48	2020-08-27	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	48032	delivery	5	22
127188	2020-08-27 10:18:06	2020-08-27	8	[{"id_menu":5,"count":1}]	27595	delivery	5	13
127189	2020-08-27 10:19:55	2020-08-27	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	3245	pick-up	0	21
127190	2020-08-27 10:23:30	2020-08-27	8	[{"id_menu":5,"count":1}]	9820	pick-up	0	8
127191	2020-08-27 10:28:17	2020-08-27	8	[{"id_menu":5,"count":1}]	12268	pick-up	0	8
127192	2020-08-27 10:29:13	2020-08-27	8	[{"id_menu":5,"count":1}]	23137	pick-up	0	8
127193	2020-08-27 10:29:17	2020-08-27	9	[{"id_menu":6,"count":1}]	9167	delivery	5	14
127194	2020-08-27 10:29:48	2020-08-27	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	6974	delivery	5	38
127195	2020-08-27 10:31:42	2020-08-27	14	[{"id_menu":2,"count":1}]	21606	delivery	5	19
127196	2020-08-27 10:33:29	2020-08-27	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	9737	delivery	5	40
127197	2020-08-27 10:36:13	2020-08-27	14	[{"id_menu":2,"count":1}]	48038	delivery	5	19
127198	2020-08-27 10:36:40	2020-08-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	48153	delivery	5	22
127199	2020-08-27 10:42:04	2020-08-27	12	[{"id_menu":1,"count":1}]	1596	delivery	5	17
127200	2020-08-27 10:42:08	2020-08-27	9	[{"id_menu":7,"count":1}]	20911	delivery	5	14
127201	2020-08-27 10:52:29	2020-08-27	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	48050	pick-up	0	24
127202	2020-08-27 10:54:09	2020-08-27	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	7188	delivery	5	43
127203	2020-08-27 10:58:39	2020-08-27	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	48092	delivery	5	43
127204	2020-08-27 10:59:08	2020-08-27	8	[{"id_menu":5,"count":1}]	48098	delivery	5	13
127205	2020-08-27 10:59:35	2020-08-27	14	[{"id_menu":2,"count":1}]	48165	delivery	5	19
127206	2020-08-27 10:59:59	2020-08-27	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	32280	delivery	5	45
127207	2020-08-27 11:00:31	2020-08-27	9	[{"id_menu":6,"count":1}]	29	delivery	5	14
127208	2020-08-27 11:02:36	2020-08-27	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	48070	pick-up	0	39
127209	2020-08-27 11:04:28	2020-08-27	14	[{"id_menu":2,"count":1}]	27370	delivery	5	19
127210	2020-08-27 11:06:00	2020-08-27	14	[{"id_menu":2,"count":1}]	23880	pick-up	0	14
127211	2020-08-27 11:10:46	2020-08-27	12	[{"id_menu":3,"count":1}]	22422	delivery	5	17
127212	2020-08-27 11:14:15	2020-08-27	9	[{"id_menu":7,"count":1}]	292	delivery	5	14
127213	2020-08-27 11:16:14	2020-08-27	17	[{"id_menu":4,"count":1}]	41326	delivery	5	22
127214	2020-08-27 11:17:48	2020-08-27	9	[{"id_menu":6,"count":3}]	37401	delivery	5	14
127215	2020-08-27 11:20:48	2020-08-27	9	[{"id_menu":6,"count":2}]	44480	delivery	5	14
127216	2020-08-27 11:22:11	2020-08-27	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	36672	delivery	5	52
127217	2020-08-27 11:23:18	2020-08-27	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	36888	delivery	5	39
127218	2020-08-27 11:26:26	2020-08-27	14	[{"id_menu":2,"count":1}]	2662	pick-up	0	14
127219	2020-08-27 11:26:56	2020-08-27	9	[{"id_menu":6,"count":1}]	15738	delivery	5	14
127220	2020-08-27 11:27:54	2020-08-27	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	42755	delivery	5	35
127221	2020-08-27 11:33:17	2020-08-27	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	44832	delivery	5	44
127222	2020-08-27 11:34:12	2020-08-27	9	[{"id_menu":6,"count":1}]	40727	delivery	5	14
127223	2020-08-27 11:36:03	2020-08-27	14	[{"id_menu":2,"count":1}]	5839	pick-up	0	14
127224	2020-08-27 11:39:26	2020-08-27	8	[{"id_menu":5,"count":1}]	14090	delivery	5	13
127225	2020-08-27 11:41:33	2020-08-27	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	33769	delivery	5	48
127226	2020-08-27 11:41:41	2020-08-27	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	34803	delivery	5	43
127227	2020-08-27 11:44:46	2020-08-27	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	30480	delivery	5	25
127228	2020-08-27 11:51:22	2020-08-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	24587	delivery	5	28
127229	2020-08-27 11:51:25	2020-08-27	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	48177	delivery	5	25
127230	2020-08-27 11:51:26	2020-08-27	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	9644	pick-up	0	24
127231	2020-08-27 11:51:50	2020-08-27	14	[{"id_menu":2,"count":1}]	13655	delivery	5	19
127232	2020-08-27 11:54:25	2020-08-27	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	48075	delivery	5	26
127233	2020-08-27 11:57:09	2020-08-27	9	[{"id_menu":6,"count":1}]	1839	pick-up	0	9
127234	2020-08-27 12:00:42	2020-08-27	14	[{"id_menu":2,"count":1}]	22228	delivery	5	19
127235	2020-08-27 12:03:29	2020-08-27	9	[{"id_menu":6,"count":2}]	16600	delivery	5	14
127236	2020-08-27 12:04:57	2020-08-27	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":2}]	24903	delivery	5	22
127237	2020-08-27 12:06:00	2020-08-27	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	48157	delivery	5	42
127238	2020-08-27 12:06:00	2020-08-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	47975	delivery	5	28
127239	2020-08-27 12:07:41	2020-08-27	14	[{"id_menu":2,"count":1}]	26624	delivery	5	19
127240	2020-08-27 12:08:10	2020-08-27	12	[{"id_menu":1,"count":1}]	39217	delivery	5	17
127241	2020-08-27 12:08:10	2020-08-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31759	delivery	5	22
127242	2020-08-27 12:08:13	2020-08-27	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	10311	delivery	5	34
127243	2020-08-27 12:08:27	2020-08-27	23	[{"id_menu":2,"count":3},{"id_menu":7,"count":1}]	47991	delivery	5	28
127244	2020-08-27 12:10:26	2020-08-27	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	48111	delivery	5	48
127245	2020-08-27 12:11:47	2020-08-27	9	[{"id_menu":7,"count":1}]	1138	pick-up	0	9
127246	2020-08-27 12:13:48	2020-08-27	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	8225	delivery	5	31
127247	2020-08-27 12:14:31	2020-08-27	9	[{"id_menu":7,"count":1}]	10007	pick-up	0	9
127248	2020-08-27 12:18:10	2020-08-27	14	[{"id_menu":2,"count":1}]	4624	pick-up	0	14
127249	2020-08-27 12:19:14	2020-08-27	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	33175	delivery	5	31
127250	2020-08-27 12:21:39	2020-08-27	9	[{"id_menu":7,"count":1}]	11380	delivery	5	14
127251	2020-08-27 12:25:01	2020-08-27	14	[{"id_menu":2,"count":1}]	21575	pick-up	0	14
127252	2020-08-27 12:25:02	2020-08-27	17	[{"id_menu":4,"count":2}]	32771	delivery	5	22
127253	2020-08-27 12:29:06	2020-08-27	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	22521	delivery	5	55
127254	2020-08-27 12:31:37	2020-08-27	14	[{"id_menu":2,"count":1}]	48114	delivery	5	19
127255	2020-08-27 12:31:48	2020-08-27	9	[{"id_menu":6,"count":1}]	47996	delivery	5	14
127256	2020-08-27 12:34:32	2020-08-27	12	[{"id_menu":3,"count":1}]	15585	delivery	5	17
127257	2020-08-27 12:35:10	2020-08-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4714	pick-up	0	18
127258	2020-08-27 12:38:40	2020-08-27	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	6977	delivery	5	38
127259	2020-08-27 12:39:34	2020-08-27	8	[{"id_menu":5,"count":1}]	21883	pick-up	0	8
127260	2020-08-27 12:42:02	2020-08-27	12	[{"id_menu":1,"count":1}]	6101	pick-up	0	12
127261	2020-08-27 12:42:14	2020-08-27	17	[{"id_menu":4,"count":1}]	5970	pick-up	0	17
127262	2020-08-27 12:43:30	2020-08-27	9	[{"id_menu":6,"count":1}]	48102	delivery	5	14
127263	2020-08-27 12:51:04	2020-08-27	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	8448	pick-up	0	38
127264	2020-08-27 12:51:49	2020-08-27	9	[{"id_menu":6,"count":1}]	21814	delivery	5	14
127265	2020-08-27 12:51:55	2020-08-27	9	[{"id_menu":6,"count":3}]	27803	delivery	5	14
127266	2020-08-27 12:52:05	2020-08-27	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	45931	delivery	5	35
127267	2020-08-27 12:54:07	2020-08-27	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15116	delivery	5	43
127268	2020-08-27 12:55:27	2020-08-27	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	48097	pick-up	0	26
127269	2020-08-27 12:58:57	2020-08-27	9	[{"id_menu":6,"count":1}]	3799	pick-up	0	9
127270	2020-08-27 13:01:46	2020-08-27	8	[{"id_menu":5,"count":1}]	21027	delivery	5	13
127271	2020-08-27 13:02:51	2020-08-27	9	[{"id_menu":6,"count":1}]	15457	delivery	5	14
127272	2020-08-27 13:04:42	2020-08-27	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	48061	delivery	5	28
127273	2020-08-27 13:04:49	2020-08-27	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4666	delivery	5	31
127274	2020-08-27 13:04:59	2020-08-27	12	[{"id_menu":3,"count":1}]	48009	delivery	5	17
127275	2020-08-27 13:08:36	2020-08-27	14	[{"id_menu":2,"count":1}]	35956	pick-up	0	14
127276	2020-08-27 13:11:27	2020-08-27	12	[{"id_menu":1,"count":1}]	43250	pick-up	0	12
127277	2020-08-27 13:11:39	2020-08-27	12	[{"id_menu":1,"count":1}]	13692	pick-up	0	12
127278	2020-08-27 13:13:06	2020-08-27	9	[{"id_menu":7,"count":1}]	26487	delivery	5	14
127279	2020-08-27 13:17:58	2020-08-27	8	[{"id_menu":5,"count":1}]	48134	delivery	5	13
127280	2020-08-27 13:20:18	2020-08-27	12	[{"id_menu":3,"count":1}]	10798	delivery	5	17
127281	2020-08-27 13:21:30	2020-08-27	9	[{"id_menu":7,"count":1}]	48160	pick-up	0	9
127282	2020-08-27 13:23:05	2020-08-27	14	[{"id_menu":2,"count":2}]	16081	delivery	5	19
127283	2020-08-27 13:23:35	2020-08-27	9	[{"id_menu":6,"count":1}]	48139	delivery	5	14
127284	2020-08-27 13:24:41	2020-08-27	17	[{"id_menu":4,"count":1}]	36762	pick-up	0	17
127285	2020-08-27 13:25:51	2020-08-27	17	[{"id_menu":4,"count":1}]	10717	pick-up	0	17
127286	2020-08-27 13:27:09	2020-08-27	9	[{"id_menu":6,"count":1}]	30608	delivery	5	14
127287	2020-08-27 13:28:30	2020-08-27	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	18797	delivery	5	28
127288	2020-08-27 13:32:33	2020-08-27	9	[{"id_menu":7,"count":1}]	13185	delivery	5	14
127289	2020-08-27 13:33:32	2020-08-27	9	[{"id_menu":7,"count":2}]	14668	delivery	5	14
127290	2020-08-27 13:33:57	2020-08-27	12	[{"id_menu":3,"count":1}]	25210	pick-up	0	12
127291	2020-08-27 13:34:18	2020-08-27	9	[{"id_menu":6,"count":1}]	48023	delivery	5	14
127292	2020-08-27 13:35:37	2020-08-27	9	[{"id_menu":6,"count":1}]	14855	delivery	5	14
127293	2020-08-27 13:36:28	2020-08-27	14	[{"id_menu":2,"count":1}]	41232	delivery	5	19
127294	2020-08-27 13:36:47	2020-08-27	14	[{"id_menu":2,"count":1}]	32581	pick-up	0	14
127295	2020-08-27 13:37:11	2020-08-27	8	[{"id_menu":5,"count":1}]	45676	delivery	5	13
127296	2020-08-27 13:44:07	2020-08-27	9	[{"id_menu":6,"count":1}]	23593	delivery	5	14
127297	2020-08-27 13:50:24	2020-08-27	8	[{"id_menu":5,"count":1}]	48030	delivery	5	13
127298	2020-08-27 13:51:18	2020-08-27	12	[{"id_menu":1,"count":1}]	21825	delivery	5	17
127299	2020-08-27 13:56:43	2020-08-27	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12236	delivery	5	31
127300	2020-08-27 13:59:53	2020-08-27	9	[{"id_menu":7,"count":1}]	15117	pick-up	0	9
127301	2020-08-27 14:00:42	2020-08-27	9	[{"id_menu":7,"count":1}]	11534	pick-up	0	9
127302	2020-08-27 14:00:54	2020-08-27	9	[{"id_menu":6,"count":1}]	17733	delivery	5	14
127303	2020-08-27 14:01:11	2020-08-27	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	44503	delivery	5	27
127304	2020-08-27 14:11:23	2020-08-27	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	26461	delivery	5	26
127305	2020-08-27 14:12:05	2020-08-27	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	749	delivery	5	38
127306	2020-08-27 14:13:06	2020-08-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	46611	pick-up	0	31
127307	2020-08-27 14:13:26	2020-08-27	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	21671	delivery	5	43
127308	2020-08-27 14:14:32	2020-08-27	9	[{"id_menu":7,"count":1}]	48089	delivery	5	14
127309	2020-08-27 14:15:51	2020-08-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	11624	delivery	5	36
127310	2020-08-27 14:19:43	2020-08-27	8	[{"id_menu":5,"count":1}]	48031	delivery	5	13
127311	2020-08-27 14:20:18	2020-08-27	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	44895	delivery	5	25
127312	2020-08-27 14:20:35	2020-08-27	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	34368	delivery	5	29
127313	2020-08-27 14:21:49	2020-08-27	8	[{"id_menu":5,"count":1}]	39780	pick-up	0	8
127314	2020-08-27 14:21:54	2020-08-27	12	[{"id_menu":3,"count":1}]	2713	delivery	5	17
127315	2020-08-27 14:25:41	2020-08-27	9	[{"id_menu":7,"count":1}]	46833	delivery	5	14
127316	2020-08-27 14:26:20	2020-08-27	8	[{"id_menu":5,"count":1}]	48129	pick-up	0	8
127317	2020-08-27 14:27:37	2020-08-27	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	2878	delivery	5	22
127318	2020-08-27 14:28:33	2020-08-27	12	[{"id_menu":1,"count":1}]	37084	pick-up	0	12
127319	2020-08-27 14:30:10	2020-08-27	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":3}]	48018	delivery	5	22
127320	2020-08-27 14:30:32	2020-08-27	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	48180	delivery	5	22
127321	2020-08-27 14:31:14	2020-08-27	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	48010	delivery	5	40
127322	2020-08-27 14:32:12	2020-08-27	12	[{"id_menu":3,"count":1}]	48118	delivery	5	17
127323	2020-08-27 14:32:30	2020-08-27	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	48085	delivery	5	30
127324	2020-08-27 14:32:43	2020-08-27	9	[{"id_menu":6,"count":1}]	10172	delivery	5	14
127325	2020-08-27 14:36:13	2020-08-27	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38970	delivery	5	40
127326	2020-08-27 14:36:16	2020-08-27	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	47604	delivery	5	26
127327	2020-08-27 14:37:10	2020-08-27	39	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6228	delivery	5	44
127328	2020-08-27 14:41:11	2020-08-27	14	[{"id_menu":2,"count":1}]	10755	pick-up	0	14
127329	2020-08-27 14:42:05	2020-08-27	12	[{"id_menu":3,"count":1}]	7588	delivery	5	17
127330	2020-08-27 14:43:29	2020-08-27	17	[{"id_menu":4,"count":1}]	28104	pick-up	0	17
127331	2020-08-27 14:43:44	2020-08-27	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	26868	delivery	5	45
127332	2020-08-27 14:50:41	2020-08-27	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	866	pick-up	0	26
127333	2020-08-27 14:56:48	2020-08-27	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	48062	delivery	5	36
127334	2020-08-27 14:57:58	2020-08-27	17	[{"id_menu":4,"count":1}]	48101	delivery	5	22
127335	2020-08-27 14:58:05	2020-08-27	14	[{"id_menu":2,"count":1}]	12327	delivery	5	19
127336	2020-08-27 14:58:35	2020-08-27	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	6366	delivery	5	44
127337	2020-08-27 14:59:50	2020-08-27	12	[{"id_menu":1,"count":1}]	20433	delivery	5	17
127338	2020-08-27 15:00:34	2020-08-27	14	[{"id_menu":2,"count":1}]	26044	delivery	5	19
127339	2020-08-27 15:03:26	2020-08-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	48058	delivery	5	36
127340	2020-08-27 15:06:17	2020-08-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	15385	pick-up	0	31
127341	2020-08-27 15:10:04	2020-08-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	26428	pick-up	0	23
127342	2020-08-27 15:10:19	2020-08-27	12	[{"id_menu":1,"count":1}]	30433	delivery	5	17
127343	2020-08-27 15:12:54	2020-08-27	8	[{"id_menu":5,"count":1}]	2228	pick-up	0	8
127344	2020-08-27 15:19:56	2020-08-27	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":2}]	48007	delivery	5	26
127345	2020-08-27 15:21:10	2020-08-27	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	7743	delivery	5	31
127346	2020-08-27 15:22:52	2020-08-27	9	[{"id_menu":7,"count":2}]	48142	delivery	5	14
127347	2020-08-27 15:27:59	2020-08-27	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	45853	delivery	5	43
127348	2020-08-27 15:34:06	2020-08-27	9	[{"id_menu":7,"count":1}]	48169	delivery	5	14
127349	2020-08-27 15:36:22	2020-08-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	10525	pick-up	0	23
127350	2020-08-27 15:37:24	2020-08-27	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11666	delivery	5	43
127351	2020-08-27 15:37:38	2020-08-27	9	[{"id_menu":6,"count":1}]	381	pick-up	0	9
127352	2020-08-27 15:43:50	2020-08-27	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	19776	pick-up	0	29
127353	2020-08-27 15:46:10	2020-08-27	9	[{"id_menu":6,"count":1}]	26782	delivery	5	14
127354	2020-08-27 15:47:14	2020-08-27	9	[{"id_menu":6,"count":1}]	48020	delivery	5	14
127355	2020-08-27 15:49:21	2020-08-27	12	[{"id_menu":1,"count":1}]	7821	delivery	5	17
127356	2020-08-27 15:50:56	2020-08-27	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	38074	delivery	5	28
127357	2020-08-27 15:53:24	2020-08-27	14	[{"id_menu":2,"count":1}]	27880	delivery	5	19
127358	2020-08-27 15:54:46	2020-08-27	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48072	delivery	5	49
127359	2020-08-27 15:56:31	2020-08-27	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	2702	pick-up	0	21
127360	2020-08-27 15:58:32	2020-08-27	14	[{"id_menu":2,"count":1}]	7158	delivery	5	19
127361	2020-08-27 15:59:36	2020-08-27	8	[{"id_menu":5,"count":2}]	38843	delivery	5	13
127362	2020-08-27 16:00:04	2020-08-27	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	48011	delivery	5	40
127363	2020-08-27 16:04:50	2020-08-27	8	[{"id_menu":5,"count":1}]	48100	delivery	5	13
127364	2020-08-27 16:06:16	2020-08-27	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7896	delivery	5	30
127365	2020-08-27 16:06:32	2020-08-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":3}]	33596	delivery	5	28
127366	2020-08-27 16:06:33	2020-08-27	17	[{"id_menu":4,"count":1}]	18491	delivery	5	22
127367	2020-08-27 16:08:20	2020-08-27	12	[{"id_menu":3,"count":1}]	3934	delivery	5	17
127368	2020-08-27 16:13:30	2020-08-27	12	[{"id_menu":1,"count":1}]	2954	pick-up	0	12
127369	2020-08-27 16:16:01	2020-08-27	14	[{"id_menu":2,"count":1}]	43587	delivery	5	19
127370	2020-08-27 16:16:44	2020-08-27	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	48016	delivery	5	38
127371	2020-08-27 16:17:11	2020-08-27	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	15236	delivery	5	26
127372	2020-08-27 16:17:46	2020-08-27	17	[{"id_menu":4,"count":1}]	47981	delivery	5	22
127373	2020-08-27 16:19:25	2020-08-27	9	[{"id_menu":6,"count":1}]	48121	delivery	5	14
127374	2020-08-27 16:20:55	2020-08-27	14	[{"id_menu":2,"count":1}]	13076	delivery	5	19
127375	2020-08-27 16:28:36	2020-08-27	9	[{"id_menu":6,"count":1}]	29995	delivery	5	14
127376	2020-08-27 16:31:54	2020-08-27	17	[{"id_menu":4,"count":1}]	38716	delivery	5	22
127377	2020-08-27 16:32:47	2020-08-27	12	[{"id_menu":3,"count":1}]	48026	pick-up	0	12
127378	2020-08-27 16:33:56	2020-08-27	9	[{"id_menu":7,"count":1}]	21235	delivery	5	14
127379	2020-08-27 16:36:21	2020-08-27	17	[{"id_menu":4,"count":1}]	47982	delivery	5	22
127380	2020-08-27 16:37:36	2020-08-27	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	26659	delivery	5	38
127381	2020-08-27 16:39:10	2020-08-27	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	40611	pick-up	0	23
127382	2020-08-27 16:42:22	2020-08-27	9	[{"id_menu":6,"count":1}]	8574	pick-up	0	9
127383	2020-08-27 16:44:12	2020-08-27	9	[{"id_menu":6,"count":1}]	36509	delivery	5	14
127384	2020-08-27 16:46:19	2020-08-27	12	[{"id_menu":3,"count":1}]	9531	pick-up	0	12
127385	2020-08-27 16:48:49	2020-08-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1445	delivery	5	23
127386	2020-08-27 16:59:34	2020-08-27	9	[{"id_menu":7,"count":1}]	29498	delivery	5	14
127387	2020-08-27 17:00:42	2020-08-27	14	[{"id_menu":2,"count":1}]	40419	delivery	5	19
127388	2020-08-27 17:04:24	2020-08-27	14	[{"id_menu":2,"count":1}]	1228	pick-up	0	14
127389	2020-08-27 17:05:06	2020-08-27	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	48049	delivery	5	31
127390	2020-08-27 17:09:21	2020-08-27	12	[{"id_menu":1,"count":1}]	18445	pick-up	0	12
127391	2020-08-27 17:12:04	2020-08-27	8	[{"id_menu":5,"count":1}]	21307	delivery	5	13
127392	2020-08-27 17:12:12	2020-08-27	9	[{"id_menu":7,"count":1}]	29088	delivery	5	14
127393	2020-08-27 17:14:50	2020-08-27	9	[{"id_menu":6,"count":1}]	39387	delivery	5	14
127394	2020-08-27 17:16:05	2020-08-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	48034	delivery	5	36
127395	2020-08-27 17:16:42	2020-08-27	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	16834	delivery	5	45
127396	2020-08-27 17:17:30	2020-08-27	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3181	delivery	5	39
127397	2020-08-27 17:19:24	2020-08-27	8	[{"id_menu":5,"count":2}]	45623	pick-up	0	8
127398	2020-08-27 17:19:40	2020-08-27	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	48110	delivery	5	31
127399	2020-08-27 17:23:54	2020-08-27	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36021	pick-up	0	32
127400	2020-08-27 17:25:12	2020-08-27	9	[{"id_menu":7,"count":3}]	48019	delivery	5	14
127401	2020-08-27 17:25:16	2020-08-27	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	8543	pick-up	0	26
127402	2020-08-27 17:27:01	2020-08-27	9	[{"id_menu":6,"count":2}]	12519	delivery	5	14
127403	2020-08-27 17:27:03	2020-08-27	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	6439	delivery	5	27
127404	2020-08-27 17:28:42	2020-08-27	9	[{"id_menu":6,"count":1}]	48094	delivery	5	14
127405	2020-08-27 17:29:09	2020-08-27	9	[{"id_menu":6,"count":1}]	48164	delivery	5	14
127406	2020-08-27 17:29:44	2020-08-27	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48132	delivery	5	40
127407	2020-08-27 17:31:18	2020-08-27	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	4459	delivery	5	27
127408	2020-08-27 17:35:05	2020-08-27	9	[{"id_menu":6,"count":1}]	1076	pick-up	0	9
127409	2020-08-27 17:38:32	2020-08-27	14	[{"id_menu":2,"count":1}]	48150	delivery	5	19
127410	2020-08-27 17:38:47	2020-08-27	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	26477	delivery	5	22
127411	2020-08-27 17:41:33	2020-08-27	9	[{"id_menu":6,"count":2}]	48096	delivery	5	14
127412	2020-08-27 17:42:26	2020-08-27	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	43655	delivery	5	28
127413	2020-08-27 17:43:01	2020-08-27	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	26909	delivery	5	40
127414	2020-08-27 17:44:57	2020-08-27	9	[{"id_menu":7,"count":2}]	31987	delivery	5	14
127415	2020-08-27 17:45:38	2020-08-27	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	48091	delivery	5	43
127416	2020-08-27 17:46:01	2020-08-27	12	[{"id_menu":3,"count":1}]	27209	pick-up	0	12
127417	2020-08-27 17:46:37	2020-08-27	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	48057	delivery	5	27
127418	2020-08-27 17:48:15	2020-08-27	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	27625	delivery	5	26
127419	2020-08-27 17:48:19	2020-08-27	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	48086	delivery	5	38
127420	2020-08-27 17:54:30	2020-08-27	12	[{"id_menu":1,"count":1}]	44321	delivery	5	17
127421	2020-08-27 17:54:36	2020-08-27	14	[{"id_menu":2,"count":1}]	26631	delivery	5	19
127422	2020-08-27 17:54:57	2020-08-27	9	[{"id_menu":7,"count":1}]	48067	delivery	5	14
127423	2020-08-27 17:55:19	2020-08-27	8	[{"id_menu":5,"count":2}]	48021	delivery	5	13
127424	2020-08-27 17:58:35	2020-08-27	8	[{"id_menu":5,"count":1}]	38541	delivery	5	13
127425	2020-08-27 17:58:38	2020-08-27	8	[{"id_menu":5,"count":1}]	29878	delivery	5	13
127426	2020-08-27 18:00:13	2020-08-27	9	[{"id_menu":7,"count":1}]	11898	pick-up	0	9
127427	2020-08-27 18:00:33	2020-08-27	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28880	delivery	5	22
127428	2020-08-27 18:04:13	2020-08-27	9	[{"id_menu":6,"count":1}]	48066	delivery	5	14
127429	2020-08-27 18:09:07	2020-08-27	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	47697	delivery	5	34
127430	2020-08-27 18:10:50	2020-08-27	9	[{"id_menu":6,"count":1}]	17511	delivery	5	14
127431	2020-08-27 18:16:21	2020-08-27	9	[{"id_menu":7,"count":1}]	32288	delivery	5	14
127432	2020-08-27 18:20:40	2020-08-27	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	43768	delivery	5	25
127433	2020-08-27 18:28:48	2020-08-27	12	[{"id_menu":1,"count":1}]	6062	pick-up	0	12
127434	2020-08-27 18:31:24	2020-08-27	14	[{"id_menu":2,"count":2}]	34202	delivery	5	19
127435	2020-08-27 18:35:07	2020-08-27	9	[{"id_menu":6,"count":1}]	16043	delivery	5	14
127436	2020-08-27 18:35:57	2020-08-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	26065	pick-up	0	23
127437	2020-08-27 18:41:08	2020-08-27	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11402	delivery	5	43
127438	2020-08-27 18:43:14	2020-08-27	9	[{"id_menu":7,"count":1}]	47978	delivery	5	14
127439	2020-08-27 18:46:44	2020-08-27	9	[{"id_menu":7,"count":1}]	42151	delivery	5	14
127440	2020-08-27 18:47:40	2020-08-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	41274	delivery	5	36
127441	2020-08-27 18:47:48	2020-08-27	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	17825	delivery	5	31
127442	2020-08-27 18:49:10	2020-08-27	9	[{"id_menu":7,"count":1}]	344	delivery	5	14
127443	2020-08-27 18:49:25	2020-08-27	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	6591	pick-up	0	29
127444	2020-08-27 18:53:14	2020-08-27	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	830	pick-up	0	26
127445	2020-08-27 18:54:46	2020-08-27	17	[{"id_menu":4,"count":1}]	2694	delivery	5	22
127446	2020-08-27 18:54:48	2020-08-27	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1433	delivery	5	40
127447	2020-08-27 18:57:08	2020-08-27	12	[{"id_menu":3,"count":1}]	21222	delivery	5	17
127448	2020-08-27 18:58:57	2020-08-27	14	[{"id_menu":2,"count":2}]	20161	delivery	5	19
127449	2020-08-27 19:05:15	2020-08-27	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	68	pick-up	0	26
127450	2020-08-27 19:06:13	2020-08-27	9	[{"id_menu":7,"count":1}]	31499	delivery	5	14
127451	2020-08-27 19:07:33	2020-08-27	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	43971	delivery	5	28
127452	2020-08-27 19:08:16	2020-08-27	12	[{"id_menu":3,"count":1}]	47087	delivery	5	17
127453	2020-08-27 19:11:30	2020-08-27	12	[{"id_menu":1,"count":1}]	24324	delivery	5	17
127454	2020-08-27 19:11:44	2020-08-27	9	[{"id_menu":7,"count":1}]	46478	delivery	5	14
127455	2020-08-27 19:17:41	2020-08-27	9	[{"id_menu":7,"count":1}]	6514	delivery	5	14
127456	2020-08-27 19:17:44	2020-08-27	9	[{"id_menu":7,"count":1}]	47969	delivery	5	14
127457	2020-08-27 19:17:56	2020-08-27	14	[{"id_menu":2,"count":1}]	2081	delivery	5	19
127458	2020-08-27 19:18:23	2020-08-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	21	delivery	5	28
127459	2020-08-27 19:18:39	2020-08-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	32097	pick-up	0	31
127460	2020-08-27 19:19:57	2020-08-27	12	[{"id_menu":1,"count":1}]	14587	delivery	5	17
127461	2020-08-27 19:22:40	2020-08-27	8	[{"id_menu":5,"count":1}]	48117	delivery	5	13
127462	2020-08-27 19:24:14	2020-08-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11550	delivery	5	22
127463	2020-08-27 19:24:51	2020-08-27	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	42089	delivery	5	31
127464	2020-08-27 19:24:52	2020-08-27	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	18676	delivery	5	31
127465	2020-08-27 19:25:01	2020-08-27	9	[{"id_menu":6,"count":1}]	35115	delivery	5	14
127466	2020-08-27 19:25:13	2020-08-27	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4197	pick-up	0	37
127467	2020-08-27 19:25:38	2020-08-27	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	41898	delivery	5	31
127468	2020-08-27 19:27:43	2020-08-27	8	[{"id_menu":5,"count":1}]	45994	delivery	5	13
127469	2020-08-27 19:29:12	2020-08-27	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	23128	delivery	5	29
127470	2020-08-27 19:29:38	2020-08-27	12	[{"id_menu":3,"count":1}]	26476	delivery	5	17
127471	2020-08-27 19:29:46	2020-08-27	17	[{"id_menu":4,"count":1}]	48136	delivery	5	22
127472	2020-08-27 19:32:37	2020-08-27	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	8631	delivery	5	23
127473	2020-08-27 19:33:21	2020-08-27	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	25214	pick-up	0	29
127474	2020-08-27 19:34:37	2020-08-27	9	[{"id_menu":7,"count":1}]	38156	delivery	5	14
127475	2020-08-27 19:36:43	2020-08-27	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	48035	pick-up	0	22
127476	2020-08-27 19:37:08	2020-08-27	8	[{"id_menu":5,"count":1}]	48161	delivery	5	13
127477	2020-08-27 19:39:07	2020-08-27	12	[{"id_menu":3,"count":3}]	16644	delivery	5	17
127478	2020-08-27 19:39:38	2020-08-27	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	39579	pick-up	0	20
127479	2020-08-27 19:42:04	2020-08-27	9	[{"id_menu":6,"count":3}]	42943	delivery	5	14
127480	2020-08-27 19:43:17	2020-08-27	9	[{"id_menu":7,"count":1}]	48175	delivery	5	14
127481	2020-08-27 19:43:20	2020-08-27	8	[{"id_menu":5,"count":1}]	15407	delivery	5	13
127482	2020-08-27 19:44:37	2020-08-27	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	29814	delivery	5	36
127483	2020-08-27 19:47:23	2020-08-27	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	21511	delivery	5	40
127484	2020-08-27 19:48:44	2020-08-27	8	[{"id_menu":5,"count":1}]	48082	delivery	5	13
127485	2020-08-27 19:51:36	2020-08-27	14	[{"id_menu":2,"count":1}]	34644	delivery	5	19
127486	2020-08-27 19:52:16	2020-08-27	12	[{"id_menu":3,"count":1}]	37109	delivery	5	17
127487	2020-08-27 19:58:08	2020-08-27	8	[{"id_menu":5,"count":1}]	8305	delivery	5	13
127488	2020-08-27 19:59:16	2020-08-27	9	[{"id_menu":6,"count":1}]	43853	delivery	5	14
127489	2020-08-27 20:02:00	2020-08-27	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	48022	delivery	5	34
127490	2020-08-27 20:05:07	2020-08-27	17	[{"id_menu":4,"count":1}]	48014	delivery	5	22
127491	2020-08-27 20:06:13	2020-08-27	21	[{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	28930	delivery	5	26
127492	2020-08-27 20:06:16	2020-08-27	14	[{"id_menu":2,"count":2}]	34463	delivery	5	19
127493	2020-08-27 20:08:23	2020-08-27	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	29423	pick-up	0	26
127494	2020-08-27 20:09:38	2020-08-27	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24409	delivery	5	39
127495	2020-08-27 20:10:32	2020-08-27	8	[{"id_menu":5,"count":1}]	32448	delivery	5	13
127496	2020-08-27 20:16:57	2020-08-27	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	48156	delivery	5	25
127497	2020-08-27 20:18:18	2020-08-27	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25688	delivery	5	46
127498	2020-08-27 20:19:28	2020-08-27	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	25509	delivery	5	22
127499	2020-08-27 20:19:47	2020-08-27	12	[{"id_menu":1,"count":1}]	11921	delivery	5	17
127500	2020-08-27 20:26:53	2020-08-27	17	[{"id_menu":4,"count":1}]	26449	pick-up	0	17
127501	2020-08-27 20:29:17	2020-08-27	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	45012	pick-up	0	20
127502	2020-08-27 20:31:04	2020-08-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3711	pick-up	0	18
127503	2020-08-27 20:36:25	2020-08-27	9	[{"id_menu":6,"count":1}]	48176	delivery	5	14
127504	2020-08-27 20:39:53	2020-08-27	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	5094	delivery	5	26
127505	2020-08-27 20:40:46	2020-08-27	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	48056	delivery	5	31
127506	2020-08-27 20:43:38	2020-08-27	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	4607	delivery	5	26
127507	2020-08-27 20:46:27	2020-08-27	17	[{"id_menu":4,"count":1}]	4644	pick-up	0	17
127508	2020-08-27 20:47:12	2020-08-27	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	46088	delivery	5	26
127509	2020-08-27 20:52:27	2020-08-27	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	9550	delivery	5	23
127510	2020-08-27 20:54:30	2020-08-27	17	[{"id_menu":4,"count":1}]	9252	pick-up	0	17
127511	2020-08-27 20:54:51	2020-08-27	12	[{"id_menu":1,"count":1}]	1344	pick-up	0	12
127512	2020-08-27 20:57:04	2020-08-27	12	[{"id_menu":1,"count":1}]	1257	delivery	5	17
127513	2020-08-27 20:57:08	2020-08-27	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	757	pick-up	0	38
127514	2020-08-27 20:58:44	2020-08-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8487	delivery	5	22
127515	2020-08-27 20:59:08	2020-08-27	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	48126	delivery	5	36
127516	2020-08-27 20:59:18	2020-08-27	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	42167	delivery	5	31
127517	2020-08-27 21:00:19	2020-08-27	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	35510	delivery	5	37
127518	2020-08-27 21:01:41	2020-08-27	12	[{"id_menu":3,"count":1}]	48017	delivery	5	17
127519	2020-08-27 21:07:17	2020-08-27	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	43081	delivery	5	34
127520	2020-08-27 21:10:25	2020-08-27	9	[{"id_menu":6,"count":1}]	34101	delivery	5	14
127521	2020-08-27 21:10:26	2020-08-27	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	48047	delivery	5	30
127522	2020-08-27 21:11:31	2020-08-27	12	[{"id_menu":1,"count":1}]	29367	delivery	5	17
127523	2020-08-27 21:12:14	2020-08-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	48109	delivery	5	22
127524	2020-08-27 21:12:26	2020-08-27	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	9757	delivery	5	22
127525	2020-08-27 21:15:12	2020-08-27	17	[{"id_menu":4,"count":1}]	34842	delivery	5	22
127526	2020-08-27 21:15:22	2020-08-27	9	[{"id_menu":7,"count":1}]	6237	delivery	5	14
127527	2020-08-27 21:19:07	2020-08-27	12	[{"id_menu":1,"count":1}]	2078	delivery	5	17
127528	2020-08-27 21:19:22	2020-08-27	12	[{"id_menu":1,"count":1}]	3077	pick-up	0	12
127529	2020-08-27 21:20:22	2020-08-27	9	[{"id_menu":7,"count":2}]	47491	delivery	5	14
127530	2020-08-27 21:20:50	2020-08-27	9	[{"id_menu":6,"count":1}]	45263	delivery	5	14
127531	2020-08-27 21:23:59	2020-08-27	12	[{"id_menu":3,"count":1}]	11296	delivery	5	17
127532	2020-08-27 21:25:37	2020-08-27	8	[{"id_menu":5,"count":1}]	48088	delivery	5	13
127533	2020-08-27 21:28:00	2020-08-27	12	[{"id_menu":1,"count":1}]	38100	delivery	5	17
127534	2020-08-27 21:28:26	2020-08-27	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23493	delivery	5	22
127535	2020-08-27 21:29:33	2020-08-27	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	48146	delivery	5	39
127536	2020-08-27 21:29:42	2020-08-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	45651	delivery	5	28
127537	2020-08-27 21:30:09	2020-08-27	14	[{"id_menu":2,"count":1}]	18426	delivery	5	19
127538	2020-08-27 21:35:54	2020-08-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	48055	pick-up	0	23
127539	2020-08-27 21:42:48	2020-08-27	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	47963	delivery	5	43
127540	2020-08-27 21:44:19	2020-08-27	12	[{"id_menu":3,"count":1}]	29222	delivery	5	17
127541	2020-08-27 21:45:48	2020-08-27	9	[{"id_menu":6,"count":1}]	24724	delivery	5	14
127542	2020-08-27 21:49:13	2020-08-27	8	[{"id_menu":5,"count":1}]	39822	delivery	5	13
127543	2020-08-27 21:52:06	2020-08-27	8	[{"id_menu":5,"count":1}]	48138	delivery	5	13
127544	2020-08-27 21:58:25	2020-08-27	9	[{"id_menu":7,"count":1}]	5558	delivery	5	14
127545	2020-08-27 22:02:12	2020-08-27	9	[{"id_menu":6,"count":1}]	48167	delivery	5	14
127546	2020-08-27 22:05:39	2020-08-27	9	[{"id_menu":7,"count":1}]	22962	delivery	5	14
127547	2020-08-27 22:07:01	2020-08-27	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	37754	delivery	5	31
127548	2020-08-27 22:07:54	2020-08-27	14	[{"id_menu":2,"count":1}]	3766	delivery	5	19
127549	2020-08-27 22:08:16	2020-08-27	9	[{"id_menu":7,"count":1}]	20628	pick-up	0	9
127550	2020-08-27 22:09:38	2020-08-27	9	[{"id_menu":6,"count":1}]	26270	delivery	5	14
127551	2020-08-27 22:10:31	2020-08-27	17	[{"id_menu":4,"count":1}]	10470	pick-up	0	17
127552	2020-08-27 22:14:53	2020-08-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48106	delivery	5	23
127553	2020-08-27 22:16:50	2020-08-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	15653	delivery	5	28
127554	2020-08-27 22:17:27	2020-08-27	12	[{"id_menu":3,"count":2}]	46493	pick-up	0	12
127555	2020-08-27 22:18:25	2020-08-27	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	44261	delivery	5	29
127556	2020-08-27 22:20:52	2020-08-27	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	48155	delivery	5	28
127557	2020-08-27 22:21:19	2020-08-27	8	[{"id_menu":5,"count":1}]	21170	delivery	5	13
127558	2020-08-27 22:22:46	2020-08-27	8	[{"id_menu":5,"count":1}]	31566	delivery	5	13
127559	2020-08-27 22:24:34	2020-08-27	14	[{"id_menu":2,"count":1}]	19054	delivery	5	19
127560	2020-08-27 22:26:16	2020-08-27	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	26580	delivery	5	34
127561	2020-08-27 22:29:55	2020-08-27	12	[{"id_menu":3,"count":1}]	33451	delivery	5	17
127562	2020-08-27 22:32:35	2020-08-27	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29919	delivery	5	43
127563	2020-08-27 22:33:24	2020-08-27	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	15067	pick-up	0	26
127564	2020-08-27 22:33:39	2020-08-27	14	[{"id_menu":2,"count":1}]	48095	delivery	5	19
127565	2020-08-27 22:35:44	2020-08-27	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41206	delivery	5	37
127566	2020-08-27 22:38:09	2020-08-27	9	[{"id_menu":7,"count":1}]	40892	delivery	5	14
127567	2020-08-27 22:43:05	2020-08-27	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	47475	delivery	5	43
127568	2020-08-27 22:45:51	2020-08-27	8	[{"id_menu":5,"count":1}]	48179	pick-up	0	8
127569	2020-08-27 22:46:48	2020-08-27	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	28503	delivery	5	40
127570	2020-08-27 22:47:44	2020-08-27	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	46459	delivery	5	26
127571	2020-08-27 22:50:14	2020-08-27	12	[{"id_menu":3,"count":1}]	8666	pick-up	0	12
127572	2020-08-27 22:52:00	2020-08-27	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	48002	delivery	5	39
127573	2020-08-27 22:56:34	2020-08-27	14	[{"id_menu":2,"count":1}]	44845	delivery	5	19
127574	2020-08-27 23:02:17	2020-08-27	9	[{"id_menu":7,"count":2}]	11766	delivery	5	14
127575	2020-08-27 23:04:42	2020-08-27	12	[{"id_menu":3,"count":1}]	23424	delivery	5	17
127576	2020-08-27 23:07:35	2020-08-27	14	[{"id_menu":2,"count":1}]	17470	pick-up	0	14
127577	2020-08-27 23:08:03	2020-08-27	9	[{"id_menu":6,"count":1}]	48149	delivery	5	14
127578	2020-08-27 23:12:18	2020-08-27	12	[{"id_menu":1,"count":1}]	15961	pick-up	0	12
127579	2020-08-27 23:14:02	2020-08-27	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	47984	delivery	5	23
127580	2020-08-27 23:14:35	2020-08-27	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32620	delivery	5	34
127581	2020-08-27 23:16:09	2020-08-27	14	[{"id_menu":2,"count":1}]	3052	delivery	5	19
127582	2020-08-27 23:16:36	2020-08-27	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	32622	delivery	5	23
127583	2020-08-27 23:16:43	2020-08-27	9	[{"id_menu":7,"count":1}]	13654	delivery	5	14
127584	2020-08-27 23:19:10	2020-08-27	9	[{"id_menu":7,"count":1}]	48008	delivery	5	14
127585	2020-08-27 23:21:38	2020-08-27	9	[{"id_menu":7,"count":1}]	14479	delivery	5	14
127586	2020-08-27 23:23:22	2020-08-27	8	[{"id_menu":5,"count":1}]	232	pick-up	0	8
127587	2020-08-27 23:24:32	2020-08-27	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32897	pick-up	0	31
127588	2020-08-27 23:24:37	2020-08-27	12	[{"id_menu":1,"count":1}]	45151	pick-up	0	12
127589	2020-08-27 23:24:38	2020-08-27	9	[{"id_menu":6,"count":1}]	48039	delivery	5	14
127590	2020-08-27 23:24:48	2020-08-27	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	17788	pick-up	0	26
127591	2020-08-27 23:25:02	2020-08-27	14	[{"id_menu":2,"count":1}]	48152	delivery	5	19
127592	2020-08-27 23:27:41	2020-08-27	8	[{"id_menu":5,"count":2}]	21290	pick-up	0	8
127593	2020-08-27 23:30:52	2020-08-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	47972	delivery	5	23
127594	2020-08-27 23:31:07	2020-08-27	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	11334	pick-up	0	29
127595	2020-08-27 23:31:10	2020-08-27	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	48131	delivery	5	36
127596	2020-08-27 23:33:49	2020-08-27	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48084	delivery	5	37
127597	2020-08-27 23:36:53	2020-08-27	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	32300	delivery	5	42
127598	2020-08-27 23:36:58	2020-08-27	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	11759	delivery	5	48
127599	2020-08-27 23:39:27	2020-08-27	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33789	delivery	5	23
127600	2020-08-27 23:42:26	2020-08-27	9	[{"id_menu":6,"count":1}]	21238	delivery	5	14
127601	2020-08-27 23:43:08	2020-08-27	14	[{"id_menu":2,"count":1}]	23696	pick-up	0	14
127602	2020-08-27 23:44:35	2020-08-27	8	[{"id_menu":5,"count":1}]	33302	delivery	5	13
127603	2020-08-27 23:45:52	2020-08-27	9	[{"id_menu":7,"count":1}]	16660	delivery	5	14
127604	2020-08-27 23:45:54	2020-08-27	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	44798	delivery	5	22
127605	2020-08-27 23:48:44	2020-08-27	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	30903	delivery	5	39
127606	2020-08-27 23:48:54	2020-08-27	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	21121	pick-up	0	26
127607	2020-08-27 23:56:57	2020-08-27	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	32128	delivery	5	29
127608	2020-08-27 23:57:06	2020-08-27	17	[{"id_menu":4,"count":1}]	30935	delivery	5	22
127609	2020-08-27 23:57:44	2020-08-27	14	[{"id_menu":2,"count":1}]	47970	delivery	5	19
127610	2020-08-27 23:59:12	2020-08-27	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	35350	pick-up	0	17
127611	2020-08-28 00:01:05	2020-08-28	8	[{"id_menu":5,"count":1}]	6410	pick-up	0	8
127612	2020-08-28 00:01:17	2020-08-28	14	[{"id_menu":2,"count":1}]	2279	pick-up	0	14
127613	2020-08-28 00:01:23	2020-08-28	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15834	delivery	5	34
127614	2020-08-28 00:04:27	2020-08-28	14	[{"id_menu":2,"count":1}]	4075	pick-up	0	14
127615	2020-08-28 00:05:54	2020-08-28	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	48285	delivery	5	26
127616	2020-08-28 00:07:06	2020-08-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22738	delivery	5	22
127617	2020-08-28 00:07:09	2020-08-28	9	[{"id_menu":6,"count":1}]	48333	delivery	5	14
127618	2020-08-28 00:09:45	2020-08-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	43245	pick-up	0	26
127619	2020-08-28 00:12:17	2020-08-28	12	[{"id_menu":1,"count":1}]	48321	delivery	5	17
127620	2020-08-28 00:13:17	2020-08-28	14	[{"id_menu":2,"count":1}]	3822	pick-up	0	14
127621	2020-08-28 00:13:55	2020-08-28	9	[{"id_menu":7,"count":1}]	48407	delivery	5	14
127622	2020-08-28 00:17:05	2020-08-28	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	48383	delivery	5	34
127623	2020-08-28 00:29:08	2020-08-28	12	[{"id_menu":3,"count":1}]	48292	pick-up	0	12
127624	2020-08-28 00:32:19	2020-08-28	12	[{"id_menu":3,"count":1}]	6776	delivery	5	17
127625	2020-08-28 00:33:21	2020-08-28	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	48189	delivery	5	26
127626	2020-08-28 00:33:49	2020-08-28	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	7412	delivery	5	39
127627	2020-08-28 00:35:12	2020-08-28	9	[{"id_menu":7,"count":1}]	48204	delivery	5	14
127628	2020-08-28 00:39:34	2020-08-28	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	47812	delivery	5	37
127629	2020-08-28 00:42:48	2020-08-28	12	[{"id_menu":1,"count":1}]	11485	delivery	5	17
127630	2020-08-28 00:48:07	2020-08-28	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	48342	delivery	5	46
127631	2020-08-28 00:48:42	2020-08-28	14	[{"id_menu":2,"count":1}]	3191	pick-up	0	14
127632	2020-08-28 00:49:49	2020-08-28	8	[{"id_menu":5,"count":1}]	6986	delivery	5	13
127633	2020-08-28 00:50:47	2020-08-28	17	[{"id_menu":4,"count":1}]	7259	delivery	5	22
127634	2020-08-28 00:54:52	2020-08-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	22395	delivery	5	28
127635	2020-08-28 00:55:44	2020-08-28	9	[{"id_menu":7,"count":1}]	4628	delivery	5	14
127636	2020-08-28 00:56:20	2020-08-28	9	[{"id_menu":6,"count":1}]	48369	delivery	5	14
127637	2020-08-28 00:56:38	2020-08-28	9	[{"id_menu":6,"count":1}]	2713	pick-up	0	9
127638	2020-08-28 00:58:02	2020-08-28	14	[{"id_menu":2,"count":1}]	33266	pick-up	0	14
127639	2020-08-28 01:02:01	2020-08-28	9	[{"id_menu":6,"count":1}]	48408	pick-up	0	9
127640	2020-08-28 01:02:54	2020-08-28	17	[{"id_menu":4,"count":1}]	18094	delivery	5	22
127641	2020-08-28 01:05:58	2020-08-28	9	[{"id_menu":7,"count":1}]	2450	pick-up	0	9
127642	2020-08-28 01:06:27	2020-08-28	8	[{"id_menu":5,"count":1}]	5970	pick-up	0	8
127643	2020-08-28 01:06:55	2020-08-28	9	[{"id_menu":7,"count":1}]	48261	delivery	5	14
127644	2020-08-28 01:12:26	2020-08-28	14	[{"id_menu":2,"count":1}]	12183	pick-up	0	14
127645	2020-08-28 01:13:58	2020-08-28	9	[{"id_menu":6,"count":1}]	40963	pick-up	0	9
127646	2020-08-28 01:15:23	2020-08-28	17	[{"id_menu":4,"count":1}]	10331	pick-up	0	17
127647	2020-08-28 01:15:42	2020-08-28	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8788	delivery	5	39
127648	2020-08-28 01:17:36	2020-08-28	14	[{"id_menu":2,"count":1}]	45410	delivery	5	19
127649	2020-08-28 01:18:28	2020-08-28	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23386	delivery	5	37
127650	2020-08-28 01:21:15	2020-08-28	14	[{"id_menu":2,"count":1}]	1922	pick-up	0	14
127651	2020-08-28 01:23:48	2020-08-28	17	[{"id_menu":4,"count":1}]	48329	delivery	5	22
127652	2020-08-28 01:26:41	2020-08-28	9	[{"id_menu":6,"count":2}]	48265	delivery	5	14
127653	2020-08-28 01:37:43	2020-08-28	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17055	delivery	5	35
127654	2020-08-28 01:39:07	2020-08-28	17	[{"id_menu":4,"count":1}]	38037	delivery	5	22
127655	2020-08-28 01:40:17	2020-08-28	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	48276	pick-up	0	31
127656	2020-08-28 01:41:15	2020-08-28	9	[{"id_menu":7,"count":1}]	45719	delivery	5	14
127657	2020-08-28 01:44:12	2020-08-28	9	[{"id_menu":7,"count":1}]	24758	delivery	5	14
127658	2020-08-28 01:46:12	2020-08-28	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	48385	delivery	5	26
127659	2020-08-28 01:47:47	2020-08-28	9	[{"id_menu":6,"count":1}]	26023	delivery	5	14
127660	2020-08-28 01:52:53	2020-08-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	43725	delivery	5	22
127661	2020-08-28 01:54:46	2020-08-28	9	[{"id_menu":7,"count":1}]	33575	delivery	5	14
127662	2020-08-28 01:56:00	2020-08-28	9	[{"id_menu":6,"count":1}]	12748	pick-up	0	9
127663	2020-08-28 01:57:34	2020-08-28	9	[{"id_menu":7,"count":1}]	48049	delivery	5	14
127664	2020-08-28 01:58:33	2020-08-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	48191	pick-up	0	26
127665	2020-08-28 01:59:15	2020-08-28	14	[{"id_menu":2,"count":2}]	19144	pick-up	0	14
127666	2020-08-28 02:02:34	2020-08-28	17	[{"id_menu":4,"count":1}]	46426	delivery	5	22
127667	2020-08-28 02:08:56	2020-08-28	26	[{"id_menu":4,"count":3},{"id_menu":7,"count":1}]	13469	delivery	5	31
127668	2020-08-28 02:11:53	2020-08-28	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	44094	delivery	5	39
127669	2020-08-28 02:13:31	2020-08-28	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	1176	pick-up	0	24
127670	2020-08-28 02:13:36	2020-08-28	8	[{"id_menu":5,"count":1}]	44281	pick-up	0	8
127671	2020-08-28 02:15:23	2020-08-28	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	46545	delivery	5	40
127672	2020-08-28 02:24:27	2020-08-28	17	[{"id_menu":4,"count":1}]	6994	delivery	5	22
127673	2020-08-28 02:25:25	2020-08-28	17	[{"id_menu":4,"count":1}]	48237	delivery	5	22
127674	2020-08-28 02:27:07	2020-08-28	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	47497	delivery	5	31
127675	2020-08-28 02:28:44	2020-08-28	9	[{"id_menu":7,"count":1}]	48214	delivery	5	14
127676	2020-08-28 02:30:28	2020-08-28	14	[{"id_menu":2,"count":1}]	27001	pick-up	0	14
127677	2020-08-28 02:32:43	2020-08-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	48438	pick-up	0	26
127678	2020-08-28 02:34:08	2020-08-28	14	[{"id_menu":2,"count":1}]	2197	delivery	5	19
127679	2020-08-28 02:37:24	2020-08-28	9	[{"id_menu":7,"count":1}]	1956	pick-up	0	9
127680	2020-08-28 02:37:55	2020-08-28	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	11438	delivery	5	28
127681	2020-08-28 02:38:57	2020-08-28	9	[{"id_menu":6,"count":1}]	10402	delivery	5	14
127682	2020-08-28 02:39:22	2020-08-28	9	[{"id_menu":7,"count":1}]	2715	delivery	5	14
127683	2020-08-28 02:39:26	2020-08-28	8	[{"id_menu":5,"count":1}]	25859	delivery	5	13
127684	2020-08-28 02:45:09	2020-08-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17652	delivery	5	23
127685	2020-08-28 02:45:24	2020-08-28	17	[{"id_menu":4,"count":1}]	48409	pick-up	0	17
127686	2020-08-28 02:45:58	2020-08-28	12	[{"id_menu":1,"count":1}]	10159	delivery	5	17
127687	2020-08-28 02:49:03	2020-08-28	8	[{"id_menu":5,"count":1}]	211	pick-up	0	8
127688	2020-08-28 02:52:32	2020-08-28	14	[{"id_menu":2,"count":1}]	3512	pick-up	0	14
127689	2020-08-28 02:53:10	2020-08-28	9	[{"id_menu":6,"count":1}]	30002	delivery	5	14
127690	2020-08-28 02:54:01	2020-08-28	9	[{"id_menu":7,"count":1}]	35890	delivery	5	14
127691	2020-08-28 02:54:13	2020-08-28	17	[{"id_menu":4,"count":1}]	35029	delivery	5	22
127692	2020-08-28 02:57:03	2020-08-28	14	[{"id_menu":2,"count":1}]	1241	delivery	5	19
127693	2020-08-28 02:59:02	2020-08-28	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48198	delivery	5	31
127694	2020-08-28 03:04:29	2020-08-28	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	16796	delivery	5	26
127695	2020-08-28 03:07:12	2020-08-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8285	pick-up	0	26
127696	2020-08-28 03:08:50	2020-08-28	17	[{"id_menu":4,"count":1}]	44048	delivery	5	22
127697	2020-08-28 03:09:50	2020-08-28	9	[{"id_menu":7,"count":1}]	31783	delivery	5	14
127698	2020-08-28 03:10:39	2020-08-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	48439	delivery	5	22
127699	2020-08-28 03:14:58	2020-08-28	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	23313	delivery	5	39
127700	2020-08-28 03:16:03	2020-08-28	17	[{"id_menu":4,"count":1}]	48392	pick-up	0	17
127701	2020-08-28 03:18:00	2020-08-28	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	48254	delivery	5	39
127702	2020-08-28 03:27:05	2020-08-28	8	[{"id_menu":5,"count":1}]	3494	pick-up	0	8
127703	2020-08-28 03:27:41	2020-08-28	9	[{"id_menu":6,"count":1}]	17830	delivery	5	14
127704	2020-08-28 03:28:27	2020-08-28	17	[{"id_menu":4,"count":1}]	48203	delivery	5	22
127705	2020-08-28 03:28:34	2020-08-28	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	10147	pick-up	0	17
127706	2020-08-28 03:30:10	2020-08-28	8	[{"id_menu":5,"count":1}]	31160	pick-up	0	8
127707	2020-08-28 03:31:55	2020-08-28	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	5387	pick-up	0	31
127708	2020-08-28 03:33:37	2020-08-28	9	[{"id_menu":7,"count":2}]	5115	delivery	5	14
127709	2020-08-28 03:33:48	2020-08-28	12	[{"id_menu":1,"count":1}]	4590	delivery	5	17
127710	2020-08-28 03:38:46	2020-08-28	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	10765	delivery	5	28
127711	2020-08-28 03:39:52	2020-08-28	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36922	delivery	5	40
127712	2020-08-28 03:41:14	2020-08-28	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2560	delivery	5	39
127713	2020-08-28 03:45:20	2020-08-28	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	48384	delivery	5	22
127714	2020-08-28 03:45:30	2020-08-28	9	[{"id_menu":6,"count":1}]	48297	pick-up	0	9
127715	2020-08-28 03:48:58	2020-08-28	9	[{"id_menu":7,"count":1}]	48251	delivery	5	14
127716	2020-08-28 03:51:29	2020-08-28	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	1896	pick-up	0	22
127717	2020-08-28 03:54:22	2020-08-28	9	[{"id_menu":6,"count":1}]	3000	delivery	5	14
127718	2020-08-28 03:54:24	2020-08-28	12	[{"id_menu":1,"count":1}]	48402	delivery	5	17
127719	2020-08-28 03:55:15	2020-08-28	12	[{"id_menu":3,"count":1}]	40609	delivery	5	17
127720	2020-08-28 03:55:51	2020-08-28	12	[{"id_menu":1,"count":1}]	7347	delivery	5	17
127721	2020-08-28 03:56:43	2020-08-28	12	[{"id_menu":3,"count":1}]	31702	delivery	5	17
127722	2020-08-28 03:58:25	2020-08-28	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	40576	delivery	5	28
127723	2020-08-28 03:58:57	2020-08-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16468	delivery	5	23
127724	2020-08-28 03:59:43	2020-08-28	12	[{"id_menu":1,"count":1}]	14375	delivery	5	17
127725	2020-08-28 04:01:36	2020-08-28	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	48340	delivery	5	56
127726	2020-08-28 04:02:49	2020-08-28	12	[{"id_menu":1,"count":1}]	37764	pick-up	0	12
127727	2020-08-28 04:04:44	2020-08-28	12	[{"id_menu":1,"count":1}]	31214	pick-up	0	12
127728	2020-08-28 04:05:15	2020-08-28	12	[{"id_menu":1,"count":1}]	832	delivery	5	17
127729	2020-08-28 04:05:16	2020-08-28	9	[{"id_menu":6,"count":1}]	643	pick-up	0	9
127730	2020-08-28 04:06:32	2020-08-28	8	[{"id_menu":5,"count":2}]	48195	delivery	5	13
127731	2020-08-28 04:07:16	2020-08-28	9	[{"id_menu":6,"count":1}]	3909	pick-up	0	9
127732	2020-08-28 04:08:15	2020-08-28	9	[{"id_menu":7,"count":1}]	37019	delivery	5	14
127733	2020-08-28 04:10:21	2020-08-28	8	[{"id_menu":5,"count":1}]	40555	delivery	5	13
127734	2020-08-28 04:11:11	2020-08-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	34473	delivery	5	28
127735	2020-08-28 04:14:23	2020-08-28	8	[{"id_menu":5,"count":1}]	9831	delivery	5	13
127736	2020-08-28 04:17:52	2020-08-28	9	[{"id_menu":7,"count":1}]	48314	delivery	5	14
127737	2020-08-28 04:18:43	2020-08-28	12	[{"id_menu":1,"count":1}]	48359	delivery	5	17
127738	2020-08-28 04:19:56	2020-08-28	12	[{"id_menu":3,"count":1}]	29991	delivery	5	17
127739	2020-08-28 04:21:52	2020-08-28	17	[{"id_menu":4,"count":1}]	43672	delivery	5	22
127740	2020-08-28 04:21:55	2020-08-28	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	27596	delivery	5	34
127741	2020-08-28 04:22:45	2020-08-28	9	[{"id_menu":7,"count":2}]	48315	delivery	5	14
127742	2020-08-28 04:28:27	2020-08-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12855	pick-up	0	26
127743	2020-08-28 04:30:51	2020-08-28	9	[{"id_menu":7,"count":1}]	48398	delivery	5	14
127744	2020-08-28 04:31:03	2020-08-28	12	[{"id_menu":1,"count":1}]	47567	delivery	5	17
127745	2020-08-28 04:32:56	2020-08-28	17	[{"id_menu":4,"count":1}]	6732	delivery	5	22
127746	2020-08-28 04:33:51	2020-08-28	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	31624	delivery	5	36
127747	2020-08-28 04:33:53	2020-08-28	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	38977	delivery	5	36
127748	2020-08-28 04:43:52	2020-08-28	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	37167	delivery	5	45
127749	2020-08-28 04:45:43	2020-08-28	8	[{"id_menu":5,"count":1}]	48335	delivery	5	13
127750	2020-08-28 04:47:58	2020-08-28	12	[{"id_menu":1,"count":1}]	47401	pick-up	0	12
127751	2020-08-28 04:48:33	2020-08-28	8	[{"id_menu":5,"count":1}]	33176	delivery	5	13
127752	2020-08-28 04:48:44	2020-08-28	8	[{"id_menu":5,"count":1}]	256	delivery	5	13
127753	2020-08-28 04:49:58	2020-08-28	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	48394	pick-up	0	23
127754	2020-08-28 04:51:30	2020-08-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	48344	delivery	5	22
127755	2020-08-28 04:52:30	2020-08-28	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	38157	delivery	5	28
127756	2020-08-28 04:56:11	2020-08-28	9	[{"id_menu":6,"count":1}]	5985	delivery	5	14
127757	2020-08-28 04:57:59	2020-08-28	8	[{"id_menu":5,"count":1}]	44549	pick-up	0	8
127758	2020-08-28 05:00:49	2020-08-28	9	[{"id_menu":6,"count":1}]	48183	delivery	5	14
127759	2020-08-28 05:01:34	2020-08-28	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	13740	pick-up	0	21
127760	2020-08-28 05:02:22	2020-08-28	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31186	delivery	5	46
127761	2020-08-28 05:03:18	2020-08-28	8	[{"id_menu":5,"count":1}]	40831	pick-up	0	8
127762	2020-08-28 05:07:25	2020-08-28	17	[{"id_menu":4,"count":1}]	31172	delivery	5	22
127763	2020-08-28 05:08:18	2020-08-28	9	[{"id_menu":7,"count":1}]	38797	delivery	5	14
127764	2020-08-28 05:10:31	2020-08-28	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	48401	delivery	5	25
127765	2020-08-28 05:10:45	2020-08-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	5183	delivery	5	31
127766	2020-08-28 05:14:39	2020-08-28	8	[{"id_menu":5,"count":1}]	37297	delivery	5	13
127767	2020-08-28 05:16:37	2020-08-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	48324	delivery	5	22
127768	2020-08-28 05:18:04	2020-08-28	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	212	delivery	5	23
127769	2020-08-28 05:22:05	2020-08-28	9	[{"id_menu":7,"count":1}]	259	pick-up	0	9
127770	2020-08-28 05:24:31	2020-08-28	9	[{"id_menu":7,"count":1}]	1674	pick-up	0	9
127771	2020-08-28 05:25:53	2020-08-28	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	7456	delivery	5	38
127772	2020-08-28 05:30:03	2020-08-28	9	[{"id_menu":7,"count":1}]	4170	pick-up	0	9
127773	2020-08-28 05:32:22	2020-08-28	12	[{"id_menu":1,"count":1}]	48325	delivery	5	17
127774	2020-08-28 05:33:35	2020-08-28	8	[{"id_menu":5,"count":1}]	28045	delivery	5	13
127775	2020-08-28 05:37:46	2020-08-28	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	48414	delivery	5	26
127776	2020-08-28 05:40:35	2020-08-28	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	2116	pick-up	0	29
127777	2020-08-28 05:42:54	2020-08-28	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	45124	delivery	5	35
127778	2020-08-28 05:43:45	2020-08-28	17	[{"id_menu":4,"count":1}]	29568	delivery	5	22
127779	2020-08-28 05:44:28	2020-08-28	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	28952	pick-up	0	26
127780	2020-08-28 05:45:46	2020-08-28	8	[{"id_menu":5,"count":1}]	27846	delivery	5	13
127781	2020-08-28 05:46:18	2020-08-28	12	[{"id_menu":1,"count":1}]	48210	pick-up	0	12
127782	2020-08-28 05:47:34	2020-08-28	8	[{"id_menu":5,"count":1}]	23513	delivery	5	13
127783	2020-08-28 05:51:20	2020-08-28	9	[{"id_menu":7,"count":2}]	44121	delivery	5	14
127784	2020-08-28 05:56:30	2020-08-28	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8352	delivery	5	31
127785	2020-08-28 05:57:15	2020-08-28	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	48319	delivery	5	31
127786	2020-08-28 06:03:27	2020-08-28	14	[{"id_menu":2,"count":1}]	34988	delivery	5	19
127787	2020-08-28 06:04:10	2020-08-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21257	delivery	5	23
127788	2020-08-28 06:07:30	2020-08-28	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	25002	delivery	5	31
127789	2020-08-28 06:08:58	2020-08-28	12	[{"id_menu":3,"count":1}]	38871	delivery	5	17
127790	2020-08-28 06:10:42	2020-08-28	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	19088	delivery	5	31
127791	2020-08-28 06:10:56	2020-08-28	17	[{"id_menu":4,"count":1}]	13054	pick-up	0	17
127792	2020-08-28 06:12:42	2020-08-28	14	[{"id_menu":2,"count":1}]	388	pick-up	0	14
127793	2020-08-28 06:13:32	2020-08-28	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	4967	pick-up	0	24
127794	2020-08-28 06:16:05	2020-08-28	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17398	delivery	5	48
127795	2020-08-28 06:24:37	2020-08-28	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	8313	delivery	5	28
127796	2020-08-28 06:25:32	2020-08-28	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	36380	delivery	5	44
127797	2020-08-28 06:26:45	2020-08-28	12	[{"id_menu":1,"count":1}]	48430	delivery	5	17
127798	2020-08-28 06:26:55	2020-08-28	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	12185	delivery	5	22
127799	2020-08-28 06:29:35	2020-08-28	9	[{"id_menu":6,"count":1}]	48418	delivery	5	14
127800	2020-08-28 06:30:48	2020-08-28	14	[{"id_menu":2,"count":1}]	43413	delivery	5	19
127801	2020-08-28 06:32:11	2020-08-28	14	[{"id_menu":2,"count":1}]	18068	delivery	5	19
127802	2020-08-28 06:33:23	2020-08-28	12	[{"id_menu":3,"count":1}]	48393	delivery	5	17
127803	2020-08-28 06:33:58	2020-08-28	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	38578	delivery	5	40
127869	2020-08-28 08:45:54	2020-08-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	23518	delivery	5	28
127804	2020-08-28 06:34:26	2020-08-28	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	47509	delivery	5	40
127805	2020-08-28 06:36:39	2020-08-28	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	5550	delivery	5	28
127806	2020-08-28 06:36:44	2020-08-28	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	23785	delivery	5	26
127807	2020-08-28 06:38:59	2020-08-28	8	[{"id_menu":5,"count":1}]	7623	delivery	5	13
127808	2020-08-28 06:41:33	2020-08-28	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	16033	delivery	5	31
127809	2020-08-28 06:42:35	2020-08-28	14	[{"id_menu":2,"count":1}]	14495	delivery	5	19
127810	2020-08-28 06:44:06	2020-08-28	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	30168	delivery	5	31
127811	2020-08-28 06:44:14	2020-08-28	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	48311	delivery	5	29
127812	2020-08-28 06:44:44	2020-08-28	9	[{"id_menu":7,"count":2}]	13827	delivery	5	14
127813	2020-08-28 06:46:15	2020-08-28	9	[{"id_menu":7,"count":1}]	22046	delivery	5	14
127814	2020-08-28 06:47:00	2020-08-28	12	[{"id_menu":1,"count":1}]	7773	delivery	5	17
127815	2020-08-28 06:47:39	2020-08-28	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	48205	delivery	5	26
127816	2020-08-28 06:49:13	2020-08-28	9	[{"id_menu":7,"count":1}]	14929	delivery	5	14
127817	2020-08-28 06:51:17	2020-08-28	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7609	delivery	5	43
127818	2020-08-28 06:53:17	2020-08-28	14	[{"id_menu":2,"count":1}]	3198	pick-up	0	14
127819	2020-08-28 06:54:02	2020-08-28	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	48431	delivery	5	26
127820	2020-08-28 07:00:28	2020-08-28	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	25608	delivery	5	27
127821	2020-08-28 07:00:44	2020-08-28	12	[{"id_menu":1,"count":1}]	48186	delivery	5	17
127822	2020-08-28 07:02:25	2020-08-28	9	[{"id_menu":6,"count":2}]	25077	delivery	5	14
127823	2020-08-28 07:04:30	2020-08-28	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	48360	delivery	5	55
127824	2020-08-28 07:10:15	2020-08-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	38231	delivery	5	23
127825	2020-08-28 07:10:45	2020-08-28	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	14094	delivery	5	23
127826	2020-08-28 07:13:37	2020-08-28	9	[{"id_menu":7,"count":1}]	48350	delivery	5	14
127827	2020-08-28 07:15:19	2020-08-28	9	[{"id_menu":7,"count":1}]	48424	delivery	5	14
127828	2020-08-28 07:15:40	2020-08-28	9	[{"id_menu":7,"count":1}]	7535	delivery	5	14
127829	2020-08-28 07:20:42	2020-08-28	9	[{"id_menu":7,"count":1}]	48262	delivery	5	14
127830	2020-08-28 07:24:35	2020-08-28	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38397	delivery	5	31
127831	2020-08-28 07:27:08	2020-08-28	17	[{"id_menu":4,"count":1}]	48209	delivery	5	22
127832	2020-08-28 07:32:11	2020-08-28	17	[{"id_menu":4,"count":1}]	19490	pick-up	0	17
127833	2020-08-28 07:33:59	2020-08-28	12	[{"id_menu":3,"count":1}]	48391	delivery	5	17
127834	2020-08-28 07:36:15	2020-08-28	9	[{"id_menu":7,"count":1}]	48367	delivery	5	14
127835	2020-08-28 07:37:59	2020-08-28	17	[{"id_menu":4,"count":1}]	2827	pick-up	0	17
127836	2020-08-28 07:41:26	2020-08-28	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	33096	delivery	5	40
127837	2020-08-28 07:46:43	2020-08-28	14	[{"id_menu":2,"count":1}]	38239	delivery	5	19
127838	2020-08-28 07:46:50	2020-08-28	9	[{"id_menu":6,"count":1}]	48245	delivery	5	14
127839	2020-08-28 07:46:57	2020-08-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	33873	pick-up	0	17
127840	2020-08-28 07:47:44	2020-08-28	12	[{"id_menu":1,"count":1}]	1757	delivery	5	17
127841	2020-08-28 07:48:52	2020-08-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	45191	delivery	5	22
127842	2020-08-28 07:51:48	2020-08-28	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	24588	delivery	5	38
127843	2020-08-28 07:53:47	2020-08-28	9	[{"id_menu":6,"count":2}]	23213	delivery	5	14
127844	2020-08-28 07:54:18	2020-08-28	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	36385	delivery	5	30
127845	2020-08-28 07:54:38	2020-08-28	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	25015	pick-up	0	23
127846	2020-08-28 07:55:51	2020-08-28	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	48288	delivery	5	26
127847	2020-08-28 07:56:10	2020-08-28	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	48243	delivery	5	34
127848	2020-08-28 08:08:32	2020-08-28	8	[{"id_menu":5,"count":1}]	43712	delivery	5	13
127849	2020-08-28 08:08:48	2020-08-28	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	20991	delivery	5	34
127850	2020-08-28 08:09:54	2020-08-28	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14304	delivery	5	43
127851	2020-08-28 08:11:51	2020-08-28	9	[{"id_menu":7,"count":1}]	48361	delivery	5	14
127852	2020-08-28 08:12:31	2020-08-28	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	36980	delivery	5	26
127853	2020-08-28 08:13:02	2020-08-28	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	27833	delivery	5	25
127854	2020-08-28 08:14:47	2020-08-28	9	[{"id_menu":6,"count":1}]	24310	pick-up	0	9
127855	2020-08-28 08:16:24	2020-08-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48244	delivery	5	23
127856	2020-08-28 08:24:14	2020-08-28	9	[{"id_menu":7,"count":1}]	12133	delivery	5	14
127857	2020-08-28 08:26:51	2020-08-28	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9814	delivery	5	30
127858	2020-08-28 08:28:26	2020-08-28	9	[{"id_menu":6,"count":1}]	31481	delivery	5	14
127859	2020-08-28 08:30:51	2020-08-28	12	[{"id_menu":1,"count":1}]	36026	delivery	5	17
127860	2020-08-28 08:32:50	2020-08-28	9	[{"id_menu":6,"count":1}]	19284	delivery	5	14
127861	2020-08-28 08:33:18	2020-08-28	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	33686	delivery	5	57
127862	2020-08-28 08:34:29	2020-08-28	17	[{"id_menu":4,"count":1}]	48257	delivery	5	22
127863	2020-08-28 08:34:42	2020-08-28	12	[{"id_menu":1,"count":1}]	28791	delivery	5	17
127864	2020-08-28 08:34:44	2020-08-28	9	[{"id_menu":6,"count":1}]	33280	delivery	5	14
127865	2020-08-28 08:36:39	2020-08-28	9	[{"id_menu":7,"count":1}]	48428	delivery	5	14
127866	2020-08-28 08:43:37	2020-08-28	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	2837	delivery	5	39
127867	2020-08-28 08:44:15	2020-08-28	9	[{"id_menu":7,"count":1}]	41835	delivery	5	14
127868	2020-08-28 08:45:24	2020-08-28	17	[{"id_menu":4,"count":1}]	48194	delivery	5	22
127870	2020-08-28 08:46:40	2020-08-28	17	[{"id_menu":4,"count":1}]	28225	pick-up	0	17
127871	2020-08-28 08:47:43	2020-08-28	8	[{"id_menu":5,"count":1}]	7888	delivery	5	13
127872	2020-08-28 08:49:17	2020-08-28	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	48395	delivery	5	31
127873	2020-08-28 08:49:35	2020-08-28	9	[{"id_menu":7,"count":1}]	7706	delivery	5	14
127874	2020-08-28 08:50:14	2020-08-28	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13073	delivery	5	40
127875	2020-08-28 08:50:34	2020-08-28	8	[{"id_menu":5,"count":2}]	31161	delivery	5	13
127876	2020-08-28 08:56:11	2020-08-28	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23658	delivery	5	52
127877	2020-08-28 08:56:41	2020-08-28	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	20077	delivery	5	40
127878	2020-08-28 08:58:13	2020-08-28	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	47170	delivery	5	39
127879	2020-08-28 08:58:30	2020-08-28	12	[{"id_menu":3,"count":1}]	48332	delivery	5	17
127880	2020-08-28 09:02:44	2020-08-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	48253	delivery	5	28
127881	2020-08-28 09:02:52	2020-08-28	17	[{"id_menu":4,"count":1}]	16799	delivery	5	22
127882	2020-08-28 09:06:13	2020-08-28	14	[{"id_menu":2,"count":2}]	45012	pick-up	0	14
127883	2020-08-28 09:06:55	2020-08-28	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23555	pick-up	0	43
127884	2020-08-28 09:07:48	2020-08-28	14	[{"id_menu":2,"count":2}]	46741	delivery	5	19
127885	2020-08-28 09:09:19	2020-08-28	12	[{"id_menu":3,"count":1}]	45095	pick-up	0	12
127886	2020-08-28 09:10:08	2020-08-28	9	[{"id_menu":7,"count":1}]	2729	delivery	5	14
127887	2020-08-28 09:15:38	2020-08-28	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	15284	delivery	5	40
127888	2020-08-28 09:23:37	2020-08-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	43331	delivery	5	28
127889	2020-08-28 09:25:29	2020-08-28	8	[{"id_menu":5,"count":1}]	2776	delivery	5	13
127890	2020-08-28 09:25:52	2020-08-28	14	[{"id_menu":2,"count":1}]	34792	pick-up	0	14
127891	2020-08-28 09:28:05	2020-08-28	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	6617	pick-up	0	26
127892	2020-08-28 09:28:50	2020-08-28	12	[{"id_menu":1,"count":1}]	9449	delivery	5	17
127893	2020-08-28 09:35:49	2020-08-28	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	5215	pick-up	0	31
127894	2020-08-28 09:37:50	2020-08-28	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	38050	pick-up	0	31
127895	2020-08-28 09:38:08	2020-08-28	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	47581	delivery	5	55
127896	2020-08-28 09:41:32	2020-08-28	12	[{"id_menu":1,"count":1}]	48252	delivery	5	17
127897	2020-08-28 09:52:19	2020-08-28	8	[{"id_menu":5,"count":1}]	14505	delivery	5	13
127898	2020-08-28 09:52:41	2020-08-28	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43553	delivery	5	45
127899	2020-08-28 09:53:49	2020-08-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	48411	delivery	5	22
127900	2020-08-28 09:56:08	2020-08-28	9	[{"id_menu":6,"count":1}]	35722	pick-up	0	9
127901	2020-08-28 09:58:19	2020-08-28	8	[{"id_menu":5,"count":1}]	33879	delivery	5	13
127902	2020-08-28 09:59:44	2020-08-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	22949	delivery	5	22
127903	2020-08-28 09:59:46	2020-08-28	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	45637	delivery	5	43
127904	2020-08-28 10:02:37	2020-08-28	9	[{"id_menu":6,"count":1}]	48249	delivery	5	14
127905	2020-08-28 10:05:32	2020-08-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	33480	pick-up	0	26
127906	2020-08-28 10:07:16	2020-08-28	17	[{"id_menu":5,"count":3},{"id_menu":7,"count":1}]	33168	delivery	5	22
127907	2020-08-28 10:08:14	2020-08-28	17	[{"id_menu":4,"count":1}]	31533	delivery	5	22
127908	2020-08-28 10:09:26	2020-08-28	9	[{"id_menu":6,"count":1}]	43053	delivery	5	14
127909	2020-08-28 10:22:00	2020-08-28	23	[{"id_menu":2,"count":3},{"id_menu":6,"count":1}]	48327	delivery	5	28
127910	2020-08-28 10:22:04	2020-08-28	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	12849	delivery	5	31
127911	2020-08-28 10:25:56	2020-08-28	9	[{"id_menu":6,"count":1}]	48222	delivery	5	14
127912	2020-08-28 10:29:03	2020-08-28	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	39711	delivery	5	26
127913	2020-08-28 10:36:20	2020-08-28	14	[{"id_menu":2,"count":1}]	30431	delivery	5	19
127914	2020-08-28 10:37:25	2020-08-28	9	[{"id_menu":7,"count":1}]	18244	delivery	5	14
127915	2020-08-28 10:39:37	2020-08-28	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	33401	delivery	5	43
127916	2020-08-28 10:40:32	2020-08-28	14	[{"id_menu":2,"count":1}]	48187	delivery	5	19
127917	2020-08-28 10:41:33	2020-08-28	8	[{"id_menu":5,"count":1}]	48376	pick-up	0	8
127918	2020-08-28 10:42:17	2020-08-28	9	[{"id_menu":6,"count":3}]	48316	pick-up	0	9
127919	2020-08-28 10:42:17	2020-08-28	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	15913	pick-up	0	25
127920	2020-08-28 10:45:08	2020-08-28	8	[{"id_menu":5,"count":1}]	24974	delivery	5	13
127921	2020-08-28 10:50:48	2020-08-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11154	delivery	5	31
127922	2020-08-28 10:54:16	2020-08-28	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	48330	delivery	5	43
127923	2020-08-28 10:55:51	2020-08-28	12	[{"id_menu":3,"count":1}]	15752	delivery	5	17
127924	2020-08-28 11:01:36	2020-08-28	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	17552	delivery	5	27
127925	2020-08-28 11:02:05	2020-08-28	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	10758	delivery	5	37
127926	2020-08-28 11:02:26	2020-08-28	12	[{"id_menu":1,"count":1}]	48231	delivery	5	17
127927	2020-08-28 11:03:17	2020-08-28	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10602	delivery	5	40
127928	2020-08-28 11:07:03	2020-08-28	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	40958	delivery	5	34
127929	2020-08-28 11:08:51	2020-08-28	12	[{"id_menu":1,"count":1}]	44190	delivery	5	17
127930	2020-08-28 11:09:05	2020-08-28	8	[{"id_menu":5,"count":1}]	48387	delivery	5	13
127931	2020-08-28 11:12:37	2020-08-28	9	[{"id_menu":6,"count":1}]	11893	delivery	5	14
127932	2020-08-28 11:13:24	2020-08-28	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	14039	delivery	5	27
127933	2020-08-28 11:18:34	2020-08-28	14	[{"id_menu":2,"count":1}]	48185	delivery	5	19
127934	2020-08-28 11:22:05	2020-08-28	8	[{"id_menu":5,"count":1}]	43688	delivery	5	13
127935	2020-08-28 11:22:49	2020-08-28	8	[{"id_menu":5,"count":1}]	36083	delivery	5	13
127936	2020-08-28 11:23:47	2020-08-28	17	[{"id_menu":4,"count":1}]	11020	delivery	5	22
127937	2020-08-28 11:24:00	2020-08-28	9	[{"id_menu":6,"count":1}]	3500	delivery	5	14
127938	2020-08-28 11:28:19	2020-08-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	44293	delivery	5	31
127939	2020-08-28 11:29:13	2020-08-28	17	[{"id_menu":4,"count":1}]	48240	delivery	5	22
127940	2020-08-28 11:31:06	2020-08-28	12	[{"id_menu":1,"count":1}]	16328	pick-up	0	12
127941	2020-08-28 11:32:39	2020-08-28	12	[{"id_menu":3,"count":1}]	30301	pick-up	0	12
127942	2020-08-28 11:33:43	2020-08-28	14	[{"id_menu":2,"count":1}]	46555	delivery	5	19
127943	2020-08-28 11:35:01	2020-08-28	12	[{"id_menu":1,"count":1}]	18724	delivery	5	17
127944	2020-08-28 11:38:27	2020-08-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19022	delivery	5	23
127945	2020-08-28 11:39:58	2020-08-28	9	[{"id_menu":6,"count":1}]	31393	delivery	5	14
127946	2020-08-28 11:46:40	2020-08-28	9	[{"id_menu":6,"count":1}]	31134	delivery	5	14
127947	2020-08-28 11:47:13	2020-08-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	48202	delivery	5	22
127948	2020-08-28 11:47:59	2020-08-28	17	[{"id_menu":4,"count":1}]	48420	delivery	5	22
127949	2020-08-28 11:49:56	2020-08-28	17	[{"id_menu":4,"count":1}]	15331	delivery	5	22
127950	2020-08-28 11:51:47	2020-08-28	9	[{"id_menu":6,"count":1}]	48317	delivery	5	14
127951	2020-08-28 11:52:45	2020-08-28	14	[{"id_menu":2,"count":1}]	3255	pick-up	0	14
127952	2020-08-28 11:53:03	2020-08-28	12	[{"id_menu":1,"count":1}]	2252	pick-up	0	12
127953	2020-08-28 11:54:38	2020-08-28	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	48305	delivery	5	44
127954	2020-08-28 11:57:42	2020-08-28	14	[{"id_menu":2,"count":1}]	14133	pick-up	0	14
127955	2020-08-28 11:57:50	2020-08-28	12	[{"id_menu":3,"count":1}]	33614	pick-up	0	12
127956	2020-08-28 11:59:34	2020-08-28	14	[{"id_menu":2,"count":1}]	9750	pick-up	0	14
127957	2020-08-28 12:01:23	2020-08-28	9	[{"id_menu":6,"count":1}]	46413	delivery	5	14
127958	2020-08-28 12:01:49	2020-08-28	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	45457	delivery	5	48
127959	2020-08-28 12:03:47	2020-08-28	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22822	delivery	5	46
127960	2020-08-28 12:05:09	2020-08-28	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	31789	delivery	5	43
127961	2020-08-28 12:07:11	2020-08-28	14	[{"id_menu":2,"count":1}]	27287	delivery	5	19
127962	2020-08-28 12:08:06	2020-08-28	12	[{"id_menu":3,"count":1}]	34601	delivery	5	17
127963	2020-08-28 12:08:30	2020-08-28	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	8229	delivery	5	29
127964	2020-08-28 12:14:08	2020-08-28	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	25159	delivery	5	40
127965	2020-08-28 12:21:39	2020-08-28	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	11721	delivery	5	36
127966	2020-08-28 12:22:41	2020-08-28	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48368	delivery	5	48
127967	2020-08-28 12:24:22	2020-08-28	9	[{"id_menu":7,"count":1}]	22610	delivery	5	14
127968	2020-08-28 12:27:13	2020-08-28	8	[{"id_menu":5,"count":1}]	33756	delivery	5	13
127969	2020-08-28 12:29:59	2020-08-28	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	36866	delivery	5	36
127970	2020-08-28 12:31:56	2020-08-28	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48273	delivery	5	35
127971	2020-08-28 12:32:17	2020-08-28	9	[{"id_menu":6,"count":3}]	18683	delivery	5	14
127972	2020-08-28 12:32:33	2020-08-28	17	[{"id_menu":4,"count":2}]	12740	pick-up	0	17
127973	2020-08-28 12:32:45	2020-08-28	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	48295	delivery	5	28
127974	2020-08-28 12:32:48	2020-08-28	9	[{"id_menu":7,"count":1}]	45987	pick-up	0	9
127975	2020-08-28 12:39:36	2020-08-28	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	10466	delivery	5	26
127976	2020-08-28 12:41:37	2020-08-28	51	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	48421	delivery	5	56
127977	2020-08-28 12:45:07	2020-08-28	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	48211	delivery	5	38
127978	2020-08-28 12:45:32	2020-08-28	9	[{"id_menu":7,"count":1}]	39939	delivery	5	14
127979	2020-08-28 12:48:35	2020-08-28	8	[{"id_menu":5,"count":1}]	1168	delivery	5	13
127980	2020-08-28 12:50:51	2020-08-28	9	[{"id_menu":6,"count":1}]	31737	delivery	5	14
127981	2020-08-28 12:53:29	2020-08-28	8	[{"id_menu":5,"count":1}]	11187	delivery	5	13
127982	2020-08-28 12:53:53	2020-08-28	12	[{"id_menu":1,"count":1}]	21053	delivery	5	17
127983	2020-08-28 12:54:01	2020-08-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	6113	delivery	5	22
127984	2020-08-28 12:55:00	2020-08-28	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	48219	delivery	5	43
127985	2020-08-28 12:55:49	2020-08-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	48353	delivery	5	22
127986	2020-08-28 12:56:00	2020-08-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	39753	delivery	5	31
127987	2020-08-28 13:01:34	2020-08-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	48238	delivery	5	22
127988	2020-08-28 13:02:12	2020-08-28	14	[{"id_menu":2,"count":1}]	48349	delivery	5	19
127989	2020-08-28 13:03:00	2020-08-28	12	[{"id_menu":1,"count":1}]	17884	delivery	5	17
127990	2020-08-28 13:03:22	2020-08-28	14	[{"id_menu":2,"count":1}]	215	pick-up	0	14
127991	2020-08-28 13:04:12	2020-08-28	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	48226	delivery	5	48
127992	2020-08-28 13:12:46	2020-08-28	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	40319	delivery	5	39
127993	2020-08-28 13:12:54	2020-08-28	12	[{"id_menu":3,"count":1}]	48405	delivery	5	17
127994	2020-08-28 13:15:16	2020-08-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34627	pick-up	0	18
127995	2020-08-28 13:16:27	2020-08-28	9	[{"id_menu":7,"count":1}]	29042	delivery	5	14
127996	2020-08-28 13:19:12	2020-08-28	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	45473	delivery	5	28
127997	2020-08-28 13:19:51	2020-08-28	9	[{"id_menu":7,"count":1}]	40002	delivery	5	14
127998	2020-08-28 13:19:59	2020-08-28	9	[{"id_menu":6,"count":1}]	45680	delivery	5	14
127999	2020-08-28 13:21:10	2020-08-28	9	[{"id_menu":6,"count":1}]	35860	delivery	5	14
128000	2020-08-28 13:24:57	2020-08-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	48192	pick-up	0	26
128001	2020-08-28 13:25:01	2020-08-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	47023	delivery	5	28
128002	2020-08-28 13:26:21	2020-08-28	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	48415	delivery	5	26
128003	2020-08-28 13:27:07	2020-08-28	14	[{"id_menu":2,"count":1}]	12808	pick-up	0	14
128004	2020-08-28 13:29:40	2020-08-28	14	[{"id_menu":2,"count":1}]	48386	delivery	5	19
128005	2020-08-28 13:31:04	2020-08-28	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13437	delivery	5	39
128006	2020-08-28 13:37:41	2020-08-28	12	[{"id_menu":3,"count":1}]	48422	delivery	5	17
128007	2020-08-28 13:38:59	2020-08-28	9	[{"id_menu":7,"count":1}]	43423	delivery	5	14
128008	2020-08-28 13:53:02	2020-08-28	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	48429	delivery	5	29
128009	2020-08-28 13:54:43	2020-08-28	8	[{"id_menu":5,"count":1}]	102	pick-up	0	8
128010	2020-08-28 13:55:37	2020-08-28	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	43669	delivery	5	25
128011	2020-08-28 13:58:27	2020-08-28	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	48303	delivery	5	45
128012	2020-08-28 13:59:03	2020-08-28	9	[{"id_menu":6,"count":1}]	48399	delivery	5	14
128013	2020-08-28 14:01:50	2020-08-28	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	48435	delivery	5	26
128014	2020-08-28 14:04:39	2020-08-28	14	[{"id_menu":2,"count":1}]	1255	pick-up	0	14
128015	2020-08-28 14:05:16	2020-08-28	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	26270	delivery	5	38
128016	2020-08-28 14:14:25	2020-08-28	17	[{"id_menu":4,"count":1}]	44144	pick-up	0	17
128017	2020-08-28 14:14:27	2020-08-28	9	[{"id_menu":6,"count":1}]	10635	delivery	5	14
128018	2020-08-28 14:14:50	2020-08-28	12	[{"id_menu":1,"count":1}]	18923	delivery	5	17
128019	2020-08-28 14:15:14	2020-08-28	17	[{"id_menu":4,"count":1}]	1666	delivery	5	22
128020	2020-08-28 14:16:48	2020-08-28	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	48221	delivery	5	57
128021	2020-08-28 14:18:05	2020-08-28	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	45452	delivery	5	40
128022	2020-08-28 14:18:13	2020-08-28	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	32365	delivery	5	26
128023	2020-08-28 14:18:35	2020-08-28	9	[{"id_menu":6,"count":1}]	48270	delivery	5	14
128024	2020-08-28 14:19:53	2020-08-28	12	[{"id_menu":1,"count":1}]	48312	delivery	5	17
128025	2020-08-28 14:20:08	2020-08-28	9	[{"id_menu":6,"count":1}]	5155	delivery	5	14
128026	2020-08-28 14:23:03	2020-08-28	9	[{"id_menu":7,"count":1}]	48271	delivery	5	14
128027	2020-08-28 14:23:29	2020-08-28	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	10340	delivery	5	35
128028	2020-08-28 14:25:26	2020-08-28	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	37341	delivery	5	38
128029	2020-08-28 14:30:02	2020-08-28	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	24865	delivery	5	43
128030	2020-08-28 14:30:45	2020-08-28	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	17546	delivery	5	48
128031	2020-08-28 14:30:48	2020-08-28	9	[{"id_menu":7,"count":1}]	48328	delivery	5	14
128032	2020-08-28 14:32:23	2020-08-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	28453	delivery	5	28
128033	2020-08-28 14:33:06	2020-08-28	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	48373	delivery	5	28
128034	2020-08-28 14:36:35	2020-08-28	8	[{"id_menu":5,"count":1}]	45713	delivery	5	13
128035	2020-08-28 14:37:22	2020-08-28	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	24276	delivery	5	43
128036	2020-08-28 14:38:20	2020-08-28	8	[{"id_menu":5,"count":1}]	32854	delivery	5	13
128037	2020-08-28 14:39:52	2020-08-28	8	[{"id_menu":5,"count":1}]	48269	delivery	5	13
128038	2020-08-28 14:42:50	2020-08-28	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20158	delivery	5	54
128039	2020-08-28 14:46:06	2020-08-28	14	[{"id_menu":2,"count":1}]	22708	pick-up	0	14
128040	2020-08-28 14:48:11	2020-08-28	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	48255	delivery	5	36
128041	2020-08-28 14:51:41	2020-08-28	14	[{"id_menu":2,"count":1}]	13893	delivery	5	19
128042	2020-08-28 14:52:12	2020-08-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36359	delivery	5	23
128043	2020-08-28 14:52:48	2020-08-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	40408	delivery	5	28
128044	2020-08-28 14:54:59	2020-08-28	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	140	delivery	5	26
128045	2020-08-28 15:05:48	2020-08-28	12	[{"id_menu":3,"count":1}]	43341	pick-up	0	12
128046	2020-08-28 15:10:20	2020-08-28	9	[{"id_menu":7,"count":2}]	48279	delivery	5	14
128047	2020-08-28 15:10:47	2020-08-28	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30122	delivery	5	49
128048	2020-08-28 15:11:54	2020-08-28	9	[{"id_menu":6,"count":1}]	25226	delivery	5	14
128049	2020-08-28 15:13:12	2020-08-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	31139	delivery	5	22
128050	2020-08-28 15:14:06	2020-08-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	48338	delivery	5	31
128051	2020-08-28 15:14:19	2020-08-28	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	10850	pick-up	0	29
128052	2020-08-28 15:14:22	2020-08-28	12	[{"id_menu":3,"count":1}]	18120	delivery	5	17
128053	2020-08-28 15:16:24	2020-08-28	12	[{"id_menu":3,"count":1}]	6202	pick-up	0	12
128054	2020-08-28 15:16:51	2020-08-28	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	45983	delivery	5	45
128055	2020-08-28 15:19:58	2020-08-28	9	[{"id_menu":6,"count":1}]	27299	pick-up	0	9
128056	2020-08-28 15:22:25	2020-08-28	8	[{"id_menu":5,"count":1}]	1053	pick-up	0	8
128057	2020-08-28 15:23:33	2020-08-28	8	[{"id_menu":5,"count":1}]	6599	delivery	5	13
128058	2020-08-28 15:24:26	2020-08-28	8	[{"id_menu":5,"count":1}]	28124	pick-up	0	8
128059	2020-08-28 15:29:28	2020-08-28	9	[{"id_menu":6,"count":1}]	27296	delivery	5	14
128060	2020-08-28 15:30:33	2020-08-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	48216	delivery	5	22
128061	2020-08-28 15:32:03	2020-08-28	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	48201	delivery	5	34
128062	2020-08-28 15:32:51	2020-08-28	8	[{"id_menu":5,"count":1}]	48322	delivery	5	13
128063	2020-08-28 15:34:20	2020-08-28	9	[{"id_menu":7,"count":1}]	7186	delivery	5	14
128064	2020-08-28 15:37:20	2020-08-28	9	[{"id_menu":7,"count":1}]	48289	delivery	5	14
128065	2020-08-28 15:45:30	2020-08-28	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	48247	delivery	5	34
128066	2020-08-28 15:47:55	2020-08-28	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	48423	delivery	5	37
128067	2020-08-28 15:48:00	2020-08-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	11932	delivery	5	31
128068	2020-08-28 15:48:27	2020-08-28	12	[{"id_menu":3,"count":1}]	22132	delivery	5	17
128069	2020-08-28 15:49:00	2020-08-28	9	[{"id_menu":6,"count":1}]	25644	pick-up	0	9
128070	2020-08-28 15:54:24	2020-08-28	12	[{"id_menu":3,"count":1}]	48206	pick-up	0	12
128071	2020-08-28 15:54:37	2020-08-28	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	5117	delivery	5	28
128072	2020-08-28 15:55:05	2020-08-28	34	[{"id_menu":4,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	4894	delivery	5	39
128073	2020-08-28 15:56:50	2020-08-28	12	[{"id_menu":1,"count":1}]	17669	delivery	5	17
128074	2020-08-28 15:57:10	2020-08-28	9	[{"id_menu":7,"count":1}]	42577	pick-up	0	9
128075	2020-08-28 16:00:19	2020-08-28	9	[{"id_menu":7,"count":1}]	1140	delivery	5	14
128076	2020-08-28 16:00:55	2020-08-28	9	[{"id_menu":6,"count":1}]	48382	delivery	5	14
128077	2020-08-28 16:03:15	2020-08-28	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	249	pick-up	0	26
128078	2020-08-28 16:05:41	2020-08-28	14	[{"id_menu":2,"count":1}]	19382	pick-up	0	14
128079	2020-08-28 16:06:24	2020-08-28	12	[{"id_menu":3,"count":1}]	10702	delivery	5	17
128080	2020-08-28 16:07:59	2020-08-28	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	20320	delivery	5	26
128081	2020-08-28 16:11:04	2020-08-28	8	[{"id_menu":5,"count":1}]	6959	delivery	5	13
128082	2020-08-28 16:11:06	2020-08-28	9	[{"id_menu":6,"count":1}]	46173	delivery	5	14
128083	2020-08-28 16:11:32	2020-08-28	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	48365	delivery	5	34
128084	2020-08-28 16:14:02	2020-08-28	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34581	delivery	5	49
128085	2020-08-28 16:14:49	2020-08-28	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	43035	delivery	5	40
128086	2020-08-28 16:15:52	2020-08-28	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	48313	delivery	5	26
128087	2020-08-28 16:15:54	2020-08-28	9	[{"id_menu":6,"count":1}]	12620	delivery	5	14
128088	2020-08-28 16:18:43	2020-08-28	14	[{"id_menu":2,"count":1}]	26212	delivery	5	19
128089	2020-08-28 16:21:47	2020-08-28	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	48234	delivery	5	39
128090	2020-08-28 16:21:54	2020-08-28	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	17809	delivery	5	25
128091	2020-08-28 16:27:06	2020-08-28	14	[{"id_menu":2,"count":2}]	38271	delivery	5	19
128092	2020-08-28 16:27:10	2020-08-28	8	[{"id_menu":5,"count":1}]	38131	delivery	5	13
128093	2020-08-28 16:27:41	2020-08-28	12	[{"id_menu":1,"count":1}]	48242	delivery	5	17
128094	2020-08-28 16:30:23	2020-08-28	12	[{"id_menu":3,"count":1}]	12506	pick-up	0	12
128095	2020-08-28 16:32:28	2020-08-28	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19212	pick-up	0	49
128096	2020-08-28 16:36:22	2020-08-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	19445	delivery	5	31
128097	2020-08-28 16:37:29	2020-08-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":3}]	16343	delivery	5	22
128098	2020-08-28 16:39:04	2020-08-28	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	18065	delivery	5	45
128099	2020-08-28 16:40:19	2020-08-28	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48372	delivery	5	35
128100	2020-08-28 16:40:26	2020-08-28	9	[{"id_menu":7,"count":1}]	48228	delivery	5	14
128101	2020-08-28 16:41:07	2020-08-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48188	delivery	5	23
128102	2020-08-28 16:41:17	2020-08-28	12	[{"id_menu":1,"count":1}]	48236	pick-up	0	12
128103	2020-08-28 16:41:52	2020-08-28	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	48318	delivery	5	30
128104	2020-08-28 16:42:47	2020-08-28	12	[{"id_menu":1,"count":1}]	20964	pick-up	0	12
128105	2020-08-28 16:45:19	2020-08-28	14	[{"id_menu":2,"count":1}]	2276	pick-up	0	14
128106	2020-08-28 16:45:54	2020-08-28	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	10718	delivery	5	25
128107	2020-08-28 16:47:58	2020-08-28	8	[{"id_menu":5,"count":1}]	36872	delivery	5	13
128108	2020-08-28 16:53:07	2020-08-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":3}]	48337	delivery	5	23
128109	2020-08-28 16:53:59	2020-08-28	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	38630	delivery	5	39
128110	2020-08-28 16:54:15	2020-08-28	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	48380	delivery	5	25
128111	2020-08-28 16:54:19	2020-08-28	9	[{"id_menu":6,"count":2}]	3851	pick-up	0	9
128112	2020-08-28 17:01:31	2020-08-28	9	[{"id_menu":6,"count":1}]	48434	delivery	5	14
128113	2020-08-28 17:02:45	2020-08-28	17	[{"id_menu":4,"count":1}]	37918	delivery	5	22
128114	2020-08-28 17:03:20	2020-08-28	14	[{"id_menu":2,"count":1}]	48290	delivery	5	19
128115	2020-08-28 17:03:24	2020-08-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	48232	delivery	5	31
128116	2020-08-28 17:03:47	2020-08-28	9	[{"id_menu":6,"count":1}]	17329	pick-up	0	9
128117	2020-08-28 17:04:12	2020-08-28	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	38229	delivery	5	31
128118	2020-08-28 17:07:30	2020-08-28	9	[{"id_menu":7,"count":1}]	5238	pick-up	0	9
128119	2020-08-28 17:11:53	2020-08-28	30	[{"id_menu":3,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48425	delivery	5	35
128120	2020-08-28 17:12:06	2020-08-28	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	45666	delivery	5	30
128121	2020-08-28 17:13:00	2020-08-28	12	[{"id_menu":1,"count":1}]	12283	pick-up	0	12
128122	2020-08-28 17:15:27	2020-08-28	14	[{"id_menu":2,"count":1}]	14559	pick-up	0	14
128123	2020-08-28 17:15:59	2020-08-28	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	48326	delivery	5	42
128124	2020-08-28 17:25:52	2020-08-28	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9682	pick-up	0	40
128125	2020-08-28 17:30:32	2020-08-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	48256	delivery	5	22
128126	2020-08-28 17:31:04	2020-08-28	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	15845	delivery	5	31
128127	2020-08-28 17:31:18	2020-08-28	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	43856	delivery	5	26
128128	2020-08-28 17:32:38	2020-08-28	12	[{"id_menu":3,"count":1}]	1272	delivery	5	17
128129	2020-08-28 17:37:09	2020-08-28	8	[{"id_menu":5,"count":1}]	48258	delivery	5	13
128130	2020-08-28 17:37:57	2020-08-28	8	[{"id_menu":5,"count":1}]	46411	delivery	5	13
128131	2020-08-28 17:41:09	2020-08-28	9	[{"id_menu":6,"count":1}]	48417	delivery	5	14
128132	2020-08-28 17:44:40	2020-08-28	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	48217	delivery	5	43
128133	2020-08-28 17:45:40	2020-08-28	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	21121	pick-up	0	26
128134	2020-08-28 17:46:01	2020-08-28	14	[{"id_menu":2,"count":1}]	48363	pick-up	0	14
128135	2020-08-28 17:47:02	2020-08-28	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	226	pick-up	0	31
128136	2020-08-28 17:47:22	2020-08-28	9	[{"id_menu":6,"count":1}]	48284	delivery	5	14
128137	2020-08-28 17:47:22	2020-08-28	9	[{"id_menu":6,"count":1}]	11616	delivery	5	14
128138	2020-08-28 17:48:00	2020-08-28	12	[{"id_menu":3,"count":1}]	2662	pick-up	0	12
128139	2020-08-28 17:51:22	2020-08-28	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	47923	pick-up	0	20
128140	2020-08-28 17:52:54	2020-08-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1569	delivery	5	31
128141	2020-08-28 18:01:03	2020-08-28	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	48190	delivery	5	26
128142	2020-08-28 18:04:08	2020-08-28	9	[{"id_menu":7,"count":1}]	36664	delivery	5	14
128143	2020-08-28 18:09:45	2020-08-28	9	[{"id_menu":6,"count":1}]	5977	delivery	5	14
128144	2020-08-28 18:10:51	2020-08-28	12	[{"id_menu":3,"count":1}]	17357	delivery	5	17
128145	2020-08-28 18:12:12	2020-08-28	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8862	delivery	5	36
128146	2020-08-28 18:13:22	2020-08-28	14	[{"id_menu":2,"count":1}]	533	delivery	5	19
128147	2020-08-28 18:13:48	2020-08-28	9	[{"id_menu":7,"count":1}]	13511	delivery	5	14
128148	2020-08-28 18:14:48	2020-08-28	9	[{"id_menu":6,"count":1}]	6212	delivery	5	14
128149	2020-08-28 18:17:38	2020-08-28	8	[{"id_menu":5,"count":1}]	42760	delivery	5	13
128150	2020-08-28 18:20:23	2020-08-28	30	[{"id_menu":3,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22995	delivery	5	35
128151	2020-08-28 18:24:32	2020-08-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4874	pick-up	0	18
128152	2020-08-28 18:25:21	2020-08-28	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	48283	delivery	5	39
128153	2020-08-28 18:29:06	2020-08-28	14	[{"id_menu":2,"count":1}]	26699	delivery	5	19
128154	2020-08-28 18:31:08	2020-08-28	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20439	delivery	5	39
128155	2020-08-28 18:31:45	2020-08-28	12	[{"id_menu":1,"count":1}]	24274	pick-up	0	12
128156	2020-08-28 18:35:01	2020-08-28	17	[{"id_menu":4,"count":1}]	32269	delivery	5	22
128157	2020-08-28 18:36:19	2020-08-28	17	[{"id_menu":4,"count":1}]	6409	delivery	5	22
128158	2020-08-28 18:36:35	2020-08-28	9	[{"id_menu":6,"count":1}]	1684	pick-up	0	9
128159	2020-08-28 18:38:16	2020-08-28	8	[{"id_menu":5,"count":1}]	10170	delivery	5	13
128160	2020-08-28 18:41:46	2020-08-28	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12491	delivery	5	37
128161	2020-08-28 18:41:51	2020-08-28	14	[{"id_menu":2,"count":1}]	5875	pick-up	0	14
128162	2020-08-28 18:44:31	2020-08-28	9	[{"id_menu":6,"count":1}]	23298	delivery	5	14
128163	2020-08-28 18:47:49	2020-08-28	9	[{"id_menu":7,"count":1}]	36721	pick-up	0	9
128164	2020-08-28 18:49:32	2020-08-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	24422	delivery	5	28
128165	2020-08-28 18:52:48	2020-08-28	17	[{"id_menu":4,"count":1}]	48339	delivery	5	22
128166	2020-08-28 18:55:05	2020-08-28	9	[{"id_menu":6,"count":1}]	1659	pick-up	0	9
128167	2020-08-28 18:56:59	2020-08-28	17	[{"id_menu":4,"count":1}]	44733	delivery	5	22
128168	2020-08-28 19:00:14	2020-08-28	9	[{"id_menu":6,"count":1}]	3168	pick-up	0	9
128169	2020-08-28 19:00:59	2020-08-28	14	[{"id_menu":2,"count":1}]	48207	delivery	5	19
128170	2020-08-28 19:05:21	2020-08-28	9	[{"id_menu":6,"count":1}]	48193	delivery	5	14
128171	2020-08-28 19:06:50	2020-08-28	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	18541	pick-up	0	40
128172	2020-08-28 19:08:28	2020-08-28	9	[{"id_menu":7,"count":1}]	18616	delivery	5	14
128173	2020-08-28 19:11:52	2020-08-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	48246	delivery	5	31
128174	2020-08-28 19:11:57	2020-08-28	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	47977	delivery	5	51
128175	2020-08-28 19:12:55	2020-08-28	12	[{"id_menu":1,"count":1}]	39699	delivery	5	17
128176	2020-08-28 19:16:21	2020-08-28	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	21464	delivery	5	30
128177	2020-08-28 19:18:28	2020-08-28	9	[{"id_menu":7,"count":1}]	46430	delivery	5	14
128178	2020-08-28 19:18:47	2020-08-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	16080	delivery	5	28
128179	2020-08-28 19:19:20	2020-08-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11239	delivery	5	31
128180	2020-08-28 19:19:38	2020-08-28	9	[{"id_menu":6,"count":1}]	15003	delivery	5	14
128181	2020-08-28 19:21:43	2020-08-28	12	[{"id_menu":3,"count":1}]	42042	delivery	5	17
128182	2020-08-28 19:23:11	2020-08-28	12	[{"id_menu":1,"count":1}]	38568	delivery	5	17
128183	2020-08-28 19:28:01	2020-08-28	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	42493	delivery	5	31
128184	2020-08-28 19:30:24	2020-08-28	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	847	delivery	5	29
128185	2020-08-28 19:30:45	2020-08-28	14	[{"id_menu":2,"count":1}]	6895	delivery	5	19
128186	2020-08-28 19:31:08	2020-08-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	18928	delivery	5	28
128187	2020-08-28 19:36:31	2020-08-28	9	[{"id_menu":7,"count":1}]	6733	delivery	5	14
128188	2020-08-28 19:38:11	2020-08-28	9	[{"id_menu":7,"count":1}]	48223	delivery	5	14
128189	2020-08-28 19:38:12	2020-08-28	12	[{"id_menu":3,"count":1}]	48436	pick-up	0	12
128190	2020-08-28 19:38:26	2020-08-28	8	[{"id_menu":5,"count":1}]	48272	delivery	5	13
128191	2020-08-28 19:38:37	2020-08-28	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	34163	delivery	5	26
128192	2020-08-28 19:39:38	2020-08-28	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	48320	delivery	5	40
128193	2020-08-28 19:40:09	2020-08-28	8	[{"id_menu":5,"count":1}]	43557	delivery	5	13
128194	2020-08-28 19:40:52	2020-08-28	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	30862	delivery	5	43
128195	2020-08-28 19:41:22	2020-08-28	17	[{"id_menu":4,"count":1}]	48378	delivery	5	22
128196	2020-08-28 19:44:00	2020-08-28	9	[{"id_menu":7,"count":1}]	23668	delivery	5	14
128197	2020-08-28 19:44:18	2020-08-28	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	36447	delivery	5	26
128198	2020-08-28 19:46:02	2020-08-28	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	45018	delivery	5	25
128199	2020-08-28 19:49:40	2020-08-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	48403	delivery	5	22
128200	2020-08-28 19:50:55	2020-08-28	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16342	delivery	5	43
128201	2020-08-28 19:50:57	2020-08-28	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	12121	delivery	5	36
128202	2020-08-28 19:55:55	2020-08-28	17	[{"id_menu":4,"count":1}]	10151	delivery	5	22
128203	2020-08-28 19:56:02	2020-08-28	9	[{"id_menu":6,"count":1}]	10073	delivery	5	14
128204	2020-08-28 19:59:18	2020-08-28	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11046	delivery	5	35
128205	2020-08-28 20:01:00	2020-08-28	8	[{"id_menu":5,"count":1}]	48208	delivery	5	13
128206	2020-08-28 20:01:24	2020-08-28	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6962	pick-up	0	31
128207	2020-08-28 20:03:34	2020-08-28	12	[{"id_menu":1,"count":1}]	11531	delivery	5	17
128208	2020-08-28 20:04:36	2020-08-28	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	16389	delivery	5	28
128209	2020-08-28 20:04:57	2020-08-28	12	[{"id_menu":3,"count":1}]	678	pick-up	0	12
128210	2020-08-28 20:05:08	2020-08-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5425	delivery	5	22
128211	2020-08-28 20:08:31	2020-08-28	9	[{"id_menu":7,"count":1}]	10203	delivery	5	14
128212	2020-08-28 20:09:31	2020-08-28	17	[{"id_menu":4,"count":1}]	7341	delivery	5	22
128213	2020-08-28 20:17:46	2020-08-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	26615	delivery	5	23
128214	2020-08-28 20:18:09	2020-08-28	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26742	delivery	5	49
128215	2020-08-28 20:21:45	2020-08-28	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	46049	delivery	5	43
128216	2020-08-28 20:22:41	2020-08-28	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	44197	delivery	5	31
128217	2020-08-28 20:26:41	2020-08-28	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	3522	delivery	5	40
128218	2020-08-28 20:29:40	2020-08-28	12	[{"id_menu":1,"count":1}]	48287	pick-up	0	12
128219	2020-08-28 20:32:26	2020-08-28	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	47047	delivery	5	34
128220	2020-08-28 20:33:09	2020-08-28	17	[{"id_menu":4,"count":1}]	48348	delivery	5	22
128221	2020-08-28 20:33:48	2020-08-28	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48397	delivery	5	31
128222	2020-08-28 20:38:45	2020-08-28	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	47803	delivery	5	38
128223	2020-08-28 20:39:43	2020-08-28	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	25279	pick-up	0	29
128224	2020-08-28 20:41:57	2020-08-28	17	[{"id_menu":4,"count":1}]	1075	pick-up	0	17
128225	2020-08-28 20:41:58	2020-08-28	17	[{"id_menu":4,"count":1}]	7461	delivery	5	22
128226	2020-08-28 20:42:24	2020-08-28	9	[{"id_menu":6,"count":1}]	5202	delivery	5	14
128227	2020-08-28 20:43:59	2020-08-28	9	[{"id_menu":7,"count":1}]	48362	delivery	5	14
128228	2020-08-28 20:49:18	2020-08-28	17	[{"id_menu":4,"count":1}]	48309	delivery	5	22
128229	2020-08-28 20:50:24	2020-08-28	14	[{"id_menu":2,"count":1}]	1654	delivery	5	19
128230	2020-08-28 20:50:51	2020-08-28	9	[{"id_menu":7,"count":1}]	18366	delivery	5	14
128231	2020-08-28 20:52:27	2020-08-28	12	[{"id_menu":3,"count":1}]	48239	delivery	5	17
128232	2020-08-28 20:53:36	2020-08-28	14	[{"id_menu":2,"count":1}]	16652	delivery	5	19
128233	2020-08-28 20:54:36	2020-08-28	9	[{"id_menu":7,"count":1}]	10847	pick-up	0	9
128234	2020-08-28 20:57:08	2020-08-28	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	270	delivery	5	29
128235	2020-08-28 20:57:14	2020-08-28	9	[{"id_menu":6,"count":1}]	33180	pick-up	0	9
128236	2020-08-28 20:59:53	2020-08-28	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23788	delivery	5	34
128237	2020-08-28 21:01:30	2020-08-28	9	[{"id_menu":6,"count":1}]	48346	delivery	5	14
128238	2020-08-28 21:06:47	2020-08-28	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	39982	delivery	5	26
128239	2020-08-28 21:08:18	2020-08-28	9	[{"id_menu":7,"count":1}]	21253	delivery	5	14
128240	2020-08-28 21:09:18	2020-08-28	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	5104	delivery	5	28
128241	2020-08-28 21:10:03	2020-08-28	12	[{"id_menu":1,"count":1}]	18948	delivery	5	17
128242	2020-08-28 21:11:29	2020-08-28	9	[{"id_menu":6,"count":1}]	17003	delivery	5	14
128243	2020-08-28 21:13:09	2020-08-28	14	[{"id_menu":2,"count":1}]	6807	pick-up	0	14
128244	2020-08-28 21:14:28	2020-08-28	14	[{"id_menu":2,"count":1}]	13574	delivery	5	19
128245	2020-08-28 21:15:10	2020-08-28	14	[{"id_menu":2,"count":1}]	48374	delivery	5	19
128246	2020-08-28 21:15:30	2020-08-28	9	[{"id_menu":6,"count":2}]	3029	pick-up	0	9
128247	2020-08-28 21:16:30	2020-08-28	9	[{"id_menu":6,"count":1}]	48278	delivery	5	14
128248	2020-08-28 21:16:31	2020-08-28	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	1932	pick-up	0	29
128249	2020-08-28 21:17:31	2020-08-28	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	593	pick-up	0	29
128250	2020-08-28 21:21:58	2020-08-28	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28441	delivery	5	36
128251	2020-08-28 21:27:50	2020-08-28	8	[{"id_menu":5,"count":1}]	12437	pick-up	0	8
128252	2020-08-28 21:30:18	2020-08-28	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	48274	delivery	5	39
128253	2020-08-28 21:30:46	2020-08-28	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	29003	delivery	5	23
128254	2020-08-28 21:33:58	2020-08-28	8	[{"id_menu":5,"count":1}]	48406	delivery	5	13
128255	2020-08-28 21:34:25	2020-08-28	32	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	23263	delivery	5	37
128256	2020-08-28 21:38:13	2020-08-28	14	[{"id_menu":2,"count":1}]	32883	pick-up	0	14
128257	2020-08-28 21:43:57	2020-08-28	8	[{"id_menu":5,"count":1}]	48212	delivery	5	13
128258	2020-08-28 21:44:44	2020-08-28	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17837	delivery	5	22
128259	2020-08-28 21:47:42	2020-08-28	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38507	delivery	5	40
128260	2020-08-28 21:48:22	2020-08-28	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	24984	delivery	5	43
128261	2020-08-28 21:50:56	2020-08-28	17	[{"id_menu":4,"count":1}]	18379	delivery	5	22
128262	2020-08-28 21:52:19	2020-08-28	8	[{"id_menu":5,"count":1}]	28283	pick-up	0	8
128263	2020-08-28 21:52:50	2020-08-28	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48412	delivery	5	52
128264	2020-08-28 21:54:01	2020-08-28	8	[{"id_menu":5,"count":1}]	12889	pick-up	0	8
128265	2020-08-28 21:54:55	2020-08-28	12	[{"id_menu":1,"count":1}]	33251	pick-up	0	12
128266	2020-08-28 21:55:49	2020-08-28	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	23939	pick-up	0	25
128267	2020-08-28 21:57:29	2020-08-28	9	[{"id_menu":6,"count":1}]	48396	delivery	5	14
128268	2020-08-28 22:01:18	2020-08-28	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	34524	delivery	5	31
128269	2020-08-28 22:02:58	2020-08-28	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	21142	delivery	5	36
128270	2020-08-28 22:03:25	2020-08-28	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	14057	delivery	5	40
128271	2020-08-28 22:03:48	2020-08-28	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	7626	pick-up	0	37
128272	2020-08-28 22:09:45	2020-08-28	17	[{"id_menu":4,"count":1}]	37530	pick-up	0	17
128273	2020-08-28 22:10:02	2020-08-28	12	[{"id_menu":1,"count":1}]	11843	pick-up	0	12
128274	2020-08-28 22:12:47	2020-08-28	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	47944	delivery	5	28
128275	2020-08-28 22:15:41	2020-08-28	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	48197	delivery	5	26
128276	2020-08-28 22:16:51	2020-08-28	12	[{"id_menu":1,"count":1}]	32545	delivery	5	17
128277	2020-08-28 22:18:24	2020-08-28	9	[{"id_menu":6,"count":2}]	48196	delivery	5	14
128278	2020-08-28 22:19:55	2020-08-28	17	[{"id_menu":4,"count":1}]	30255	delivery	5	22
128279	2020-08-28 22:20:57	2020-08-28	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	48323	delivery	5	31
128280	2020-08-28 22:29:33	2020-08-28	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	48286	delivery	5	22
128281	2020-08-28 22:34:07	2020-08-28	9	[{"id_menu":7,"count":1}]	40007	delivery	5	14
128282	2020-08-28 22:35:04	2020-08-28	14	[{"id_menu":2,"count":1}]	40510	delivery	5	19
128283	2020-08-28 22:35:37	2020-08-28	12	[{"id_menu":1,"count":1}]	48229	delivery	5	17
128284	2020-08-28 22:37:26	2020-08-28	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	19566	delivery	5	43
128285	2020-08-28 22:43:25	2020-08-28	8	[{"id_menu":5,"count":1}]	10216	delivery	5	13
128286	2020-08-28 22:44:58	2020-08-28	12	[{"id_menu":1,"count":1}]	48277	delivery	5	17
128287	2020-08-28 22:46:27	2020-08-28	9	[{"id_menu":6,"count":1}]	48263	delivery	5	14
128288	2020-08-28 22:47:20	2020-08-28	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	32020	delivery	5	27
128289	2020-08-28 22:48:44	2020-08-28	9	[{"id_menu":7,"count":3}]	14469	delivery	5	14
128290	2020-08-28 22:49:04	2020-08-28	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	46358	delivery	5	28
128291	2020-08-28 22:57:37	2020-08-28	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	41818	delivery	5	34
128292	2020-08-28 22:59:04	2020-08-28	8	[{"id_menu":5,"count":1}]	42772	pick-up	0	8
128293	2020-08-28 23:00:54	2020-08-28	12	[{"id_menu":3,"count":1}]	48233	delivery	5	17
128294	2020-08-28 23:04:37	2020-08-28	17	[{"id_menu":4,"count":1}]	21430	delivery	5	22
128295	2020-08-28 23:05:21	2020-08-28	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	48250	delivery	5	34
128296	2020-08-28 23:08:01	2020-08-28	9	[{"id_menu":6,"count":1}]	47815	delivery	5	14
128297	2020-08-28 23:08:42	2020-08-28	17	[{"id_menu":4,"count":1}]	29576	delivery	5	22
128298	2020-08-28 23:12:15	2020-08-28	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1215	pick-up	0	26
128299	2020-08-28 23:12:45	2020-08-28	9	[{"id_menu":6,"count":1}]	25044	delivery	5	14
128300	2020-08-28 23:12:59	2020-08-28	8	[{"id_menu":5,"count":1}]	48304	delivery	5	13
128301	2020-08-28 23:13:13	2020-08-28	12	[{"id_menu":1,"count":1}]	48334	delivery	5	17
128302	2020-08-28 23:13:38	2020-08-28	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	20136	delivery	5	34
128303	2020-08-28 23:14:06	2020-08-28	17	[{"id_menu":4,"count":1}]	37248	delivery	5	22
128304	2020-08-28 23:14:20	2020-08-28	12	[{"id_menu":3,"count":1}]	13858	pick-up	0	12
128305	2020-08-28 23:14:39	2020-08-28	12	[{"id_menu":3,"count":1}]	48358	delivery	5	17
128306	2020-08-28 23:14:41	2020-08-28	9	[{"id_menu":6,"count":2}]	42627	delivery	5	14
128307	2020-08-28 23:18:00	2020-08-28	17	[{"id_menu":4,"count":1}]	8651	delivery	5	22
128308	2020-08-28 23:21:39	2020-08-28	9	[{"id_menu":6,"count":1}]	48354	delivery	5	14
128309	2020-08-28 23:21:50	2020-08-28	14	[{"id_menu":2,"count":1}]	26694	pick-up	0	14
128310	2020-08-28 23:24:24	2020-08-28	12	[{"id_menu":3,"count":1}]	6786	delivery	5	17
128311	2020-08-28 23:25:01	2020-08-28	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	21910	pick-up	0	20
128312	2020-08-28 23:25:09	2020-08-28	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	48218	delivery	5	28
128313	2020-08-28 23:26:51	2020-08-28	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39891	delivery	5	31
128314	2020-08-28 23:29:02	2020-08-28	8	[{"id_menu":5,"count":1}]	6379	delivery	5	13
128315	2020-08-28 23:29:18	2020-08-28	14	[{"id_menu":2,"count":1}]	3539	pick-up	0	14
128316	2020-08-28 23:35:19	2020-08-28	9	[{"id_menu":7,"count":1}]	5047	pick-up	0	9
128317	2020-08-28 23:36:06	2020-08-28	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	11013	delivery	5	26
128318	2020-08-28 23:41:11	2020-08-28	17	[{"id_menu":4,"count":1}]	362	delivery	5	22
128319	2020-08-28 23:44:58	2020-08-28	9	[{"id_menu":6,"count":1}]	25944	pick-up	0	9
128320	2020-08-28 23:48:10	2020-08-28	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	20408	pick-up	0	23
128321	2020-08-28 23:48:52	2020-08-28	9	[{"id_menu":6,"count":1}]	28432	delivery	5	14
128322	2020-08-28 23:50:23	2020-08-28	12	[{"id_menu":1,"count":1}]	26651	pick-up	0	12
128323	2020-08-28 23:50:37	2020-08-28	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48293	delivery	5	37
128324	2020-08-28 23:53:28	2020-08-28	17	[{"id_menu":4,"count":1}]	4646	delivery	5	22
128325	2020-08-28 23:54:11	2020-08-28	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	34485	delivery	5	39
128326	2020-08-28 23:54:57	2020-08-28	9	[{"id_menu":6,"count":1}]	24511	delivery	5	14
128327	2020-08-28 23:55:23	2020-08-28	12	[{"id_menu":3,"count":1}]	48371	delivery	5	17
128328	2020-08-28 23:59:07	2020-08-28	14	[{"id_menu":2,"count":1}]	48282	delivery	5	19
128329	2020-08-29 00:00:26	2020-08-29	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	29394	delivery	5	34
128330	2020-08-29 00:03:04	2020-08-29	17	[{"id_menu":4,"count":1}]	21562	delivery	5	22
128331	2020-08-29 00:07:43	2020-08-29	12	[{"id_menu":3,"count":1}]	48614	pick-up	0	12
128332	2020-08-29 00:09:08	2020-08-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27313	delivery	5	23
128333	2020-08-29 00:09:13	2020-08-29	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	24899	delivery	5	43
128334	2020-08-29 00:10:30	2020-08-29	9	[{"id_menu":6,"count":1}]	48707	pick-up	0	9
128335	2020-08-29 00:11:11	2020-08-29	8	[{"id_menu":5,"count":1}]	48599	delivery	5	13
128336	2020-08-29 00:11:23	2020-08-29	9	[{"id_menu":6,"count":1}]	45186	pick-up	0	9
128337	2020-08-29 00:15:20	2020-08-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27011	delivery	5	23
128338	2020-08-29 00:16:58	2020-08-29	9	[{"id_menu":6,"count":1}]	22572	delivery	5	14
128339	2020-08-29 00:17:15	2020-08-29	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	17532	delivery	5	34
128340	2020-08-29 00:21:23	2020-08-29	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	7025	delivery	5	26
128341	2020-08-29 00:21:31	2020-08-29	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	23349	delivery	5	30
128342	2020-08-29 00:22:34	2020-08-29	9	[{"id_menu":6,"count":1}]	48463	delivery	5	14
128343	2020-08-29 00:23:57	2020-08-29	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	24688	delivery	5	34
128344	2020-08-29 00:24:58	2020-08-29	8	[{"id_menu":5,"count":1}]	48559	delivery	5	13
128345	2020-08-29 00:28:40	2020-08-29	9	[{"id_menu":6,"count":1}]	48590	delivery	5	14
128346	2020-08-29 00:28:55	2020-08-29	12	[{"id_menu":1,"count":1}]	8873	delivery	5	17
128347	2020-08-29 00:31:01	2020-08-29	12	[{"id_menu":1,"count":1}]	48634	delivery	5	17
128348	2020-08-29 00:32:32	2020-08-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	16820	delivery	5	26
128349	2020-08-29 00:33:50	2020-08-29	9	[{"id_menu":6,"count":1}]	34078	delivery	5	14
128350	2020-08-29 00:34:32	2020-08-29	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	15048	pick-up	0	31
128351	2020-08-29 00:34:36	2020-08-29	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	18125	delivery	5	26
128352	2020-08-29 00:36:14	2020-08-29	9	[{"id_menu":6,"count":1}]	2744	pick-up	0	9
128353	2020-08-29 00:37:42	2020-08-29	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	21612	pick-up	0	38
128354	2020-08-29 00:38:49	2020-08-29	14	[{"id_menu":2,"count":1}]	48677	pick-up	0	14
128355	2020-08-29 00:44:46	2020-08-29	9	[{"id_menu":7,"count":1}]	22463	delivery	5	14
128356	2020-08-29 00:45:38	2020-08-29	12	[{"id_menu":3,"count":1}]	24956	delivery	5	17
128357	2020-08-29 00:46:04	2020-08-29	9	[{"id_menu":6,"count":1}]	48464	delivery	5	14
128358	2020-08-29 00:49:53	2020-08-29	9	[{"id_menu":6,"count":2}]	21541	delivery	5	14
128359	2020-08-29 00:53:26	2020-08-29	9	[{"id_menu":7,"count":1}]	48723	delivery	5	14
128360	2020-08-29 00:54:24	2020-08-29	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	37272	delivery	5	34
128361	2020-08-29 00:56:07	2020-08-29	9	[{"id_menu":7,"count":1}]	12384	delivery	5	14
128362	2020-08-29 00:59:19	2020-08-29	17	[{"id_menu":4,"count":2}]	10421	delivery	5	22
128363	2020-08-29 00:59:53	2020-08-29	12	[{"id_menu":1,"count":1}]	1506	delivery	5	17
128364	2020-08-29 01:00:25	2020-08-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	48731	delivery	5	26
128365	2020-08-29 01:02:43	2020-08-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	16404	delivery	5	26
128366	2020-08-29 01:03:22	2020-08-29	14	[{"id_menu":2,"count":1}]	48500	delivery	5	19
128367	2020-08-29 01:03:33	2020-08-29	8	[{"id_menu":5,"count":1}]	24766	pick-up	0	8
128368	2020-08-29 01:04:07	2020-08-29	17	[{"id_menu":4,"count":2}]	7051	delivery	5	22
128369	2020-08-29 01:10:49	2020-08-29	17	[{"id_menu":4,"count":1}]	25532	pick-up	0	17
128370	2020-08-29 01:11:11	2020-08-29	9	[{"id_menu":6,"count":1}]	2691	pick-up	0	9
128371	2020-08-29 01:12:49	2020-08-29	12	[{"id_menu":1,"count":1}]	11359	pick-up	0	12
128372	2020-08-29 01:14:31	2020-08-29	12	[{"id_menu":3,"count":1}]	47432	delivery	5	17
128373	2020-08-29 01:17:23	2020-08-29	8	[{"id_menu":5,"count":2}]	48746	delivery	5	13
128374	2020-08-29 01:18:03	2020-08-29	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	39536	pick-up	0	31
128375	2020-08-29 01:20:20	2020-08-29	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":2}]	1324	delivery	5	22
128376	2020-08-29 01:21:00	2020-08-29	8	[{"id_menu":5,"count":1}]	21553	pick-up	0	8
128377	2020-08-29 01:21:20	2020-08-29	14	[{"id_menu":2,"count":1}]	3213	delivery	5	19
128378	2020-08-29 01:21:22	2020-08-29	9	[{"id_menu":6,"count":2}]	27791	delivery	5	14
128379	2020-08-29 01:21:34	2020-08-29	12	[{"id_menu":1,"count":1}]	25295	pick-up	0	12
128380	2020-08-29 01:21:43	2020-08-29	17	[{"id_menu":4,"count":1}]	23884	delivery	5	22
128381	2020-08-29 01:22:46	2020-08-29	9	[{"id_menu":6,"count":1}]	48242	delivery	5	14
128382	2020-08-29 01:23:08	2020-08-29	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	8435	delivery	5	35
128383	2020-08-29 01:23:51	2020-08-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48736	pick-up	0	18
128384	2020-08-29 01:24:23	2020-08-29	9	[{"id_menu":7,"count":1}]	33520	delivery	5	14
128385	2020-08-29 01:28:57	2020-08-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37515	delivery	5	23
128386	2020-08-29 01:30:03	2020-08-29	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	48650	delivery	5	31
128387	2020-08-29 01:33:15	2020-08-29	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	5473	delivery	5	45
128388	2020-08-29 01:33:46	2020-08-29	9	[{"id_menu":6,"count":1}]	48574	delivery	5	14
128389	2020-08-29 01:35:34	2020-08-29	9	[{"id_menu":7,"count":1}]	40906	delivery	5	14
128390	2020-08-29 01:36:19	2020-08-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	25696	delivery	5	22
128391	2020-08-29 01:36:21	2020-08-29	9	[{"id_menu":6,"count":1}]	48715	delivery	5	14
128392	2020-08-29 01:36:39	2020-08-29	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	48703	delivery	5	39
128393	2020-08-29 01:39:09	2020-08-29	12	[{"id_menu":1,"count":1}]	48671	delivery	5	17
128394	2020-08-29 01:39:50	2020-08-29	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32620	delivery	5	39
128395	2020-08-29 01:40:01	2020-08-29	12	[{"id_menu":3,"count":1}]	48549	delivery	5	17
128396	2020-08-29 01:40:05	2020-08-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	37217	delivery	5	31
128397	2020-08-29 01:42:44	2020-08-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31583	delivery	5	23
128398	2020-08-29 01:43:17	2020-08-29	17	[{"id_menu":4,"count":1}]	48539	delivery	5	22
128399	2020-08-29 01:43:40	2020-08-29	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48522	delivery	5	54
128400	2020-08-29 01:43:50	2020-08-29	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	21907	delivery	5	40
128401	2020-08-29 01:45:07	2020-08-29	9	[{"id_menu":7,"count":1}]	48592	delivery	5	14
128402	2020-08-29 01:45:39	2020-08-29	12	[{"id_menu":3,"count":1}]	26408	pick-up	0	12
128403	2020-08-29 01:47:41	2020-08-29	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	48485	delivery	5	40
128404	2020-08-29 01:50:42	2020-08-29	9	[{"id_menu":6,"count":1}]	15907	pick-up	0	9
128405	2020-08-29 01:54:03	2020-08-29	34	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	48511	delivery	5	39
128406	2020-08-29 01:56:12	2020-08-29	9	[{"id_menu":6,"count":1}]	14372	delivery	5	14
128407	2020-08-29 01:59:49	2020-08-29	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	35836	delivery	5	34
128408	2020-08-29 01:59:58	2020-08-29	14	[{"id_menu":2,"count":2}]	6090	delivery	5	19
128409	2020-08-29 02:00:45	2020-08-29	12	[{"id_menu":1,"count":1}]	11407	pick-up	0	12
128410	2020-08-29 02:01:00	2020-08-29	12	[{"id_menu":1,"count":1}]	4370	pick-up	0	12
128411	2020-08-29 02:01:23	2020-08-29	12	[{"id_menu":1,"count":1}]	48699	delivery	5	17
128412	2020-08-29 02:03:49	2020-08-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	38241	delivery	5	28
128413	2020-08-29 02:04:14	2020-08-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	36853	delivery	5	22
128414	2020-08-29 02:05:27	2020-08-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	24869	delivery	5	26
128415	2020-08-29 02:06:29	2020-08-29	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	48653	delivery	5	25
128416	2020-08-29 02:08:17	2020-08-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	19851	delivery	5	28
128417	2020-08-29 02:11:15	2020-08-29	9	[{"id_menu":7,"count":1}]	48532	delivery	5	14
128418	2020-08-29 02:16:35	2020-08-29	8	[{"id_menu":5,"count":1}]	42978	delivery	5	13
128419	2020-08-29 02:17:11	2020-08-29	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	46326	delivery	5	34
128420	2020-08-29 02:20:17	2020-08-29	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	8726	delivery	5	40
128421	2020-08-29 02:20:42	2020-08-29	9	[{"id_menu":6,"count":1}]	13707	pick-up	0	9
128422	2020-08-29 02:22:13	2020-08-29	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":2}]	47989	delivery	5	31
128423	2020-08-29 02:22:34	2020-08-29	14	[{"id_menu":2,"count":1}]	48553	delivery	5	19
128424	2020-08-29 02:24:09	2020-08-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	25061	delivery	5	28
128425	2020-08-29 02:25:35	2020-08-29	9	[{"id_menu":6,"count":1}]	28912	delivery	5	14
128426	2020-08-29 02:28:38	2020-08-29	14	[{"id_menu":2,"count":1}]	48635	delivery	5	19
128427	2020-08-29 02:31:06	2020-08-29	17	[{"id_menu":4,"count":1}]	48469	delivery	5	22
128428	2020-08-29 02:31:17	2020-08-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	32116	delivery	5	31
128429	2020-08-29 02:32:04	2020-08-29	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	2820	pick-up	0	26
128430	2020-08-29 02:32:21	2020-08-29	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48694	delivery	5	37
128431	2020-08-29 02:34:12	2020-08-29	12	[{"id_menu":3,"count":1}]	31214	delivery	5	17
128432	2020-08-29 02:34:13	2020-08-29	12	[{"id_menu":1,"count":1}]	48379	pick-up	0	12
128433	2020-08-29 02:34:27	2020-08-29	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	25125	delivery	5	39
128434	2020-08-29 02:34:40	2020-08-29	14	[{"id_menu":2,"count":1}]	19442	pick-up	0	14
128435	2020-08-29 02:35:15	2020-08-29	14	[{"id_menu":2,"count":1}]	48453	delivery	5	19
128436	2020-08-29 02:35:42	2020-08-29	12	[{"id_menu":3,"count":1}]	29164	delivery	5	17
128437	2020-08-29 02:36:33	2020-08-29	8	[{"id_menu":5,"count":1}]	24848	delivery	5	13
128438	2020-08-29 02:36:58	2020-08-29	9	[{"id_menu":7,"count":2}]	47478	delivery	5	14
128439	2020-08-29 02:39:20	2020-08-29	9	[{"id_menu":7,"count":1}]	26014	delivery	5	14
128440	2020-08-29 02:39:32	2020-08-29	14	[{"id_menu":2,"count":1}]	23881	pick-up	0	14
128441	2020-08-29 02:41:09	2020-08-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17075	delivery	5	22
128442	2020-08-29 02:43:48	2020-08-29	12	[{"id_menu":3,"count":1}]	8108	delivery	5	17
128443	2020-08-29 02:44:30	2020-08-29	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	36980	pick-up	0	31
128444	2020-08-29 02:44:54	2020-08-29	9	[{"id_menu":6,"count":1}]	27703	delivery	5	14
128445	2020-08-29 02:45:41	2020-08-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	13403	delivery	5	27
128446	2020-08-29 02:47:16	2020-08-29	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	46837	delivery	5	45
128447	2020-08-29 02:47:46	2020-08-29	9	[{"id_menu":7,"count":1}]	6885	pick-up	0	9
128448	2020-08-29 02:50:25	2020-08-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	45589	delivery	5	31
128449	2020-08-29 02:51:31	2020-08-29	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48443	delivery	5	40
128450	2020-08-29 02:51:32	2020-08-29	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	48698	delivery	5	25
128451	2020-08-29 02:54:40	2020-08-29	14	[{"id_menu":2,"count":1}]	45327	delivery	5	19
128452	2020-08-29 02:56:12	2020-08-29	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	8027	delivery	5	42
128453	2020-08-29 02:56:31	2020-08-29	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36922	delivery	5	37
128454	2020-08-29 02:59:46	2020-08-29	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	48745	delivery	5	37
128455	2020-08-29 03:01:39	2020-08-29	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	48619	delivery	5	34
128456	2020-08-29 03:05:00	2020-08-29	9	[{"id_menu":6,"count":1}]	20812	delivery	5	14
128457	2020-08-29 03:05:39	2020-08-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	48461	pick-up	0	26
128458	2020-08-29 03:07:58	2020-08-29	14	[{"id_menu":2,"count":1}]	48546	delivery	5	19
128459	2020-08-29 03:08:35	2020-08-29	9	[{"id_menu":7,"count":1}]	48444	delivery	5	14
128460	2020-08-29 03:09:17	2020-08-29	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	48521	delivery	5	36
128461	2020-08-29 03:09:25	2020-08-29	12	[{"id_menu":3,"count":1}]	27775	pick-up	0	12
128462	2020-08-29 03:11:32	2020-08-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	46640	pick-up	0	21
128463	2020-08-29 03:11:50	2020-08-29	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	39061	delivery	5	34
128464	2020-08-29 03:12:15	2020-08-29	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	1207	delivery	5	37
128465	2020-08-29 03:13:11	2020-08-29	14	[{"id_menu":2,"count":1}]	48486	delivery	5	19
128466	2020-08-29 03:14:14	2020-08-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2780	pick-up	0	26
128467	2020-08-29 03:17:44	2020-08-29	9	[{"id_menu":6,"count":1}]	17271	delivery	5	14
128468	2020-08-29 03:18:17	2020-08-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	47544	delivery	5	23
128469	2020-08-29 03:19:20	2020-08-29	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33227	delivery	5	52
128470	2020-08-29 03:20:06	2020-08-29	9	[{"id_menu":6,"count":1}]	48584	delivery	5	14
128471	2020-08-29 03:20:23	2020-08-29	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	24870	pick-up	0	38
128472	2020-08-29 03:20:41	2020-08-29	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48509	delivery	5	43
128473	2020-08-29 03:21:06	2020-08-29	12	[{"id_menu":1,"count":1}]	48648	delivery	5	17
128474	2020-08-29 03:21:34	2020-08-29	17	[{"id_menu":4,"count":1}]	48658	delivery	5	22
128475	2020-08-29 03:22:29	2020-08-29	9	[{"id_menu":6,"count":1}]	41002	delivery	5	14
128476	2020-08-29 03:22:46	2020-08-29	14	[{"id_menu":2,"count":1}]	31018	delivery	5	19
128477	2020-08-29 03:24:39	2020-08-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48714	delivery	5	23
128478	2020-08-29 03:27:28	2020-08-29	8	[{"id_menu":5,"count":1}]	9493	delivery	5	13
128479	2020-08-29 03:28:11	2020-08-29	14	[{"id_menu":2,"count":1}]	9804	pick-up	0	14
128480	2020-08-29 03:34:35	2020-08-29	9	[{"id_menu":7,"count":1}]	25548	pick-up	0	9
128481	2020-08-29 03:35:28	2020-08-29	9	[{"id_menu":7,"count":1}]	1333	delivery	5	14
128482	2020-08-29 03:35:39	2020-08-29	9	[{"id_menu":7,"count":1}]	48711	delivery	5	14
128483	2020-08-29 03:36:02	2020-08-29	8	[{"id_menu":5,"count":1}]	48662	delivery	5	13
128484	2020-08-29 03:36:04	2020-08-29	14	[{"id_menu":2,"count":1}]	39587	pick-up	0	14
128485	2020-08-29 03:37:24	2020-08-29	9	[{"id_menu":6,"count":1}]	3743	delivery	5	14
128486	2020-08-29 03:38:05	2020-08-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48595	delivery	5	23
128487	2020-08-29 03:38:30	2020-08-29	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	48730	delivery	5	26
128488	2020-08-29 03:38:55	2020-08-29	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	7254	delivery	5	37
128489	2020-08-29 03:41:10	2020-08-29	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	30609	delivery	5	53
128490	2020-08-29 03:43:12	2020-08-29	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	40564	pick-up	0	31
128491	2020-08-29 03:44:25	2020-08-29	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	28893	delivery	5	45
128492	2020-08-29 03:44:37	2020-08-29	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39810	delivery	5	45
128493	2020-08-29 03:49:20	2020-08-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	5839	pick-up	0	17
128494	2020-08-29 03:50:08	2020-08-29	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	44456	delivery	5	35
128495	2020-08-29 03:50:14	2020-08-29	9	[{"id_menu":6,"count":2}]	3160	pick-up	0	9
128496	2020-08-29 03:51:27	2020-08-29	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	13467	pick-up	0	26
128497	2020-08-29 03:53:13	2020-08-29	14	[{"id_menu":2,"count":1}]	17337	delivery	5	19
128498	2020-08-29 03:53:21	2020-08-29	9	[{"id_menu":6,"count":1}]	41094	delivery	5	14
128499	2020-08-29 03:53:59	2020-08-29	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48295	delivery	5	52
128500	2020-08-29 03:55:06	2020-08-29	8	[{"id_menu":5,"count":1}]	42516	delivery	5	13
128501	2020-08-29 03:56:21	2020-08-29	12	[{"id_menu":1,"count":1}]	10908	delivery	5	17
128502	2020-08-29 03:56:42	2020-08-29	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	48587	pick-up	0	48
128503	2020-08-29 03:56:53	2020-08-29	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	48710	delivery	5	39
128504	2020-08-29 03:56:57	2020-08-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	38457	delivery	5	22
128505	2020-08-29 04:01:04	2020-08-29	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	48598	delivery	5	28
128506	2020-08-29 04:01:34	2020-08-29	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	15442	delivery	5	26
128507	2020-08-29 04:05:33	2020-08-29	9	[{"id_menu":6,"count":3}]	48697	delivery	5	14
128508	2020-08-29 04:06:05	2020-08-29	9	[{"id_menu":6,"count":1}]	41797	delivery	5	14
128509	2020-08-29 04:06:16	2020-08-29	8	[{"id_menu":5,"count":1}]	48683	delivery	5	13
128510	2020-08-29 04:14:33	2020-08-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	46433	delivery	5	36
128511	2020-08-29 04:15:43	2020-08-29	9	[{"id_menu":7,"count":1}]	48724	delivery	5	14
128512	2020-08-29 04:16:32	2020-08-29	14	[{"id_menu":2,"count":1}]	4192	delivery	5	19
128513	2020-08-29 04:19:09	2020-08-29	17	[{"id_menu":4,"count":1}]	7275	pick-up	0	17
128514	2020-08-29 04:23:02	2020-08-29	14	[{"id_menu":2,"count":1}]	44706	delivery	5	19
128515	2020-08-29 04:24:25	2020-08-29	17	[{"id_menu":4,"count":1}]	1138	pick-up	0	17
128516	2020-08-29 04:27:56	2020-08-29	12	[{"id_menu":1,"count":1}]	2776	delivery	5	17
128517	2020-08-29 04:30:13	2020-08-29	9	[{"id_menu":7,"count":1}]	22320	delivery	5	14
128518	2020-08-29 04:30:23	2020-08-29	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	42798	pick-up	0	26
128519	2020-08-29 04:31:32	2020-08-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	8852	delivery	5	31
128520	2020-08-29 04:31:36	2020-08-29	14	[{"id_menu":2,"count":2}]	33706	pick-up	0	14
128521	2020-08-29 04:33:49	2020-08-29	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	27506	delivery	5	26
128522	2020-08-29 04:34:03	2020-08-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	29974	pick-up	0	23
128523	2020-08-29 04:36:22	2020-08-29	8	[{"id_menu":5,"count":1}]	43688	delivery	5	13
128524	2020-08-29 04:40:36	2020-08-29	14	[{"id_menu":2,"count":1}]	8363	delivery	5	19
128525	2020-08-29 04:41:29	2020-08-29	14	[{"id_menu":2,"count":1}]	37937	delivery	5	19
128526	2020-08-29 04:42:39	2020-08-29	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	35284	delivery	5	28
128527	2020-08-29 04:42:45	2020-08-29	9	[{"id_menu":6,"count":1}]	45653	delivery	5	14
128528	2020-08-29 04:45:45	2020-08-29	8	[{"id_menu":5,"count":1}]	2411	pick-up	0	8
128529	2020-08-29 04:46:03	2020-08-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	20816	delivery	5	27
128530	2020-08-29 04:51:10	2020-08-29	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	48727	pick-up	0	20
128531	2020-08-29 04:51:47	2020-08-29	8	[{"id_menu":5,"count":1}]	31076	pick-up	0	8
128532	2020-08-29 04:52:37	2020-08-29	12	[{"id_menu":3,"count":1}]	48649	delivery	5	17
128533	2020-08-29 04:52:50	2020-08-29	17	[{"id_menu":4,"count":1}]	48528	delivery	5	22
128534	2020-08-29 04:53:38	2020-08-29	9	[{"id_menu":6,"count":1}]	19288	delivery	5	14
128535	2020-08-29 04:54:52	2020-08-29	12	[{"id_menu":3,"count":1}]	25970	delivery	5	17
128536	2020-08-29 04:55:31	2020-08-29	9	[{"id_menu":6,"count":1}]	48627	delivery	5	14
128537	2020-08-29 04:55:50	2020-08-29	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	24729	delivery	5	27
128538	2020-08-29 04:56:22	2020-08-29	17	[{"id_menu":4,"count":1}]	2282	delivery	5	22
128539	2020-08-29 04:58:36	2020-08-29	9	[{"id_menu":6,"count":1}]	48632	delivery	5	14
128540	2020-08-29 04:59:11	2020-08-29	17	[{"id_menu":4,"count":1}]	46135	delivery	5	22
128541	2020-08-29 05:00:31	2020-08-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	48452	pick-up	0	21
128542	2020-08-29 05:02:01	2020-08-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	16498	delivery	5	27
128543	2020-08-29 05:03:44	2020-08-29	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	24690	delivery	5	31
128544	2020-08-29 05:05:47	2020-08-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	48475	delivery	5	28
128545	2020-08-29 05:05:59	2020-08-29	9	[{"id_menu":7,"count":1}]	32262	delivery	5	14
128546	2020-08-29 05:06:41	2020-08-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	48535	delivery	5	28
128547	2020-08-29 05:07:30	2020-08-29	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3701	delivery	5	39
128548	2020-08-29 05:08:01	2020-08-29	9	[{"id_menu":7,"count":1}]	22844	pick-up	0	9
128549	2020-08-29 05:10:08	2020-08-29	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	19619	delivery	5	45
128550	2020-08-29 05:13:23	2020-08-29	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	36925	delivery	5	23
128551	2020-08-29 05:15:59	2020-08-29	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	38732	delivery	5	45
128552	2020-08-29 05:17:54	2020-08-29	9	[{"id_menu":6,"count":1}]	15578	delivery	5	14
128553	2020-08-29 05:22:08	2020-08-29	14	[{"id_menu":2,"count":1}]	12590	pick-up	0	14
128554	2020-08-29 05:22:32	2020-08-29	12	[{"id_menu":1,"count":1}]	30664	delivery	5	17
128555	2020-08-29 05:22:40	2020-08-29	9	[{"id_menu":6,"count":1}]	33998	delivery	5	14
128556	2020-08-29 05:23:26	2020-08-29	9	[{"id_menu":7,"count":1}]	40679	delivery	5	14
128557	2020-08-29 05:23:43	2020-08-29	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	48457	delivery	5	22
128558	2020-08-29 05:23:45	2020-08-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	48638	delivery	5	27
128559	2020-08-29 05:24:14	2020-08-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14927	delivery	5	23
128560	2020-08-29 05:26:18	2020-08-29	14	[{"id_menu":2,"count":1}]	47905	delivery	5	19
128561	2020-08-29 05:29:03	2020-08-29	9	[{"id_menu":7,"count":1}]	28237	delivery	5	14
128562	2020-08-29 05:30:55	2020-08-29	12	[{"id_menu":1,"count":1}]	48514	pick-up	0	12
128563	2020-08-29 05:32:22	2020-08-29	17	[{"id_menu":4,"count":1}]	37627	delivery	5	22
128564	2020-08-29 05:33:48	2020-08-29	9	[{"id_menu":6,"count":1}]	30455	pick-up	0	9
128565	2020-08-29 05:36:04	2020-08-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	39642	delivery	5	31
128566	2020-08-29 05:38:19	2020-08-29	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	45152	delivery	5	36
128567	2020-08-29 05:39:08	2020-08-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	18828	delivery	5	28
128568	2020-08-29 05:41:17	2020-08-29	9	[{"id_menu":7,"count":2}]	48660	delivery	5	14
128569	2020-08-29 05:43:06	2020-08-29	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	12053	pick-up	0	24
128570	2020-08-29 05:43:25	2020-08-29	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	30976	pick-up	0	26
128571	2020-08-29 05:45:10	2020-08-29	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23384	delivery	5	51
128572	2020-08-29 05:47:32	2020-08-29	14	[{"id_menu":2,"count":1}]	48743	delivery	5	19
128573	2020-08-29 05:49:31	2020-08-29	9	[{"id_menu":7,"count":1}]	19697	delivery	5	14
128574	2020-08-29 05:52:34	2020-08-29	8	[{"id_menu":5,"count":1}]	42254	delivery	5	13
128575	2020-08-29 05:54:01	2020-08-29	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	28456	pick-up	0	29
128576	2020-08-29 05:55:01	2020-08-29	9	[{"id_menu":7,"count":1}]	13413	delivery	5	14
128577	2020-08-29 05:56:35	2020-08-29	9	[{"id_menu":7,"count":1}]	39635	pick-up	0	9
128578	2020-08-29 05:59:05	2020-08-29	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48704	delivery	5	43
128579	2020-08-29 06:02:02	2020-08-29	8	[{"id_menu":5,"count":2}]	41657	delivery	5	13
128580	2020-08-29 06:02:44	2020-08-29	14	[{"id_menu":2,"count":1}]	1072	delivery	5	19
128581	2020-08-29 06:03:55	2020-08-29	9	[{"id_menu":6,"count":1}]	46793	delivery	5	14
128582	2020-08-29 06:04:17	2020-08-29	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	44354	delivery	5	39
128583	2020-08-29 06:04:43	2020-08-29	9	[{"id_menu":7,"count":1}]	48689	delivery	5	14
128584	2020-08-29 06:08:34	2020-08-29	17	[{"id_menu":4,"count":1}]	31472	pick-up	0	17
128585	2020-08-29 06:10:50	2020-08-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	5671	delivery	5	22
128586	2020-08-29 06:21:32	2020-08-29	9	[{"id_menu":7,"count":1}]	13958	delivery	5	14
128587	2020-08-29 06:23:10	2020-08-29	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	48459	delivery	5	34
128588	2020-08-29 06:23:41	2020-08-29	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4047	delivery	5	31
128589	2020-08-29 06:24:00	2020-08-29	12	[{"id_menu":1,"count":1}]	690	pick-up	0	12
128590	2020-08-29 06:24:31	2020-08-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	33334	delivery	5	26
128591	2020-08-29 06:26:31	2020-08-29	9	[{"id_menu":7,"count":1}]	45929	delivery	5	14
128592	2020-08-29 06:26:42	2020-08-29	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	9114	delivery	5	30
128593	2020-08-29 06:26:56	2020-08-29	9	[{"id_menu":7,"count":1}]	19181	pick-up	0	9
128594	2020-08-29 06:31:48	2020-08-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	24959	delivery	5	28
128595	2020-08-29 06:33:26	2020-08-29	9	[{"id_menu":7,"count":1}]	34780	delivery	5	14
128596	2020-08-29 06:34:01	2020-08-29	9	[{"id_menu":6,"count":2}]	1670	delivery	5	14
128597	2020-08-29 06:34:32	2020-08-29	12	[{"id_menu":3,"count":1}]	48600	pick-up	0	12
128598	2020-08-29 06:36:07	2020-08-29	8	[{"id_menu":5,"count":1}]	27455	delivery	5	13
128599	2020-08-29 06:38:10	2020-08-29	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	14593	pick-up	0	37
128600	2020-08-29 06:39:05	2020-08-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	48526	delivery	5	23
128601	2020-08-29 06:41:22	2020-08-29	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	32886	delivery	5	43
128602	2020-08-29 06:41:25	2020-08-29	14	[{"id_menu":2,"count":1}]	9348	pick-up	0	14
128603	2020-08-29 06:42:38	2020-08-29	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	5097	delivery	5	29
128604	2020-08-29 06:46:35	2020-08-29	17	[{"id_menu":4,"count":1}]	48685	delivery	5	22
128605	2020-08-29 06:51:04	2020-08-29	12	[{"id_menu":1,"count":1}]	48456	delivery	5	17
128606	2020-08-29 06:52:44	2020-08-29	14	[{"id_menu":2,"count":1}]	6666	delivery	5	19
128607	2020-08-29 06:53:08	2020-08-29	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9870	delivery	5	43
128608	2020-08-29 06:53:33	2020-08-29	12	[{"id_menu":1,"count":2}]	48637	pick-up	0	12
128609	2020-08-29 06:54:54	2020-08-29	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48618	delivery	5	52
128610	2020-08-29 06:55:43	2020-08-29	17	[{"id_menu":4,"count":1}]	2771	delivery	5	22
128611	2020-08-29 06:56:37	2020-08-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":3}]	33962	delivery	5	31
128612	2020-08-29 07:00:06	2020-08-29	17	[{"id_menu":4,"count":1}]	30313	delivery	5	22
128613	2020-08-29 07:00:11	2020-08-29	8	[{"id_menu":5,"count":1}]	14853	delivery	5	13
128614	2020-08-29 07:00:13	2020-08-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6439	pick-up	0	17
128615	2020-08-29 07:02:00	2020-08-29	17	[{"id_menu":4,"count":1}]	17861	pick-up	0	17
128616	2020-08-29 07:02:09	2020-08-29	9	[{"id_menu":6,"count":1}]	48620	delivery	5	14
128617	2020-08-29 07:03:26	2020-08-29	14	[{"id_menu":2,"count":1}]	4793	delivery	5	19
128618	2020-08-29 07:05:49	2020-08-29	14	[{"id_menu":2,"count":1}]	20667	pick-up	0	14
128619	2020-08-29 07:05:53	2020-08-29	14	[{"id_menu":2,"count":2}]	48734	delivery	5	19
128620	2020-08-29 07:06:54	2020-08-29	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	762	delivery	5	31
128621	2020-08-29 07:09:39	2020-08-29	14	[{"id_menu":2,"count":1}]	33211	delivery	5	19
128622	2020-08-29 07:11:34	2020-08-29	22	[{"id_menu":2,"count":3},{"id_menu":5,"count":1}]	48625	delivery	5	27
128623	2020-08-29 07:12:06	2020-08-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29666	delivery	5	36
128624	2020-08-29 07:13:34	2020-08-29	9	[{"id_menu":7,"count":1}]	8543	pick-up	0	9
128625	2020-08-29 07:14:52	2020-08-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	48680	delivery	5	28
128626	2020-08-29 07:16:02	2020-08-29	14	[{"id_menu":2,"count":1}]	291	delivery	5	19
128627	2020-08-29 07:17:39	2020-08-29	12	[{"id_menu":1,"count":1}]	48712	delivery	5	17
128628	2020-08-29 07:21:16	2020-08-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37870	delivery	5	23
128629	2020-08-29 07:21:54	2020-08-29	9	[{"id_menu":7,"count":1}]	26784	delivery	5	14
128630	2020-08-29 07:22:45	2020-08-29	17	[{"id_menu":4,"count":1}]	18944	delivery	5	22
128631	2020-08-29 07:24:59	2020-08-29	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	37419	delivery	5	39
128632	2020-08-29 07:25:54	2020-08-29	17	[{"id_menu":4,"count":1}]	1619	delivery	5	22
128633	2020-08-29 07:29:46	2020-08-29	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	48621	delivery	5	34
128634	2020-08-29 07:29:52	2020-08-29	9	[{"id_menu":7,"count":1}]	7730	delivery	5	14
128635	2020-08-29 07:32:06	2020-08-29	14	[{"id_menu":2,"count":1}]	18304	pick-up	0	14
128636	2020-08-29 07:33:41	2020-08-29	17	[{"id_menu":4,"count":1}]	43911	delivery	5	22
128637	2020-08-29 07:34:29	2020-08-29	12	[{"id_menu":1,"count":1}]	20907	delivery	5	17
128638	2020-08-29 07:38:48	2020-08-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11455	delivery	5	36
128639	2020-08-29 07:38:53	2020-08-29	12	[{"id_menu":3,"count":1}]	38536	pick-up	0	12
128640	2020-08-29 07:41:50	2020-08-29	9	[{"id_menu":7,"count":1}]	48622	delivery	5	14
128641	2020-08-29 07:42:44	2020-08-29	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48445	delivery	5	45
128642	2020-08-29 07:43:54	2020-08-29	9	[{"id_menu":7,"count":1}]	36773	delivery	5	14
128643	2020-08-29 07:45:55	2020-08-29	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	48611	delivery	5	23
128644	2020-08-29 07:47:25	2020-08-29	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	3774	pick-up	0	48
128645	2020-08-29 07:48:10	2020-08-29	9	[{"id_menu":7,"count":1}]	48610	delivery	5	14
128646	2020-08-29 07:49:09	2020-08-29	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	41772	delivery	5	39
128647	2020-08-29 07:49:46	2020-08-29	8	[{"id_menu":5,"count":1}]	12043	delivery	5	13
128648	2020-08-29 07:51:23	2020-08-29	8	[{"id_menu":5,"count":1}]	16399	delivery	5	13
128649	2020-08-29 07:51:28	2020-08-29	9	[{"id_menu":7,"count":1}]	5815	delivery	5	14
128650	2020-08-29 07:51:53	2020-08-29	9	[{"id_menu":6,"count":3}]	22837	delivery	5	14
128651	2020-08-29 07:52:38	2020-08-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	33667	pick-up	0	26
128652	2020-08-29 07:55:33	2020-08-29	9	[{"id_menu":7,"count":1}]	12286	delivery	5	14
128653	2020-08-29 07:55:52	2020-08-29	9	[{"id_menu":6,"count":1}]	2538	delivery	5	14
128654	2020-08-29 07:57:55	2020-08-29	9	[{"id_menu":7,"count":1}]	48672	delivery	5	14
128655	2020-08-29 07:59:39	2020-08-29	12	[{"id_menu":1,"count":1}]	17093	delivery	5	17
128656	2020-08-29 08:00:08	2020-08-29	14	[{"id_menu":2,"count":1}]	16226	pick-up	0	14
128657	2020-08-29 08:01:28	2020-08-29	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	39666	delivery	5	26
128658	2020-08-29 08:02:19	2020-08-29	12	[{"id_menu":1,"count":1}]	48666	pick-up	0	12
128659	2020-08-29 08:02:57	2020-08-29	9	[{"id_menu":6,"count":1}]	48496	delivery	5	14
128660	2020-08-29 08:04:02	2020-08-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	45411	delivery	5	28
128661	2020-08-29 08:05:50	2020-08-29	17	[{"id_menu":4,"count":1}]	48656	delivery	5	22
128662	2020-08-29 08:10:56	2020-08-29	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	40971	delivery	5	40
128663	2020-08-29 08:11:42	2020-08-29	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	48645	delivery	5	34
128664	2020-08-29 08:13:33	2020-08-29	17	[{"id_menu":4,"count":1}]	23380	delivery	5	22
128665	2020-08-29 08:15:10	2020-08-29	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	19931	delivery	5	36
128666	2020-08-29 08:15:47	2020-08-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	44258	delivery	5	26
128667	2020-08-29 08:16:41	2020-08-29	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	21263	delivery	5	57
128668	2020-08-29 08:17:10	2020-08-29	8	[{"id_menu":5,"count":1}]	27602	delivery	5	13
128669	2020-08-29 08:17:18	2020-08-29	14	[{"id_menu":2,"count":1}]	26911	pick-up	0	14
128670	2020-08-29 08:17:38	2020-08-29	8	[{"id_menu":5,"count":1}]	46515	pick-up	0	8
128671	2020-08-29 08:18:53	2020-08-29	14	[{"id_menu":2,"count":1}]	48550	pick-up	0	14
128672	2020-08-29 08:18:54	2020-08-29	12	[{"id_menu":1,"count":1}]	43391	delivery	5	17
128673	2020-08-29 08:18:55	2020-08-29	9	[{"id_menu":7,"count":1}]	48717	delivery	5	14
128674	2020-08-29 08:21:44	2020-08-29	9	[{"id_menu":6,"count":2}]	31236	delivery	5	14
128675	2020-08-29 08:23:00	2020-08-29	12	[{"id_menu":1,"count":1}]	7984	delivery	5	17
128676	2020-08-29 08:23:09	2020-08-29	12	[{"id_menu":1,"count":1}]	27452	delivery	5	17
128677	2020-08-29 08:25:42	2020-08-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44327	delivery	5	23
128678	2020-08-29 08:25:44	2020-08-29	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	40462	delivery	5	43
128679	2020-08-29 08:25:52	2020-08-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	48686	delivery	5	28
128680	2020-08-29 08:26:01	2020-08-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	43245	pick-up	0	18
128681	2020-08-29 08:28:20	2020-08-29	9	[{"id_menu":7,"count":1}]	5356	delivery	5	14
128682	2020-08-29 08:29:05	2020-08-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	32133	pick-up	0	17
128683	2020-08-29 08:32:46	2020-08-29	9	[{"id_menu":7,"count":1}]	34850	delivery	5	14
128684	2020-08-29 08:33:29	2020-08-29	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	44828	delivery	5	40
128685	2020-08-29 08:33:33	2020-08-29	12	[{"id_menu":1,"count":1}]	233	pick-up	0	12
128686	2020-08-29 08:34:17	2020-08-29	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6127	delivery	5	43
128687	2020-08-29 08:34:58	2020-08-29	14	[{"id_menu":2,"count":1}]	13767	pick-up	0	14
128688	2020-08-29 08:35:28	2020-08-29	9	[{"id_menu":7,"count":1}]	4721	pick-up	0	9
128689	2020-08-29 08:36:13	2020-08-29	9	[{"id_menu":7,"count":1}]	29150	delivery	5	14
128690	2020-08-29 08:36:27	2020-08-29	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	48523	delivery	5	39
128691	2020-08-29 08:37:29	2020-08-29	8	[{"id_menu":5,"count":1}]	28638	delivery	5	13
128692	2020-08-29 08:37:43	2020-08-29	9	[{"id_menu":6,"count":2}]	6645	pick-up	0	9
128693	2020-08-29 08:38:17	2020-08-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	48442	delivery	5	31
128694	2020-08-29 08:42:37	2020-08-29	17	[{"id_menu":4,"count":1}]	30424	pick-up	0	17
128695	2020-08-29 08:42:46	2020-08-29	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	48613	delivery	5	34
128696	2020-08-29 08:43:14	2020-08-29	14	[{"id_menu":2,"count":1}]	31161	delivery	5	19
128697	2020-08-29 08:43:56	2020-08-29	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11979	delivery	5	37
128698	2020-08-29 08:45:38	2020-08-29	9	[{"id_menu":6,"count":1}]	48482	delivery	5	14
128699	2020-08-29 08:48:25	2020-08-29	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	48606	delivery	5	39
128700	2020-08-29 08:49:50	2020-08-29	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19049	delivery	5	43
128701	2020-08-29 08:56:54	2020-08-29	9	[{"id_menu":6,"count":1}]	48577	delivery	5	14
128702	2020-08-29 08:59:16	2020-08-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	27583	delivery	5	22
128703	2020-08-29 09:00:34	2020-08-29	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	44985	delivery	5	34
128704	2020-08-29 09:01:41	2020-08-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	38350	delivery	5	26
128705	2020-08-29 09:01:48	2020-08-29	14	[{"id_menu":2,"count":1}]	9787	delivery	5	19
128706	2020-08-29 09:04:09	2020-08-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10388	delivery	5	23
128707	2020-08-29 09:04:26	2020-08-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	48458	delivery	5	28
128708	2020-08-29 09:06:47	2020-08-29	9	[{"id_menu":6,"count":1}]	48661	delivery	5	14
128709	2020-08-29 09:09:33	2020-08-29	12	[{"id_menu":3,"count":1}]	27569	delivery	5	17
128710	2020-08-29 09:09:59	2020-08-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	28808	delivery	5	26
128711	2020-08-29 09:10:50	2020-08-29	9	[{"id_menu":7,"count":1}]	29597	delivery	5	14
128712	2020-08-29 09:11:05	2020-08-29	9	[{"id_menu":7,"count":1}]	35027	delivery	5	14
128713	2020-08-29 09:11:31	2020-08-29	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	48516	delivery	5	31
128714	2020-08-29 09:12:03	2020-08-29	9	[{"id_menu":7,"count":1}]	3170	delivery	5	14
128715	2020-08-29 09:12:10	2020-08-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	48529	delivery	5	27
128716	2020-08-29 09:13:34	2020-08-29	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	9391	delivery	5	39
128717	2020-08-29 09:13:34	2020-08-29	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	40885	delivery	5	42
128785	2020-08-29 10:54:10	2020-08-29	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	48657	delivery	5	26
128718	2020-08-29 09:14:00	2020-08-29	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	44361	delivery	5	48
128719	2020-08-29 09:16:19	2020-08-29	12	[{"id_menu":3,"count":1}]	27332	pick-up	0	12
128720	2020-08-29 09:18:51	2020-08-29	14	[{"id_menu":2,"count":1}]	23001	delivery	5	19
128721	2020-08-29 09:20:43	2020-08-29	12	[{"id_menu":3,"count":1}]	5048	pick-up	0	12
128722	2020-08-29 09:29:32	2020-08-29	14	[{"id_menu":2,"count":1}]	6565	pick-up	0	14
128723	2020-08-29 09:30:33	2020-08-29	12	[{"id_menu":3,"count":1}]	1557	delivery	5	17
128724	2020-08-29 09:31:10	2020-08-29	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	44881	delivery	5	46
128725	2020-08-29 09:31:22	2020-08-29	9	[{"id_menu":6,"count":1}]	295	pick-up	0	9
128726	2020-08-29 09:36:39	2020-08-29	9	[{"id_menu":6,"count":3}]	7388	delivery	5	14
128727	2020-08-29 09:37:09	2020-08-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	16549	pick-up	0	23
128728	2020-08-29 09:41:44	2020-08-29	14	[{"id_menu":2,"count":1}]	48545	delivery	5	19
128729	2020-08-29 09:42:48	2020-08-29	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	48639	delivery	5	31
128730	2020-08-29 09:42:54	2020-08-29	8	[{"id_menu":5,"count":1}]	3961	pick-up	0	8
128731	2020-08-29 09:43:24	2020-08-29	9	[{"id_menu":7,"count":1}]	14756	delivery	5	14
128732	2020-08-29 09:43:45	2020-08-29	12	[{"id_menu":1,"count":1}]	45814	delivery	5	17
128733	2020-08-29 09:43:53	2020-08-29	9	[{"id_menu":7,"count":1}]	32010	delivery	5	14
128734	2020-08-29 09:45:13	2020-08-29	9	[{"id_menu":6,"count":2}]	48732	delivery	5	14
128735	2020-08-29 09:45:39	2020-08-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48725	delivery	5	23
128736	2020-08-29 09:45:40	2020-08-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	30698	delivery	5	31
128737	2020-08-29 09:46:26	2020-08-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48631	delivery	5	23
128738	2020-08-29 09:47:41	2020-08-29	17	[{"id_menu":4,"count":1}]	9757	delivery	5	22
128739	2020-08-29 09:48:47	2020-08-29	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	6737	delivery	5	39
128740	2020-08-29 09:52:19	2020-08-29	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	48492	delivery	5	31
128741	2020-08-29 09:53:01	2020-08-29	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	802	pick-up	0	29
128742	2020-08-29 09:53:37	2020-08-29	12	[{"id_menu":1,"count":1}]	48572	delivery	5	17
128743	2020-08-29 09:56:41	2020-08-29	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	14284	delivery	5	26
128744	2020-08-29 09:57:42	2020-08-29	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48560	delivery	5	54
128745	2020-08-29 09:58:34	2020-08-29	9	[{"id_menu":6,"count":1}]	48555	delivery	5	14
128746	2020-08-29 09:59:37	2020-08-29	9	[{"id_menu":7,"count":1}]	8052	delivery	5	14
128747	2020-08-29 10:00:07	2020-08-29	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	44084	delivery	5	39
128748	2020-08-29 10:00:09	2020-08-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	868	pick-up	0	26
128749	2020-08-29 10:01:09	2020-08-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	48450	delivery	5	27
128750	2020-08-29 10:01:39	2020-08-29	14	[{"id_menu":2,"count":1}]	1569	pick-up	0	14
128751	2020-08-29 10:03:10	2020-08-29	9	[{"id_menu":6,"count":1}]	48474	pick-up	0	9
128752	2020-08-29 10:03:12	2020-08-29	14	[{"id_menu":2,"count":1}]	48473	delivery	5	19
128753	2020-08-29 10:03:30	2020-08-29	9	[{"id_menu":6,"count":1}]	26559	delivery	5	14
128754	2020-08-29 10:03:32	2020-08-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	48720	delivery	5	28
128755	2020-08-29 10:06:13	2020-08-29	9	[{"id_menu":7,"count":1}]	48741	delivery	5	14
128756	2020-08-29 10:06:40	2020-08-29	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	48498	delivery	5	40
128757	2020-08-29 10:08:38	2020-08-29	9	[{"id_menu":6,"count":1}]	11551	delivery	5	14
128758	2020-08-29 10:09:02	2020-08-29	9	[{"id_menu":6,"count":1}]	40656	delivery	5	14
128759	2020-08-29 10:11:00	2020-08-29	12	[{"id_menu":1,"count":1}]	1119	delivery	5	17
128760	2020-08-29 10:11:17	2020-08-29	12	[{"id_menu":3,"count":2}]	48465	delivery	5	17
128761	2020-08-29 10:13:23	2020-08-29	17	[{"id_menu":4,"count":1}]	5217	delivery	5	22
128762	2020-08-29 10:14:41	2020-08-29	12	[{"id_menu":1,"count":1}]	48748	pick-up	0	12
128763	2020-08-29 10:16:36	2020-08-29	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	26728	delivery	5	34
128764	2020-08-29 10:19:31	2020-08-29	12	[{"id_menu":3,"count":1}]	1115	delivery	5	17
128765	2020-08-29 10:21:01	2020-08-29	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	48489	delivery	5	36
128766	2020-08-29 10:23:36	2020-08-29	9	[{"id_menu":6,"count":1}]	102	pick-up	0	9
128767	2020-08-29 10:27:04	2020-08-29	9	[{"id_menu":6,"count":1}]	48454	delivery	5	14
128768	2020-08-29 10:30:15	2020-08-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	32120	delivery	5	28
128769	2020-08-29 10:31:06	2020-08-29	12	[{"id_menu":1,"count":1}]	12752	delivery	5	17
128770	2020-08-29 10:31:24	2020-08-29	17	[{"id_menu":4,"count":1}]	1710	delivery	5	22
128771	2020-08-29 10:34:13	2020-08-29	17	[{"id_menu":4,"count":1}]	3237	delivery	5	22
128772	2020-08-29 10:35:40	2020-08-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	32054	delivery	5	26
128773	2020-08-29 10:36:39	2020-08-29	14	[{"id_menu":2,"count":1}]	48695	delivery	5	19
128774	2020-08-29 10:38:35	2020-08-29	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	48693	pick-up	0	46
128775	2020-08-29 10:39:53	2020-08-29	17	[{"id_menu":4,"count":1}]	27878	pick-up	0	17
128776	2020-08-29 10:41:23	2020-08-29	14	[{"id_menu":2,"count":1}]	42809	pick-up	0	14
128777	2020-08-29 10:43:12	2020-08-29	14	[{"id_menu":2,"count":1}]	38682	delivery	5	19
128778	2020-08-29 10:43:49	2020-08-29	12	[{"id_menu":1,"count":1}]	20708	delivery	5	17
128779	2020-08-29 10:45:35	2020-08-29	22	[{"id_menu":2,"count":3},{"id_menu":5,"count":1}]	43436	delivery	5	27
128780	2020-08-29 10:48:46	2020-08-29	9	[{"id_menu":7,"count":1}]	48519	delivery	5	14
128781	2020-08-29 10:50:21	2020-08-29	9	[{"id_menu":6,"count":1}]	45862	delivery	5	14
128782	2020-08-29 10:51:34	2020-08-29	12	[{"id_menu":1,"count":1}]	27191	pick-up	0	12
128783	2020-08-29 10:51:47	2020-08-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23288	delivery	5	23
128784	2020-08-29 10:52:07	2020-08-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":3}]	26899	delivery	5	26
128786	2020-08-29 10:55:32	2020-08-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	26003	delivery	5	27
128787	2020-08-29 10:55:54	2020-08-29	12	[{"id_menu":1,"count":1}]	24789	delivery	5	17
128788	2020-08-29 10:56:34	2020-08-29	12	[{"id_menu":3,"count":1}]	39340	delivery	5	17
128789	2020-08-29 10:57:23	2020-08-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	48713	delivery	5	26
128790	2020-08-29 10:58:28	2020-08-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	519	delivery	5	23
128791	2020-08-29 10:59:00	2020-08-29	14	[{"id_menu":2,"count":1}]	48705	delivery	5	19
128792	2020-08-29 11:01:16	2020-08-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	23581	pick-up	0	26
128793	2020-08-29 11:01:58	2020-08-29	14	[{"id_menu":2,"count":1}]	30977	delivery	5	19
128794	2020-08-29 11:01:58	2020-08-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5930	delivery	5	36
128795	2020-08-29 11:03:18	2020-08-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	31172	delivery	5	28
128796	2020-08-29 11:03:22	2020-08-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	48558	delivery	5	26
128797	2020-08-29 11:08:24	2020-08-29	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	17680	delivery	5	40
128798	2020-08-29 11:09:20	2020-08-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	22360	delivery	5	28
128799	2020-08-29 11:12:13	2020-08-29	14	[{"id_menu":2,"count":1}]	48563	delivery	5	19
128800	2020-08-29 11:13:53	2020-08-29	14	[{"id_menu":2,"count":1}]	48468	delivery	5	19
128801	2020-08-29 11:14:47	2020-08-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	8755	pick-up	0	26
128802	2020-08-29 11:14:49	2020-08-29	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	25717	delivery	5	25
128803	2020-08-29 11:15:41	2020-08-29	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	46078	delivery	5	31
128804	2020-08-29 11:17:29	2020-08-29	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	48557	delivery	5	42
128805	2020-08-29 11:17:54	2020-08-29	8	[{"id_menu":5,"count":1}]	8054	delivery	5	13
128806	2020-08-29 11:18:12	2020-08-29	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	33250	delivery	5	34
128807	2020-08-29 11:18:31	2020-08-29	12	[{"id_menu":1,"count":2}]	25997	pick-up	0	12
128808	2020-08-29 11:19:19	2020-08-29	9	[{"id_menu":6,"count":1}]	48568	delivery	5	14
128809	2020-08-29 11:21:23	2020-08-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	2962	pick-up	0	21
128810	2020-08-29 11:23:38	2020-08-29	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	41696	delivery	5	26
128811	2020-08-29 11:26:01	2020-08-29	9	[{"id_menu":6,"count":1}]	21867	pick-up	0	9
128812	2020-08-29 11:26:40	2020-08-29	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1415	pick-up	0	31
128813	2020-08-29 11:29:25	2020-08-29	9	[{"id_menu":7,"count":1}]	15361	pick-up	0	9
128814	2020-08-29 11:31:47	2020-08-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17901	pick-up	0	17
128815	2020-08-29 11:32:11	2020-08-29	14	[{"id_menu":2,"count":2}]	48542	delivery	5	19
128816	2020-08-29 11:33:30	2020-08-29	12	[{"id_menu":1,"count":1}]	48551	delivery	5	17
128817	2020-08-29 11:33:36	2020-08-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	48708	delivery	5	22
128818	2020-08-29 11:35:42	2020-08-29	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	24880	delivery	5	35
128819	2020-08-29 11:36:07	2020-08-29	17	[{"id_menu":4,"count":1}]	48515	pick-up	0	17
128820	2020-08-29 11:37:16	2020-08-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	29637	delivery	5	28
128821	2020-08-29 11:38:03	2020-08-29	17	[{"id_menu":4,"count":1}]	42904	delivery	5	22
128822	2020-08-29 11:38:34	2020-08-29	9	[{"id_menu":6,"count":1}]	24511	delivery	5	14
128823	2020-08-29 11:40:46	2020-08-29	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	12394	delivery	5	40
128824	2020-08-29 11:42:20	2020-08-29	14	[{"id_menu":2,"count":1}]	9191	delivery	5	19
128825	2020-08-29 11:43:51	2020-08-29	14	[{"id_menu":2,"count":1}]	48628	delivery	5	19
128826	2020-08-29 11:44:48	2020-08-29	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":2}]	36349	delivery	5	22
128827	2020-08-29 11:45:20	2020-08-29	12	[{"id_menu":1,"count":1}]	48701	pick-up	0	12
128828	2020-08-29 11:46:05	2020-08-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	45772	delivery	5	31
128829	2020-08-29 11:46:36	2020-08-29	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	17391	delivery	5	34
128830	2020-08-29 11:46:43	2020-08-29	14	[{"id_menu":2,"count":1}]	32298	delivery	5	19
128831	2020-08-29 11:48:13	2020-08-29	9	[{"id_menu":6,"count":1}]	14313	delivery	5	14
128832	2020-08-29 11:54:36	2020-08-29	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	48612	delivery	5	39
128833	2020-08-29 11:55:35	2020-08-29	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4287	delivery	5	40
128834	2020-08-29 11:57:31	2020-08-29	17	[{"id_menu":4,"count":1}]	27708	delivery	5	22
128835	2020-08-29 11:58:37	2020-08-29	17	[{"id_menu":4,"count":1}]	12808	pick-up	0	17
128836	2020-08-29 11:59:03	2020-08-29	9	[{"id_menu":7,"count":1}]	39922	delivery	5	14
128837	2020-08-29 12:01:05	2020-08-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	48476	delivery	5	31
128838	2020-08-29 12:04:47	2020-08-29	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	48688	delivery	5	39
128839	2020-08-29 12:05:31	2020-08-29	9	[{"id_menu":7,"count":1}]	41688	pick-up	0	9
128840	2020-08-29 12:07:05	2020-08-29	14	[{"id_menu":2,"count":1}]	18307	delivery	5	19
128841	2020-08-29 12:08:17	2020-08-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	42883	delivery	5	26
128842	2020-08-29 12:09:40	2020-08-29	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	23473	delivery	5	22
128843	2020-08-29 12:09:41	2020-08-29	9	[{"id_menu":7,"count":1}]	28530	delivery	5	14
128844	2020-08-29 12:09:48	2020-08-29	8	[{"id_menu":5,"count":1}]	48629	delivery	5	13
128845	2020-08-29 12:12:30	2020-08-29	12	[{"id_menu":1,"count":2}]	1854	pick-up	0	12
128846	2020-08-29 12:14:55	2020-08-29	14	[{"id_menu":2,"count":1}]	5106	delivery	5	19
128847	2020-08-29 12:15:57	2020-08-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	48467	delivery	5	36
128848	2020-08-29 12:16:17	2020-08-29	14	[{"id_menu":2,"count":1}]	48675	delivery	5	19
128849	2020-08-29 12:16:47	2020-08-29	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	34681	delivery	5	36
128850	2020-08-29 12:16:50	2020-08-29	8	[{"id_menu":5,"count":1}]	4624	pick-up	0	8
128851	2020-08-29 12:18:12	2020-08-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	22570	delivery	5	23
128852	2020-08-29 12:19:46	2020-08-29	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	47693	delivery	5	40
128853	2020-08-29 12:21:33	2020-08-29	9	[{"id_menu":7,"count":2}]	48721	delivery	5	14
128854	2020-08-29 12:23:50	2020-08-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	48566	delivery	5	26
128855	2020-08-29 12:24:08	2020-08-29	17	[{"id_menu":4,"count":1}]	33689	pick-up	0	17
128856	2020-08-29 12:24:21	2020-08-29	14	[{"id_menu":2,"count":1}]	48554	pick-up	0	14
128857	2020-08-29 12:25:09	2020-08-29	17	[{"id_menu":4,"count":1}]	12134	delivery	5	22
128858	2020-08-29 12:28:16	2020-08-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	24389	delivery	5	31
128859	2020-08-29 12:28:53	2020-08-29	8	[{"id_menu":5,"count":1}]	48667	delivery	5	13
128860	2020-08-29 12:29:08	2020-08-29	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	36966	pick-up	0	29
128861	2020-08-29 12:29:13	2020-08-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	48608	delivery	5	27
128862	2020-08-29 12:29:37	2020-08-29	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	38999	delivery	5	51
128863	2020-08-29 12:31:15	2020-08-29	9	[{"id_menu":7,"count":1}]	48581	delivery	5	14
128864	2020-08-29 12:31:53	2020-08-29	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	44376	delivery	5	44
128865	2020-08-29 12:32:34	2020-08-29	9	[{"id_menu":6,"count":1}]	30253	delivery	5	14
128866	2020-08-29 12:34:49	2020-08-29	12	[{"id_menu":1,"count":1}]	24851	delivery	5	17
128867	2020-08-29 12:35:48	2020-08-29	9	[{"id_menu":7,"count":1}]	15155	delivery	5	14
128868	2020-08-29 12:36:26	2020-08-29	9	[{"id_menu":7,"count":1}]	17503	delivery	5	14
128869	2020-08-29 12:36:49	2020-08-29	8	[{"id_menu":5,"count":1}]	13948	delivery	5	13
128870	2020-08-29 12:37:35	2020-08-29	12	[{"id_menu":3,"count":1}]	48624	delivery	5	17
128871	2020-08-29 12:38:54	2020-08-29	8	[{"id_menu":5,"count":1}]	14984	delivery	5	13
128872	2020-08-29 12:39:48	2020-08-29	9	[{"id_menu":6,"count":1}]	20959	delivery	5	14
128873	2020-08-29 12:40:47	2020-08-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	7945	delivery	5	27
128874	2020-08-29 12:41:02	2020-08-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	29052	pick-up	0	26
128875	2020-08-29 12:44:52	2020-08-29	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	34995	delivery	5	37
128876	2020-08-29 12:46:28	2020-08-29	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	48531	delivery	5	34
128877	2020-08-29 12:47:33	2020-08-29	9	[{"id_menu":7,"count":2}]	42090	delivery	5	14
128878	2020-08-29 12:48:15	2020-08-29	9	[{"id_menu":7,"count":1}]	48644	delivery	5	14
128879	2020-08-29 12:48:23	2020-08-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	10495	delivery	5	27
128880	2020-08-29 12:48:46	2020-08-29	9	[{"id_menu":7,"count":1}]	40231	delivery	5	14
128881	2020-08-29 12:51:42	2020-08-29	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	25299	delivery	5	48
128882	2020-08-29 12:53:11	2020-08-29	9	[{"id_menu":6,"count":1}]	25744	delivery	5	14
128883	2020-08-29 12:56:36	2020-08-29	12	[{"id_menu":1,"count":1}]	48716	delivery	5	17
128884	2020-08-29 13:04:05	2020-08-29	12	[{"id_menu":3,"count":1}]	48744	delivery	5	17
128885	2020-08-29 13:08:46	2020-08-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	33654	delivery	5	28
128886	2020-08-29 13:09:05	2020-08-29	9	[{"id_menu":6,"count":2}]	48582	delivery	5	14
128887	2020-08-29 13:11:20	2020-08-29	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	45821	delivery	5	34
128888	2020-08-29 13:11:36	2020-08-29	9	[{"id_menu":7,"count":1}]	48726	delivery	5	14
128889	2020-08-29 13:12:07	2020-08-29	17	[{"id_menu":5,"count":3},{"id_menu":6,"count":1}]	23676	delivery	5	22
128890	2020-08-29 13:12:10	2020-08-29	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	17502	pick-up	0	21
128891	2020-08-29 13:14:02	2020-08-29	12	[{"id_menu":1,"count":1}]	28755	delivery	5	17
128892	2020-08-29 13:16:59	2020-08-29	8	[{"id_menu":5,"count":1}]	3403	pick-up	0	8
128893	2020-08-29 13:17:17	2020-08-29	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	16501	pick-up	0	29
128894	2020-08-29 13:17:49	2020-08-29	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	48466	pick-up	0	29
128895	2020-08-29 13:18:31	2020-08-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	48460	delivery	5	28
128896	2020-08-29 13:19:33	2020-08-29	17	[{"id_menu":4,"count":1}]	48654	delivery	5	22
128897	2020-08-29 13:20:25	2020-08-29	12	[{"id_menu":1,"count":1}]	21265	delivery	5	17
128898	2020-08-29 13:21:19	2020-08-29	9	[{"id_menu":7,"count":1}]	48607	delivery	5	14
128899	2020-08-29 13:23:59	2020-08-29	9	[{"id_menu":6,"count":1}]	48633	delivery	5	14
128900	2020-08-29 13:24:04	2020-08-29	8	[{"id_menu":5,"count":1}]	48636	delivery	5	13
128901	2020-08-29 13:24:57	2020-08-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6341	delivery	5	23
128902	2020-08-29 13:25:27	2020-08-29	9	[{"id_menu":6,"count":1}]	18746	pick-up	0	9
128903	2020-08-29 13:26:16	2020-08-29	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	48679	delivery	5	30
128904	2020-08-29 13:27:18	2020-08-29	9	[{"id_menu":6,"count":1}]	41455	delivery	5	14
128905	2020-08-29 13:29:22	2020-08-29	17	[{"id_menu":4,"count":1}]	4281	delivery	5	22
128906	2020-08-29 13:29:35	2020-08-29	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	48534	delivery	5	37
128907	2020-08-29 13:31:04	2020-08-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	48690	delivery	5	22
128908	2020-08-29 13:31:05	2020-08-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	44522	delivery	5	27
128909	2020-08-29 13:34:51	2020-08-29	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	44223	delivery	5	34
128910	2020-08-29 13:35:52	2020-08-29	8	[{"id_menu":5,"count":1}]	25802	delivery	5	13
128911	2020-08-29 13:35:58	2020-08-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	48663	delivery	5	28
128912	2020-08-29 13:37:44	2020-08-29	12	[{"id_menu":1,"count":1}]	13253	delivery	5	17
128913	2020-08-29 13:40:31	2020-08-29	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	38023	delivery	5	44
128914	2020-08-29 13:42:18	2020-08-29	14	[{"id_menu":2,"count":1}]	24939	delivery	5	19
128915	2020-08-29 13:44:23	2020-08-29	9	[{"id_menu":6,"count":2}]	8040	delivery	5	14
128916	2020-08-29 13:45:15	2020-08-29	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	48494	delivery	5	37
128917	2020-08-29 13:46:11	2020-08-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	25770	pick-up	0	21
128918	2020-08-29 13:48:04	2020-08-29	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	42031	delivery	5	40
128919	2020-08-29 13:48:55	2020-08-29	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	7907	delivery	5	37
128920	2020-08-29 13:49:46	2020-08-29	9	[{"id_menu":6,"count":2}]	48548	delivery	5	14
128921	2020-08-29 13:51:11	2020-08-29	9	[{"id_menu":6,"count":1}]	41507	pick-up	0	9
128922	2020-08-29 13:51:25	2020-08-29	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	48470	pick-up	0	29
128923	2020-08-29 13:52:00	2020-08-29	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	2553	delivery	5	48
128924	2020-08-29 13:52:41	2020-08-29	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	27202	delivery	5	34
128925	2020-08-29 13:53:51	2020-08-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	10604	delivery	5	31
128926	2020-08-29 13:54:56	2020-08-29	8	[{"id_menu":5,"count":2}]	48626	delivery	5	13
128927	2020-08-29 13:57:01	2020-08-29	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	17747	delivery	5	34
128928	2020-08-29 13:57:04	2020-08-29	12	[{"id_menu":3,"count":1}]	7550	pick-up	0	12
128929	2020-08-29 13:57:41	2020-08-29	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17304	delivery	5	43
128930	2020-08-29 14:02:47	2020-08-29	8	[{"id_menu":5,"count":1}]	35124	delivery	5	13
128931	2020-08-29 14:05:01	2020-08-29	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	14553	delivery	5	25
128932	2020-08-29 14:05:08	2020-08-29	9	[{"id_menu":7,"count":1}]	1977	pick-up	0	9
128933	2020-08-29 14:06:29	2020-08-29	12	[{"id_menu":1,"count":2}]	669	pick-up	0	12
128934	2020-08-29 14:12:28	2020-08-29	9	[{"id_menu":6,"count":1}]	39308	delivery	5	14
128935	2020-08-29 14:12:41	2020-08-29	9	[{"id_menu":6,"count":1}]	44413	pick-up	0	9
128936	2020-08-29 14:14:15	2020-08-29	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15057	delivery	5	35
128937	2020-08-29 14:15:35	2020-08-29	9	[{"id_menu":6,"count":1}]	14652	pick-up	0	9
128938	2020-08-29 14:17:30	2020-08-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	42342	delivery	5	23
128939	2020-08-29 14:17:32	2020-08-29	9	[{"id_menu":6,"count":1}]	48718	pick-up	0	9
128940	2020-08-29 14:17:39	2020-08-29	14	[{"id_menu":2,"count":1}]	16183	delivery	5	19
128941	2020-08-29 14:17:40	2020-08-29	8	[{"id_menu":5,"count":1}]	5822	delivery	5	13
128942	2020-08-29 14:18:00	2020-08-29	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	655	pick-up	0	21
128943	2020-08-29 14:19:57	2020-08-29	14	[{"id_menu":2,"count":1}]	48501	delivery	5	19
128944	2020-08-29 14:20:34	2020-08-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	12102	delivery	5	23
128945	2020-08-29 14:22:41	2020-08-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	32259	delivery	5	22
128946	2020-08-29 14:25:00	2020-08-29	14	[{"id_menu":2,"count":1}]	41191	delivery	5	19
128947	2020-08-29 14:30:21	2020-08-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	24379	delivery	5	31
128948	2020-08-29 14:34:39	2020-08-29	14	[{"id_menu":2,"count":1}]	1856	delivery	5	19
128949	2020-08-29 14:35:48	2020-08-29	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	48647	delivery	5	42
128950	2020-08-29 14:40:19	2020-08-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	48505	delivery	5	31
128951	2020-08-29 14:40:29	2020-08-29	9	[{"id_menu":7,"count":1}]	48646	delivery	5	14
128952	2020-08-29 14:40:55	2020-08-29	9	[{"id_menu":6,"count":1}]	32167	delivery	5	14
128953	2020-08-29 14:41:07	2020-08-29	9	[{"id_menu":7,"count":1}]	34105	delivery	5	14
128954	2020-08-29 14:41:54	2020-08-29	9	[{"id_menu":7,"count":1}]	48615	delivery	5	14
128955	2020-08-29 14:42:05	2020-08-29	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	48575	delivery	5	34
128956	2020-08-29 14:44:12	2020-08-29	9	[{"id_menu":6,"count":1}]	8239	delivery	5	14
128957	2020-08-29 14:44:25	2020-08-29	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	48524	delivery	5	43
128958	2020-08-29 14:44:45	2020-08-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	782	delivery	5	31
128959	2020-08-29 14:44:47	2020-08-29	9	[{"id_menu":7,"count":1}]	4001	delivery	5	14
128960	2020-08-29 14:47:23	2020-08-29	14	[{"id_menu":2,"count":1}]	1654	pick-up	0	14
128961	2020-08-29 14:48:54	2020-08-29	14	[{"id_menu":2,"count":1}]	10705	pick-up	0	14
128962	2020-08-29 14:49:46	2020-08-29	17	[{"id_menu":4,"count":1}]	22207	delivery	5	22
128963	2020-08-29 14:50:04	2020-08-29	14	[{"id_menu":2,"count":1}]	27508	delivery	5	19
128964	2020-08-29 14:54:11	2020-08-29	12	[{"id_menu":1,"count":1}]	48684	delivery	5	17
128965	2020-08-29 14:54:27	2020-08-29	9	[{"id_menu":7,"count":1}]	28952	pick-up	0	9
128966	2020-08-29 15:02:37	2020-08-29	17	[{"id_menu":4,"count":1}]	19447	delivery	5	22
128967	2020-08-29 15:06:32	2020-08-29	9	[{"id_menu":6,"count":1}]	48749	delivery	5	14
128968	2020-08-29 15:10:51	2020-08-29	17	[{"id_menu":4,"count":1}]	48722	delivery	5	22
128969	2020-08-29 15:12:58	2020-08-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	17551	delivery	5	22
128970	2020-08-29 15:13:37	2020-08-29	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	48702	delivery	5	43
128971	2020-08-29 15:13:52	2020-08-29	9	[{"id_menu":6,"count":1}]	33855	delivery	5	14
128972	2020-08-29 15:14:09	2020-08-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48740	delivery	5	23
128973	2020-08-29 15:14:56	2020-08-29	14	[{"id_menu":2,"count":2}]	7782	delivery	5	19
128974	2020-08-29 15:15:57	2020-08-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8977	delivery	5	22
128975	2020-08-29 15:16:38	2020-08-29	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	4824	delivery	5	40
128976	2020-08-29 15:18:02	2020-08-29	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	48520	delivery	5	26
128977	2020-08-29 15:20:21	2020-08-29	14	[{"id_menu":2,"count":2}]	35373	delivery	5	19
128978	2020-08-29 15:23:30	2020-08-29	14	[{"id_menu":2,"count":1}]	32846	pick-up	0	14
128979	2020-08-29 15:24:24	2020-08-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":3}]	40016	delivery	5	22
128980	2020-08-29 15:25:11	2020-08-29	9	[{"id_menu":6,"count":1}]	32818	pick-up	0	9
128981	2020-08-29 15:30:25	2020-08-29	12	[{"id_menu":1,"count":1}]	48462	delivery	5	17
128982	2020-08-29 15:32:44	2020-08-29	9	[{"id_menu":7,"count":1}]	15495	delivery	5	14
128983	2020-08-29 15:33:41	2020-08-29	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	43909	delivery	5	34
128984	2020-08-29 15:34:05	2020-08-29	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	41909	delivery	5	45
128985	2020-08-29 15:34:14	2020-08-29	14	[{"id_menu":2,"count":1}]	27299	pick-up	0	14
128986	2020-08-29 15:35:22	2020-08-29	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	30577	delivery	5	34
128987	2020-08-29 15:37:10	2020-08-29	9	[{"id_menu":6,"count":1}]	48676	delivery	5	14
128988	2020-08-29 15:39:00	2020-08-29	9	[{"id_menu":6,"count":1}]	11053	delivery	5	14
128989	2020-08-29 15:40:05	2020-08-29	9	[{"id_menu":7,"count":1}]	46243	delivery	5	14
128990	2020-08-29 15:41:39	2020-08-29	17	[{"id_menu":4,"count":2}]	48491	delivery	5	22
128991	2020-08-29 15:42:41	2020-08-29	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	48547	delivery	5	52
128992	2020-08-29 15:43:51	2020-08-29	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	10256	delivery	5	34
128993	2020-08-29 15:45:02	2020-08-29	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23706	delivery	5	31
128994	2020-08-29 15:45:38	2020-08-29	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48552	delivery	5	43
128995	2020-08-29 15:45:52	2020-08-29	14	[{"id_menu":2,"count":1}]	48525	delivery	5	19
128996	2020-08-29 15:49:41	2020-08-29	14	[{"id_menu":2,"count":1}]	48455	pick-up	0	14
128997	2020-08-29 15:51:32	2020-08-29	17	[{"id_menu":4,"count":1}]	33672	delivery	5	22
128998	2020-08-29 15:51:48	2020-08-29	12	[{"id_menu":3,"count":1}]	48477	delivery	5	17
128999	2020-08-29 15:54:10	2020-08-29	9	[{"id_menu":6,"count":1}]	48652	pick-up	0	9
129000	2020-08-29 15:54:27	2020-08-29	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	10310	delivery	5	26
129001	2020-08-29 15:58:28	2020-08-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48642	delivery	5	23
129002	2020-08-29 16:00:04	2020-08-29	8	[{"id_menu":5,"count":2}]	9465	delivery	5	13
129003	2020-08-29 16:02:05	2020-08-29	14	[{"id_menu":2,"count":1}]	32501	delivery	5	19
129004	2020-08-29 16:03:26	2020-08-29	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	4714	pick-up	0	20
129005	2020-08-29 16:04:22	2020-08-29	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	40393	pick-up	0	40
129006	2020-08-29 16:04:28	2020-08-29	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	26542	delivery	5	31
129007	2020-08-29 16:09:18	2020-08-29	8	[{"id_menu":5,"count":1}]	48742	delivery	5	13
129008	2020-08-29 16:16:40	2020-08-29	14	[{"id_menu":2,"count":1}]	35565	pick-up	0	14
129009	2020-08-29 16:16:53	2020-08-29	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	8635	delivery	5	39
129010	2020-08-29 16:18:54	2020-08-29	9	[{"id_menu":7,"count":1}]	31374	pick-up	0	9
129011	2020-08-29 16:19:16	2020-08-29	17	[{"id_menu":4,"count":1}]	30607	delivery	5	22
129012	2020-08-29 16:22:55	2020-08-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	8121	delivery	5	22
129013	2020-08-29 16:23:22	2020-08-29	17	[{"id_menu":4,"count":1}]	12248	pick-up	0	17
129014	2020-08-29 16:23:46	2020-08-29	12	[{"id_menu":1,"count":1}]	5050	delivery	5	17
129015	2020-08-29 16:27:39	2020-08-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	48700	delivery	5	28
129016	2020-08-29 16:28:45	2020-08-29	17	[{"id_menu":4,"count":1}]	41169	delivery	5	22
129017	2020-08-29 16:29:30	2020-08-29	12	[{"id_menu":1,"count":1}]	48447	pick-up	0	12
129018	2020-08-29 16:29:55	2020-08-29	14	[{"id_menu":2,"count":1}]	40500	delivery	5	19
129019	2020-08-29 16:30:47	2020-08-29	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	48681	delivery	5	43
129020	2020-08-29 16:31:16	2020-08-29	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	48564	delivery	5	42
129021	2020-08-29 16:31:53	2020-08-29	9	[{"id_menu":6,"count":2}]	34839	pick-up	0	9
129022	2020-08-29 16:33:52	2020-08-29	9	[{"id_menu":7,"count":1}]	29647	delivery	5	14
129023	2020-08-29 16:36:48	2020-08-29	12	[{"id_menu":1,"count":1}]	5758	delivery	5	17
129024	2020-08-29 16:36:49	2020-08-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	8064	delivery	5	23
129025	2020-08-29 16:37:15	2020-08-29	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	14432	pick-up	0	25
129026	2020-08-29 16:39:23	2020-08-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27790	delivery	5	23
129027	2020-08-29 16:41:11	2020-08-29	26	[{"id_menu":5,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	42452	delivery	5	31
129028	2020-08-29 16:42:05	2020-08-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	39690	pick-up	0	26
129029	2020-08-29 16:43:09	2020-08-29	9	[{"id_menu":7,"count":1}]	48449	delivery	5	14
129030	2020-08-29 16:46:45	2020-08-29	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	28715	delivery	5	40
129031	2020-08-29 16:47:53	2020-08-29	12	[{"id_menu":3,"count":1}]	552	delivery	5	17
129032	2020-08-29 16:49:14	2020-08-29	17	[{"id_menu":4,"count":1}]	48527	delivery	5	22
129033	2020-08-29 16:52:59	2020-08-29	17	[{"id_menu":4,"count":1}]	48562	delivery	5	22
129034	2020-08-29 16:55:46	2020-08-29	17	[{"id_menu":4,"count":1}]	11543	delivery	5	22
129035	2020-08-29 16:58:27	2020-08-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	13708	delivery	5	31
129036	2020-08-29 17:02:19	2020-08-29	9	[{"id_menu":7,"count":1}]	19218	pick-up	0	9
129037	2020-08-29 17:03:54	2020-08-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	48669	delivery	5	27
129038	2020-08-29 17:04:28	2020-08-29	9	[{"id_menu":7,"count":1}]	48605	delivery	5	14
129039	2020-08-29 17:04:46	2020-08-29	9	[{"id_menu":6,"count":1}]	48706	delivery	5	14
129040	2020-08-29 17:05:20	2020-08-29	9	[{"id_menu":6,"count":1}]	29755	delivery	5	14
129041	2020-08-29 17:05:33	2020-08-29	9	[{"id_menu":6,"count":1}]	1924	pick-up	0	9
129042	2020-08-29 17:07:13	2020-08-29	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	44573	delivery	5	26
129043	2020-08-29 17:08:56	2020-08-29	12	[{"id_menu":3,"count":1}]	48537	delivery	5	17
129044	2020-08-29 17:08:59	2020-08-29	17	[{"id_menu":4,"count":1}]	26984	pick-up	0	17
129045	2020-08-29 17:09:31	2020-08-29	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	48739	delivery	5	31
129046	2020-08-29 17:09:58	2020-08-29	12	[{"id_menu":3,"count":1}]	39344	delivery	5	17
129047	2020-08-29 17:10:00	2020-08-29	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	48517	delivery	5	40
129048	2020-08-29 17:10:07	2020-08-29	12	[{"id_menu":3,"count":1}]	16581	delivery	5	17
129049	2020-08-29 17:10:12	2020-08-29	17	[{"id_menu":4,"count":1}]	27370	delivery	5	22
129050	2020-08-29 17:10:29	2020-08-29	17	[{"id_menu":4,"count":1}]	20353	pick-up	0	17
129051	2020-08-29 17:11:19	2020-08-29	8	[{"id_menu":5,"count":1}]	48544	delivery	5	13
129052	2020-08-29 17:11:53	2020-08-29	9	[{"id_menu":7,"count":1}]	9097	pick-up	0	9
129053	2020-08-29 17:11:59	2020-08-29	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	14928	delivery	5	31
129054	2020-08-29 17:13:05	2020-08-29	8	[{"id_menu":5,"count":1}]	48530	delivery	5	13
129055	2020-08-29 17:15:45	2020-08-29	9	[{"id_menu":7,"count":1}]	48641	delivery	5	14
129056	2020-08-29 17:17:18	2020-08-29	8	[{"id_menu":5,"count":1}]	30947	pick-up	0	8
129057	2020-08-29 17:18:42	2020-08-29	14	[{"id_menu":2,"count":1}]	48659	delivery	5	19
129058	2020-08-29 17:21:55	2020-08-29	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":2}]	48493	delivery	5	22
129059	2020-08-29 17:23:10	2020-08-29	9	[{"id_menu":6,"count":1}]	33833	delivery	5	14
129060	2020-08-29 17:27:02	2020-08-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	19949	delivery	5	23
129061	2020-08-29 17:27:03	2020-08-29	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	48503	delivery	5	34
129062	2020-08-29 17:27:19	2020-08-29	8	[{"id_menu":5,"count":1}]	3804	delivery	5	13
129063	2020-08-29 17:27:20	2020-08-29	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	48536	delivery	5	30
129064	2020-08-29 17:27:44	2020-08-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	46033	delivery	5	31
129065	2020-08-29 17:31:34	2020-08-29	9	[{"id_menu":6,"count":1}]	26353	delivery	5	14
129066	2020-08-29 17:35:00	2020-08-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	32802	delivery	5	28
129067	2020-08-29 17:39:59	2020-08-29	8	[{"id_menu":5,"count":1}]	43400	delivery	5	13
129068	2020-08-29 17:42:04	2020-08-29	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	40614	delivery	5	31
129069	2020-08-29 17:43:53	2020-08-29	12	[{"id_menu":1,"count":1}]	48565	delivery	5	17
129070	2020-08-29 17:44:15	2020-08-29	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	48709	delivery	5	40
129071	2020-08-29 17:47:05	2020-08-29	12	[{"id_menu":3,"count":1}]	48513	delivery	5	17
129072	2020-08-29 17:47:07	2020-08-29	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	30271	delivery	5	35
129073	2020-08-29 17:48:37	2020-08-29	9	[{"id_menu":6,"count":1}]	13753	delivery	5	14
129074	2020-08-29 17:50:06	2020-08-29	8	[{"id_menu":5,"count":1}]	39667	delivery	5	13
129075	2020-08-29 17:50:36	2020-08-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	48729	delivery	5	28
129076	2020-08-29 17:51:59	2020-08-29	47	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	42117	delivery	5	52
129077	2020-08-29 17:54:23	2020-08-29	9	[{"id_menu":7,"count":1}]	47172	delivery	5	14
129078	2020-08-29 18:01:30	2020-08-29	14	[{"id_menu":2,"count":1}]	204	pick-up	0	14
129079	2020-08-29 18:04:54	2020-08-29	17	[{"id_menu":4,"count":1}]	7432	pick-up	0	17
129080	2020-08-29 18:06:07	2020-08-29	12	[{"id_menu":3,"count":1}]	7582	delivery	5	17
129081	2020-08-29 18:09:05	2020-08-29	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48448	delivery	5	49
129082	2020-08-29 18:10:33	2020-08-29	14	[{"id_menu":2,"count":1}]	48518	delivery	5	19
129083	2020-08-29 18:10:56	2020-08-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	6104	delivery	5	31
129084	2020-08-29 18:11:05	2020-08-29	12	[{"id_menu":3,"count":1}]	31061	delivery	5	17
129085	2020-08-29 18:11:42	2020-08-29	8	[{"id_menu":5,"count":1}]	48603	pick-up	0	8
129086	2020-08-29 18:19:53	2020-08-29	9	[{"id_menu":6,"count":1}]	18593	delivery	5	14
129087	2020-08-29 18:19:56	2020-08-29	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	4062	pick-up	0	29
129088	2020-08-29 18:22:59	2020-08-29	8	[{"id_menu":5,"count":1}]	48623	delivery	5	13
129089	2020-08-29 18:25:31	2020-08-29	9	[{"id_menu":7,"count":1}]	48602	pick-up	0	9
129090	2020-08-29 18:25:48	2020-08-29	9	[{"id_menu":6,"count":1}]	43912	delivery	5	14
129091	2020-08-29 18:27:42	2020-08-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	48197	delivery	5	36
129092	2020-08-29 18:27:53	2020-08-29	9	[{"id_menu":7,"count":1}]	29679	delivery	5	14
129093	2020-08-29 18:28:03	2020-08-29	14	[{"id_menu":2,"count":1}]	2091	pick-up	0	14
129094	2020-08-29 18:31:45	2020-08-29	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	5338	delivery	5	26
129095	2020-08-29 18:31:53	2020-08-29	12	[{"id_menu":1,"count":1}]	1321	pick-up	0	12
129096	2020-08-29 18:33:57	2020-08-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	48696	delivery	5	31
129097	2020-08-29 18:34:22	2020-08-29	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	41992	pick-up	0	20
129098	2020-08-29 18:34:27	2020-08-29	17	[{"id_menu":4,"count":1}]	8657	pick-up	0	17
129099	2020-08-29 18:35:03	2020-08-29	14	[{"id_menu":2,"count":1}]	1263	pick-up	0	14
129100	2020-08-29 18:35:12	2020-08-29	14	[{"id_menu":2,"count":1}]	5811	pick-up	0	14
129101	2020-08-29 18:37:36	2020-08-29	12	[{"id_menu":3,"count":1}]	6385	delivery	5	17
129102	2020-08-29 18:38:50	2020-08-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	31737	delivery	5	26
129103	2020-08-29 18:43:44	2020-08-29	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6616	delivery	5	34
129104	2020-08-29 18:44:19	2020-08-29	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	48540	delivery	5	28
129105	2020-08-29 18:44:55	2020-08-29	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	6054	delivery	5	26
129106	2020-08-29 18:45:35	2020-08-29	8	[{"id_menu":5,"count":1}]	1280	pick-up	0	8
129107	2020-08-29 18:46:29	2020-08-29	17	[{"id_menu":4,"count":1}]	47465	delivery	5	22
129108	2020-08-29 18:46:41	2020-08-29	12	[{"id_menu":1,"count":1}]	48665	delivery	5	17
129109	2020-08-29 18:47:26	2020-08-29	9	[{"id_menu":7,"count":1}]	48673	delivery	5	14
129110	2020-08-29 18:48:14	2020-08-29	9	[{"id_menu":7,"count":1}]	35820	delivery	5	14
129111	2020-08-29 18:49:24	2020-08-29	12	[{"id_menu":1,"count":1}]	43882	delivery	5	17
129112	2020-08-29 18:49:51	2020-08-29	9	[{"id_menu":6,"count":1}]	39736	delivery	5	14
129113	2020-08-29 18:49:53	2020-08-29	14	[{"id_menu":2,"count":1}]	42808	delivery	5	19
129114	2020-08-29 18:50:04	2020-08-29	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	38922	delivery	5	57
129115	2020-08-29 18:50:13	2020-08-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	11192	delivery	5	23
129116	2020-08-29 18:54:00	2020-08-29	12	[{"id_menu":1,"count":1}]	42086	delivery	5	17
129117	2020-08-29 18:54:27	2020-08-29	14	[{"id_menu":2,"count":2}]	19965	delivery	5	19
129118	2020-08-29 18:55:39	2020-08-29	9	[{"id_menu":7,"count":1}]	29702	pick-up	0	9
129119	2020-08-29 18:56:46	2020-08-29	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	41493	delivery	5	31
129120	2020-08-29 18:58:19	2020-08-29	9	[{"id_menu":7,"count":1}]	34859	delivery	5	14
129121	2020-08-29 19:01:54	2020-08-29	9	[{"id_menu":6,"count":1}]	2263	delivery	5	14
129122	2020-08-29 19:04:16	2020-08-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":3}]	48691	delivery	5	23
129123	2020-08-29 19:07:19	2020-08-29	17	[{"id_menu":4,"count":1}]	43026	delivery	5	22
129124	2020-08-29 19:08:05	2020-08-29	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	32713	delivery	5	28
129125	2020-08-29 19:08:32	2020-08-29	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":2}]	48506	delivery	5	31
129126	2020-08-29 19:09:20	2020-08-29	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	48692	delivery	5	30
129127	2020-08-29 19:09:56	2020-08-29	9	[{"id_menu":7,"count":1}]	22623	delivery	5	14
129128	2020-08-29 19:10:20	2020-08-29	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	11542	delivery	5	26
129129	2020-08-29 19:11:21	2020-08-29	12	[{"id_menu":1,"count":1}]	14027	delivery	5	17
129130	2020-08-29 19:11:22	2020-08-29	9	[{"id_menu":6,"count":1}]	36478	delivery	5	14
129131	2020-08-29 19:12:56	2020-08-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	48737	delivery	5	23
129132	2020-08-29 19:14:20	2020-08-29	9	[{"id_menu":6,"count":1}]	46978	delivery	5	14
129133	2020-08-29 19:17:27	2020-08-29	9	[{"id_menu":6,"count":1}]	10147	pick-up	0	9
129134	2020-08-29 19:19:41	2020-08-29	8	[{"id_menu":5,"count":1}]	9241	pick-up	0	8
129135	2020-08-29 19:20:06	2020-08-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	22308	delivery	5	36
129136	2020-08-29 19:22:22	2020-08-29	8	[{"id_menu":5,"count":1}]	46423	delivery	5	13
129137	2020-08-29 19:23:26	2020-08-29	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5891	delivery	5	34
129138	2020-08-29 19:24:38	2020-08-29	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	48583	delivery	5	28
129139	2020-08-29 19:25:39	2020-08-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	48487	delivery	5	31
129140	2020-08-29 19:26:16	2020-08-29	14	[{"id_menu":2,"count":1}]	40287	delivery	5	19
129141	2020-08-29 19:26:38	2020-08-29	17	[{"id_menu":4,"count":1}]	15808	delivery	5	22
129142	2020-08-29 19:28:20	2020-08-29	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	19607	delivery	5	39
129143	2020-08-29 19:29:17	2020-08-29	12	[{"id_menu":3,"count":2}]	48597	delivery	5	17
129144	2020-08-29 19:29:58	2020-08-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	6979	delivery	5	28
129145	2020-08-29 19:30:27	2020-08-29	14	[{"id_menu":2,"count":1}]	10994	delivery	5	19
129146	2020-08-29 19:31:28	2020-08-29	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	48733	delivery	5	34
129147	2020-08-29 19:32:59	2020-08-29	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	13068	pick-up	0	21
129148	2020-08-29 19:33:05	2020-08-29	12	[{"id_menu":1,"count":1}]	48484	delivery	5	17
129149	2020-08-29 19:34:04	2020-08-29	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":2}]	5817	delivery	5	31
129150	2020-08-29 19:35:44	2020-08-29	9	[{"id_menu":7,"count":2}]	6800	delivery	5	14
129151	2020-08-29 19:36:08	2020-08-29	12	[{"id_menu":3,"count":1}]	17174	pick-up	0	12
129152	2020-08-29 19:38:09	2020-08-29	9	[{"id_menu":6,"count":1}]	9793	pick-up	0	9
129153	2020-08-29 19:38:43	2020-08-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26600	pick-up	0	18
129154	2020-08-29 19:40:32	2020-08-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	48601	delivery	5	28
129155	2020-08-29 19:43:21	2020-08-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	23663	delivery	5	31
129156	2020-08-29 19:45:33	2020-08-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	48512	delivery	5	26
129157	2020-08-29 19:47:09	2020-08-29	12	[{"id_menu":1,"count":1}]	48735	delivery	5	17
129158	2020-08-29 19:48:48	2020-08-29	14	[{"id_menu":2,"count":1}]	48682	delivery	5	19
129159	2020-08-29 19:50:04	2020-08-29	9	[{"id_menu":7,"count":1}]	9853	delivery	5	14
129160	2020-08-29 19:50:32	2020-08-29	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7212	delivery	5	47
129161	2020-08-29 19:51:25	2020-08-29	9	[{"id_menu":6,"count":1}]	48728	delivery	5	14
129162	2020-08-29 19:53:48	2020-08-29	12	[{"id_menu":1,"count":1}]	23709	pick-up	0	12
129163	2020-08-29 19:55:22	2020-08-29	12	[{"id_menu":3,"count":1}]	9866	delivery	5	17
129164	2020-08-29 20:05:46	2020-08-29	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	19183	pick-up	0	21
129165	2020-08-29 20:06:01	2020-08-29	9	[{"id_menu":6,"count":1}]	14958	delivery	5	14
129166	2020-08-29 20:10:45	2020-08-29	17	[{"id_menu":4,"count":1}]	3870	pick-up	0	17
129167	2020-08-29 20:10:52	2020-08-29	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48507	delivery	5	37
129168	2020-08-29 20:10:58	2020-08-29	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	42958	delivery	5	31
129169	2020-08-29 20:11:19	2020-08-29	12	[{"id_menu":3,"count":1}]	47249	delivery	5	17
129170	2020-08-29 20:11:40	2020-08-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	42952	delivery	5	26
129171	2020-08-29 20:16:36	2020-08-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":3}]	38324	delivery	5	31
129172	2020-08-29 20:17:21	2020-08-29	12	[{"id_menu":3,"count":1}]	21779	delivery	5	17
129173	2020-08-29 20:18:55	2020-08-29	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	48617	delivery	5	29
129174	2020-08-29 20:19:01	2020-08-29	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19398	delivery	5	31
129175	2020-08-29 20:19:20	2020-08-29	9	[{"id_menu":7,"count":1}]	48578	delivery	5	14
129176	2020-08-29 20:19:48	2020-08-29	17	[{"id_menu":4,"count":1}]	20617	delivery	5	22
129177	2020-08-29 20:23:34	2020-08-29	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	26428	delivery	5	34
129178	2020-08-29 20:27:59	2020-08-29	12	[{"id_menu":3,"count":1}]	23312	pick-up	0	12
129179	2020-08-29 20:28:41	2020-08-29	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	16839	delivery	5	28
129180	2020-08-29 20:28:41	2020-08-29	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	27426	delivery	5	22
129181	2020-08-29 20:29:23	2020-08-29	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5000	delivery	5	34
129182	2020-08-29 20:31:22	2020-08-29	9	[{"id_menu":7,"count":1}]	48580	delivery	5	14
129183	2020-08-29 20:32:00	2020-08-29	9	[{"id_menu":7,"count":1}]	19872	delivery	5	14
129184	2020-08-29 20:33:05	2020-08-29	8	[{"id_menu":5,"count":1}]	48670	delivery	5	13
129185	2020-08-29 20:33:15	2020-08-29	9	[{"id_menu":6,"count":1}]	30555	delivery	5	14
129186	2020-08-29 20:33:43	2020-08-29	17	[{"id_menu":4,"count":1}]	48668	delivery	5	22
129187	2020-08-29 20:34:30	2020-08-29	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3399	delivery	5	36
129188	2020-08-29 20:36:42	2020-08-29	14	[{"id_menu":2,"count":1}]	21870	delivery	5	19
129189	2020-08-29 20:36:56	2020-08-29	17	[{"id_menu":4,"count":1}]	43332	delivery	5	22
129190	2020-08-29 20:37:50	2020-08-29	9	[{"id_menu":6,"count":1}]	48588	delivery	5	14
129191	2020-08-29 20:38:22	2020-08-29	14	[{"id_menu":2,"count":2}]	48570	delivery	5	19
129192	2020-08-29 20:40:37	2020-08-29	12	[{"id_menu":3,"count":1}]	12055	delivery	5	17
129193	2020-08-29 20:42:17	2020-08-29	9	[{"id_menu":6,"count":2}]	48569	delivery	5	14
129194	2020-08-29 20:42:58	2020-08-29	12	[{"id_menu":3,"count":1}]	5808	pick-up	0	12
129195	2020-08-29 20:43:48	2020-08-29	14	[{"id_menu":2,"count":2}]	15948	delivery	5	19
129196	2020-08-29 20:44:38	2020-08-29	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	48504	delivery	5	36
129197	2020-08-29 20:44:44	2020-08-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":3}]	8044	delivery	5	31
129198	2020-08-29 20:45:05	2020-08-29	9	[{"id_menu":7,"count":1}]	20013	delivery	5	14
129199	2020-08-29 20:51:26	2020-08-29	12	[{"id_menu":3,"count":1}]	48556	pick-up	0	12
129200	2020-08-29 20:52:05	2020-08-29	14	[{"id_menu":2,"count":1}]	48481	delivery	5	19
129201	2020-08-29 20:54:50	2020-08-29	12	[{"id_menu":3,"count":1}]	24610	pick-up	0	12
129202	2020-08-29 20:56:30	2020-08-29	9	[{"id_menu":6,"count":1}]	39447	delivery	5	14
129203	2020-08-29 20:57:51	2020-08-29	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	48571	delivery	5	34
129204	2020-08-29 21:01:17	2020-08-29	12	[{"id_menu":1,"count":1}]	26490	delivery	5	17
129205	2020-08-29 21:01:21	2020-08-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	48643	delivery	5	26
129206	2020-08-29 21:05:19	2020-08-29	9	[{"id_menu":7,"count":1}]	48678	delivery	5	14
129207	2020-08-29 21:05:27	2020-08-29	17	[{"id_menu":4,"count":1}]	48573	delivery	5	22
129208	2020-08-29 21:07:39	2020-08-29	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	14845	pick-up	0	20
129209	2020-08-29 21:07:51	2020-08-29	14	[{"id_menu":2,"count":1}]	3537	delivery	5	19
129210	2020-08-29 21:07:53	2020-08-29	9	[{"id_menu":7,"count":1}]	2024	pick-up	0	9
129211	2020-08-29 21:08:41	2020-08-29	17	[{"id_menu":4,"count":1}]	48609	delivery	5	22
129212	2020-08-29 21:10:37	2020-08-29	17	[{"id_menu":4,"count":1}]	46430	delivery	5	22
129213	2020-08-29 21:11:32	2020-08-29	9	[{"id_menu":6,"count":1}]	489	pick-up	0	9
129214	2020-08-29 21:11:39	2020-08-29	12	[{"id_menu":3,"count":1}]	2821	delivery	5	17
129215	2020-08-29 21:13:53	2020-08-29	9	[{"id_menu":6,"count":1}]	48488	delivery	5	14
129216	2020-08-29 21:16:07	2020-08-29	14	[{"id_menu":2,"count":1}]	48596	delivery	5	19
129217	2020-08-29 21:17:28	2020-08-29	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	26740	delivery	5	27
129218	2020-08-29 21:18:14	2020-08-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	23128	delivery	5	26
129219	2020-08-29 21:21:10	2020-08-29	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	48747	delivery	5	43
129220	2020-08-29 21:21:51	2020-08-29	12	[{"id_menu":3,"count":1}]	25685	delivery	5	17
129221	2020-08-29 21:28:59	2020-08-29	12	[{"id_menu":3,"count":1}]	48687	delivery	5	17
129222	2020-08-29 21:29:05	2020-08-29	17	[{"id_menu":4,"count":1}]	10218	delivery	5	22
129223	2020-08-29 21:29:53	2020-08-29	17	[{"id_menu":4,"count":2}]	12362	pick-up	0	17
129224	2020-08-29 21:31:06	2020-08-29	9	[{"id_menu":6,"count":1}]	25151	delivery	5	14
129225	2020-08-29 21:31:29	2020-08-29	12	[{"id_menu":3,"count":1}]	48604	delivery	5	17
129226	2020-08-29 21:32:09	2020-08-29	12	[{"id_menu":3,"count":1}]	39809	pick-up	0	12
129227	2020-08-29 21:33:37	2020-08-29	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	19313	pick-up	0	21
129228	2020-08-29 21:34:14	2020-08-29	9	[{"id_menu":6,"count":1}]	48561	delivery	5	14
129229	2020-08-29 21:36:35	2020-08-29	9	[{"id_menu":6,"count":1}]	20065	delivery	5	14
129230	2020-08-29 21:37:30	2020-08-29	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	48472	delivery	5	28
129231	2020-08-29 21:39:29	2020-08-29	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	41150	delivery	5	22
129232	2020-08-29 21:41:59	2020-08-29	12	[{"id_menu":1,"count":1}]	26906	delivery	5	17
129233	2020-08-29 21:46:50	2020-08-29	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	40789	delivery	5	45
129234	2020-08-29 21:47:47	2020-08-29	17	[{"id_menu":4,"count":1}]	48640	delivery	5	22
129235	2020-08-29 21:50:32	2020-08-29	12	[{"id_menu":3,"count":1}]	5192	delivery	5	17
129236	2020-08-29 21:52:08	2020-08-29	14	[{"id_menu":2,"count":1}]	48738	delivery	5	19
129237	2020-08-29 21:54:38	2020-08-29	14	[{"id_menu":2,"count":1}]	21104	delivery	5	19
129238	2020-08-29 21:56:23	2020-08-29	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	40794	pick-up	0	29
129239	2020-08-29 21:58:37	2020-08-29	9	[{"id_menu":6,"count":1}]	48480	delivery	5	14
129240	2020-08-29 22:00:37	2020-08-29	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	35154	delivery	5	31
129241	2020-08-29 22:01:26	2020-08-29	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48541	delivery	5	35
129242	2020-08-29 22:03:18	2020-08-29	9	[{"id_menu":6,"count":1}]	16000	delivery	5	14
129243	2020-08-29 22:07:00	2020-08-29	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	21601	delivery	5	25
129244	2020-08-29 22:07:58	2020-08-29	9	[{"id_menu":6,"count":1}]	48483	delivery	5	14
129245	2020-08-29 22:07:58	2020-08-29	9	[{"id_menu":6,"count":1}]	6068	delivery	5	14
129246	2020-08-29 22:11:24	2020-08-29	9	[{"id_menu":7,"count":1}]	38424	delivery	5	14
129247	2020-08-29 22:14:14	2020-08-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	19279	delivery	5	22
129248	2020-08-29 22:15:35	2020-08-29	12	[{"id_menu":3,"count":1}]	19796	delivery	5	17
129249	2020-08-29 22:19:48	2020-08-29	8	[{"id_menu":5,"count":1}]	17500	pick-up	0	8
129250	2020-08-29 22:20:00	2020-08-29	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48490	delivery	5	37
129316	2020-08-30 00:06:52	2020-08-30	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	12231	delivery	5	26
129251	2020-08-29 22:20:42	2020-08-29	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	48591	delivery	5	44
129252	2020-08-29 22:21:51	2020-08-29	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	48589	delivery	5	43
129253	2020-08-29 22:24:57	2020-08-29	9	[{"id_menu":7,"count":1}]	48655	pick-up	0	9
129254	2020-08-29 22:25:08	2020-08-29	12	[{"id_menu":3,"count":1}]	47400	delivery	5	17
129255	2020-08-29 22:26:03	2020-08-29	8	[{"id_menu":5,"count":2}]	48479	delivery	5	13
129256	2020-08-29 22:26:03	2020-08-29	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	48510	delivery	5	40
129257	2020-08-29 22:28:07	2020-08-29	9	[{"id_menu":6,"count":1}]	3239	delivery	5	14
129258	2020-08-29 22:28:11	2020-08-29	8	[{"id_menu":5,"count":1}]	48502	delivery	5	13
129259	2020-08-29 22:28:13	2020-08-29	9	[{"id_menu":6,"count":1}]	35096	pick-up	0	9
129260	2020-08-29 22:29:07	2020-08-29	9	[{"id_menu":6,"count":1}]	13287	delivery	5	14
129261	2020-08-29 22:32:20	2020-08-29	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	48497	delivery	5	39
129262	2020-08-29 22:33:42	2020-08-29	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	29382	delivery	5	35
129263	2020-08-29 22:34:05	2020-08-29	9	[{"id_menu":7,"count":1}]	48533	delivery	5	14
129264	2020-08-29 22:34:55	2020-08-29	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	37398	delivery	5	22
129265	2020-08-29 22:37:35	2020-08-29	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	26521	delivery	5	45
129266	2020-08-29 22:42:23	2020-08-29	12	[{"id_menu":1,"count":1}]	48576	delivery	5	17
129267	2020-08-29 22:43:59	2020-08-29	12	[{"id_menu":3,"count":2}]	48471	pick-up	0	12
129268	2020-08-29 22:46:28	2020-08-29	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48674	delivery	5	23
129269	2020-08-29 22:47:08	2020-08-29	12	[{"id_menu":3,"count":1}]	3763	delivery	5	17
129270	2020-08-29 22:49:19	2020-08-29	14	[{"id_menu":2,"count":1}]	20631	delivery	5	19
129271	2020-08-29 22:51:07	2020-08-29	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	14610	delivery	5	22
129272	2020-08-29 22:54:54	2020-08-29	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	48543	delivery	5	40
129273	2020-08-29 22:59:03	2020-08-29	9	[{"id_menu":6,"count":1}]	19197	delivery	5	14
129274	2020-08-29 22:59:36	2020-08-29	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	48616	delivery	5	45
129275	2020-08-29 23:06:05	2020-08-29	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	48495	delivery	5	28
129276	2020-08-29 23:09:12	2020-08-29	14	[{"id_menu":2,"count":1}]	3439	pick-up	0	14
129277	2020-08-29 23:09:40	2020-08-29	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8600	delivery	5	34
129278	2020-08-29 23:13:49	2020-08-29	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	48630	delivery	5	26
129279	2020-08-29 23:13:58	2020-08-29	17	[{"id_menu":4,"count":1}]	48585	delivery	5	22
129280	2020-08-29 23:17:12	2020-08-29	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	22941	delivery	5	34
129281	2020-08-29 23:18:32	2020-08-29	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	11586	delivery	5	31
129282	2020-08-29 23:19:05	2020-08-29	17	[{"id_menu":4,"count":1}]	48567	pick-up	0	17
129283	2020-08-29 23:19:16	2020-08-29	25	[{"id_menu":4,"count":3},{"id_menu":5,"count":1}]	25926	delivery	5	30
129284	2020-08-29 23:19:49	2020-08-29	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	40157	delivery	5	45
129285	2020-08-29 23:21:04	2020-08-29	14	[{"id_menu":2,"count":1}]	32924	delivery	5	19
129286	2020-08-29 23:21:06	2020-08-29	12	[{"id_menu":1,"count":1}]	48446	delivery	5	17
129287	2020-08-29 23:21:46	2020-08-29	12	[{"id_menu":1,"count":1}]	18228	pick-up	0	12
129288	2020-08-29 23:22:04	2020-08-29	12	[{"id_menu":3,"count":1}]	19543	delivery	5	17
129289	2020-08-29 23:22:24	2020-08-29	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	8167	pick-up	0	29
129290	2020-08-29 23:24:48	2020-08-29	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	30162	delivery	5	48
129291	2020-08-29 23:26:53	2020-08-29	9	[{"id_menu":6,"count":1}]	11806	delivery	5	14
129292	2020-08-29 23:30:21	2020-08-29	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	44012	delivery	5	43
129293	2020-08-29 23:31:39	2020-08-29	14	[{"id_menu":2,"count":1}]	48478	delivery	5	19
129294	2020-08-29 23:32:56	2020-08-29	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	18461	delivery	5	30
129295	2020-08-29 23:34:58	2020-08-29	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48579	delivery	5	37
129296	2020-08-29 23:35:18	2020-08-29	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	19300	delivery	5	31
129297	2020-08-29 23:36:00	2020-08-29	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16087	delivery	5	40
129298	2020-08-29 23:36:27	2020-08-29	14	[{"id_menu":2,"count":1}]	2631	pick-up	0	14
129299	2020-08-29 23:37:59	2020-08-29	9	[{"id_menu":7,"count":1}]	2180	pick-up	0	9
129300	2020-08-29 23:42:40	2020-08-29	8	[{"id_menu":5,"count":1}]	48719	delivery	5	13
129301	2020-08-29 23:42:55	2020-08-29	12	[{"id_menu":3,"count":1}]	14509	delivery	5	17
129302	2020-08-29 23:44:20	2020-08-29	17	[{"id_menu":4,"count":1}]	39151	delivery	5	22
129303	2020-08-29 23:47:23	2020-08-29	38	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	47580	delivery	5	43
129304	2020-08-29 23:48:15	2020-08-29	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	18106	delivery	5	31
129305	2020-08-29 23:49:33	2020-08-29	12	[{"id_menu":3,"count":1}]	45620	delivery	5	17
129306	2020-08-29 23:49:38	2020-08-29	9	[{"id_menu":6,"count":3}]	30070	delivery	5	14
129307	2020-08-29 23:51:38	2020-08-29	12	[{"id_menu":1,"count":1}]	24517	delivery	5	17
129308	2020-08-29 23:51:43	2020-08-29	14	[{"id_menu":2,"count":1}]	10436	delivery	5	19
129309	2020-08-29 23:54:31	2020-08-29	9	[{"id_menu":6,"count":1}]	45139	delivery	5	14
129310	2020-08-29 23:56:03	2020-08-29	9	[{"id_menu":6,"count":1}]	47158	delivery	5	14
129311	2020-08-30 00:01:08	2020-08-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	28333	delivery	5	28
129312	2020-08-30 00:01:19	2020-08-30	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	45720	delivery	5	31
129313	2020-08-30 00:04:33	2020-08-30	14	[{"id_menu":2,"count":1}]	48501	delivery	5	19
129314	2020-08-30 00:05:17	2020-08-30	9	[{"id_menu":7,"count":1}]	48875	delivery	5	14
129315	2020-08-30 00:05:56	2020-08-30	17	[{"id_menu":4,"count":1}]	48989	delivery	5	22
129317	2020-08-30 00:08:12	2020-08-30	17	[{"id_menu":4,"count":1}]	20353	pick-up	0	17
129318	2020-08-30 00:09:29	2020-08-30	8	[{"id_menu":5,"count":1}]	48874	delivery	5	13
129319	2020-08-30 00:12:41	2020-08-30	9	[{"id_menu":6,"count":1}]	12108	delivery	5	14
129320	2020-08-30 00:12:42	2020-08-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	32325	delivery	5	27
129321	2020-08-30 00:12:48	2020-08-30	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	3318	delivery	5	29
129322	2020-08-30 00:13:24	2020-08-30	9	[{"id_menu":6,"count":1}]	18602	pick-up	0	9
129323	2020-08-30 00:14:25	2020-08-30	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	48806	delivery	5	36
129324	2020-08-30 00:15:46	2020-08-30	9	[{"id_menu":6,"count":1}]	17690	delivery	5	14
129325	2020-08-30 00:17:18	2020-08-30	14	[{"id_menu":2,"count":1}]	43850	delivery	5	19
129326	2020-08-30 00:17:30	2020-08-30	12	[{"id_menu":1,"count":1}]	21872	delivery	5	17
129327	2020-08-30 00:18:21	2020-08-30	9	[{"id_menu":6,"count":1}]	41800	delivery	5	14
129328	2020-08-30 00:18:30	2020-08-30	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":2}]	48797	pick-up	0	38
129329	2020-08-30 00:21:09	2020-08-30	9	[{"id_menu":6,"count":1}]	11634	delivery	5	14
129330	2020-08-30 00:21:20	2020-08-30	12	[{"id_menu":1,"count":1}]	48870	delivery	5	17
129331	2020-08-30 00:21:29	2020-08-30	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	48781	delivery	5	31
129332	2020-08-30 00:22:12	2020-08-30	9	[{"id_menu":6,"count":1}]	48815	delivery	5	14
129333	2020-08-30 00:29:19	2020-08-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48926	delivery	5	23
129334	2020-08-30 00:29:20	2020-08-30	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	49036	delivery	5	22
129335	2020-08-30 00:29:36	2020-08-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	26006	pick-up	0	26
129336	2020-08-30 00:33:26	2020-08-30	12	[{"id_menu":1,"count":1}]	48851	delivery	5	17
129337	2020-08-30 00:34:10	2020-08-30	14	[{"id_menu":2,"count":1}]	43499	delivery	5	19
129338	2020-08-30 00:37:23	2020-08-30	12	[{"id_menu":3,"count":1}]	46308	pick-up	0	12
129339	2020-08-30 00:38:04	2020-08-30	12	[{"id_menu":3,"count":1}]	48981	pick-up	0	12
129340	2020-08-30 00:38:54	2020-08-30	17	[{"id_menu":4,"count":1}]	17172	pick-up	0	17
129341	2020-08-30 00:40:45	2020-08-30	12	[{"id_menu":3,"count":1}]	21016	delivery	5	17
129342	2020-08-30 00:42:04	2020-08-30	9	[{"id_menu":6,"count":1}]	16550	pick-up	0	9
129343	2020-08-30 00:44:01	2020-08-30	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	49025	delivery	5	39
129344	2020-08-30 00:45:32	2020-08-30	9	[{"id_menu":6,"count":1}]	18715	delivery	5	14
129345	2020-08-30 00:45:38	2020-08-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	5730	delivery	5	28
129346	2020-08-30 00:46:20	2020-08-30	17	[{"id_menu":4,"count":1}]	14887	pick-up	0	17
129347	2020-08-30 00:49:32	2020-08-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	48835	delivery	5	27
129348	2020-08-30 00:50:47	2020-08-30	17	[{"id_menu":4,"count":1}]	16853	pick-up	0	17
129349	2020-08-30 00:51:32	2020-08-30	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23478	pick-up	0	41
129350	2020-08-30 00:52:35	2020-08-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	23164	delivery	5	28
129351	2020-08-30 00:55:35	2020-08-30	12	[{"id_menu":1,"count":1}]	34328	pick-up	0	12
129352	2020-08-30 00:56:27	2020-08-30	14	[{"id_menu":2,"count":1}]	8281	delivery	5	19
129353	2020-08-30 00:58:01	2020-08-30	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	29880	delivery	5	42
129354	2020-08-30 00:58:30	2020-08-30	9	[{"id_menu":7,"count":1}]	35850	delivery	5	14
129355	2020-08-30 00:58:33	2020-08-30	14	[{"id_menu":2,"count":1}]	4161	pick-up	0	14
129356	2020-08-30 00:59:46	2020-08-30	12	[{"id_menu":3,"count":1}]	7330	pick-up	0	12
129357	2020-08-30 01:01:02	2020-08-30	12	[{"id_menu":3,"count":2}]	32146	delivery	5	17
129358	2020-08-30 01:03:38	2020-08-30	9	[{"id_menu":6,"count":1}]	22062	delivery	5	14
129359	2020-08-30 01:04:01	2020-08-30	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	46326	delivery	5	36
129360	2020-08-30 01:05:04	2020-08-30	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	48878	delivery	5	39
129361	2020-08-30 01:06:17	2020-08-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	15449	delivery	5	27
129362	2020-08-30 01:06:46	2020-08-30	17	[{"id_menu":4,"count":1}]	35282	delivery	5	22
129363	2020-08-30 01:08:08	2020-08-30	12	[{"id_menu":1,"count":1}]	49032	delivery	5	17
129364	2020-08-30 01:08:40	2020-08-30	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	48757	pick-up	0	24
129365	2020-08-30 01:08:46	2020-08-30	12	[{"id_menu":3,"count":1}]	49028	delivery	5	17
129366	2020-08-30 01:09:59	2020-08-30	17	[{"id_menu":4,"count":1}]	6698	delivery	5	22
129367	2020-08-30 01:12:10	2020-08-30	12	[{"id_menu":1,"count":1}]	2620	delivery	5	17
129368	2020-08-30 01:13:30	2020-08-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	41553	delivery	5	28
129369	2020-08-30 01:19:20	2020-08-30	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	48790	delivery	5	36
129370	2020-08-30 01:22:01	2020-08-30	12	[{"id_menu":3,"count":1}]	6280	delivery	5	17
129371	2020-08-30 01:22:38	2020-08-30	17	[{"id_menu":4,"count":1}]	13388	delivery	5	22
129372	2020-08-30 01:25:12	2020-08-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	7070	delivery	5	28
129373	2020-08-30 01:27:06	2020-08-30	9	[{"id_menu":6,"count":1}]	24632	delivery	5	14
129374	2020-08-30 01:29:24	2020-08-30	9	[{"id_menu":7,"count":1}]	23928	delivery	5	14
129375	2020-08-30 01:31:06	2020-08-30	17	[{"id_menu":4,"count":1}]	47320	delivery	5	22
129376	2020-08-30 01:31:18	2020-08-30	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	9045	delivery	5	34
129377	2020-08-30 01:33:02	2020-08-30	9	[{"id_menu":6,"count":1}]	23551	delivery	5	14
129378	2020-08-30 01:33:57	2020-08-30	8	[{"id_menu":5,"count":1}]	28319	pick-up	0	8
129379	2020-08-30 01:37:56	2020-08-30	8	[{"id_menu":5,"count":1}]	32114	delivery	5	13
129380	2020-08-30 01:40:33	2020-08-30	9	[{"id_menu":6,"count":1}]	4983	delivery	5	14
129381	2020-08-30 01:41:39	2020-08-30	14	[{"id_menu":2,"count":1}]	42079	pick-up	0	14
129382	2020-08-30 01:45:11	2020-08-30	9	[{"id_menu":7,"count":1}]	25682	delivery	5	14
129383	2020-08-30 01:48:46	2020-08-30	9	[{"id_menu":6,"count":1}]	48899	delivery	5	14
129384	2020-08-30 01:49:40	2020-08-30	14	[{"id_menu":2,"count":1}]	21726	delivery	5	19
129385	2020-08-30 01:50:47	2020-08-30	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	32399	pick-up	0	25
129386	2020-08-30 01:52:56	2020-08-30	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	40146	delivery	5	34
129387	2020-08-30 01:54:02	2020-08-30	9	[{"id_menu":6,"count":1}]	35038	delivery	5	14
129388	2020-08-30 01:54:17	2020-08-30	8	[{"id_menu":5,"count":1}]	33230	delivery	5	13
129389	2020-08-30 01:54:28	2020-08-30	9	[{"id_menu":6,"count":2}]	34058	delivery	5	14
129390	2020-08-30 01:56:19	2020-08-30	9	[{"id_menu":6,"count":1}]	48497	delivery	5	14
129391	2020-08-30 01:56:32	2020-08-30	9	[{"id_menu":7,"count":2}]	48818	delivery	5	14
129392	2020-08-30 01:56:40	2020-08-30	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	22900	pick-up	0	26
129393	2020-08-30 01:58:27	2020-08-30	9	[{"id_menu":7,"count":1}]	7697	delivery	5	14
129394	2020-08-30 01:59:22	2020-08-30	12	[{"id_menu":1,"count":1}]	22885	delivery	5	17
129395	2020-08-30 02:01:19	2020-08-30	9	[{"id_menu":7,"count":1}]	3534	delivery	5	14
129396	2020-08-30 02:02:17	2020-08-30	8	[{"id_menu":5,"count":1}]	48957	delivery	5	13
129397	2020-08-30 02:03:14	2020-08-30	8	[{"id_menu":5,"count":1}]	17002	delivery	5	13
129398	2020-08-30 02:05:18	2020-08-30	12	[{"id_menu":1,"count":1}]	48937	delivery	5	17
129399	2020-08-30 02:05:43	2020-08-30	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	40089	delivery	5	31
129400	2020-08-30 02:05:48	2020-08-30	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	25649	delivery	5	48
129401	2020-08-30 02:06:15	2020-08-30	9	[{"id_menu":7,"count":1}]	7695	delivery	5	14
129402	2020-08-30 02:08:41	2020-08-30	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	28616	delivery	5	45
129403	2020-08-30 02:14:14	2020-08-30	17	[{"id_menu":4,"count":1}]	46851	delivery	5	22
129404	2020-08-30 02:14:45	2020-08-30	9	[{"id_menu":6,"count":1}]	315	delivery	5	14
129405	2020-08-30 02:16:33	2020-08-30	9	[{"id_menu":6,"count":1}]	2607	pick-up	0	9
129406	2020-08-30 02:17:07	2020-08-30	8	[{"id_menu":5,"count":1}]	48891	delivery	5	13
129407	2020-08-30 02:22:52	2020-08-30	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	41614	delivery	5	44
129408	2020-08-30 02:24:01	2020-08-30	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	38456	pick-up	0	43
129409	2020-08-30 02:24:14	2020-08-30	9	[{"id_menu":7,"count":1}]	48898	delivery	5	14
129410	2020-08-30 02:25:24	2020-08-30	12	[{"id_menu":3,"count":1}]	5516	pick-up	0	12
129411	2020-08-30 02:25:54	2020-08-30	12	[{"id_menu":1,"count":1}]	16046	delivery	5	17
129412	2020-08-30 02:28:21	2020-08-30	12	[{"id_menu":1,"count":1}]	48862	delivery	5	17
129413	2020-08-30 02:28:44	2020-08-30	12	[{"id_menu":1,"count":1}]	10777	delivery	5	17
129414	2020-08-30 02:30:05	2020-08-30	8	[{"id_menu":5,"count":1}]	48911	delivery	5	13
129415	2020-08-30 02:32:56	2020-08-30	9	[{"id_menu":7,"count":2}]	43669	delivery	5	14
129416	2020-08-30 02:33:09	2020-08-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	49035	delivery	5	27
129417	2020-08-30 02:35:47	2020-08-30	14	[{"id_menu":2,"count":2}]	15827	delivery	5	19
129418	2020-08-30 02:40:09	2020-08-30	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	3719	pick-up	0	31
129419	2020-08-30 02:42:13	2020-08-30	14	[{"id_menu":2,"count":1}]	19883	delivery	5	19
129420	2020-08-30 02:43:20	2020-08-30	9	[{"id_menu":7,"count":1}]	49019	delivery	5	14
129421	2020-08-30 02:44:17	2020-08-30	8	[{"id_menu":5,"count":1}]	40196	delivery	5	13
129422	2020-08-30 02:44:53	2020-08-30	9	[{"id_menu":7,"count":1}]	22223	delivery	5	14
129423	2020-08-30 02:47:07	2020-08-30	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	46993	pick-up	0	29
129424	2020-08-30 02:47:17	2020-08-30	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	33845	delivery	5	26
129425	2020-08-30 02:47:34	2020-08-30	12	[{"id_menu":3,"count":1}]	49006	delivery	5	17
129426	2020-08-30 02:47:37	2020-08-30	8	[{"id_menu":5,"count":1}]	14820	delivery	5	13
129427	2020-08-30 02:48:01	2020-08-30	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	43266	delivery	5	34
129428	2020-08-30 02:48:42	2020-08-30	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	3682	delivery	5	31
129429	2020-08-30 02:52:36	2020-08-30	9	[{"id_menu":7,"count":1}]	601	pick-up	0	9
129430	2020-08-30 02:53:57	2020-08-30	8	[{"id_menu":5,"count":1}]	13134	pick-up	0	8
129431	2020-08-30 02:54:20	2020-08-30	14	[{"id_menu":2,"count":1}]	7418	delivery	5	19
129432	2020-08-30 02:55:33	2020-08-30	9	[{"id_menu":6,"count":1}]	8959	delivery	5	14
129433	2020-08-30 02:56:06	2020-08-30	14	[{"id_menu":2,"count":1}]	42915	delivery	5	19
129434	2020-08-30 02:58:40	2020-08-30	9	[{"id_menu":7,"count":1}]	32366	delivery	5	14
129435	2020-08-30 02:59:08	2020-08-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	23241	pick-up	0	23
129436	2020-08-30 02:59:23	2020-08-30	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	43129	delivery	5	36
129437	2020-08-30 02:59:56	2020-08-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	11603	delivery	5	28
129438	2020-08-30 03:00:20	2020-08-30	17	[{"id_menu":4,"count":1}]	48969	delivery	5	22
129439	2020-08-30 03:00:24	2020-08-30	9	[{"id_menu":7,"count":2}]	8554	delivery	5	14
129440	2020-08-30 03:00:56	2020-08-30	12	[{"id_menu":1,"count":1}]	48752	delivery	5	17
129441	2020-08-30 03:01:53	2020-08-30	8	[{"id_menu":5,"count":2}]	41555	delivery	5	13
129442	2020-08-30 03:03:16	2020-08-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	48928	delivery	5	28
129443	2020-08-30 03:03:54	2020-08-30	9	[{"id_menu":6,"count":1}]	41310	delivery	5	14
129444	2020-08-30 03:04:08	2020-08-30	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":2}]	5580	delivery	5	34
129445	2020-08-30 03:06:15	2020-08-30	46	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	48801	delivery	5	51
129446	2020-08-30 03:06:30	2020-08-30	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	31456	delivery	5	45
129447	2020-08-30 03:07:58	2020-08-30	12	[{"id_menu":1,"count":1}]	16964	pick-up	0	12
129448	2020-08-30 03:10:32	2020-08-30	14	[{"id_menu":2,"count":2}]	22610	delivery	5	19
129449	2020-08-30 03:12:44	2020-08-30	17	[{"id_menu":4,"count":1}]	48925	delivery	5	22
129450	2020-08-30 03:17:07	2020-08-30	14	[{"id_menu":2,"count":1}]	3913	delivery	5	19
129451	2020-08-30 03:17:49	2020-08-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	43636	delivery	5	23
129452	2020-08-30 03:18:06	2020-08-30	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	6015	delivery	5	40
129453	2020-08-30 03:19:17	2020-08-30	14	[{"id_menu":2,"count":1}]	9766	pick-up	0	14
129454	2020-08-30 03:21:35	2020-08-30	12	[{"id_menu":3,"count":1}]	9695	delivery	5	17
129455	2020-08-30 03:22:55	2020-08-30	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	37358	delivery	5	37
129456	2020-08-30 03:23:20	2020-08-30	9	[{"id_menu":6,"count":1}]	25071	delivery	5	14
129457	2020-08-30 03:26:10	2020-08-30	14	[{"id_menu":2,"count":1}]	43749	pick-up	0	14
129458	2020-08-30 03:27:30	2020-08-30	9	[{"id_menu":6,"count":1}]	3721	delivery	5	14
129459	2020-08-30 03:27:38	2020-08-30	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	26642	pick-up	0	31
129460	2020-08-30 03:28:15	2020-08-30	8	[{"id_menu":5,"count":1}]	37692	delivery	5	13
129461	2020-08-30 03:29:25	2020-08-30	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	15594	pick-up	0	31
129462	2020-08-30 03:29:36	2020-08-30	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7803	delivery	5	36
129463	2020-08-30 03:30:47	2020-08-30	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	48933	delivery	5	42
129464	2020-08-30 03:32:05	2020-08-30	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27979	delivery	5	37
129465	2020-08-30 03:32:25	2020-08-30	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	42154	delivery	5	31
129466	2020-08-30 03:32:27	2020-08-30	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18546	delivery	5	40
129467	2020-08-30 03:35:33	2020-08-30	8	[{"id_menu":5,"count":1}]	36502	delivery	5	13
129468	2020-08-30 03:36:57	2020-08-30	12	[{"id_menu":1,"count":1}]	33030	pick-up	0	12
129469	2020-08-30 03:39:39	2020-08-30	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	28230	pick-up	0	26
129470	2020-08-30 03:39:50	2020-08-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	25474	delivery	5	28
129471	2020-08-30 03:40:22	2020-08-30	14	[{"id_menu":2,"count":1}]	8286	pick-up	0	14
129472	2020-08-30 03:40:31	2020-08-30	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	24040	delivery	5	28
129473	2020-08-30 03:41:29	2020-08-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	725	delivery	5	31
129474	2020-08-30 03:43:00	2020-08-30	17	[{"id_menu":4,"count":1}]	23479	delivery	5	22
129475	2020-08-30 03:45:12	2020-08-30	17	[{"id_menu":4,"count":2}]	31690	pick-up	0	17
129476	2020-08-30 03:50:41	2020-08-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	14362	pick-up	0	22
129477	2020-08-30 03:54:05	2020-08-30	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	48767	delivery	5	31
129478	2020-08-30 03:55:41	2020-08-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	35729	delivery	5	31
129479	2020-08-30 03:57:09	2020-08-30	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	26709	delivery	5	44
129480	2020-08-30 03:57:35	2020-08-30	9	[{"id_menu":6,"count":1}]	41704	delivery	5	14
129481	2020-08-30 03:58:33	2020-08-30	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	27152	delivery	5	23
129482	2020-08-30 04:00:30	2020-08-30	12	[{"id_menu":1,"count":1}]	48927	delivery	5	17
129483	2020-08-30 04:02:45	2020-08-30	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	48942	delivery	5	25
129484	2020-08-30 04:03:29	2020-08-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	16136	delivery	5	27
129485	2020-08-30 04:04:26	2020-08-30	8	[{"id_menu":5,"count":1}]	28615	pick-up	0	8
129486	2020-08-30 04:04:50	2020-08-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	6591	pick-up	0	26
129487	2020-08-30 04:07:26	2020-08-30	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	45806	delivery	5	34
129488	2020-08-30 04:07:28	2020-08-30	12	[{"id_menu":3,"count":1}]	3785	pick-up	0	12
129489	2020-08-30 04:08:12	2020-08-30	14	[{"id_menu":2,"count":1}]	9402	delivery	5	19
129490	2020-08-30 04:13:14	2020-08-30	14	[{"id_menu":2,"count":1}]	48808	delivery	5	19
129491	2020-08-30 04:14:16	2020-08-30	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	27721	delivery	5	45
129492	2020-08-30 04:15:12	2020-08-30	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	23625	delivery	5	34
129493	2020-08-30 04:16:05	2020-08-30	17	[{"id_menu":4,"count":1}]	9193	pick-up	0	17
129494	2020-08-30 04:19:56	2020-08-30	8	[{"id_menu":5,"count":2}]	44083	delivery	5	13
129495	2020-08-30 04:21:33	2020-08-30	9	[{"id_menu":7,"count":2}]	47664	delivery	5	14
129496	2020-08-30 04:24:27	2020-08-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	43447	delivery	5	31
129497	2020-08-30 04:25:13	2020-08-30	8	[{"id_menu":5,"count":1}]	48788	delivery	5	13
129498	2020-08-30 04:25:14	2020-08-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	48997	delivery	5	31
129499	2020-08-30 04:29:34	2020-08-30	8	[{"id_menu":5,"count":1}]	48758	delivery	5	13
129500	2020-08-30 04:31:05	2020-08-30	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	24590	delivery	5	31
129501	2020-08-30 04:31:27	2020-08-30	12	[{"id_menu":3,"count":1}]	21702	delivery	5	17
129502	2020-08-30 04:32:16	2020-08-30	9	[{"id_menu":6,"count":1}]	48849	delivery	5	14
129503	2020-08-30 04:32:26	2020-08-30	17	[{"id_menu":4,"count":1}]	1765	delivery	5	22
129504	2020-08-30 04:33:20	2020-08-30	12	[{"id_menu":3,"count":1}]	1693	pick-up	0	12
129505	2020-08-30 04:34:18	2020-08-30	9	[{"id_menu":6,"count":1}]	48822	delivery	5	14
129506	2020-08-30 04:34:33	2020-08-30	12	[{"id_menu":3,"count":1}]	170	delivery	5	17
129507	2020-08-30 04:36:25	2020-08-30	9	[{"id_menu":6,"count":1}]	48750	delivery	5	14
129508	2020-08-30 04:39:40	2020-08-30	38	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48970	delivery	5	43
129509	2020-08-30 04:39:56	2020-08-30	46	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	8355	pick-up	0	46
129510	2020-08-30 04:40:08	2020-08-30	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1415	pick-up	0	26
129511	2020-08-30 04:41:38	2020-08-30	8	[{"id_menu":5,"count":1}]	19006	delivery	5	13
129512	2020-08-30 04:42:27	2020-08-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	48890	delivery	5	26
129513	2020-08-30 04:43:15	2020-08-30	8	[{"id_menu":5,"count":1}]	32878	delivery	5	13
129514	2020-08-30 04:43:18	2020-08-30	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	48773	pick-up	0	40
129515	2020-08-30 04:43:40	2020-08-30	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	5654	delivery	5	38
129516	2020-08-30 04:43:54	2020-08-30	17	[{"id_menu":4,"count":1}]	48856	delivery	5	22
129517	2020-08-30 04:49:15	2020-08-30	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	48315	delivery	5	36
129518	2020-08-30 04:50:09	2020-08-30	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	34388	delivery	5	26
129519	2020-08-30 04:52:59	2020-08-30	17	[{"id_menu":4,"count":1}]	43094	delivery	5	22
129520	2020-08-30 04:53:00	2020-08-30	8	[{"id_menu":5,"count":1}]	48900	delivery	5	13
129521	2020-08-30 04:55:07	2020-08-30	39	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2651	pick-up	0	39
129522	2020-08-30 04:55:07	2020-08-30	17	[{"id_menu":4,"count":1}]	23801	delivery	5	22
129523	2020-08-30 04:55:50	2020-08-30	9	[{"id_menu":7,"count":1}]	48917	pick-up	0	9
129524	2020-08-30 04:58:43	2020-08-30	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	48872	pick-up	0	43
129525	2020-08-30 04:58:48	2020-08-30	9	[{"id_menu":7,"count":1}]	16534	delivery	5	14
129526	2020-08-30 05:00:26	2020-08-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	20284	delivery	5	26
129527	2020-08-30 05:04:02	2020-08-30	17	[{"id_menu":4,"count":1}]	29541	pick-up	0	17
129528	2020-08-30 05:04:07	2020-08-30	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	49013	delivery	5	30
129529	2020-08-30 05:04:55	2020-08-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21866	delivery	5	22
129530	2020-08-30 05:05:04	2020-08-30	12	[{"id_menu":1,"count":1}]	26535	delivery	5	17
129531	2020-08-30 05:05:25	2020-08-30	8	[{"id_menu":5,"count":1}]	33708	pick-up	0	8
129532	2020-08-30 05:06:02	2020-08-30	8	[{"id_menu":5,"count":1}]	11901	delivery	5	13
129533	2020-08-30 05:06:37	2020-08-30	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	48916	delivery	5	43
129534	2020-08-30 05:06:56	2020-08-30	14	[{"id_menu":2,"count":1}]	19274	delivery	5	19
129535	2020-08-30 05:07:37	2020-08-30	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":2}]	48391	delivery	5	25
129536	2020-08-30 05:07:39	2020-08-30	35	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	48755	delivery	5	40
129537	2020-08-30 05:08:37	2020-08-30	9	[{"id_menu":7,"count":1}]	48893	delivery	5	14
129538	2020-08-30 05:08:54	2020-08-30	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	23600	delivery	5	39
129539	2020-08-30 05:10:30	2020-08-30	9	[{"id_menu":7,"count":1}]	10433	delivery	5	14
129540	2020-08-30 05:11:04	2020-08-30	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19771	delivery	5	54
129541	2020-08-30 05:13:53	2020-08-30	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	49023	delivery	5	22
129542	2020-08-30 05:19:37	2020-08-30	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	48936	delivery	5	22
129543	2020-08-30 05:19:40	2020-08-30	9	[{"id_menu":6,"count":1}]	34585	delivery	5	14
129544	2020-08-30 05:20:41	2020-08-30	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	32434	delivery	5	26
129545	2020-08-30 05:20:48	2020-08-30	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	1656	pick-up	0	29
129546	2020-08-30 05:20:59	2020-08-30	49	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	48803	delivery	5	54
129547	2020-08-30 05:21:45	2020-08-30	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	49007	delivery	5	34
129548	2020-08-30 05:22:44	2020-08-30	8	[{"id_menu":5,"count":1}]	48873	delivery	5	13
129549	2020-08-30 05:22:46	2020-08-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	49000	delivery	5	23
129550	2020-08-30 05:22:48	2020-08-30	9	[{"id_menu":7,"count":1}]	49016	delivery	5	14
129551	2020-08-30 05:25:09	2020-08-30	8	[{"id_menu":5,"count":1}]	46347	delivery	5	13
129552	2020-08-30 05:27:48	2020-08-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	11849	delivery	5	22
129553	2020-08-30 05:28:49	2020-08-30	30	[{"id_menu":1,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13564	delivery	5	35
129554	2020-08-30 05:33:15	2020-08-30	12	[{"id_menu":3,"count":1}]	48770	pick-up	0	12
129555	2020-08-30 05:35:11	2020-08-30	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	49003	delivery	5	48
129556	2020-08-30 05:36:40	2020-08-30	9	[{"id_menu":6,"count":1}]	2008	pick-up	0	9
129557	2020-08-30 05:37:05	2020-08-30	12	[{"id_menu":1,"count":1}]	48897	pick-up	0	12
129558	2020-08-30 05:37:57	2020-08-30	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	48884	delivery	5	43
129559	2020-08-30 05:37:58	2020-08-30	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	45739	delivery	5	39
129560	2020-08-30 05:39:49	2020-08-30	12	[{"id_menu":3,"count":1}]	34281	delivery	5	17
129561	2020-08-30 05:40:32	2020-08-30	14	[{"id_menu":2,"count":1}]	31290	delivery	5	19
129562	2020-08-30 05:41:00	2020-08-30	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	48888	delivery	5	34
129563	2020-08-30 05:42:57	2020-08-30	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	48857	delivery	5	23
129564	2020-08-30 05:44:42	2020-08-30	17	[{"id_menu":4,"count":1}]	31172	delivery	5	22
129565	2020-08-30 05:45:28	2020-08-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	45659	delivery	5	27
129566	2020-08-30 05:45:33	2020-08-30	9	[{"id_menu":6,"count":1}]	46644	delivery	5	14
129567	2020-08-30 05:46:00	2020-08-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	46096	delivery	5	22
129568	2020-08-30 05:46:48	2020-08-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	48829	delivery	5	22
129569	2020-08-30 05:47:28	2020-08-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31077	delivery	5	23
129570	2020-08-30 05:48:30	2020-08-30	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	44719	delivery	5	26
129571	2020-08-30 05:48:38	2020-08-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	48979	delivery	5	31
129572	2020-08-30 05:48:42	2020-08-30	12	[{"id_menu":3,"count":1}]	48772	delivery	5	17
129573	2020-08-30 05:51:52	2020-08-30	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	13413	delivery	5	34
129574	2020-08-30 05:53:51	2020-08-30	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	48830	delivery	5	28
129575	2020-08-30 05:57:12	2020-08-30	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	36324	delivery	5	42
129576	2020-08-30 05:57:36	2020-08-30	8	[{"id_menu":5,"count":1}]	48913	delivery	5	13
129577	2020-08-30 05:58:56	2020-08-30	8	[{"id_menu":5,"count":1}]	26457	delivery	5	13
129578	2020-08-30 05:59:46	2020-08-30	9	[{"id_menu":7,"count":1}]	25916	delivery	5	14
129579	2020-08-30 05:59:56	2020-08-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	47167	delivery	5	23
129580	2020-08-30 06:00:07	2020-08-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48877	delivery	5	23
129581	2020-08-30 06:02:18	2020-08-30	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	49004	delivery	5	39
129582	2020-08-30 06:04:07	2020-08-30	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	1183	pick-up	0	49
129583	2020-08-30 06:04:14	2020-08-30	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	8152	pick-up	0	29
129584	2020-08-30 06:04:51	2020-08-30	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	48785	delivery	5	26
129585	2020-08-30 06:04:52	2020-08-30	9	[{"id_menu":7,"count":1}]	32237	delivery	5	14
129586	2020-08-30 06:05:48	2020-08-30	9	[{"id_menu":7,"count":1}]	13755	pick-up	0	9
129587	2020-08-30 06:06:34	2020-08-30	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	256	pick-up	0	39
129588	2020-08-30 06:07:23	2020-08-30	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	32805	delivery	5	40
129589	2020-08-30 06:08:13	2020-08-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	24971	delivery	5	27
129590	2020-08-30 06:08:40	2020-08-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	15798	delivery	5	26
129591	2020-08-30 06:10:47	2020-08-30	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	48941	delivery	5	42
129592	2020-08-30 06:12:22	2020-08-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	8473	delivery	5	23
129593	2020-08-30 06:13:06	2020-08-30	9	[{"id_menu":6,"count":1}]	48894	delivery	5	14
129594	2020-08-30 06:14:32	2020-08-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	49010	delivery	5	23
129595	2020-08-30 06:16:55	2020-08-30	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	907	delivery	5	29
129596	2020-08-30 06:17:45	2020-08-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	46754	delivery	5	31
129597	2020-08-30 06:18:51	2020-08-30	9	[{"id_menu":6,"count":1}]	13062	pick-up	0	9
129598	2020-08-30 06:19:50	2020-08-30	17	[{"id_menu":4,"count":1}]	37141	delivery	5	22
129599	2020-08-30 06:21:47	2020-08-30	9	[{"id_menu":7,"count":2}]	14161	delivery	5	14
129600	2020-08-30 06:22:42	2020-08-30	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17952	pick-up	0	32
129601	2020-08-30 06:24:03	2020-08-30	14	[{"id_menu":2,"count":1}]	43604	delivery	5	19
129602	2020-08-30 06:27:26	2020-08-30	9	[{"id_menu":6,"count":2}]	29019	delivery	5	14
129603	2020-08-30 06:27:34	2020-08-30	14	[{"id_menu":2,"count":1}]	40611	delivery	5	19
129604	2020-08-30 06:27:50	2020-08-30	9	[{"id_menu":7,"count":1}]	40620	delivery	5	14
129605	2020-08-30 06:29:17	2020-08-30	8	[{"id_menu":5,"count":2}]	28422	delivery	5	13
129606	2020-08-30 06:29:33	2020-08-30	9	[{"id_menu":6,"count":1}]	34900	delivery	5	14
129607	2020-08-30 06:29:53	2020-08-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	8391	delivery	5	28
129608	2020-08-30 06:31:04	2020-08-30	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17654	delivery	5	43
129609	2020-08-30 06:33:02	2020-08-30	14	[{"id_menu":2,"count":1}]	4655	delivery	5	19
129610	2020-08-30 06:34:22	2020-08-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	44626	delivery	5	26
129611	2020-08-30 06:37:02	2020-08-30	9	[{"id_menu":6,"count":1}]	48963	delivery	5	14
129612	2020-08-30 06:37:27	2020-08-30	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	5426	pick-up	0	26
129613	2020-08-30 06:38:03	2020-08-30	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	48811	delivery	5	34
129614	2020-08-30 06:42:21	2020-08-30	9	[{"id_menu":6,"count":1}]	4499	delivery	5	14
129615	2020-08-30 06:42:26	2020-08-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	43823	delivery	5	28
129616	2020-08-30 06:48:10	2020-08-30	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	48999	delivery	5	36
129617	2020-08-30 06:48:51	2020-08-30	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	39229	delivery	5	31
129618	2020-08-30 06:51:17	2020-08-30	14	[{"id_menu":2,"count":1}]	17037	delivery	5	19
129619	2020-08-30 06:52:52	2020-08-30	9	[{"id_menu":6,"count":1}]	49029	pick-up	0	9
129620	2020-08-30 06:53:51	2020-08-30	12	[{"id_menu":1,"count":1}]	14856	delivery	5	17
129621	2020-08-30 06:58:06	2020-08-30	12	[{"id_menu":1,"count":1}]	44356	delivery	5	17
129622	2020-08-30 06:58:42	2020-08-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48759	delivery	5	23
129623	2020-08-30 06:59:59	2020-08-30	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	48985	delivery	5	36
129624	2020-08-30 07:00:47	2020-08-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	41108	delivery	5	27
129625	2020-08-30 07:02:25	2020-08-30	9	[{"id_menu":7,"count":1}]	14057	delivery	5	14
129626	2020-08-30 07:03:21	2020-08-30	12	[{"id_menu":3,"count":1}]	19143	delivery	5	17
129627	2020-08-30 07:04:04	2020-08-30	12	[{"id_menu":1,"count":1}]	28623	delivery	5	17
129628	2020-08-30 07:06:03	2020-08-30	14	[{"id_menu":2,"count":1}]	18533	pick-up	0	14
129629	2020-08-30 07:12:08	2020-08-30	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	48964	delivery	5	39
129630	2020-08-30 07:16:09	2020-08-30	9	[{"id_menu":6,"count":1}]	40993	pick-up	0	9
129631	2020-08-30 07:17:02	2020-08-30	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	40285	delivery	5	40
129632	2020-08-30 07:17:19	2020-08-30	8	[{"id_menu":5,"count":1}]	11666	delivery	5	13
129633	2020-08-30 07:19:20	2020-08-30	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	47924	delivery	5	40
129634	2020-08-30 07:19:25	2020-08-30	12	[{"id_menu":3,"count":1}]	35261	delivery	5	17
129635	2020-08-30 07:21:43	2020-08-30	9	[{"id_menu":7,"count":1}]	48958	delivery	5	14
129636	2020-08-30 07:21:59	2020-08-30	12	[{"id_menu":3,"count":1}]	812	delivery	5	17
129637	2020-08-30 07:24:56	2020-08-30	17	[{"id_menu":4,"count":1}]	46039	delivery	5	22
129638	2020-08-30 07:27:04	2020-08-30	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	18272	delivery	5	36
129639	2020-08-30 07:27:14	2020-08-30	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	48965	delivery	5	25
129640	2020-08-30 07:27:18	2020-08-30	12	[{"id_menu":3,"count":1}]	16737	pick-up	0	12
129641	2020-08-30 07:27:38	2020-08-30	9	[{"id_menu":6,"count":1}]	30896	delivery	5	14
129642	2020-08-30 07:28:25	2020-08-30	9	[{"id_menu":6,"count":1}]	2198	pick-up	0	9
129643	2020-08-30 07:29:11	2020-08-30	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	42485	delivery	5	26
129644	2020-08-30 07:30:49	2020-08-30	9	[{"id_menu":6,"count":1}]	42682	delivery	5	14
129645	2020-08-30 07:31:36	2020-08-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	48930	delivery	5	28
129646	2020-08-30 07:32:06	2020-08-30	9	[{"id_menu":7,"count":1}]	8597	delivery	5	14
129647	2020-08-30 07:32:34	2020-08-30	9	[{"id_menu":6,"count":1}]	47814	delivery	5	14
129648	2020-08-30 07:33:59	2020-08-30	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":2}]	27592	delivery	5	31
129649	2020-08-30 07:36:05	2020-08-30	17	[{"id_menu":4,"count":1}]	48864	delivery	5	22
129650	2020-08-30 07:36:36	2020-08-30	9	[{"id_menu":7,"count":1}]	6090	pick-up	0	9
129651	2020-08-30 07:38:27	2020-08-30	18	[{"id_menu":6,"count":3},{"id_menu":7,"count":1}]	42091	delivery	5	23
129652	2020-08-30 07:39:16	2020-08-30	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	29929	delivery	5	57
129653	2020-08-30 07:42:45	2020-08-30	9	[{"id_menu":6,"count":1}]	15793	delivery	5	14
129654	2020-08-30 07:44:30	2020-08-30	14	[{"id_menu":2,"count":1}]	48960	delivery	5	19
129655	2020-08-30 07:45:42	2020-08-30	14	[{"id_menu":2,"count":1}]	27686	delivery	5	19
129656	2020-08-30 07:45:45	2020-08-30	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	48778	delivery	5	48
129657	2020-08-30 07:46:34	2020-08-30	9	[{"id_menu":6,"count":1}]	27426	delivery	5	14
129658	2020-08-30 07:47:45	2020-08-30	14	[{"id_menu":2,"count":1}]	33220	pick-up	0	14
129659	2020-08-30 07:48:21	2020-08-30	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	48753	delivery	5	40
129660	2020-08-30 07:48:26	2020-08-30	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1431	pick-up	0	31
129661	2020-08-30 07:48:40	2020-08-30	14	[{"id_menu":2,"count":1}]	48908	delivery	5	19
129662	2020-08-30 07:49:06	2020-08-30	14	[{"id_menu":2,"count":1}]	33416	delivery	5	19
129663	2020-08-30 07:49:07	2020-08-30	9	[{"id_menu":7,"count":1}]	36727	delivery	5	14
129664	2020-08-30 07:54:00	2020-08-30	12	[{"id_menu":3,"count":1}]	29001	pick-up	0	12
129665	2020-08-30 07:54:35	2020-08-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	8583	delivery	5	26
129666	2020-08-30 07:54:52	2020-08-30	9	[{"id_menu":7,"count":2}]	17685	pick-up	0	9
129667	2020-08-30 07:56:27	2020-08-30	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	14698	delivery	5	23
129668	2020-08-30 07:56:35	2020-08-30	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	2848	delivery	5	48
129669	2020-08-30 07:56:38	2020-08-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	43202	pick-up	0	23
129670	2020-08-30 07:57:25	2020-08-30	12	[{"id_menu":1,"count":1}]	37473	delivery	5	17
129671	2020-08-30 07:58:15	2020-08-30	9	[{"id_menu":7,"count":1}]	13731	delivery	5	14
129672	2020-08-30 08:00:47	2020-08-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	48845	delivery	5	28
129673	2020-08-30 08:02:17	2020-08-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	4455	delivery	5	26
129674	2020-08-30 08:02:21	2020-08-30	17	[{"id_menu":4,"count":1}]	43262	delivery	5	22
129675	2020-08-30 08:04:02	2020-08-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48956	delivery	5	23
129676	2020-08-30 08:04:08	2020-08-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	23153	delivery	5	28
129677	2020-08-30 08:06:44	2020-08-30	26	[{"id_menu":2,"count":3},{"id_menu":3,"count":1}]	8632	pick-up	0	26
129678	2020-08-30 08:06:48	2020-08-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3280	delivery	5	27
129679	2020-08-30 08:08:56	2020-08-30	12	[{"id_menu":1,"count":1}]	5972	delivery	5	17
129680	2020-08-30 08:09:53	2020-08-30	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	48784	delivery	5	39
129681	2020-08-30 08:11:29	2020-08-30	9	[{"id_menu":6,"count":1}]	48998	delivery	5	14
129682	2020-08-30 08:11:35	2020-08-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	14782	pick-up	0	26
129683	2020-08-30 08:12:32	2020-08-30	12	[{"id_menu":1,"count":1}]	48782	delivery	5	17
129684	2020-08-30 08:16:36	2020-08-30	9	[{"id_menu":7,"count":1}]	39782	delivery	5	14
129685	2020-08-30 08:16:54	2020-08-30	9	[{"id_menu":6,"count":1}]	45118	pick-up	0	9
129686	2020-08-30 08:19:50	2020-08-30	12	[{"id_menu":3,"count":1}]	4800	pick-up	0	12
129687	2020-08-30 08:20:35	2020-08-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	25246	delivery	5	28
129688	2020-08-30 08:22:16	2020-08-30	8	[{"id_menu":5,"count":1}]	44927	delivery	5	13
129689	2020-08-30 08:26:40	2020-08-30	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	49026	delivery	5	43
129690	2020-08-30 08:30:15	2020-08-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	49018	delivery	5	31
129691	2020-08-30 08:32:04	2020-08-30	12	[{"id_menu":3,"count":1}]	43572	delivery	5	17
129692	2020-08-30 08:32:09	2020-08-30	9	[{"id_menu":6,"count":2}]	48929	delivery	5	14
129693	2020-08-30 08:33:21	2020-08-30	9	[{"id_menu":7,"count":1}]	30811	delivery	5	14
129694	2020-08-30 08:34:12	2020-08-30	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":3}]	25648	delivery	5	25
129695	2020-08-30 08:34:19	2020-08-30	12	[{"id_menu":3,"count":1}]	48971	pick-up	0	12
129696	2020-08-30 08:35:41	2020-08-30	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48796	delivery	5	35
129697	2020-08-30 08:38:55	2020-08-30	9	[{"id_menu":6,"count":1}]	36748	delivery	5	14
129698	2020-08-30 08:41:38	2020-08-30	43	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	19396	pick-up	0	43
129699	2020-08-30 08:43:50	2020-08-30	12	[{"id_menu":1,"count":1}]	4020	delivery	5	17
129700	2020-08-30 08:44:02	2020-08-30	17	[{"id_menu":4,"count":1}]	9867	delivery	5	22
129701	2020-08-30 08:47:48	2020-08-30	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	8877	delivery	5	36
129702	2020-08-30 08:48:02	2020-08-30	14	[{"id_menu":2,"count":1}]	6485	delivery	5	19
129703	2020-08-30 08:48:09	2020-08-30	14	[{"id_menu":2,"count":1}]	41772	pick-up	0	14
129704	2020-08-30 08:49:26	2020-08-30	14	[{"id_menu":2,"count":1}]	44012	delivery	5	19
129705	2020-08-30 08:51:00	2020-08-30	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	27769	delivery	5	25
129706	2020-08-30 08:54:53	2020-08-30	9	[{"id_menu":6,"count":1}]	42608	delivery	5	14
129707	2020-08-30 08:55:23	2020-08-30	42	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15334	delivery	5	47
129708	2020-08-30 08:55:47	2020-08-30	25	[{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	25108	delivery	5	30
129709	2020-08-30 08:58:23	2020-08-30	9	[{"id_menu":6,"count":1}]	36152	delivery	5	14
129710	2020-08-30 08:58:36	2020-08-30	9	[{"id_menu":7,"count":1}]	23684	delivery	5	14
129711	2020-08-30 08:59:57	2020-08-30	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	48840	delivery	5	39
129712	2020-08-30 09:00:30	2020-08-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	34238	delivery	5	28
129713	2020-08-30 09:06:12	2020-08-30	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10008	pick-up	0	49
129714	2020-08-30 09:07:43	2020-08-30	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":2}]	1380	delivery	5	22
129715	2020-08-30 09:09:18	2020-08-30	8	[{"id_menu":5,"count":1}]	48763	delivery	5	13
129716	2020-08-30 09:10:14	2020-08-30	17	[{"id_menu":4,"count":1}]	29926	delivery	5	22
129717	2020-08-30 09:10:34	2020-08-30	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5047	delivery	5	30
129718	2020-08-30 09:11:10	2020-08-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	48880	delivery	5	31
129719	2020-08-30 09:14:03	2020-08-30	17	[{"id_menu":4,"count":2}]	45129	delivery	5	22
129720	2020-08-30 09:14:32	2020-08-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	20556	delivery	5	26
129721	2020-08-30 09:15:43	2020-08-30	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	39745	delivery	5	23
129722	2020-08-30 09:19:40	2020-08-30	9	[{"id_menu":7,"count":1}]	18359	delivery	5	14
129723	2020-08-30 09:20:26	2020-08-30	9	[{"id_menu":6,"count":1}]	5643	delivery	5	14
129724	2020-08-30 09:20:27	2020-08-30	14	[{"id_menu":2,"count":1}]	23797	delivery	5	19
129725	2020-08-30 09:22:58	2020-08-30	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	48853	delivery	5	29
129726	2020-08-30 09:23:20	2020-08-30	9	[{"id_menu":7,"count":1}]	9573	pick-up	0	9
129727	2020-08-30 09:24:50	2020-08-30	8	[{"id_menu":5,"count":1}]	24563	delivery	5	13
129728	2020-08-30 09:31:17	2020-08-30	12	[{"id_menu":1,"count":1}]	19399	delivery	5	17
129729	2020-08-30 09:31:54	2020-08-30	9	[{"id_menu":7,"count":1}]	30762	delivery	5	14
129730	2020-08-30 09:33:08	2020-08-30	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26849	delivery	5	49
129731	2020-08-30 09:33:21	2020-08-30	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	44097	delivery	5	39
129732	2020-08-30 09:34:01	2020-08-30	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	11559	delivery	5	26
129733	2020-08-30 09:36:36	2020-08-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	25850	delivery	5	31
129734	2020-08-30 09:38:45	2020-08-30	12	[{"id_menu":3,"count":1}]	49015	pick-up	0	12
129735	2020-08-30 09:39:23	2020-08-30	9	[{"id_menu":7,"count":1}]	31824	delivery	5	14
129736	2020-08-30 09:39:32	2020-08-30	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	42899	pick-up	0	21
129737	2020-08-30 09:39:52	2020-08-30	17	[{"id_menu":4,"count":1}]	1698	delivery	5	22
129738	2020-08-30 09:40:05	2020-08-30	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	25075	delivery	5	43
129739	2020-08-30 09:41:57	2020-08-30	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	133	delivery	5	43
129740	2020-08-30 09:42:35	2020-08-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	48886	delivery	5	22
129741	2020-08-30 09:43:42	2020-08-30	14	[{"id_menu":2,"count":1}]	15357	pick-up	0	14
129742	2020-08-30 09:44:40	2020-08-30	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	832	pick-up	0	20
129743	2020-08-30 09:46:48	2020-08-30	9	[{"id_menu":7,"count":1}]	31304	delivery	5	14
129744	2020-08-30 09:49:11	2020-08-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	30298	delivery	5	31
129745	2020-08-30 09:49:12	2020-08-30	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	14633	delivery	5	30
129746	2020-08-30 09:50:12	2020-08-30	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	27329	delivery	5	38
129747	2020-08-30 09:50:38	2020-08-30	14	[{"id_menu":2,"count":1}]	27854	pick-up	0	14
129748	2020-08-30 09:51:17	2020-08-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12022	delivery	5	23
129749	2020-08-30 09:52:54	2020-08-30	9	[{"id_menu":7,"count":1}]	48823	delivery	5	14
129750	2020-08-30 09:52:58	2020-08-30	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	36517	delivery	5	22
129751	2020-08-30 09:53:00	2020-08-30	9	[{"id_menu":6,"count":1}]	9577	delivery	5	14
129752	2020-08-30 09:55:24	2020-08-30	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	26884	delivery	5	42
129753	2020-08-30 09:55:25	2020-08-30	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	11395	pick-up	0	29
129754	2020-08-30 09:55:25	2020-08-30	17	[{"id_menu":4,"count":1}]	6882	delivery	5	22
129755	2020-08-30 09:55:29	2020-08-30	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	48266	delivery	5	25
129756	2020-08-30 09:55:40	2020-08-30	14	[{"id_menu":2,"count":1}]	10203	pick-up	0	14
129757	2020-08-30 09:56:08	2020-08-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	15982	delivery	5	26
129758	2020-08-30 09:58:00	2020-08-30	14	[{"id_menu":2,"count":1}]	19164	delivery	5	19
129759	2020-08-30 10:00:24	2020-08-30	17	[{"id_menu":4,"count":1}]	31369	delivery	5	22
129760	2020-08-30 10:03:06	2020-08-30	8	[{"id_menu":5,"count":1}]	14067	delivery	5	13
129761	2020-08-30 10:03:25	2020-08-30	17	[{"id_menu":4,"count":1}]	8657	pick-up	0	17
129762	2020-08-30 10:05:35	2020-08-30	12	[{"id_menu":1,"count":1}]	48802	delivery	5	17
129763	2020-08-30 10:07:02	2020-08-30	14	[{"id_menu":2,"count":1}]	34065	delivery	5	19
129764	2020-08-30 10:07:26	2020-08-30	14	[{"id_menu":2,"count":1}]	39899	delivery	5	19
129765	2020-08-30 10:08:02	2020-08-30	9	[{"id_menu":7,"count":1}]	2392	delivery	5	14
129766	2020-08-30 10:09:05	2020-08-30	9	[{"id_menu":6,"count":1}]	10461	delivery	5	14
129767	2020-08-30 10:09:09	2020-08-30	9	[{"id_menu":6,"count":1}]	47203	delivery	5	14
129768	2020-08-30 10:15:28	2020-08-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	39410	pick-up	0	26
129769	2020-08-30 10:15:29	2020-08-30	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	17671	delivery	5	39
129770	2020-08-30 10:15:37	2020-08-30	9	[{"id_menu":7,"count":2}]	43873	pick-up	0	9
129771	2020-08-30 10:15:59	2020-08-30	9	[{"id_menu":7,"count":1}]	48959	delivery	5	14
129772	2020-08-30 10:18:06	2020-08-30	12	[{"id_menu":1,"count":1}]	44590	delivery	5	17
129773	2020-08-30 10:18:27	2020-08-30	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	48868	delivery	5	30
129774	2020-08-30 10:18:51	2020-08-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	14668	delivery	5	31
129775	2020-08-30 10:21:12	2020-08-30	8	[{"id_menu":5,"count":1}]	16083	delivery	5	13
129776	2020-08-30 10:23:16	2020-08-30	17	[{"id_menu":4,"count":1}]	48805	delivery	5	22
129777	2020-08-30 10:23:27	2020-08-30	9	[{"id_menu":7,"count":1}]	33229	delivery	5	14
129778	2020-08-30 10:26:52	2020-08-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48762	delivery	5	23
129779	2020-08-30 10:29:30	2020-08-30	9	[{"id_menu":6,"count":1}]	48826	delivery	5	14
129780	2020-08-30 10:30:19	2020-08-30	14	[{"id_menu":2,"count":1}]	21597	delivery	5	19
129781	2020-08-30 10:30:44	2020-08-30	8	[{"id_menu":5,"count":1}]	2293	pick-up	0	8
129782	2020-08-30 10:32:29	2020-08-30	14	[{"id_menu":2,"count":1}]	48765	delivery	5	19
129783	2020-08-30 10:32:53	2020-08-30	17	[{"id_menu":4,"count":1}]	30385	delivery	5	22
129784	2020-08-30 10:33:36	2020-08-30	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48780	delivery	5	31
129785	2020-08-30 10:34:43	2020-08-30	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48906	delivery	5	31
129786	2020-08-30 10:34:56	2020-08-30	12	[{"id_menu":3,"count":3}]	48825	delivery	5	17
129787	2020-08-30 10:35:27	2020-08-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7227	delivery	5	28
129788	2020-08-30 10:36:38	2020-08-30	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	27701	delivery	5	23
129789	2020-08-30 10:36:48	2020-08-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	26766	delivery	5	31
129790	2020-08-30 10:37:38	2020-08-30	12	[{"id_menu":1,"count":1}]	19889	delivery	5	17
129791	2020-08-30 10:40:02	2020-08-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	11029	delivery	5	23
129792	2020-08-30 10:41:09	2020-08-30	8	[{"id_menu":5,"count":1}]	48885	delivery	5	13
129793	2020-08-30 10:43:25	2020-08-30	8	[{"id_menu":5,"count":1}]	48903	delivery	5	13
129794	2020-08-30 10:43:54	2020-08-30	8	[{"id_menu":5,"count":1}]	39759	delivery	5	13
129795	2020-08-30 10:46:17	2020-08-30	8	[{"id_menu":5,"count":1}]	16794	delivery	5	13
129796	2020-08-30 10:46:33	2020-08-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	5668	delivery	5	26
129797	2020-08-30 10:47:52	2020-08-30	14	[{"id_menu":2,"count":1}]	20805	pick-up	0	14
129798	2020-08-30 10:48:11	2020-08-30	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	48852	delivery	5	55
129799	2020-08-30 10:49:08	2020-08-30	17	[{"id_menu":4,"count":1}]	6253	delivery	5	22
129800	2020-08-30 10:49:28	2020-08-30	9	[{"id_menu":6,"count":1}]	21705	delivery	5	14
129801	2020-08-30 10:54:25	2020-08-30	9	[{"id_menu":6,"count":2}]	24989	pick-up	0	9
129802	2020-08-30 10:54:29	2020-08-30	9	[{"id_menu":6,"count":1}]	25951	delivery	5	14
129803	2020-08-30 10:55:07	2020-08-30	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	44537	delivery	5	36
129804	2020-08-30 10:55:30	2020-08-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	19916	delivery	5	26
129805	2020-08-30 10:56:46	2020-08-30	9	[{"id_menu":6,"count":1}]	39454	delivery	5	14
129806	2020-08-30 10:57:07	2020-08-30	8	[{"id_menu":5,"count":1}]	7359	delivery	5	13
129807	2020-08-30 10:58:44	2020-08-30	8	[{"id_menu":5,"count":1}]	37188	delivery	5	13
129808	2020-08-30 10:59:19	2020-08-30	12	[{"id_menu":1,"count":1}]	48918	delivery	5	17
129809	2020-08-30 11:00:33	2020-08-30	17	[{"id_menu":4,"count":1}]	6508	delivery	5	22
129810	2020-08-30 11:04:19	2020-08-30	17	[{"id_menu":4,"count":1}]	39105	delivery	5	22
129811	2020-08-30 11:05:32	2020-08-30	9	[{"id_menu":7,"count":1}]	48938	delivery	5	14
129812	2020-08-30 11:06:05	2020-08-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	12369	delivery	5	28
129813	2020-08-30 11:06:52	2020-08-30	9	[{"id_menu":7,"count":1}]	1253	pick-up	0	9
129814	2020-08-30 11:07:31	2020-08-30	14	[{"id_menu":2,"count":1}]	5789	delivery	5	19
129815	2020-08-30 11:11:28	2020-08-30	14	[{"id_menu":2,"count":1}]	48945	delivery	5	19
129816	2020-08-30 11:12:37	2020-08-30	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	48924	delivery	5	26
129817	2020-08-30 11:13:33	2020-08-30	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	8211	delivery	5	36
129818	2020-08-30 11:13:35	2020-08-30	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	14656	delivery	5	40
129819	2020-08-30 11:14:51	2020-08-30	8	[{"id_menu":5,"count":1}]	36717	delivery	5	13
129820	2020-08-30 11:15:08	2020-08-30	9	[{"id_menu":6,"count":1}]	1352	delivery	5	14
129821	2020-08-30 11:16:41	2020-08-30	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	48994	delivery	5	48
129822	2020-08-30 11:16:59	2020-08-30	8	[{"id_menu":5,"count":2}]	37111	delivery	5	13
129823	2020-08-30 11:18:49	2020-08-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	19862	delivery	5	23
129824	2020-08-30 11:18:53	2020-08-30	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":2}]	9214	delivery	5	27
129825	2020-08-30 11:20:40	2020-08-30	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	48871	delivery	5	39
129826	2020-08-30 11:22:33	2020-08-30	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38961	delivery	5	31
129827	2020-08-30 11:22:43	2020-08-30	12	[{"id_menu":1,"count":1}]	22801	delivery	5	17
129828	2020-08-30 11:23:21	2020-08-30	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	30567	delivery	5	48
129829	2020-08-30 11:24:15	2020-08-30	9	[{"id_menu":7,"count":1}]	29659	delivery	5	14
129830	2020-08-30 11:24:36	2020-08-30	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	10142	delivery	5	30
129831	2020-08-30 11:26:37	2020-08-30	14	[{"id_menu":2,"count":1}]	48760	delivery	5	19
129832	2020-08-30 11:28:28	2020-08-30	9	[{"id_menu":6,"count":1}]	42089	delivery	5	14
129833	2020-08-30 11:29:31	2020-08-30	9	[{"id_menu":6,"count":1}]	48807	delivery	5	14
129834	2020-08-30 11:29:41	2020-08-30	8	[{"id_menu":5,"count":1}]	45543	delivery	5	13
129835	2020-08-30 11:30:08	2020-08-30	12	[{"id_menu":3,"count":1}]	24559	delivery	5	17
129836	2020-08-30 11:31:00	2020-08-30	9	[{"id_menu":7,"count":2}]	37398	delivery	5	14
129837	2020-08-30 11:31:18	2020-08-30	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	34077	delivery	5	43
129838	2020-08-30 11:31:54	2020-08-30	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	16001	delivery	5	22
129839	2020-08-30 11:36:38	2020-08-30	12	[{"id_menu":3,"count":1}]	33192	delivery	5	17
129840	2020-08-30 11:36:58	2020-08-30	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	48920	delivery	5	25
129841	2020-08-30 11:37:25	2020-08-30	9	[{"id_menu":6,"count":1}]	48976	pick-up	0	9
129842	2020-08-30 11:38:21	2020-08-30	8	[{"id_menu":5,"count":1}]	38199	delivery	5	13
129843	2020-08-30 11:38:46	2020-08-30	8	[{"id_menu":5,"count":1}]	3314	pick-up	0	8
129844	2020-08-30 11:39:48	2020-08-30	12	[{"id_menu":3,"count":2}]	24863	delivery	5	17
129845	2020-08-30 11:41:57	2020-08-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":3}]	17226	delivery	5	28
129846	2020-08-30 11:42:52	2020-08-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33629	delivery	5	23
129847	2020-08-30 11:44:26	2020-08-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	48792	delivery	5	28
129848	2020-08-30 11:44:37	2020-08-30	17	[{"id_menu":4,"count":1}]	27960	delivery	5	22
129849	2020-08-30 11:44:42	2020-08-30	9	[{"id_menu":7,"count":1}]	16461	delivery	5	14
129850	2020-08-30 11:44:56	2020-08-30	35	[{"id_menu":1,"count":2},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	16549	pick-up	0	35
129851	2020-08-30 11:45:34	2020-08-30	8	[{"id_menu":5,"count":1}]	40022	delivery	5	13
129852	2020-08-30 11:48:20	2020-08-30	12	[{"id_menu":1,"count":1}]	15473	pick-up	0	12
129853	2020-08-30 11:51:09	2020-08-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	2307	pick-up	0	23
129854	2020-08-30 11:53:50	2020-08-30	9	[{"id_menu":7,"count":1}]	19931	pick-up	0	9
129855	2020-08-30 11:55:22	2020-08-30	38	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	17702	delivery	5	43
129856	2020-08-30 11:55:35	2020-08-30	9	[{"id_menu":7,"count":1}]	8683	delivery	5	14
129857	2020-08-30 11:57:34	2020-08-30	12	[{"id_menu":3,"count":1}]	3098	pick-up	0	12
129858	2020-08-30 11:58:39	2020-08-30	12	[{"id_menu":3,"count":1}]	36773	delivery	5	17
129859	2020-08-30 11:58:43	2020-08-30	8	[{"id_menu":5,"count":1}]	40901	pick-up	0	8
129860	2020-08-30 11:58:48	2020-08-30	9	[{"id_menu":7,"count":1}]	13257	delivery	5	14
129861	2020-08-30 11:58:49	2020-08-30	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	14481	delivery	5	25
129862	2020-08-30 11:59:06	2020-08-30	9	[{"id_menu":7,"count":1}]	27577	pick-up	0	9
129863	2020-08-30 11:59:08	2020-08-30	9	[{"id_menu":6,"count":1}]	48846	delivery	5	14
129864	2020-08-30 11:59:41	2020-08-30	14	[{"id_menu":2,"count":1}]	21377	delivery	5	19
129865	2020-08-30 12:00:50	2020-08-30	12	[{"id_menu":3,"count":1}]	26754	delivery	5	17
129866	2020-08-30 12:04:29	2020-08-30	9	[{"id_menu":6,"count":1}]	10923	delivery	5	14
129867	2020-08-30 12:04:55	2020-08-30	9	[{"id_menu":7,"count":1}]	48990	delivery	5	14
129868	2020-08-30 12:07:59	2020-08-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1424	pick-up	0	26
129869	2020-08-30 12:09:41	2020-08-30	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	48820	pick-up	0	21
129870	2020-08-30 12:10:46	2020-08-30	9	[{"id_menu":7,"count":1}]	48876	delivery	5	14
129871	2020-08-30 12:11:04	2020-08-30	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	2735	pick-up	0	31
129872	2020-08-30 12:11:38	2020-08-30	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24364	delivery	5	51
129873	2020-08-30 12:11:41	2020-08-30	9	[{"id_menu":7,"count":2}]	1107	delivery	5	14
129874	2020-08-30 12:11:52	2020-08-30	9	[{"id_menu":7,"count":1}]	13026	pick-up	0	9
129875	2020-08-30 12:12:30	2020-08-30	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	48810	delivery	5	26
129876	2020-08-30 12:12:38	2020-08-30	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	49022	delivery	5	31
129877	2020-08-30 12:14:07	2020-08-30	14	[{"id_menu":2,"count":1}]	2310	pick-up	0	14
129878	2020-08-30 12:14:46	2020-08-30	8	[{"id_menu":5,"count":2}]	28342	delivery	5	13
129879	2020-08-30 12:15:52	2020-08-30	9	[{"id_menu":7,"count":1}]	5354	delivery	5	14
129880	2020-08-30 12:17:04	2020-08-30	14	[{"id_menu":2,"count":1}]	49008	delivery	5	19
129881	2020-08-30 12:18:11	2020-08-30	14	[{"id_menu":2,"count":1}]	12934	delivery	5	19
129882	2020-08-30 12:19:17	2020-08-30	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":2}]	48769	delivery	5	29
129883	2020-08-30 12:22:29	2020-08-30	9	[{"id_menu":6,"count":1}]	48915	delivery	5	14
129884	2020-08-30 12:23:28	2020-08-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	49021	delivery	5	23
129885	2020-08-30 12:23:39	2020-08-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	715	pick-up	0	18
129886	2020-08-30 12:24:56	2020-08-30	14	[{"id_menu":2,"count":1}]	48939	delivery	5	19
129887	2020-08-30 12:26:46	2020-08-30	9	[{"id_menu":7,"count":2}]	49002	delivery	5	14
129888	2020-08-30 12:27:51	2020-08-30	17	[{"id_menu":4,"count":1}]	42258	pick-up	0	17
129889	2020-08-30 12:31:58	2020-08-30	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	18587	delivery	5	48
129890	2020-08-30 12:32:27	2020-08-30	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	1713	pick-up	0	26
129891	2020-08-30 12:32:35	2020-08-30	9	[{"id_menu":7,"count":1}]	46828	delivery	5	14
129892	2020-08-30 12:35:33	2020-08-30	9	[{"id_menu":7,"count":1}]	7041	delivery	5	14
129893	2020-08-30 12:35:54	2020-08-30	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	47661	delivery	5	43
129894	2020-08-30 12:36:11	2020-08-30	9	[{"id_menu":7,"count":1}]	48882	delivery	5	14
129895	2020-08-30 12:37:21	2020-08-30	8	[{"id_menu":5,"count":1}]	7058	pick-up	0	8
129896	2020-08-30 12:37:24	2020-08-30	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	8247	delivery	5	48
129897	2020-08-30 12:39:42	2020-08-30	8	[{"id_menu":5,"count":2}]	22133	delivery	5	13
129898	2020-08-30 12:40:47	2020-08-30	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	778	pick-up	0	31
129899	2020-08-30 12:43:06	2020-08-30	9	[{"id_menu":6,"count":1}]	49009	delivery	5	14
129900	2020-08-30 12:45:34	2020-08-30	8	[{"id_menu":5,"count":1}]	27565	delivery	5	13
129901	2020-08-30 12:46:08	2020-08-30	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29932	delivery	5	34
129902	2020-08-30 12:46:41	2020-08-30	12	[{"id_menu":1,"count":1}]	21978	pick-up	0	12
129903	2020-08-30 12:46:48	2020-08-30	17	[{"id_menu":4,"count":1}]	2149	delivery	5	22
129904	2020-08-30 12:48:39	2020-08-30	9	[{"id_menu":6,"count":1}]	48812	delivery	5	14
129905	2020-08-30 12:48:45	2020-08-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	42666	delivery	5	22
129906	2020-08-30 12:50:52	2020-08-30	8	[{"id_menu":5,"count":1}]	35421	delivery	5	13
129907	2020-08-30 12:51:15	2020-08-30	12	[{"id_menu":3,"count":1}]	48813	delivery	5	17
129908	2020-08-30 12:51:26	2020-08-30	14	[{"id_menu":2,"count":1}]	27583	delivery	5	19
129909	2020-08-30 12:53:39	2020-08-30	8	[{"id_menu":5,"count":1}]	48795	delivery	5	13
129910	2020-08-30 12:57:29	2020-08-30	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16152	delivery	5	35
129911	2020-08-30 12:59:47	2020-08-30	9	[{"id_menu":6,"count":1}]	12248	pick-up	0	9
129912	2020-08-30 12:59:50	2020-08-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12532	pick-up	0	26
129913	2020-08-30 13:00:28	2020-08-30	17	[{"id_menu":4,"count":1}]	15809	delivery	5	22
129914	2020-08-30 13:03:46	2020-08-30	17	[{"id_menu":4,"count":1}]	48787	delivery	5	22
129915	2020-08-30 13:04:36	2020-08-30	8	[{"id_menu":5,"count":1}]	13930	pick-up	0	8
129916	2020-08-30 13:06:47	2020-08-30	14	[{"id_menu":2,"count":2}]	18392	delivery	5	19
129917	2020-08-30 13:07:03	2020-08-30	12	[{"id_menu":3,"count":1}]	19969	delivery	5	17
129918	2020-08-30 13:07:11	2020-08-30	14	[{"id_menu":2,"count":1}]	31351	pick-up	0	14
129919	2020-08-30 13:07:17	2020-08-30	12	[{"id_menu":3,"count":1}]	41230	delivery	5	17
129920	2020-08-30 13:07:38	2020-08-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	9630	delivery	5	28
129921	2020-08-30 13:07:58	2020-08-30	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	48892	delivery	5	30
129922	2020-08-30 13:08:34	2020-08-30	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	9271	delivery	5	43
129923	2020-08-30 13:09:19	2020-08-30	12	[{"id_menu":3,"count":1}]	31780	pick-up	0	12
129924	2020-08-30 13:10:20	2020-08-30	12	[{"id_menu":1,"count":1}]	46053	delivery	5	17
129925	2020-08-30 13:11:34	2020-08-30	12	[{"id_menu":3,"count":1}]	19380	delivery	5	17
129926	2020-08-30 13:12:43	2020-08-30	9	[{"id_menu":7,"count":1}]	49014	delivery	5	14
129927	2020-08-30 13:14:18	2020-08-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	13772	delivery	5	27
129928	2020-08-30 13:14:53	2020-08-30	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7931	pick-up	0	43
129929	2020-08-30 13:15:52	2020-08-30	17	[{"id_menu":4,"count":1}]	31181	delivery	5	22
129930	2020-08-30 13:16:15	2020-08-30	9	[{"id_menu":6,"count":1}]	48949	delivery	5	14
129931	2020-08-30 13:18:15	2020-08-30	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	28755	delivery	5	30
129932	2020-08-30 13:20:20	2020-08-30	14	[{"id_menu":2,"count":1}]	48809	delivery	5	19
129933	2020-08-30 13:21:19	2020-08-30	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	36846	delivery	5	34
129934	2020-08-30 13:21:53	2020-08-30	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48843	delivery	5	40
129935	2020-08-30 13:23:16	2020-08-30	8	[{"id_menu":5,"count":1}]	11756	delivery	5	13
129936	2020-08-30 13:23:27	2020-08-30	12	[{"id_menu":1,"count":1}]	9368	delivery	5	17
129937	2020-08-30 13:23:38	2020-08-30	17	[{"id_menu":4,"count":1}]	48766	delivery	5	22
129938	2020-08-30 13:23:42	2020-08-30	9	[{"id_menu":6,"count":1}]	7279	delivery	5	14
129939	2020-08-30 13:24:53	2020-08-30	9	[{"id_menu":6,"count":2}]	42804	delivery	5	14
129940	2020-08-30 13:26:21	2020-08-30	8	[{"id_menu":5,"count":1}]	28991	delivery	5	13
129941	2020-08-30 13:28:07	2020-08-30	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	45736	delivery	5	53
129942	2020-08-30 13:28:10	2020-08-30	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	48921	delivery	5	34
129943	2020-08-30 13:28:44	2020-08-30	14	[{"id_menu":2,"count":1}]	48972	delivery	5	19
129944	2020-08-30 13:28:57	2020-08-30	8	[{"id_menu":5,"count":1}]	8054	delivery	5	13
129945	2020-08-30 13:32:38	2020-08-30	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	48816	pick-up	0	20
129946	2020-08-30 13:33:56	2020-08-30	17	[{"id_menu":4,"count":1}]	31811	delivery	5	22
129947	2020-08-30 13:34:41	2020-08-30	14	[{"id_menu":2,"count":1}]	30582	delivery	5	19
129948	2020-08-30 13:36:48	2020-08-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	12905	pick-up	0	21
129949	2020-08-30 13:36:52	2020-08-30	9	[{"id_menu":7,"count":1}]	35838	delivery	5	14
129950	2020-08-30 13:37:55	2020-08-30	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	48943	delivery	5	25
129951	2020-08-30 13:39:15	2020-08-30	9	[{"id_menu":7,"count":1}]	11156	pick-up	0	9
129952	2020-08-30 13:40:10	2020-08-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	25310	delivery	5	28
129953	2020-08-30 13:40:51	2020-08-30	8	[{"id_menu":5,"count":1}]	47590	delivery	5	13
129954	2020-08-30 13:43:42	2020-08-30	9	[{"id_menu":7,"count":1}]	48991	delivery	5	14
129955	2020-08-30 13:44:10	2020-08-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	48869	delivery	5	26
129956	2020-08-30 13:44:57	2020-08-30	9	[{"id_menu":7,"count":1}]	49039	delivery	5	14
129957	2020-08-30 13:46:12	2020-08-30	9	[{"id_menu":7,"count":1}]	14088	pick-up	0	9
129958	2020-08-30 13:48:24	2020-08-30	14	[{"id_menu":2,"count":1}]	431	pick-up	0	14
129959	2020-08-30 13:48:43	2020-08-30	20	[{"id_menu":1,"count":2},{"id_menu":5,"count":1}]	2311	pick-up	0	20
129960	2020-08-30 13:48:45	2020-08-30	14	[{"id_menu":2,"count":4}]	9783	delivery	5	19
129961	2020-08-30 13:48:59	2020-08-30	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	26489	delivery	5	25
129962	2020-08-30 13:50:02	2020-08-30	9	[{"id_menu":6,"count":1}]	6125	delivery	5	14
129963	2020-08-30 13:50:04	2020-08-30	12	[{"id_menu":1,"count":1}]	11764	pick-up	0	12
129964	2020-08-30 13:50:14	2020-08-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":3}]	14660	delivery	5	28
129965	2020-08-30 13:52:48	2020-08-30	9	[{"id_menu":6,"count":1}]	9832	delivery	5	14
129966	2020-08-30 13:56:00	2020-08-30	12	[{"id_menu":3,"count":1}]	48973	delivery	5	17
129967	2020-08-30 13:57:39	2020-08-30	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	31309	delivery	5	36
129968	2020-08-30 13:59:38	2020-08-30	12	[{"id_menu":1,"count":1}]	6883	delivery	5	17
129969	2020-08-30 14:01:56	2020-08-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	5669	delivery	5	31
129970	2020-08-30 14:04:01	2020-08-30	9	[{"id_menu":6,"count":2}]	25061	delivery	5	14
129971	2020-08-30 14:04:23	2020-08-30	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	30382	delivery	5	39
129972	2020-08-30 14:04:27	2020-08-30	9	[{"id_menu":7,"count":1}]	25885	pick-up	0	9
129973	2020-08-30 14:05:08	2020-08-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	20215	pick-up	0	21
129974	2020-08-30 14:05:17	2020-08-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	16387	delivery	5	31
129975	2020-08-30 14:09:28	2020-08-30	12	[{"id_menu":1,"count":1}]	24518	pick-up	0	12
129976	2020-08-30 14:10:13	2020-08-30	12	[{"id_menu":1,"count":2}]	48783	delivery	5	17
129977	2020-08-30 14:10:21	2020-08-30	9	[{"id_menu":6,"count":1}]	48895	delivery	5	14
129978	2020-08-30 14:10:35	2020-08-30	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	30108	pick-up	0	20
129979	2020-08-30 14:11:45	2020-08-30	8	[{"id_menu":5,"count":1}]	32915	delivery	5	13
129980	2020-08-30 14:11:50	2020-08-30	17	[{"id_menu":4,"count":1}]	2004	delivery	5	22
129981	2020-08-30 14:13:30	2020-08-30	14	[{"id_menu":2,"count":1}]	14881	delivery	5	19
129982	2020-08-30 14:14:09	2020-08-30	9	[{"id_menu":7,"count":1}]	7953	delivery	5	14
129983	2020-08-30 14:15:28	2020-08-30	9	[{"id_menu":6,"count":1}]	24842	delivery	5	14
129984	2020-08-30 14:16:05	2020-08-30	17	[{"id_menu":4,"count":1}]	48798	delivery	5	22
129985	2020-08-30 14:16:49	2020-08-30	12	[{"id_menu":3,"count":1}]	24987	delivery	5	17
129986	2020-08-30 14:17:56	2020-08-30	9	[{"id_menu":6,"count":1}]	1331	pick-up	0	9
129987	2020-08-30 14:19:27	2020-08-30	17	[{"id_menu":4,"count":2}]	20340	delivery	5	22
129988	2020-08-30 14:19:49	2020-08-30	12	[{"id_menu":3,"count":1}]	32730	pick-up	0	12
129989	2020-08-30 14:21:40	2020-08-30	8	[{"id_menu":5,"count":1}]	2313	delivery	5	13
129990	2020-08-30 14:22:14	2020-08-30	17	[{"id_menu":4,"count":1}]	2377	pick-up	0	17
129991	2020-08-30 14:25:13	2020-08-30	17	[{"id_menu":4,"count":1}]	3326	pick-up	0	17
129992	2020-08-30 14:25:50	2020-08-30	14	[{"id_menu":2,"count":1}]	239	pick-up	0	14
129993	2020-08-30 14:26:58	2020-08-30	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	8230	delivery	5	29
129994	2020-08-30 14:27:56	2020-08-30	12	[{"id_menu":1,"count":1}]	23754	delivery	5	17
129995	2020-08-30 14:29:25	2020-08-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	43195	delivery	5	23
129996	2020-08-30 14:32:03	2020-08-30	9	[{"id_menu":6,"count":1}]	48904	delivery	5	14
129997	2020-08-30 14:36:09	2020-08-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	4193	pick-up	0	26
129998	2020-08-30 14:38:29	2020-08-30	17	[{"id_menu":4,"count":1}]	48839	delivery	5	22
129999	2020-08-30 14:40:18	2020-08-30	9	[{"id_menu":7,"count":1}]	17740	pick-up	0	9
130000	2020-08-30 14:40:50	2020-08-30	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	36812	delivery	5	40
130001	2020-08-30 14:42:20	2020-08-30	12	[{"id_menu":3,"count":1}]	48848	delivery	5	17
130002	2020-08-30 14:43:38	2020-08-30	9	[{"id_menu":6,"count":1}]	14972	pick-up	0	9
130003	2020-08-30 14:43:56	2020-08-30	14	[{"id_menu":2,"count":1}]	35806	delivery	5	19
130004	2020-08-30 14:43:58	2020-08-30	14	[{"id_menu":2,"count":1}]	8619	delivery	5	19
130005	2020-08-30 14:45:36	2020-08-30	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	48800	delivery	5	37
130006	2020-08-30 14:46:03	2020-08-30	9	[{"id_menu":6,"count":2}]	48764	delivery	5	14
130007	2020-08-30 14:47:54	2020-08-30	9	[{"id_menu":6,"count":1}]	18805	delivery	5	14
130008	2020-08-30 14:49:51	2020-08-30	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18871	delivery	5	22
130009	2020-08-30 14:49:52	2020-08-30	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	48821	delivery	5	34
130010	2020-08-30 14:50:33	2020-08-30	17	[{"id_menu":4,"count":1}]	49034	delivery	5	22
130011	2020-08-30 14:53:03	2020-08-30	17	[{"id_menu":4,"count":1}]	21557	delivery	5	22
130012	2020-08-30 14:54:28	2020-08-30	14	[{"id_menu":2,"count":1}]	18652	pick-up	0	14
130013	2020-08-30 14:55:06	2020-08-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	49001	pick-up	0	18
130014	2020-08-30 14:55:58	2020-08-30	9	[{"id_menu":7,"count":2}]	48977	delivery	5	14
130015	2020-08-30 14:58:11	2020-08-30	14	[{"id_menu":2,"count":2}]	28324	delivery	5	19
130016	2020-08-30 14:58:21	2020-08-30	9	[{"id_menu":6,"count":1}]	7670	delivery	5	14
130017	2020-08-30 15:01:10	2020-08-30	9	[{"id_menu":7,"count":1}]	34669	delivery	5	14
130018	2020-08-30 15:04:51	2020-08-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	43717	delivery	5	28
130019	2020-08-30 15:07:00	2020-08-30	9	[{"id_menu":6,"count":1}]	48814	delivery	5	14
130020	2020-08-30 15:08:01	2020-08-30	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	48914	delivery	5	23
130021	2020-08-30 15:08:33	2020-08-30	14	[{"id_menu":2,"count":1}]	35590	delivery	5	19
130022	2020-08-30 15:08:49	2020-08-30	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	15696	delivery	5	40
130023	2020-08-30 15:09:17	2020-08-30	12	[{"id_menu":1,"count":1}]	38851	pick-up	0	12
130024	2020-08-30 15:10:53	2020-08-30	9	[{"id_menu":7,"count":1}]	2569	pick-up	0	9
130025	2020-08-30 15:11:14	2020-08-30	17	[{"id_menu":4,"count":1}]	48984	delivery	5	22
130026	2020-08-30 15:12:05	2020-08-30	8	[{"id_menu":5,"count":1}]	8536	delivery	5	13
130027	2020-08-30 15:12:21	2020-08-30	9	[{"id_menu":7,"count":1}]	48793	delivery	5	14
130028	2020-08-30 15:13:40	2020-08-30	12	[{"id_menu":3,"count":1}]	11979	delivery	5	17
130029	2020-08-30 15:14:59	2020-08-30	9	[{"id_menu":7,"count":1}]	14127	delivery	5	14
130030	2020-08-30 15:18:29	2020-08-30	14	[{"id_menu":2,"count":1}]	607	pick-up	0	14
130031	2020-08-30 15:20:05	2020-08-30	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	30104	delivery	5	36
130032	2020-08-30 15:23:41	2020-08-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	41926	delivery	5	27
130033	2020-08-30 15:26:00	2020-08-30	12	[{"id_menu":1,"count":1}]	47170	delivery	5	17
130034	2020-08-30 15:26:20	2020-08-30	14	[{"id_menu":2,"count":1}]	48947	pick-up	0	14
130035	2020-08-30 15:27:18	2020-08-30	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	33994	delivery	5	46
130036	2020-08-30 15:28:44	2020-08-30	9	[{"id_menu":7,"count":1}]	48901	delivery	5	14
130037	2020-08-30 15:29:10	2020-08-30	14	[{"id_menu":2,"count":1}]	30406	delivery	5	19
130038	2020-08-30 15:31:29	2020-08-30	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	14913	pick-up	0	26
130039	2020-08-30 15:32:44	2020-08-30	14	[{"id_menu":2,"count":1}]	30991	delivery	5	19
130040	2020-08-30 15:36:03	2020-08-30	9	[{"id_menu":6,"count":2}]	49031	delivery	5	14
130041	2020-08-30 15:38:11	2020-08-30	9	[{"id_menu":7,"count":1}]	22655	delivery	5	14
130042	2020-08-30 15:39:04	2020-08-30	8	[{"id_menu":5,"count":1}]	15653	delivery	5	13
130043	2020-08-30 15:41:42	2020-08-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	13277	delivery	5	23
130044	2020-08-30 15:44:09	2020-08-30	12	[{"id_menu":3,"count":1}]	48896	delivery	5	17
130045	2020-08-30 15:45:25	2020-08-30	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	48946	delivery	5	37
130046	2020-08-30 15:45:28	2020-08-30	9	[{"id_menu":6,"count":2}]	36901	delivery	5	14
130047	2020-08-30 15:45:47	2020-08-30	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	48858	delivery	5	39
130048	2020-08-30 15:48:59	2020-08-30	17	[{"id_menu":4,"count":1}]	43543	delivery	5	22
130049	2020-08-30 15:50:21	2020-08-30	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	17641	delivery	5	31
130050	2020-08-30 15:53:07	2020-08-30	14	[{"id_menu":2,"count":1}]	35599	pick-up	0	14
130051	2020-08-30 15:54:17	2020-08-30	17	[{"id_menu":4,"count":1}]	19107	delivery	5	22
130052	2020-08-30 15:56:23	2020-08-30	8	[{"id_menu":5,"count":1}]	34421	pick-up	0	8
130053	2020-08-30 15:56:41	2020-08-30	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	16613	pick-up	0	29
130054	2020-08-30 15:57:25	2020-08-30	9	[{"id_menu":6,"count":1}]	20255	delivery	5	14
130055	2020-08-30 15:58:42	2020-08-30	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	44685	delivery	5	31
130056	2020-08-30 15:59:43	2020-08-30	9	[{"id_menu":6,"count":1}]	13761	delivery	5	14
130057	2020-08-30 16:00:37	2020-08-30	17	[{"id_menu":4,"count":1}]	33949	delivery	5	22
130058	2020-08-30 16:01:21	2020-08-30	9	[{"id_menu":7,"count":1}]	43156	pick-up	0	9
130059	2020-08-30 16:02:03	2020-08-30	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	38094	delivery	5	34
130060	2020-08-30 16:03:51	2020-08-30	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	35291	delivery	5	25
130061	2020-08-30 16:04:46	2020-08-30	14	[{"id_menu":2,"count":1}]	48950	delivery	5	19
130062	2020-08-30 16:05:04	2020-08-30	12	[{"id_menu":3,"count":1}]	27019	delivery	5	17
130063	2020-08-30 16:06:31	2020-08-30	8	[{"id_menu":5,"count":1}]	5201	delivery	5	13
130064	2020-08-30 16:07:07	2020-08-30	9	[{"id_menu":6,"count":1}]	4804	delivery	5	14
130065	2020-08-30 16:08:16	2020-08-30	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	43320	delivery	5	34
130066	2020-08-30 16:10:48	2020-08-30	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	282	pick-up	0	38
130067	2020-08-30 16:11:32	2020-08-30	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4196	delivery	5	40
130068	2020-08-30 16:12:40	2020-08-30	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	49017	delivery	5	22
130069	2020-08-30 16:15:01	2020-08-30	14	[{"id_menu":2,"count":1}]	48842	delivery	5	19
130070	2020-08-30 16:15:27	2020-08-30	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	46315	delivery	5	34
130071	2020-08-30 16:16:00	2020-08-30	38	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2665	delivery	5	43
130072	2020-08-30 16:16:10	2020-08-30	9	[{"id_menu":7,"count":1}]	21782	delivery	5	14
130073	2020-08-30 16:17:34	2020-08-30	8	[{"id_menu":5,"count":1}]	27199	delivery	5	13
130074	2020-08-30 16:18:14	2020-08-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23350	pick-up	0	18
130075	2020-08-30 16:18:32	2020-08-30	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":1}]	42500	pick-up	0	26
130076	2020-08-30 16:18:39	2020-08-30	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23925	delivery	5	49
130077	2020-08-30 16:19:20	2020-08-30	12	[{"id_menu":1,"count":1}]	23988	delivery	5	17
130078	2020-08-30 16:19:22	2020-08-30	14	[{"id_menu":2,"count":2}]	7352	delivery	5	19
130079	2020-08-30 16:19:38	2020-08-30	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	25928	delivery	5	43
130080	2020-08-30 16:20:28	2020-08-30	8	[{"id_menu":5,"count":2}]	36574	pick-up	0	8
130081	2020-08-30 16:20:46	2020-08-30	12	[{"id_menu":1,"count":1}]	32144	pick-up	0	12
130082	2020-08-30 16:22:09	2020-08-30	9	[{"id_menu":7,"count":1}]	24726	delivery	5	14
130083	2020-08-30 16:22:49	2020-08-30	12	[{"id_menu":3,"count":2}]	37349	delivery	5	17
130084	2020-08-30 16:24:08	2020-08-30	12	[{"id_menu":1,"count":1}]	32952	delivery	5	17
130085	2020-08-30 16:24:25	2020-08-30	12	[{"id_menu":3,"count":1}]	40658	pick-up	0	12
130086	2020-08-30 16:24:58	2020-08-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28283	pick-up	0	18
130087	2020-08-30 16:25:39	2020-08-30	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	25519	delivery	5	44
130088	2020-08-30 16:26:43	2020-08-30	8	[{"id_menu":5,"count":1}]	48775	delivery	5	13
130089	2020-08-30 16:26:48	2020-08-30	12	[{"id_menu":1,"count":1}]	8664	delivery	5	17
130090	2020-08-30 16:27:05	2020-08-30	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	48865	delivery	5	34
130091	2020-08-30 16:27:57	2020-08-30	17	[{"id_menu":4,"count":1}]	9116	delivery	5	22
130092	2020-08-30 16:28:56	2020-08-30	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	12224	delivery	5	31
130093	2020-08-30 16:31:00	2020-08-30	9	[{"id_menu":6,"count":1}]	45725	delivery	5	14
130094	2020-08-30 16:32:42	2020-08-30	12	[{"id_menu":1,"count":1}]	49012	pick-up	0	12
130095	2020-08-30 16:34:46	2020-08-30	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	32152	pick-up	0	26
130096	2020-08-30 16:34:48	2020-08-30	9	[{"id_menu":7,"count":1}]	18770	pick-up	0	9
130097	2020-08-30 16:34:52	2020-08-30	14	[{"id_menu":2,"count":2}]	28218	delivery	5	19
130098	2020-08-30 16:36:45	2020-08-30	17	[{"id_menu":4,"count":1}]	48828	delivery	5	22
130099	2020-08-30 16:42:36	2020-08-30	9	[{"id_menu":6,"count":1}]	48832	delivery	5	14
130100	2020-08-30 16:43:46	2020-08-30	12	[{"id_menu":3,"count":1}]	2883	delivery	5	17
130101	2020-08-30 16:44:37	2020-08-30	17	[{"id_menu":4,"count":1}]	48988	delivery	5	22
130102	2020-08-30 16:47:16	2020-08-30	12	[{"id_menu":1,"count":1}]	13410	pick-up	0	12
130103	2020-08-30 16:47:59	2020-08-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	822	pick-up	0	22
130104	2020-08-30 16:52:16	2020-08-30	14	[{"id_menu":2,"count":1}]	37921	delivery	5	19
130105	2020-08-30 16:52:16	2020-08-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	46576	delivery	5	28
130106	2020-08-30 16:57:09	2020-08-30	14	[{"id_menu":2,"count":2}]	48905	delivery	5	19
130107	2020-08-30 16:57:11	2020-08-30	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	34229	delivery	5	25
130108	2020-08-30 16:57:24	2020-08-30	14	[{"id_menu":2,"count":1}]	13570	delivery	5	19
130109	2020-08-30 16:59:13	2020-08-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	17926	delivery	5	27
130110	2020-08-30 17:00:57	2020-08-30	14	[{"id_menu":2,"count":1}]	20498	delivery	5	19
130111	2020-08-30 17:01:56	2020-08-30	9	[{"id_menu":6,"count":1}]	29702	pick-up	0	9
130112	2020-08-30 17:02:20	2020-08-30	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	4079	delivery	5	40
130113	2020-08-30 17:02:51	2020-08-30	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	48952	delivery	5	38
130114	2020-08-30 17:03:06	2020-08-30	14	[{"id_menu":2,"count":1}]	48776	pick-up	0	14
130115	2020-08-30 17:03:47	2020-08-30	8	[{"id_menu":5,"count":1}]	16459	delivery	5	13
130116	2020-08-30 17:05:37	2020-08-30	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	48754	delivery	5	38
130117	2020-08-30 17:05:40	2020-08-30	8	[{"id_menu":5,"count":1}]	36177	delivery	5	13
130118	2020-08-30 17:08:03	2020-08-30	9	[{"id_menu":6,"count":1}]	37579	delivery	5	14
130119	2020-08-30 17:09:46	2020-08-30	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	292	delivery	5	28
130120	2020-08-30 17:10:35	2020-08-30	17	[{"id_menu":4,"count":1}]	17784	delivery	5	22
130121	2020-08-30 17:11:14	2020-08-30	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	32097	delivery	5	45
130122	2020-08-30 17:12:24	2020-08-30	9	[{"id_menu":7,"count":1}]	16422	pick-up	0	9
130123	2020-08-30 17:12:27	2020-08-30	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	48923	delivery	5	38
130124	2020-08-30 17:13:58	2020-08-30	14	[{"id_menu":2,"count":1}]	2237	pick-up	0	14
130125	2020-08-30 17:14:05	2020-08-30	14	[{"id_menu":2,"count":1}]	8388	delivery	5	19
130126	2020-08-30 17:18:02	2020-08-30	9	[{"id_menu":7,"count":1}]	7216	delivery	5	14
130127	2020-08-30 17:18:09	2020-08-30	17	[{"id_menu":4,"count":1}]	9308	pick-up	0	17
130128	2020-08-30 17:18:30	2020-08-30	17	[{"id_menu":4,"count":1}]	48935	delivery	5	22
130129	2020-08-30 17:21:33	2020-08-30	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":2}]	49020	delivery	5	26
130130	2020-08-30 17:22:21	2020-08-30	8	[{"id_menu":5,"count":1}]	16749	delivery	5	13
130131	2020-08-30 17:24:15	2020-08-30	14	[{"id_menu":2,"count":1}]	23840	delivery	5	19
130132	2020-08-30 17:25:01	2020-08-30	17	[{"id_menu":4,"count":1}]	48859	delivery	5	22
130133	2020-08-30 17:25:56	2020-08-30	17	[{"id_menu":4,"count":1}]	9750	pick-up	0	17
130134	2020-08-30 17:26:16	2020-08-30	17	[{"id_menu":4,"count":1}]	17245	pick-up	0	17
130135	2020-08-30 17:28:47	2020-08-30	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	35403	pick-up	0	20
130136	2020-08-30 17:29:26	2020-08-30	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	48940	pick-up	0	17
130137	2020-08-30 17:29:37	2020-08-30	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	30771	pick-up	0	31
130138	2020-08-30 17:29:48	2020-08-30	8	[{"id_menu":5,"count":1}]	26843	delivery	5	13
130139	2020-08-30 17:30:21	2020-08-30	17	[{"id_menu":4,"count":1}]	21122	delivery	5	22
130140	2020-08-30 17:30:42	2020-08-30	17	[{"id_menu":4,"count":1}]	754	pick-up	0	17
130141	2020-08-30 17:32:19	2020-08-30	17	[{"id_menu":4,"count":1}]	26045	delivery	5	22
130142	2020-08-30 17:32:28	2020-08-30	9	[{"id_menu":6,"count":3}]	38985	delivery	5	14
130143	2020-08-30 17:32:40	2020-08-30	26	[{"id_menu":1,"count":2},{"id_menu":2,"count":2}]	19711	delivery	5	31
130144	2020-08-30 17:36:14	2020-08-30	12	[{"id_menu":1,"count":1}]	47957	pick-up	0	12
130145	2020-08-30 17:37:40	2020-08-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	48978	pick-up	0	23
130146	2020-08-30 17:37:43	2020-08-30	9	[{"id_menu":7,"count":1}]	34475	delivery	5	14
130147	2020-08-30 17:38:13	2020-08-30	17	[{"id_menu":4,"count":1}]	48824	delivery	5	22
130148	2020-08-30 17:38:23	2020-08-30	8	[{"id_menu":5,"count":1}]	32482	delivery	5	13
130149	2020-08-30 17:41:25	2020-08-30	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	49005	delivery	5	43
130150	2020-08-30 17:42:19	2020-08-30	14	[{"id_menu":2,"count":1}]	9923	delivery	5	19
130151	2020-08-30 17:51:47	2020-08-30	8	[{"id_menu":5,"count":1}]	27567	delivery	5	13
130152	2020-08-30 17:52:47	2020-08-30	9	[{"id_menu":6,"count":1}]	16438	delivery	5	14
130153	2020-08-30 17:55:20	2020-08-30	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	44750	delivery	5	40
130154	2020-08-30 17:55:26	2020-08-30	9	[{"id_menu":7,"count":1}]	22373	delivery	5	14
130155	2020-08-30 17:55:45	2020-08-30	17	[{"id_menu":4,"count":1}]	4192	delivery	5	22
130156	2020-08-30 17:55:54	2020-08-30	12	[{"id_menu":3,"count":1}]	48473	delivery	5	17
130157	2020-08-30 18:01:08	2020-08-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	36320	pick-up	0	26
130158	2020-08-30 18:02:57	2020-08-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	40047	delivery	5	27
130159	2020-08-30 18:05:56	2020-08-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	47837	delivery	5	31
130160	2020-08-30 18:06:57	2020-08-30	9	[{"id_menu":6,"count":1}]	48944	delivery	5	14
130161	2020-08-30 18:07:02	2020-08-30	12	[{"id_menu":3,"count":1}]	46683	delivery	5	17
130162	2020-08-30 18:07:14	2020-08-30	9	[{"id_menu":6,"count":1}]	20948	delivery	5	14
130163	2020-08-30 18:07:35	2020-08-30	9	[{"id_menu":6,"count":1}]	5639	pick-up	0	9
130164	2020-08-30 18:08:13	2020-08-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	48948	delivery	5	31
130165	2020-08-30 18:10:32	2020-08-30	9	[{"id_menu":6,"count":2}]	23432	pick-up	0	9
130166	2020-08-30 18:14:21	2020-08-30	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	10446	delivery	5	40
130167	2020-08-30 18:14:54	2020-08-30	9	[{"id_menu":6,"count":1}]	48975	pick-up	0	9
130168	2020-08-30 18:15:01	2020-08-30	9	[{"id_menu":7,"count":1}]	22650	delivery	5	14
130169	2020-08-30 18:17:13	2020-08-30	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	21515	pick-up	0	34
130170	2020-08-30 18:18:41	2020-08-30	9	[{"id_menu":6,"count":1}]	44655	delivery	5	14
130171	2020-08-30 18:22:28	2020-08-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	35079	delivery	5	23
130172	2020-08-30 18:22:29	2020-08-30	8	[{"id_menu":5,"count":1}]	30671	delivery	5	13
130173	2020-08-30 18:22:45	2020-08-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	14775	delivery	5	31
130174	2020-08-30 18:23:18	2020-08-30	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	13149	delivery	5	34
130175	2020-08-30 18:23:24	2020-08-30	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3352	pick-up	0	29
130176	2020-08-30 18:23:56	2020-08-30	9	[{"id_menu":7,"count":1}]	48887	pick-up	0	9
130177	2020-08-30 18:24:34	2020-08-30	9	[{"id_menu":6,"count":1}]	46793	delivery	5	14
130178	2020-08-30 18:26:37	2020-08-30	8	[{"id_menu":5,"count":1}]	17770	delivery	5	13
130179	2020-08-30 18:28:13	2020-08-30	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	19296	delivery	5	29
130180	2020-08-30 18:28:19	2020-08-30	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	23365	delivery	5	43
130181	2020-08-30 18:29:11	2020-08-30	9	[{"id_menu":6,"count":1}]	8148	delivery	5	14
130182	2020-08-30 18:30:07	2020-08-30	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48774	delivery	5	37
130183	2020-08-30 18:32:59	2020-08-30	8	[{"id_menu":5,"count":1}]	37417	delivery	5	13
130184	2020-08-30 18:35:23	2020-08-30	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	29588	delivery	5	36
130185	2020-08-30 18:35:51	2020-08-30	9	[{"id_menu":6,"count":1}]	22324	delivery	5	14
130186	2020-08-30 18:36:43	2020-08-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	23270	delivery	5	26
130187	2020-08-30 18:38:14	2020-08-30	9	[{"id_menu":7,"count":2}]	48551	delivery	5	14
130188	2020-08-30 18:38:42	2020-08-30	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	48841	delivery	5	45
130189	2020-08-30 18:40:51	2020-08-30	12	[{"id_menu":3,"count":1}]	15740	delivery	5	17
130190	2020-08-30 18:41:03	2020-08-30	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	39870	delivery	5	34
130191	2020-08-30 18:45:44	2020-08-30	29	[{"id_menu":1,"count":3},{"id_menu":4,"count":1}]	21561	delivery	5	34
130192	2020-08-30 18:51:15	2020-08-30	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48863	delivery	5	48
130193	2020-08-30 18:53:08	2020-08-30	14	[{"id_menu":2,"count":1}]	5363	delivery	5	19
130194	2020-08-30 18:53:57	2020-08-30	12	[{"id_menu":3,"count":1}]	2855	delivery	5	17
130195	2020-08-30 18:58:59	2020-08-30	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	12169	delivery	5	34
130196	2020-08-30 18:59:54	2020-08-30	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	4809	delivery	5	29
130197	2020-08-30 19:00:01	2020-08-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	15622	delivery	5	31
130198	2020-08-30 19:01:21	2020-08-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	26127	pick-up	0	18
130199	2020-08-30 19:02:48	2020-08-30	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	17365	pick-up	0	21
130200	2020-08-30 19:03:17	2020-08-30	8	[{"id_menu":5,"count":1}]	48902	delivery	5	13
130201	2020-08-30 19:05:53	2020-08-30	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	18549	delivery	5	40
130202	2020-08-30 19:06:11	2020-08-30	12	[{"id_menu":1,"count":1}]	4309	delivery	5	17
130203	2020-08-30 19:11:22	2020-08-30	14	[{"id_menu":2,"count":1}]	42136	delivery	5	19
130204	2020-08-30 19:14:41	2020-08-30	9	[{"id_menu":7,"count":3}]	48953	delivery	5	14
130205	2020-08-30 19:14:59	2020-08-30	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	48955	delivery	5	44
130206	2020-08-30 19:15:47	2020-08-30	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	39481	delivery	5	31
130207	2020-08-30 19:18:24	2020-08-30	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	48951	delivery	5	31
130208	2020-08-30 19:19:17	2020-08-30	9	[{"id_menu":6,"count":2}]	41845	pick-up	0	9
130209	2020-08-30 19:19:22	2020-08-30	9	[{"id_menu":6,"count":3}]	8268	delivery	5	14
130210	2020-08-30 19:20:59	2020-08-30	12	[{"id_menu":1,"count":1}]	28125	delivery	5	17
130211	2020-08-30 19:21:48	2020-08-30	9	[{"id_menu":7,"count":1}]	46316	delivery	5	14
130212	2020-08-30 19:23:11	2020-08-30	17	[{"id_menu":4,"count":1}]	46586	pick-up	0	17
130213	2020-08-30 19:25:55	2020-08-30	9	[{"id_menu":6,"count":1}]	37936	delivery	5	14
130214	2020-08-30 19:26:15	2020-08-30	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	37718	delivery	5	30
130215	2020-08-30 19:28:18	2020-08-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	626	delivery	5	23
130216	2020-08-30 19:28:34	2020-08-30	8	[{"id_menu":5,"count":2}]	48995	delivery	5	13
130217	2020-08-30 19:28:46	2020-08-30	17	[{"id_menu":4,"count":1}]	49030	delivery	5	22
130218	2020-08-30 19:30:48	2020-08-30	12	[{"id_menu":1,"count":1}]	33876	delivery	5	17
130219	2020-08-30 19:31:05	2020-08-30	9	[{"id_menu":7,"count":1}]	48470	pick-up	0	9
130220	2020-08-30 19:31:42	2020-08-30	12	[{"id_menu":3,"count":2}]	20503	pick-up	0	12
130221	2020-08-30 19:31:57	2020-08-30	14	[{"id_menu":2,"count":1}]	41194	delivery	5	19
130222	2020-08-30 19:32:31	2020-08-30	12	[{"id_menu":1,"count":1}]	48804	pick-up	0	12
130223	2020-08-30 19:34:06	2020-08-30	17	[{"id_menu":4,"count":1}]	25320	pick-up	0	17
130224	2020-08-30 19:34:35	2020-08-30	17	[{"id_menu":4,"count":1}]	32280	delivery	5	22
130225	2020-08-30 19:34:36	2020-08-30	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	2821	pick-up	0	29
130226	2020-08-30 19:35:07	2020-08-30	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23908	delivery	5	31
130227	2020-08-30 19:38:03	2020-08-30	8	[{"id_menu":5,"count":1}]	48996	delivery	5	13
130228	2020-08-30 19:40:05	2020-08-30	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	48919	delivery	5	39
130229	2020-08-30 19:40:52	2020-08-30	12	[{"id_menu":3,"count":1}]	48954	delivery	5	17
130230	2020-08-30 19:41:04	2020-08-30	12	[{"id_menu":1,"count":1}]	14245	delivery	5	17
130231	2020-08-30 19:42:15	2020-08-30	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	8441	delivery	5	34
130232	2020-08-30 19:43:04	2020-08-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	9367	delivery	5	22
130233	2020-08-30 19:44:04	2020-08-30	8	[{"id_menu":5,"count":1}]	173	pick-up	0	8
130234	2020-08-30 19:44:26	2020-08-30	9	[{"id_menu":7,"count":2}]	12443	delivery	5	14
130235	2020-08-30 19:45:16	2020-08-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	48982	delivery	5	31
130236	2020-08-30 19:45:29	2020-08-30	12	[{"id_menu":1,"count":1}]	18603	delivery	5	17
130237	2020-08-30 19:45:53	2020-08-30	12	[{"id_menu":1,"count":1}]	48791	delivery	5	17
130238	2020-08-30 19:46:03	2020-08-30	9	[{"id_menu":7,"count":1}]	25478	delivery	5	14
130239	2020-08-30 19:46:28	2020-08-30	9	[{"id_menu":7,"count":1}]	3594	pick-up	0	9
130240	2020-08-30 19:47:34	2020-08-30	17	[{"id_menu":4,"count":1}]	35894	delivery	5	22
130241	2020-08-30 19:47:46	2020-08-30	9	[{"id_menu":6,"count":1}]	39279	delivery	5	14
130242	2020-08-30 19:48:01	2020-08-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	5183	delivery	5	28
130243	2020-08-30 19:49:05	2020-08-30	12	[{"id_menu":1,"count":1}]	32605	delivery	5	17
130244	2020-08-30 19:52:35	2020-08-30	30	[{"id_menu":3,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	25493	delivery	5	35
130245	2020-08-30 19:54:41	2020-08-30	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	48934	delivery	5	26
130246	2020-08-30 19:57:10	2020-08-30	14	[{"id_menu":2,"count":1}]	31766	delivery	5	19
130247	2020-08-30 19:57:18	2020-08-30	12	[{"id_menu":3,"count":1}]	34433	delivery	5	17
130248	2020-08-30 19:58:42	2020-08-30	17	[{"id_menu":4,"count":1}]	9749	pick-up	0	17
130249	2020-08-30 19:58:46	2020-08-30	8	[{"id_menu":5,"count":2}]	48836	delivery	5	13
130250	2020-08-30 19:59:58	2020-08-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	7027	delivery	5	31
130251	2020-08-30 20:01:33	2020-08-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	2151	delivery	5	31
130252	2020-08-30 20:02:34	2020-08-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	32777	delivery	5	23
130253	2020-08-30 20:02:50	2020-08-30	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	48980	delivery	5	45
130254	2020-08-30 20:04:33	2020-08-30	14	[{"id_menu":2,"count":1}]	15194	pick-up	0	14
130255	2020-08-30 20:05:48	2020-08-30	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	11006	delivery	5	31
130256	2020-08-30 20:06:49	2020-08-30	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	48731	delivery	5	28
130257	2020-08-30 20:09:01	2020-08-30	14	[{"id_menu":2,"count":1}]	13003	pick-up	0	14
130258	2020-08-30 20:09:54	2020-08-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	39925	delivery	5	23
130259	2020-08-30 20:10:16	2020-08-30	8	[{"id_menu":5,"count":1}]	29710	delivery	5	13
130260	2020-08-30 20:10:19	2020-08-30	14	[{"id_menu":2,"count":1}]	38860	delivery	5	19
130261	2020-08-30 20:10:50	2020-08-30	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	41219	delivery	5	55
130262	2020-08-30 20:11:12	2020-08-30	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	8866	delivery	5	22
130263	2020-08-30 20:12:52	2020-08-30	9	[{"id_menu":6,"count":1}]	12205	pick-up	0	9
130264	2020-08-30 20:13:22	2020-08-30	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	48889	pick-up	0	31
130265	2020-08-30 20:15:10	2020-08-30	9	[{"id_menu":6,"count":1}]	4732	delivery	5	14
130266	2020-08-30 20:15:22	2020-08-30	12	[{"id_menu":3,"count":1}]	15028	pick-up	0	12
130267	2020-08-30 20:15:40	2020-08-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7526	delivery	5	31
130268	2020-08-30 20:16:53	2020-08-30	14	[{"id_menu":2,"count":1}]	48993	delivery	5	19
130269	2020-08-30 20:19:12	2020-08-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	45083	delivery	5	28
130270	2020-08-30 20:19:21	2020-08-30	8	[{"id_menu":5,"count":1}]	48768	delivery	5	13
130271	2020-08-30 20:19:45	2020-08-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	48756	delivery	5	28
130272	2020-08-30 20:25:22	2020-08-30	9	[{"id_menu":7,"count":1}]	37714	delivery	5	14
130273	2020-08-30 20:25:27	2020-08-30	44	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48779	delivery	5	49
130274	2020-08-30 20:26:07	2020-08-30	14	[{"id_menu":2,"count":1}]	48907	delivery	5	19
130275	2020-08-30 20:29:38	2020-08-30	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19691	delivery	5	34
130276	2020-08-30 20:29:55	2020-08-30	12	[{"id_menu":1,"count":1}]	25295	pick-up	0	12
130277	2020-08-30 20:32:30	2020-08-30	17	[{"id_menu":4,"count":2}]	34594	delivery	5	22
130278	2020-08-30 20:32:59	2020-08-30	14	[{"id_menu":2,"count":1}]	6916	pick-up	0	14
130279	2020-08-30 20:33:08	2020-08-30	17	[{"id_menu":4,"count":1}]	48666	pick-up	0	17
130280	2020-08-30 20:34:51	2020-08-30	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	23280	delivery	5	34
130281	2020-08-30 20:36:52	2020-08-30	12	[{"id_menu":1,"count":1}]	709	pick-up	0	12
130282	2020-08-30 20:38:04	2020-08-30	9	[{"id_menu":7,"count":1}]	26618	pick-up	0	9
130283	2020-08-30 20:38:19	2020-08-30	9	[{"id_menu":6,"count":1}]	9485	delivery	5	14
130284	2020-08-30 20:39:26	2020-08-30	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	48974	delivery	5	39
130285	2020-08-30 20:39:35	2020-08-30	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	48968	pick-up	0	29
130286	2020-08-30 20:42:48	2020-08-30	17	[{"id_menu":4,"count":1}]	26445	delivery	5	22
130287	2020-08-30 20:44:15	2020-08-30	17	[{"id_menu":4,"count":1}]	4634	delivery	5	22
130288	2020-08-30 20:44:49	2020-08-30	12	[{"id_menu":3,"count":1}]	27557	pick-up	0	12
130289	2020-08-30 20:48:52	2020-08-30	17	[{"id_menu":4,"count":1}]	41154	delivery	5	22
130290	2020-08-30 20:51:16	2020-08-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48861	pick-up	0	18
130291	2020-08-30 20:51:59	2020-08-30	17	[{"id_menu":4,"count":1}]	47698	delivery	5	22
130292	2020-08-30 20:52:57	2020-08-30	14	[{"id_menu":2,"count":1}]	46451	delivery	5	19
130293	2020-08-30 20:54:12	2020-08-30	9	[{"id_menu":6,"count":1}]	15306	delivery	5	14
130294	2020-08-30 20:54:43	2020-08-30	12	[{"id_menu":1,"count":1}]	11838	pick-up	0	12
130295	2020-08-30 20:54:47	2020-08-30	14	[{"id_menu":2,"count":1}]	30119	delivery	5	19
130296	2020-08-30 20:56:04	2020-08-30	9	[{"id_menu":6,"count":1}]	6232	pick-up	0	9
130297	2020-08-30 21:01:08	2020-08-30	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	48961	delivery	5	34
130298	2020-08-30 21:01:29	2020-08-30	9	[{"id_menu":6,"count":1}]	48847	delivery	5	14
130299	2020-08-30 21:01:46	2020-08-30	9	[{"id_menu":6,"count":1}]	48817	delivery	5	14
130300	2020-08-30 21:02:05	2020-08-30	17	[{"id_menu":4,"count":1}]	24274	pick-up	0	17
130301	2020-08-30 21:02:59	2020-08-30	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	48931	pick-up	0	21
130302	2020-08-30 21:05:41	2020-08-30	14	[{"id_menu":2,"count":1}]	19965	delivery	5	19
130303	2020-08-30 21:07:15	2020-08-30	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	41386	delivery	5	48
130304	2020-08-30 21:07:23	2020-08-30	8	[{"id_menu":5,"count":1}]	1258	delivery	5	13
130305	2020-08-30 21:13:00	2020-08-30	17	[{"id_menu":4,"count":1}]	5848	delivery	5	22
130306	2020-08-30 21:13:26	2020-08-30	12	[{"id_menu":1,"count":1}]	17808	delivery	5	17
130307	2020-08-30 21:16:38	2020-08-30	8	[{"id_menu":5,"count":1}]	23407	delivery	5	13
130308	2020-08-30 21:17:55	2020-08-30	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	18612	delivery	5	34
130309	2020-08-30 21:19:45	2020-08-30	14	[{"id_menu":2,"count":1}]	35161	pick-up	0	14
130310	2020-08-30 21:20:33	2020-08-30	9	[{"id_menu":7,"count":1}]	48912	delivery	5	14
130311	2020-08-30 21:20:40	2020-08-30	12	[{"id_menu":3,"count":1}]	46810	delivery	5	17
130312	2020-08-30 21:20:44	2020-08-30	12	[{"id_menu":1,"count":1}]	3736	pick-up	0	12
130313	2020-08-30 21:21:28	2020-08-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":3}]	48983	delivery	5	22
130314	2020-08-30 21:22:17	2020-08-30	14	[{"id_menu":2,"count":1}]	48229	delivery	5	19
130315	2020-08-30 21:23:32	2020-08-30	14	[{"id_menu":2,"count":1}]	48761	delivery	5	19
130316	2020-08-30 21:25:47	2020-08-30	12	[{"id_menu":1,"count":1}]	5485	delivery	5	17
130317	2020-08-30 21:26:03	2020-08-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	38401	delivery	5	26
130318	2020-08-30 21:26:12	2020-08-30	12	[{"id_menu":1,"count":1}]	4206	delivery	5	17
130319	2020-08-30 21:26:39	2020-08-30	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	32101	delivery	5	34
130320	2020-08-30 21:26:51	2020-08-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	48909	delivery	5	31
130321	2020-08-30 21:27:42	2020-08-30	14	[{"id_menu":2,"count":1}]	38233	delivery	5	19
130322	2020-08-30 21:30:42	2020-08-30	17	[{"id_menu":4,"count":2}]	48827	delivery	5	22
130323	2020-08-30 21:30:55	2020-08-30	9	[{"id_menu":6,"count":1}]	45294	delivery	5	14
130324	2020-08-30 21:30:58	2020-08-30	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	25571	pick-up	0	38
130325	2020-08-30 21:32:54	2020-08-30	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	49033	delivery	5	42
130326	2020-08-30 21:36:20	2020-08-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	48932	delivery	5	28
130327	2020-08-30 21:38:45	2020-08-30	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	48786	delivery	5	35
130328	2020-08-30 21:39:26	2020-08-30	14	[{"id_menu":2,"count":1}]	48838	delivery	5	19
130329	2020-08-30 21:40:48	2020-08-30	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	5992	delivery	5	39
130330	2020-08-30 21:41:39	2020-08-30	12	[{"id_menu":3,"count":1}]	854	pick-up	0	12
130331	2020-08-30 21:43:27	2020-08-30	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	48962	pick-up	0	29
130332	2020-08-30 21:45:16	2020-08-30	14	[{"id_menu":2,"count":1}]	48833	delivery	5	19
130333	2020-08-30 21:46:13	2020-08-30	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	39108	delivery	5	44
130334	2020-08-30 21:47:51	2020-08-30	9	[{"id_menu":7,"count":1}]	8702	delivery	5	14
130335	2020-08-30 21:48:36	2020-08-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	48922	delivery	5	26
130336	2020-08-30 21:48:51	2020-08-30	14	[{"id_menu":2,"count":1}]	43504	delivery	5	19
130337	2020-08-30 21:49:29	2020-08-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	46464	pick-up	0	21
130338	2020-08-30 21:50:30	2020-08-30	17	[{"id_menu":4,"count":1}]	42928	pick-up	0	17
130339	2020-08-30 21:53:02	2020-08-30	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	41604	delivery	5	25
130340	2020-08-30 21:54:31	2020-08-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	9784	delivery	5	22
130341	2020-08-30 21:55:20	2020-08-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	49037	delivery	5	28
130342	2020-08-30 21:58:14	2020-08-30	9	[{"id_menu":6,"count":1}]	48831	delivery	5	14
130343	2020-08-30 21:58:22	2020-08-30	17	[{"id_menu":4,"count":2}]	34358	delivery	5	22
130344	2020-08-30 21:59:06	2020-08-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	30090	delivery	5	26
130345	2020-08-30 22:00:14	2020-08-30	37	[{"id_menu":3,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	30616	delivery	5	42
130346	2020-08-30 22:01:55	2020-08-30	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	47252	delivery	5	26
130347	2020-08-30 22:02:27	2020-08-30	9	[{"id_menu":7,"count":1}]	4034	pick-up	0	9
130348	2020-08-30 22:02:33	2020-08-30	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	24165	delivery	5	53
130349	2020-08-30 22:03:20	2020-08-30	14	[{"id_menu":2,"count":1}]	20021	pick-up	0	14
130350	2020-08-30 22:03:24	2020-08-30	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	2623	pick-up	0	29
130351	2020-08-30 22:08:12	2020-08-30	39	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	5979	delivery	5	44
130352	2020-08-30 22:09:53	2020-08-30	9	[{"id_menu":6,"count":1}]	48967	delivery	5	14
130353	2020-08-30 22:10:14	2020-08-30	14	[{"id_menu":2,"count":1}]	48854	delivery	5	19
130354	2020-08-30 22:12:27	2020-08-30	9	[{"id_menu":6,"count":1}]	10022	delivery	5	14
130355	2020-08-30 22:16:16	2020-08-30	17	[{"id_menu":4,"count":1}]	12338	pick-up	0	17
130356	2020-08-30 22:18:15	2020-08-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	3260	pick-up	0	22
130357	2020-08-30 22:20:11	2020-08-30	9	[{"id_menu":6,"count":1}]	9423	pick-up	0	9
130358	2020-08-30 22:20:55	2020-08-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	49038	delivery	5	28
130359	2020-08-30 22:21:45	2020-08-30	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	41290	delivery	5	35
130360	2020-08-30 22:27:17	2020-08-30	9	[{"id_menu":6,"count":1}]	48079	delivery	5	14
130361	2020-08-30 22:30:14	2020-08-30	12	[{"id_menu":1,"count":1}]	31218	pick-up	0	12
130362	2020-08-30 22:30:36	2020-08-30	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	2659	pick-up	0	24
130363	2020-08-30 22:30:54	2020-08-30	12	[{"id_menu":1,"count":1}]	8394	pick-up	0	12
130364	2020-08-30 22:31:04	2020-08-30	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	48771	delivery	5	26
130365	2020-08-30 22:33:01	2020-08-30	9	[{"id_menu":7,"count":1}]	48837	delivery	5	14
130366	2020-08-30 22:35:02	2020-08-30	9	[{"id_menu":6,"count":2}]	30604	delivery	5	14
130367	2020-08-30 22:35:24	2020-08-30	9	[{"id_menu":6,"count":1}]	12670	delivery	5	14
130368	2020-08-30 22:36:25	2020-08-30	9	[{"id_menu":6,"count":1}]	6987	delivery	5	14
130369	2020-08-30 22:36:34	2020-08-30	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12488	delivery	5	45
130370	2020-08-30 22:39:45	2020-08-30	9	[{"id_menu":7,"count":1}]	24047	delivery	5	14
130371	2020-08-30 22:39:49	2020-08-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	48794	pick-up	0	17
130372	2020-08-30 22:40:30	2020-08-30	8	[{"id_menu":5,"count":1}]	18433	delivery	5	13
130373	2020-08-30 22:41:26	2020-08-30	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	27861	pick-up	0	32
130374	2020-08-30 22:41:33	2020-08-30	17	[{"id_menu":4,"count":1}]	37797	delivery	5	22
130375	2020-08-30 22:41:55	2020-08-30	17	[{"id_menu":4,"count":1}]	5790	pick-up	0	17
130376	2020-08-30 22:42:24	2020-08-30	9	[{"id_menu":7,"count":1}]	8778	pick-up	0	9
130377	2020-08-30 22:43:30	2020-08-30	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	23466	delivery	5	23
130378	2020-08-30 22:44:46	2020-08-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	7958	pick-up	0	26
130379	2020-08-30 22:44:47	2020-08-30	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	21142	delivery	5	43
130380	2020-08-30 22:46:58	2020-08-30	9	[{"id_menu":6,"count":1}]	48844	delivery	5	14
130381	2020-08-30 22:52:40	2020-08-30	14	[{"id_menu":2,"count":1}]	8903	delivery	5	19
130382	2020-08-30 22:53:10	2020-08-30	9	[{"id_menu":7,"count":1}]	19160	delivery	5	14
130383	2020-08-30 22:53:38	2020-08-30	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	32623	delivery	5	31
130384	2020-08-30 22:54:53	2020-08-30	8	[{"id_menu":5,"count":1}]	25930	pick-up	0	8
130385	2020-08-30 22:57:17	2020-08-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	15575	delivery	5	27
130386	2020-08-30 22:57:36	2020-08-30	14	[{"id_menu":2,"count":1}]	49027	delivery	5	19
130387	2020-08-30 22:57:54	2020-08-30	14	[{"id_menu":2,"count":1}]	21076	delivery	5	19
130388	2020-08-30 23:01:17	2020-08-30	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48850	delivery	5	23
130389	2020-08-30 23:01:36	2020-08-30	9	[{"id_menu":6,"count":1}]	43399	delivery	5	14
130390	2020-08-30 23:02:17	2020-08-30	9	[{"id_menu":6,"count":1}]	47987	delivery	5	14
130391	2020-08-30 23:05:12	2020-08-30	9	[{"id_menu":6,"count":1}]	31800	delivery	5	14
130392	2020-08-30 23:07:24	2020-08-30	17	[{"id_menu":4,"count":1}]	48881	pick-up	0	17
130393	2020-08-30 23:07:49	2020-08-30	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	48777	delivery	5	27
130394	2020-08-30 23:09:09	2020-08-30	9	[{"id_menu":7,"count":1}]	30917	delivery	5	14
130395	2020-08-30 23:09:32	2020-08-30	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48879	delivery	5	40
130396	2020-08-30 23:10:43	2020-08-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	48866	delivery	5	31
130397	2020-08-30 23:10:46	2020-08-30	9	[{"id_menu":6,"count":1}]	48987	delivery	5	14
130398	2020-08-30 23:11:43	2020-08-30	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	15863	delivery	5	22
130399	2020-08-30 23:12:29	2020-08-30	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	49011	delivery	5	31
130400	2020-08-30 23:13:57	2020-08-30	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	15337	delivery	5	40
130401	2020-08-30 23:14:24	2020-08-30	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	30389	delivery	5	31
130402	2020-08-30 23:14:28	2020-08-30	9	[{"id_menu":6,"count":1}]	29667	delivery	5	14
130403	2020-08-30 23:15:02	2020-08-30	17	[{"id_menu":4,"count":1}]	17089	pick-up	0	17
130404	2020-08-30 23:15:56	2020-08-30	12	[{"id_menu":3,"count":1}]	9021	delivery	5	17
130405	2020-08-30 23:16:16	2020-08-30	12	[{"id_menu":1,"count":1}]	25337	delivery	5	17
130406	2020-08-30 23:17:23	2020-08-30	9	[{"id_menu":6,"count":1}]	48910	delivery	5	14
130407	2020-08-30 23:17:24	2020-08-30	9	[{"id_menu":6,"count":1}]	46468	delivery	5	14
130408	2020-08-30 23:18:42	2020-08-30	9	[{"id_menu":6,"count":1}]	48986	delivery	5	14
130409	2020-08-30 23:19:31	2020-08-30	8	[{"id_menu":5,"count":1}]	415	delivery	5	13
130410	2020-08-30 23:19:40	2020-08-30	14	[{"id_menu":2,"count":1}]	48855	delivery	5	19
130411	2020-08-30 23:20:48	2020-08-30	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	37548	delivery	5	36
130412	2020-08-30 23:21:24	2020-08-30	9	[{"id_menu":7,"count":2}]	40373	delivery	5	14
130413	2020-08-30 23:21:45	2020-08-30	17	[{"id_menu":4,"count":1}]	33827	pick-up	0	17
130414	2020-08-30 23:22:50	2020-08-30	9	[{"id_menu":7,"count":1}]	6045	delivery	5	14
130415	2020-08-30 23:22:58	2020-08-30	9	[{"id_menu":6,"count":1}]	21863	delivery	5	14
130416	2020-08-30 23:24:14	2020-08-30	9	[{"id_menu":7,"count":1}]	20787	delivery	5	14
130417	2020-08-30 23:24:16	2020-08-30	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	48751	delivery	5	28
130418	2020-08-30 23:26:37	2020-08-30	9	[{"id_menu":7,"count":2}]	10314	delivery	5	14
130419	2020-08-30 23:28:17	2020-08-30	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	37082	delivery	5	23
130420	2020-08-30 23:28:49	2020-08-30	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	48789	delivery	5	34
130421	2020-08-30 23:31:03	2020-08-30	9	[{"id_menu":6,"count":1}]	34249	delivery	5	14
130422	2020-08-30 23:31:19	2020-08-30	12	[{"id_menu":1,"count":2}]	48883	delivery	5	17
130423	2020-08-30 23:32:58	2020-08-30	12	[{"id_menu":3,"count":1}]	48635	pick-up	0	12
130424	2020-08-30 23:35:19	2020-08-30	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	8444	delivery	5	38
130425	2020-08-30 23:35:44	2020-08-30	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	38372	pick-up	0	20
130426	2020-08-30 23:36:28	2020-08-30	12	[{"id_menu":1,"count":1}]	20961	delivery	5	17
130427	2020-08-30 23:37:34	2020-08-30	12	[{"id_menu":3,"count":1}]	20769	delivery	5	17
130428	2020-08-30 23:38:18	2020-08-30	12	[{"id_menu":3,"count":1}]	9198	pick-up	0	12
130429	2020-08-30 23:39:18	2020-08-30	14	[{"id_menu":2,"count":1}]	3155	pick-up	0	14
130430	2020-08-30 23:39:28	2020-08-30	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	32974	delivery	5	45
130431	2020-08-30 23:40:16	2020-08-30	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	31197	delivery	5	22
130432	2020-08-30 23:41:32	2020-08-30	14	[{"id_menu":2,"count":1}]	14992	delivery	5	19
130433	2020-08-30 23:43:09	2020-08-30	12	[{"id_menu":3,"count":1}]	48992	delivery	5	17
130434	2020-08-30 23:44:06	2020-08-30	12	[{"id_menu":3,"count":1}]	22275	delivery	5	17
130435	2020-08-30 23:44:20	2020-08-30	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	34367	pick-up	0	21
130436	2020-08-30 23:46:11	2020-08-30	9	[{"id_menu":7,"count":1}]	37938	delivery	5	14
130437	2020-08-30 23:46:40	2020-08-30	9	[{"id_menu":6,"count":1}]	49024	delivery	5	14
130438	2020-08-30 23:48:21	2020-08-30	17	[{"id_menu":4,"count":1}]	23523	pick-up	0	17
130439	2020-08-30 23:52:39	2020-08-30	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":2}]	10135	delivery	5	34
130440	2020-08-30 23:52:51	2020-08-30	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	48834	delivery	5	36
130441	2020-08-30 23:54:58	2020-08-30	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	8451	delivery	5	36
130442	2020-08-30 23:57:48	2020-08-30	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	19042	pick-up	0	37
130443	2020-08-30 23:58:30	2020-08-30	17	[{"id_menu":4,"count":1}]	3168	delivery	5	22
130444	2020-08-30 23:58:50	2020-08-30	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	821	pick-up	0	23
130445	2020-08-30 23:59:18	2020-08-30	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":3}]	48867	delivery	5	22
130446	2020-08-30 23:59:55	2020-08-30	9	[{"id_menu":6,"count":1}]	48819	delivery	5	14
130447	2020-08-31 00:01:50	2020-08-31	12	[{"id_menu":1,"count":1}]	44384	delivery	5	17
130448	2020-08-31 00:04:04	2020-08-31	8	[{"id_menu":5,"count":1}]	49101	delivery	5	13
130449	2020-08-31 00:05:05	2020-08-31	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	30702	delivery	5	31
130450	2020-08-31 00:06:48	2020-08-31	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	49128	delivery	5	22
130451	2020-08-31 00:07:57	2020-08-31	8	[{"id_menu":5,"count":1}]	30330	pick-up	0	8
130452	2020-08-31 00:09:49	2020-08-31	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	49263	delivery	5	26
130453	2020-08-31 00:10:17	2020-08-31	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	49031	delivery	5	31
130454	2020-08-31 00:14:24	2020-08-31	9	[{"id_menu":6,"count":2}]	49189	delivery	5	14
130455	2020-08-31 00:21:45	2020-08-31	9	[{"id_menu":7,"count":2}]	35885	delivery	5	14
130456	2020-08-31 00:23:18	2020-08-31	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	49131	delivery	5	40
130457	2020-08-31 00:24:05	2020-08-31	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24089	delivery	5	36
130458	2020-08-31 00:25:56	2020-08-31	9	[{"id_menu":6,"count":1}]	34771	delivery	5	14
130459	2020-08-31 00:25:57	2020-08-31	17	[{"id_menu":4,"count":1}]	45636	delivery	5	22
130460	2020-08-31 00:28:50	2020-08-31	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	24301	delivery	5	28
130461	2020-08-31 00:29:58	2020-08-31	12	[{"id_menu":1,"count":1}]	22320	pick-up	0	12
130462	2020-08-31 00:31:49	2020-08-31	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	44028	delivery	5	36
130463	2020-08-31 00:41:39	2020-08-31	14	[{"id_menu":2,"count":1}]	10656	delivery	5	19
130464	2020-08-31 00:42:42	2020-08-31	12	[{"id_menu":1,"count":1}]	35134	delivery	5	17
130465	2020-08-31 00:53:12	2020-08-31	9	[{"id_menu":6,"count":1}]	39961	delivery	5	14
130466	2020-08-31 00:53:20	2020-08-31	14	[{"id_menu":2,"count":1}]	49197	delivery	5	19
130467	2020-08-31 00:56:02	2020-08-31	9	[{"id_menu":6,"count":1}]	27984	delivery	5	14
130468	2020-08-31 00:57:39	2020-08-31	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	33326	delivery	5	23
130469	2020-08-31 00:58:32	2020-08-31	9	[{"id_menu":7,"count":1}]	49201	delivery	5	14
130470	2020-08-31 01:06:50	2020-08-31	9	[{"id_menu":6,"count":1}]	18617	delivery	5	14
130471	2020-08-31 01:06:53	2020-08-31	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	25776	delivery	5	31
130472	2020-08-31 01:06:59	2020-08-31	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	2571	delivery	5	42
130473	2020-08-31 01:08:46	2020-08-31	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	12089	delivery	5	22
130474	2020-08-31 01:11:14	2020-08-31	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	49216	delivery	5	55
130475	2020-08-31 01:17:40	2020-08-31	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	12276	pick-up	0	52
130476	2020-08-31 01:19:52	2020-08-31	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	12943	pick-up	0	23
130477	2020-08-31 01:20:27	2020-08-31	9	[{"id_menu":7,"count":1}]	11621	delivery	5	14
130478	2020-08-31 01:20:28	2020-08-31	14	[{"id_menu":2,"count":1}]	49214	delivery	5	19
130479	2020-08-31 01:22:05	2020-08-31	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	26024	delivery	5	31
130480	2020-08-31 01:28:56	2020-08-31	9	[{"id_menu":6,"count":1}]	20598	delivery	5	14
130481	2020-08-31 01:34:48	2020-08-31	9	[{"id_menu":6,"count":1}]	371	pick-up	0	9
130482	2020-08-31 01:36:26	2020-08-31	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	7069	delivery	5	29
130483	2020-08-31 01:38:43	2020-08-31	12	[{"id_menu":1,"count":2}]	1301	pick-up	0	12
130484	2020-08-31 01:39:39	2020-08-31	14	[{"id_menu":2,"count":1}]	33749	delivery	5	19
130485	2020-08-31 01:41:56	2020-08-31	9	[{"id_menu":7,"count":1}]	45146	delivery	5	14
130486	2020-08-31 01:46:38	2020-08-31	12	[{"id_menu":1,"count":1}]	25907	delivery	5	17
130487	2020-08-31 01:49:07	2020-08-31	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	41542	delivery	5	45
130488	2020-08-31 01:53:16	2020-08-31	12	[{"id_menu":1,"count":1}]	34778	delivery	5	17
130489	2020-08-31 01:53:52	2020-08-31	17	[{"id_menu":4,"count":1}]	41804	delivery	5	22
130490	2020-08-31 02:01:17	2020-08-31	12	[{"id_menu":1,"count":1}]	49252	delivery	5	17
130491	2020-08-31 02:05:16	2020-08-31	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	49077	delivery	5	22
130492	2020-08-31 02:05:37	2020-08-31	14	[{"id_menu":2,"count":1}]	14558	pick-up	0	14
130493	2020-08-31 02:05:57	2020-08-31	12	[{"id_menu":3,"count":1}]	12096	delivery	5	17
130494	2020-08-31 02:09:36	2020-08-31	14	[{"id_menu":2,"count":1}]	8397	delivery	5	19
130495	2020-08-31 02:10:47	2020-08-31	12	[{"id_menu":3,"count":1}]	27960	delivery	5	17
130496	2020-08-31 02:22:03	2020-08-31	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	18676	delivery	5	31
130497	2020-08-31 02:22:38	2020-08-31	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	49165	delivery	5	35
130498	2020-08-31 02:24:20	2020-08-31	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	49188	delivery	5	43
130499	2020-08-31 02:24:57	2020-08-31	9	[{"id_menu":6,"count":1}]	49049	delivery	5	14
130500	2020-08-31 02:25:30	2020-08-31	12	[{"id_menu":1,"count":1}]	36556	delivery	5	17
130501	2020-08-31 02:26:34	2020-08-31	9	[{"id_menu":6,"count":1}]	35177	delivery	5	14
130502	2020-08-31 02:33:35	2020-08-31	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	2369	pick-up	0	26
130503	2020-08-31 02:43:21	2020-08-31	9	[{"id_menu":7,"count":1}]	49196	delivery	5	14
130504	2020-08-31 02:48:10	2020-08-31	8	[{"id_menu":5,"count":1}]	32063	delivery	5	13
130505	2020-08-31 02:50:45	2020-08-31	9	[{"id_menu":7,"count":1}]	16217	pick-up	0	9
130506	2020-08-31 02:51:19	2020-08-31	12	[{"id_menu":1,"count":1}]	5365	delivery	5	17
130507	2020-08-31 02:53:59	2020-08-31	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	18702	delivery	5	23
130508	2020-08-31 02:55:25	2020-08-31	14	[{"id_menu":2,"count":1}]	48466	pick-up	0	14
130509	2020-08-31 02:57:30	2020-08-31	12	[{"id_menu":3,"count":1}]	49211	delivery	5	17
130510	2020-08-31 02:59:16	2020-08-31	12	[{"id_menu":3,"count":1}]	31694	delivery	5	17
130511	2020-08-31 03:01:33	2020-08-31	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	15192	delivery	5	37
130512	2020-08-31 03:02:04	2020-08-31	9	[{"id_menu":6,"count":1}]	20732	delivery	5	14
130513	2020-08-31 03:05:00	2020-08-31	8	[{"id_menu":5,"count":1}]	32911	delivery	5	13
130514	2020-08-31 03:05:34	2020-08-31	14	[{"id_menu":2,"count":1}]	49171	delivery	5	19
130515	2020-08-31 03:10:31	2020-08-31	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18445	pick-up	0	30
130516	2020-08-31 03:11:03	2020-08-31	9	[{"id_menu":7,"count":1}]	49127	pick-up	0	9
130517	2020-08-31 03:11:10	2020-08-31	12	[{"id_menu":3,"count":1}]	49281	delivery	5	17
130518	2020-08-31 03:11:37	2020-08-31	12	[{"id_menu":1,"count":1}]	1255	pick-up	0	12
130519	2020-08-31 03:16:25	2020-08-31	12	[{"id_menu":1,"count":1}]	44556	pick-up	0	12
130520	2020-08-31 03:17:06	2020-08-31	12	[{"id_menu":1,"count":1}]	49261	pick-up	0	12
130521	2020-08-31 03:23:37	2020-08-31	51	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	49225	delivery	5	56
130522	2020-08-31 03:28:26	2020-08-31	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	43664	delivery	5	38
130523	2020-08-31 03:28:33	2020-08-31	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	10869	delivery	5	22
130524	2020-08-31 03:34:33	2020-08-31	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	49059	pick-up	0	26
130525	2020-08-31 03:41:33	2020-08-31	9	[{"id_menu":6,"count":1}]	39996	pick-up	0	9
130526	2020-08-31 03:42:08	2020-08-31	9	[{"id_menu":6,"count":1}]	49152	delivery	5	14
130527	2020-08-31 03:42:40	2020-08-31	12	[{"id_menu":1,"count":1}]	28750	delivery	5	17
130528	2020-08-31 03:43:58	2020-08-31	14	[{"id_menu":2,"count":1}]	1545	pick-up	0	14
130529	2020-08-31 03:45:12	2020-08-31	12	[{"id_menu":3,"count":1}]	3850	delivery	5	17
130530	2020-08-31 03:45:12	2020-08-31	9	[{"id_menu":7,"count":2}]	18353	pick-up	0	9
130531	2020-08-31 03:47:58	2020-08-31	9	[{"id_menu":7,"count":2}]	19741	delivery	5	14
130532	2020-08-31 03:48:00	2020-08-31	9	[{"id_menu":7,"count":1}]	27951	delivery	5	14
130533	2020-08-31 03:49:48	2020-08-31	9	[{"id_menu":7,"count":1}]	49086	delivery	5	14
130534	2020-08-31 03:55:58	2020-08-31	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	6578	delivery	5	22
130535	2020-08-31 03:59:58	2020-08-31	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	39735	delivery	5	28
130536	2020-08-31 04:02:34	2020-08-31	17	[{"id_menu":4,"count":1}]	30130	pick-up	0	17
130537	2020-08-31 04:03:59	2020-08-31	14	[{"id_menu":2,"count":1}]	49057	pick-up	0	14
130538	2020-08-31 04:04:41	2020-08-31	9	[{"id_menu":6,"count":1}]	40060	delivery	5	14
130539	2020-08-31 04:07:23	2020-08-31	8	[{"id_menu":5,"count":1}]	33081	delivery	5	13
130540	2020-08-31 04:13:40	2020-08-31	9	[{"id_menu":6,"count":1}]	2123	delivery	5	14
130541	2020-08-31 04:16:07	2020-08-31	9	[{"id_menu":7,"count":1}]	10633	delivery	5	14
130542	2020-08-31 04:19:41	2020-08-31	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":2}]	47684	delivery	5	31
130543	2020-08-31 04:19:58	2020-08-31	12	[{"id_menu":1,"count":1}]	3600	pick-up	0	12
130544	2020-08-31 04:20:46	2020-08-31	9	[{"id_menu":7,"count":1}]	46821	pick-up	0	9
130545	2020-08-31 04:27:16	2020-08-31	17	[{"id_menu":4,"count":1}]	31877	pick-up	0	17
130546	2020-08-31 04:29:05	2020-08-31	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	47480	delivery	5	43
130547	2020-08-31 04:29:14	2020-08-31	9	[{"id_menu":6,"count":1}]	15679	delivery	5	14
130548	2020-08-31 04:30:37	2020-08-31	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	14845	pick-up	0	21
130549	2020-08-31 04:31:00	2020-08-31	9	[{"id_menu":6,"count":1}]	49282	delivery	5	14
130550	2020-08-31 04:31:36	2020-08-31	8	[{"id_menu":5,"count":1}]	36547	delivery	5	13
130551	2020-08-31 04:34:51	2020-08-31	9	[{"id_menu":6,"count":1}]	39322	delivery	5	14
130552	2020-08-31 04:35:50	2020-08-31	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	49215	delivery	5	39
130553	2020-08-31 04:35:51	2020-08-31	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	49249	delivery	5	43
130554	2020-08-31 04:41:29	2020-08-31	9	[{"id_menu":7,"count":1}]	49058	delivery	5	14
130555	2020-08-31 04:43:13	2020-08-31	12	[{"id_menu":1,"count":1}]	21585	delivery	5	17
130556	2020-08-31 04:44:59	2020-08-31	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22511	delivery	5	23
130557	2020-08-31 04:45:11	2020-08-31	12	[{"id_menu":3,"count":1}]	49040	pick-up	0	12
130558	2020-08-31 04:48:38	2020-08-31	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":2}]	44025	delivery	5	31
130559	2020-08-31 04:49:34	2020-08-31	14	[{"id_menu":2,"count":1}]	49121	delivery	5	19
130560	2020-08-31 04:51:17	2020-08-31	21	[{"id_menu":1,"count":2},{"id_menu":7,"count":1}]	49155	delivery	5	26
130561	2020-08-31 04:52:18	2020-08-31	12	[{"id_menu":3,"count":1}]	43027	delivery	5	17
130562	2020-08-31 04:55:12	2020-08-31	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	48263	delivery	5	37
130563	2020-08-31 04:58:46	2020-08-31	9	[{"id_menu":6,"count":1}]	265	pick-up	0	9
130564	2020-08-31 05:03:38	2020-08-31	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	41405	delivery	5	40
130565	2020-08-31 05:06:03	2020-08-31	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14097	delivery	5	40
130566	2020-08-31 05:06:27	2020-08-31	43	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	39315	delivery	5	48
130567	2020-08-31 05:10:43	2020-08-31	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	30745	delivery	5	30
130568	2020-08-31 05:13:55	2020-08-31	17	[{"id_menu":4,"count":1}]	8576	delivery	5	22
130569	2020-08-31 05:14:00	2020-08-31	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	49199	delivery	5	44
130570	2020-08-31 05:14:35	2020-08-31	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	49242	delivery	5	31
130571	2020-08-31 05:21:18	2020-08-31	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	49112	delivery	5	39
130572	2020-08-31 05:30:35	2020-08-31	9	[{"id_menu":7,"count":1}]	25345	delivery	5	14
130573	2020-08-31 05:30:51	2020-08-31	17	[{"id_menu":4,"count":1}]	37742	delivery	5	22
130574	2020-08-31 05:37:28	2020-08-31	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	49147	delivery	5	31
130575	2020-08-31 05:43:01	2020-08-31	8	[{"id_menu":5,"count":1}]	38423	delivery	5	13
130576	2020-08-31 05:43:18	2020-08-31	12	[{"id_menu":1,"count":1}]	20964	delivery	5	17
130577	2020-08-31 05:46:58	2020-08-31	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	36216	delivery	5	31
130578	2020-08-31 05:47:31	2020-08-31	9	[{"id_menu":7,"count":1}]	12327	delivery	5	14
130579	2020-08-31 05:48:49	2020-08-31	14	[{"id_menu":2,"count":1}]	49060	delivery	5	19
130580	2020-08-31 05:49:37	2020-08-31	12	[{"id_menu":3,"count":1}]	15883	pick-up	0	12
130581	2020-08-31 06:04:34	2020-08-31	17	[{"id_menu":4,"count":1}]	21606	delivery	5	22
130582	2020-08-31 06:05:59	2020-08-31	17	[{"id_menu":4,"count":1}]	31006	delivery	5	22
130583	2020-08-31 06:08:55	2020-08-31	8	[{"id_menu":5,"count":1}]	49117	delivery	5	13
130584	2020-08-31 06:10:53	2020-08-31	14	[{"id_menu":2,"count":2}]	24167	delivery	5	19
130585	2020-08-31 06:12:10	2020-08-31	12	[{"id_menu":3,"count":1}]	49260	delivery	5	17
130586	2020-08-31 06:12:23	2020-08-31	9	[{"id_menu":7,"count":1}]	41091	delivery	5	14
130587	2020-08-31 06:13:10	2020-08-31	14	[{"id_menu":2,"count":1}]	17329	pick-up	0	14
130588	2020-08-31 06:15:49	2020-08-31	14	[{"id_menu":2,"count":1}]	16342	pick-up	0	14
130589	2020-08-31 06:16:32	2020-08-31	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	28020	delivery	5	45
130590	2020-08-31 06:18:29	2020-08-31	9	[{"id_menu":7,"count":2}]	46695	delivery	5	14
130591	2020-08-31 06:26:31	2020-08-31	9	[{"id_menu":7,"count":1}]	31384	delivery	5	14
130592	2020-08-31 06:31:11	2020-08-31	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	1379	pick-up	0	21
130593	2020-08-31 06:35:25	2020-08-31	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	13522	pick-up	0	21
130594	2020-08-31 06:36:25	2020-08-31	8	[{"id_menu":5,"count":1}]	7159	pick-up	0	8
130595	2020-08-31 06:38:24	2020-08-31	17	[{"id_menu":4,"count":1}]	1537	pick-up	0	17
130596	2020-08-31 06:41:03	2020-08-31	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	49168	delivery	5	26
130597	2020-08-31 06:42:41	2020-08-31	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3613	delivery	5	34
130598	2020-08-31 06:42:58	2020-08-31	14	[{"id_menu":2,"count":1}]	27767	delivery	5	19
130599	2020-08-31 06:47:51	2020-08-31	12	[{"id_menu":1,"count":1}]	20010	delivery	5	17
130600	2020-08-31 06:50:21	2020-08-31	12	[{"id_menu":1,"count":1}]	23600	delivery	5	17
130601	2020-08-31 06:52:29	2020-08-31	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	36306	delivery	5	25
130602	2020-08-31 06:53:44	2020-08-31	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	30977	delivery	5	27
130603	2020-08-31 06:54:20	2020-08-31	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	27330	delivery	5	22
130604	2020-08-31 06:55:58	2020-08-31	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	3568	delivery	5	31
130605	2020-08-31 07:04:26	2020-08-31	17	[{"id_menu":4,"count":1}]	346	pick-up	0	17
130606	2020-08-31 07:05:25	2020-08-31	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	49135	delivery	5	30
130607	2020-08-31 07:05:48	2020-08-31	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13994	delivery	5	39
130608	2020-08-31 07:08:22	2020-08-31	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	28413	delivery	5	28
130609	2020-08-31 07:11:01	2020-08-31	12	[{"id_menu":1,"count":1}]	47419	pick-up	0	12
130610	2020-08-31 07:11:46	2020-08-31	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	49222	delivery	5	27
130611	2020-08-31 07:12:18	2020-08-31	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	49146	delivery	5	39
130612	2020-08-31 07:14:09	2020-08-31	12	[{"id_menu":3,"count":1}]	5811	delivery	5	17
130613	2020-08-31 07:15:09	2020-08-31	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	22921	delivery	5	40
130614	2020-08-31 07:16:35	2020-08-31	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	39604	delivery	5	22
130615	2020-08-31 07:23:06	2020-08-31	12	[{"id_menu":1,"count":1}]	16466	pick-up	0	12
130616	2020-08-31 07:23:51	2020-08-31	12	[{"id_menu":3,"count":1}]	14339	pick-up	0	12
130617	2020-08-31 07:26:51	2020-08-31	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	3585	delivery	5	28
130618	2020-08-31 07:27:51	2020-08-31	9	[{"id_menu":6,"count":1}]	7766	pick-up	0	9
130619	2020-08-31 07:28:27	2020-08-31	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	49175	delivery	5	38
130620	2020-08-31 07:41:25	2020-08-31	14	[{"id_menu":2,"count":1}]	40309	delivery	5	19
130621	2020-08-31 07:41:36	2020-08-31	43	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	38625	delivery	5	48
130622	2020-08-31 07:41:55	2020-08-31	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9449	delivery	5	45
130623	2020-08-31 07:44:06	2020-08-31	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	49124	delivery	5	42
130624	2020-08-31 07:46:56	2020-08-31	8	[{"id_menu":5,"count":1}]	49288	delivery	5	13
130625	2020-08-31 07:50:17	2020-08-31	12	[{"id_menu":3,"count":2}]	49226	pick-up	0	12
130626	2020-08-31 07:50:19	2020-08-31	8	[{"id_menu":5,"count":1}]	49069	delivery	5	13
130627	2020-08-31 07:52:56	2020-08-31	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":2}]	5319	delivery	5	23
130628	2020-08-31 07:53:54	2020-08-31	12	[{"id_menu":1,"count":1}]	49240	delivery	5	17
130629	2020-08-31 07:54:19	2020-08-31	9	[{"id_menu":6,"count":1}]	30455	pick-up	0	9
130630	2020-08-31 07:56:44	2020-08-31	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	7439	delivery	5	37
130631	2020-08-31 07:57:20	2020-08-31	8	[{"id_menu":5,"count":1}]	42906	delivery	5	13
130632	2020-08-31 07:57:30	2020-08-31	9	[{"id_menu":6,"count":3}]	49048	delivery	5	14
130633	2020-08-31 08:01:16	2020-08-31	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	34413	delivery	5	22
130634	2020-08-31 08:01:20	2020-08-31	8	[{"id_menu":5,"count":1}]	2706	delivery	5	13
130635	2020-08-31 08:03:20	2020-08-31	14	[{"id_menu":2,"count":1}]	49228	pick-up	0	14
130636	2020-08-31 08:07:01	2020-08-31	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	7606	delivery	5	26
130637	2020-08-31 08:07:13	2020-08-31	9	[{"id_menu":6,"count":1}]	49254	delivery	5	14
130638	2020-08-31 08:07:56	2020-08-31	12	[{"id_menu":1,"count":1}]	40901	pick-up	0	12
130639	2020-08-31 08:11:41	2020-08-31	9	[{"id_menu":6,"count":2}]	2022	pick-up	0	9
130640	2020-08-31 08:12:13	2020-08-31	9	[{"id_menu":6,"count":1}]	2101	pick-up	0	9
130641	2020-08-31 08:14:38	2020-08-31	12	[{"id_menu":1,"count":1}]	14364	delivery	5	17
130642	2020-08-31 08:17:46	2020-08-31	9	[{"id_menu":6,"count":1}]	49237	pick-up	0	9
130643	2020-08-31 08:19:02	2020-08-31	12	[{"id_menu":1,"count":1}]	49088	delivery	5	17
130644	2020-08-31 08:20:37	2020-08-31	23	[{"id_menu":2,"count":3},{"id_menu":6,"count":1}]	33219	delivery	5	28
130645	2020-08-31 08:23:27	2020-08-31	9	[{"id_menu":6,"count":1}]	46324	delivery	5	14
130646	2020-08-31 08:30:11	2020-08-31	9	[{"id_menu":7,"count":1}]	49109	delivery	5	14
130647	2020-08-31 08:32:45	2020-08-31	12	[{"id_menu":1,"count":1}]	30884	delivery	5	17
130648	2020-08-31 08:33:53	2020-08-31	9	[{"id_menu":6,"count":2}]	49223	delivery	5	14
130649	2020-08-31 08:37:15	2020-08-31	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	37676	delivery	5	31
130650	2020-08-31 08:38:21	2020-08-31	17	[{"id_menu":4,"count":1}]	19036	delivery	5	22
130651	2020-08-31 08:39:15	2020-08-31	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	48819	delivery	5	23
130652	2020-08-31 08:41:54	2020-08-31	17	[{"id_menu":4,"count":1}]	49173	delivery	5	22
130653	2020-08-31 08:42:21	2020-08-31	17	[{"id_menu":4,"count":1}]	49160	delivery	5	22
130654	2020-08-31 08:44:55	2020-08-31	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	22450	delivery	5	35
130655	2020-08-31 08:59:43	2020-08-31	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	45028	pick-up	0	23
130656	2020-08-31 09:00:06	2020-08-31	9	[{"id_menu":6,"count":1}]	1780	pick-up	0	9
130657	2020-08-31 09:00:34	2020-08-31	9	[{"id_menu":6,"count":1}]	49053	delivery	5	14
130658	2020-08-31 09:01:40	2020-08-31	8	[{"id_menu":5,"count":1}]	39745	delivery	5	13
130659	2020-08-31 09:01:58	2020-08-31	8	[{"id_menu":5,"count":1}]	49064	delivery	5	13
130660	2020-08-31 09:07:39	2020-08-31	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	49154	delivery	5	26
130661	2020-08-31 09:09:15	2020-08-31	9	[{"id_menu":7,"count":2}]	41133	delivery	5	14
130662	2020-08-31 09:15:09	2020-08-31	17	[{"id_menu":4,"count":1}]	16186	pick-up	0	17
130663	2020-08-31 09:19:54	2020-08-31	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	49167	delivery	5	22
130664	2020-08-31 09:21:54	2020-08-31	14	[{"id_menu":2,"count":1}]	42237	pick-up	0	14
130665	2020-08-31 09:23:44	2020-08-31	12	[{"id_menu":3,"count":1}]	4467	pick-up	0	12
130666	2020-08-31 09:24:29	2020-08-31	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	11907	delivery	5	30
130667	2020-08-31 09:27:55	2020-08-31	12	[{"id_menu":3,"count":1}]	7919	pick-up	0	12
130668	2020-08-31 09:29:22	2020-08-31	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	49122	delivery	5	43
130669	2020-08-31 09:31:04	2020-08-31	14	[{"id_menu":2,"count":1}]	49141	delivery	5	19
130670	2020-08-31 09:33:55	2020-08-31	9	[{"id_menu":6,"count":1}]	49085	delivery	5	14
130671	2020-08-31 09:35:12	2020-08-31	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	39960	delivery	5	39
130672	2020-08-31 09:43:24	2020-08-31	9	[{"id_menu":6,"count":1}]	27120	delivery	5	14
130673	2020-08-31 09:46:47	2020-08-31	9	[{"id_menu":6,"count":1}]	11294	delivery	5	14
130674	2020-08-31 09:48:49	2020-08-31	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	24753	delivery	5	36
130675	2020-08-31 09:48:57	2020-08-31	9	[{"id_menu":7,"count":1}]	22395	delivery	5	14
130676	2020-08-31 09:50:04	2020-08-31	12	[{"id_menu":3,"count":1}]	45450	delivery	5	17
130677	2020-08-31 09:51:31	2020-08-31	9	[{"id_menu":7,"count":1}]	48471	pick-up	0	9
130678	2020-08-31 09:54:09	2020-08-31	14	[{"id_menu":2,"count":1}]	49245	delivery	5	19
130679	2020-08-31 09:55:29	2020-08-31	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17794	delivery	5	31
130680	2020-08-31 09:55:46	2020-08-31	12	[{"id_menu":3,"count":1}]	49083	delivery	5	17
130681	2020-08-31 10:03:47	2020-08-31	12	[{"id_menu":3,"count":1}]	9898	delivery	5	17
130682	2020-08-31 10:07:24	2020-08-31	9	[{"id_menu":6,"count":1}]	30317	delivery	5	14
130683	2020-08-31 10:07:36	2020-08-31	47	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18293	delivery	5	52
130684	2020-08-31 10:07:51	2020-08-31	9	[{"id_menu":6,"count":1}]	33802	delivery	5	14
130685	2020-08-31 10:07:55	2020-08-31	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	16283	delivery	5	25
130686	2020-08-31 10:09:16	2020-08-31	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	49143	delivery	5	29
130687	2020-08-31 10:16:53	2020-08-31	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	49244	delivery	5	26
130688	2020-08-31 10:17:09	2020-08-31	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	35325	delivery	5	40
130689	2020-08-31 10:18:42	2020-08-31	17	[{"id_menu":4,"count":1}]	49142	delivery	5	22
130690	2020-08-31 10:22:22	2020-08-31	17	[{"id_menu":4,"count":1}]	36029	pick-up	0	17
130691	2020-08-31 10:24:11	2020-08-31	12	[{"id_menu":3,"count":1}]	48179	delivery	5	17
130692	2020-08-31 10:25:18	2020-08-31	12	[{"id_menu":1,"count":1}]	48441	pick-up	0	12
130693	2020-08-31 10:29:18	2020-08-31	14	[{"id_menu":2,"count":1}]	9772	pick-up	0	14
130694	2020-08-31 10:30:42	2020-08-31	17	[{"id_menu":4,"count":1}]	49100	delivery	5	22
130695	2020-08-31 10:32:04	2020-08-31	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	34032	pick-up	0	34
130696	2020-08-31 10:34:56	2020-08-31	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	49119	delivery	5	48
130697	2020-08-31 10:38:24	2020-08-31	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	7195	delivery	5	27
130698	2020-08-31 10:42:17	2020-08-31	17	[{"id_menu":4,"count":1}]	17438	delivery	5	22
130699	2020-08-31 10:52:08	2020-08-31	12	[{"id_menu":3,"count":1}]	43539	pick-up	0	12
130700	2020-08-31 10:52:48	2020-08-31	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	31981	delivery	5	43
130701	2020-08-31 10:56:46	2020-08-31	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	49227	delivery	5	43
130702	2020-08-31 10:59:27	2020-08-31	14	[{"id_menu":2,"count":1}]	14661	pick-up	0	14
130703	2020-08-31 10:59:27	2020-08-31	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	13297	delivery	5	34
130704	2020-08-31 10:59:46	2020-08-31	9	[{"id_menu":7,"count":1}]	30221	delivery	5	14
130705	2020-08-31 11:02:35	2020-08-31	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	49081	pick-up	0	52
130706	2020-08-31 11:03:35	2020-08-31	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	26373	pick-up	0	29
130707	2020-08-31 11:07:52	2020-08-31	9	[{"id_menu":7,"count":1}]	49206	delivery	5	14
130708	2020-08-31 11:10:57	2020-08-31	14	[{"id_menu":2,"count":1}]	48174	delivery	5	19
130709	2020-08-31 11:14:43	2020-08-31	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	15394	pick-up	0	26
130710	2020-08-31 11:16:15	2020-08-31	14	[{"id_menu":2,"count":1}]	49219	delivery	5	19
130711	2020-08-31 11:19:34	2020-08-31	14	[{"id_menu":2,"count":1}]	41539	pick-up	0	14
130712	2020-08-31 11:19:36	2020-08-31	14	[{"id_menu":2,"count":2}]	37373	delivery	5	19
130713	2020-08-31 11:20:53	2020-08-31	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	34330	delivery	5	36
130714	2020-08-31 11:27:58	2020-08-31	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	49200	delivery	5	35
130715	2020-08-31 11:29:31	2020-08-31	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	49205	delivery	5	27
130716	2020-08-31 11:35:36	2020-08-31	9	[{"id_menu":7,"count":1}]	49045	delivery	5	14
130717	2020-08-31 11:38:26	2020-08-31	12	[{"id_menu":1,"count":1}]	47675	pick-up	0	12
130718	2020-08-31 11:45:35	2020-08-31	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	22126	delivery	5	34
130719	2020-08-31 11:47:21	2020-08-31	9	[{"id_menu":6,"count":1}]	10706	pick-up	0	9
130720	2020-08-31 11:50:58	2020-08-31	14	[{"id_menu":2,"count":1}]	10694	pick-up	0	14
130721	2020-08-31 12:03:09	2020-08-31	17	[{"id_menu":4,"count":1}]	49287	delivery	5	22
130722	2020-08-31 12:14:27	2020-08-31	52	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	1718	delivery	5	57
130723	2020-08-31 12:14:29	2020-08-31	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	18687	pick-up	0	18
130724	2020-08-31 12:17:06	2020-08-31	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	49239	delivery	5	31
130725	2020-08-31 12:18:13	2020-08-31	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	49250	delivery	5	27
130726	2020-08-31 12:20:25	2020-08-31	14	[{"id_menu":2,"count":1}]	14049	pick-up	0	14
130727	2020-08-31 12:20:49	2020-08-31	12	[{"id_menu":3,"count":1}]	9517	delivery	5	17
130728	2020-08-31 12:21:05	2020-08-31	8	[{"id_menu":5,"count":1}]	44798	delivery	5	13
130729	2020-08-31 12:24:25	2020-08-31	12	[{"id_menu":3,"count":2}]	9467	pick-up	0	12
130730	2020-08-31 12:26:39	2020-08-31	35	[{"id_menu":4,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	47661	delivery	5	40
130731	2020-08-31 12:31:52	2020-08-31	14	[{"id_menu":2,"count":1}]	49229	delivery	5	19
130732	2020-08-31 12:32:53	2020-08-31	14	[{"id_menu":2,"count":1}]	4372	delivery	5	19
130733	2020-08-31 12:34:18	2020-08-31	9	[{"id_menu":7,"count":1}]	1588	delivery	5	14
130734	2020-08-31 12:35:42	2020-08-31	9	[{"id_menu":6,"count":1}]	23882	delivery	5	14
130735	2020-08-31 12:42:59	2020-08-31	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	35347	delivery	5	23
130736	2020-08-31 12:46:10	2020-08-31	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	49284	delivery	5	36
130737	2020-08-31 12:46:57	2020-08-31	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	42974	delivery	5	34
130738	2020-08-31 12:52:07	2020-08-31	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	49078	delivery	5	26
130739	2020-08-31 12:52:37	2020-08-31	8	[{"id_menu":5,"count":1}]	13026	delivery	5	13
130740	2020-08-31 12:53:02	2020-08-31	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9886	pick-up	0	26
130741	2020-08-31 12:57:15	2020-08-31	12	[{"id_menu":1,"count":1}]	271	delivery	5	17
130742	2020-08-31 13:02:10	2020-08-31	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	49090	delivery	5	30
130743	2020-08-31 13:03:08	2020-08-31	9	[{"id_menu":7,"count":1}]	49183	delivery	5	14
130744	2020-08-31 13:04:45	2020-08-31	12	[{"id_menu":3,"count":1}]	49050	delivery	5	17
130745	2020-08-31 13:05:31	2020-08-31	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	2065	pick-up	0	26
130746	2020-08-31 13:09:26	2020-08-31	9	[{"id_menu":6,"count":1}]	15501	delivery	5	14
130747	2020-08-31 13:13:15	2020-08-31	17	[{"id_menu":4,"count":1}]	153	pick-up	0	17
130748	2020-08-31 13:14:33	2020-08-31	9	[{"id_menu":7,"count":1}]	19812	delivery	5	14
130749	2020-08-31 13:25:32	2020-08-31	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	5004	delivery	5	26
130750	2020-08-31 13:29:22	2020-08-31	12	[{"id_menu":3,"count":1}]	49277	delivery	5	17
130751	2020-08-31 13:35:57	2020-08-31	12	[{"id_menu":1,"count":1}]	26371	delivery	5	17
130752	2020-08-31 13:37:50	2020-08-31	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	20681	delivery	5	34
130753	2020-08-31 13:38:29	2020-08-31	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	49044	delivery	5	26
130754	2020-08-31 13:43:08	2020-08-31	9	[{"id_menu":6,"count":1}]	36179	delivery	5	14
130755	2020-08-31 13:44:24	2020-08-31	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	23673	delivery	5	51
130756	2020-08-31 13:44:46	2020-08-31	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	35871	delivery	5	36
130757	2020-08-31 13:55:11	2020-08-31	14	[{"id_menu":2,"count":1}]	43566	delivery	5	19
130758	2020-08-31 13:55:58	2020-08-31	9	[{"id_menu":7,"count":1}]	12661	delivery	5	14
130759	2020-08-31 13:59:58	2020-08-31	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	47980	pick-up	0	24
130760	2020-08-31 14:02:48	2020-08-31	12	[{"id_menu":3,"count":1}]	22338	delivery	5	17
130761	2020-08-31 14:05:48	2020-08-31	8	[{"id_menu":5,"count":1}]	22793	delivery	5	13
130762	2020-08-31 14:09:26	2020-08-31	8	[{"id_menu":5,"count":1}]	4188	delivery	5	13
130763	2020-08-31 14:14:22	2020-08-31	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	49055	delivery	5	36
130764	2020-08-31 14:16:08	2020-08-31	9	[{"id_menu":7,"count":1}]	29560	delivery	5	14
130765	2020-08-31 14:22:07	2020-08-31	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	23165	delivery	5	43
130766	2020-08-31 14:23:43	2020-08-31	17	[{"id_menu":4,"count":1}]	22194	pick-up	0	17
130767	2020-08-31 14:23:49	2020-08-31	17	[{"id_menu":4,"count":1}]	23162	delivery	5	22
130768	2020-08-31 14:23:58	2020-08-31	22	[{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	49272	delivery	5	27
130769	2020-08-31 14:24:07	2020-08-31	50	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	49151	delivery	5	55
130770	2020-08-31 14:27:25	2020-08-31	12	[{"id_menu":1,"count":1}]	25810	delivery	5	17
130771	2020-08-31 14:31:24	2020-08-31	12	[{"id_menu":1,"count":1}]	49265	delivery	5	17
130772	2020-08-31 14:34:22	2020-08-31	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	44532	delivery	5	31
130773	2020-08-31 14:34:41	2020-08-31	8	[{"id_menu":5,"count":2}]	31957	delivery	5	13
130774	2020-08-31 14:34:56	2020-08-31	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	23604	delivery	5	27
130775	2020-08-31 14:36:43	2020-08-31	9	[{"id_menu":7,"count":1}]	49279	delivery	5	14
130776	2020-08-31 14:54:03	2020-08-31	14	[{"id_menu":2,"count":1}]	31223	pick-up	0	14
130777	2020-08-31 14:54:53	2020-08-31	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	49092	delivery	5	34
130778	2020-08-31 14:55:25	2020-08-31	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	29571	delivery	5	28
130779	2020-08-31 14:56:37	2020-08-31	9	[{"id_menu":6,"count":1}]	49159	delivery	5	14
130780	2020-08-31 14:57:19	2020-08-31	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	49073	delivery	5	36
130781	2020-08-31 14:57:29	2020-08-31	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	22698	delivery	5	37
130782	2020-08-31 15:02:58	2020-08-31	12	[{"id_menu":3,"count":1}]	46124	delivery	5	17
130783	2020-08-31 15:10:21	2020-08-31	9	[{"id_menu":6,"count":1}]	49251	delivery	5	14
130784	2020-08-31 15:12:10	2020-08-31	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	16003	delivery	5	40
130785	2020-08-31 15:12:28	2020-08-31	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	12479	delivery	5	34
130786	2020-08-31 15:14:14	2020-08-31	9	[{"id_menu":6,"count":1}]	4399	delivery	5	14
130787	2020-08-31 15:20:44	2020-08-31	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	24264	delivery	5	31
130788	2020-08-31 15:22:58	2020-08-31	12	[{"id_menu":1,"count":1}]	49176	delivery	5	17
130789	2020-08-31 15:24:29	2020-08-31	12	[{"id_menu":1,"count":1}]	46125	delivery	5	17
130790	2020-08-31 15:35:55	2020-08-31	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	1656	pick-up	0	31
130791	2020-08-31 15:40:03	2020-08-31	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	33282	delivery	5	36
130792	2020-08-31 15:43:34	2020-08-31	12	[{"id_menu":1,"count":1}]	24597	delivery	5	17
130793	2020-08-31 15:43:48	2020-08-31	14	[{"id_menu":2,"count":1}]	24041	pick-up	0	14
130794	2020-08-31 15:46:31	2020-08-31	9	[{"id_menu":7,"count":1}]	36294	delivery	5	14
130795	2020-08-31 15:47:50	2020-08-31	9	[{"id_menu":7,"count":1}]	2080	delivery	5	14
130796	2020-08-31 15:48:36	2020-08-31	12	[{"id_menu":3,"count":1}]	25062	delivery	5	17
130797	2020-08-31 15:49:10	2020-08-31	17	[{"id_menu":4,"count":1}]	49126	delivery	5	22
130798	2020-08-31 16:01:36	2020-08-31	12	[{"id_menu":3,"count":1}]	7814	pick-up	0	12
130799	2020-08-31 16:03:46	2020-08-31	8	[{"id_menu":5,"count":1}]	20749	delivery	5	13
130800	2020-08-31 16:04:15	2020-08-31	14	[{"id_menu":2,"count":1}]	626	pick-up	0	14
130801	2020-08-31 16:11:22	2020-08-31	9	[{"id_menu":7,"count":1}]	47057	delivery	5	14
130802	2020-08-31 16:13:53	2020-08-31	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	49262	pick-up	0	26
130803	2020-08-31 16:14:24	2020-08-31	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	11767	delivery	5	36
130804	2020-08-31 16:14:52	2020-08-31	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	49184	delivery	5	36
130805	2020-08-31 16:16:33	2020-08-31	9	[{"id_menu":6,"count":1}]	33919	delivery	5	14
130806	2020-08-31 16:18:41	2020-08-31	9	[{"id_menu":6,"count":1}]	16679	delivery	5	14
130807	2020-08-31 16:23:17	2020-08-31	12	[{"id_menu":3,"count":1}]	49132	delivery	5	17
130808	2020-08-31 16:24:01	2020-08-31	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	49129	delivery	5	22
130809	2020-08-31 16:24:32	2020-08-31	9	[{"id_menu":6,"count":1}]	49072	pick-up	0	9
130810	2020-08-31 16:24:58	2020-08-31	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	49185	delivery	5	26
130811	2020-08-31 16:28:26	2020-08-31	14	[{"id_menu":2,"count":1}]	5508	delivery	5	19
130812	2020-08-31 16:29:00	2020-08-31	9	[{"id_menu":7,"count":1}]	16915	delivery	5	14
130813	2020-08-31 16:32:06	2020-08-31	9	[{"id_menu":7,"count":1}]	36485	delivery	5	14
130814	2020-08-31 16:32:13	2020-08-31	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	5202	delivery	5	36
130815	2020-08-31 16:37:55	2020-08-31	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	34746	delivery	5	34
130816	2020-08-31 16:40:13	2020-08-31	14	[{"id_menu":2,"count":2}]	49054	delivery	5	19
130817	2020-08-31 16:46:32	2020-08-31	17	[{"id_menu":4,"count":1}]	49163	delivery	5	22
130818	2020-08-31 16:53:51	2020-08-31	9	[{"id_menu":7,"count":1}]	40495	delivery	5	14
130819	2020-08-31 16:54:42	2020-08-31	9	[{"id_menu":7,"count":3}]	49186	delivery	5	14
130820	2020-08-31 17:08:43	2020-08-31	8	[{"id_menu":5,"count":1}]	7077	delivery	5	13
130821	2020-08-31 17:09:32	2020-08-31	9	[{"id_menu":6,"count":1}]	45794	pick-up	0	9
130822	2020-08-31 17:11:26	2020-08-31	17	[{"id_menu":4,"count":2}]	21273	pick-up	0	17
130823	2020-08-31 17:15:18	2020-08-31	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	34497	delivery	5	25
130824	2020-08-31 17:18:21	2020-08-31	9	[{"id_menu":7,"count":1}]	17594	delivery	5	14
130825	2020-08-31 17:22:14	2020-08-31	12	[{"id_menu":3,"count":1}]	30841	delivery	5	17
130826	2020-08-31 17:23:25	2020-08-31	14	[{"id_menu":2,"count":1}]	24865	delivery	5	19
130827	2020-08-31 17:29:25	2020-08-31	12	[{"id_menu":1,"count":1}]	49157	delivery	5	17
130828	2020-08-31 17:29:27	2020-08-31	12	[{"id_menu":3,"count":1}]	12484	pick-up	0	12
130829	2020-08-31 17:31:34	2020-08-31	8	[{"id_menu":5,"count":1}]	49144	delivery	5	13
130830	2020-08-31 17:32:20	2020-08-31	12	[{"id_menu":1,"count":1}]	49115	delivery	5	17
130831	2020-08-31 17:39:24	2020-08-31	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	39536	pick-up	0	21
130832	2020-08-31 17:41:28	2020-08-31	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	35961	delivery	5	22
130833	2020-08-31 17:44:45	2020-08-31	9	[{"id_menu":6,"count":2}]	19751	delivery	5	14
130834	2020-08-31 17:46:35	2020-08-31	14	[{"id_menu":2,"count":1}]	49267	delivery	5	19
130835	2020-08-31 17:48:24	2020-08-31	12	[{"id_menu":3,"count":1}]	2531	pick-up	0	12
130836	2020-08-31 17:49:41	2020-08-31	17	[{"id_menu":4,"count":1}]	26493	delivery	5	22
130837	2020-08-31 17:51:41	2020-08-31	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	32967	delivery	5	34
130838	2020-08-31 17:53:04	2020-08-31	12	[{"id_menu":1,"count":1}]	20729	delivery	5	17
130839	2020-08-31 17:57:54	2020-08-31	12	[{"id_menu":1,"count":1}]	44991	delivery	5	17
130840	2020-08-31 17:59:02	2020-08-31	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	40686	delivery	5	40
130841	2020-08-31 18:00:31	2020-08-31	9	[{"id_menu":7,"count":1}]	48927	delivery	5	14
130842	2020-08-31 18:09:28	2020-08-31	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	38866	delivery	5	22
130843	2020-08-31 18:09:57	2020-08-31	9	[{"id_menu":6,"count":1}]	20792	delivery	5	14
130844	2020-08-31 18:11:01	2020-08-31	12	[{"id_menu":3,"count":1}]	401	delivery	5	17
130845	2020-08-31 18:12:07	2020-08-31	17	[{"id_menu":4,"count":1}]	49217	pick-up	0	17
130846	2020-08-31 18:13:21	2020-08-31	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	28549	delivery	5	22
130847	2020-08-31 18:17:44	2020-08-31	9	[{"id_menu":7,"count":1}]	473	pick-up	0	9
130848	2020-08-31 18:18:57	2020-08-31	34	[{"id_menu":2,"count":2},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	7531	delivery	5	39
130849	2020-08-31 18:19:21	2020-08-31	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	31856	delivery	5	22
130850	2020-08-31 18:21:29	2020-08-31	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	37424	delivery	5	36
130851	2020-08-31 18:22:40	2020-08-31	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	12185	delivery	5	40
130852	2020-08-31 18:23:02	2020-08-31	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	49195	delivery	5	23
130853	2020-08-31 18:27:49	2020-08-31	14	[{"id_menu":2,"count":1}]	49170	delivery	5	19
130854	2020-08-31 18:30:25	2020-08-31	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	49061	delivery	5	39
130855	2020-08-31 18:31:20	2020-08-31	17	[{"id_menu":4,"count":1}]	19100	pick-up	0	17
130856	2020-08-31 18:32:05	2020-08-31	8	[{"id_menu":5,"count":1}]	49137	pick-up	0	8
130857	2020-08-31 18:36:33	2020-08-31	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17736	delivery	5	40
130858	2020-08-31 18:37:17	2020-08-31	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	4695	pick-up	0	26
130859	2020-08-31 18:39:26	2020-08-31	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	49243	delivery	5	22
130860	2020-08-31 18:39:58	2020-08-31	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	26120	pick-up	0	25
130861	2020-08-31 18:50:07	2020-08-31	9	[{"id_menu":6,"count":1}]	25245	delivery	5	14
130862	2020-08-31 19:03:25	2020-08-31	9	[{"id_menu":7,"count":1}]	1862	pick-up	0	9
130863	2020-08-31 19:07:44	2020-08-31	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	7924	delivery	5	45
130864	2020-08-31 19:14:18	2020-08-31	9	[{"id_menu":7,"count":2}]	20899	delivery	5	14
130865	2020-08-31 19:17:13	2020-08-31	14	[{"id_menu":2,"count":2}]	49235	delivery	5	19
130866	2020-08-31 19:19:10	2020-08-31	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	42599	delivery	5	36
130867	2020-08-31 19:20:06	2020-08-31	14	[{"id_menu":2,"count":2}]	25526	delivery	5	19
130868	2020-08-31 19:31:02	2020-08-31	8	[{"id_menu":5,"count":1}]	49145	delivery	5	13
130869	2020-08-31 19:33:56	2020-08-31	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	40238	delivery	5	26
130870	2020-08-31 19:48:46	2020-08-31	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	684	pick-up	0	26
130871	2020-08-31 19:51:19	2020-08-31	14	[{"id_menu":2,"count":1}]	49096	delivery	5	19
130872	2020-08-31 19:54:10	2020-08-31	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	49149	delivery	5	34
130873	2020-08-31 19:57:48	2020-08-31	9	[{"id_menu":7,"count":1}]	27096	delivery	5	14
130874	2020-08-31 19:58:47	2020-08-31	17	[{"id_menu":4,"count":1}]	22572	delivery	5	22
130875	2020-08-31 20:02:03	2020-08-31	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	7371	delivery	5	34
130876	2020-08-31 20:03:07	2020-08-31	8	[{"id_menu":5,"count":1}]	28727	delivery	5	13
130877	2020-08-31 20:10:39	2020-08-31	9	[{"id_menu":6,"count":1}]	2672	pick-up	0	9
130878	2020-08-31 20:13:03	2020-08-31	17	[{"id_menu":4,"count":1}]	49238	delivery	5	22
130879	2020-08-31 20:14:49	2020-08-31	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	39223	delivery	5	27
130880	2020-08-31 20:18:18	2020-08-31	9	[{"id_menu":7,"count":1}]	1147	delivery	5	14
130881	2020-08-31 20:21:18	2020-08-31	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	49233	delivery	5	26
130882	2020-08-31 20:21:34	2020-08-31	17	[{"id_menu":4,"count":1}]	31963	pick-up	0	17
130883	2020-08-31 20:25:12	2020-08-31	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	33767	delivery	5	22
130884	2020-08-31 20:25:43	2020-08-31	9	[{"id_menu":7,"count":1}]	46211	delivery	5	14
130885	2020-08-31 20:27:17	2020-08-31	9	[{"id_menu":6,"count":1}]	27291	delivery	5	14
130886	2020-08-31 20:30:55	2020-08-31	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	17534	delivery	5	40
130887	2020-08-31 20:34:56	2020-08-31	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	49097	delivery	5	26
130888	2020-08-31 20:36:20	2020-08-31	12	[{"id_menu":3,"count":1}]	10374	pick-up	0	12
130889	2020-08-31 20:39:27	2020-08-31	9	[{"id_menu":6,"count":1}]	2290	pick-up	0	9
130890	2020-08-31 20:45:17	2020-08-31	12	[{"id_menu":3,"count":1}]	49047	delivery	5	17
130891	2020-08-31 20:48:43	2020-08-31	9	[{"id_menu":6,"count":1}]	49270	delivery	5	14
130892	2020-08-31 20:50:14	2020-08-31	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	12454	pick-up	0	26
130893	2020-08-31 20:51:52	2020-08-31	12	[{"id_menu":3,"count":1}]	26952	delivery	5	17
130894	2020-08-31 21:02:51	2020-08-31	8	[{"id_menu":5,"count":1}]	34638	delivery	5	13
130895	2020-08-31 21:02:52	2020-08-31	12	[{"id_menu":3,"count":2}]	49068	delivery	5	17
130896	2020-08-31 21:06:58	2020-08-31	12	[{"id_menu":1,"count":1}]	21487	delivery	5	17
130897	2020-08-31 21:08:55	2020-08-31	8	[{"id_menu":5,"count":1}]	26037	delivery	5	13
130898	2020-08-31 21:10:50	2020-08-31	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	36946	delivery	5	22
130899	2020-08-31 21:11:52	2020-08-31	9	[{"id_menu":7,"count":1}]	40549	delivery	5	14
130900	2020-08-31 21:12:11	2020-08-31	9	[{"id_menu":6,"count":1}]	14175	delivery	5	14
130901	2020-08-31 21:17:30	2020-08-31	14	[{"id_menu":2,"count":1}]	27545	delivery	5	19
130902	2020-08-31 21:17:41	2020-08-31	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	6221	delivery	5	36
130903	2020-08-31 21:20:55	2020-08-31	14	[{"id_menu":2,"count":1}]	22785	delivery	5	19
130904	2020-08-31 21:21:17	2020-08-31	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	38224	delivery	5	43
130905	2020-08-31 21:22:05	2020-08-31	9	[{"id_menu":7,"count":1}]	49071	delivery	5	14
130906	2020-08-31 21:22:11	2020-08-31	14	[{"id_menu":2,"count":1}]	33544	delivery	5	19
130907	2020-08-31 21:23:33	2020-08-31	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	49177	delivery	5	22
130908	2020-08-31 21:26:25	2020-08-31	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	43925	delivery	5	31
130909	2020-08-31 21:34:40	2020-08-31	14	[{"id_menu":2,"count":1}]	49166	delivery	5	19
130910	2020-08-31 21:35:21	2020-08-31	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	288	pick-up	0	29
130911	2020-08-31 21:38:27	2020-08-31	14	[{"id_menu":2,"count":1}]	15361	pick-up	0	14
130912	2020-08-31 21:42:14	2020-08-31	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	17932	pick-up	0	24
130913	2020-08-31 21:42:16	2020-08-31	9	[{"id_menu":7,"count":1}]	24650	delivery	5	14
130914	2020-08-31 21:42:56	2020-08-31	14	[{"id_menu":2,"count":1}]	43291	delivery	5	19
130915	2020-08-31 21:43:26	2020-08-31	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	49106	delivery	5	39
130916	2020-08-31 21:44:13	2020-08-31	14	[{"id_menu":2,"count":1}]	379	pick-up	0	14
130917	2020-08-31 21:44:35	2020-08-31	17	[{"id_menu":4,"count":1}]	26686	delivery	5	22
130918	2020-08-31 21:45:45	2020-08-31	17	[{"id_menu":4,"count":1}]	42290	pick-up	0	17
130919	2020-08-31 21:55:55	2020-08-31	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	24174	delivery	5	31
130920	2020-08-31 21:58:24	2020-08-31	14	[{"id_menu":2,"count":1}]	14841	pick-up	0	14
130921	2020-08-31 21:58:41	2020-08-31	9	[{"id_menu":6,"count":1}]	49042	delivery	5	14
130922	2020-08-31 22:03:41	2020-08-31	12	[{"id_menu":3,"count":1}]	12690	delivery	5	17
130923	2020-08-31 22:05:07	2020-08-31	12	[{"id_menu":3,"count":1}]	49213	delivery	5	17
130924	2020-08-31 22:06:22	2020-08-31	9	[{"id_menu":6,"count":1}]	1995	pick-up	0	9
130925	2020-08-31 22:06:59	2020-08-31	14	[{"id_menu":2,"count":1}]	49178	delivery	5	19
130926	2020-08-31 22:12:18	2020-08-31	9	[{"id_menu":6,"count":1}]	26125	delivery	5	14
130927	2020-08-31 22:16:18	2020-08-31	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	42194	pick-up	0	26
130928	2020-08-31 22:17:33	2020-08-31	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	281	pick-up	0	29
130929	2020-08-31 22:28:38	2020-08-31	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	23835	delivery	5	35
130930	2020-08-31 22:36:17	2020-08-31	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	11258	delivery	5	25
130931	2020-08-31 22:39:55	2020-08-31	12	[{"id_menu":3,"count":1}]	3314	pick-up	0	12
130932	2020-08-31 22:42:15	2020-08-31	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	42381	delivery	5	22
130933	2020-08-31 22:49:04	2020-08-31	17	[{"id_menu":4,"count":1}]	16785	delivery	5	22
130934	2020-08-31 22:49:23	2020-08-31	9	[{"id_menu":7,"count":2}]	5923	delivery	5	14
130935	2020-08-31 22:49:26	2020-08-31	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	49093	delivery	5	27
130936	2020-08-31 22:56:43	2020-08-31	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	30624	delivery	5	35
130937	2020-08-31 22:57:04	2020-08-31	12	[{"id_menu":1,"count":1}]	49111	pick-up	0	12
130938	2020-08-31 22:59:53	2020-08-31	9	[{"id_menu":6,"count":1}]	32345	delivery	5	14
130939	2020-08-31 23:00:25	2020-08-31	9	[{"id_menu":7,"count":1}]	14243	delivery	5	14
130940	2020-08-31 23:05:02	2020-08-31	8	[{"id_menu":5,"count":1}]	34050	delivery	5	13
130941	2020-08-31 23:08:06	2020-08-31	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	49158	delivery	5	23
130942	2020-08-31 23:09:26	2020-08-31	9	[{"id_menu":6,"count":1}]	37226	delivery	5	14
130943	2020-08-31 23:12:44	2020-08-31	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	47853	delivery	5	45
130944	2020-08-31 23:17:11	2020-08-31	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	33492	delivery	5	22
130945	2020-08-31 23:17:49	2020-08-31	9	[{"id_menu":6,"count":1}]	19705	delivery	5	14
130946	2020-08-31 23:19:09	2020-08-31	17	[{"id_menu":4,"count":1}]	49255	delivery	5	22
130947	2020-08-31 23:25:02	2020-08-31	14	[{"id_menu":2,"count":1}]	49266	delivery	5	19
130948	2020-08-31 23:25:48	2020-08-31	17	[{"id_menu":4,"count":1}]	49204	delivery	5	22
130949	2020-08-31 23:25:53	2020-08-31	14	[{"id_menu":2,"count":1}]	47024	delivery	5	19
130950	2020-08-31 23:28:23	2020-08-31	9	[{"id_menu":6,"count":1}]	49052	delivery	5	14
130951	2020-08-31 23:30:02	2020-08-31	14	[{"id_menu":2,"count":2}]	15458	delivery	5	19
130952	2020-08-31 23:30:16	2020-08-31	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	19566	delivery	5	39
130953	2020-08-31 23:33:02	2020-08-31	8	[{"id_menu":5,"count":1}]	47223	delivery	5	13
130954	2020-08-31 23:37:14	2020-08-31	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	38812	pick-up	0	21
130955	2020-08-31 23:37:49	2020-08-31	8	[{"id_menu":5,"count":1}]	49246	delivery	5	13
130956	2020-08-31 23:39:26	2020-08-31	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	44546	pick-up	0	29
130957	2020-08-31 23:39:26	2020-08-31	12	[{"id_menu":3,"count":1}]	21809	delivery	5	17
130958	2020-08-31 23:49:40	2020-08-31	17	[{"id_menu":4,"count":1}]	20859	delivery	5	22
130959	2020-08-31 23:50:02	2020-08-31	17	[{"id_menu":4,"count":1}]	45244	delivery	5	22
130960	2020-08-31 23:50:16	2020-08-31	9	[{"id_menu":7,"count":1}]	13131	delivery	5	14
130961	2020-08-31 23:59:20	2020-08-31	21	[{"id_menu":1,"count":2},{"id_menu":6,"count":1}]	46430	delivery	5	26
130962	2020-09-01 00:03:45	2020-09-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	11527	delivery	5	22
130963	2020-09-01 00:08:40	2020-09-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	49586	delivery	5	28
130964	2020-09-01 00:08:54	2020-09-01	9	[{"id_menu":6,"count":1}]	7974	delivery	5	14
130965	2020-09-01 00:12:39	2020-09-01	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	22418	pick-up	0	22
130966	2020-09-01 00:13:03	2020-09-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	49367	delivery	5	31
130967	2020-09-01 00:18:45	2020-09-01	12	[{"id_menu":3,"count":1}]	4862	pick-up	0	12
130968	2020-09-01 00:18:45	2020-09-01	9	[{"id_menu":7,"count":1}]	26860	pick-up	0	9
130969	2020-09-01 00:22:32	2020-09-01	14	[{"id_menu":2,"count":1}]	7279	delivery	5	19
130970	2020-09-01 00:23:08	2020-09-01	8	[{"id_menu":5,"count":1}]	13964	delivery	5	13
130971	2020-09-01 00:24:11	2020-09-01	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	8438	delivery	5	40
130972	2020-09-01 00:26:24	2020-09-01	14	[{"id_menu":2,"count":1}]	32128	delivery	5	19
130973	2020-09-01 00:33:25	2020-09-01	12	[{"id_menu":1,"count":1}]	19443	delivery	5	17
130974	2020-09-01 00:36:03	2020-09-01	14	[{"id_menu":2,"count":1}]	8550	pick-up	0	14
130975	2020-09-01 00:37:27	2020-09-01	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	43915	delivery	5	30
130976	2020-09-01 00:37:33	2020-09-01	9	[{"id_menu":6,"count":1}]	44510	delivery	5	14
130977	2020-09-01 00:39:08	2020-09-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	49364	delivery	5	22
130978	2020-09-01 00:39:10	2020-09-01	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	36693	delivery	5	39
130979	2020-09-01 00:46:51	2020-09-01	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	6504	delivery	5	22
130980	2020-09-01 00:51:11	2020-09-01	12	[{"id_menu":3,"count":1}]	49406	pick-up	0	12
130981	2020-09-01 00:51:12	2020-09-01	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	36251	delivery	5	37
130982	2020-09-01 00:57:48	2020-09-01	17	[{"id_menu":4,"count":1}]	7705	delivery	5	22
130983	2020-09-01 00:59:38	2020-09-01	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	49298	delivery	5	27
130984	2020-09-01 01:00:34	2020-09-01	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	49496	delivery	5	39
130985	2020-09-01 01:05:09	2020-09-01	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	37186	pick-up	0	38
130986	2020-09-01 01:05:26	2020-09-01	8	[{"id_menu":5,"count":1}]	46429	delivery	5	13
130987	2020-09-01 01:06:10	2020-09-01	14	[{"id_menu":2,"count":1}]	7090	delivery	5	19
130988	2020-09-01 01:06:13	2020-09-01	9	[{"id_menu":6,"count":1}]	9463	delivery	5	14
130989	2020-09-01 01:07:51	2020-09-01	12	[{"id_menu":1,"count":1}]	49328	delivery	5	17
130990	2020-09-01 01:10:41	2020-09-01	9	[{"id_menu":6,"count":1}]	29711	pick-up	0	9
130991	2020-09-01 01:12:19	2020-09-01	9	[{"id_menu":6,"count":1}]	49555	delivery	5	14
130992	2020-09-01 01:21:19	2020-09-01	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	7566	delivery	5	39
130993	2020-09-01 01:21:46	2020-09-01	17	[{"id_menu":4,"count":1}]	4656	delivery	5	22
130994	2020-09-01 01:23:28	2020-09-01	17	[{"id_menu":4,"count":1}]	32178	pick-up	0	17
130995	2020-09-01 01:23:28	2020-09-01	8	[{"id_menu":5,"count":1}]	49567	delivery	5	13
130996	2020-09-01 01:26:34	2020-09-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	49532	delivery	5	26
130997	2020-09-01 01:27:31	2020-09-01	12	[{"id_menu":1,"count":1}]	5287	delivery	5	17
130998	2020-09-01 01:29:27	2020-09-01	14	[{"id_menu":2,"count":1}]	46273	delivery	5	19
130999	2020-09-01 01:30:03	2020-09-01	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	17695	pick-up	0	26
131000	2020-09-01 01:30:49	2020-09-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	7119	pick-up	0	17
131001	2020-09-01 01:34:50	2020-09-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	49306	delivery	5	36
131002	2020-09-01 01:37:26	2020-09-01	8	[{"id_menu":5,"count":1}]	39322	delivery	5	13
131003	2020-09-01 01:40:18	2020-09-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44991	delivery	5	23
131004	2020-09-01 01:43:11	2020-09-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	3996	delivery	5	22
131005	2020-09-01 01:52:48	2020-09-01	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	49296	pick-up	0	25
131006	2020-09-01 01:53:54	2020-09-01	35	[{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	49593	delivery	5	40
131007	2020-09-01 01:53:59	2020-09-01	8	[{"id_menu":5,"count":1}]	42586	delivery	5	13
131008	2020-09-01 01:56:15	2020-09-01	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	49592	delivery	5	34
131009	2020-09-01 01:59:14	2020-09-01	8	[{"id_menu":5,"count":1}]	41815	delivery	5	13
131010	2020-09-01 02:01:18	2020-09-01	14	[{"id_menu":2,"count":1}]	49389	delivery	5	19
131011	2020-09-01 02:02:16	2020-09-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37176	pick-up	0	18
131012	2020-09-01 02:02:41	2020-09-01	8	[{"id_menu":5,"count":1}]	28491	delivery	5	13
131013	2020-09-01 02:06:28	2020-09-01	12	[{"id_menu":3,"count":1}]	2056	pick-up	0	12
131014	2020-09-01 02:07:37	2020-09-01	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":5,"count":1}]	5329	delivery	5	39
131015	2020-09-01 02:10:05	2020-09-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	41616	pick-up	0	17
131016	2020-09-01 02:10:38	2020-09-01	9	[{"id_menu":7,"count":1}]	18374	pick-up	0	9
131017	2020-09-01 02:11:39	2020-09-01	9	[{"id_menu":6,"count":1}]	43352	delivery	5	14
131018	2020-09-01 02:14:47	2020-09-01	9	[{"id_menu":7,"count":1}]	12210	delivery	5	14
131019	2020-09-01 02:19:20	2020-09-01	8	[{"id_menu":5,"count":1}]	10729	delivery	5	13
131020	2020-09-01 02:20:40	2020-09-01	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	49434	delivery	5	44
131021	2020-09-01 02:20:55	2020-09-01	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	10641	pick-up	0	20
131022	2020-09-01 02:21:16	2020-09-01	12	[{"id_menu":1,"count":1}]	32846	pick-up	0	12
131023	2020-09-01 02:21:54	2020-09-01	12	[{"id_menu":1,"count":1}]	47131	delivery	5	17
131024	2020-09-01 02:23:10	2020-09-01	9	[{"id_menu":6,"count":1}]	38953	delivery	5	14
131025	2020-09-01 02:25:40	2020-09-01	8	[{"id_menu":5,"count":1}]	49569	delivery	5	13
131026	2020-09-01 02:25:46	2020-09-01	8	[{"id_menu":5,"count":1}]	49294	delivery	5	13
131027	2020-09-01 02:27:31	2020-09-01	9	[{"id_menu":6,"count":1}]	49362	delivery	5	14
131028	2020-09-01 02:27:36	2020-09-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	19174	delivery	5	23
131029	2020-09-01 02:31:09	2020-09-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	8341	pick-up	0	31
131030	2020-09-01 02:32:05	2020-09-01	9	[{"id_menu":6,"count":1}]	47372	delivery	5	14
131031	2020-09-01 02:32:26	2020-09-01	14	[{"id_menu":2,"count":1}]	49307	delivery	5	19
131032	2020-09-01 02:36:49	2020-09-01	17	[{"id_menu":4,"count":1}]	49425	delivery	5	22
131033	2020-09-01 02:37:17	2020-09-01	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	33742	delivery	5	40
131034	2020-09-01 02:39:46	2020-09-01	9	[{"id_menu":6,"count":1}]	45892	delivery	5	14
131035	2020-09-01 02:40:08	2020-09-01	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	30777	pick-up	0	22
131036	2020-09-01 02:40:47	2020-09-01	33	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	27023	delivery	5	38
131037	2020-09-01 02:41:44	2020-09-01	17	[{"id_menu":4,"count":1}]	49415	delivery	5	22
131038	2020-09-01 02:42:06	2020-09-01	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	11109	delivery	5	26
131039	2020-09-01 02:50:58	2020-09-01	14	[{"id_menu":2,"count":1}]	6080	delivery	5	19
131040	2020-09-01 02:53:21	2020-09-01	9	[{"id_menu":6,"count":1}]	30453	delivery	5	14
131041	2020-09-01 02:54:16	2020-09-01	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":4,"count":2}]	49432	delivery	5	46
131042	2020-09-01 02:57:26	2020-09-01	9	[{"id_menu":6,"count":1}]	23102	delivery	5	14
131043	2020-09-01 02:57:36	2020-09-01	8	[{"id_menu":5,"count":1}]	21862	delivery	5	13
131044	2020-09-01 02:57:43	2020-09-01	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	49546	delivery	5	36
131045	2020-09-01 02:58:47	2020-09-01	14	[{"id_menu":2,"count":2}]	49336	delivery	5	19
131046	2020-09-01 02:58:57	2020-09-01	9	[{"id_menu":6,"count":1}]	23696	pick-up	0	9
131047	2020-09-01 02:59:57	2020-09-01	14	[{"id_menu":2,"count":1}]	10475	delivery	5	19
131048	2020-09-01 03:04:46	2020-09-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	6442	pick-up	0	26
131049	2020-09-01 03:11:07	2020-09-01	9	[{"id_menu":6,"count":1}]	13031	delivery	5	14
131050	2020-09-01 03:13:10	2020-09-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4818	delivery	5	31
131051	2020-09-01 03:14:24	2020-09-01	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	33772	delivery	5	25
131052	2020-09-01 03:22:50	2020-09-01	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	31430	delivery	5	26
131053	2020-09-01 03:23:48	2020-09-01	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	49371	delivery	5	40
131054	2020-09-01 03:24:28	2020-09-01	12	[{"id_menu":3,"count":1}]	822	delivery	5	17
131055	2020-09-01 03:27:18	2020-09-01	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	49494	delivery	5	25
131056	2020-09-01 03:30:16	2020-09-01	9	[{"id_menu":7,"count":1}]	27260	delivery	5	14
131057	2020-09-01 03:31:46	2020-09-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	31927	delivery	5	31
131058	2020-09-01 03:32:36	2020-09-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	49407	delivery	5	23
131059	2020-09-01 03:33:29	2020-09-01	12	[{"id_menu":3,"count":1}]	8805	pick-up	0	12
131060	2020-09-01 03:37:01	2020-09-01	12	[{"id_menu":3,"count":1}]	30584	delivery	5	17
131061	2020-09-01 03:37:13	2020-09-01	12	[{"id_menu":1,"count":1}]	26154	delivery	5	17
131062	2020-09-01 03:38:15	2020-09-01	9	[{"id_menu":7,"count":1}]	34245	delivery	5	14
131063	2020-09-01 03:38:23	2020-09-01	12	[{"id_menu":1,"count":1}]	17808	delivery	5	17
131064	2020-09-01 03:38:39	2020-09-01	12	[{"id_menu":1,"count":1}]	7688	pick-up	0	12
131065	2020-09-01 03:41:41	2020-09-01	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	32738	delivery	5	53
131066	2020-09-01 03:42:06	2020-09-01	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	38102	delivery	5	40
131067	2020-09-01 03:49:24	2020-09-01	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	1429	pick-up	0	21
131068	2020-09-01 03:50:25	2020-09-01	17	[{"id_menu":4,"count":1}]	49351	delivery	5	22
131069	2020-09-01 03:51:30	2020-09-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	49418	delivery	5	22
131070	2020-09-01 03:53:59	2020-09-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	49048	delivery	5	23
131071	2020-09-01 03:58:04	2020-09-01	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	15599	pick-up	0	37
131072	2020-09-01 03:58:38	2020-09-01	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	49564	delivery	5	43
131073	2020-09-01 03:59:04	2020-09-01	12	[{"id_menu":3,"count":1}]	19256	pick-up	0	12
131074	2020-09-01 04:03:19	2020-09-01	9	[{"id_menu":7,"count":1}]	976	pick-up	0	9
131075	2020-09-01 04:03:54	2020-09-01	14	[{"id_menu":2,"count":1}]	14219	delivery	5	19
131076	2020-09-01 04:04:16	2020-09-01	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	49446	delivery	5	37
131077	2020-09-01 04:13:04	2020-09-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	49612	delivery	5	22
131078	2020-09-01 04:14:55	2020-09-01	9	[{"id_menu":7,"count":1}]	8139	delivery	5	14
131079	2020-09-01 04:19:41	2020-09-01	12	[{"id_menu":1,"count":1}]	49378	delivery	5	17
131080	2020-09-01 04:20:16	2020-09-01	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	8029	delivery	5	51
131081	2020-09-01 04:20:33	2020-09-01	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	46833	delivery	5	30
131082	2020-09-01 04:24:13	2020-09-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	30909	delivery	5	22
131083	2020-09-01 04:27:58	2020-09-01	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	9995	pick-up	0	31
131084	2020-09-01 04:32:27	2020-09-01	9	[{"id_menu":7,"count":1}]	1347	pick-up	0	9
131085	2020-09-01 04:36:57	2020-09-01	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	16536	delivery	5	26
131086	2020-09-01 04:37:05	2020-09-01	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	44854	delivery	5	25
131087	2020-09-01 04:42:43	2020-09-01	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	49467	delivery	5	37
131088	2020-09-01 04:47:02	2020-09-01	9	[{"id_menu":7,"count":1}]	15590	pick-up	0	9
131089	2020-09-01 04:48:28	2020-09-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	49430	delivery	5	26
131090	2020-09-01 04:48:45	2020-09-01	14	[{"id_menu":2,"count":1}]	6113	delivery	5	19
131091	2020-09-01 04:56:17	2020-09-01	9	[{"id_menu":7,"count":1}]	49542	delivery	5	14
131092	2020-09-01 04:58:26	2020-09-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	10755	delivery	5	28
131093	2020-09-01 04:59:43	2020-09-01	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	5180	delivery	5	34
131094	2020-09-01 05:04:04	2020-09-01	9	[{"id_menu":6,"count":1}]	49447	delivery	5	14
131095	2020-09-01 05:06:18	2020-09-01	14	[{"id_menu":2,"count":1}]	14862	delivery	5	19
131096	2020-09-01 05:06:41	2020-09-01	47	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	2843	delivery	5	52
131097	2020-09-01 05:07:03	2020-09-01	12	[{"id_menu":1,"count":1}]	20494	delivery	5	17
131098	2020-09-01 05:09:01	2020-09-01	12	[{"id_menu":3,"count":1}]	5189	pick-up	0	12
131099	2020-09-01 05:09:20	2020-09-01	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	49339	delivery	5	26
131100	2020-09-01 05:14:02	2020-09-01	12	[{"id_menu":3,"count":1}]	228	pick-up	0	12
131101	2020-09-01 05:15:37	2020-09-01	17	[{"id_menu":4,"count":1}]	4428	pick-up	0	17
131102	2020-09-01 05:15:44	2020-09-01	9	[{"id_menu":6,"count":1}]	14495	delivery	5	14
131103	2020-09-01 05:16:04	2020-09-01	8	[{"id_menu":5,"count":1}]	21834	delivery	5	13
131104	2020-09-01 05:16:18	2020-09-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	49610	delivery	5	31
131105	2020-09-01 05:18:31	2020-09-01	9	[{"id_menu":7,"count":1}]	32638	delivery	5	14
131106	2020-09-01 05:19:37	2020-09-01	9	[{"id_menu":6,"count":1}]	49422	delivery	5	14
131107	2020-09-01 05:19:41	2020-09-01	9	[{"id_menu":6,"count":1}]	36037	delivery	5	14
131108	2020-09-01 05:23:50	2020-09-01	17	[{"id_menu":4,"count":1}]	13287	delivery	5	22
131109	2020-09-01 05:23:52	2020-09-01	9	[{"id_menu":6,"count":1}]	49620	delivery	5	14
131110	2020-09-01 05:24:31	2020-09-01	9	[{"id_menu":7,"count":1}]	15244	delivery	5	14
131111	2020-09-01 05:25:24	2020-09-01	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	41621	pick-up	0	24
131112	2020-09-01 05:26:39	2020-09-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13838	pick-up	0	17
131113	2020-09-01 05:26:44	2020-09-01	12	[{"id_menu":1,"count":1}]	49445	delivery	5	17
131114	2020-09-01 05:29:07	2020-09-01	9	[{"id_menu":7,"count":1}]	19653	delivery	5	14
131115	2020-09-01 05:30:02	2020-09-01	14	[{"id_menu":2,"count":1}]	11889	delivery	5	19
131116	2020-09-01 05:33:02	2020-09-01	9	[{"id_menu":6,"count":1}]	29360	delivery	5	14
131117	2020-09-01 05:34:06	2020-09-01	32	[{"id_menu":2,"count":2},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	49299	delivery	5	37
131118	2020-09-01 05:34:34	2020-09-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	49603	delivery	5	23
131119	2020-09-01 05:35:51	2020-09-01	9	[{"id_menu":7,"count":1}]	41537	delivery	5	14
131120	2020-09-01 05:36:01	2020-09-01	17	[{"id_menu":4,"count":1}]	34984	delivery	5	22
131121	2020-09-01 05:37:38	2020-09-01	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	42929	delivery	5	39
131122	2020-09-01 05:38:40	2020-09-01	9	[{"id_menu":7,"count":1}]	25320	pick-up	0	9
131123	2020-09-01 05:38:56	2020-09-01	9	[{"id_menu":6,"count":1}]	29671	delivery	5	14
131124	2020-09-01 05:44:56	2020-09-01	9	[{"id_menu":7,"count":1}]	49421	delivery	5	14
131125	2020-09-01 05:47:07	2020-09-01	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	3755	pick-up	0	32
131126	2020-09-01 05:47:18	2020-09-01	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	6429	delivery	5	39
131127	2020-09-01 05:47:18	2020-09-01	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	49417	delivery	5	25
131128	2020-09-01 05:49:00	2020-09-01	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	49347	delivery	5	25
131129	2020-09-01 05:49:42	2020-09-01	9	[{"id_menu":6,"count":1}]	35619	delivery	5	14
131130	2020-09-01 05:52:19	2020-09-01	9	[{"id_menu":6,"count":1}]	49462	delivery	5	14
131131	2020-09-01 05:53:39	2020-09-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	22472	delivery	5	23
131132	2020-09-01 05:57:16	2020-09-01	17	[{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	49349	delivery	5	22
131133	2020-09-01 06:01:26	2020-09-01	17	[{"id_menu":4,"count":1}]	49427	delivery	5	22
131134	2020-09-01 06:04:41	2020-09-01	9	[{"id_menu":6,"count":1}]	39525	delivery	5	14
131135	2020-09-01 06:06:57	2020-09-01	32	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	10826	delivery	5	37
131136	2020-09-01 06:11:45	2020-09-01	9	[{"id_menu":7,"count":1}]	35039	delivery	5	14
131137	2020-09-01 06:12:05	2020-09-01	14	[{"id_menu":2,"count":1}]	49313	delivery	5	19
131138	2020-09-01 06:15:46	2020-09-01	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	49503	delivery	5	37
131139	2020-09-01 06:20:43	2020-09-01	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	19687	pick-up	0	26
131140	2020-09-01 06:21:27	2020-09-01	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	49550	delivery	5	34
131141	2020-09-01 06:23:11	2020-09-01	9	[{"id_menu":6,"count":1}]	29161	pick-up	0	9
131142	2020-09-01 06:23:17	2020-09-01	17	[{"id_menu":4,"count":1}]	39801	delivery	5	22
131143	2020-09-01 06:28:20	2020-09-01	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	7780	delivery	5	36
131144	2020-09-01 06:33:22	2020-09-01	9	[{"id_menu":6,"count":1}]	11849	delivery	5	14
131145	2020-09-01 06:37:32	2020-09-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	26653	delivery	5	26
131146	2020-09-01 06:38:27	2020-09-01	12	[{"id_menu":3,"count":1}]	40564	pick-up	0	12
131147	2020-09-01 06:41:04	2020-09-01	9	[{"id_menu":6,"count":1}]	19795	delivery	5	14
131148	2020-09-01 06:43:51	2020-09-01	9	[{"id_menu":6,"count":1}]	47164	delivery	5	14
131149	2020-09-01 06:44:18	2020-09-01	9	[{"id_menu":7,"count":1}]	5669	delivery	5	14
131150	2020-09-01 06:44:21	2020-09-01	12	[{"id_menu":3,"count":1}]	49352	delivery	5	17
131151	2020-09-01 06:45:48	2020-09-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	43124	delivery	5	22
131152	2020-09-01 06:48:16	2020-09-01	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	15222	delivery	5	26
131153	2020-09-01 06:49:27	2020-09-01	9	[{"id_menu":7,"count":1}]	33615	delivery	5	14
131154	2020-09-01 06:51:22	2020-09-01	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":2}]	49581	delivery	5	31
131155	2020-09-01 06:53:06	2020-09-01	9	[{"id_menu":6,"count":1}]	18556	delivery	5	14
131156	2020-09-01 06:56:10	2020-09-01	17	[{"id_menu":4,"count":1}]	2000	delivery	5	22
131157	2020-09-01 07:00:38	2020-09-01	9	[{"id_menu":7,"count":1}]	18913	delivery	5	14
131158	2020-09-01 07:00:56	2020-09-01	14	[{"id_menu":2,"count":1}]	49568	delivery	5	19
131159	2020-09-01 07:09:27	2020-09-01	9	[{"id_menu":6,"count":1}]	3733	delivery	5	14
131160	2020-09-01 07:09:50	2020-09-01	17	[{"id_menu":4,"count":1}]	21294	delivery	5	22
131161	2020-09-01 07:11:56	2020-09-01	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	49594	delivery	5	31
131162	2020-09-01 07:13:28	2020-09-01	9	[{"id_menu":6,"count":1}]	24247	delivery	5	14
131163	2020-09-01 07:13:58	2020-09-01	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	12019	pick-up	0	24
131164	2020-09-01 07:14:08	2020-09-01	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	11525	delivery	5	48
131165	2020-09-01 07:21:42	2020-09-01	8	[{"id_menu":5,"count":1}]	22485	delivery	5	13
131166	2020-09-01 07:23:44	2020-09-01	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	31764	delivery	5	31
131167	2020-09-01 07:23:54	2020-09-01	9	[{"id_menu":6,"count":1}]	34091	pick-up	0	9
131168	2020-09-01 07:32:05	2020-09-01	12	[{"id_menu":3,"count":1}]	12011	pick-up	0	12
131169	2020-09-01 07:32:16	2020-09-01	14	[{"id_menu":2,"count":1}]	11413	delivery	5	19
131170	2020-09-01 07:34:44	2020-09-01	17	[{"id_menu":4,"count":1}]	49575	delivery	5	22
131171	2020-09-01 07:35:54	2020-09-01	9	[{"id_menu":7,"count":1}]	2413	pick-up	0	9
131172	2020-09-01 07:36:19	2020-09-01	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	49305	delivery	5	31
131173	2020-09-01 07:39:25	2020-09-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	5933	pick-up	0	31
131174	2020-09-01 07:40:01	2020-09-01	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	49493	pick-up	0	22
131175	2020-09-01 07:40:09	2020-09-01	9	[{"id_menu":7,"count":1}]	35668	delivery	5	14
131176	2020-09-01 07:40:18	2020-09-01	9	[{"id_menu":7,"count":1}]	49458	delivery	5	14
131177	2020-09-01 07:46:15	2020-09-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	49591	delivery	5	23
131178	2020-09-01 07:46:47	2020-09-01	14	[{"id_menu":2,"count":1}]	6097	pick-up	0	14
131179	2020-09-01 07:47:25	2020-09-01	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	14021	delivery	5	35
131180	2020-09-01 07:50:30	2020-09-01	17	[{"id_menu":4,"count":1}]	2072	pick-up	0	17
131181	2020-09-01 07:55:56	2020-09-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	49429	delivery	5	23
131182	2020-09-01 07:56:23	2020-09-01	14	[{"id_menu":2,"count":1}]	33566	delivery	5	19
131183	2020-09-01 07:57:50	2020-09-01	17	[{"id_menu":4,"count":1}]	3393	delivery	5	22
131184	2020-09-01 08:00:20	2020-09-01	9	[{"id_menu":6,"count":1}]	49437	delivery	5	14
131185	2020-09-01 08:04:02	2020-09-01	17	[{"id_menu":4,"count":2}]	4350	delivery	5	22
131186	2020-09-01 08:04:24	2020-09-01	8	[{"id_menu":5,"count":1}]	49502	delivery	5	13
131187	2020-09-01 08:15:26	2020-09-01	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	49300	delivery	5	40
131188	2020-09-01 08:20:00	2020-09-01	8	[{"id_menu":5,"count":1}]	35549	delivery	5	13
131189	2020-09-01 08:21:36	2020-09-01	9	[{"id_menu":7,"count":1}]	49399	delivery	5	14
131190	2020-09-01 08:23:25	2020-09-01	12	[{"id_menu":3,"count":1}]	6820	delivery	5	17
131191	2020-09-01 08:28:43	2020-09-01	12	[{"id_menu":3,"count":1}]	17372	pick-up	0	12
131192	2020-09-01 08:32:53	2020-09-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	40468	pick-up	0	21
131193	2020-09-01 08:33:44	2020-09-01	8	[{"id_menu":5,"count":1}]	1861	pick-up	0	8
131194	2020-09-01 08:33:57	2020-09-01	9	[{"id_menu":6,"count":2}]	5009	delivery	5	14
131195	2020-09-01 08:38:46	2020-09-01	29	[{"id_menu":1,"count":2},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	49551	delivery	5	34
131196	2020-09-01 08:40:56	2020-09-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	49310	delivery	5	31
131197	2020-09-01 08:41:11	2020-09-01	49	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	4534	delivery	5	54
131198	2020-09-01 08:42:46	2020-09-01	8	[{"id_menu":5,"count":1}]	4158	delivery	5	13
131199	2020-09-01 08:45:53	2020-09-01	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	49308	delivery	5	35
131200	2020-09-01 08:46:45	2020-09-01	8	[{"id_menu":5,"count":1}]	49457	delivery	5	13
131201	2020-09-01 08:50:58	2020-09-01	14	[{"id_menu":2,"count":1}]	49411	delivery	5	19
131202	2020-09-01 08:51:28	2020-09-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":2}]	49622	delivery	5	31
131203	2020-09-01 08:52:13	2020-09-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	626	delivery	5	23
131204	2020-09-01 08:52:23	2020-09-01	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	575	pick-up	0	21
131205	2020-09-01 08:55:56	2020-09-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	10771	delivery	5	23
131206	2020-09-01 08:56:10	2020-09-01	14	[{"id_menu":2,"count":1}]	16844	pick-up	0	14
131207	2020-09-01 08:56:19	2020-09-01	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	7364	delivery	5	26
131208	2020-09-01 08:57:11	2020-09-01	14	[{"id_menu":2,"count":1}]	7439	delivery	5	19
131209	2020-09-01 08:58:49	2020-09-01	8	[{"id_menu":5,"count":1}]	49335	pick-up	0	8
131210	2020-09-01 09:00:59	2020-09-01	9	[{"id_menu":6,"count":1}]	35688	delivery	5	14
131211	2020-09-01 09:01:42	2020-09-01	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	11415	delivery	5	34
131212	2020-09-01 09:02:54	2020-09-01	9	[{"id_menu":6,"count":1}]	14764	pick-up	0	9
131213	2020-09-01 09:03:04	2020-09-01	9	[{"id_menu":7,"count":2}]	34173	delivery	5	14
131214	2020-09-01 09:04:56	2020-09-01	17	[{"id_menu":4,"count":1}]	7623	delivery	5	22
131215	2020-09-01 09:07:08	2020-09-01	9	[{"id_menu":6,"count":1}]	13316	delivery	5	14
131216	2020-09-01 09:08:44	2020-09-01	9	[{"id_menu":7,"count":1}]	24996	pick-up	0	9
131217	2020-09-01 09:12:58	2020-09-01	14	[{"id_menu":2,"count":2}]	10281	pick-up	0	14
131218	2020-09-01 09:13:17	2020-09-01	9	[{"id_menu":7,"count":1}]	44811	delivery	5	14
131219	2020-09-01 09:18:28	2020-09-01	17	[{"id_menu":4,"count":1}]	41741	pick-up	0	17
131220	2020-09-01 09:21:10	2020-09-01	12	[{"id_menu":1,"count":2}]	2728	pick-up	0	12
131221	2020-09-01 09:22:03	2020-09-01	44	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9292	delivery	5	49
131222	2020-09-01 09:23:27	2020-09-01	8	[{"id_menu":5,"count":1}]	49478	delivery	5	13
131223	2020-09-01 09:23:51	2020-09-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	49392	delivery	5	23
131224	2020-09-01 09:29:19	2020-09-01	14	[{"id_menu":2,"count":1}]	49596	delivery	5	19
131225	2020-09-01 09:29:39	2020-09-01	14	[{"id_menu":2,"count":3}]	49433	delivery	5	19
131226	2020-09-01 09:32:15	2020-09-01	14	[{"id_menu":2,"count":1}]	1180	delivery	5	19
131227	2020-09-01 09:35:19	2020-09-01	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	25885	pick-up	0	21
131228	2020-09-01 09:38:29	2020-09-01	9	[{"id_menu":7,"count":1}]	49505	delivery	5	14
131229	2020-09-01 09:38:54	2020-09-01	23	[{"id_menu":2,"count":2},{"id_menu":6,"count":1}]	49535	delivery	5	28
131230	2020-09-01 09:41:04	2020-09-01	9	[{"id_menu":7,"count":1}]	28739	delivery	5	14
131231	2020-09-01 09:42:14	2020-09-01	9	[{"id_menu":6,"count":2}]	49345	delivery	5	14
131232	2020-09-01 09:44:05	2020-09-01	41	[{"id_menu":1,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	49522	delivery	5	46
131233	2020-09-01 09:45:52	2020-09-01	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	17036	pick-up	0	32
131234	2020-09-01 09:47:01	2020-09-01	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	44954	delivery	5	45
131235	2020-09-01 09:47:25	2020-09-01	12	[{"id_menu":1,"count":1}]	1155	pick-up	0	12
131236	2020-09-01 09:48:50	2020-09-01	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	1638	delivery	5	43
131237	2020-09-01 09:49:07	2020-09-01	9	[{"id_menu":7,"count":1}]	27699	delivery	5	14
131238	2020-09-01 09:51:54	2020-09-01	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	12598	delivery	5	31
131239	2020-09-01 09:55:19	2020-09-01	9	[{"id_menu":7,"count":1}]	47654	delivery	5	14
131240	2020-09-01 09:55:53	2020-09-01	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	49376	delivery	5	26
131241	2020-09-01 09:59:54	2020-09-01	12	[{"id_menu":1,"count":1}]	49309	delivery	5	17
131242	2020-09-01 10:03:44	2020-09-01	8	[{"id_menu":5,"count":1}]	49553	delivery	5	13
131243	2020-09-01 10:04:24	2020-09-01	9	[{"id_menu":7,"count":1}]	34311	delivery	5	14
131244	2020-09-01 10:06:00	2020-09-01	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":1}]	980	pick-up	0	21
131245	2020-09-01 10:12:36	2020-09-01	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	46057	delivery	5	34
131246	2020-09-01 10:21:25	2020-09-01	17	[{"id_menu":4,"count":1}]	49521	pick-up	0	17
131247	2020-09-01 10:22:12	2020-09-01	9	[{"id_menu":7,"count":3}]	48420	delivery	5	14
131248	2020-09-01 10:22:18	2020-09-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	30357	pick-up	0	31
131249	2020-09-01 10:29:57	2020-09-01	9	[{"id_menu":7,"count":1}]	43245	pick-up	0	9
131250	2020-09-01 10:31:33	2020-09-01	8	[{"id_menu":5,"count":1}]	45171	pick-up	0	8
131251	2020-09-01 10:33:44	2020-09-01	9	[{"id_menu":6,"count":1}]	48480	delivery	5	14
131252	2020-09-01 10:34:16	2020-09-01	9	[{"id_menu":7,"count":1}]	43759	delivery	5	14
131253	2020-09-01 10:36:56	2020-09-01	8	[{"id_menu":5,"count":1}]	49440	delivery	5	13
131254	2020-09-01 10:37:32	2020-09-01	9	[{"id_menu":7,"count":1}]	42493	delivery	5	14
131255	2020-09-01 10:38:00	2020-09-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	7953	delivery	5	28
131256	2020-09-01 10:42:55	2020-09-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":2}]	49514	delivery	5	26
131257	2020-09-01 10:45:57	2020-09-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	16961	delivery	5	23
131258	2020-09-01 10:46:55	2020-09-01	17	[{"id_menu":4,"count":1}]	49368	delivery	5	22
131259	2020-09-01 10:50:51	2020-09-01	9	[{"id_menu":6,"count":2}]	35245	delivery	5	14
131260	2020-09-01 10:53:26	2020-09-01	14	[{"id_menu":2,"count":1}]	9749	delivery	5	19
131261	2020-09-01 10:57:08	2020-09-01	8	[{"id_menu":5,"count":1}]	3182	delivery	5	13
131262	2020-09-01 11:01:24	2020-09-01	9	[{"id_menu":6,"count":1}]	41311	delivery	5	14
131263	2020-09-01 11:06:32	2020-09-01	9	[{"id_menu":7,"count":1}]	49341	delivery	5	14
131264	2020-09-01 11:07:17	2020-09-01	8	[{"id_menu":5,"count":1}]	19344	delivery	5	13
131265	2020-09-01 11:07:46	2020-09-01	26	[{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	49501	delivery	5	31
131266	2020-09-01 11:08:44	2020-09-01	12	[{"id_menu":3,"count":1}]	49474	delivery	5	17
131267	2020-09-01 11:10:07	2020-09-01	9	[{"id_menu":7,"count":1}]	49506	delivery	5	14
131268	2020-09-01 11:13:06	2020-09-01	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	21041	delivery	5	30
131269	2020-09-01 11:16:00	2020-09-01	12	[{"id_menu":1,"count":2}]	4784	delivery	5	17
131270	2020-09-01 11:16:58	2020-09-01	9	[{"id_menu":7,"count":1}]	11189	pick-up	0	9
131271	2020-09-01 11:18:01	2020-09-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	49482	delivery	5	22
131272	2020-09-01 11:19:29	2020-09-01	8	[{"id_menu":5,"count":2}]	49578	delivery	5	13
131273	2020-09-01 11:19:52	2020-09-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	32542	pick-up	0	23
131274	2020-09-01 11:21:51	2020-09-01	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4445	pick-up	0	37
131275	2020-09-01 11:23:37	2020-09-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	18621	delivery	5	28
131276	2020-09-01 11:23:39	2020-09-01	14	[{"id_menu":2,"count":1}]	45018	delivery	5	19
131277	2020-09-01 11:24:20	2020-09-01	9	[{"id_menu":7,"count":2}]	38999	delivery	5	14
131278	2020-09-01 11:24:53	2020-09-01	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":2}]	23883	delivery	5	25
131279	2020-09-01 11:34:02	2020-09-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	6230	delivery	5	22
131280	2020-09-01 11:35:24	2020-09-01	9	[{"id_menu":6,"count":1}]	9139	delivery	5	14
131281	2020-09-01 11:40:30	2020-09-01	17	[{"id_menu":4,"count":1}]	2085	delivery	5	22
131282	2020-09-01 11:41:38	2020-09-01	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	31814	delivery	5	31
131283	2020-09-01 11:44:13	2020-09-01	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	7058	pick-up	0	35
131284	2020-09-01 11:44:14	2020-09-01	9	[{"id_menu":6,"count":1}]	33984	delivery	5	14
131285	2020-09-01 11:45:56	2020-09-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13948	delivery	5	22
131286	2020-09-01 11:46:02	2020-09-01	9	[{"id_menu":6,"count":1}]	15788	delivery	5	14
131287	2020-09-01 11:46:23	2020-09-01	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	49316	delivery	5	23
131288	2020-09-01 11:48:52	2020-09-01	17	[{"id_menu":4,"count":1}]	49523	delivery	5	22
131289	2020-09-01 11:49:10	2020-09-01	9	[{"id_menu":7,"count":1}]	49557	delivery	5	14
131290	2020-09-01 11:51:33	2020-09-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	41652	delivery	5	22
131291	2020-09-01 11:53:13	2020-09-01	9	[{"id_menu":7,"count":1}]	12721	delivery	5	14
131292	2020-09-01 11:55:21	2020-09-01	17	[{"id_menu":4,"count":1}]	48539	delivery	5	22
131293	2020-09-01 11:55:26	2020-09-01	17	[{"id_menu":4,"count":1}]	2114	delivery	5	22
131294	2020-09-01 11:56:15	2020-09-01	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	45308	delivery	5	27
131295	2020-09-01 11:57:05	2020-09-01	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	20338	pick-up	0	29
131296	2020-09-01 12:02:05	2020-09-01	12	[{"id_menu":3,"count":1}]	11737	delivery	5	17
131297	2020-09-01 12:02:20	2020-09-01	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	49469	delivery	5	28
131298	2020-09-01 12:02:24	2020-09-01	9	[{"id_menu":7,"count":2}]	39982	delivery	5	14
131299	2020-09-01 12:05:51	2020-09-01	12	[{"id_menu":1,"count":1}]	17414	delivery	5	17
131300	2020-09-01 12:06:07	2020-09-01	12	[{"id_menu":3,"count":1}]	49439	delivery	5	17
131301	2020-09-01 12:06:52	2020-09-01	14	[{"id_menu":2,"count":1}]	7155	pick-up	0	14
131302	2020-09-01 12:13:11	2020-09-01	9	[{"id_menu":6,"count":1}]	36873	delivery	5	14
131303	2020-09-01 12:14:24	2020-09-01	38	[{"id_menu":1,"count":1},{"id_menu":4,"count":2},{"id_menu":6,"count":1}]	9164	delivery	5	43
131304	2020-09-01 12:16:53	2020-09-01	12	[{"id_menu":1,"count":1}]	1765	delivery	5	17
131305	2020-09-01 12:20:55	2020-09-01	9	[{"id_menu":7,"count":1}]	49580	delivery	5	14
131306	2020-09-01 12:26:00	2020-09-01	14	[{"id_menu":2,"count":1}]	4997	pick-up	0	14
131307	2020-09-01 12:26:24	2020-09-01	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	25461	delivery	5	31
131308	2020-09-01 12:26:27	2020-09-01	17	[{"id_menu":4,"count":1}]	28136	delivery	5	22
131309	2020-09-01 12:26:55	2020-09-01	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	29856	delivery	5	22
131310	2020-09-01 12:32:52	2020-09-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	49479	delivery	5	22
131311	2020-09-01 12:34:59	2020-09-01	17	[{"id_menu":4,"count":1}]	7414	pick-up	0	17
131312	2020-09-01 12:35:17	2020-09-01	14	[{"id_menu":2,"count":1}]	49329	delivery	5	19
131313	2020-09-01 12:35:29	2020-09-01	9	[{"id_menu":7,"count":1}]	33242	pick-up	0	9
131314	2020-09-01 12:38:25	2020-09-01	18	[{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	6646	delivery	5	23
131315	2020-09-01 12:42:58	2020-09-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	46486	delivery	5	22
131316	2020-09-01 12:47:43	2020-09-01	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	5679	pick-up	0	22
131317	2020-09-01 12:50:18	2020-09-01	43	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	30680	delivery	5	48
131318	2020-09-01 12:51:28	2020-09-01	9	[{"id_menu":6,"count":1}]	49558	delivery	5	14
131319	2020-09-01 12:53:13	2020-09-01	8	[{"id_menu":5,"count":1}]	30117	delivery	5	13
131320	2020-09-01 12:53:52	2020-09-01	12	[{"id_menu":3,"count":1}]	49537	pick-up	0	12
131321	2020-09-01 12:57:17	2020-09-01	8	[{"id_menu":5,"count":1}]	37834	pick-up	0	8
131322	2020-09-01 12:59:01	2020-09-01	12	[{"id_menu":1,"count":1}]	48447	delivery	5	17
131323	2020-09-01 13:00:45	2020-09-01	14	[{"id_menu":2,"count":1}]	41	pick-up	0	14
131324	2020-09-01 13:02:36	2020-09-01	8	[{"id_menu":5,"count":1}]	8298	delivery	5	13
131325	2020-09-01 13:04:55	2020-09-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9806	delivery	5	23
131326	2020-09-01 13:05:15	2020-09-01	20	[{"id_menu":1,"count":1},{"id_menu":5,"count":1}]	20970	delivery	5	25
131327	2020-09-01 13:05:23	2020-09-01	17	[{"id_menu":4,"count":1}]	36979	pick-up	0	17
131328	2020-09-01 13:06:51	2020-09-01	12	[{"id_menu":3,"count":1}]	27362	delivery	5	17
131329	2020-09-01 13:07:23	2020-09-01	9	[{"id_menu":7,"count":1}]	25563	delivery	5	14
131330	2020-09-01 13:10:16	2020-09-01	8	[{"id_menu":5,"count":1}]	47945	delivery	5	13
131331	2020-09-01 13:12:31	2020-09-01	29	[{"id_menu":3,"count":1},{"id_menu":4,"count":1}]	15941	pick-up	0	29
131332	2020-09-01 13:15:59	2020-09-01	9	[{"id_menu":6,"count":1}]	29613	delivery	5	14
131333	2020-09-01 13:19:19	2020-09-01	9	[{"id_menu":6,"count":1}]	28034	delivery	5	14
131334	2020-09-01 13:19:39	2020-09-01	12	[{"id_menu":3,"count":1}]	49410	pick-up	0	12
131335	2020-09-01 13:22:31	2020-09-01	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	46389	delivery	5	35
131336	2020-09-01 13:23:19	2020-09-01	9	[{"id_menu":7,"count":2}]	21067	delivery	5	14
131337	2020-09-01 13:24:14	2020-09-01	14	[{"id_menu":2,"count":1}]	1365	pick-up	0	14
131338	2020-09-01 13:24:28	2020-09-01	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	37948	delivery	5	42
131339	2020-09-01 13:24:55	2020-09-01	9	[{"id_menu":7,"count":1}]	47987	delivery	5	14
131340	2020-09-01 13:26:23	2020-09-01	9	[{"id_menu":6,"count":1}]	20116	pick-up	0	9
131341	2020-09-01 13:28:29	2020-09-01	17	[{"id_menu":4,"count":1}]	32993	delivery	5	22
131342	2020-09-01 13:30:09	2020-09-01	29	[{"id_menu":1,"count":2},{"id_menu":4,"count":1}]	49608	delivery	5	34
131343	2020-09-01 13:30:09	2020-09-01	12	[{"id_menu":1,"count":1}]	44535	pick-up	0	12
131344	2020-09-01 13:30:22	2020-09-01	17	[{"id_menu":4,"count":1}]	4040	pick-up	0	17
131345	2020-09-01 13:31:22	2020-09-01	9	[{"id_menu":7,"count":1}]	49508	delivery	5	14
131346	2020-09-01 13:35:30	2020-09-01	8	[{"id_menu":5,"count":2}]	23430	delivery	5	13
131347	2020-09-01 13:35:49	2020-09-01	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	12664	delivery	5	31
131348	2020-09-01 13:36:51	2020-09-01	12	[{"id_menu":1,"count":1}]	33422	pick-up	0	12
131349	2020-09-01 13:40:30	2020-09-01	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	9308	pick-up	0	26
131350	2020-09-01 13:43:37	2020-09-01	12	[{"id_menu":1,"count":1}]	49489	delivery	5	17
131351	2020-09-01 13:47:17	2020-09-01	14	[{"id_menu":2,"count":1}]	1780	delivery	5	19
131352	2020-09-01 13:50:37	2020-09-01	9	[{"id_menu":6,"count":1}]	49559	delivery	5	14
131353	2020-09-01 13:57:29	2020-09-01	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	7032	delivery	5	27
131354	2020-09-01 13:57:34	2020-09-01	9	[{"id_menu":7,"count":1}]	49443	delivery	5	14
131355	2020-09-01 13:58:42	2020-09-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	1303	pick-up	0	26
131356	2020-09-01 13:59:15	2020-09-01	14	[{"id_menu":2,"count":1}]	13732	delivery	5	19
131357	2020-09-01 14:00:15	2020-09-01	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	49372	delivery	5	35
131358	2020-09-01 14:01:19	2020-09-01	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	4655	delivery	5	26
131359	2020-09-01 14:01:26	2020-09-01	9	[{"id_menu":6,"count":1}]	6470	pick-up	0	9
131360	2020-09-01 14:02:38	2020-09-01	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	46444	delivery	5	35
131361	2020-09-01 14:03:11	2020-09-01	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	47215	delivery	5	27
131362	2020-09-01 14:03:12	2020-09-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	13859	pick-up	0	17
131363	2020-09-01 14:04:56	2020-09-01	12	[{"id_menu":1,"count":1}]	49297	delivery	5	17
131364	2020-09-01 14:07:11	2020-09-01	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	20074	delivery	5	35
131365	2020-09-01 14:14:50	2020-09-01	14	[{"id_menu":2,"count":2}]	49386	pick-up	0	14
131366	2020-09-01 14:16:00	2020-09-01	9	[{"id_menu":7,"count":1}]	24594	delivery	5	14
131367	2020-09-01 14:19:28	2020-09-01	17	[{"id_menu":4,"count":1}]	22216	delivery	5	22
131368	2020-09-01 14:25:53	2020-09-01	14	[{"id_menu":2,"count":1}]	27602	delivery	5	19
131369	2020-09-01 14:28:40	2020-09-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":2}]	49565	delivery	5	22
131370	2020-09-01 14:29:42	2020-09-01	8	[{"id_menu":5,"count":1}]	6410	pick-up	0	8
131371	2020-09-01 14:33:32	2020-09-01	14	[{"id_menu":2,"count":1}]	13000	delivery	5	19
131372	2020-09-01 14:35:33	2020-09-01	9	[{"id_menu":7,"count":1}]	16306	delivery	5	14
131373	2020-09-01 14:36:00	2020-09-01	17	[{"id_menu":4,"count":1}]	39002	delivery	5	22
131374	2020-09-01 14:38:36	2020-09-01	14	[{"id_menu":2,"count":1}]	4453	pick-up	0	14
131375	2020-09-01 14:39:26	2020-09-01	38	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	37134	delivery	5	43
131376	2020-09-01 14:40:10	2020-09-01	9	[{"id_menu":7,"count":1}]	27120	delivery	5	14
131377	2020-09-01 14:43:54	2020-09-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	49486	delivery	5	26
131378	2020-09-01 14:45:03	2020-09-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	24510	delivery	5	28
131379	2020-09-01 14:45:50	2020-09-01	9	[{"id_menu":7,"count":3}]	11588	delivery	5	14
131380	2020-09-01 14:50:02	2020-09-01	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11635	delivery	5	35
131381	2020-09-01 14:51:19	2020-09-01	14	[{"id_menu":2,"count":1}]	45172	delivery	5	19
131382	2020-09-01 14:56:50	2020-09-01	14	[{"id_menu":2,"count":1}]	28417	pick-up	0	14
131449	2020-09-01 17:12:21	2020-09-01	9	[{"id_menu":6,"count":2}]	3835	delivery	5	14
131383	2020-09-01 14:58:02	2020-09-01	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	11646	delivery	5	35
131384	2020-09-01 15:00:40	2020-09-01	9	[{"id_menu":6,"count":1}]	49579	delivery	5	14
131385	2020-09-01 15:02:37	2020-09-01	8	[{"id_menu":5,"count":1}]	41817	delivery	5	13
131386	2020-09-01 15:06:41	2020-09-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	40235	pick-up	0	23
131387	2020-09-01 15:06:42	2020-09-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	6715	delivery	5	36
131388	2020-09-01 15:11:37	2020-09-01	17	[{"id_menu":4,"count":1}]	27777	pick-up	0	17
131389	2020-09-01 15:15:32	2020-09-01	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	39424	delivery	5	34
131390	2020-09-01 15:16:07	2020-09-01	9	[{"id_menu":6,"count":1}]	38282	delivery	5	14
131391	2020-09-01 15:16:32	2020-09-01	26	[{"id_menu":4,"count":2},{"id_menu":6,"count":2}]	29445	delivery	5	31
131392	2020-09-01 15:19:22	2020-09-01	14	[{"id_menu":2,"count":1}]	49394	delivery	5	19
131393	2020-09-01 15:20:10	2020-09-01	9	[{"id_menu":6,"count":1}]	41665	delivery	5	14
131394	2020-09-01 15:21:14	2020-09-01	9	[{"id_menu":7,"count":1}]	1790	pick-up	0	9
131395	2020-09-01 15:23:07	2020-09-01	17	[{"id_menu":4,"count":1}]	30391	pick-up	0	17
131396	2020-09-01 15:26:01	2020-09-01	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":2}]	4104	delivery	5	29
131397	2020-09-01 15:32:32	2020-09-01	9	[{"id_menu":6,"count":1}]	29601	delivery	5	14
131398	2020-09-01 15:36:36	2020-09-01	8	[{"id_menu":5,"count":1}]	10033	delivery	5	13
131399	2020-09-01 15:41:09	2020-09-01	17	[{"id_menu":4,"count":1}]	23022	delivery	5	22
131400	2020-09-01 15:46:45	2020-09-01	8	[{"id_menu":5,"count":1}]	31215	delivery	5	13
131401	2020-09-01 15:47:09	2020-09-01	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	3903	pick-up	0	29
131402	2020-09-01 15:47:14	2020-09-01	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	9008	delivery	5	30
131403	2020-09-01 15:49:28	2020-09-01	9	[{"id_menu":7,"count":1}]	49544	delivery	5	14
131404	2020-09-01 15:52:46	2020-09-01	9	[{"id_menu":7,"count":2}]	30697	pick-up	0	9
131405	2020-09-01 15:54:41	2020-09-01	9	[{"id_menu":7,"count":1}]	33998	delivery	5	14
131406	2020-09-01 15:55:25	2020-09-01	39	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	4411	pick-up	0	39
131407	2020-09-01 15:56:02	2020-09-01	9	[{"id_menu":6,"count":1}]	41507	pick-up	0	9
131408	2020-09-01 16:01:27	2020-09-01	9	[{"id_menu":7,"count":1}]	49530	delivery	5	14
131409	2020-09-01 16:02:12	2020-09-01	14	[{"id_menu":2,"count":1}]	3052	pick-up	0	14
131410	2020-09-01 16:02:30	2020-09-01	29	[{"id_menu":3,"count":2},{"id_menu":4,"count":1}]	49541	delivery	5	34
131411	2020-09-01 16:04:05	2020-09-01	26	[{"id_menu":1,"count":1},{"id_menu":2,"count":1}]	24950	pick-up	0	26
131412	2020-09-01 16:05:45	2020-09-01	12	[{"id_menu":1,"count":1}]	47101	pick-up	0	12
131413	2020-09-01 16:09:00	2020-09-01	8	[{"id_menu":5,"count":1}]	16267	delivery	5	13
131414	2020-09-01 16:11:07	2020-09-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	46777	delivery	5	36
131415	2020-09-01 16:12:39	2020-09-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	49485	pick-up	0	23
131416	2020-09-01 16:14:10	2020-09-01	12	[{"id_menu":1,"count":1}]	44052	delivery	5	17
131417	2020-09-01 16:15:44	2020-09-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	18228	pick-up	0	23
131418	2020-09-01 16:17:15	2020-09-01	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	49381	delivery	5	42
131419	2020-09-01 16:19:13	2020-09-01	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":2},{"id_menu":6,"count":1}]	27733	delivery	5	36
131420	2020-09-01 16:19:44	2020-09-01	21	[{"id_menu":3,"count":2},{"id_menu":6,"count":1}]	1232	delivery	5	26
131421	2020-09-01 16:20:21	2020-09-01	12	[{"id_menu":1,"count":1}]	5047	pick-up	0	12
131422	2020-09-01 16:22:30	2020-09-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":1}]	20060	pick-up	0	31
131423	2020-09-01 16:23:42	2020-09-01	14	[{"id_menu":2,"count":1}]	38640	delivery	5	19
131424	2020-09-01 16:25:18	2020-09-01	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	49459	delivery	5	34
131425	2020-09-01 16:26:59	2020-09-01	17	[{"id_menu":4,"count":1}]	49472	delivery	5	22
131426	2020-09-01 16:27:05	2020-09-01	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	49444	delivery	5	27
131427	2020-09-01 16:30:36	2020-09-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":2}]	8461	delivery	5	22
131428	2020-09-01 16:31:18	2020-09-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	21006	delivery	5	31
131429	2020-09-01 16:33:50	2020-09-01	8	[{"id_menu":5,"count":2}]	49584	delivery	5	13
131430	2020-09-01 16:34:53	2020-09-01	26	[{"id_menu":1,"count":3},{"id_menu":2,"count":1}]	19664	pick-up	0	26
131431	2020-09-01 16:40:01	2020-09-01	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	9311	delivery	5	35
131432	2020-09-01 16:40:02	2020-09-01	17	[{"id_menu":4,"count":1}]	20815	delivery	5	22
131433	2020-09-01 16:40:04	2020-09-01	14	[{"id_menu":2,"count":1}]	49548	delivery	5	19
131434	2020-09-01 16:40:21	2020-09-01	9	[{"id_menu":7,"count":1}]	10820	delivery	5	14
131435	2020-09-01 16:41:45	2020-09-01	9	[{"id_menu":6,"count":1}]	6491	delivery	5	14
131436	2020-09-01 16:42:12	2020-09-01	21	[{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	49471	delivery	5	26
131437	2020-09-01 16:43:08	2020-09-01	17	[{"id_menu":4,"count":1}]	21009	delivery	5	22
131438	2020-09-01 16:46:38	2020-09-01	9	[{"id_menu":6,"count":2}]	20649	delivery	5	14
131439	2020-09-01 16:50:46	2020-09-01	9	[{"id_menu":6,"count":2}]	49552	delivery	5	14
131440	2020-09-01 16:52:25	2020-09-01	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	49615	delivery	5	35
131441	2020-09-01 16:53:03	2020-09-01	37	[{"id_menu":3,"count":1},{"id_menu":4,"count":2},{"id_menu":5,"count":1}]	49387	delivery	5	42
131442	2020-09-01 16:53:37	2020-09-01	21	[{"id_menu":1,"count":1},{"id_menu":6,"count":1}]	16186	pick-up	0	21
131443	2020-09-01 16:55:22	2020-09-01	17	[{"id_menu":4,"count":1}]	44376	delivery	5	22
131444	2020-09-01 16:56:44	2020-09-01	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	49621	delivery	5	35
131445	2020-09-01 17:02:06	2020-09-01	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	49315	delivery	5	34
131446	2020-09-01 17:02:31	2020-09-01	17	[{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	49585	delivery	5	22
131447	2020-09-01 17:09:54	2020-09-01	12	[{"id_menu":3,"count":2}]	49576	delivery	5	17
131448	2020-09-01 17:10:54	2020-09-01	17	[{"id_menu":4,"count":3}]	17091	delivery	5	22
131450	2020-09-01 17:13:16	2020-09-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	49354	delivery	5	28
131451	2020-09-01 17:15:57	2020-09-01	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	21205	delivery	5	35
131452	2020-09-01 17:17:15	2020-09-01	9	[{"id_menu":7,"count":1}]	17399	delivery	5	14
131453	2020-09-01 17:18:13	2020-09-01	9	[{"id_menu":7,"count":1}]	2672	pick-up	0	9
131454	2020-09-01 17:23:50	2020-09-01	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	49312	delivery	5	27
131455	2020-09-01 17:24:03	2020-09-01	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	49337	delivery	5	31
131456	2020-09-01 17:26:12	2020-09-01	9	[{"id_menu":6,"count":1}]	44962	delivery	5	14
131457	2020-09-01 17:27:38	2020-09-01	9	[{"id_menu":7,"count":1}]	13273	delivery	5	14
131458	2020-09-01 17:28:59	2020-09-01	12	[{"id_menu":3,"count":1}]	15563	delivery	5	17
131459	2020-09-01 17:29:23	2020-09-01	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	19637	delivery	5	31
131460	2020-09-01 17:30:43	2020-09-01	12	[{"id_menu":1,"count":2}]	655	pick-up	0	12
131461	2020-09-01 17:31:57	2020-09-01	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	48518	delivery	5	36
131462	2020-09-01 17:35:52	2020-09-01	8	[{"id_menu":5,"count":1}]	16550	pick-up	0	8
131463	2020-09-01 17:37:11	2020-09-01	9	[{"id_menu":7,"count":1}]	20598	pick-up	0	9
131464	2020-09-01 17:39:03	2020-09-01	9	[{"id_menu":6,"count":1}]	49470	delivery	5	14
131465	2020-09-01 17:40:16	2020-09-01	48	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	43468	delivery	5	53
131466	2020-09-01 17:48:52	2020-09-01	9	[{"id_menu":7,"count":1}]	17811	delivery	5	14
131467	2020-09-01 17:53:55	2020-09-01	17	[{"id_menu":4,"count":1}]	49303	delivery	5	22
131468	2020-09-01 17:54:16	2020-09-01	12	[{"id_menu":1,"count":1}]	46541	delivery	5	17
131469	2020-09-01 17:55:13	2020-09-01	38	[{"id_menu":1,"count":1},{"id_menu":2,"count":2},{"id_menu":3,"count":1}]	3335	delivery	5	43
131470	2020-09-01 17:58:06	2020-09-01	8	[{"id_menu":5,"count":1}]	41245	delivery	5	13
131471	2020-09-01 17:58:13	2020-09-01	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	49627	delivery	5	40
131472	2020-09-01 17:58:48	2020-09-01	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	31383	delivery	5	31
131473	2020-09-01 17:59:29	2020-09-01	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	15076	delivery	5	25
131474	2020-09-01 17:59:47	2020-09-01	40	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	44563	delivery	5	45
131475	2020-09-01 18:01:01	2020-09-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	4678	pick-up	0	26
131476	2020-09-01 18:10:48	2020-09-01	37	[{"id_menu":1,"count":2},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	31391	delivery	5	42
131477	2020-09-01 18:12:03	2020-09-01	9	[{"id_menu":6,"count":1}]	49611	delivery	5	14
131478	2020-09-01 18:15:32	2020-09-01	26	[{"id_menu":2,"count":1},{"id_menu":3,"count":1}]	11394	delivery	5	31
131479	2020-09-01 18:15:35	2020-09-01	12	[{"id_menu":3,"count":1}]	49461	delivery	5	17
131480	2020-09-01 18:16:50	2020-09-01	12	[{"id_menu":1,"count":1}]	9175	delivery	5	17
131481	2020-09-01 18:18:48	2020-09-01	9	[{"id_menu":7,"count":2}]	28796	delivery	5	14
131482	2020-09-01 18:24:24	2020-09-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	30915	delivery	5	28
131483	2020-09-01 18:26:10	2020-09-01	31	[{"id_menu":2,"count":2},{"id_menu":4,"count":1}]	27195	delivery	5	36
131484	2020-09-01 18:30:36	2020-09-01	12	[{"id_menu":1,"count":1}]	49370	delivery	5	17
131485	2020-09-01 18:41:56	2020-09-01	17	[{"id_menu":4,"count":1}]	14702	delivery	5	22
131486	2020-09-01 18:43:32	2020-09-01	9	[{"id_menu":6,"count":1}]	49363	delivery	5	14
131487	2020-09-01 18:43:43	2020-09-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	49590	delivery	5	28
131488	2020-09-01 18:44:28	2020-09-01	31	[{"id_menu":2,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	49570	delivery	5	36
131489	2020-09-01 18:44:47	2020-09-01	12	[{"id_menu":3,"count":1}]	9421	pick-up	0	12
131490	2020-09-01 18:45:28	2020-09-01	9	[{"id_menu":6,"count":1}]	12986	delivery	5	14
131491	2020-09-01 18:49:34	2020-09-01	52	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	49587	delivery	5	57
131492	2020-09-01 18:50:38	2020-09-01	31	[{"id_menu":2,"count":1},{"id_menu":4,"count":2}]	11052	delivery	5	36
131493	2020-09-01 18:52:37	2020-09-01	8	[{"id_menu":5,"count":1}]	37570	delivery	5	13
131494	2020-09-01 18:53:17	2020-09-01	9	[{"id_menu":6,"count":1}]	49373	delivery	5	14
131495	2020-09-01 18:54:43	2020-09-01	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	31581	delivery	5	26
131496	2020-09-01 18:58:20	2020-09-01	12	[{"id_menu":3,"count":1}]	38239	pick-up	0	12
131497	2020-09-01 19:02:33	2020-09-01	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	9575	pick-up	0	21
131498	2020-09-01 19:02:58	2020-09-01	9	[{"id_menu":6,"count":1}]	28269	delivery	5	14
131499	2020-09-01 19:03:06	2020-09-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	22886	delivery	5	31
131500	2020-09-01 19:03:59	2020-09-01	9	[{"id_menu":6,"count":1}]	16224	delivery	5	14
131501	2020-09-01 19:06:34	2020-09-01	17	[{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	15350	delivery	5	22
131502	2020-09-01 19:13:55	2020-09-01	9	[{"id_menu":7,"count":1}]	48187	delivery	5	14
131503	2020-09-01 19:14:01	2020-09-01	29	[{"id_menu":1,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	49577	delivery	5	34
131504	2020-09-01 19:16:04	2020-09-01	24	[{"id_menu":1,"count":2},{"id_menu":3,"count":1}]	2769	delivery	5	29
131505	2020-09-01 19:19:21	2020-09-01	14	[{"id_menu":2,"count":1}]	40772	pick-up	0	14
131506	2020-09-01 19:20:29	2020-09-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	24407	pick-up	0	26
131507	2020-09-01 19:22:36	2020-09-01	18	[{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	5603	delivery	5	23
131508	2020-09-01 19:24:37	2020-09-01	9	[{"id_menu":6,"count":1}]	47887	delivery	5	14
131509	2020-09-01 19:24:38	2020-09-01	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	2994	delivery	5	30
131510	2020-09-01 19:24:45	2020-09-01	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	49609	delivery	5	39
131511	2020-09-01 19:24:54	2020-09-01	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	49464	delivery	5	39
131512	2020-09-01 19:26:17	2020-09-01	46	[{"id_menu":3,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	49344	delivery	5	51
131513	2020-09-01 19:27:26	2020-09-01	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	49326	delivery	5	37
131514	2020-09-01 19:30:44	2020-09-01	8	[{"id_menu":5,"count":1}]	49466	delivery	5	13
131515	2020-09-01 19:31:49	2020-09-01	17	[{"id_menu":4,"count":1}]	43558	delivery	5	22
131516	2020-09-01 19:37:38	2020-09-01	40	[{"id_menu":2,"count":2},{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	49400	delivery	5	45
131517	2020-09-01 19:38:08	2020-09-01	14	[{"id_menu":2,"count":1}]	49499	pick-up	0	14
131518	2020-09-01 19:40:50	2020-09-01	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	48067	delivery	5	31
131519	2020-09-01 19:42:10	2020-09-01	12	[{"id_menu":3,"count":1}]	33698	delivery	5	17
131520	2020-09-01 19:43:54	2020-09-01	9	[{"id_menu":6,"count":1}]	21509	delivery	5	14
131521	2020-09-01 19:47:46	2020-09-01	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	49321	delivery	5	22
131522	2020-09-01 19:52:58	2020-09-01	12	[{"id_menu":1,"count":1}]	49375	delivery	5	17
131523	2020-09-01 19:55:37	2020-09-01	12	[{"id_menu":1,"count":1}]	49325	delivery	5	17
131524	2020-09-01 19:56:25	2020-09-01	9	[{"id_menu":6,"count":1}]	39580	delivery	5	14
131525	2020-09-01 19:59:24	2020-09-01	14	[{"id_menu":2,"count":1}]	19645	pick-up	0	14
131526	2020-09-01 19:59:53	2020-09-01	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	49531	delivery	5	26
131527	2020-09-01 20:02:12	2020-09-01	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	49393	delivery	5	22
131528	2020-09-01 20:05:00	2020-09-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":2}]	40659	delivery	5	28
131529	2020-09-01 20:06:28	2020-09-01	12	[{"id_menu":3,"count":1}]	23859	delivery	5	17
131530	2020-09-01 20:06:37	2020-09-01	9	[{"id_menu":7,"count":1}]	39091	delivery	5	14
131531	2020-09-01 20:07:47	2020-09-01	8	[{"id_menu":5,"count":1}]	49507	delivery	5	13
131532	2020-09-01 20:08:45	2020-09-01	12	[{"id_menu":3,"count":1}]	7897	pick-up	0	12
131533	2020-09-01 20:16:02	2020-09-01	14	[{"id_menu":2,"count":1}]	49563	delivery	5	19
131534	2020-09-01 20:19:30	2020-09-01	26	[{"id_menu":4,"count":2},{"id_menu":7,"count":1}]	9014	delivery	5	31
131535	2020-09-01 20:20:34	2020-09-01	21	[{"id_menu":1,"count":1},{"id_menu":7,"count":2}]	49476	delivery	5	26
131536	2020-09-01 20:22:30	2020-09-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	36567	delivery	5	28
131537	2020-09-01 20:26:01	2020-09-01	33	[{"id_menu":1,"count":2},{"id_menu":3,"count":1},{"id_menu":6,"count":1}]	35104	delivery	5	38
131538	2020-09-01 20:27:39	2020-09-01	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	37528	delivery	5	31
131539	2020-09-01 20:28:40	2020-09-01	12	[{"id_menu":1,"count":1}]	14220	delivery	5	17
131540	2020-09-01 20:28:46	2020-09-01	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	47177	delivery	5	31
131541	2020-09-01 20:28:53	2020-09-01	17	[{"id_menu":4,"count":1}]	49583	delivery	5	22
131542	2020-09-01 20:30:55	2020-09-01	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	12823	delivery	5	42
131543	2020-09-01 20:32:18	2020-09-01	9	[{"id_menu":6,"count":2}]	21290	pick-up	0	9
131544	2020-09-01 20:35:21	2020-09-01	14	[{"id_menu":2,"count":1}]	49488	pick-up	0	14
131545	2020-09-01 20:36:37	2020-09-01	12	[{"id_menu":3,"count":1}]	9976	delivery	5	17
131546	2020-09-01 20:38:31	2020-09-01	14	[{"id_menu":2,"count":1}]	12478	delivery	5	19
131547	2020-09-01 20:40:01	2020-09-01	25	[{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	49428	delivery	5	30
131548	2020-09-01 20:41:29	2020-09-01	9	[{"id_menu":6,"count":1}]	49607	delivery	5	14
131549	2020-09-01 20:45:52	2020-09-01	9	[{"id_menu":6,"count":2}]	49498	delivery	5	14
131550	2020-09-01 20:46:17	2020-09-01	17	[{"id_menu":4,"count":1}]	33909	delivery	5	22
131551	2020-09-01 20:50:32	2020-09-01	21	[{"id_menu":3,"count":1},{"id_menu":7,"count":2}]	12390	delivery	5	26
131552	2020-09-01 20:59:57	2020-09-01	14	[{"id_menu":2,"count":2}]	18125	delivery	5	19
131553	2020-09-01 21:03:14	2020-09-01	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	9467	pick-up	0	22
131554	2020-09-01 21:03:51	2020-09-01	9	[{"id_menu":7,"count":3}]	49536	delivery	5	14
131555	2020-09-01 21:05:25	2020-09-01	9	[{"id_menu":6,"count":1}]	49483	delivery	5	14
131556	2020-09-01 21:08:39	2020-09-01	14	[{"id_menu":2,"count":1}]	37761	delivery	5	19
131557	2020-09-01 21:12:41	2020-09-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	49484	delivery	5	28
131558	2020-09-01 21:13:37	2020-09-01	17	[{"id_menu":4,"count":1}]	17041	pick-up	0	17
131559	2020-09-01 21:14:53	2020-09-01	46	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	29397	delivery	5	51
131560	2020-09-01 21:15:46	2020-09-01	9	[{"id_menu":6,"count":1}]	7733	delivery	5	14
131561	2020-09-01 21:17:33	2020-09-01	14	[{"id_menu":2,"count":2}]	27014	delivery	5	19
131562	2020-09-01 21:18:03	2020-09-01	12	[{"id_menu":3,"count":1}]	49390	delivery	5	17
131563	2020-09-01 21:24:02	2020-09-01	9	[{"id_menu":7,"count":1}]	49323	delivery	5	14
131564	2020-09-01 21:26:58	2020-09-01	17	[{"id_menu":4,"count":2}]	47549	delivery	5	22
131565	2020-09-01 21:28:21	2020-09-01	23	[{"id_menu":2,"count":2},{"id_menu":7,"count":1}]	36559	delivery	5	28
131566	2020-09-01 21:29:07	2020-09-01	35	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	34792	pick-up	0	35
131567	2020-09-01 21:32:57	2020-09-01	9	[{"id_menu":6,"count":1}]	30204	pick-up	0	9
131568	2020-09-01 21:34:46	2020-09-01	26	[{"id_menu":4,"count":1},{"id_menu":6,"count":2}]	49560	delivery	5	31
131569	2020-09-01 21:38:51	2020-09-01	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	18296	delivery	5	31
131570	2020-09-01 21:41:15	2020-09-01	30	[{"id_menu":1,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":1}]	49554	delivery	5	35
131571	2020-09-01 21:41:44	2020-09-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	36762	pick-up	0	26
131572	2020-09-01 21:43:15	2020-09-01	12	[{"id_menu":1,"count":1}]	34366	pick-up	0	12
131573	2020-09-01 21:48:21	2020-09-01	34	[{"id_menu":1,"count":1},{"id_menu":2,"count":1},{"id_menu":5,"count":1}]	27449	delivery	5	39
131574	2020-09-01 21:49:02	2020-09-01	9	[{"id_menu":7,"count":1}]	49374	delivery	5	14
131575	2020-09-01 21:49:41	2020-09-01	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":2},{"id_menu":7,"count":1}]	49342	delivery	5	40
131576	2020-09-01 21:50:25	2020-09-01	12	[{"id_menu":3,"count":1}]	5097	delivery	5	17
131577	2020-09-01 21:51:29	2020-09-01	24	[{"id_menu":1,"count":1},{"id_menu":3,"count":1}]	11926	pick-up	0	24
131578	2020-09-01 21:51:49	2020-09-01	14	[{"id_menu":2,"count":1}]	30686	delivery	5	19
131579	2020-09-01 21:56:09	2020-09-01	9	[{"id_menu":7,"count":1}]	49477	delivery	5	14
131580	2020-09-01 21:58:50	2020-09-01	30	[{"id_menu":3,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	49384	delivery	5	35
131581	2020-09-01 21:59:47	2020-09-01	9	[{"id_menu":7,"count":2}]	10692	pick-up	0	9
131582	2020-09-01 22:02:39	2020-09-01	9	[{"id_menu":6,"count":2}]	46433	delivery	5	14
131583	2020-09-01 22:05:10	2020-09-01	40	[{"id_menu":2,"count":1},{"id_menu":4,"count":1},{"id_menu":6,"count":1}]	3616	delivery	5	45
131584	2020-09-01 22:05:32	2020-09-01	31	[{"id_menu":2,"count":2},{"id_menu":5,"count":1},{"id_menu":7,"count":1}]	49495	delivery	5	36
131585	2020-09-01 22:08:29	2020-09-01	22	[{"id_menu":2,"count":1},{"id_menu":5,"count":2}]	25252	pick-up	0	22
131586	2020-09-01 22:09:42	2020-09-01	26	[{"id_menu":5,"count":1},{"id_menu":6,"count":2},{"id_menu":7,"count":1}]	36273	delivery	5	31
131587	2020-09-01 22:10:25	2020-09-01	29	[{"id_menu":3,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	28390	delivery	5	34
131588	2020-09-01 22:10:46	2020-09-01	12	[{"id_menu":1,"count":1}]	49463	delivery	5	17
131589	2020-09-01 22:13:21	2020-09-01	17	[{"id_menu":5,"count":2},{"id_menu":7,"count":1}]	49625	delivery	5	22
131590	2020-09-01 22:16:44	2020-09-01	9	[{"id_menu":6,"count":1}]	4681	pick-up	0	9
131591	2020-09-01 22:16:51	2020-09-01	8	[{"id_menu":5,"count":1}]	39115	delivery	5	13
131592	2020-09-01 22:18:58	2020-09-01	12	[{"id_menu":3,"count":1}]	287	pick-up	0	12
131593	2020-09-01 22:24:07	2020-09-01	9	[{"id_menu":6,"count":1}]	8241	delivery	5	14
131594	2020-09-01 22:25:09	2020-09-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	38124	delivery	5	28
131595	2020-09-01 22:26:04	2020-09-01	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":1}]	32998	delivery	5	42
131596	2020-09-01 22:27:14	2020-09-01	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	49449	pick-up	0	29
131597	2020-09-01 22:29:04	2020-09-01	20	[{"id_menu":3,"count":2},{"id_menu":5,"count":1}]	49442	delivery	5	25
131598	2020-09-01 22:29:36	2020-09-01	9	[{"id_menu":6,"count":1}]	49547	delivery	5	14
131599	2020-09-01 22:31:01	2020-09-01	12	[{"id_menu":1,"count":1}]	49355	delivery	5	17
131600	2020-09-01 22:31:36	2020-09-01	17	[{"id_menu":4,"count":1}]	33645	delivery	5	22
131601	2020-09-01 22:31:54	2020-09-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	19876	delivery	5	28
131602	2020-09-01 22:33:54	2020-09-01	32	[{"id_menu":2,"count":1},{"id_menu":6,"count":1},{"id_menu":7,"count":2}]	8675	delivery	5	37
131603	2020-09-01 22:34:22	2020-09-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":1}]	42317	delivery	5	28
131604	2020-09-01 22:35:51	2020-09-01	23	[{"id_menu":2,"count":1},{"id_menu":6,"count":2}]	31787	delivery	5	28
131605	2020-09-01 22:37:47	2020-09-01	9	[{"id_menu":6,"count":1}]	49556	delivery	5	14
131606	2020-09-01 22:38:16	2020-09-01	9	[{"id_menu":6,"count":3}]	42920	delivery	5	14
131607	2020-09-01 22:46:31	2020-09-01	29	[{"id_menu":1,"count":1},{"id_menu":4,"count":1}]	49561	delivery	5	34
131608	2020-09-01 22:46:45	2020-09-01	9	[{"id_menu":6,"count":2}]	49424	delivery	5	14
131609	2020-09-01 22:47:17	2020-09-01	17	[{"id_menu":4,"count":1}]	30946	delivery	5	22
131610	2020-09-01 22:52:50	2020-09-01	20	[{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	31989	delivery	5	25
131611	2020-09-01 22:57:05	2020-09-01	12	[{"id_menu":1,"count":1}]	49359	delivery	5	17
131612	2020-09-01 22:57:40	2020-09-01	9	[{"id_menu":7,"count":1}]	49416	delivery	5	14
131613	2020-09-01 22:59:46	2020-09-01	34	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":5,"count":1}]	49574	delivery	5	39
131614	2020-09-01 23:02:43	2020-09-01	26	[{"id_menu":4,"count":1},{"id_menu":7,"count":1}]	33808	delivery	5	31
131615	2020-09-01 23:03:40	2020-09-01	34	[{"id_menu":4,"count":1},{"id_menu":5,"count":1},{"id_menu":6,"count":1}]	22790	delivery	5	39
131616	2020-09-01 23:06:32	2020-09-01	23	[{"id_menu":2,"count":1},{"id_menu":7,"count":1}]	49414	delivery	5	28
131617	2020-09-01 23:07:46	2020-09-01	17	[{"id_menu":4,"count":1}]	45705	delivery	5	22
131618	2020-09-01 23:08:52	2020-09-01	17	[{"id_menu":4,"count":1}]	20874	delivery	5	22
131619	2020-09-01 23:10:58	2020-09-01	9	[{"id_menu":6,"count":1}]	23379	delivery	5	14
131620	2020-09-01 23:11:28	2020-09-01	9	[{"id_menu":6,"count":2}]	49595	delivery	5	14
131621	2020-09-01 23:15:27	2020-09-01	14	[{"id_menu":2,"count":1}]	11961	delivery	5	19
131622	2020-09-01 23:18:46	2020-09-01	9	[{"id_menu":7,"count":3}]	49491	delivery	5	14
131623	2020-09-01 23:19:57	2020-09-01	12	[{"id_menu":3,"count":1}]	39739	delivery	5	17
131624	2020-09-01 23:20:45	2020-09-01	9	[{"id_menu":6,"count":1}]	49451	delivery	5	14
131625	2020-09-01 23:21:12	2020-09-01	9	[{"id_menu":6,"count":1}]	29283	delivery	5	14
131626	2020-09-01 23:22:36	2020-09-01	9	[{"id_menu":7,"count":1}]	36828	delivery	5	14
131627	2020-09-01 23:31:33	2020-09-01	17	[{"id_menu":4,"count":1}]	47096	delivery	5	22
131628	2020-09-01 23:32:59	2020-09-01	9	[{"id_menu":7,"count":1}]	13827	delivery	5	14
131629	2020-09-01 23:35:19	2020-09-01	9	[{"id_menu":6,"count":1}]	21667	delivery	5	14
131630	2020-09-01 23:36:55	2020-09-01	12	[{"id_menu":3,"count":1}]	17519	delivery	5	17
131631	2020-09-01 23:38:29	2020-09-01	9	[{"id_menu":7,"count":1}]	49379	delivery	5	14
131632	2020-09-01 23:41:55	2020-09-01	14	[{"id_menu":2,"count":1}]	4730	delivery	5	19
131633	2020-09-01 23:46:02	2020-09-01	14	[{"id_menu":2,"count":1}]	49487	delivery	5	19
131634	2020-09-01 23:47:58	2020-09-01	37	[{"id_menu":1,"count":1},{"id_menu":4,"count":1},{"id_menu":5,"count":2}]	49490	pick-up	0	37
131635	2020-09-01 23:48:51	2020-09-01	9	[{"id_menu":6,"count":1}]	24045	delivery	5	14
131636	2020-09-01 23:51:22	2020-09-01	12	[{"id_menu":3,"count":1}]	3688	delivery	5	17
131637	2020-09-01 23:52:11	2020-09-01	14	[{"id_menu":2,"count":1}]	49599	pick-up	0	14
131638	2020-09-01 23:58:00	2020-09-01	12	[{"id_menu":3,"count":1}]	45256	delivery	5	17
131639	2020-09-01 23:59:53	2020-09-01	35	[{"id_menu":2,"count":1},{"id_menu":3,"count":1},{"id_menu":7,"count":1}]	22841	delivery	5	40
\.


--
-- Data for Name: reviews; Type: TABLE DATA; Schema: public; Owner: -
--

COPY public.reviews (id_review, star_rating, id_order, id_menu, id_user) FROM stdin;
1	4	4	5	72
2	5	5	4	15
3	3	8	3	35
4	3	10	4	67
5	5	11	2	11
6	5	19	1	9
7	4	21	2	49
8	3	22	1	1
9	5	27	2	22
10	5	28	2	70
11	4	31	3	68
12	5	32	5	74
13	5	36	2	16
14	4	44	7	45
15	5	47	3	4
16	4	48	3	51
17	3	50	2	77
18	4	54	4	60
19	3	56	5	80
20	4	57	6	119
21	5	58	3	114
22	4	60	3	116
23	5	60	6	116
24	5	65	2	117
25	4	68	2	122
26	4	69	4	99
27	5	70	4	112
28	5	71	6	108
29	5	75	4	103
30	5	76	1	85
31	4	77	7	104
32	4	78	2	82
33	5	79	2	94
34	5	81	4	91
35	3	87	5	102
36	4	92	3	89
37	1	96	3	84
38	5	96	6	84
39	5	105	6	159
40	3	109	5	137
41	4	111	7	151
42	2	118	4	143
43	5	119	1	134
44	5	123	2	149
45	5	125	3	130
46	5	126	3	41
47	4	127	1	141
48	4	128	7	140
49	5	129	7	139
50	5	135	1	178
51	3	138	4	182
52	5	148	1	169
53	5	151	3	160
54	5	151	1	160
55	5	155	4	200
56	5	156	4	215
57	3	157	1	191
58	5	160	3	192
59	4	161	1	206
60	5	165	1	207
61	3	173	7	212
62	5	174	7	209
63	5	175	1	194
64	3	176	4	202
65	5	182	3	236
66	5	183	1	153
67	3	187	3	226
68	5	189	1	222
69	3	192	7	231
70	3	198	3	99
71	5	204	2	232
72	5	206	6	235
73	4	209	7	225
74	5	211	2	37
75	5	214	5	6
76	5	217	4	169
77	5	226	4	263
78	3	228	5	257
79	3	229	7	256
80	5	230	1	254
81	5	231	1	258
82	4	232	6	111
83	3	242	7	122
84	3	243	3	92
85	5	244	4	282
86	5	248	1	48
87	5	252	5	279
88	4	257	1	283
89	5	259	1	278
90	4	260	5	281
91	5	267	4	287
92	5	273	3	66
93	4	277	5	306
94	5	282	6	301
95	5	284	2	299
96	3	289	1	304
97	3	292	5	319
98	5	293	7	232
99	5	294	2	321
100	4	295	2	313
101	4	296	7	311
102	4	310	1	328
103	4	313	3	332
104	2	314	6	226
105	5	316	3	330
106	3	317	7	212
107	5	322	4	341
108	4	327	7	336
109	5	329	3	340
110	4	332	7	281
111	5	334	1	342
112	5	335	6	173
113	3	336	4	344
114	4	337	1	44
115	5	338	3	226
116	5	342	3	347
117	4	356	4	227
118	4	358	7	358
119	5	360	7	351
120	4	362	5	83
121	5	363	1	89
122	5	365	7	44
123	5	369	2	361
124	5	374	1	360
125	5	375	7	366
126	5	378	2	367
127	4	381	1	370
128	5	382	2	71
129	5	390	6	338
130	5	399	3	246
131	4	402	4	384
132	4	404	2	386
133	3	405	1	135
134	4	407	5	385
135	4	410	6	382
136	5	412	7	383
137	5	413	4	245
138	3	416	7	377
139	4	417	7	357
140	5	421	5	292
141	4	424	1	197
142	5	425	6	111
143	5	426	1	48
144	5	428	4	404
145	4	432	2	215
146	5	432	3	215
147	5	436	2	398
148	5	441	4	74
149	5	450	6	62
150	5	458	1	30
151	5	462	4	412
152	4	468	3	330
153	5	469	2	310
154	4	475	1	92
155	4	479	6	330
156	3	480	3	428
157	4	481	4	430
158	4	484	2	170
159	4	486	2	27
160	4	486	7	27
161	5	489	4	437
162	5	498	4	352
163	4	501	5	401
164	3	510	1	431
165	3	511	4	78
166	5	518	2	444
167	1	521	3	44
168	5	534	3	451
169	5	536	7	226
170	5	539	2	455
171	5	540	6	456
172	5	543	5	454
173	4	545	7	270
174	5	550	2	428
175	3	551	5	219
176	5	553	7	382
177	4	555	1	457
178	5	556	3	80
179	5	558	7	191
180	4	562	6	464
181	3	563	5	461
182	5	563	6	461
183	5	565	1	428
184	4	566	7	463
185	2	566	4	463
186	5	567	4	153
187	5	568	6	387
188	5	574	3	456
189	5	580	4	465
190	5	584	6	136
191	5	589	6	472
192	2	590	4	285
193	4	591	7	338
194	5	593	5	470
195	5	597	2	476
196	5	601	2	477
197	4	603	7	265
198	1	613	2	382
199	4	615	1	481
200	5	617	4	299
201	5	618	4	66
202	3	621	5	484
203	5	621	6	484
204	4	623	6	197
205	5	625	1	483
206	3	626	1	399
207	4	627	1	86
208	5	633	6	56
209	5	637	4	125
210	4	638	2	487
211	4	641	2	107
212	5	647	6	390
213	4	652	5	292
214	3	661	7	391
215	4	662	3	96
216	2	669	1	214
217	3	678	7	502
218	5	679	1	437
219	5	680	1	323
220	5	684	7	507
221	4	686	1	171
222	5	689	1	508
223	4	692	1	158
224	5	696	3	513
225	5	699	7	64
226	5	700	6	514
227	5	701	7	227
228	2	702	6	316
229	4	708	2	378
230	5	709	5	464
231	5	713	4	229
232	5	714	3	213
233	3	717	3	518
234	4	721	5	379
235	5	721	1	379
236	4	722	1	440
237	4	727	5	521
238	5	728	5	489
239	5	730	4	522
240	5	732	4	152
241	5	737	7	529
242	4	738	7	462
243	5	740	2	213
244	5	756	6	482
245	5	757	2	528
246	5	764	4	228
247	5	765	2	484
248	5	766	3	257
249	4	770	7	538
250	4	774	2	466
251	3	775	4	541
252	3	782	1	126
253	5	786	2	96
254	1	787	4	113
255	4	790	3	548
256	5	793	4	546
257	5	798	4	271
258	3	800	5	551
259	5	802	7	552
260	5	804	2	554
261	5	805	3	311
262	3	806	3	443
263	4	813	4	556
264	5	814	3	560
265	5	816	6	150
266	5	818	6	54
267	5	819	3	270
268	5	820	3	561
269	4	826	7	544
270	5	828	2	408
271	4	829	5	562
272	5	833	1	528
273	5	834	4	44
274	4	836	6	567
275	3	837	5	226
276	4	839	5	213
277	5	841	6	383
278	1	844	5	68
279	3	845	5	335
280	4	849	5	247
281	5	849	6	247
282	4	854	5	397
283	5	855	2	531
284	5	857	1	570
285	1	859	6	376
286	4	864	5	217
287	5	872	6	173
288	5	873	7	227
289	5	874	6	577
290	5	882	2	31
291	2	885	6	581
292	5	889	7	113
293	3	893	5	203
294	5	895	1	519
295	3	897	7	440
296	5	901	2	588
297	5	903	5	135
298	4	904	7	27
299	3	905	3	586
300	5	908	2	173
301	5	913	5	590
302	5	916	4	431
303	5	918	3	21
304	4	919	6	464
305	4	920	4	595
306	5	923	5	593
307	4	924	4	583
308	5	928	2	418
309	5	930	2	599
310	5	934	6	543
311	1	936	2	601
312	5	937	5	397
313	2	938	1	607
314	5	939	1	437
315	5	939	4	437
316	5	940	6	352
317	4	942	4	605
318	5	948	2	602
319	1	950	6	606
320	3	951	7	271
321	5	955	6	604
322	4	956	4	608
323	5	958	4	226
324	3	959	5	281
325	3	962	3	526
326	5	967	3	612
327	4	968	4	430
328	3	970	3	613
329	5	972	4	610
330	3	973	5	48
331	3	979	2	89
332	5	983	1	543
333	3	984	1	615
334	5	992	6	563
335	5	996	1	625
336	3	1002	6	477
337	5	1006	3	264
338	5	1007	2	629
339	1	1013	5	631
340	5	1015	7	635
341	4	1016	5	633
342	5	1019	7	590
343	5	1021	1	293
344	4	1026	1	17
345	3	1030	2	189
346	5	1034	7	227
347	4	1035	7	640
348	4	1036	6	92
349	5	1038	2	378
350	2	1039	1	648
351	2	1040	6	73
352	4	1041	7	645
353	5	1045	2	359
354	5	1054	3	456
355	5	1055	6	340
356	4	1057	7	650
357	5	1060	1	122
358	5	1070	2	377
359	3	1072	1	123
360	4	1074	3	552
361	3	1079	7	546
362	3	1081	5	208
363	5	1082	6	376
364	3	1083	7	658
365	5	1084	2	149
366	5	1086	6	311
367	4	1093	7	659
368	1	1095	6	24
369	5	1097	4	105
370	3	1102	4	666
371	5	1103	1	546
372	5	1105	5	197
373	3	1108	1	552
374	5	1108	7	552
375	5	1110	7	675
376	5	1112	3	673
377	4	1116	5	672
378	5	1117	7	671
379	5	1120	3	6
380	5	1121	4	270
381	2	1126	6	681
382	4	1126	7	681
383	5	1128	2	482
384	4	1132	3	655
385	4	1135	3	677
386	4	1145	7	170
387	5	1149	6	437
388	5	1152	6	381
389	5	1154	2	685
390	5	1155	4	223
391	3	1156	1	682
392	4	1159	6	693
393	4	1168	1	555
394	5	1168	3	555
395	5	1170	3	691
396	5	1170	2	691
397	4	1181	7	635
398	4	1182	6	701
399	4	1189	6	306
400	5	1194	1	661
401	1	1195	6	691
402	5	1200	4	640
403	3	1203	3	703
404	5	1208	3	699
405	5	1210	6	705
406	5	1211	1	710
407	4	1212	2	670
408	4	1213	1	486
409	3	1214	3	482
410	5	1215	5	249
411	5	1216	6	304
412	5	1222	5	711
413	5	1225	2	149
414	5	1231	4	634
415	3	1233	4	628
416	5	1233	6	628
417	4	1235	2	434
418	4	1237	6	717
419	5	1238	1	722
420	5	1239	7	707
421	5	1242	2	169
422	3	1243	1	207
423	5	1245	7	718
424	3	1246	5	720
425	4	1248	7	375
426	5	1257	2	723
427	4	1259	6	503
428	5	1260	6	527
429	3	1269	3	624
430	4	1272	1	727
431	4	1274	4	534
432	5	1275	6	683
433	3	1278	5	726
434	5	1280	6	730
435	5	1281	7	732
436	3	1282	5	546
437	5	1284	3	186
438	4	1285	5	634
439	3	1288	7	712
440	3	1290	4	731
441	5	1294	6	733
442	5	1298	4	21
443	5	1299	7	736
444	5	1300	5	742
445	3	1304	3	601
446	4	1305	5	373
447	4	1306	6	741
448	5	1307	6	560
449	3	1312	1	738
450	5	1315	3	398
451	5	1315	6	398
452	5	1316	6	361
453	3	1320	7	748
454	4	1322	7	72
455	5	1324	4	711
456	5	1325	6	660
457	3	1328	4	741
458	5	1329	3	719
459	5	1331	6	371
460	3	1333	2	750
461	5	1334	2	3
462	4	1335	7	511
463	4	1340	7	256
464	5	1341	5	44
465	3	1342	3	123
466	5	1343	6	753
467	5	1344	2	48
468	4	1362	7	764
469	5	1362	3	764
470	5	1364	2	154
471	5	1367	1	304
472	3	1374	1	482
473	5	1375	4	769
474	3	1377	1	770
475	4	1378	5	597
476	4	1379	7	390
477	5	1381	3	765
478	3	1383	4	267
479	5	1386	5	491
480	5	1387	6	768
481	5	1391	7	71
482	5	1392	7	774
483	3	1400	2	363
484	1	1403	4	209
485	5	1405	1	147
486	5	1413	5	773
487	5	1414	7	315
488	4	1417	7	57
489	5	1418	4	48
490	3	1421	5	676
491	2	1426	3	786
492	5	1428	7	623
493	5	1429	1	346
494	4	1432	1	477
495	4	1435	4	350
496	4	1436	4	793
497	4	1446	7	377
498	5	1448	4	792
499	4	1453	1	790
500	5	1456	3	126
501	5	1460	1	647
502	5	1462	4	245
503	5	1463	1	360
504	3	1465	5	706
505	4	1477	5	797
506	3	1478	3	229
507	5	1485	4	340
508	3	1486	4	376
509	5	1492	6	177
510	4	1493	3	807
511	5	1496	7	666
512	5	1502	6	709
513	5	1503	3	816
514	1	1505	7	749
515	4	1514	2	812
516	5	1517	6	823
517	5	1519	2	310
518	5	1524	3	713
519	4	1529	4	822
520	3	1531	2	826
521	4	1532	2	831
522	3	1533	5	482
523	4	1536	7	308
524	5	1552	5	613
525	3	1554	1	802
526	5	1559	6	438
527	5	1561	3	313
528	5	1563	2	838
529	5	1567	4	126
530	4	1568	1	721
531	4	1571	3	837
532	5	1572	6	834
533	5	1579	3	677
534	3	1582	2	779
535	4	1585	2	193
536	5	1587	7	729
537	5	1589	5	157
538	3	1590	5	123
539	5	1591	3	847
540	5	1594	6	751
541	5	1597	4	396
542	4	1599	3	756
543	5	1600	1	846
544	3	1602	5	143
545	5	1602	6	143
546	5	1604	1	154
547	5	1605	1	332
548	5	1607	5	337
549	1	1612	7	97
550	5	1615	5	383
551	5	1616	7	203
552	3	1618	4	439
553	4	1628	1	856
554	5	1630	1	851
555	5	1635	7	640
556	5	1639	6	561
557	5	1640	1	863
558	4	1645	5	684
559	5	1648	1	99
560	4	1649	5	601
561	4	1654	5	519
562	5	1656	4	708
563	3	1665	5	731
564	5	1667	7	879
565	5	1676	6	204
566	5	1676	1	204
567	4	1683	4	425
568	5	1683	7	425
569	3	1684	1	884
570	4	1687	1	871
571	5	1689	2	880
572	5	1690	7	887
573	3	1698	5	806
574	5	1707	5	66
575	5	1708	7	891
576	5	1712	2	140
577	4	1713	7	895
578	5	1716	2	896
579	4	1722	7	889
580	4	1723	1	64
581	4	1727	1	414
582	4	1728	1	612
583	4	1731	1	902
584	3	1732	1	493
585	3	1735	7	901
586	5	1742	7	638
587	4	1743	5	19
588	3	1749	4	719
589	5	1750	2	913
590	5	1753	4	677
591	3	1758	6	876
592	4	1760	5	911
593	4	1762	1	626
594	4	1765	4	905
595	3	1767	3	524
596	5	1768	7	837
597	3	1769	4	150
598	4	1770	3	912
599	5	1774	3	907
600	5	1776	2	659
601	5	1778	6	520
602	4	1783	3	236
603	5	1786	6	709
604	5	1788	4	707
605	5	1789	4	113
606	4	1796	3	920
607	4	1799	7	575
608	3	1800	1	790
609	5	1801	2	695
610	5	1802	6	923
611	5	1803	1	261
612	4	1808	4	493
613	3	1808	1	493
614	3	1810	1	880
615	4	1815	5	314
616	3	1825	6	936
617	5	1827	1	932
618	4	1828	5	173
619	5	1831	6	856
620	5	1832	6	937
621	5	1835	5	935
622	2	1839	1	709
623	5	1842	6	33
624	3	1843	5	714
625	5	1845	2	553
626	5	1848	4	790
627	5	1849	2	518
628	5	1852	6	945
629	3	1853	1	75
630	4	1856	3	135
631	1	1856	6	135
632	3	1861	7	782
633	1	1864	6	943
634	3	1867	3	939
635	5	1869	7	944
636	5	1870	3	209
637	5	1871	2	260
638	5	1872	2	81
639	5	1873	2	493
640	4	1877	4	537
641	4	1877	3	537
642	3	1878	7	425
643	5	1882	1	763
644	5	1885	5	584
645	4	1891	7	401
646	4	1892	6	950
647	4	1893	4	643
648	4	1895	7	962
649	3	1898	1	477
650	3	1903	5	960
651	5	1903	1	960
652	5	1904	7	448
653	3	1910	5	961
654	5	1912	6	956
655	3	1917	3	95
656	5	1918	5	228
657	5	1919	3	889
658	4	1926	1	546
659	3	1927	3	959
660	5	1929	3	501
661	5	1931	7	764
662	5	1931	5	764
663	5	1932	4	126
664	5	1933	2	190
665	2	1935	6	966
666	4	1939	1	968
667	4	1941	7	969
668	2	1951	7	528
669	4	1954	7	599
670	4	1956	1	655
671	3	1962	5	292
672	4	1962	7	292
673	5	1963	2	640
674	1	1966	7	406
675	5	1972	6	136
676	5	1974	4	979
677	3	1974	5	979
678	5	1975	6	982
679	4	1977	5	983
680	5	1979	4	295
681	5	1980	2	166
682	4	1981	6	985
683	5	1982	1	187
684	4	1984	7	601
685	4	1986	2	837
686	4	1991	1	993
687	5	1994	6	992
688	2	1995	1	665
689	5	2003	4	48
690	5	2009	6	995
691	5	2019	1	1000
692	3	2020	2	691
693	5	2021	2	379
694	4	2022	1	148
695	5	2023	6	280
696	5	2028	2	749
697	5	2030	4	998
698	4	2032	2	1005
699	5	2033	4	1006
700	4	2041	5	880
701	2	2041	4	880
702	1	2044	6	82
703	5	2051	2	424
704	5	2053	2	1010
705	4	2054	7	1007
706	5	2055	1	571
707	4	2056	7	1009
708	5	2062	2	281
709	5	2064	2	834
710	3	2066	3	707
711	5	2067	5	508
712	3	2068	1	1022
713	4	2073	2	907
714	5	2077	4	360
715	5	2079	2	701
716	4	2081	5	1019
717	4	2083	3	990
718	3	2084	2	1018
719	3	2093	3	614
720	5	2098	6	271
721	3	2099	5	233
722	4	2101	5	1035
723	5	2102	3	1034
724	3	2103	2	583
725	5	2110	5	173
726	5	2113	3	1029
727	4	2116	5	422
728	5	2119	1	34
729	4	2121	7	48
730	5	2124	2	227
731	3	2125	1	378
732	5	2126	6	1042
733	4	2130	5	44
734	5	2131	4	1036
735	5	2136	1	799
736	4	2138	7	925
737	5	2138	3	925
738	5	2140	5	1041
739	3	2142	5	58
740	5	2144	6	868
741	3	2146	7	1046
742	3	2154	6	744
743	4	2155	7	581
744	4	2158	7	1055
745	5	2160	7	1038
746	5	2161	3	1060
747	5	2165	2	338
748	4	2166	3	610
749	3	2168	4	1058
750	5	2171	3	237
751	5	2175	2	1056
752	4	2177	7	150
753	5	2182	6	149
754	5	2186	4	656
755	5	2186	5	656
756	5	2187	1	204
757	5	2196	3	1040
758	5	2197	2	788
759	5	2199	2	1064
760	4	2200	1	29
761	5	2207	7	950
762	3	2214	4	485
763	5	2220	4	207
764	4	2220	7	207
765	3	2224	1	799
766	5	2229	1	626
767	1	2232	6	871
768	4	2242	3	839
769	5	2243	2	630
770	1	2248	6	536
771	5	2249	1	1084
772	3	2250	7	1091
773	4	2252	7	461
774	5	2253	6	958
775	4	2255	7	708
776	4	2258	2	1083
777	5	2260	4	757
778	5	2261	6	1088
779	5	2267	2	203
780	5	2271	3	626
781	5	2276	4	424
782	5	2278	4	640
783	5	2285	1	1016
784	5	2286	1	1101
785	4	2287	6	378
786	3	2288	2	1097
787	5	2292	5	919
788	2	2297	3	66
789	5	2301	3	1093
790	1	2303	7	867
791	5	2307	5	808
792	5	2310	4	586
793	5	2311	6	1100
794	5	2312	5	1099
795	4	2312	4	1099
796	5	2313	7	1098
797	5	2315	4	343
798	3	2316	7	1109
799	3	2319	5	376
800	4	2324	2	1104
801	5	2328	3	1041
802	5	2330	4	701
803	3	2332	1	1111
804	4	2336	2	638
805	5	2337	6	233
806	5	2342	1	1112
807	4	2342	2	1112
808	5	2343	3	1119
809	3	2346	7	1117
810	4	2347	1	905
811	5	2351	5	253
812	4	2357	5	1021
813	3	2358	2	1115
814	4	2362	5	627
815	4	2364	7	215
816	4	2364	2	215
817	5	2366	6	411
818	5	2366	3	411
819	5	2368	6	1122
820	5	2369	7	1129
821	1	2372	6	1121
822	5	2375	1	437
823	5	2375	3	437
824	4	2378	2	193
825	4	2380	7	626
826	4	2390	5	458
827	5	2393	2	93
828	5	2395	6	41
829	4	2402	7	591
830	4	2403	7	543
831	5	2409	5	772
832	4	2412	4	567
833	4	2415	7	1110
834	4	2417	1	1137
835	5	2418	5	832
836	4	2420	4	621
837	4	2422	3	171
838	5	2423	3	964
839	4	2424	3	362
840	4	2426	5	1149
841	5	2428	6	318
842	5	2428	5	318
843	3	2429	7	999
844	5	2431	2	274
845	4	2432	2	1139
846	4	2432	3	1139
847	5	2434	6	563
848	5	2435	4	557
849	5	2436	4	630
850	5	2437	6	1144
851	1	2438	6	440
852	5	2438	4	440
853	5	2441	7	676
854	3	2444	2	1156
855	5	2449	1	481
856	4	2450	7	1157
857	1	2455	6	653
858	5	2455	7	653
859	5	2456	6	359
860	3	2459	4	527
861	4	2460	7	197
862	3	2461	7	1151
863	5	2462	1	154
864	4	2463	5	41
865	4	2464	7	1159
866	5	2465	7	29
867	5	2467	2	1153
868	5	2468	2	108
869	4	2468	7	108
870	5	2472	2	506
871	5	2476	6	787
872	5	2480	6	293
873	5	2484	4	418
874	4	2487	5	669
875	4	2490	2	1163
876	5	2493	6	285
877	5	2494	6	677
878	5	2495	5	688
879	4	2499	6	1171
880	3	2501	5	847
881	5	2511	6	1166
882	2	2516	6	440
883	4	2518	1	1167
884	5	2519	3	1164
885	5	2521	1	78
886	5	2524	2	41
887	5	2529	4	1176
888	5	2532	4	74
889	2	2534	6	1186
890	5	2538	2	714
891	2	2539	1	1014
892	5	2547	4	667
893	4	2550	7	1173
894	4	2555	7	1195
895	5	2556	5	527
896	5	2558	6	660
897	3	2559	3	796
898	5	2561	6	81
899	3	2562	7	817
900	5	2564	4	1191
901	3	2566	4	1199
902	5	2578	2	1143
903	5	2582	7	518
904	5	2583	6	950
905	5	2587	7	399
906	5	2589	5	602
907	5	2590	4	325
908	5	2605	6	950
909	5	2618	4	467
910	5	2620	1	1212
911	4	2621	4	963
912	5	2623	2	371
913	5	2624	2	1115
914	3	2631	5	1213
915	3	2643	7	333
916	5	2644	4	171
917	5	2648	2	189
918	5	2650	6	443
919	3	2650	7	443
920	4	2655	1	628
921	5	2655	4	628
922	5	2659	4	233
923	4	2662	5	575
924	4	2670	7	748
925	4	2670	3	748
926	5	2676	1	1211
927	5	2678	5	798
928	4	2682	5	763
929	5	2685	2	925
930	5	2688	2	1227
931	5	2691	1	1223
932	5	2693	2	1222
933	5	2694	5	1128
934	5	2696	5	4
935	4	2699	7	1238
936	3	2700	4	285
937	5	2709	2	609
938	5	2715	2	148
939	5	2719	2	466
940	5	2721	5	754
941	5	2722	4	1239
942	5	2726	2	126
943	4	2729	1	995
944	5	2730	6	832
945	5	2731	3	981
946	5	2734	2	1231
947	5	2740	6	970
948	5	2742	4	519
949	5	2747	2	802
950	3	2748	4	477
951	3	2749	7	1155
952	3	2750	3	1092
953	5	2754	6	901
954	4	2757	1	322
955	3	2760	5	821
956	5	2764	7	1247
957	5	2778	2	292
958	5	2778	6	292
959	5	2779	2	440
960	5	2780	6	1211
961	3	2781	1	1155
962	5	2783	2	895
963	5	2786	4	1260
964	3	2788	6	480
965	5	2789	2	786
966	3	2793	4	1256
967	4	2799	5	1269
968	5	2803	3	536
969	5	2805	6	806
970	5	2809	4	1253
971	4	2811	5	590
972	4	2813	3	270
973	5	2815	1	1261
974	5	2817	1	1075
975	5	2818	2	1268
976	4	2822	7	1266
977	4	2823	4	122
978	3	2829	7	1137
979	3	2830	5	601
980	5	2842	7	239
981	4	2845	7	1273
982	5	2847	7	1023
983	5	2850	2	748
984	5	2852	1	400
985	5	2853	6	796
986	5	2855	6	1214
987	1	2858	4	83
988	5	2863	3	1284
989	5	2864	1	381
990	5	2865	2	997
991	5	2868	1	765
992	5	2873	6	260
993	5	2874	4	832
994	5	2878	5	1285
995	4	2879	3	679
996	5	2880	7	1147
997	4	2881	4	394
998	3	2882	4	449
999	1	2883	6	1290
1000	5	2890	2	1294
1001	4	2891	4	1301
1002	4	2897	4	233
1003	4	2898	4	162
1004	3	2901	4	1298
1005	4	2902	2	1297
1006	5	2902	4	1297
1007	4	2904	6	177
1008	4	2905	2	1233
1009	3	2915	3	1300
1010	5	2917	7	396
1011	3	2920	5	1291
1012	3	2921	3	1293
1013	5	2930	7	862
1014	5	2936	3	1307
1015	5	2940	3	563
1016	5	2941	5	458
1017	5	2942	6	1304
1018	5	2945	5	719
1019	4	2947	5	1310
1020	5	2949	6	1075
1021	2	2949	1	1075
1022	4	2950	5	1315
1023	2	2952	1	634
1024	3	2953	3	1308
1025	3	2961	4	446
1026	2	2962	6	946
1027	5	2964	1	831
1028	5	2965	4	381
1029	4	2967	5	639
1030	5	2968	6	495
1031	4	2970	5	409
1032	2	2971	3	663
1033	2	2972	6	654
1034	4	2975	1	1324
1035	5	2980	6	467
1036	5	2981	1	408
1037	3	2982	5	1319
1038	4	2988	7	730
1039	4	2990	7	1322
1040	5	2991	3	292
1041	5	2996	4	591
1042	5	3002	1	721
1043	5	3003	2	1332
1044	5	3007	2	228
1045	5	3012	6	1254
1046	5	3013	6	1333
1047	3	3013	2	1333
1048	4	3014	2	678
1049	2	3018	1	1309
1050	4	3021	6	1341
1051	4	3025	1	680
1052	4	3026	7	802
1053	5	3027	1	1340
1054	5	3028	1	120
1055	5	3031	7	1034
1056	5	3033	5	1336
1057	5	3035	4	721
1058	5	3036	3	134
1059	5	3038	3	996
1060	5	3039	3	1343
1061	5	3040	7	1183
1062	4	3043	4	1302
1063	1	3045	6	1338
1064	4	3046	1	981
1065	5	3047	1	1280
1066	5	3049	6	213
1067	4	3050	1	1317
1068	4	3052	2	935
1069	5	3054	1	757
1070	4	3054	6	757
1071	4	3060	5	1352
1072	5	3064	6	1347
1073	5	3067	6	1293
1074	5	3071	7	1346
1075	5	3073	3	1348
1076	5	3082	6	1085
1077	5	3087	7	1358
1078	4	3095	6	721
1079	4	3096	4	676
1080	3	3099	3	735
1081	5	3100	3	1363
1082	4	3103	3	1337
1083	3	3107	7	226
1084	4	3109	1	260
1085	5	3111	6	245
1086	3	3115	5	169
1087	5	3118	2	1376
1088	5	3119	3	101
1089	3	3121	4	1374
1090	4	3129	3	1159
1091	4	3130	6	150
1092	4	3135	2	377
1093	4	3136	6	576
1094	4	3141	4	382
1095	4	3142	3	236
1096	2	3150	1	1262
1097	5	3151	3	1051
1098	4	3152	1	1377
1099	5	3153	2	371
1100	5	3156	4	1384
1101	4	3161	6	1391
1102	5	3162	6	172
1103	5	3164	6	1339
1104	5	3165	2	1277
1105	5	3168	6	473
1106	5	3171	2	1389
1107	5	3180	7	293
1108	3	3188	1	226
1109	5	3196	2	29
1110	4	3197	2	1223
1111	4	3204	7	790
1112	4	3205	7	1229
1113	5	3207	4	76
1114	5	3208	7	989
1115	1	3210	4	1399
1116	5	3211	3	1402
1117	5	3215	6	1401
1118	4	3219	4	241
1119	5	3220	1	16
1120	4	3220	6	16
1121	5	3222	7	582
1122	4	3225	7	1393
1123	5	3229	2	860
1124	4	3230	1	1411
1125	5	3248	1	630
1126	4	3250	7	1269
1127	1	3251	6	1416
1128	3	3252	4	1418
1129	4	3255	3	1419
1130	5	3255	7	1419
1131	4	3256	1	1352
1132	5	3260	1	1203
1133	5	3264	6	1056
1134	4	3269	7	925
1135	5	3270	6	1420
1136	3	3271	4	479
1137	3	3274	7	1012
1138	5	3276	1	599
1139	4	3278	4	424
1140	3	3281	5	1433
1141	4	3282	3	260
1142	3	3282	5	260
1143	5	3283	5	500
1144	3	3285	5	1079
1145	4	3292	3	1174
1146	5	3295	2	676
1147	4	3299	7	289
1148	5	3300	4	1429
1149	3	3301	2	764
1150	5	3306	4	87
1151	3	3306	7	87
1152	5	3307	2	1435
1153	5	3309	4	254
1154	5	3310	1	933
1155	3	3311	4	538
1156	3	3312	4	1255
1157	5	3321	4	1447
1158	4	3329	5	1442
1159	4	3330	7	1446
1160	4	3331	1	144
1161	5	3334	1	584
1162	5	3337	5	628
1163	2	3340	6	62
1164	5	3343	6	1302
1165	5	3344	2	821
1166	5	3349	2	1209
1167	5	3350	4	1004
1168	4	3354	7	593
1169	4	3356	6	73
1170	5	3368	7	415
1171	4	3373	2	1245
1172	5	3376	4	1451
1173	5	3377	2	1450
1174	5	3380	4	1355
1175	3	3385	5	1445
1176	4	3387	2	633
1177	3	3393	4	857
1178	5	3395	6	169
1179	4	3395	5	169
1180	3	3396	5	1464
1181	5	3396	2	1464
1182	5	3398	6	1472
1183	5	3399	7	906
1184	5	3400	3	172
1185	5	3400	1	172
1186	5	3403	6	1148
1187	4	3408	1	1090
1188	5	3410	7	377
1189	4	3419	3	1473
1190	4	3420	7	1258
1191	4	3427	4	550
1192	5	3428	3	1466
1193	4	3429	7	1469
1194	3	3430	4	929
1195	3	3434	2	519
1196	5	3440	2	1212
1197	1	3446	6	589
1198	5	3452	2	1021
1199	3	3453	3	1483
1200	3	3454	4	67
1201	3	3458	6	1259
1202	4	3460	2	48
1203	2	3462	5	94
1204	5	3463	1	1493
1205	1	3467	4	787
1206	4	3468	7	28
1207	5	3469	4	1453
1208	5	3478	2	1495
1209	5	3480	6	684
1210	5	3486	5	806
1211	5	3489	1	1503
1212	1	3491	6	399
1213	4	3494	4	1505
1214	5	3496	6	1500
1215	3	3497	2	1501
1216	1	3503	6	1498
1217	1	3509	4	88
1218	3	3510	7	157
1219	5	3518	1	708
1220	5	3520	6	1514
1221	3	3525	7	1513
1222	3	3530	2	1516
1223	3	3535	5	1251
1224	5	3536	2	1379
1225	5	3536	3	1379
1226	4	3537	7	1343
1227	3	3539	1	1064
1228	4	3540	4	1517
1229	5	3540	5	1517
1230	5	3546	1	1034
1231	3	3547	4	1413
1232	5	3548	4	1033
1233	5	3553	5	506
1234	5	3554	2	1528
1235	5	3555	1	878
1236	3	3556	5	527
1237	3	3563	5	62
1238	4	3566	7	721
1239	5	3567	7	1097
1240	4	3569	3	1055
1241	3	3574	2	763
1242	3	3577	6	1533
1243	3	3580	2	1263
1244	4	3585	4	1536
1245	5	3589	4	310
1246	4	3592	1	1540
1247	3	3594	5	1542
1248	5	3596	1	376
1249	4	3598	1	498
1250	5	3600	2	1076
1251	3	3601	5	1541
1252	3	3605	5	1143
1253	5	3612	2	914
1254	5	3616	7	1538
1255	5	3616	4	1538
1256	4	3620	1	1534
1257	1	3623	6	748
1258	5	3626	1	1172
1259	5	3627	2	1548
1260	5	3629	4	1551
1261	5	3631	2	778
1262	4	3632	5	707
1263	1	3633	6	1429
1264	4	3640	4	972
1265	3	3641	7	1507
1266	5	3647	3	709
1267	5	3647	5	709
1268	5	3649	1	946
1269	4	3653	7	823
1270	3	3654	7	1554
1271	1	3655	4	905
1272	5	3663	4	1564
1273	4	3666	7	1561
1274	4	3675	1	270
1275	5	3676	4	1556
1276	3	3679	1	467
1277	5	3683	1	381
1278	5	3684	1	274
1279	4	3689	3	1140
1280	3	3690	7	1570
1281	5	3693	3	722
1282	3	3702	4	197
1283	5	3704	4	31
1284	5	3705	2	982
1285	5	3712	6	1405
1286	5	3714	7	310
1287	5	3715	3	113
1288	5	3725	7	1580
1289	4	3730	7	1582
1290	5	3734	3	1101
1291	3	3735	2	1587
1292	5	3740	6	1303
1293	5	3743	6	1534
1294	4	3749	4	1244
1295	4	3750	7	1598
1296	4	3751	2	274
1297	5	3764	4	1597
1298	5	3767	1	1590
1299	5	3768	2	1596
1300	5	3774	6	1599
1301	3	3775	7	1595
1302	5	3783	7	1602
1303	5	3784	3	1352
1304	4	3798	1	1612
1305	5	3805	3	1607
1306	3	3813	3	197
1307	5	3815	3	1619
1308	5	3820	6	1623
1309	5	3822	4	140
1310	5	3824	7	1208
1311	5	3825	1	1626
1312	5	3836	4	847
1313	5	3836	1	847
1314	3	3841	5	1617
1315	3	3842	3	884
1316	5	3843	3	1114
1317	5	3846	7	1319
1318	5	3847	6	432
1319	5	3848	6	122
1320	5	3856	2	1021
1321	5	3858	6	381
1322	5	3859	6	1257
1323	3	3862	3	1637
1324	4	3865	5	1628
1325	5	3873	7	1633
1326	5	3873	1	1633
1327	5	3874	2	1630
1328	5	3875	5	1635
1329	4	3881	3	586
1330	5	3882	2	73
1331	3	3884	1	37
1332	5	3885	6	440
1333	5	3888	2	1634
1334	5	3888	7	1634
1335	5	3889	6	1031
1336	5	3889	4	1031
1337	5	3895	2	1078
1338	4	3898	3	729
1339	4	3900	3	535
1340	4	3900	6	535
1341	4	3902	4	1487
1342	5	3904	7	836
1343	3	3905	6	490
1344	3	3912	4	137
1345	5	3913	3	265
1346	5	3914	2	1501
1347	5	3916	2	1647
1348	1	3918	6	509
1349	5	3921	6	749
1350	3	3930	3	1645
1351	4	3933	5	699
1352	4	3935	2	1072
1353	5	3948	7	1663
1354	4	3949	2	790
1355	4	3952	7	1144
1356	3	3954	5	126
1357	5	3957	3	389
1358	5	3960	6	841
1359	3	3965	5	1514
1360	3	3966	5	1664
1361	2	3971	6	754
1362	5	3972	6	748
1363	4	3977	5	1653
1364	5	3978	6	1451
1365	5	3979	6	525
1366	4	3980	2	1481
1367	5	3984	3	1675
1368	4	3988	1	570
1369	5	3989	7	1188
1370	5	3990	2	1088
1371	5	3992	6	925
1372	4	3995	4	460
1373	1	4000	6	1581
1374	5	4003	4	27
1375	4	4006	5	1494
1376	5	4007	2	688
1377	5	4009	3	1667
1378	5	4010	3	1363
1379	5	4011	6	1537
1380	3	4012	3	377
1381	5	4013	5	1559
1382	5	4015	6	1490
1383	4	4016	2	975
1384	3	4017	7	1322
1385	4	4020	5	1687
1386	5	4021	6	1682
1387	4	4021	4	1682
1388	5	4023	3	543
1389	4	4024	7	1683
1390	5	4028	3	1255
1391	5	4029	6	1562
1392	3	4033	3	906
1393	5	4034	2	1313
1394	5	4043	6	1681
1395	5	4045	3	1684
1396	3	4046	5	17
1397	5	4048	4	786
1398	5	4049	5	656
1399	2	4050	3	1085
1400	5	4053	2	679
1401	5	4056	1	1657
1402	5	4058	3	11
1403	1	4067	4	843
1404	5	4070	6	1310
1405	5	4072	2	1638
1406	5	4074	2	1691
1407	5	4080	6	194
1408	4	4083	2	152
1409	5	4084	4	130
1410	5	4085	6	968
1411	5	4091	4	1088
1412	5	4091	2	1088
1413	3	4096	1	786
1414	5	4097	2	1390
1415	5	4100	2	1705
1416	4	4105	4	1574
1417	5	4109	2	1462
1418	5	4112	3	1708
1419	5	4113	5	1239
1420	5	4114	6	396
1421	5	4115	4	1149
1422	5	4116	2	1714
1423	5	4117	6	1710
1424	5	4125	2	169
1425	4	4127	2	1704
1426	5	4129	7	1709
1427	3	4134	3	1732
1428	3	4140	4	1731
1429	5	4142	7	260
1430	3	4143	4	1728
1431	4	4145	1	655
1432	4	4146	2	972
1433	4	4150	5	832
1434	5	4152	7	1725
1435	5	4157	2	76
1436	2	4159	7	1592
1437	3	4160	5	764
1438	4	4161	1	437
1439	5	4166	2	1046
1440	4	4171	7	569
1441	4	4172	7	1195
1442	5	4175	7	1564
1443	5	4176	3	1562
1444	5	4179	2	786
1445	5	4183	6	491
1446	4	4190	3	1721
1447	1	4193	4	1719
1448	5	4197	1	465
1449	3	4198	3	932
1450	5	4199	4	1734
1451	5	4202	2	1211
1452	4	4205	4	1739
1453	3	4207	1	669
1454	4	4225	1	1011
1455	1	4227	6	1751
1456	5	4228	1	1390
1457	5	4229	4	1747
1458	5	4231	4	1701
1459	5	4238	5	1744
1460	5	4239	4	1427
1461	5	4245	4	300
1462	5	4246	4	1458
1463	3	4249	4	313
1464	3	4252	2	1760
1465	5	4254	4	318
1466	5	4255	1	1310
1467	3	4259	7	1757
1468	2	4265	4	634
1469	2	4266	6	37
1470	5	4272	7	1762
1471	4	4273	5	840
1472	5	4274	2	1037
1473	5	4275	6	1766
1474	5	4276	2	1759
1475	5	4285	1	256
1476	5	4287	2	669
1477	3	4290	4	1756
1478	5	4295	6	1768
1479	1	4298	1	399
1480	4	4299	5	1330
1481	5	4299	6	1330
1482	5	4301	3	1770
1483	5	4305	2	338
1484	4	4311	3	853
1485	5	4313	2	63
1486	5	4314	2	1773
1487	5	4315	2	78
1488	3	4321	3	1239
1489	3	4322	5	1746
1490	5	4324	4	310
1491	5	4325	5	1784
1492	5	4326	1	1783
1493	4	4326	5	1783
1494	5	4327	2	1781
1495	4	4330	1	1266
1496	5	4332	2	1092
1497	4	4332	5	1092
1498	5	4335	2	820
1499	3	4344	7	1788
1500	5	4345	3	1448
1501	5	4346	2	1779
1502	3	4347	5	841
1503	4	4348	3	403
1504	5	4350	7	1786
1505	4	4357	7	1789
1506	5	4363	1	1598
1507	5	4367	3	1808
1508	5	4367	2	1808
1509	3	4371	2	986
1510	5	4378	3	1353
1511	4	4381	3	1796
1512	5	4387	3	703
1513	4	4394	5	211
1514	5	4395	3	1250
1515	5	4397	7	1592
1516	5	4400	2	1807
1517	5	4402	5	245
1518	4	4403	1	1805
1519	3	4404	6	424
1520	4	4410	2	482
1521	5	4419	2	1813
1522	4	4423	7	1610
1523	5	4424	2	277
1524	5	4425	3	1299
1525	5	4427	2	336
1526	3	4436	6	1816
1527	5	4437	5	523
1528	3	4439	1	424
1529	5	4441	4	1659
1530	4	4448	7	525
1531	4	4452	1	847
1532	3	4453	1	1645
1533	5	4454	6	1468
1534	4	4456	7	233
1535	5	4462	6	1831
1536	4	4465	5	1053
1537	3	4465	7	1053
1538	3	4467	5	1826
1539	5	4476	4	1514
1540	4	4478	7	1834
1541	5	4482	7	1117
1542	5	4490	7	1824
1543	4	4492	2	329
1544	3	4492	7	329
1545	5	4495	7	1746
1546	5	4497	7	466
1547	5	4498	6	298
1548	4	4505	1	1676
1549	5	4506	6	1269
1550	3	4506	2	1269
1551	4	4508	7	1085
1552	4	4509	7	1837
1553	5	4512	3	1843
1554	5	4517	1	989
1555	3	4518	6	77
1556	5	4519	5	150
1557	4	4524	5	1261
1558	3	4527	3	122
1559	5	4528	4	1836
1560	5	4529	6	1841
1561	4	4531	2	1076
1562	5	4532	1	330
1563	5	4533	7	1435
1564	5	4535	1	1387
1565	5	4536	7	1464
1566	2	4537	1	138
1567	3	4543	7	1640
1568	5	4545	1	606
1569	5	4547	7	1390
1570	5	4550	1	1855
1571	5	4559	1	1742
1572	5	4562	5	1859
1573	5	4567	5	1376
1574	5	4570	3	1852
1575	5	4570	1	1852
1576	5	4571	1	946
1577	3	4572	1	1445
1578	4	4581	2	1863
1579	4	4584	7	1379
1580	4	4586	7	1869
1581	5	4589	2	655
1582	5	4590	6	1871
1583	5	4591	5	946
1584	5	4594	6	1860
1585	5	4599	6	1867
1586	5	4600	2	149
1587	4	4607	1	1862
1588	4	4608	5	232
1589	3	4609	7	894
1590	5	4611	6	1176
1591	5	4613	3	213
1592	3	4617	1	1872
1593	5	4620	6	1881
1594	4	4624	5	1880
1595	5	4625	7	1233
1596	5	4626	6	1886
1597	5	4629	7	378
1598	5	4633	3	1874
1599	4	4634	5	921
1600	3	4639	1	1885
1601	5	4647	3	1060
1602	5	4648	1	1656
1603	4	4648	7	1656
1604	2	4652	5	1878
1605	5	4655	2	599
1606	5	4660	4	1446
1607	5	4664	1	964
1608	5	4668	2	701
1609	4	4675	7	1247
1610	5	4677	7	1904
1611	5	4680	6	784
1612	5	4680	2	784
1613	5	4684	2	68
1614	5	4687	6	1687
1615	5	4688	3	314
1616	3	4689	7	53
1617	5	4692	6	506
1618	5	4693	3	1774
1619	1	4694	3	531
1620	4	4698	6	1674
1621	4	4705	2	1902
1622	4	4707	7	1789
1623	5	4711	2	477
1624	3	4712	1	784
1625	5	4715	6	351
1626	5	4717	2	1912
1627	4	4725	4	1905
1628	5	4727	4	74
1629	5	4730	6	1908
1630	2	4734	6	1918
1631	5	4736	6	1638
1632	4	4737	5	1765
1633	5	4739	1	389
1634	5	4740	5	1913
1635	3	4741	7	972
1636	4	4741	5	972
1637	5	4743	6	274
1638	5	4745	6	1909
1639	3	4746	2	804
1640	5	4750	2	282
1641	5	4759	3	447
1642	3	4760	5	754
1643	5	4763	4	229
1644	5	4764	4	1085
1645	5	4770	1	200
1646	5	4774	4	91
1647	3	4774	1	91
1648	3	4775	4	982
1649	5	4781	5	1923
1650	5	4784	2	360
1651	5	4789	1	1929
1652	2	4791	6	1928
1653	5	4792	4	1053
1654	5	4794	1	1321
1655	2	4804	1	173
1656	5	4806	2	964
1657	3	4807	5	1860
1658	4	4808	2	1887
1659	5	4809	7	1854
1660	3	4811	7	1934
1661	4	4817	4	972
1662	5	4818	1	575
1663	3	4819	4	1933
1664	5	4823	2	1771
1665	4	4823	1	1771
1666	5	4826	4	1296
1667	5	4826	6	1296
1668	1	4832	6	1941
1669	5	4834	2	12
1670	3	4836	2	552
1671	5	4840	3	1550
1672	5	4841	6	1461
1673	5	4842	2	1076
1674	4	4843	1	548
1675	5	4844	7	997
1676	5	4849	4	1950
1677	3	4855	5	1854
1678	5	4859	7	1951
1679	5	4861	6	330
1680	1	4869	6	1889
1681	1	4871	4	1722
1682	5	4875	2	1490
1683	5	4876	5	1555
1684	4	4877	3	1959
1685	4	4880	6	1585
1686	4	4884	6	1722
1687	3	4885	2	1119
1688	5	4886	4	1442
1689	5	4890	6	1445
1690	4	4890	3	1445
1691	3	4892	2	173
1692	1	4895	4	1967
1693	5	4898	7	1958
1694	5	4899	4	737
1695	3	4901	5	1013
1696	5	4902	5	281
1697	4	4905	7	1960
1698	4	4911	3	1654
1699	5	4911	1	1654
1700	5	4917	3	120
1701	4	4921	5	1713
1702	4	4925	7	444
1703	4	4926	5	1435
1704	4	4928	7	96
1705	4	4933	3	299
1706	5	4935	3	411
1707	3	4941	1	1247
1708	5	4942	3	697
1709	4	4945	5	274
1710	4	4948	1	802
1711	4	4961	7	1093
1712	3	4963	1	679
1713	5	4964	1	1239
1714	5	4967	4	1986
1715	3	4995	5	1992
1716	5	4996	2	270
1717	5	5000	4	1997
1718	5	5003	5	1896
1719	4	5008	7	1322
1720	3	5009	6	531
1721	5	5013	2	286
1722	5	5014	7	2010
1723	3	5026	1	2006
1724	5	5030	4	1334
1725	3	5031	4	219
1726	5	5033	2	638
1727	4	5036	5	2011
1728	5	5037	6	1097
1729	5	5038	5	1445
1730	5	5046	4	1085
1731	5	5047	4	833
1732	5	5052	6	477
1733	4	5053	7	942
1734	4	5055	2	95
1735	5	5056	1	584
1736	5	5063	6	233
1737	5	5069	1	189
1738	5	5076	1	826
1739	5	5077	6	439
1740	1	5079	3	1266
1741	4	5081	3	519
1742	5	5086	3	2019
1743	5	5093	4	333
1744	5	5094	5	2016
1745	2	5094	1	2016
1746	3	5096	2	826
1747	5	5097	6	788
1748	5	5099	3	1527
1749	4	5101	5	1681
1750	5	5109	6	781
1751	4	5111	1	1707
1752	5	5112	2	1819
1753	4	5114	4	1208
1754	4	5126	3	316
1755	5	5130	7	444
1756	5	5132	2	2036
1757	5	5133	7	1170
1758	5	5136	4	925
1759	5	5139	5	1632
1760	3	5140	6	788
1761	4	5142	4	2028
1762	3	5144	4	832
1763	4	5150	4	1224
1764	5	5153	6	2048
1765	5	5159	6	2042
1766	5	5164	4	1262
1767	5	5168	6	1776
1768	5	5171	6	236
1769	5	5172	4	2040
1770	4	5174	4	886
1771	2	5179	6	2045
1772	3	5189	5	361
1773	4	5191	6	1900
1774	5	5193	4	1996
1775	4	5195	2	2049
1776	5	5198	7	29
1777	4	5205	2	2056
1778	5	5212	7	256
1779	5	5215	2	2057
1780	5	5221	4	88
1781	5	5223	7	1836
1782	5	5225	6	461
1783	5	5226	7	1343
1784	4	5228	3	536
1785	5	5229	5	2003
1786	5	5231	4	1245
1787	5	5242	4	1834
1788	5	5243	7	27
1789	4	5249	1	2072
1790	3	5251	1	612
1791	5	5252	1	856
1792	4	5254	5	1732
1793	5	5256	2	1659
1794	4	5258	2	854
1795	4	5259	5	2067
1796	5	5261	2	1464
1797	5	5262	2	1068
1798	3	5264	1	739
1799	4	5267	1	486
1800	4	5271	7	2069
1801	5	5278	5	608
1802	3	5279	5	2080
1803	5	5280	1	2092
1804	5	5285	4	1502
1805	4	5286	6	2094
1806	3	5287	3	2088
1807	5	5288	6	1924
1808	3	5292	1	797
1809	5	5295	3	1742
1810	4	5298	2	2085
1811	5	5303	4	2083
1812	5	5304	5	27
1813	2	5305	4	1079
1814	5	5306	3	6
1815	5	5307	1	267
1816	4	5312	4	201
1817	5	5320	4	482
1818	5	5323	3	2093
1819	5	5324	5	1537
1820	5	5326	6	2081
1821	3	5328	3	1995
1822	3	5339	5	832
1823	5	5344	2	1667
1824	4	5346	7	391
1825	4	5347	5	2097
1826	4	5352	4	1233
1827	3	5353	3	997
1828	3	5360	5	962
1829	4	5363	1	2099
1830	3	5369	1	1375
1831	5	5370	3	519
1832	4	5371	1	2103
1833	5	5374	3	2105
1834	1	5374	2	2105
1835	5	5380	6	612
1836	4	5388	1	543
1837	2	5398	3	2118
1838	4	5405	7	2120
1839	5	5406	1	2115
1840	5	5407	2	2110
1841	5	5408	4	1834
1842	5	5409	5	1800
1843	1	5411	6	1424
1844	4	5413	2	1557
1845	5	5415	4	566
1846	4	5418	6	1988
1847	5	5430	6	360
1848	5	5431	6	1638
1849	4	5431	4	1638
1850	5	5437	7	763
1851	5	5438	7	437
1852	5	5438	4	437
1853	5	5439	6	2135
1854	3	5444	7	2127
1855	3	5445	7	158
1856	4	5450	7	2130
1857	3	5454	7	1834
1858	4	5455	4	1108
1859	4	5456	2	1344
1860	5	5457	5	708
1861	5	5459	2	1025
1862	5	5461	4	195
1863	5	5462	4	2133
1864	4	5465	5	440
1865	5	5468	6	2149
1866	5	5471	7	2148
1867	5	5475	7	1612
1868	5	5479	3	2143
1869	1	5483	7	2121
1870	3	5486	6	709
1871	5	5487	6	1460
1872	4	5495	1	1804
1873	3	5497	2	1233
1874	5	5503	6	1269
1875	5	5505	7	1965
1876	5	5506	4	710
1877	3	5508	4	1457
1878	5	5512	2	2158
1879	5	5513	6	223
1880	4	5514	7	40
1881	4	5516	7	1457
1882	5	5522	3	1915
1883	3	5526	4	539
1884	3	5528	1	1359
1885	5	5529	1	820
1886	3	5530	7	1176
1887	5	5532	2	1594
1888	5	5535	5	2154
1889	5	5538	4	2160
1890	2	5539	4	1685
1891	4	5541	7	1239
1892	4	5543	5	2157
1893	5	5545	4	371
1894	5	5547	4	197
1895	1	5550	6	2153
1896	5	5555	6	455
1897	4	5558	2	2119
1898	5	5562	2	1427
1899	4	5563	2	1879
1900	4	5566	2	184
1901	5	5569	2	1269
1902	5	5572	3	1464
1903	3	5575	4	1537
1904	1	5576	4	1933
1905	5	5580	6	1400
1906	4	5582	5	2165
1907	5	5583	2	981
1908	5	5584	2	464
1909	5	5586	4	1563
1910	3	5588	3	2172
1911	5	5591	3	1685
1912	5	5595	6	653
1913	5	5596	3	62
1914	3	5603	5	2177
1915	5	5609	3	2190
1916	3	5612	5	83
1917	4	5613	2	1531
1918	5	5615	3	972
1919	2	5622	1	1123
1920	5	5624	7	1992
1921	4	5629	5	2196
1922	3	5635	2	1693
1923	4	5636	1	1103
1924	4	5637	4	915
1925	5	5640	4	2191
1926	4	5641	6	2173
1927	3	5643	1	2193
1928	5	5649	4	1596
1929	1	5652	6	2182
1930	5	5654	5	2189
1931	4	5658	7	461
1932	3	5659	5	356
1933	5	5664	3	315
1934	5	5674	2	635
1935	5	5678	6	1296
1936	5	5680	1	708
1937	3	5682	2	1208
1938	3	5684	3	214
1939	5	5688	3	2130
1940	5	5688	1	2130
1941	5	5692	2	2021
1942	3	5693	7	68
1943	1	5694	6	310
1944	5	5698	5	2123
1945	5	5701	1	871
1946	3	5703	2	391
1947	5	5708	6	2208
1948	5	5711	1	677
1949	3	5712	5	1793
1950	5	5714	4	805
1951	5	5715	2	1309
1952	4	5720	5	2201
1953	4	5735	3	1425
1954	3	5741	1	2000
1955	4	5744	2	1025
1956	5	5747	5	2069
1957	5	5749	2	1033
1958	5	5753	6	41
1959	5	5755	1	845
1960	3	5768	2	1021
1961	5	5771	3	2101
1962	5	5772	2	980
1963	5	5775	1	216
1964	5	5778	3	362
1965	5	5780	2	1402
1966	3	5780	7	1402
1967	5	5781	3	2231
1968	5	5785	7	2197
1969	5	5788	6	2229
1970	4	5790	5	2230
1971	2	5793	6	2240
1972	5	5797	4	1679
1973	4	5799	4	1264
1974	5	5800	4	1014
1975	5	5800	1	1014
1976	4	5802	2	1998
1977	5	5803	4	506
1978	5	5811	5	150
1979	5	5815	7	972
1980	5	5821	6	823
1981	5	5822	4	479
1982	5	5825	7	2253
1983	5	5826	4	963
1984	5	5831	2	2
1985	3	5833	4	1530
1986	4	5834	4	233
1987	1	5835	4	2250
1988	3	5840	2	338
1989	5	5841	6	2201
1990	4	5842	5	2254
1991	5	5846	2	1627
1992	5	5848	2	418
1993	5	5850	6	1896
1994	4	5850	3	1896
1995	5	5856	1	1687
1996	3	5857	5	2249
1997	5	5859	7	512
1998	3	5863	4	809
1999	5	5866	4	1816
2000	3	5867	2	1992
2001	5	5871	1	2244
2002	5	5872	7	1885
2003	3	5880	7	550
2004	3	5882	7	1104
2005	4	5886	3	298
2006	4	5887	7	367
2007	3	5889	4	2262
2008	3	5899	5	11
2009	5	5902	4	821
2010	3	5909	3	1922
2011	5	5911	4	482
2012	5	5915	3	2264
2013	2	5918	2	436
2014	5	5918	3	436
2015	5	5922	7	2188
2016	5	5925	4	1228
2017	4	5931	2	1110
2018	3	5937	7	1193
2019	5	5943	4	2217
2020	5	5945	2	95
2021	5	5947	7	2072
2022	5	5948	4	2137
2023	5	5951	5	2282
2024	4	5952	6	2283
2025	3	5953	7	527
2026	4	5956	3	1455
2027	5	5957	2	1765
2028	3	5959	7	506
2029	5	5962	2	1456
2030	5	5965	3	2000
2031	4	5969	2	2270
2032	5	5970	1	1258
2033	5	5972	2	105
2034	5	5973	7	1514
2035	3	5977	3	2168
2036	5	5979	4	1331
2037	5	5982	2	2287
2038	5	5986	1	2297
2039	5	5987	3	1400
2040	4	5988	1	2291
2041	5	5989	2	1956
2042	5	5993	3	701
2043	2	5995	1	2026
2044	5	6003	4	2300
2045	4	6012	7	1545
2046	2	6016	2	1685
2047	4	6019	5	2296
2048	3	6021	7	66
2049	4	6029	7	1846
2050	5	6033	2	1792
2051	1	6037	4	372
2052	5	6038	3	62
2053	5	6040	5	1239
2054	5	6043	1	2316
2055	5	6047	7	431
2056	5	6050	4	1905
2057	4	6051	4	787
2058	3	6056	1	338
2059	5	6058	2	1648
2060	1	6065	3	2307
2061	5	6070	1	2308
2062	5	6072	2	1583
2063	4	6080	5	1653
2064	5	6083	7	799
2065	5	6087	6	807
2066	5	6091	1	399
2067	5	6093	3	2303
2068	4	6096	2	27
2069	3	6107	2	1647
2070	4	6121	5	1176
2071	5	6122	4	837
2072	3	6127	5	1537
2073	5	6130	6	552
2074	3	6136	1	2335
2075	5	6138	1	806
2076	3	6139	5	1572
2077	3	6140	6	2336
2078	4	6141	1	395
2079	3	6143	2	970
2080	3	6147	5	684
2081	4	6149	7	104
2082	5	6152	2	1226
2083	5	6155	7	2008
2084	5	6158	7	1693
2085	5	6161	2	945
2086	5	6163	4	1780
2087	4	6169	2	292
2088	2	6171	2	2340
2089	5	6172	1	599
2090	5	6176	3	781
2091	2	6177	3	104
2092	5	6178	7	1679
2093	3	6182	4	2355
2094	4	6186	4	2353
2095	4	6187	2	1888
2096	5	6190	4	2349
2097	5	6193	3	593
2098	5	6197	6	2350
2099	4	6200	5	1043
2100	5	6204	4	1241
2101	4	6206	1	2358
2102	3	6207	4	1375
2103	4	6208	7	1862
2104	5	6209	7	1736
2105	4	6211	2	1458
2106	4	6212	4	2348
2107	4	6214	5	2082
2108	5	6215	5	2213
2109	4	6218	5	216
2110	4	6221	6	1380
2111	3	6222	6	1387
2112	1	6224	4	2124
2113	4	6227	2	1857
2114	5	6234	1	669
2115	3	6235	2	412
2116	5	6236	2	482
2117	5	6238	5	1523
2118	5	6241	6	2373
2119	4	6243	6	1143
2120	4	6246	2	1393
2121	4	6248	5	758
2122	5	6250	7	1675
2123	4	6251	5	232
2124	5	6253	2	135
2125	4	6256	2	467
2126	5	6261	1	1376
2127	3	6262	4	941
2128	3	6268	7	1970
2129	3	6269	2	2362
2130	3	6274	7	2389
2131	5	6276	6	1228
2132	5	6278	6	547
2133	5	6281	6	2
2134	1	6283	5	1325
2135	4	6286	7	669
2136	2	6287	5	2354
2137	3	6290	2	1303
2138	5	6294	1	2375
2139	3	6300	6	676
2140	5	6304	4	1374
2141	5	6308	6	1937
2142	5	6308	2	1937
2143	5	6313	2	2382
2144	5	6314	1	2252
2145	5	6326	2	71
2146	4	6336	6	784
2147	5	6337	7	271
2148	5	6339	5	2404
2149	4	6340	2	1094
2150	5	6348	4	2405
2151	5	6351	2	2403
2152	2	6352	6	1525
2153	5	6357	3	2076
2154	1	6359	6	397
2155	1	6363	4	1861
2156	4	6365	4	2408
2157	5	6366	1	707
2158	3	6380	5	2407
2159	4	6384	4	195
2160	5	6385	5	2179
2161	5	6392	6	2422
2162	5	6400	5	2425
2163	5	6401	5	2189
2164	4	6406	1	1854
2165	5	6408	6	1272
2166	4	6408	4	1272
2167	4	6411	7	378
2168	4	6412	2	2409
2169	5	6415	4	36
2170	3	6415	3	36
2171	4	6416	7	857
2172	5	6417	5	2369
2173	5	6418	1	2420
2174	5	6422	6	2004
2175	3	6427	5	2416
2176	5	6428	2	1390
2177	5	6431	6	2419
2178	5	6434	6	2412
2179	5	6435	7	362
2180	5	6436	4	1200
2181	5	6442	7	826
2182	5	6443	5	2199
2183	4	6443	7	2199
2184	4	6449	2	359
2185	5	6454	2	536
2186	5	6456	2	287
2187	5	6457	6	581
2188	5	6460	4	2411
2189	5	6463	6	840
2190	5	6464	1	1902
2191	5	6470	4	1207
2192	3	6478	5	2015
2193	3	6480	4	362
2194	3	6482	1	2440
2195	3	6486	2	2425
2196	4	6489	4	1800
2197	5	6493	7	2429
2198	4	6494	5	2367
2199	5	6498	7	2433
2200	5	6501	6	2110
2201	4	6503	1	66
2202	5	6504	6	2000
2203	5	6505	2	528
2204	5	6509	4	1679
2205	5	6510	7	2447
2206	4	6512	1	2454
2207	5	6513	3	2442
2208	5	6514	6	1173
2209	4	6520	6	2449
2210	5	6527	4	787
2211	5	6528	7	2445
2212	4	6531	1	2452
2213	4	6535	4	2443
2214	3	6536	5	1070
2215	4	6539	1	314
2216	5	6541	4	2451
2217	4	6543	7	2450
2218	4	6551	6	2466
2219	3	6552	5	2465
2220	5	6560	6	2317
2221	5	6563	2	2404
2222	4	6571	4	2468
2223	5	6574	5	1665
2224	4	6581	4	1072
2225	5	6583	6	2192
2226	3	6585	2	2458
2227	5	6587	3	2469
2228	3	6589	3	1164
2229	5	6594	5	1969
2230	5	6599	5	2415
2231	4	6606	3	2480
2232	5	6608	3	1148
2233	5	6610	2	2472
2234	5	6615	2	2474
2235	5	6619	6	1677
2236	4	6623	1	336
2237	5	6624	3	509
2238	5	6628	4	74
2239	4	6631	7	2476
2240	5	6635	1	1112
2241	5	6640	6	627
2242	3	6642	5	1278
2243	4	6644	4	303
2244	5	6646	4	669
2245	4	6647	7	2087
2246	5	6648	4	2434
2247	4	6649	4	2473
2248	5	6651	6	184
2249	3	6652	4	528
2250	5	6658	4	1521
2251	2	6659	2	2487
2252	5	6661	6	2497
2253	5	6663	1	1679
2254	4	6664	5	1009
2255	5	6671	5	1712
2256	4	6674	4	1461
2257	5	6675	1	1377
2258	4	6677	3	2418
2259	5	6686	3	1427
2260	4	6688	7	2491
2261	3	6691	4	1963
2262	5	6694	6	1053
2263	3	6695	5	624
2264	4	6696	7	1713
2265	5	6699	6	631
2266	3	6701	5	1541
2267	4	6707	6	1257
2268	5	6707	3	1257
2269	5	6708	1	2351
2270	4	6711	1	2480
2271	5	6713	3	1114
2272	5	6715	1	2508
2273	5	6717	6	356
2274	4	6718	4	477
2275	5	6719	4	2516
2276	5	6721	6	2514
2277	4	6726	1	2191
2278	5	6727	7	2505
2279	4	6728	7	2502
2280	5	6730	4	2339
2281	2	6731	3	2173
2282	3	6734	2	2512
2283	5	6738	2	58
2284	5	6739	3	2041
2285	5	6741	2	2500
2286	4	6747	7	149
2287	5	6749	5	2290
2288	4	6750	2	1119
2289	3	6751	1	2511
2290	5	6752	5	2503
2291	4	6752	3	2503
2292	5	6754	7	2507
2293	4	6755	1	48
2294	5	6757	3	573
2295	5	6759	6	1173
2296	1	6760	6	291
2297	5	6764	6	1948
2298	5	6766	2	1244
2299	5	6767	3	1888
2300	1	6767	4	1888
2301	4	6768	1	2527
2302	3	6772	1	962
2303	5	6775	2	740
2304	5	6776	2	627
2305	5	6777	4	1155
2306	5	6778	6	2521
2307	3	6783	1	2533
2308	2	6788	6	712
2309	5	6791	1	1934
2310	4	6794	4	2523
2311	5	6798	3	2178
2312	4	6800	5	1813
2313	5	6808	6	491
2314	5	6818	3	1732
2315	5	6819	6	2524
2316	5	6820	6	547
2317	4	6823	1	1263
2318	5	6825	7	853
2319	5	6828	4	21
2320	4	6830	2	240
2321	5	6831	7	376
2322	5	6832	2	2531
2323	5	6840	4	2530
2324	3	6844	4	2367
2325	5	6845	4	1443
2326	4	6850	5	666
2327	5	6852	2	950
2328	1	6853	3	807
2329	5	6856	2	293
2330	4	6858	7	2544
2331	5	6862	5	107
2332	5	6863	1	676
2333	5	6866	2	1235
2334	2	6866	3	1235
2335	5	6869	2	506
2336	5	6870	7	1374
2337	1	6871	6	887
2338	5	6872	4	612
2339	4	6877	4	763
2340	5	6880	1	1376
2341	5	6881	7	2550
2342	5	6883	4	189
2343	3	6886	4	1215
2344	4	6888	2	1659
2345	4	6892	6	1455
2346	4	6895	3	1209
2347	4	6897	2	1464
2348	3	6899	7	2555
2349	5	6903	2	1422
2350	5	6906	5	1161
2351	5	6910	6	712
2352	4	6911	1	2262
2353	4	6914	5	1410
2354	5	6915	4	610
2355	5	6918	7	2557
2356	5	6920	6	1729
2357	5	6927	5	1860
2358	4	6931	1	1053
2359	5	6933	3	1427
2360	5	6934	3	2571
2361	5	6936	2	2231
2362	5	6938	3	2478
2363	5	6939	6	1055
2364	3	6943	5	490
2365	5	6945	6	964
2366	4	6947	4	907
2367	3	6953	4	1314
2368	5	6957	7	399
2369	3	6959	4	2010
2370	4	6960	7	5
2371	3	6961	5	208
2372	5	6963	5	2567
2373	3	6964	1	1681
2374	3	6967	1	66
2375	5	6968	6	1832
2376	2	6973	6	2287
2377	5	6974	6	286
2378	5	6976	6	1674
2379	5	6977	2	1321
2380	5	6981	1	1104
2381	5	6986	1	2466
2382	4	6990	4	1185
2383	4	6995	1	708
2384	5	6996	2	2575
2385	3	7001	5	1166
2386	4	7001	1	1166
2387	5	7003	3	2581
2388	5	7004	4	2578
2389	5	7006	5	1929
2390	5	7009	4	2592
2391	5	7015	2	2584
2392	4	7019	6	2287
2393	5	7022	3	2029
2394	4	7026	3	2582
2395	5	7028	7	2107
2396	4	7029	7	806
2397	5	7032	6	1182
2398	5	7035	2	2591
2399	5	7036	4	2143
2400	3	7037	5	1808
2401	5	7041	7	2440
2402	3	7041	3	2440
2403	4	7045	4	2587
2404	4	7047	1	133
2405	5	7048	1	417
2406	3	7054	6	929
2407	5	7056	3	285
2408	4	7060	6	2189
2409	5	7066	4	2611
2410	3	7068	5	2608
2411	5	7071	4	172
2412	5	7073	2	2604
2413	5	7074	2	2492
2414	4	7078	5	880
2415	5	7082	4	669
2416	5	7083	3	2330
2417	5	7086	1	2575
2418	1	7088	6	1181
2419	5	7089	1	2115
2420	4	7093	7	2442
2421	5	7096	7	1968
2422	4	7099	2	511
2423	4	7101	1	787
2424	5	7106	6	2546
2425	3	7107	5	799
2426	5	7110	2	1692
2427	3	7113	7	2062
2428	3	7114	5	2068
2429	5	7118	3	708
2430	4	7124	7	1163
2431	4	7125	2	2615
2432	5	7126	5	915
2433	5	7128	7	1406
2434	5	7128	2	1406
2435	5	7129	6	865
2436	5	7132	6	1255
2437	5	7138	6	2272
2438	5	7140	1	2616
2439	3	7149	3	1106
2440	5	7155	3	2575
2441	2	7157	6	1950
2442	3	7159	4	158
2443	4	7161	3	351
2444	4	7162	2	394
2445	5	7163	5	642
2446	2	7170	3	1900
2447	5	7171	3	466
2448	5	7173	6	1301
2449	5	7174	5	2629
2450	5	7176	1	2623
2451	4	7182	3	2551
2452	5	7184	1	1289
2453	3	7186	5	203
2454	5	7188	6	1324
2455	3	7192	1	2635
2456	5	7192	6	2635
2457	5	7193	3	832
2458	4	7194	7	754
2459	4	7195	5	1712
2460	5	7198	2	575
2461	5	7200	7	1441
2462	5	7204	4	382
2463	4	7206	2	654
2464	4	7207	1	66
2465	5	7208	4	2653
2466	3	7209	5	337
2467	5	7210	6	1679
2468	5	7214	6	475
2469	5	7218	5	749
2470	4	7219	7	2649
2471	4	7222	3	1316
2472	4	7226	5	1530
2473	5	7228	3	886
2474	3	7232	6	2619
2475	3	7237	5	285
2476	3	7241	4	701
2477	5	7248	2	2647
2478	5	7251	7	958
2479	5	7257	2	1273
2480	5	7259	1	489
2481	4	7260	1	2651
2482	3	7261	1	2640
2483	5	7263	2	29
2484	1	7266	6	2538
2485	3	7268	7	466
2486	4	7270	4	1772
2487	5	7273	5	1710
2488	5	7277	2	821
2489	4	7278	7	2227
2490	5	7279	6	1750
2491	5	7280	6	2643
2492	4	7282	7	2645
2493	5	7282	2	2645
2494	5	7283	1	1016
2495	4	7287	4	2310
2496	5	7288	4	2511
2497	2	7289	6	2226
2498	5	7298	6	2623
2499	4	7301	1	1238
2500	3	7302	3	2633
2501	5	7311	7	2287
2502	5	7311	2	2287
2503	4	7313	6	743
2504	4	7315	5	2540
2505	5	7317	4	2660
2506	5	7325	6	166
2507	4	7326	5	2681
2508	5	7329	7	2092
2509	5	7332	5	1860
2510	5	7334	3	228
2511	5	7336	5	1215
2512	5	7341	4	357
2513	5	7344	3	2682
2514	4	7345	2	2050
2515	4	7347	2	1889
2516	3	7348	6	2687
2517	5	7350	7	2702
2518	4	7351	5	270
2519	5	7352	5	1423
2520	5	7355	6	2691
2521	3	7356	5	1963
2522	5	7358	5	49
2523	4	7359	2	2683
2524	3	7364	7	2627
2525	4	7365	4	1854
2526	3	7366	2	2692
2527	5	7370	5	2236
2528	5	7375	2	2332
2529	4	7378	5	2704
2530	4	7382	2	2695
2531	5	7384	2	2698
2532	3	7385	5	642
2533	1	7386	6	413
2534	1	7388	6	2520
2535	5	7390	5	2700
2536	4	7395	3	1700
2537	5	7399	6	2217
2538	3	7400	7	2724
2539	5	7401	4	2716
2540	5	7403	5	1680
2541	4	7406	3	2712
2542	5	7409	3	1104
2543	3	7420	6	2706
2544	5	7423	2	2715
2545	5	7425	6	506
2546	5	7427	1	2105
2547	5	7427	3	2105
2548	3	7429	4	247
2549	4	7432	3	44
2550	5	7433	1	143
2551	3	7434	2	1677
2552	5	7438	1	2705
2553	4	7440	2	1075
2554	3	7443	2	2573
2555	4	7444	3	1266
2556	5	7451	2	2392
2557	4	7455	3	2631
2558	4	7458	1	528
2559	5	7459	6	476
2560	3	7460	2	743
2561	4	7463	1	1017
2562	5	7464	2	2231
2563	5	7464	4	2231
2564	5	7465	5	2729
2565	3	7468	4	295
2566	5	7475	2	1215
2567	5	7477	3	48
2568	2	7478	5	2733
2569	3	7479	7	2741
2570	5	7480	2	94
2571	4	7482	5	1674
2572	5	7483	6	2738
2573	5	7485	4	2734
2574	5	7487	7	2731
2575	5	7490	2	1414
2576	4	7493	3	143
2577	5	7493	2	143
2578	2	7494	4	2745
2579	5	7497	6	2541
2580	5	7499	4	2747
2581	5	7499	7	2747
2582	4	7508	7	2750
2583	3	7508	5	2750
2584	1	7509	4	1021
2585	5	7513	1	2672
2586	5	7514	1	265
2587	3	7515	7	2753
2588	5	7516	2	2749
2589	3	7516	3	2749
2590	4	7517	1	1736
2591	5	7518	1	2740
2592	1	7530	6	1651
2593	5	7533	4	2021
2594	3	7537	4	381
2595	5	7539	2	1442
2596	5	7544	4	2754
2597	5	7545	6	1080
2598	5	7551	7	2781
2599	5	7555	4	2053
2600	5	7558	6	2763
2601	5	7560	5	2775
2602	5	7569	5	2770
2603	3	7570	7	2778
2604	5	7571	6	96
2605	5	7577	6	2771
2606	5	7579	6	2766
2607	5	7582	4	285
2608	2	7583	3	1009
2609	4	7585	6	2774
2610	5	7589	5	2772
2611	5	7591	6	2780
2612	5	7605	5	2795
2613	5	7609	6	2657
2614	4	7618	5	2691
2615	5	7622	5	2673
2616	3	7624	7	2793
2617	4	7626	5	1118
2618	5	7628	3	2474
2619	5	7630	4	928
2620	5	7631	1	2272
2621	5	7631	2	2272
2622	4	7632	2	206
2623	3	7633	6	2803
2624	5	7640	1	634
2625	5	7643	7	1306
2626	5	7654	5	2794
2627	1	7658	6	2791
2628	3	7662	1	932
2629	5	7671	5	2140
2630	5	7672	7	1582
2631	3	7677	5	2837
2632	5	7680	7	2821
2633	4	7683	2	1569
2634	5	7686	7	2579
2635	3	7689	2	1212
2636	5	7694	5	2317
2637	5	7695	6	2320
2638	5	7698	1	1888
2639	3	7699	5	2078
2640	5	7699	2	2078
2641	3	7700	5	1601
2642	5	7701	6	2401
2643	3	7702	4	684
2644	5	7703	2	2237
2645	5	7704	6	1134
2646	3	7714	5	1929
2647	5	7715	2	2819
2648	3	7718	4	2827
2649	3	7720	5	2293
2650	4	7721	4	2833
2651	5	7721	2	2833
2652	5	7726	6	2829
2653	5	7727	6	974
2654	1	7729	6	1099
2655	5	7737	5	2812
2656	3	7741	5	2811
2657	5	7745	1	1208
2658	4	7748	2	2813
2659	4	7751	4	2820
2660	5	7752	5	2836
2661	5	7753	6	2817
2662	5	7755	2	2831
2663	5	7756	6	2825
2664	5	7760	4	2815
2665	5	7760	2	2815
2666	5	7762	1	1282
2667	5	7763	3	764
2668	3	7766	7	2845
2669	5	7769	2	2854
2670	4	7770	6	2848
2671	4	7779	7	2846
2672	5	7780	2	1373
2673	1	7789	6	2849
2674	1	7790	5	2774
2675	5	7793	2	136
2676	4	7799	1	529
2677	3	7802	2	2770
2678	5	7803	6	2864
2679	5	7806	6	2417
2680	4	7826	5	2391
2681	4	7829	2	2882
2682	3	7830	5	2551
2683	3	7831	1	2869
2684	3	7838	5	2885
2685	3	7840	1	2872
2686	4	7843	3	2875
2687	2	7845	1	2870
2688	2	7849	4	2181
2689	3	7851	1	382
2690	4	7852	5	2895
2691	5	7853	1	356
2692	3	7855	3	41
2693	5	7855	2	41
2694	1	7856	6	2887
2695	1	7859	5	886
2696	5	7864	3	2897
2697	5	7869	6	2907
2698	2	7873	7	1535
2699	5	7874	2	1212
2700	5	7876	5	2886
2701	5	7877	6	2077
2702	3	7878	2	348
2703	5	7879	4	950
2704	4	7882	5	2899
2705	4	7882	1	2899
2706	5	7884	1	2582
2707	4	7889	5	2905
2708	5	7890	6	236
2709	4	7892	5	2906
2710	5	7893	2	1432
2711	4	7897	4	658
2712	1	7898	6	29
2713	5	7899	6	1900
2714	1	7901	6	1263
2715	4	7908	2	1369
2716	5	7910	2	2562
2717	4	7911	6	2434
2718	4	7915	2	510
2719	3	7923	7	1760
2720	5	7925	7	2927
2721	4	7926	7	2575
2722	5	7931	7	138
2723	4	7932	3	2352
2724	5	7934	6	2929
2725	4	7937	3	1312
2726	3	7940	5	2926
2727	2	7949	7	1391
2728	3	7951	5	2924
2729	5	7959	5	1529
2730	4	7961	2	2919
2731	4	7962	1	2662
2732	3	7966	3	74
2733	5	7968	2	2004
2734	5	7971	3	154
2735	1	7971	6	154
2736	5	7972	6	156
2737	4	7976	5	2931
2738	5	7977	2	2914
2739	5	7978	1	910
2740	5	7983	2	1019
2741	4	7984	3	315
2742	3	7985	7	2954
2743	4	7988	2	1754
2744	5	7989	7	2936
2745	1	7991	6	2934
2746	5	7992	3	1166
2747	3	7994	1	2945
2748	5	7995	2	442
2749	3	7998	7	585
2750	2	8000	6	1715
2751	1	8006	6	2000
2752	1	8008	1	2960
2753	3	8011	5	1950
2754	5	8015	4	1733
2755	3	8017	5	1834
2756	5	8021	6	2942
2757	4	8031	2	138
2758	3	8032	6	2937
2759	4	8034	5	1015
2760	3	8035	1	1972
2761	3	8039	2	1457
2762	3	8040	2	541
2763	5	8041	6	1537
2764	5	8046	4	1118
2765	4	8049	7	2974
2766	4	8058	4	2971
2767	4	8062	1	1376
2768	4	8065	2	2573
2769	5	8065	6	2573
2770	4	8069	2	2982
2771	4	8070	1	1818
2772	4	8078	7	2843
2773	2	8079	4	2966
2774	3	8083	7	2139
2775	4	8084	1	2980
2776	5	8087	2	2116
2777	4	8091	2	1680
2778	5	8092	6	2984
2779	5	8093	7	1687
2780	5	8095	3	1979
2781	4	8097	1	2282
2782	3	8098	1	708
2783	5	8099	7	2979
2784	3	8103	2	2798
2785	5	8105	5	2007
2786	5	8108	4	2972
2787	4	8109	6	1304
2788	5	8115	5	2672
2789	4	8119	2	2977
2790	3	8120	5	2975
2791	3	8121	7	2976
2792	4	8122	3	2965
2793	4	8123	5	1289
2794	5	8128	6	1295
2795	5	8131	7	601
2796	4	8132	3	2119
2797	3	8133	4	723
2798	5	8137	4	203
2799	1	8141	6	2237
2800	5	8142	5	3009
2801	4	8143	4	2105
2802	5	8147	2	3007
2803	2	8148	3	232
2804	4	8152	1	3011
2805	4	8154	4	2989
2806	4	8161	6	2453
2807	5	8162	6	2762
2808	5	8163	1	691
2809	5	8167	5	2855
2810	5	8169	4	3013
2811	5	8171	2	1760
2812	5	8175	4	2313
2813	3	8178	5	654
2814	5	8180	2	1424
2815	4	8183	2	466
2816	4	8184	5	2991
2817	5	8186	6	1640
2818	3	8187	2	138
2819	5	8188	6	2834
2820	5	8191	6	2710
2821	3	8196	6	1261
2822	5	8199	5	1363
2823	5	8203	2	2996
2824	5	8204	2	2997
2825	3	8211	2	917
2826	5	8213	5	2982
2827	4	8216	4	684
2828	4	8220	2	2664
2829	5	8221	3	119
2830	3	8222	4	2956
2831	5	8223	3	3000
2832	4	8225	5	3001
2833	3	8227	6	3008
2834	5	8233	6	1266
2835	4	8239	3	2922
2836	5	8240	4	2995
2837	4	8242	1	1223
2838	5	8247	7	831
2839	5	8253	3	3024
2840	2	8255	3	1656
2841	5	8257	2	2332
2842	3	8258	1	3030
2843	5	8258	4	3030
2844	4	8263	5	567
2845	3	8265	6	1690
2846	5	8272	3	1279
2847	3	8277	3	2401
2848	4	8279	7	2845
2849	3	8290	5	3049
2850	5	8292	6	3065
2851	3	8297	7	25
2852	4	8298	2	2954
2853	1	8300	3	80
2854	4	8302	7	1233
2855	3	8309	2	2185
2856	5	8314	7	3056
2857	5	8315	4	74
2858	4	8318	4	3044
2859	5	8320	5	3061
2860	3	8326	5	1457
2861	4	8327	4	993
2862	5	8333	3	788
2863	3	8337	1	292
2864	5	8338	4	1803
2865	5	8343	6	1932
2866	5	8346	2	3071
2867	5	8347	4	1170
2868	5	8349	4	790
2869	4	8350	7	868
2870	3	8351	1	2068
2871	5	8352	4	2443
2872	5	8357	6	3093
2873	5	8359	3	2861
2874	3	8362	5	810
2875	2	8365	1	1266
2876	3	8365	3	1266
2877	5	8375	1	1409
2878	3	8375	3	1409
2879	5	8378	3	3072
2880	3	8388	6	784
2881	5	8391	4	71
2882	4	8398	2	3077
2883	5	8401	2	2916
2884	3	8405	2	160
2885	4	8406	2	2100
2886	5	8408	1	1839
2887	5	8412	4	3123
2888	5	8415	1	1481
2889	2	8416	6	573
2890	3	8417	4	3127
2891	5	8418	3	1889
2892	4	8419	1	3117
2893	5	8420	6	1843
2894	5	8424	2	1223
2895	5	8428	6	2519
2896	5	8429	3	3100
2897	4	8432	7	3118
2898	5	8433	3	2796
2899	5	8443	2	74
2900	5	8446	7	2845
2901	5	8452	4	3111
2902	5	8455	7	3105
2903	5	8460	1	3121
2904	3	8462	7	487
2905	5	8464	5	3106
2906	3	8466	2	2079
2907	4	8470	6	3103
2908	5	8471	2	372
2909	3	8474	1	1640
2910	5	8478	6	425
2911	5	8479	2	536
2912	3	8480	1	1924
2913	5	8481	3	931
2914	5	8483	2	1044
2915	5	8484	6	1445
2916	5	8488	2	2349
2917	4	8488	1	2349
2918	4	8489	5	2816
2919	5	8492	1	2126
2920	5	8495	3	2875
2921	4	8495	1	2875
2922	5	8497	6	148
2923	5	8500	4	1101
2924	3	8501	3	3136
2925	3	8506	7	3143
2926	5	8508	6	2975
2927	4	8510	6	351
2928	5	8511	2	1780
2929	2	8513	6	135
2930	5	8516	2	1731
2931	5	8517	5	466
2932	4	8524	5	1273
2933	4	8527	7	2060
2934	3	8530	7	3132
2935	5	8531	1	3035
2936	4	8533	4	532
2937	5	8535	7	3149
2938	4	8536	3	2189
2939	3	8542	6	2064
2940	5	8543	2	3133
2941	3	8544	4	1845
2942	4	8547	6	3131
2943	3	8553	3	1132
2944	3	8553	5	1132
2945	4	8554	2	3101
2946	5	8555	2	560
2947	4	8556	5	609
2948	4	8557	7	228
2949	5	8558	2	1250
2950	5	8560	2	1557
2951	3	8561	1	2793
2952	4	8566	7	980
2953	4	8570	3	1816
2954	4	8574	5	293
2955	4	8575	4	126
2956	3	8579	5	1272
2957	3	8582	1	292
2958	5	8585	4	3176
2959	5	8586	5	3188
2960	4	8587	3	2457
2961	5	8594	6	2111
2962	4	8595	2	1137
2963	4	8598	2	1820
2964	2	8603	3	1358
2965	5	8606	1	3163
2966	3	8620	5	2933
2967	5	8621	6	3187
2968	4	8622	4	547
2969	4	8623	1	1453
2970	5	8625	3	2217
2971	4	8627	1	3165
2972	5	8628	6	342
2973	4	8631	7	3182
2974	3	8632	5	634
2975	5	8640	2	665
2976	5	8642	1	3168
2977	3	8643	1	1938
2978	5	8649	2	1563
2979	5	8650	1	3190
2980	4	8651	6	3183
2981	5	8652	2	3175
2982	5	8653	4	3172
2983	5	8657	1	557
2984	4	8663	2	1281
2985	5	8665	2	304
2986	5	8666	3	3171
2987	5	8679	1	1797
2988	5	8680	2	1072
2989	4	8681	4	3220
2990	5	8681	2	3220
2991	5	8684	6	695
2992	5	8685	5	3212
2993	4	8690	2	3198
2994	4	8697	5	3213
2995	4	8701	4	3197
2996	4	8702	6	3146
2997	4	8704	2	2134
2998	5	8706	5	91
2999	3	8708	3	3223
3000	5	8709	4	1742
3001	5	8711	1	806
3002	4	8715	5	2618
3003	3	8716	3	2025
3004	5	8717	2	1160
3005	2	8721	3	1053
3006	5	8728	2	3224
3007	5	8734	5	3200
3008	5	8735	7	964
3009	4	8740	3	631
3010	4	8746	2	2420
3011	5	8746	6	2420
3012	4	8747	4	1390
3013	4	8750	7	3221
3014	5	8752	1	1767
3015	5	8753	3	382
3016	3	8754	5	3211
3017	5	8756	7	583
3018	5	8758	4	818
3019	2	8758	6	818
3020	5	8759	6	1679
3021	5	8761	6	229
3022	5	8769	7	3209
3023	5	8770	2	3208
3024	5	8771	3	3205
3025	5	8773	2	1522
3026	4	8776	5	1638
3027	5	8778	6	1293
3028	4	8780	5	1492
3029	5	8781	1	3240
3030	5	8782	6	3231
3031	5	8785	3	534
3032	4	8787	3	2799
3033	4	8792	1	1970
3034	5	8808	6	2277
3035	5	8811	6	3238
3036	3	8812	3	1942
3037	4	8816	1	3227
3038	5	8817	4	1700
3039	5	8820	2	1625
3040	5	8821	7	575
3041	1	8822	6	3235
3042	4	8827	7	2694
3043	4	8827	4	2694
3044	5	8832	2	19
3045	4	8834	3	2731
3046	1	8839	6	431
3047	5	8841	7	32
3048	4	8842	5	318
3049	4	8842	6	318
3050	5	8843	7	1570
3051	5	8848	4	3254
3052	5	8849	7	3256
3053	5	8858	2	1140
3054	4	8861	1	3272
3055	3	8862	5	1819
3056	3	8862	7	1819
3057	3	8868	7	2734
3058	4	8871	5	2868
3059	4	8873	7	2662
3060	5	8876	2	3270
3061	4	8881	7	1310
3062	4	8884	4	3266
3063	5	8885	5	3265
3064	4	8886	2	2197
3065	5	8890	1	1289
3066	5	8892	3	3037
3067	5	8893	1	171
3068	4	8897	3	1670
3069	5	8900	2	3293
3070	4	8903	1	2653
3071	5	8909	4	378
3072	5	8911	6	3297
3073	4	8913	5	8
3074	5	8914	4	3292
3075	5	8917	6	2933
3076	4	8918	7	1528
3077	5	8920	6	3102
3078	4	8920	1	3102
3079	5	8924	6	3294
3080	5	8926	3	3285
3081	4	8927	7	3299
3082	4	8928	3	327
3083	4	8929	5	2783
3084	5	8930	6	786
3085	5	8935	5	2605
3086	5	8936	7	3300
3087	3	8939	7	3159
3088	1	8944	6	351
3089	4	8945	2	628
3090	5	8945	7	628
3091	4	8946	5	3296
3092	5	8948	2	151
3093	3	8953	4	3288
3094	5	8955	5	3281
3095	4	8959	3	3286
3096	3	8961	2	564
3097	5	8968	2	1729
3098	5	8969	6	3330
3099	4	8972	5	3323
3100	3	8978	5	763
3101	4	8978	1	763
3102	5	8979	5	709
3103	5	8981	2	2254
3104	5	8981	6	2254
3105	5	8986	3	3326
3106	5	8990	4	2619
3107	4	8993	6	1968
3108	5	8994	7	1282
3109	3	8996	6	3329
3110	4	8996	3	3329
3111	4	9002	5	3309
3112	4	9006	5	2653
3113	5	9009	7	3176
3114	4	9010	2	3331
3115	4	9013	1	970
3116	3	9014	1	975
3117	5	9020	2	439
3118	4	9024	1	2894
3119	4	9035	6	1780
3120	5	9035	5	1780
3121	5	9039	2	544
3122	4	9040	3	3324
3123	5	9041	1	799
3124	4	9044	4	3363
3125	5	9048	1	3348
3126	5	9055	6	1747
3127	5	9058	1	3338
3128	5	9063	2	3360
3129	4	9065	1	1059
3130	3	9069	1	3102
3131	4	9070	6	140
3132	5	9072	1	3364
3133	5	9073	2	3342
3134	4	9074	6	3153
3135	3	9074	4	3153
3136	5	9076	4	3346
3137	5	9077	7	3349
3138	5	9078	4	122
3139	5	9080	3	3361
3140	1	9081	6	3371
3141	5	9084	1	3339
3142	5	9087	2	465
3143	5	9091	6	3340
3144	5	9095	5	3354
3145	5	9096	6	590
3146	5	9112	6	3352
3147	3	9113	1	3126
3148	5	9116	6	173
3149	5	9116	5	173
3150	4	9118	7	3365
3151	2	9118	6	3365
3152	5	9119	1	372
3153	3	9121	6	1289
3154	3	9122	3	1085
3155	5	9123	2	135
3156	5	9126	5	3394
3157	5	9129	2	580
3158	5	9130	1	1194
3159	3	9131	5	2858
3160	5	9132	4	960
3161	5	9136	7	2354
3162	5	9140	4	2723
3163	5	9143	2	3395
3164	5	9153	2	3402
3165	5	9153	6	3402
3166	4	9154	1	3382
3167	5	9155	1	2659
3168	3	9158	5	3397
3169	3	9161	4	560
3170	5	9163	7	3406
3171	5	9165	1	1972
3172	4	9167	5	3387
3173	3	9168	7	3392
3174	5	9170	6	3403
3175	3	9171	3	175
3176	4	9173	1	2573
3177	1	9175	6	3400
3178	1	9178	6	3388
3179	5	9182	7	3396
3180	3	9186	3	826
3181	5	9188	1	2546
3182	5	9194	4	3374
3183	3	9198	3	1914
3184	5	9203	2	3385
3185	5	9212	5	1087
3186	5	9216	2	3378
3187	3	9222	5	3258
3188	4	9224	7	3443
3189	3	9228	7	886
3190	5	9232	4	3440
3191	4	9237	3	3407
3192	1	9242	6	3107
3193	3	9245	1	3277
3194	5	9247	7	2283
3195	5	9249	1	2977
3196	4	9252	7	1760
3197	5	9253	6	2550
3198	5	9255	7	3438
3199	4	9265	2	837
3200	5	9269	4	3427
3201	5	9270	5	2882
3202	1	9273	7	279
3203	3	9275	7	190
3204	4	9276	4	1860
3205	5	9277	2	1147
3206	4	9279	4	1134
3207	4	9285	7	552
3208	3	9285	5	552
3209	4	9286	7	2812
3210	3	9287	7	3429
3211	5	9289	5	1150
3212	1	9291	6	2845
3213	5	9296	3	3434
3214	4	9299	2	676
3215	5	9308	6	2303
3216	5	9312	4	3111
3217	5	9313	2	337
3218	4	9320	2	3428
3219	5	9322	1	3419
3220	5	9323	7	972
3221	4	9327	6	1810
3222	4	9332	5	1514
3223	5	9336	6	3036
3224	5	9342	2	2517
3225	5	9344	1	802
3226	5	9359	6	3435
3227	3	9360	5	3441
3228	2	9361	6	3421
3229	5	9362	5	3450
3230	3	9366	5	3459
3231	4	9367	2	3461
3232	5	9370	4	1905
3233	4	9373	6	3411
3234	4	9377	2	3451
3235	4	9380	2	3464
3236	5	9386	6	1369
3237	4	9391	6	3419
3238	5	9391	2	3419
3239	2	9396	4	826
3240	5	9399	7	3469
3241	5	9403	7	1703
3242	4	9404	4	3457
3243	5	9404	7	3457
3244	5	9405	3	2071
3245	5	9408	6	3471
3246	5	9408	7	3471
3247	5	9409	3	213
3248	3	9413	5	3494
3249	4	9414	7	1046
3250	3	9417	1	3477
3251	5	9418	2	3500
3252	5	9419	7	3119
3253	1	9420	2	3484
3254	2	9423	1	1382
3255	5	9423	2	1382
3256	5	9430	2	3490
3257	3	9432	4	2230
3258	5	9433	2	3480
3259	5	9435	2	2065
3260	5	9441	2	3489
3261	3	9441	1	3489
3262	5	9444	6	3486
3263	4	9448	7	964
3264	2	9454	6	274
3265	4	9455	6	2761
3266	5	9455	1	2761
3267	5	9457	1	2936
3268	5	9462	4	2078
3269	5	9463	2	2332
3270	5	9465	4	2001
3271	5	9470	5	3136
3272	5	9481	5	880
3273	4	9483	6	3040
3274	4	9484	3	2367
3275	5	9491	2	3052
3276	5	9492	4	2065
3277	3	9493	1	3529
3278	5	9495	2	2485
3279	4	9499	1	626
3280	5	9508	3	2902
3281	4	9509	2	2870
3282	2	9511	6	3083
3283	4	9517	1	2181
3284	4	9525	5	1715
3285	3	9527	1	2128
3286	2	9530	5	3524
3287	4	9533	2	2920
3288	3	9534	7	413
3289	4	9536	3	2477
3290	1	9537	6	1765
3291	5	9541	5	820
3292	4	9542	1	265
3293	5	9545	4	3526
3294	5	9549	4	2691
3295	3	9551	5	3517
3296	3	9551	4	3517
3297	5	9553	6	1041
3298	4	9554	7	2237
3299	4	9555	2	2127
3300	5	9559	3	400
3301	5	9563	2	3520
3302	3	9566	5	270
3303	1	9567	6	719
3304	3	9572	5	2252
3305	5	9576	7	2418
3306	5	9579	2	654
3307	4	9581	2	2466
3308	5	9585	1	946
3309	4	9586	6	3543
3310	5	9587	4	3563
3311	4	9589	2	169
3312	5	9590	5	2010
3313	5	9591	1	1369
3314	4	9593	6	1071
3315	3	9596	2	3550
3316	5	9598	1	3330
3317	5	9600	4	2282
3318	4	9601	4	3572
3319	5	9602	3	1531
3320	4	9603	3	1468
3321	5	9605	3	37
3322	3	9607	1	110
3323	5	9608	6	3569
3324	5	9610	4	3568
3325	5	9610	1	3568
3326	5	9611	2	1742
3327	5	9616	6	1831
3328	5	9617	2	656
3329	3	9618	5	3551
3330	5	9620	7	3554
3331	5	9621	2	529
3332	1	9622	5	1337
3333	5	9623	4	3224
3334	3	9627	6	3552
3335	5	9628	2	2116
3336	5	9630	7	970
3337	5	9631	4	729
3338	5	9632	2	3571
3339	3	9634	1	1840
3340	5	9635	2	3558
3341	3	9645	5	2868
3342	5	9646	5	3556
3343	4	9647	7	2555
3344	5	9647	3	2555
3345	5	9650	4	3546
3346	5	9651	7	3539
3347	5	9653	2	3559
3348	5	9655	4	2374
3349	5	9657	2	3553
3350	5	9658	6	3562
3351	5	9660	2	3564
3352	3	9662	3	3380
3353	4	9664	1	3570
3354	5	9670	2	3602
3355	3	9671	2	2446
3356	5	9672	6	3587
3357	3	9677	7	3583
3358	5	9679	1	3599
3359	1	9679	6	3599
3360	5	9680	6	92
3361	5	9683	2	3586
3362	5	9685	1	391
3363	5	9688	2	3574
3364	5	9692	5	1245
3365	3	9698	2	821
3366	4	9700	5	341
3367	5	9708	7	3509
3368	3	9710	1	735
3369	5	9720	5	2695
3370	4	9722	5	489
3371	5	9723	1	203
3372	5	9731	4	3585
3373	5	9731	6	3585
3374	3	9736	3	731
3375	5	9736	6	731
3376	4	9737	4	3173
3377	3	9742	5	3605
3378	5	9745	6	2000
3379	5	9749	7	3059
3380	5	9755	4	2134
3381	1	9757	6	3638
3382	5	9758	5	931
3383	5	9759	7	3640
3384	5	9766	3	2715
3385	2	9769	3	2736
3386	5	9772	2	3634
3387	5	9772	6	3634
3388	4	9773	6	3643
3389	3	9776	4	3623
3390	4	9780	4	3604
3391	5	9784	1	2513
3392	5	9786	6	3612
3393	3	9788	1	2263
3394	4	9790	3	2507
3395	3	9798	6	3335
3396	3	9800	7	2699
3397	5	9807	2	3646
3398	4	9812	1	1810
3399	4	9813	4	3059
3400	5	9815	1	1306
3401	5	9816	5	941
3402	5	9819	1	2232
3403	5	9822	6	3622
3404	5	9829	7	832
3405	4	9834	6	3321
3406	3	9836	3	3626
3407	3	9840	7	3633
3408	4	9844	5	3625
3409	5	9847	5	3614
3410	2	9850	6	2132
3411	3	9851	4	2470
3412	4	9853	5	3644
3413	5	9854	4	3621
3414	5	9856	6	2114
3415	4	9857	1	1993
3416	3	9859	4	3658
3417	2	9862	3	1289
3418	5	9863	6	3653
3419	5	9865	2	1914
3420	3	9866	5	577
3421	2	9868	1	2956
3422	3	9871	4	1070
3423	5	9872	6	3130
3424	2	9876	1	3668
3425	3	9877	6	956
3426	4	9878	2	1373
3427	5	9879	1	2562
3428	5	9880	2	3661
3429	5	9885	1	2583
3430	5	9885	5	2583
3431	5	9893	4	311
3432	5	9894	4	650
3433	4	9895	1	1412
3434	5	9897	4	1754
3435	5	9899	5	2358
3436	5	9900	6	3647
3437	4	9902	1	1924
3438	4	9903	2	654
3439	5	9909	4	2445
3440	3	9913	3	3579
3441	5	9916	7	3671
3442	3	9917	5	3670
3443	3	9921	1	3667
3444	5	9927	3	1963
3445	3	9928	2	41
3446	5	9935	1	3651
3447	1	9936	6	816
3448	5	9937	7	172
3449	5	9939	4	3655
3450	4	9940	7	2243
3451	3	9946	7	3654
3452	4	9947	5	1161
3453	5	9948	4	1569
3454	5	9951	1	3681
3455	4	9952	2	232
3456	5	9953	2	236
3457	3	9954	4	2283
3458	3	9956	5	2781
3459	5	9959	4	3343
3460	5	9961	4	2706
3461	5	9962	6	2143
3462	5	9965	1	3664
3463	5	9965	6	3664
3464	5	9966	2	1311
3465	4	9971	1	3669
3466	5	9972	5	136
3467	5	9978	3	2868
3468	4	9979	1	2070
3469	5	9980	1	2960
3470	5	9981	1	3656
3471	5	9987	6	2386
3472	5	9988	2	2125
3473	5	9989	2	3708
3474	5	9990	6	3688
3475	5	9991	6	1107
3476	5	9998	7	3043
3477	5	10004	6	3692
3478	4	10005	2	1968
3479	4	10006	5	3684
3480	5	10007	2	1699
3481	5	10013	4	3713
3482	4	10019	7	379
3483	3	10021	7	2832
3484	4	10023	1	2570
3485	4	10024	2	3460
3486	3	10026	7	1481
3487	5	10031	4	180
3488	5	10040	2	3699
3489	5	10041	6	2728
3490	2	10043	7	3700
3491	5	10044	6	1448
3492	5	10046	3	3739
3493	5	10052	6	1344
3494	5	10057	4	3740
3495	4	10060	4	3343
3496	5	10065	3	3733
3497	4	10066	7	3746
3498	5	10069	5	2083
3499	5	10071	1	1375
3500	5	10073	5	2398
3501	4	10082	3	3734
3502	3	10083	7	2599
3503	5	10085	7	3719
3504	5	10086	2	695
3505	4	10087	7	3211
3506	4	10088	5	153
3507	3	10089	5	973
3508	3	10089	7	973
3509	5	10090	6	3742
3510	5	10091	4	1834
3511	3	10092	7	2733
3512	5	10095	5	310
3513	5	10097	3	3379
3514	4	10098	3	946
3515	5	10099	6	3363
3516	5	10101	6	1131
3517	5	10101	1	1131
3518	5	10103	2	3052
3519	5	10106	2	3139
3520	1	10107	6	612
3521	4	10108	1	2851
3522	5	10110	5	669
3523	4	10112	4	2956
3524	4	10113	7	2507
3525	5	10117	3	2193
3526	1	10121	6	1309
3527	2	10124	1	63
3528	4	10126	6	1172
3529	3	10130	2	2139
3530	5	10131	7	3780
3531	4	10133	1	3252
3532	5	10135	5	122
3533	5	10139	2	475
3534	5	10140	4	3765
3535	5	10141	2	1103
3536	2	10144	1	3764
3537	5	10148	7	389
3538	5	10149	5	3228
3539	5	10150	1	2619
3540	5	10151	1	3776
3541	5	10155	4	3766
3542	5	10157	2	2025
3543	5	10161	2	1166
3544	3	10162	7	3289
3545	4	10163	3	3757
3546	4	10164	2	3754
3547	3	10165	1	1323
3548	5	10166	6	3753
3549	5	10169	6	3779
3550	5	10171	2	1465
3551	5	10178	2	1796
3552	5	10182	1	78
3553	5	10184	2	765
3554	5	10186	7	3172
3555	5	10189	6	636
3556	5	10193	6	3748
3557	3	10196	7	3751
3558	4	10197	5	3755
3559	5	10199	4	2081
3560	5	10200	2	1842
3561	1	10203	6	3761
3562	3	10205	7	3190
3563	5	10208	6	3775
3564	2	10214	5	2291
3565	5	10215	2	3789
3566	5	10216	2	2088
3567	5	10221	1	318
3568	5	10223	2	3793
3569	4	10228	3	2309
3570	4	10228	4	2309
3571	4	10229	6	708
3572	5	10230	6	977
3573	4	10232	4	2000
3574	4	10232	1	2000
3575	5	10233	2	3480
3576	5	10234	2	3790
3577	5	10236	3	2901
3578	5	10239	2	3794
3579	5	10241	7	3784
3580	1	10241	4	3784
3581	5	10247	3	44
3582	5	10249	3	269
3583	3	10252	5	2538
3584	5	10254	4	3811
3585	5	10257	6	3815
3586	4	10258	5	3804
3587	5	10259	4	3797
3588	5	10262	7	3059
3589	4	10266	1	783
3590	5	10268	4	3786
3591	4	10271	5	3662
3592	3	10271	1	3662
3593	5	10273	6	2938
3594	3	10280	1	3553
3595	4	10288	5	3048
3596	5	10291	1	3805
3597	5	10293	2	1120
3598	5	10295	5	3782
3599	5	10299	2	3787
3600	1	10301	6	1574
3601	4	10305	2	3821
3602	5	10310	1	1698
3603	5	10312	4	3019
3604	3	10314	5	415
3605	4	10320	7	3841
3606	5	10321	7	3831
3607	4	10323	3	3233
3608	5	10324	7	1115
3609	4	10325	7	790
3610	3	10326	5	3853
3611	4	10328	1	1184
3612	3	10335	3	2101
3613	4	10338	2	3851
3614	3	10340	1	2275
3615	5	10344	1	3827
3616	4	10347	3	3845
3617	5	10348	6	227
3618	4	10352	3	3816
3619	4	10352	7	3816
3620	5	10356	6	2000
3621	5	10359	7	3837
3622	3	10361	2	1025
3623	4	10365	2	3829
3624	2	10366	3	2277
3625	4	10371	3	454
3626	5	10374	6	3855
3627	5	10379	4	1055
3628	4	10380	2	3852
3629	5	10381	3	3830
3630	4	10384	5	2811
3631	5	10385	5	1713
3632	4	10388	4	3882
3633	5	10390	4	3884
3634	1	10397	7	1276
3635	4	10400	4	2268
3636	5	10405	5	2386
3637	3	10407	5	3870
3638	5	10408	2	171
3639	5	10417	2	3863
3640	5	10420	7	2776
3641	5	10422	5	3679
3642	5	10423	3	1088
3643	4	10427	5	2674
3644	4	10437	2	3872
3645	5	10438	3	2993
3646	5	10442	3	3146
3647	5	10443	7	1960
3648	5	10444	2	623
3649	4	10448	1	1889
3650	5	10449	3	2543
3651	1	10450	6	826
3652	4	10453	1	2416
3653	5	10457	7	3152
3654	4	10458	4	1176
3655	5	10463	1	640
3656	3	10464	6	3385
3657	4	10464	3	3385
3658	4	10465	7	3493
3659	5	10468	6	2931
3660	4	10474	3	3205
3661	5	10476	6	2125
3662	5	10477	6	3538
3663	3	10480	3	1427
3664	4	10482	3	3873
3665	4	10485	5	3002
3666	4	10486	1	3539
3667	1	10491	6	3883
3668	5	10494	6	3859
3669	3	10498	2	1258
3670	4	10501	4	1435
3671	4	10503	3	2470
3672	4	10505	4	3908
3673	5	10508	2	3915
3674	4	10511	6	593
3675	5	10520	4	1729
3676	4	10521	6	1674
3677	5	10524	2	3918
3678	3	10526	1	1485
3679	5	10529	2	1344
3680	5	10530	6	3100
3681	5	10532	5	706
3682	3	10536	7	2804
3683	5	10543	5	3893
3684	3	10545	4	3456
3685	5	10550	1	3923
3686	5	10551	6	2853
3687	5	10555	5	3910
3688	4	10561	2	3913
3689	5	10565	7	3224
3690	4	10567	2	3902
3691	4	10570	5	3139
3692	4	10571	1	299
3693	5	10576	4	653
3694	4	10579	1	3917
3695	5	10586	2	2872
3696	4	10590	5	3886
3697	4	10597	5	3899
3698	5	10598	7	1892
3699	5	10605	4	3921
3700	5	10606	2	3888
3701	5	10607	2	3771
3702	5	10608	6	1755
3703	5	10615	1	813
3704	5	10618	5	729
3705	5	10619	6	2520
3706	5	10621	2	2951
3707	5	10623	2	1592
3708	5	10625	3	2064
3709	3	10632	7	355
3710	5	10635	4	741
3711	5	10636	6	3861
3712	4	10637	7	2573
3713	5	10644	2	3945
3714	5	10646	7	3957
3715	4	10649	7	62
3716	3	10650	1	3934
3717	5	10651	7	295
3718	4	10653	1	3385
3719	4	10660	7	3947
3720	5	10661	1	981
3721	5	10663	4	1531
3722	4	10667	6	2843
3723	5	10674	7	3927
3724	3	10675	5	3709
3725	4	10677	7	437
3726	5	10680	4	1507
3727	5	10685	4	3940
3728	5	10695	2	1317
3729	5	10697	3	3752
3730	5	10698	6	1087
3731	5	10701	1	2416
3732	1	10703	6	3931
3733	4	10705	4	2333
3734	5	10707	2	3970
3735	3	10709	7	1173
3736	5	10711	2	29
3737	5	10713	4	3964
3738	5	10713	6	3964
3739	5	10714	4	1379
3740	5	10717	5	3348
3741	3	10722	5	1705
3742	5	10724	7	3977
3743	4	10728	2	1081
3744	4	10733	7	285
3745	5	10735	4	1025
3746	3	10735	1	1025
3747	3	10736	2	3985
3748	3	10743	5	1485
3749	5	10744	3	1259
3750	4	10747	1	2427
3751	3	10752	5	2583
3752	5	10756	5	3960
3753	3	10757	3	3362
3754	5	10759	7	3713
3755	5	10760	5	3966
3756	4	10766	5	3993
3757	5	10768	3	3324
3758	1	10769	6	1536
3759	5	10771	2	3971
3760	3	10772	5	1548
3761	4	10776	2	62
3762	4	10777	6	3153
3763	5	10778	7	3221
3764	1	10781	6	528
3765	5	10783	6	4031
3766	3	10784	5	3996
3767	4	10788	1	4021
3768	4	10789	1	4019
3769	1	10797	5	1318
3770	5	10798	2	1657
3771	3	10802	2	3848
3772	3	10804	3	274
3773	4	10806	7	4024
3774	3	10807	7	1352
3775	3	10817	5	3623
3776	4	10820	1	2770
3777	5	10821	4	2165
3778	5	10825	2	3863
3779	5	10830	6	839
3780	3	10832	5	4017
3781	3	10839	4	4018
3782	3	10842	5	3825
3783	5	10848	1	4029
3784	4	10852	1	352
3785	5	10859	4	3211
3786	5	10866	6	4032
3787	5	10868	6	1097
3788	5	10868	3	1097
3789	5	10870	7	1848
3790	5	10872	2	4010
3791	5	10876	6	3240
3792	4	10878	1	4059
3793	3	10878	3	4059
3794	3	10880	3	3392
3795	5	10882	1	74
3796	5	10883	2	3614
3797	5	10887	2	3847
3798	5	10889	6	1775
3799	5	10890	7	1811
3800	5	10891	6	4056
3801	4	10892	3	2287
3802	4	10905	3	4049
3803	5	10906	6	4045
3804	5	10908	1	1095
3805	5	10909	6	4038
3806	2	10912	1	1649
3807	5	10914	2	4062
3808	5	10918	7	213
3809	5	10919	5	713
3810	2	10920	3	4041
3811	2	10930	7	2436
3812	5	10933	4	2838
3813	5	10938	6	3843
3814	5	10942	4	3681
3815	5	10950	2	419
3816	4	10952	3	4043
3817	5	10953	5	4060
3818	3	10957	2	2768
3819	5	10958	4	2606
3820	5	10962	6	4044
3821	5	10963	4	3012
3822	1	10964	6	3487
3823	5	10965	6	2001
3824	5	10967	4	4066
3825	4	10969	1	1531
3826	3	10971	7	2358
3827	3	10973	3	1308
3828	5	10974	7	3679
3829	5	10978	1	4081
3830	5	10985	1	455
3831	5	10991	6	1280
3832	5	10992	7	4075
3833	5	10997	6	4101
3834	5	10998	2	139
3835	5	11000	2	4078
3836	4	11003	7	4072
3837	5	11004	1	3715
3838	4	11009	5	3467
3839	5	11018	6	2546
3840	3	11022	1	41
3841	5	11024	7	1303
3842	5	11026	7	1656
3843	5	11032	1	2207
3844	4	11032	7	2207
3845	5	11034	6	3371
3846	5	11035	5	577
3847	5	11041	2	427
3848	5	11041	7	427
3849	5	11042	3	4104
3850	3	11043	7	4069
3851	4	11045	7	4088
3852	4	11046	3	3165
3853	5	11049	6	4134
3854	5	11050	4	706
3855	4	11053	7	4142
3856	5	11055	4	424
3857	3	11056	7	3153
3858	1	11057	1	2055
3859	5	11059	6	338
3860	5	11060	4	4124
3861	5	11061	5	4119
3862	5	11064	6	1167
3863	5	11064	5	1167
3864	5	11075	2	2193
3865	3	11076	5	3126
3866	5	11077	6	2602
3867	5	11078	4	1058
3868	3	11081	6	1220
3869	4	11082	2	701
3870	5	11089	1	3491
3871	4	11090	1	111
3872	4	11091	5	4125
3873	5	11092	3	208
3874	1	11095	6	945
3875	5	11098	6	4120
3876	5	11099	6	3707
3877	4	11100	6	138
3878	3	11106	5	2570
3879	5	11116	2	4057
3880	4	11120	2	2507
3881	5	11122	4	2948
3882	5	11125	2	4141
3883	5	11126	1	4127
3884	3	11127	3	921
3885	5	11129	1	788
3886	5	11130	3	1529
3887	4	11131	3	4115
3888	3	11133	7	3202
3889	4	11135	4	3755
3890	5	11137	5	3892
3891	3	11139	1	4121
3892	5	11141	6	4129
3893	3	11145	7	2998
3894	1	11148	6	492
3895	3	11152	3	1204
3896	3	11152	1	1204
3897	3	11153	3	3868
3898	5	11156	2	1900
3899	4	11157	4	372
3900	2	11163	3	1686
3901	5	11164	4	4133
3902	5	11164	2	4133
3903	4	11168	2	401
3904	4	11170	5	4113
3905	4	11175	2	4161
3906	3	11178	4	2597
3907	4	11182	7	1088
3908	5	11185	2	1025
3909	5	11187	6	4181
3910	4	11189	3	4164
3911	3	11192	5	528
3912	3	11197	6	4176
3913	4	11200	6	4152
3914	3	11203	3	2434
3915	4	11205	3	25
3916	3	11206	1	4177
3917	5	11207	3	4149
3918	5	11218	6	4159
3919	4	11221	1	3976
3920	3	11224	5	3574
3921	3	11226	7	4185
3922	4	11228	6	1518
3923	3	11229	1	4169
3924	4	11233	6	4153
3925	3	11234	4	1859
3926	3	11235	7	4179
3927	3	11236	3	2821
3928	5	11237	1	4178
3929	4	11245	1	54
3930	4	11247	6	907
3931	5	11252	2	4158
3932	4	11256	7	3883
3933	5	11258	6	4003
3934	3	11259	5	863
3935	4	11264	5	3853
3936	5	11265	2	1971
3937	5	11274	1	4166
3938	5	11275	5	1729
3939	5	11275	4	1729
3940	5	11277	6	1727
3941	4	11278	6	729
3942	4	11279	5	1260
3943	4	11280	2	2351
3944	4	11281	5	2540
3945	5	11285	2	2588
3946	5	11286	4	2590
3947	5	11287	4	3048
3948	5	11288	6	1476
3949	5	11289	1	1917
3950	5	11293	6	1269
3951	1	11298	4	1294
3952	4	11298	5	1294
3953	3	11299	2	2025
3954	5	11301	2	709
3955	5	11302	4	4189
3956	3	11303	7	2653
3957	5	11306	4	1956
3958	4	11308	6	4167
3959	3	11311	5	4173
3960	5	11316	5	2425
3961	5	11319	6	4182
3962	3	11320	4	179
3963	5	11321	3	1306
3964	4	11328	7	4150
3965	4	11331	2	382
3966	5	11332	1	4207
3967	3	11335	7	642
3968	2	11340	6	4195
3969	3	11341	2	4197
3970	3	11342	7	2404
3971	4	11343	7	4210
3972	5	11343	6	4210
3973	3	11344	1	4208
3974	4	11346	3	3949
3975	5	11348	6	4196
3976	5	11351	7	4214
3977	4	11351	5	4214
3978	5	11354	5	4193
3979	5	11355	6	4219
3980	1	11357	6	3545
3981	5	11359	7	80
3982	5	11360	7	4211
3983	4	11362	6	4205
3984	5	11364	6	1085
3985	5	11365	1	4200
3986	3	11367	7	1390
3987	5	11368	1	675
3988	4	11369	2	84
3989	3	11371	4	1720
3990	5	11373	6	4199
3991	3	11374	5	3116
3992	1	11382	6	1314
3993	5	11388	2	2605
3994	4	11391	4	931
3995	3	11392	6	547
3996	5	11393	6	4201
3997	4	11394	5	4243
3998	4	11395	1	2633
3999	5	11396	6	3739
4000	5	11397	2	3082
4001	1	11398	7	4043
4002	5	11401	2	946
4003	4	11402	7	4230
4004	3	11407	5	2730
4005	3	11408	5	3827
4006	5	11409	7	3320
4007	2	11413	4	4224
4008	5	11418	3	563
4009	5	11422	2	4240
4010	5	11428	5	1627
4011	5	11432	6	1223
4012	3	11432	4	1223
4013	5	11433	6	3619
4014	5	11437	6	2887
4015	4	11441	3	4250
4016	2	11450	6	426
4017	4	11451	7	4232
4018	4	11451	5	4232
4019	5	11454	6	169
4020	5	11456	4	4238
4021	4	11457	5	4259
4022	4	11467	7	489
4023	4	11474	4	4299
4024	5	11475	1	2540
4025	3	11478	7	2327
4026	3	11479	5	4290
4027	5	11485	5	3076
4028	4	11495	6	4118
4029	5	11497	6	4277
4030	3	11499	5	3757
4031	5	11500	6	3343
4032	4	11508	2	4272
4033	4	11510	6	1869
4034	2	11511	3	1148
4035	5	11518	4	4265
4036	4	11521	2	511
4037	3	11523	4	2885
4038	5	11529	2	932
4039	4	11530	7	4294
4040	5	11532	2	1677
4041	5	11534	2	1365
4042	4	11536	6	4293
4043	5	11539	6	3752
4044	5	11540	6	2264
4045	5	11542	6	528
4046	4	11542	7	528
4047	5	11546	4	3722
4048	5	11548	6	490
4049	1	11549	6	4287
4050	5	11551	1	3491
4051	4	11552	6	4284
4052	5	11553	4	4289
4053	5	11554	1	790
4054	5	11555	1	1795
4055	5	11559	4	3788
4056	4	11561	6	4281
4057	5	11563	1	4248
4058	5	11565	6	3372
4059	4	11573	4	3160
4060	5	11577	3	3600
4061	4	11586	7	4310
4062	5	11590	5	3115
4063	5	11591	7	2122
4064	4	11594	4	699
4065	5	11598	3	362
4066	3	11602	4	1344
4067	5	11608	7	2451
4068	4	11611	2	349
4069	4	11613	2	4314
4070	5	11620	2	847
4071	5	11622	4	3119
4072	4	11624	2	489
4073	5	11630	2	4170
4074	4	11637	1	359
4075	5	11640	2	4304
4076	5	11642	2	4329
4077	4	11646	7	3794
4078	2	11648	1	2845
4079	4	11652	5	3711
4080	4	11654	3	240
4081	3	11662	4	633
4082	3	11664	4	96
4083	5	11665	7	2580
4084	5	11666	5	567
4085	5	11671	2	44
4086	5	11672	4	2815
4087	5	11680	4	4315
4088	1	11686	4	679
4089	4	11688	1	438
4090	5	11693	2	1729
4091	3	11695	6	2511
4092	4	11696	3	3016
4093	3	11698	5	440
4094	2	11703	2	2072
4095	5	11704	2	4346
4096	5	11704	6	4346
4097	5	11705	2	2291
4098	4	11706	6	1309
4099	3	11711	2	4336
4100	5	11712	6	3728
4101	3	11713	2	2065
4102	4	11714	4	4354
4103	3	11715	3	833
4104	5	11717	1	1085
4105	5	11719	6	581
4106	3	11721	7	927
4107	5	11723	5	1468
4108	5	11724	3	4361
4109	5	11725	4	4339
4110	3	11729	4	3494
4111	5	11733	6	295
4112	4	11744	1	2774
4113	4	11745	3	3961
4114	5	11746	6	767
4115	5	11751	7	383
4116	5	11755	6	2790
4117	2	11756	2	1320
4118	4	11760	6	2562
4119	4	11764	5	4343
4120	4	11765	7	2366
4121	5	11768	6	4337
4122	5	11771	2	1473
4123	5	11772	5	4357
4124	5	11774	6	4299
4125	5	11777	2	4356
4126	5	11778	7	4360
4127	4	11779	3	2517
4128	5	11782	3	4372
4129	5	11783	1	1380
4130	1	11784	6	4403
4131	3	11788	1	4402
4132	5	11790	4	4398
4133	5	11795	3	4399
4134	5	11797	3	424
4135	3	11797	7	424
4136	5	11799	5	2465
4137	4	11806	2	2088
4138	5	11808	4	569
4139	5	11811	2	2771
4140	4	11816	4	4422
4141	3	11816	7	4422
4142	1	11817	4	4427
4143	4	11818	3	4419
4144	5	11822	4	2469
4145	4	11826	3	1089
4146	2	11830	2	2119
4147	3	11832	3	1687
4148	1	11833	6	1504
4149	4	11835	7	243
4150	5	11836	1	4415
4151	5	11843	7	2843
4152	5	11848	6	2538
4153	5	11849	1	4416
4154	3	11850	5	729
4155	5	11854	2	3940
4156	5	11860	1	470
4157	3	11862	5	1267
4158	4	11867	1	2000
4159	5	11875	1	203
4160	4	11876	5	2052
4161	3	11877	2	2071
4162	5	11879	1	2647
4163	5	11886	3	3260
4164	5	11888	6	34
4165	5	11888	1	34
4166	5	11889	6	211
4167	5	11890	7	4410
4168	5	11894	5	444
4169	4	11898	3	4380
4170	5	11900	3	4388
4171	5	11901	2	1996
4172	5	11902	6	4409
4173	5	11909	6	3600
4174	5	11912	6	2729
4175	3	11913	5	1376
4176	5	11915	7	1598
4177	5	11918	2	229
4178	5	11919	4	3086
4179	3	11919	7	3086
4180	5	11921	1	4441
4181	5	11924	6	1686
4182	4	11926	7	3345
4183	4	11930	7	2653
4184	5	11931	6	2728
4185	5	11932	2	3567
4186	4	11937	2	3393
4187	5	11938	3	4467
4188	5	11942	3	4192
4189	5	11943	6	4457
4190	5	11950	7	1560
4191	3	11952	3	3112
4192	4	11956	7	4465
4193	5	11956	3	4465
4194	5	11964	1	730
4195	4	11967	5	3619
4196	4	11969	3	1337
4197	3	11972	6	4432
4198	4	11978	7	212
4199	5	11982	4	3289
4200	5	11985	6	2644
4201	5	11987	4	89
4202	3	11988	4	2054
4203	4	11988	7	2054
4204	5	11991	4	1409
4205	4	11993	5	4108
4206	5	11996	2	401
4207	4	11999	5	125
4208	4	12000	5	3066
4209	5	12003	5	1618
4210	5	12004	4	4428
4211	5	12012	3	4106
4212	1	12012	6	4106
4213	5	12015	4	2798
4214	3	12017	5	643
4215	5	12019	6	4446
4216	1	12022	6	3121
4217	3	12027	7	4438
4218	3	12029	1	274
4219	5	12033	6	308
4220	5	12038	7	3338
4221	3	12041	2	154
4222	5	12042	2	4456
4223	5	12043	1	917
4224	3	12044	6	4452
4225	5	12044	5	4452
4226	2	12046	2	4279
4227	3	12056	2	272
4228	5	12061	1	4448
4229	5	12062	1	514
4230	4	12064	1	4475
4231	4	12068	4	3219
4232	5	12071	6	1632
4233	3	12072	3	138
4234	5	12075	1	4507
4235	5	12076	6	4495
4236	5	12077	7	3721
4237	5	12078	6	2567
4238	5	12085	2	4502
4239	5	12087	7	2571
4240	4	12087	1	2571
4241	5	12090	6	4482
4242	4	12096	4	4506
4243	5	12098	1	2759
4244	5	12099	5	4468
4245	4	12103	5	4488
4246	3	12104	3	1681
4247	3	12105	3	3634
4248	5	12106	5	1740
4249	5	12108	5	4489
4250	5	12113	2	4505
4251	5	12114	1	4487
4252	3	12122	7	3540
4253	4	12123	5	4498
4254	5	12128	6	4509
4255	5	12129	2	2000
4256	4	12130	1	4478
4257	5	12132	1	4258
4258	5	12133	4	4469
4259	3	12134	7	358
4260	4	12136	7	2962
4261	4	12137	1	3853
4262	4	12144	7	2310
4263	4	12146	6	4533
4264	5	12147	2	4541
4265	5	12149	2	2776
4266	5	12149	7	2776
4267	5	12155	3	4537
4268	4	12156	5	1023
4269	4	12160	7	4544
4270	4	12161	5	1742
4271	3	12169	1	4517
4272	5	12171	1	802
4273	5	12175	6	766
4274	2	12177	1	4523
4275	5	12178	6	2867
4276	5	12179	7	3160
4277	3	12184	5	4364
4278	4	12185	1	4510
4279	5	12193	6	4542
4280	3	12193	3	4542
4281	5	12197	1	3896
4282	5	12199	6	4514
4283	4	12200	3	1306
4284	5	12204	2	1191
4285	2	12211	2	4558
4286	5	12215	2	4589
4287	5	12217	4	467
4288	4	12220	2	4365
4289	3	12225	7	4587
4290	4	12227	5	4557
4291	3	12232	5	3527
4292	5	12237	1	4552
4293	3	12241	7	1615
4294	2	12242	1	4582
4295	5	12243	4	4577
4296	5	12245	1	4574
4297	3	12246	1	1840
4298	5	12248	2	1138
4299	4	12249	6	3537
4300	3	12249	7	3537
4301	4	12251	4	4580
4302	5	12253	1	1645
4303	4	12266	7	4555
4304	4	12267	3	4411
4305	5	12268	5	1406
4306	5	12269	7	2050
4307	5	12273	4	2123
4308	5	12274	5	4571
4309	5	12276	3	4287
4310	5	12277	2	4561
4311	5	12278	4	4563
4312	3	12280	2	4547
4313	3	12281	3	4553
4314	5	12286	7	4573
4315	5	12288	4	1376
4316	1	12291	6	798
4317	2	12294	6	4578
4318	5	12295	3	1269
4319	5	12296	4	1272
4320	5	12297	2	2184
4321	5	12298	5	4556
4322	5	12299	4	1337
4323	3	12304	2	4586
4324	5	12306	7	1813
4325	3	12307	5	223
4326	5	12308	2	4548
4327	5	12314	3	3372
4328	5	12315	2	2799
4329	5	12316	1	1820
4330	5	12316	5	1820
4331	3	12319	5	1273
4332	5	12320	4	916
4333	3	12322	5	2140
4334	3	12323	5	2160
4335	5	12328	7	4619
4336	4	12329	4	4594
4337	5	12331	6	1167
4338	3	12334	3	4631
4339	4	12338	4	3123
4340	5	12342	2	3745
4341	5	12344	3	4635
4342	5	12347	4	1447
4343	4	12347	3	1447
4344	3	12348	1	4614
4345	5	12352	7	681
4346	4	12354	3	4636
4347	4	12356	5	4339
4348	5	12365	1	4595
4349	5	12367	4	654
4350	5	12369	5	4600
4351	4	12370	3	4622
4352	5	12371	2	4146
4353	2	12373	2	2748
4354	4	12375	1	4607
4355	5	12379	4	3540
4356	5	12381	4	4613
4357	5	12384	2	4629
4358	5	12387	2	2783
4359	5	12392	4	4605
4360	4	12401	2	401
4361	5	12402	3	1893
4362	3	12403	1	3393
4363	5	12404	2	4632
4364	5	12406	7	1696
4365	4	12408	4	4598
4366	1	12409	6	4621
4367	4	12409	7	4621
4368	4	12419	1	197
4369	5	12421	2	227
4370	5	12422	5	3887
4371	1	12423	6	4612
4372	5	12423	3	4612
4373	5	12426	1	1811
4374	3	12428	5	4609
4375	5	12429	4	3754
4376	4	12430	7	4224
4377	1	12431	6	748
4378	3	12439	2	1587
4379	4	12440	2	997
4380	4	12440	3	997
4381	5	12442	7	931
4382	4	12443	1	1927
4383	4	12446	7	252
4384	3	12448	5	4509
4385	4	12448	2	4509
4386	5	12452	6	4459
4387	4	12454	2	3956
4388	5	12457	4	1390
4389	5	12464	7	2165
4390	5	12465	2	3870
4391	5	12466	7	2910
4392	5	12471	1	4254
4393	4	12479	6	3172
4394	3	12482	1	4659
4395	5	12483	3	4656
4396	4	12485	4	4661
4397	5	12486	2	1831
4398	5	12487	1	3040
4399	5	12487	6	3040
4400	5	12496	1	546
4401	4	12497	7	3858
4402	4	12504	5	4665
4403	4	12506	5	376
4404	5	12508	2	3211
4405	5	12509	1	271
4406	5	12510	7	3433
4407	4	12512	3	4645
4408	5	12513	2	1760
4409	5	12524	1	4640
4410	3	12524	7	4640
4411	5	12525	1	4663
4412	5	12532	6	1093
4413	5	12539	7	1263
4414	4	12539	5	1263
4415	2	12540	3	3459
4416	4	12545	1	743
4417	4	12548	1	1442
4418	3	12549	5	3393
4419	4	12550	1	822
4420	5	12559	6	4675
4421	2	12559	1	4675
4422	5	12560	2	1088
4423	3	12561	2	2741
4424	5	12563	1	2608
4425	5	12564	2	4704
4426	1	12567	1	1900
4427	4	12568	1	95
4428	5	12575	5	4141
4429	3	12581	7	4686
4430	3	12584	1	4707
4431	1	12586	1	1834
4432	5	12588	6	207
4433	4	12589	1	378
4434	5	12591	6	420
4435	5	12592	7	1940
4436	5	12594	6	4674
4437	5	12598	4	4716
4438	4	12599	1	3063
4439	5	12601	5	3451
4440	5	12604	6	245
4441	5	12605	7	3540
4442	5	12610	7	4708
4443	3	12613	5	2266
4444	3	12615	3	4700
4445	5	12619	3	3730
4446	5	12623	4	3069
4447	5	12632	6	4687
4448	4	12633	7	4697
4449	5	12636	6	4705
4450	3	12641	7	1988
4451	5	12642	7	2289
4452	5	12643	4	1768
4453	5	12644	3	1859
4454	5	12649	1	1369
4455	5	12650	5	4690
4456	5	12651	7	4719
4457	5	12655	4	1729
4458	4	12657	2	4682
4459	5	12660	3	1569
4460	4	12661	7	3388
4461	5	12666	1	4042
4462	4	12667	2	2553
4463	5	12668	5	2928
4464	3	12673	5	172
4465	4	12677	5	4730
4466	3	12685	2	4655
4467	4	12686	5	4733
4468	4	12688	2	4771
4469	5	12699	1	2440
4470	5	12705	6	4766
4471	5	12706	6	4747
4472	3	12707	1	4445
4473	5	12711	7	499
4474	4	12713	7	4292
4475	4	12716	1	2995
4476	5	12717	5	2664
4477	5	12721	5	4738
4478	4	12723	5	4062
4479	3	12724	3	4672
4480	2	12725	1	4732
4481	4	12726	1	876
4482	5	12728	3	2618
4483	5	12731	1	4750
4484	5	12734	3	4763
4485	3	12734	4	4763
4486	5	12735	2	3864
4487	4	12743	3	2867
4488	5	12745	4	4723
4489	5	12749	3	1255
4490	5	12753	5	4742
4491	5	12755	4	2932
4492	4	12756	6	1376
4493	5	12763	6	2065
4494	5	12767	2	4767
4495	3	12773	4	2546
4496	5	12774	4	4737
4497	5	12776	2	2951
4498	5	12777	6	2590
4499	4	12785	7	376
4500	5	12789	6	1236
4501	4	12790	6	96
4502	5	12795	7	4088
4503	4	12796	7	1192
4504	4	12797	5	1956
4505	3	12798	5	3051
4506	5	12799	1	4282
4507	5	12800	6	638
4508	5	12804	3	1289
4509	2	12805	3	4710
4510	5	12806	3	4768
4511	4	12807	7	4727
4512	5	12808	4	2434
4513	5	12809	3	1371
4514	5	12810	7	3248
4515	5	12811	6	4741
4516	5	12815	1	2954
4517	1	12816	4	2916
4518	4	12818	1	4729
4519	5	12822	3	3227
4520	5	12827	4	444
4521	3	12829	1	4122
4522	5	12839	1	4559
4523	5	12845	4	21
4524	4	12846	7	4817
4525	5	12851	4	4714
4526	3	12852	5	1153
4527	4	12855	5	4807
4528	4	12856	7	833
4529	5	12859	4	2420
4530	4	12866	7	3901
4531	5	12867	2	655
4532	4	12868	7	4799
4533	4	12869	7	917
4534	5	12870	1	204
4535	4	12872	7	4007
4536	5	12874	2	4811
4537	4	12875	1	2889
4538	2	12877	5	4792
4539	4	12877	7	4792
4540	4	12878	5	964
4541	4	12879	7	3205
4542	5	12882	6	4808
4543	5	12883	6	466
4544	4	12884	7	4796
4545	5	12886	7	3101
4546	5	12894	7	4815
4547	5	12895	7	2653
4548	1	12896	1	4778
4549	5	12901	4	4802
4550	5	12904	2	4793
4551	5	12916	4	220
4552	5	12917	3	822
4553	4	12918	2	486
4554	5	12919	2	4524
4555	5	12922	7	542
4556	3	12925	3	1119
4557	5	12926	7	2855
4558	4	12927	2	580
4559	5	12929	4	260
4560	5	12930	7	4831
4561	5	12934	6	4802
4562	5	12941	6	512
4563	5	12942	4	4824
4564	5	12943	4	2083
4565	3	12948	5	4043
4566	4	12951	4	612
4567	1	12954	5	3678
4568	4	12957	6	3553
4569	3	12959	7	4845
4570	1	12961	6	304
4571	3	12962	3	2867
4572	5	12965	2	4839
4573	5	12965	7	4839
4574	5	12968	6	4578
4575	5	12969	7	3996
4576	4	12970	5	4849
4577	5	12974	1	826
4578	5	12978	3	711
4579	2	12981	6	4832
4580	3	12989	5	1215
4581	5	12990	2	1756
4582	4	12991	2	1380
4583	5	12992	3	4828
4584	5	12994	6	2527
4585	5	12995	5	822
4586	5	12997	6	1970
4587	5	12998	4	4836
4588	4	12998	1	4836
4589	5	12999	3	4857
4590	4	13000	1	4116
4591	4	13002	2	479
4592	5	13002	5	479
4593	5	13007	2	4851
4594	5	13008	3	4193
4595	4	13014	5	2237
4596	5	13015	6	4859
4597	5	13016	6	3820
4598	4	13021	6	3680
4599	5	13023	6	4889
4600	5	13029	7	822
4601	5	13032	1	2792
4602	5	13035	2	4877
4603	5	13036	4	4880
4604	5	13043	1	1289
4605	4	13045	4	1941
4606	5	13048	6	1280
4607	5	13050	2	1115
4608	3	13052	7	1820
4609	5	13053	7	677
4610	4	13055	3	4870
4611	3	13056	5	4892
4612	4	13057	7	4905
4613	3	13057	5	4905
4614	5	13060	6	4873
4615	4	13064	7	1514
4616	4	13068	5	2627
4617	5	13069	1	3635
4618	5	13073	2	4878
4619	5	13075	4	4901
4620	3	13079	4	2752
4621	5	13081	5	4042
4622	5	13082	6	1557
4623	4	13090	4	1241
4624	5	13093	1	1092
4625	5	13095	5	3823
4626	5	13096	2	4903
4627	3	13097	5	2980
4628	5	13099	4	4876
4629	4	13099	1	4876
4630	5	13100	6	4284
4631	5	13103	6	4727
4632	4	13106	1	285
4633	5	13107	6	728
4634	5	13110	6	4121
4635	3	13114	7	4149
4636	5	13118	3	2843
4637	5	13120	5	1486
4638	4	13123	1	1951
4639	3	13128	5	4023
4640	5	13129	1	2242
4641	3	13129	3	2242
4642	5	13132	7	3301
4643	5	13135	1	4915
4644	3	13135	7	4915
4645	5	13137	2	4943
4646	5	13138	1	4948
4647	5	13139	6	1540
4648	5	13140	1	4955
4649	3	13141	5	2911
4650	3	13142	5	4549
4651	5	13144	3	2198
4652	5	13147	3	4651
4653	1	13148	6	3865
4654	5	13149	2	4697
4655	5	13151	3	4924
4656	3	13157	1	4942
4657	5	13158	1	4925
4658	5	13161	6	454
4659	3	13163	6	2672
4660	5	13166	6	4854
4661	4	13167	3	640
4662	4	13168	4	4458
4663	5	13169	1	2413
4664	5	13171	7	3142
4665	5	13176	3	2438
4666	4	13178	7	4944
4667	2	13182	6	376
4668	5	13183	2	3477
4669	4	13184	7	4919
4670	4	13185	1	4911
4671	4	13187	7	3126
4672	4	13189	1	4567
4673	1	13194	3	4953
4674	4	13196	3	4580
4675	4	13197	5	4917
4676	4	13198	4	2472
4677	5	13199	5	2605
4678	4	13199	6	2605
4679	5	13200	7	4922
4680	4	13202	6	2507
4681	4	13205	5	4931
4682	5	13208	2	1952
4683	4	13213	3	4708
4684	5	13216	5	1944
4685	5	13217	2	3623
4686	5	13223	3	2768
4687	2	13224	3	341
4688	5	13226	6	4760
4689	4	13228	5	3689
4690	3	13233	3	1317
4691	4	13236	4	4927
4692	5	13240	5	4928
4693	3	13241	4	3361
4694	4	13242	5	196
4695	3	13243	7	3645
4696	5	13245	4	4909
4697	4	13245	1	4909
4698	4	13251	4	2868
4699	5	13255	6	4965
4700	4	13258	7	5003
4701	5	13259	5	4981
4702	3	13260	2	4975
4703	4	13264	5	111
4704	3	13267	2	4960
4705	4	13268	7	47
4706	5	13269	5	4972
4707	5	13275	5	2124
4708	4	13276	1	4978
4709	5	13278	6	1736
4710	5	13279	2	4970
4711	5	13280	2	80
4712	3	13289	1	788
4713	3	13292	3	5004
4714	3	13293	4	2907
4715	5	13293	6	2907
4716	4	13295	2	4193
4717	5	13297	3	3504
4718	5	13299	6	4498
4719	5	13301	6	4969
4720	3	13304	4	223
4721	2	13310	3	4971
4722	4	13311	3	626
4723	3	13312	4	4132
4724	4	13320	3	4190
4725	3	13321	5	3645
4726	5	13324	6	4964
4727	4	13325	4	676
4728	5	13328	1	5001
4729	5	13330	6	5000
4730	5	13334	6	5006
4731	4	13338	5	4998
4732	4	13340	5	4753
4733	5	13349	7	3864
4734	5	13360	6	1815
4735	5	13362	2	4993
4736	3	13373	3	3688
4737	3	13374	2	4985
4738	4	13376	2	1343
4739	5	13379	1	4606
4740	4	13382	4	4196
4741	5	13385	5	5059
4742	4	13387	1	5033
4743	5	13389	3	5017
4744	5	13393	5	925
4745	4	13395	1	5022
4746	5	13396	3	5029
4747	5	13399	6	2352
4748	3	13400	3	3378
4749	5	13401	2	4836
4750	5	13402	5	5030
4751	3	13403	1	5026
4752	3	13407	5	5013
4753	5	13410	6	3617
4754	5	13412	4	5021
4755	5	13415	2	3169
4756	4	13419	7	5027
4757	3	13420	5	5046
4758	3	13425	7	5035
4759	5	13430	6	5016
4760	4	13433	5	5056
4761	4	13434	7	3562
4762	5	13435	6	2752
4763	4	13437	7	691
4764	3	13438	3	806
4765	5	13439	6	538
4766	5	13440	2	5014
4767	3	13441	6	2362
4768	5	13442	6	5040
4769	5	13444	7	1313
4770	3	13452	7	5050
4771	4	13457	5	5034
4772	5	13461	3	5036
4773	4	13463	1	669
4774	5	13465	7	2942
4775	4	13467	5	5025
4776	5	13473	1	950
4777	2	13474	4	5023
4778	5	13477	7	2653
4779	3	13478	3	5028
4780	5	13479	3	373
4781	5	13485	2	2142
4782	3	13486	1	2476
4783	5	13489	4	3173
4784	4	13489	3	3173
4785	5	13490	2	3511
4786	5	13491	6	5008
4787	5	13492	2	1063
4788	3	13493	7	5000
4789	1	13495	6	3871
4790	1	13500	5	943
4791	4	13504	5	1742
4792	3	13505	2	5010
4793	5	13507	6	200
4794	4	13509	1	5041
4795	5	13509	2	5041
4796	4	13511	2	5018
4797	5	13512	2	2502
4798	4	13513	3	5019
4799	5	13514	6	68
4800	5	13517	1	5055
4801	3	13517	3	5055
4802	5	13520	5	3444
4803	4	13522	6	4144
4804	5	13523	6	5042
4805	5	13524	7	3552
4806	4	13527	6	1851
4807	5	13530	6	3835
4808	5	13531	4	3860
4809	5	13532	4	2511
4810	2	13533	1	5099
4811	5	13534	6	2766
4812	5	13538	4	5072
4813	5	13549	2	32
4814	5	13550	2	5090
4815	4	13553	7	23
4816	5	13559	6	2275
4817	5	13560	1	5097
4818	3	13561	2	457
4819	3	13563	3	1199
4820	4	13564	5	609
4821	5	13566	4	4723
4822	1	13573	1	3846
4823	5	13577	4	5061
4824	5	13577	5	5061
4825	5	13580	5	1700
4826	3	13582	5	172
4827	5	13586	7	5091
4828	4	13586	5	5091
4829	4	13593	7	5078
4830	5	13594	4	3108
4831	4	13595	2	5079
4832	5	13597	6	5085
4833	3	13598	5	2774
4834	5	13601	3	2518
4835	5	13606	6	179
4836	3	13607	3	5105
4837	5	13607	1	5105
4838	5	13609	6	4655
4839	5	13613	7	5104
4840	5	13620	4	3848
4841	4	13621	5	5102
4842	2	13626	6	2305
4843	3	13631	5	981
4844	5	13632	2	80
4845	5	13635	7	2306
4846	3	13637	7	1135
4847	1	13638	6	5074
4848	4	13640	5	432
4849	3	13648	4	1227
4850	4	13649	5	3885
4851	5	13653	7	1693
4852	5	13655	4	3679
4853	5	13655	6	3679
4854	5	13663	1	5065
4855	4	13665	7	4351
4856	5	13666	7	5064
4857	5	13669	4	1194
4858	4	13671	3	677
4859	5	13673	6	1271
4860	5	13674	2	3569
4861	5	13678	6	4574
4862	4	13679	4	382
4863	4	13682	3	2885
4864	5	13687	7	5089
4865	3	13690	4	5073
4866	4	13691	7	5062
4867	5	13692	4	5110
4868	4	13693	6	5095
4869	1	13698	1	833
4870	5	13705	6	1387
4871	5	13706	7	4995
4872	5	13707	4	4190
4873	3	13713	5	2605
4874	5	13715	6	5127
4875	5	13718	3	3507
4876	5	13722	5	5115
4877	3	13725	5	5124
4878	5	13726	3	4853
4879	5	13730	5	2995
4880	5	13731	7	3174
4881	5	13732	5	5158
4882	5	13743	5	5150
4883	3	13744	2	1968
4884	5	13745	2	5147
4885	3	13745	7	5147
4886	4	13746	7	2993
4887	4	13748	1	5155
4888	4	13748	5	5155
4889	3	13752	3	5137
4890	5	13753	4	3314
4891	3	13754	5	5117
4892	3	13754	3	5117
4893	2	13755	6	5143
4894	4	13760	7	1810
4895	2	13761	6	5135
4896	4	13763	3	5136
4897	5	13764	7	4562
4898	3	13765	6	2044
4899	5	13769	2	5125
4900	5	13770	4	1786
4901	5	13771	1	5122
4902	1	13773	3	3155
4903	4	13778	5	5138
4904	5	13780	4	4629
4905	5	13781	4	865
4906	5	13786	6	4146
4907	5	13787	4	4391
4908	5	13789	4	3393
4909	5	13791	3	5184
4910	2	13793	5	5182
4911	4	13800	3	27
4912	4	13802	4	5196
4913	4	13808	3	5194
4914	4	13810	2	1537
4915	4	13811	3	5175
4916	4	13818	7	5171
4917	5	13819	4	2068
4918	3	13822	6	5188
4919	5	13822	4	5188
4920	5	13826	2	5207
4921	5	13829	5	5181
4922	4	13830	4	5177
4923	5	13833	6	5187
4924	5	13834	4	1245
4925	5	13835	7	2446
4926	5	13842	4	3435
4927	3	13849	5	5179
4928	5	13852	2	2540
4929	5	13853	2	13
4930	5	13854	5	4815
4931	5	13860	4	5195
4932	5	13864	6	5191
4933	5	13865	2	1970
4934	3	13866	5	5178
4935	4	13867	1	4400
4936	4	13870	2	5192
4937	5	13870	3	5192
4938	5	13873	4	5199
4939	4	13874	2	5186
4940	2	13875	1	5165
4941	5	13877	3	66
4942	5	13880	3	3211
4943	5	13888	7	5213
4944	5	13889	5	4818
4945	4	13891	3	3971
4946	3	13892	7	2616
4947	4	13893	5	2139
4948	3	13894	4	569
4949	5	13896	2	5220
4950	5	13897	6	5250
4951	3	13904	3	5226
4952	4	13909	3	5229
4953	4	13910	3	2270
4954	5	13915	1	2894
4955	4	13918	2	3973
4956	2	13919	3	2050
4957	4	13921	5	4100
4958	5	13925	5	3447
4959	4	13926	1	2706
4960	5	13928	6	5214
4961	1	13930	1	4260
4962	5	13931	7	5218
4963	3	13934	3	378
4964	5	13938	2	1825
4965	3	13939	3	472
4966	5	13940	1	2148
4967	5	13941	4	1501
4968	5	13943	6	4946
4969	3	13945	5	5246
4970	4	13947	3	5032
4971	4	13950	6	1633
4972	5	13953	2	1640
4973	3	13956	3	5230
4974	5	13956	2	5230
4975	3	13957	1	4535
4976	5	13961	4	3178
4977	5	13964	5	5251
4978	5	13965	4	820
4979	3	13966	4	3651
4980	4	13967	6	5224
4981	5	13969	1	4406
4982	3	13970	7	5225
4983	4	13972	7	1409
4984	5	13980	4	87
4985	4	13982	6	2179
4986	5	13986	5	2935
4987	5	13988	6	5227
4988	5	13989	4	5233
4989	5	13992	2	80
4990	5	13994	3	729
4991	5	13996	7	616
4992	5	13997	4	2078
4993	4	14002	7	4800
4994	5	14007	6	3501
4995	5	14013	7	5244
4996	3	14014	3	3835
4997	5	14017	1	1736
4998	4	14019	3	3428
4999	5	14020	7	301
5000	5	14024	3	2993
5001	4	14032	1	697
5002	3	14033	3	5292
5003	3	14038	6	5265
5004	3	14043	7	536
5005	5	14044	3	2163
5006	4	14046	4	788
5007	5	14047	5	811
5008	5	14048	2	5297
5009	5	14053	4	5284
5010	5	14054	2	5253
5011	4	14058	5	4044
5012	3	14059	4	5277
5013	5	14067	6	5285
5014	4	14073	7	4333
5015	3	14074	7	2875
5016	5	14075	7	3513
5017	3	14076	5	4393
5018	5	14077	2	1563
5019	5	14079	6	2931
5020	5	14083	7	5271
5021	3	14088	3	552
5022	4	14090	1	5276
5023	5	14091	1	2959
5024	5	14092	6	5289
5025	4	14094	7	5278
5026	2	14096	4	4499
5027	5	14097	2	1072
5028	1	14098	4	1107
5029	5	14099	2	2439
5030	4	14101	6	5264
5031	1	14103	6	4709
5032	5	14103	1	4709
5033	3	14104	4	5295
5034	1	14105	6	778
5035	5	14113	6	4629
5036	5	14114	2	5286
5037	5	14120	7	5294
5038	5	14122	3	2513
5039	3	14123	1	2640
5040	5	14125	6	2739
5041	5	14127	2	317
5042	5	14129	1	4980
5043	5	14135	2	5312
5044	4	14138	5	2581
5045	4	14140	4	2667
5046	3	14145	4	1072
5047	5	14147	6	5340
5048	5	14148	7	2503
5049	5	14163	4	1435
5050	5	14164	7	1523
5051	4	14167	2	2272
5052	5	14171	5	4946
5053	4	14172	2	5345
5054	5	14177	6	5348
5055	5	14178	2	754
5056	3	14180	4	787
5057	3	14185	6	3413
5058	5	14186	1	5352
5059	4	14188	7	5329
5060	5	14188	5	5329
5061	5	14191	6	5316
5062	4	14200	4	527
5063	5	14202	5	5075
5064	5	14204	6	1922
5065	4	14208	7	790
5066	5	14213	4	5337
5067	5	14216	2	5332
5068	3	14217	2	5346
5069	5	14217	5	5346
5070	5	14219	6	1106
5071	4	14221	4	5003
5072	5	14221	2	5003
5073	3	14225	7	5331
5074	5	14227	7	5323
5075	5	14230	5	5350
5076	5	14232	1	3634
5077	5	14233	4	3125
5078	3	14236	6	5320
5079	4	14239	7	5351
5080	4	14242	1	1209
5081	4	14243	1	2227
5082	1	14244	1	594
5083	5	14245	6	852
5084	5	14247	1	1293
5085	5	14252	3	1490
5086	5	14253	3	4628
5087	5	14259	2	5071
5088	4	14261	5	5379
5089	3	14265	1	15
5090	5	14267	6	5374
5091	5	14270	6	5343
5092	4	14271	2	5364
5093	5	14274	6	2037
5094	5	14275	2	3916
5095	5	14276	1	1342
5096	4	14278	5	5380
5097	5	14280	6	4034
5098	5	14290	2	113
5099	3	14293	5	5125
5100	4	14297	2	5408
5101	3	14298	7	2853
5102	3	14299	2	2546
5103	5	14302	7	5394
5104	4	14304	2	4959
5105	5	14305	1	1568
5106	3	14309	7	1321
5107	4	14312	3	3491
5108	5	14313	7	5371
5109	4	14315	2	3869
5110	5	14316	1	2082
5111	5	14318	1	601
5112	3	14319	7	4786
5113	5	14327	4	5373
5114	3	14327	6	5373
5115	5	14330	6	285
5116	4	14332	7	5360
5117	5	14334	1	5368
5118	5	14337	7	4356
5119	5	14338	4	1435
5120	5	14340	5	4060
5121	4	14341	3	5358
5122	5	14343	2	5402
5123	4	14345	1	2605
5124	5	14347	7	5359
5125	3	14352	7	460
5126	4	14353	5	1015
5127	5	14358	5	3688
5128	5	14361	2	5395
5129	4	14363	2	4396
5130	5	14364	2	1119
5131	4	14365	3	4622
5132	4	14368	2	5361
5133	3	14371	1	5412
5134	3	14376	5	2676
5135	3	14380	7	2790
5136	1	14389	6	3542
5137	4	14391	3	4896
5138	5	14393	6	5362
5139	5	14394	7	3398
5140	4	14396	5	2602
5141	3	14403	5	4889
5142	4	14404	7	5356
5143	4	14412	5	1996
5144	5	14419	3	1702
5145	5	14421	1	5403
5146	1	14421	6	5403
5147	5	14425	2	153
5148	5	14432	5	5423
5149	4	14434	7	4455
5150	4	14438	4	5453
5151	5	14438	2	5453
5152	5	14439	6	5456
5153	5	14442	7	1531
5154	4	14445	2	4076
5155	5	14448	4	2410
5156	5	14449	2	1184
5157	5	14453	4	634
5158	5	14461	6	1547
5159	5	14463	3	5424
5160	5	14469	5	2064
5161	5	14475	6	2916
5162	5	14481	1	2234
5163	3	14486	7	5464
5164	5	14487	4	1860
5165	5	14489	7	5441
5166	5	14491	3	5338
5167	1	14492	6	1415
5168	3	14493	3	3705
5169	3	14493	2	3705
5170	5	14494	1	4223
5171	3	14496	4	4683
5172	4	14496	7	4683
5173	3	14499	3	5443
5174	5	14499	4	5443
5175	5	14503	7	3025
5176	5	14506	6	5435
5177	4	14508	3	5463
5178	5	14508	7	5463
5179	5	14509	4	3558
5180	5	14511	2	431
5181	3	14512	7	5445
5182	3	14512	4	5445
5183	1	14513	6	5429
5184	4	14516	7	5459
5185	5	14519	4	5446
5186	4	14521	1	5448
5187	3	14523	1	2659
5188	5	14528	2	201
5189	5	14532	6	5406
5190	5	14533	3	813
5191	3	14534	7	4478
5192	3	14534	1	4478
5193	5	14535	3	4161
5194	5	14537	1	2189
5195	4	14538	5	3651
5196	2	14549	6	5438
5197	2	14551	6	4628
5198	4	14552	3	1011
5199	3	14555	2	5019
5200	5	14556	7	1258
5201	4	14560	1	26
5202	4	14566	3	2442
5203	3	14568	4	2951
5204	5	14571	7	385
5205	3	14572	2	5077
5206	5	14576	4	4544
5207	5	14577	5	5451
5208	4	14580	5	5419
5209	5	14582	5	3783
5210	4	14584	1	5416
5211	3	14589	1	4376
5212	5	14594	7	5413
5213	4	14603	7	4655
5214	4	14605	6	5465
5215	5	14606	4	501
5216	4	14608	7	5421
5217	4	14609	5	5415
5218	5	14610	4	467
5219	5	14618	2	1383
5220	5	14621	6	424
5221	4	14623	5	5468
5222	3	14627	5	4194
5223	5	14627	7	4194
5224	5	14630	2	2420
5225	5	14636	5	4099
5226	5	14637	4	4835
5227	5	14641	3	136
5228	4	14643	4	719
5229	5	14645	7	964
5230	5	14647	1	4482
5231	5	14648	3	5052
5232	5	14651	1	1756
5233	3	14655	7	5485
5234	4	14656	2	5494
5235	5	14657	2	553
5236	5	14658	1	5479
5237	4	14662	1	3224
5238	5	14665	7	2413
5239	5	14666	4	3151
5240	3	14668	1	4779
5241	5	14672	4	2190
5242	3	14680	7	5490
5243	5	14681	3	4643
5244	3	14683	3	1239
5245	4	14684	4	5506
5246	3	14685	5	270
5247	4	14689	1	4001
5248	4	14694	1	5483
5249	5	14702	4	1143
5250	5	14703	6	3731
5251	5	14704	1	5525
5252	4	14708	1	2752
5253	5	14710	7	4860
5254	4	14712	2	5519
5255	5	14713	3	5547
5256	5	14715	6	5511
5257	1	14715	7	5511
5258	3	14716	1	5180
5259	5	14717	2	5541
5260	5	14720	1	5527
5261	5	14723	7	1659
5262	5	14724	2	5552
5263	5	14731	4	5399
5264	5	14741	2	1255
5265	1	14742	6	5533
5266	2	14743	6	4870
5267	3	14744	5	3593
5268	3	14745	7	1860
5269	5	14747	2	5556
5270	5	14749	2	236
5271	5	14751	7	4112
5272	5	14757	6	730
5273	5	14766	1	5510
5274	5	14767	5	4420
5275	5	14768	3	994
5276	5	14771	1	5521
5277	5	14773	3	213
5278	4	14774	1	5554
5279	4	14775	2	5516
5280	5	14776	1	1093
5281	5	14780	5	2477
5282	5	14783	1	1104
5283	4	14784	3	5535
5284	3	14785	1	2933
5285	3	14787	5	13
5286	4	14790	2	2582
5287	5	14792	2	5591
5288	4	14793	4	2630
5289	5	14795	6	5594
5290	4	14797	7	5579
5291	4	14800	6	5198
5292	4	14801	3	2965
5293	5	14803	6	5558
5294	5	14804	5	5585
5295	5	14805	4	2951
5296	5	14806	6	1028
5297	2	14807	3	2885
5298	5	14808	2	1631
5299	3	14810	1	5559
5300	5	14816	4	5568
5301	5	14824	2	3119
5302	1	14825	6	3125
5303	2	14826	6	5572
5304	5	14827	3	4312
5305	3	14831	3	4450
5306	4	14835	5	5573
5307	4	14835	1	5573
5308	4	14836	5	962
5309	5	14845	2	5608
5310	5	14853	7	5567
5311	3	14856	5	5603
5312	5	14857	3	5565
5313	3	14857	1	5565
5314	5	14859	7	5443
5315	4	14862	3	1263
5316	3	14867	7	3851
5317	5	14874	5	5580
5318	5	14875	6	2401
5319	3	14877	5	4333
5320	3	14879	4	3372
5321	5	14880	3	694
5322	5	14881	6	904
5323	3	14882	4	833
5324	4	14884	2	5563
5325	4	14885	5	5465
5326	5	14887	7	5571
5327	3	14895	4	2780
5328	5	14898	6	113
5329	3	14900	7	1187
5330	3	14902	2	2843
5331	5	14903	2	5560
5332	5	14905	3	1273
5333	4	14906	2	1593
5334	4	14907	5	2083
5335	4	14911	1	5308
5336	4	14912	2	2173
5337	5	14913	1	708
5338	4	14916	2	3451
5339	5	14918	3	5606
5340	5	14923	5	5639
5341	4	14927	5	2993
5342	5	14930	4	5666
5343	5	14931	7	2423
5344	5	14934	7	5620
5345	3	14935	2	790
5346	5	14941	4	2305
5347	5	14943	4	5290
5348	5	14946	3	2398
5349	4	14948	3	5105
5350	1	14949	6	5645
5351	4	14951	7	5618
5352	5	14952	6	5651
5353	5	14953	3	4547
5354	3	14962	1	5632
5355	5	14962	4	5632
5356	3	14969	7	467
5357	4	14970	7	5631
5358	3	14971	1	377
5359	3	14972	4	5652
5360	5	14978	2	5064
5361	5	14981	2	3578
5362	3	14985	4	5634
5363	4	14988	7	4664
5364	1	14990	4	1989
5365	4	14994	4	2575
5366	5	14999	6	1132
5367	5	15001	7	5657
5368	5	15004	2	3335
5369	5	15010	1	1640
5370	5	15011	5	2870
5371	4	15022	4	5654
5372	3	15022	5	5654
5373	5	15023	7	4946
5374	3	15025	2	3961
5375	3	15026	3	5629
5376	5	15026	6	5629
5377	3	15027	5	5616
5378	5	15030	3	5640
5379	5	15032	7	5662
5380	5	15035	6	5656
5381	4	15041	6	2222
5382	5	15042	6	5644
5383	5	15049	2	2176
5384	2	15058	3	4160
5385	5	15062	5	2523
5386	5	15062	6	2523
5387	4	15063	2	3567
5388	3	15064	7	2097
5389	4	15066	6	2244
5390	5	15067	2	2615
5391	4	15070	7	5713
5392	4	15077	7	5682
5393	5	15078	2	5712
5394	4	15079	6	3385
5395	5	15080	4	5681
5396	5	15084	6	3754
5397	5	15089	4	5673
5398	4	15094	1	2521
5399	3	15095	4	4748
5400	4	15096	3	5706
5401	4	15099	2	4665
5402	5	15100	6	1614
5403	3	15101	7	4290
5404	2	15102	3	1547
5405	5	15103	2	5723
5406	5	15106	2	5721
5407	5	15107	2	2031
5408	5	15109	4	2176
5409	4	15113	3	5668
5410	5	15117	5	5678
5411	5	15121	2	2052
5412	5	15123	2	2135
5413	5	15124	2	5710
5414	5	15129	4	5711
5415	1	15131	6	5720
5416	4	15133	2	5675
5417	5	15134	2	2309
5418	2	15134	1	2309
5419	3	15138	7	5680
5420	5	15138	4	5680
5421	5	15141	7	48
5422	4	15143	4	2291
5423	5	15144	4	3080
5424	5	15145	6	5704
5425	5	15149	5	2110
5426	5	15150	7	145
5427	3	15153	7	1490
5428	5	15153	3	1490
5429	5	15158	4	2187
5430	3	15161	7	2614
5431	1	15167	6	5689
5432	3	15168	3	4291
5433	2	15169	4	5696
5434	5	15176	2	5106
5435	5	15177	4	3655
5436	3	15180	4	5705
5437	5	15183	3	1587
5438	4	15187	2	5767
5439	5	15190	4	5773
5440	5	15191	5	3686
5441	5	15192	3	5732
5442	4	15193	6	3293
5443	5	15201	4	5771
5444	4	15202	5	3052
5445	4	15203	4	841
5446	5	15205	5	5787
5447	5	15207	2	1432
5448	5	15211	4	5763
5449	3	15213	2	3863
5450	5	15215	6	5796
5451	4	15220	1	5293
5452	1	15224	6	5786
5453	5	15225	7	3796
5454	5	15225	2	3796
5455	5	15227	3	304
5456	5	15231	7	766
5457	5	15232	7	3485
5458	4	15234	1	1925
5459	5	15237	2	5784
5460	3	15241	5	5751
5461	2	15243	6	5768
5462	3	15247	1	5790
5463	5	15248	5	3545
5464	4	15249	6	1461
5465	5	15253	4	925
5466	3	15257	7	1833
5467	4	15258	1	5775
5468	5	15260	2	909
5469	4	15262	2	5762
5470	5	15263	6	5791
5471	3	15265	5	5310
5472	3	15266	4	5737
5473	3	15274	7	5727
5474	3	15276	7	5511
5475	5	15277	6	1267
5476	5	15279	6	5778
5477	4	15285	7	5726
5478	5	15288	4	3949
5479	5	15292	4	5774
5480	5	15293	6	593
5481	4	15295	5	5746
5482	5	15302	3	923
5483	5	15304	6	5757
5484	5	15307	2	5730
5485	3	15309	7	1115
5486	4	15315	5	2689
5487	2	15316	4	2119
5488	1	15317	6	5743
5489	5	15325	6	1333
5490	3	15332	5	5740
5491	4	15334	7	752
5492	5	15340	4	5760
5493	4	15343	4	1314
5494	5	15344	3	158
5495	5	15345	2	5788
5496	4	15345	5	5788
5497	3	15347	2	4355
5498	4	15348	1	5758
5499	4	15349	6	3369
5500	3	15350	3	2450
5501	5	15353	6	641
5502	5	15355	4	73
5503	3	15358	3	2228
5504	5	15359	6	5078
5505	5	15367	3	1076
5506	3	15370	2	2104
5507	3	15371	6	5846
5508	4	15373	7	2752
5509	4	15378	7	2891
5510	5	15380	2	3911
5511	4	15381	7	5845
5512	5	15384	4	5842
5513	4	15384	2	5842
5514	1	15386	4	5509
5515	5	15388	7	3372
5516	3	15392	6	4116
5517	5	15398	6	1021
5518	5	15399	1	1079
5519	5	15405	1	5855
5520	5	15406	5	5840
5521	5	15406	7	5840
5522	5	15408	2	2555
5523	1	15413	7	4115
5524	5	15416	6	4218
5525	5	15418	6	3007
5526	3	15421	5	5192
5527	3	15424	2	2352
5528	3	15426	7	3228
5529	4	15430	7	1736
5530	5	15431	4	5854
5531	5	15435	2	1006
5532	4	15436	6	1509
5533	4	15438	1	5827
5534	5	15440	2	4646
5535	3	15441	7	4785
5536	3	15443	5	4451
5537	5	15444	3	4875
5538	5	15446	2	4192
5539	3	15448	4	2237
5540	3	15453	1	2572
5541	5	15454	7	4234
5542	5	15459	7	5095
5543	4	15466	5	4173
5544	5	15467	6	5806
5545	5	15469	4	1569
5546	5	15473	2	1100
5547	4	15474	7	3992
5548	5	15475	2	5829
5549	5	15477	6	2332
5550	5	15480	6	5818
5551	5	15481	6	5805
5552	3	15482	7	5125
5553	5	15485	5	3621
5554	5	15489	6	2485
5555	5	15491	1	5850
5556	4	15491	5	5850
5557	5	15493	3	2492
5558	5	15497	1	1259
5559	5	15498	3	832
5560	5	15499	4	5802
5561	4	15501	5	5817
5562	5	15502	5	3138
5563	5	15503	5	2048
5564	5	15504	1	5828
5565	4	15505	4	4612
5566	5	15507	5	184
5567	5	15517	2	4083
5568	5	15519	7	890
5569	3	15524	1	4614
5570	4	15527	6	5821
5571	3	15529	2	1445
5572	4	15530	1	1810
5573	4	15532	4	5823
5574	5	15536	6	5183
5575	4	15537	5	5800
5576	3	15539	3	5826
5577	1	15544	6	3629
5578	4	15545	2	2638
5579	5	15545	6	2638
5580	3	15552	4	1334
5581	4	15553	2	5816
5582	5	15555	6	5836
5583	4	15557	4	5405
5584	5	15558	5	4357
5585	3	15559	2	1230
5586	4	15567	6	165
5587	4	15580	5	54
5588	5	15583	1	5867
5589	3	15584	5	1239
5590	3	15585	5	3948
5591	4	15586	2	5473
5592	3	15587	3	5866
5593	3	15592	3	5631
5594	1	15597	2	5882
5595	5	15600	7	5908
5596	4	15601	4	5901
5597	5	15602	3	5877
5598	5	15603	5	5880
5599	5	15605	1	5899
5600	5	15606	1	2191
5601	5	15608	6	5878
5602	5	15610	6	2401
5603	5	15611	4	2574
5604	4	15611	5	2574
5605	5	15613	4	5895
5606	5	15614	6	5886
5607	5	15617	6	5897
5608	5	15624	5	3332
5609	5	15627	2	41
5610	5	15628	1	290
5611	5	15634	7	5903
5612	4	15635	6	2653
5613	2	15636	3	2659
5614	3	15637	4	5884
5615	5	15643	5	5900
5616	5	15644	4	5891
5617	4	15645	2	4044
5618	5	15650	6	5910
5619	4	15651	5	5188
5620	5	15656	4	4309
5621	2	15657	1	5037
5622	3	15661	1	5931
5623	4	15665	3	5915
5624	4	15666	6	2882
5625	5	15667	1	5948
5626	5	15667	6	5948
5627	3	15668	1	5918
5628	5	15673	1	1143
5629	4	15675	2	680
5630	5	15676	5	5912
5631	5	15678	6	5954
5632	4	15680	3	5456
5633	5	15691	6	4108
5634	5	15696	1	232
5635	4	15698	3	5941
5636	3	15701	6	3438
5637	5	15703	7	2917
5638	5	15708	3	5875
5639	2	15712	6	2958
5640	2	15714	6	5923
5641	4	15715	6	5926
5642	5	15716	7	1255
5643	5	15717	2	1116
5644	5	15721	1	4281
5645	4	15726	7	2472
5646	5	15728	1	150
5647	4	15729	2	5848
5648	5	15730	7	5937
5649	4	15731	1	5952
5650	3	15732	7	1044
5651	3	15733	5	5934
5652	3	15734	4	5947
5653	5	15736	2	5935
5654	2	15737	3	4414
5655	4	15737	5	4414
5656	5	15739	2	2101
5657	4	15742	1	4279
5658	5	15742	3	4279
5659	5	15745	4	4794
5660	5	15748	4	3674
5661	5	15751	7	5929
5662	5	15752	4	1212
5663	4	15755	4	1211
5664	5	15756	6	4772
5665	5	15757	6	2624
5666	3	15771	5	2778
5667	5	15771	2	2778
5668	3	15773	2	4896
5669	5	15775	3	2748
5670	5	15781	2	1933
5671	5	15787	5	2729
5672	1	15790	4	5763
5673	4	15792	2	5992
5674	4	15794	4	4132
5675	5	15795	2	3621
5676	5	15800	2	1819
5677	5	15801	2	4436
5678	5	15808	7	6008
5679	5	15809	4	4792
5680	5	15810	2	236
5681	3	15811	2	209
5682	3	15813	5	4459
5683	3	15814	5	560
5684	5	15819	1	6013
5685	1	15821	6	66
5686	4	15826	2	6018
5687	5	15831	2	5930
5688	5	15832	2	4116
5689	5	15834	2	5977
5690	5	15836	2	5983
5691	5	15838	3	1244
5692	4	15840	6	5996
5693	3	15843	1	3123
5694	5	15845	6	5984
5695	5	15846	2	1800
5696	5	15847	6	5987
5697	4	15848	6	3473
5698	5	15848	1	3473
5699	5	15852	4	1376
5700	5	15854	5	3736
5701	5	15856	3	5986
5702	1	15859	7	5967
5703	3	15861	5	6015
5704	4	15863	4	5995
5705	4	15865	4	4695
5706	4	15867	7	1409
5707	1	15868	6	5975
5708	5	15871	7	1154
5709	3	15872	7	113
5710	5	15876	4	5972
5711	5	15881	6	5997
5712	5	15885	4	6034
5713	4	15885	3	6034
5714	2	15892	3	4747
5715	4	15896	5	3266
5716	3	15901	3	3101
5717	5	15901	4	3101
5718	5	15902	4	6066
5719	4	15903	3	6054
5720	4	15905	5	6058
5721	4	15909	2	4962
5722	5	15910	1	970
5723	5	15913	4	3588
5724	5	15923	2	6069
5725	5	15924	6	4306
5726	5	15926	3	6059
5727	4	15926	7	6059
5728	4	15927	2	196
5729	5	15928	6	3219
5730	3	15929	5	6057
5731	3	15930	1	6037
5732	4	15934	7	6022
5733	2	15937	6	4233
5734	5	15938	6	5966
5735	5	15941	6	6055
5736	3	15942	4	1851
5737	4	15943	2	6028
5738	3	15947	7	6074
5739	4	15948	7	6040
5740	3	15950	7	3566
5741	3	15951	4	2850
5742	5	15952	6	764
5743	4	15954	7	3393
5744	5	15958	7	260
5745	4	15967	5	6072
5746	3	15967	3	6072
5747	5	15968	4	1557
5748	3	15970	1	6050
5749	5	15976	6	1348
5750	5	15977	1	3693
5751	5	15984	6	2694
5752	5	15985	4	2564
5753	5	15986	5	6060
5754	4	15988	6	4022
5755	3	15989	4	6067
5756	3	15993	3	6062
5757	5	15994	5	6041
5758	5	15996	2	2915
5759	5	15999	4	6064
5760	4	16008	7	5864
5761	5	16009	6	602
5762	4	16012	1	3644
5763	4	16013	1	2264
5764	3	16015	2	6053
5765	4	16020	3	6068
5766	5	16023	4	1306
5767	5	16023	7	1306
5768	5	16025	6	3984
5769	3	16030	5	6065
5770	5	16034	3	3123
5771	3	16037	2	5576
5772	5	16042	6	6115
5773	5	16043	4	5466
5774	5	16045	5	3267
5775	5	16050	6	4590
5776	5	16051	1	5414
5777	3	16054	5	2646
5778	5	16056	2	6127
5779	5	16064	5	5050
5780	5	16066	1	718
5781	4	16068	7	6085
5782	5	16069	7	6129
5783	3	16071	6	993
5784	5	16072	2	3002
5785	4	16073	1	6138
5786	5	16075	6	6124
5787	5	16077	3	5530
5788	5	16078	4	1992
5789	5	16078	7	1992
5790	5	16086	2	6118
5791	5	16087	6	6106
5792	5	16088	6	4710
5793	4	16092	5	5338
5794	5	16095	7	1447
5795	4	16096	3	6084
5796	3	16097	3	1700
5797	5	16098	1	4732
5798	5	16101	3	6088
5799	3	16102	7	1015
5800	4	16104	5	1905
5801	5	16105	1	770
5802	3	16106	4	880
5803	5	16107	6	6141
5804	5	16115	5	2770
5805	5	16119	4	2477
5806	5	16123	5	6116
5807	3	16127	7	5287
5808	5	16128	7	2943
5809	5	16132	2	5930
5810	5	16134	1	2434
5811	5	16143	1	1278
5812	5	16151	1	6113
5813	5	16156	4	905
5814	5	16158	1	5983
5815	5	16160	2	2006
5816	4	16162	4	1720
5817	5	16165	1	2890
5818	5	16168	3	4676
5819	3	16169	5	6128
5820	4	16171	3	304
5821	5	16172	6	6123
5822	3	16173	7	6079
5823	5	16176	1	6107
5824	4	16181	7	6161
5825	5	16181	5	6161
5826	5	16185	2	1733
5827	3	16186	1	3806
5828	4	16187	7	5339
5829	3	16189	5	2231
5830	3	16190	5	6164
5831	4	16191	1	4960
5832	4	16192	6	4847
5833	5	16200	2	4619
5834	5	16201	1	2699
5835	1	16202	6	3224
5836	5	16209	6	6180
5837	5	16209	2	6180
5838	5	16210	2	2875
5839	5	16212	4	4710
5840	3	16219	4	6160
5841	3	16220	5	2532
5842	5	16224	7	2101
5843	5	16225	5	3124
5844	5	16226	1	709
5845	4	16228	1	536
5846	5	16230	6	6172
5847	4	16231	4	5105
5848	5	16232	6	143
5849	5	16233	1	6177
5850	4	16234	7	6189
5851	4	16235	1	6070
5852	5	16238	3	3361
5853	3	16241	4	3469
5854	3	16242	2	6148
5855	5	16246	5	1681
5856	3	16248	4	2230
5857	5	16251	6	2853
5858	5	16255	4	4247
5859	1	16256	3	6170
5860	4	16260	7	6151
5861	5	16265	6	687
5862	5	16267	2	1810
5863	5	16268	4	6154
5864	5	16270	3	5125
5865	5	16271	7	1627
5866	1	16272	6	1251
5867	5	16275	3	1427
5868	5	16276	1	6183
5869	4	16277	1	749
5870	5	16280	7	5699
5871	5	16282	2	6168
5872	5	16284	7	4016
5873	5	16287	6	3764
5874	5	16289	6	6149
5875	5	16290	2	401
5876	5	16294	1	5455
5877	1	16295	3	3471
5878	5	16296	5	1406
5879	5	16297	5	5491
5880	5	16298	7	6158
5881	4	16300	7	3641
5882	5	16302	6	3421
5883	1	16303	4	847
5884	3	16307	2	6153
5885	5	16308	3	6146
5886	4	16309	6	6167
5887	4	16310	5	5712
5888	4	16314	3	6181
5889	5	16316	3	5670
5890	4	16316	7	5670
5891	1	16317	2	6152
5892	5	16324	5	3548
5893	4	16329	7	5196
5894	3	16330	4	4451
5895	5	16332	7	3243
5896	4	16333	3	299
5897	3	16334	4	6171
5898	5	16336	6	5777
5899	5	16338	4	6186
5900	3	16341	3	4223
5901	4	16343	1	3852
5902	5	16345	1	6225
5903	5	16346	1	4592
5904	5	16347	6	4979
5905	4	16347	5	4979
5906	3	16348	5	6217
5907	5	16350	6	6198
5908	5	16353	2	3802
5909	5	16355	4	6216
5910	5	16358	4	874
5911	4	16359	1	5038
5912	3	16359	6	5038
5913	5	16360	2	4309
5914	4	16361	3	2110
5915	5	16362	7	3912
5916	4	16363	7	6172
5917	5	16367	2	4824
5918	5	16369	1	6255
5919	5	16370	2	1214
5920	3	16374	2	3590
5921	5	16378	6	3842
5922	4	16382	1	6239
5923	3	16388	5	6234
5924	5	16390	7	6192
5925	5	16392	4	5791
5926	5	16394	5	3734
5927	4	16395	2	6229
5928	5	16397	2	3898
5929	5	16398	6	2068
5930	4	16400	3	4370
5931	4	16402	4	1170
5932	5	16408	7	2705
5933	5	16409	6	6210
5934	3	16411	5	3703
5935	4	16412	7	2522
5936	5	16414	3	4802
5937	5	16415	7	1865
5938	5	16417	6	6219
5939	5	16420	4	6237
5940	3	16421	3	6241
5941	5	16425	6	2417
5942	4	16426	5	6208
5943	5	16427	6	4072
5944	4	16428	3	6248
5945	5	16431	1	84
5946	3	16434	1	5927
5947	4	16436	2	6194
5948	5	16438	2	21
5949	3	16443	7	2829
5950	5	16445	7	6207
5951	4	16446	3	4622
5952	5	16447	6	2567
5953	1	16449	6	486
5954	4	16451	7	3458
5955	4	16458	7	6206
5956	4	16470	7	5151
5957	3	16471	3	6245
5958	5	16473	6	3945
5959	5	16474	2	6242
5960	4	16475	4	386
5961	5	16476	7	6249
5962	5	16478	4	3755
5963	5	16479	6	6200
5964	4	16481	6	5545
5965	4	16481	2	5545
5966	5	16482	7	6213
5967	5	16489	6	3173
5968	5	16491	6	5891
5969	5	16492	7	1547
5970	4	16494	6	5301
5971	4	16494	3	5301
5972	4	16496	2	4590
5973	4	16499	7	6252
5974	4	16506	7	2631
5975	5	16509	4	1038
5976	5	16517	4	1425
5977	5	16519	6	3015
5978	5	16522	5	6218
5979	4	16525	1	6228
5980	4	16532	2	6223
5981	2	16535	1	6203
5982	5	16539	4	5707
5983	4	16540	1	2850
5984	3	16542	2	4300
5985	4	16543	3	5192
5986	5	16544	4	2107
5987	5	16545	6	3491
5988	4	16548	4	6227
5989	5	16549	4	1842
5990	4	16550	3	340
5991	4	16551	7	6253
5992	4	16552	6	5638
5993	4	16557	3	399
5994	5	16559	7	1587
5995	5	16564	3	765
5996	5	16565	1	6288
5997	5	16568	7	784
5998	5	16570	2	6277
5999	5	16573	1	6286
6000	1	16574	4	1866
6001	3	16576	2	1803
6002	4	16581	7	5718
6003	5	16584	4	189
6004	5	16585	4	3343
6005	3	16585	7	3343
6006	5	16586	4	6305
6007	3	16589	1	2460
6008	4	16597	6	5613
6009	3	16600	5	6296
6010	4	16604	7	4258
6011	5	16605	3	6269
6012	5	16606	1	3756
6013	5	16608	4	3022
6014	4	16609	7	6292
6015	4	16610	5	5824
6016	3	16614	2	262
6017	5	16617	6	3483
6018	5	16618	4	5222
6019	4	16620	4	2649
6020	3	16620	5	2649
6021	5	16621	2	24
6022	4	16623	1	1495
6023	3	16624	5	6307
6024	3	16624	1	6307
6025	4	16625	1	2885
6026	5	16628	6	3749
6027	3	16629	6	6282
6028	5	16630	5	3827
6029	4	16638	2	1654
6030	5	16640	6	4766
6031	5	16641	3	811
6032	5	16642	1	2191
6033	5	16643	7	5425
6034	5	16645	4	6263
6035	5	16646	1	2873
6036	3	16648	3	2523
6037	5	16649	1	1313
6038	4	16653	6	6298
6039	5	16654	2	4248
6040	5	16656	2	6309
6041	5	16660	3	5004
6042	5	16663	7	4250
6043	5	16664	6	4007
6044	3	16673	7	6232
6045	5	16674	1	6342
6046	1	16675	5	536
6047	5	16676	6	6334
6048	1	16679	7	6318
6049	5	16681	6	6362
6050	5	16683	5	6090
6051	5	16686	7	2308
6052	4	16687	7	5220
6053	5	16688	7	3456
6054	5	16690	7	5110
6055	4	16692	2	2638
6056	4	16694	5	575
6057	5	16694	6	575
6058	4	16696	5	2237
6059	5	16699	7	6338
6060	3	16700	5	6320
6061	5	16701	3	2608
6062	3	16705	7	3459
6063	5	16707	6	6369
6064	5	16711	3	3365
6065	1	16712	6	4045
6066	5	16713	1	1282
6067	4	16714	2	2021
6068	5	16715	3	5174
6069	5	16718	1	6350
6070	5	16718	4	6350
6071	4	16719	2	260
6072	5	16720	7	6345
6073	5	16721	7	5527
6074	4	16724	2	3575
6075	4	16725	4	2858
6076	5	16726	7	6322
6077	3	16729	1	3153
6078	5	16739	4	6366
6079	5	16741	2	257
6080	5	16746	1	33
6081	4	16747	3	2970
6082	4	16749	7	3502
6083	4	16749	4	3502
6084	4	16751	7	6347
6085	5	16758	6	6312
6086	5	16763	5	5783
6087	5	16763	2	5783
6088	2	16764	6	6365
6089	3	16766	2	4673
6090	5	16768	4	4411
6091	5	16770	2	6351
6092	5	16773	3	6343
6093	3	16778	5	3155
6094	5	16780	3	2785
6095	4	16782	2	2602
6096	5	16790	2	6381
6097	3	16791	6	6400
6098	5	16792	3	6411
6099	4	16793	2	5461
6100	4	16798	4	4461
6101	5	16799	6	4075
6102	5	16800	7	5717
6103	5	16802	1	3403
6104	3	16804	1	6414
6105	4	16806	7	6421
6106	4	16807	6	4189
6107	5	16809	6	5188
6108	4	16811	5	6382
6109	5	16813	6	5658
6110	4	16814	5	1988
6111	5	16815	2	2993
6112	4	16818	5	1674
6113	4	16822	3	6390
6114	5	16823	6	2416
6115	4	16824	1	6374
6116	3	16833	7	6418
6117	5	16833	4	6418
6118	5	16834	1	6423
6119	5	16836	4	3704
6120	1	16838	6	2833
6121	3	16841	1	1227
6122	4	16851	5	6281
6123	5	16852	2	1334
6124	5	16855	4	4050
6125	1	16858	6	5540
6126	5	16861	2	6401
6127	5	16863	7	1565
6128	4	16866	7	1529
6129	3	16869	4	525
6130	4	16872	3	3000
6131	4	16873	5	3679
6132	5	16874	2	6387
6133	5	16878	1	4587
6134	5	16879	4	6383
6135	5	16881	2	4007
6136	4	16884	7	6407
6137	4	16887	5	5972
6138	5	16887	1	5972
6139	3	16893	4	6399
6140	4	16895	1	997
6141	4	16901	1	6394
6142	5	16905	1	5858
6143	3	16906	5	5201
6144	5	16909	1	6370
6145	4	16910	2	6392
6146	5	16915	3	4751
6147	5	16916	4	6396
6148	4	16921	2	170
6149	1	16923	3	6379
6150	4	16923	7	6379
6151	5	16928	1	6450
6152	4	16934	7	122
6153	5	16939	5	607
6154	3	16940	4	6475
6155	4	16945	6	6438
6156	5	16946	4	6433
6157	5	16946	2	6433
6158	5	16949	5	6063
6159	3	16957	5	1676
6160	4	16959	3	3701
6161	3	16961	4	3644
6162	3	16964	6	2065
6163	4	16965	7	173
6164	4	16966	6	6455
6165	5	16969	4	4958
6166	5	16970	4	3812
6167	5	16972	6	4966
6168	5	16973	6	6477
6169	4	16975	2	3800
6170	4	16976	5	1461
6171	5	16979	5	6463
6172	5	16982	2	2348
6173	5	16983	2	6435
6174	5	16989	6	6427
6175	5	16993	6	3690
6176	5	16999	2	2339
6177	4	17006	2	5113
6178	5	17013	7	4543
6179	5	17015	2	6432
6180	4	17016	2	1476
6181	5	17017	6	3887
6182	5	17020	1	563
6183	5	17021	3	6430
6184	3	17022	7	6429
6185	3	17025	4	2373
6186	5	17028	4	6470
6187	1	17031	4	6447
6188	4	17031	5	6447
6189	2	17032	6	6454
6190	5	17034	4	6431
6191	4	17036	5	3423
6192	3	17038	1	5155
6193	5	17046	4	778
6194	4	17049	2	5890
6195	5	17050	6	5337
6196	2	17051	6	2854
6197	5	17056	1	6480
6198	4	17061	1	6478
6199	5	17063	1	6457
6200	5	17064	4	900
6201	5	17066	6	5958
6202	4	17068	6	287
6203	3	17073	1	6461
6204	5	17074	2	3256
6205	1	17077	2	6546
6206	5	17088	3	5970
6207	4	17088	1	5970
6208	5	17090	1	6506
6209	5	17093	6	6333
6210	4	17094	5	6519
6211	5	17095	1	1118
6212	5	17097	7	6493
6213	4	17100	7	2124
6214	5	17101	4	6491
6215	5	17103	1	3788
6216	5	17104	6	972
6217	4	17110	2	6508
6218	4	17112	3	3385
6219	4	17114	5	4995
6220	5	17124	3	6530
6221	5	17125	4	6528
6222	3	17127	3	378
6223	4	17132	4	5910
6224	5	17139	1	1266
6225	5	17140	5	5165
6226	5	17142	5	4172
6227	5	17143	7	1364
6228	2	17145	4	3649
6229	5	17147	3	3135
6230	5	17152	4	2843
6231	5	17154	6	6498
6232	5	17155	6	5104
6233	5	17156	2	847
6234	4	17158	5	6510
6235	5	17159	5	4281
6236	3	17164	1	6533
6237	3	17168	4	6489
6238	3	17171	4	1713
6239	5	17173	1	5545
6240	5	17175	6	660
6241	4	17176	4	6497
6242	5	17178	3	6104
6243	4	17179	7	4912
6244	5	17181	4	3467
6245	4	17182	6	6509
6246	5	17184	2	6536
6247	3	17188	1	2152
6248	5	17198	5	6534
6249	5	17202	2	5857
6250	5	17204	4	424
6251	5	17205	7	1021
6252	4	17206	1	6505
6253	5	17207	1	5026
6254	5	17208	7	6499
6255	5	17211	3	6513
6256	3	17212	1	6494
6257	1	17213	4	3063
6258	4	17214	7	5856
6259	4	17215	4	1657
6260	4	17222	1	4837
6261	4	17225	7	1161
6262	5	17226	6	5169
6263	1	17227	4	1313
6264	5	17231	7	536
6265	5	17233	4	602
6266	5	17236	1	1106
6267	4	17238	3	6560
6268	5	17239	7	4125
6269	4	17240	7	5043
6270	5	17244	3	1931
6271	3	17253	2	5812
6272	5	17254	7	6581
6273	5	17257	7	6602
6274	5	17260	2	5180
6275	1	17261	6	2585
6276	5	17262	6	4441
6277	5	17263	4	67
6278	5	17264	6	2236
6279	4	17265	3	2880
6280	5	17267	7	1918
6281	4	17269	6	6599
6282	4	17272	2	6593
6283	5	17274	6	2862
6284	4	17276	3	4685
6285	5	17280	2	2168
6286	4	17282	7	1115
6287	5	17283	4	6611
6288	1	17286	1	6564
6289	4	17287	7	6597
6290	5	17289	4	6569
6291	5	17292	4	5447
6292	5	17293	6	6598
6293	5	17294	7	6606
6294	5	17300	6	6561
6295	5	17301	2	6579
6296	5	17303	2	2023
6297	4	17305	4	3010
6298	5	17308	6	2401
6299	5	17311	2	6608
6300	5	17313	5	3125
6301	4	17316	7	3903
6302	5	17322	2	6590
6303	4	17323	7	4804
6304	4	17324	6	6572
6305	4	17325	7	6241
6306	5	17327	3	6552
6307	5	17330	2	6195
6308	5	17333	4	6585
6309	5	17334	2	6137
6310	5	17336	4	6506
6311	4	17338	3	788
6312	5	17352	5	6126
6313	5	17354	2	1876
6314	4	17356	7	6554
6315	3	17360	7	1427
6316	5	17363	3	275
6317	4	17365	2	6566
6318	5	17371	3	171
6319	5	17372	6	1460
6320	5	17379	6	3825
6321	5	17380	6	1208
6322	3	17381	6	4792
6323	5	17381	7	4792
6324	5	17383	1	2907
6325	3	17387	5	6582
6326	5	17388	5	6557
6327	1	17390	6	6586
6328	4	17392	1	5604
6329	5	17393	3	6594
6330	4	17400	1	4424
6331	5	17407	5	3204
6332	4	17408	3	2902
6333	5	17409	6	6553
6334	5	17410	1	6596
6335	4	17411	4	6652
6336	4	17413	5	1107
6337	5	17420	5	437
6338	5	17422	5	6650
6339	4	17431	5	5503
6340	5	17433	6	5332
6341	4	17434	3	2593
6342	5	17435	2	6626
6343	5	17439	4	4453
6344	5	17441	1	6263
6345	5	17445	1	3745
6346	4	17446	6	2734
6347	5	17451	7	6628
6348	5	17453	6	2955
6349	4	17454	1	5253
6350	5	17456	6	1379
6351	5	17465	6	4008
6352	1	17466	6	5707
6353	5	17469	6	5935
6354	4	17474	4	2592
6355	5	17475	6	1988
6356	5	17479	1	5201
6357	4	17481	4	2640
6358	5	17482	2	2300
6359	3	17486	7	5022
6360	5	17489	3	6637
6361	4	17490	2	4352
6362	3	17494	2	6613
6363	3	17497	3	2413
6364	5	17501	3	4224
6365	5	17506	7	6482
6366	5	17507	7	6657
6367	5	17508	4	6618
6368	5	17511	4	6478
6369	5	17513	1	6635
6370	5	17514	7	3363
6371	5	17515	2	6619
6372	4	17516	7	3483
6373	3	17518	7	6136
6374	5	17521	2	286
6375	4	17523	2	71
6376	3	17525	2	3848
6377	3	17525	6	3848
6378	5	17529	6	3293
6379	4	17531	1	1115
6380	4	17532	6	6624
6381	5	17533	6	6660
6382	5	17535	1	3106
6383	5	17538	6	6629
6384	3	17540	4	3754
6385	5	17542	6	2611
6386	4	17543	4	5191
6387	3	17551	5	6659
6388	4	17552	5	6334
6389	3	17556	2	2979
6390	5	17558	1	6651
6391	4	17559	3	979
6392	5	17560	2	5189
6393	5	17564	1	162
6394	5	17566	3	4663
6395	1	17572	4	6661
6396	4	17574	7	6104
6397	5	17577	2	2415
6398	5	17581	3	6025
6399	5	17583	6	6089
6400	3	17586	5	5777
6401	5	17588	4	3440
6402	4	17593	1	6662
6403	3	17597	7	6625
6404	5	17598	2	3155
6405	4	17604	7	6638
6406	5	17610	2	6243
6407	3	17611	1	6633
6408	4	17617	7	6640
6409	5	17619	3	6614
6410	5	17621	5	5194
6411	5	17622	1	6615
6412	5	17623	1	6630
6413	4	17625	5	3614
6414	2	17626	6	279
6415	3	17627	7	950
6416	5	17627	6	950
6417	4	17632	2	3394
6418	4	17634	3	6672
6419	5	17636	5	6702
6420	4	17640	4	2599
6421	5	17642	4	6686
6422	3	17643	7	6669
6423	5	17644	2	764
6424	5	17645	5	6683
6425	5	17648	6	4034
6426	3	17652	3	3361
6427	3	17656	5	6673
6428	3	17662	7	531
6429	4	17666	5	742
6430	4	17672	3	6701
6431	4	17674	6	203
6432	4	17675	7	2263
6433	4	17676	2	6725
6434	3	17691	5	1640
6435	3	17693	6	4297
6436	1	17697	6	6691
6437	5	17702	5	2173
6438	3	17710	7	6235
6439	4	17711	1	6728
6440	5	17715	2	6696
6441	1	17719	6	5195
6442	5	17720	2	3350
6443	5	17726	4	511
6444	3	17727	3	1557
6445	4	17735	2	6722
6446	5	17736	3	6181
6447	4	17738	3	6679
6448	5	17739	2	6681
6449	5	17741	5	847
6450	3	17744	4	2851
6451	3	17745	4	847
6452	3	17746	1	1665
6453	5	17752	6	6734
6454	4	17753	5	41
6455	3	17756	5	659
6456	4	17758	5	6759
6457	3	17759	4	3805
6458	5	17760	4	6793
6459	3	17761	3	4636
6460	4	17762	2	1995
6461	2	17767	3	5091
6462	4	17770	1	3065
6463	5	17771	3	6772
6464	4	17772	7	4282
6465	5	17773	7	6776
6466	2	17775	6	6786
6467	5	17776	6	6785
6468	3	17779	5	623
6469	5	17780	7	6768
6470	4	17784	7	6794
6471	4	17785	7	6749
6472	2	17787	5	6746
6473	5	17788	7	6763
6474	5	17793	1	292
6475	5	17795	5	6644
6476	5	17799	6	6765
6477	5	17800	2	1132
6478	5	17804	6	6761
6479	4	17805	5	6773
6480	5	17806	5	275
6481	5	17808	2	5304
6482	5	17813	7	6296
6483	5	17814	3	6752
6484	2	17817	1	6764
6485	1	17818	6	6741
6486	5	17819	7	5110
6487	4	17820	7	6782
6488	4	17823	5	6767
6489	5	17824	7	6751
6490	5	17825	4	4363
6491	5	17828	1	3873
6492	4	17833	7	6737
6493	3	17835	5	367
6494	4	17847	5	2217
6495	5	17848	3	6748
6496	5	17850	4	6755
6497	3	17851	7	3882
6498	3	17853	7	4262
6499	5	17854	7	6736
6500	3	17856	7	6742
6501	1	17862	1	6792
6502	5	17862	4	6792
6503	2	17863	4	6747
6504	3	17867	4	3054
6505	5	17868	7	5508
6506	5	17872	1	802
6507	4	17877	2	2933
6508	3	17879	5	3384
6509	5	17885	7	6857
6510	5	17888	3	5572
6511	4	17895	2	5643
6512	5	17896	4	6028
6513	4	17897	4	5500
6514	5	17899	4	6802
6515	5	17904	4	6829
6516	5	17905	2	1452
6517	3	17907	5	6799
6518	5	17910	6	1934
6519	5	17911	3	253
6520	5	17912	3	1074
6521	4	17916	5	6827
6522	3	17921	5	6826
6523	3	17922	4	6854
6524	4	17926	1	2176
6525	5	17928	6	6814
6526	4	17929	5	6081
6527	1	17933	6	236
6528	4	17936	5	3705
6529	4	17940	1	6844
6530	3	17944	5	6835
6531	4	17947	2	790
6532	5	17950	6	910
6533	5	17951	4	2101
6534	5	17951	2	2101
6535	5	17952	1	3821
6536	4	17952	5	3821
6537	5	17954	2	2056
6538	4	17959	6	1296
6539	5	17960	2	6811
6540	4	17962	4	6820
6541	5	17962	1	6820
6542	1	17965	6	1563
6543	5	17967	7	6805
6544	5	17969	5	6850
6545	3	17970	5	1545
6546	5	17974	3	6843
6547	5	17976	5	3318
6548	4	17977	2	6813
6549	4	17977	5	6813
6550	5	17986	4	5642
6551	5	17993	1	1541
6552	3	17994	5	6846
6553	5	17997	2	3716
6554	4	17998	5	3153
6555	3	18003	2	6801
6556	4	18004	3	4224
6557	5	18006	6	281
6558	5	18008	6	6839
6559	1	18011	4	2124
6560	4	18014	2	4629
6561	4	18016	3	6824
6562	4	18021	7	3627
6563	5	18023	1	1756
6564	5	18025	6	2520
6565	5	18026	4	1528
6566	4	18036	2	3054
6567	5	18037	4	5098
6568	5	18043	4	2857
6569	3	18044	3	6856
6570	2	18047	6	6921
6571	5	18050	2	6875
6572	3	18051	5	6894
6573	5	18051	7	6894
6574	4	18052	7	2010
6575	5	18054	2	1582
6576	5	18054	6	1582
6577	3	18055	3	4519
6578	2	18058	3	637
6579	4	18062	7	263
6580	5	18063	2	3000
6581	4	18073	2	6877
6582	3	18077	2	389
6583	4	18078	5	6903
6584	5	18079	4	313
6585	4	18083	2	1432
6586	5	18090	7	6893
6587	5	18090	4	6893
6588	5	18100	3	1313
6589	5	18101	7	2432
6590	5	18102	2	3837
6591	4	18107	5	6888
6592	5	18108	5	6876
6593	5	18110	5	6864
6594	5	18116	2	5970
6595	5	18120	6	6913
6596	5	18121	6	6919
6597	2	18122	3	7
6598	3	18123	7	925
6599	5	18124	1	1244
6600	5	18127	1	4301
6601	5	18128	7	6678
6602	3	18130	4	6885
6603	5	18134	6	6729
6604	5	18136	5	6883
6605	5	18140	7	189
6606	4	18141	3	6898
6607	4	18142	7	5774
6608	5	18148	1	2076
6609	5	18151	6	1726
6610	3	18152	3	4347
6611	4	18153	2	1810
6612	5	18158	7	6891
6613	4	18162	5	6062
6614	5	18164	4	3684
6615	5	18172	6	6904
6616	5	18175	2	4219
6617	3	18176	5	6928
6618	5	18178	5	5125
6619	5	18180	2	4217
6620	3	18185	1	3236
6621	1	18186	6	6890
6622	4	18191	4	6920
6623	5	18192	6	6870
6624	2	18193	6	6863
6625	5	18197	7	6897
6626	3	18199	5	2139
6627	5	18201	2	6934
6628	5	18205	1	5149
6629	5	18207	4	3961
6630	4	18209	4	3614
6631	5	18210	6	4749
6632	3	18211	1	41
6633	5	18213	2	6966
6634	5	18217	5	4096
6635	5	18220	5	6951
6636	4	18221	2	2191
6637	5	18223	2	6932
6638	4	18223	5	6932
6639	5	18225	7	378
6640	5	18228	1	6933
6641	5	18230	7	5718
6642	5	18231	3	6841
6643	4	18232	4	2148
6644	4	18239	2	2264
6645	5	18242	7	6952
6646	1	18243	6	3104
6647	5	18247	5	988
6648	4	18249	7	176
6649	3	18250	4	6969
6650	4	18257	6	358
6651	3	18263	2	6953
6652	5	18266	6	6981
6653	5	18268	4	6941
6654	4	18272	7	6947
6655	5	18278	6	6955
6656	5	18281	7	6979
6657	5	18285	2	244
6658	4	18286	2	2618
6659	5	18288	7	1460
6660	5	18292	4	5590
6661	5	18292	1	5590
6662	4	18296	3	4013
6663	5	18299	6	6930
6664	5	18299	1	6930
6665	4	18308	1	6931
6666	5	18310	4	5301
6667	3	18311	3	1889
6668	5	18312	4	708
6669	5	18313	6	4095
6670	3	18315	1	4605
6671	5	18316	7	3132
6672	4	18319	1	4161
6673	4	18321	7	6971
6674	3	18322	2	5963
6675	2	18327	3	1970
6676	5	18330	2	3563
6677	5	18330	6	3563
6678	5	18331	7	5733
6679	5	18332	2	2054
6680	5	18333	5	3115
6681	5	18336	6	7035
6682	5	18342	1	4652
6683	5	18343	2	7015
6684	5	18344	1	7022
6685	5	18346	6	7018
6686	4	18349	5	1334
6687	5	18354	6	7025
6688	5	18356	6	2672
6689	4	18362	5	2961
6690	5	18364	4	4960
6691	3	18369	7	6996
6692	5	18370	6	113
6693	5	18371	6	2739
6694	5	18373	7	3048
6695	4	18374	3	7009
6696	5	18379	5	7003
6697	3	18386	3	1659
6698	5	18387	6	6994
6699	3	18388	1	2699
6700	4	18389	3	7036
6701	5	18390	3	6986
6702	5	18395	7	1313
6703	5	18396	5	3895
6704	5	18400	2	2578
6705	4	18403	5	5387
6706	3	18407	7	4094
6707	3	18410	6	7040
6708	5	18410	3	7040
6709	5	18414	1	6991
6710	5	18418	1	411
6711	5	18419	5	5094
6712	5	18420	2	2139
6713	5	18423	1	3393
6714	5	18424	2	5117
6715	4	18431	5	6678
6716	5	18435	7	2207
6717	4	18436	2	5649
6718	1	18438	3	586
6719	5	18439	6	68
6720	5	18442	1	806
6721	3	18452	5	5663
6722	5	18454	1	80
6723	5	18457	7	7000
6724	3	18459	1	2151
6725	2	18460	1	6983
6726	5	18461	7	3084
6727	3	18465	7	7050
6728	5	18466	2	5473
6729	5	18468	6	7004
6730	5	18469	6	6982
6731	5	18470	6	5582
6732	3	18473	1	5699
6733	1	18477	5	543
6734	5	18478	7	7002
6735	1	18482	5	1942
6736	4	18487	5	6971
6737	5	18494	5	5197
6738	4	18499	7	3003
6739	5	18500	3	511
6740	4	18501	3	802
6741	3	18504	7	6985
6742	5	18512	6	7038
6743	3	18513	5	6997
6744	5	18514	2	3494
6745	4	18519	6	7070
6746	5	18522	5	4592
6747	5	18522	4	4592
6748	5	18523	1	5799
6749	5	18528	6	7105
6750	4	18533	2	204
6751	5	18536	4	2651
6752	4	18538	4	5645
6753	2	18539	4	57
6754	4	18540	5	7102
6755	5	18548	6	7079
6756	3	18552	3	3135
6757	4	18553	6	6193
6758	5	18558	2	6495
6759	1	18562	4	223
6760	5	18567	7	4264
6761	3	18568	1	933
6762	5	18571	6	586
6763	5	18572	4	6901
6764	3	18575	6	4300
6765	5	18576	7	6820
6766	5	18582	6	874
6767	5	18587	6	7055
6768	5	18588	6	7062
6769	5	18589	6	7085
6770	5	18594	4	7093
6771	4	18597	7	7072
6772	5	18598	2	7087
6773	5	18602	1	7107
6774	3	18607	5	7095
6775	1	18607	1	7095
6776	4	18611	3	4872
6777	5	18613	7	6170
6778	4	18616	5	7092
6779	5	18616	6	7092
6780	4	18617	2	7064
6781	1	18618	6	4214
6782	5	18619	4	92
6783	5	18621	2	7077
6784	4	18622	2	5155
6785	5	18626	6	2398
6786	5	18627	2	5848
6787	5	18628	2	7073
6788	5	18632	7	5691
6789	3	18634	4	3082
6790	4	18635	5	918
6791	5	18639	4	1948
6792	4	18643	1	7056
6793	5	18644	1	2945
6794	4	18645	6	6485
6795	5	18646	6	7090
6796	3	18648	7	3777
6797	3	18649	5	2802
6798	5	18650	4	3460
6799	5	18651	2	408
6800	5	18654	2	7111
6801	5	18656	7	6064
6802	5	18657	2	3960
6803	5	18659	2	356
6804	3	18660	7	399
6805	4	18661	5	7046
6806	5	18662	3	3772
6807	3	18664	1	4453
6808	5	18667	6	6076
6809	5	18671	6	1312
6810	5	18672	1	1908
6811	3	18675	5	7071
6812	4	18676	7	5031
6813	3	18680	6	7109
6814	4	18683	1	669
6815	4	18692	3	3065
6816	4	18694	2	7091
6817	1	18695	5	6839
6818	3	18697	5	7089
6819	5	18701	4	4001
6820	5	18703	5	7063
6821	3	18705	1	7099
6822	5	18707	2	7084
6823	3	18709	5	7112
6824	5	18716	6	729
6825	3	18717	3	2256
6826	5	18718	6	3962
6827	3	18720	3	209
6828	3	18723	5	7054
6829	5	18729	5	6095
6830	4	18729	1	6095
6831	1	18731	6	3863
6832	4	18732	1	7157
6833	3	18733	1	5730
6834	5	18738	7	260
6835	5	18739	3	6950
6836	4	18741	3	5094
6837	5	18744	6	3633
6838	3	18745	3	7123
6839	4	18747	7	7131
6840	5	18750	2	7133
6841	3	18752	5	7162
6842	5	18755	4	7122
6843	3	18759	2	2692
6844	5	18761	6	1208
6845	5	18762	5	2823
6846	5	18766	2	7081
6847	3	18768	5	4131
6848	3	18769	4	4029
6849	5	18775	6	1295
6850	1	18777	4	7153
6851	5	18778	6	6235
6852	4	18779	4	7163
6853	5	18781	1	1321
6854	5	18784	6	7152
6855	5	18789	2	883
6856	3	18792	7	638
6857	4	18793	5	873
6858	5	18794	7	7148
6859	5	18798	6	5236
6860	5	18799	4	2081
6861	5	18800	7	1233
6862	5	18801	2	7142
6863	5	18803	7	6215
6864	5	18804	2	4356
6865	4	18807	3	5180
6866	5	18811	6	7160
6867	4	18814	1	7158
6868	5	18817	4	2605
6869	3	18818	4	3868
6870	5	18820	5	6664
6871	4	18821	1	506
6872	4	18827	5	7118
6873	5	18828	6	7165
6874	5	18830	6	748
6875	5	18832	7	6139
6876	1	18837	1	7146
6877	4	18842	6	7138
6878	3	18843	4	1660
6879	4	18846	7	1536
6880	5	18847	5	7241
6881	5	18848	5	4168
6882	5	18850	1	7192
6883	5	18852	2	209
6884	5	18854	6	2422
6885	5	18855	6	7188
6886	4	18855	7	7188
6887	5	18858	2	2030
6888	1	18859	6	3937
6889	3	18868	6	6761
6890	4	18871	2	7189
6891	3	18872	4	5151
6892	5	18873	2	3327
6893	4	18874	3	4947
6894	1	18875	6	7212
6895	4	18876	1	5961
6896	4	18878	2	6478
6897	3	18880	5	6410
6898	5	18882	3	632
6899	3	18887	2	7177
6900	3	18891	4	7180
6901	4	18892	5	7226
6902	4	18892	7	7226
6903	5	18897	7	7232
6904	5	18898	3	7195
6905	5	18902	6	4577
6906	5	18903	4	4479
6907	4	18907	3	7238
6908	5	18909	7	7181
6909	4	18910	3	1800
6910	5	18911	5	7240
6911	3	18913	5	3108
6912	5	18914	4	7235
6913	5	18915	4	3755
6914	3	18916	3	3280
6915	5	18922	2	7138
6916	5	18923	4	2819
6917	5	18924	7	7210
6918	4	18925	5	4146
6919	5	18926	3	2868
6920	5	18927	2	6164
6921	5	18929	6	5180
6922	4	18930	3	4728
6923	3	18945	5	1766
6924	4	18950	2	2068
6925	5	18951	4	527
6926	5	18954	2	7222
6927	4	18957	5	6884
6928	4	18958	5	7224
6929	2	18965	1	5306
6930	3	18967	5	7227
6931	4	18968	4	7231
6932	3	18971	5	3040
6933	5	18972	6	5520
6934	3	18973	7	2804
6935	3	18974	5	1018
6936	5	18975	2	5817
6937	5	18978	2	2123
6938	3	18982	1	5215
6939	4	18983	6	7019
6940	5	18985	2	5170
6941	2	18987	6	7220
6942	5	18989	6	7279
6943	5	18990	6	292
6944	3	18990	5	292
6945	4	18991	7	3000
6946	5	18997	6	7011
6947	5	18998	7	7280
6948	1	18998	6	7280
6949	4	18999	2	2780
6950	5	19000	1	7291
6951	5	19007	2	6747
6952	3	19007	4	6747
6953	4	19012	5	7259
6954	3	19015	7	7292
6955	4	19016	7	7265
6956	4	19017	7	1340
6957	5	19018	1	5745
6958	5	19019	2	2432
6959	5	19020	2	6949
6960	4	19020	4	6949
6961	5	19021	6	7254
6962	5	19026	4	207
6963	3	19030	7	673
6964	3	19031	7	7294
6965	5	19033	6	4665
6966	5	19035	7	7305
6967	2	19040	6	6798
6968	5	19041	4	3787
6969	1	19044	3	7245
6970	5	19048	4	3492
6971	4	19050	7	4022
6972	5	19055	7	7267
6973	4	19056	5	5506
6974	5	19058	1	1581
6975	3	19059	6	6499
6976	4	19061	5	2982
6977	5	19065	5	3040
6978	1	19065	2	3040
6979	5	19068	7	3887
6980	4	19070	5	3204
6981	4	19071	5	7304
6982	4	19073	7	7312
6983	5	19076	3	2436
6984	1	19078	6	7299
6985	3	19081	5	2608
6986	3	19083	1	1449
6987	4	19084	4	5730
6988	5	19085	6	256
6989	4	19086	7	2983
6990	5	19087	3	7288
6991	2	19090	4	1813
6992	4	19091	2	7293
6993	4	19092	5	4432
6994	5	19093	5	7281
6995	5	19093	7	7281
6996	5	19094	3	582
6997	5	19100	6	7262
6998	3	19101	5	4225
6999	5	19102	2	5106
7000	5	19104	4	7277
7001	4	19107	7	2193
7002	5	19108	7	1140
7003	5	19114	7	7253
7004	5	19115	2	7269
7005	3	19117	5	7287
7006	5	19120	7	5699
7007	4	19122	2	5329
7008	5	19124	6	7298
7009	5	19127	6	6238
7010	5	19128	7	6480
7011	5	19129	7	2482
7012	5	19130	1	7257
7013	5	19135	1	2806
7014	5	19135	2	2806
7015	2	19139	6	7249
7016	5	19140	5	5110
7017	5	19141	4	4734
7018	5	19142	1	2564
7019	5	19143	5	7355
7020	5	19145	5	5309
7021	5	19148	2	3318
7022	5	19151	5	2392
7023	4	19154	1	4920
7024	5	19156	1	320
7025	4	19157	5	7353
7026	5	19162	4	3823
7027	3	19169	2	6540
7028	4	19176	4	4960
7029	4	19179	7	7358
7030	4	19180	2	2916
7031	4	19182	5	7372
7032	5	19183	1	7327
7033	5	19184	4	7319
7034	5	19185	2	7365
7035	5	19187	2	2928
7036	5	19188	2	504
7037	5	19189	3	177
7038	5	19192	2	7333
7039	5	19194	6	2418
7040	5	19196	2	1380
7041	3	19198	4	2543
7042	3	19200	3	1736
7043	5	19203	7	5711
7044	5	19204	4	6038
7045	5	19208	2	3708
7046	5	19209	2	1439
7047	4	19210	5	7322
7048	3	19221	1	3164
7049	5	19222	3	7156
7050	5	19224	3	1708
7051	5	19225	2	1427
7052	1	19227	6	7371
7053	4	19229	7	1472
7054	4	19232	6	5699
7055	5	19234	3	7341
7056	5	19234	5	7341
7057	4	19238	7	2837
7058	5	19238	4	2837
7059	4	19248	2	519
7060	2	19251	3	7324
7061	5	19252	2	4368
7062	4	19256	6	5455
7063	5	19259	3	346
7064	4	19264	4	7364
7065	4	19265	6	7332
7066	5	19267	6	2511
7067	4	19271	5	4867
7068	5	19272	6	5050
7069	5	19273	1	7345
7070	4	19274	7	2332
7071	5	19286	7	7330
7072	5	19287	1	7359
7073	2	19299	1	1370
7074	5	19301	4	7360
7075	3	19302	7	3867
7076	5	19303	3	6156
7077	4	19304	2	7338
7078	5	19308	2	1352
7079	5	19309	7	5476
7080	5	19312	2	52
7081	5	19314	2	4912
7082	5	19320	6	3332
7083	4	19321	2	2018
7084	5	19325	6	7049
7085	4	19326	3	7381
7086	3	19331	5	7421
7087	1	19333	4	7383
7088	4	19334	5	675
7089	5	19338	2	7379
7090	5	19339	4	7428
7091	3	19345	1	6869
7092	2	19346	4	4533
7093	5	19348	5	6080
7094	5	19351	2	6277
7095	3	19352	5	5152
7096	5	19356	6	623
7097	3	19360	6	7377
7098	5	19368	4	4481
7099	4	19370	1	2298
7100	2	19372	7	4982
7101	2	19373	3	1272
7102	5	19374	2	3368
7103	5	19375	4	3311
7104	5	19376	1	7086
7105	4	19380	4	7420
7106	4	19385	1	3570
7107	4	19389	3	7402
7108	5	19390	4	3399
7109	4	19392	7	3400
7110	5	19396	3	528
7111	5	19408	5	7384
7112	3	19409	5	7441
7113	4	19414	6	664
7114	3	19427	4	7355
7115	5	19429	6	7427
7116	4	19432	2	7387
7117	5	19435	7	1158
7118	4	19437	2	7439
7119	3	19441	1	3398
7120	5	19443	6	5886
7121	5	19444	3	654
7122	4	19447	3	7408
7123	1	19448	4	4395
7124	4	19450	6	1731
7125	2	19451	3	626
7126	5	19453	4	7489
7127	5	19455	3	894
7128	4	19459	4	1557
7129	5	19465	6	2857
7130	3	19472	2	209
7131	5	19472	6	209
7132	4	19477	6	7469
7133	5	19483	1	3268
7134	5	19485	5	7511
7135	5	19486	7	6778
7136	3	19488	2	7528
7137	5	19491	4	7444
7138	4	19494	7	7503
7139	5	19495	5	7485
7140	5	19497	2	3052
7141	3	19500	5	7442
7142	5	19502	5	7500
7143	5	19505	1	1954
7144	4	19506	7	6954
7145	5	19513	3	7514
7146	4	19514	7	7478
7147	4	19515	7	3568
7148	5	19516	3	2592
7149	5	19517	7	7477
7150	3	19518	7	7457
7151	5	19524	3	2190
7152	2	19528	6	3726
7153	5	19529	7	865
7154	4	19532	3	7520
7155	5	19535	4	5811
7156	4	19537	7	7211
7157	1	19539	6	2183
7158	5	19540	4	1316
7159	5	19542	3	7482
7160	3	19544	4	401
7161	3	19546	6	6536
7162	4	19547	7	7483
7163	4	19548	7	151
7164	4	19549	4	7223
7165	5	19550	3	4527
7166	5	19554	6	7507
7167	3	19555	1	7490
7168	5	19557	6	7509
7169	3	19558	6	7471
7170	5	19560	4	7470
7171	5	19562	6	5596
7172	5	19563	7	1269
7173	5	19564	5	2743
7174	5	19569	7	7499
7175	3	19569	6	7499
7176	3	19582	4	7464
7177	4	19584	5	7525
7178	5	19587	1	173
7179	2	19587	7	173
7180	5	19590	7	7513
7181	3	19591	6	6219
7182	4	19591	4	6219
7183	4	19593	5	7484
7184	5	19597	5	4429
7185	5	19598	6	7453
7186	3	19599	1	1627
7187	5	19600	1	7447
7188	5	19601	3	7467
7189	5	19603	1	7468
7190	3	19609	5	7508
7191	5	19616	7	1010
7192	5	19622	2	5928
7193	3	19622	1	5928
7194	5	19623	6	227
7195	5	19626	7	4714
7196	4	19626	5	4714
7197	5	19627	4	7472
7198	5	19629	3	993
7199	4	19630	1	1788
7200	5	19634	4	3502
7201	5	19634	2	3502
7202	5	19635	6	4824
7203	5	19637	7	2526
7204	2	19638	6	7338
7205	1	19639	6	7492
7206	5	19641	7	7134
7207	5	19646	2	3444
7208	2	19647	6	7495
7209	5	19648	7	7481
7210	3	19651	1	7526
7211	5	19653	7	2252
7212	5	19655	6	3343
7213	3	19656	3	903
7214	5	19658	6	3073
7215	3	19662	5	6802
7216	4	19664	7	117
7217	4	19666	4	6377
7218	5	19667	4	6878
7219	5	19669	6	7597
7220	3	19672	4	6769
7221	5	19678	4	3883
7222	5	19683	3	7567
7223	5	19685	4	7541
7224	5	19686	2	4425
7225	4	19687	7	1118
7226	5	19689	2	7564
7227	5	19692	7	7568
7228	5	19697	1	5234
7229	5	19702	6	2326
7230	3	19704	1	7590
7231	5	19707	2	6232
7232	4	19709	5	7600
7233	2	19710	6	4320
7234	5	19717	4	7570
7235	4	19721	3	1781
7236	5	19726	5	5877
7237	4	19728	6	7592
7238	3	19731	6	7594
7239	5	19732	6	3332
7240	5	19732	1	3332
7241	3	19735	3	5924
7242	5	19736	3	5192
7243	5	19737	3	184
7244	5	19739	1	6711
7245	4	19740	3	3005
7246	4	19742	7	2455
7247	3	19742	2	2455
7248	3	19743	5	7572
7249	5	19744	3	5738
7250	1	19751	6	7593
7251	5	19756	6	7532
7252	3	19757	5	7579
7253	4	19758	5	1834
7254	3	19761	7	3898
7255	5	19761	2	3898
7256	4	19767	2	7545
7257	5	19769	6	6385
7258	5	19770	5	3026
7259	5	19775	6	4981
7260	5	19782	1	7547
7261	2	19783	6	7585
7262	1	19792	6	2083
7263	4	19798	3	7559
7264	5	19799	3	6283
7265	5	19802	7	6150
7266	3	19803	5	835
7267	5	19808	4	7491
7268	4	19809	5	2244
7269	5	19810	6	601
7270	5	19812	1	6009
7271	2	19814	6	5552
7272	4	19819	4	7024
7273	3	19820	1	7534
7274	5	19820	6	7534
7275	4	19822	4	7211
7276	5	19824	6	3102
7277	2	19826	1	3403
7278	4	19827	7	4072
7279	4	19832	7	7530
7280	4	19833	7	7583
7281	3	19837	4	7562
7282	5	19844	2	719
7283	3	19845	4	5384
7284	4	19849	4	740
7285	5	19852	2	2232
7286	2	19853	6	7548
7287	4	19856	6	7584
7288	5	19860	2	7563
7289	3	19862	7	7544
7290	5	19863	1	7025
7291	3	19869	7	7536
7292	5	19872	4	7586
7293	5	19873	4	4983
7294	4	19876	7	7306
7295	4	19882	2	7578
7296	1	19883	7	2546
7297	5	19885	3	5189
7298	3	19885	2	5189
7299	5	19888	7	7041
7300	3	19889	7	7573
7301	5	19892	1	7646
7302	5	19896	6	1163
7303	5	19899	2	7668
7304	5	19901	2	7633
7305	3	19904	2	6439
7306	3	19907	4	2594
7307	5	19909	6	7658
7308	5	19911	6	7648
7309	3	19913	4	4682
7310	4	19915	3	7527
7311	4	19917	6	7661
7312	3	19919	5	3460
7313	5	19924	7	4746
7314	3	19926	2	7656
7315	4	19930	3	7624
7316	3	19932	7	7625
7317	4	19933	4	3412
7318	4	19934	7	7644
7319	4	19936	3	7666
7320	4	19936	7	7666
7321	5	19938	7	3280
7322	5	19939	2	7629
7323	5	19942	2	740
7324	5	19946	4	7626
7325	4	19948	1	7627
7326	5	19950	5	7634
7327	2	19952	6	2903
7328	1	19953	2	585
7329	5	19954	2	7620
7330	5	19955	6	4131
7331	5	19959	1	7545
7332	3	19960	5	6953
7333	5	19961	5	7636
7334	5	19965	4	2290
7335	4	19968	4	7604
7336	5	19969	4	7641
7337	4	19973	5	2897
7338	3	19980	6	806
7339	5	19981	5	7665
7340	4	19983	6	3597
7341	5	19984	3	2472
7342	5	19985	6	3480
7343	5	19986	5	7610
7344	5	19988	3	7609
7345	3	19991	2	482
7346	5	19994	7	5486
7347	4	19996	2	7683
7348	4	19998	5	7700
7349	5	20005	2	7723
7350	5	20006	5	6727
7351	4	20007	5	3851
7352	3	20009	7	7703
7353	5	20010	6	7141
7354	3	20014	2	3835
7355	5	20015	6	1944
7356	5	20018	5	7717
7357	4	20019	7	7728
7358	5	20024	7	1170
7359	5	20025	5	2101
7360	5	20027	4	2752
7361	4	20042	5	7679
7362	5	20049	7	7702
7363	4	20050	4	7412
7364	1	20053	6	6496
7365	4	20054	6	4348
7366	4	20056	7	938
7367	5	20058	2	6152
7368	3	20066	5	486
7369	5	20068	2	2827
7370	5	20070	6	6214
7371	5	20073	4	2771
7372	5	20079	5	1104
7373	3	20080	5	6705
7374	2	20081	5	7718
7375	4	20087	7	2704
7376	5	20091	6	7699
7377	4	20091	7	7699
7378	3	20092	1	84
7379	3	20094	4	547
7380	5	20097	5	7715
7381	4	20098	2	1301
7382	3	20099	5	7712
7383	5	20104	2	7696
7384	4	20105	2	5961
7385	4	20109	4	7122
7386	4	20111	6	7673
7387	5	20112	4	7164
7388	4	20113	6	7706
7389	4	20115	1	6736
7390	5	20116	6	7684
7391	3	20120	1	1537
7392	4	20126	4	599
7393	5	20129	2	701
7394	2	20130	3	6600
7395	5	20132	3	6556
7396	4	20134	1	1485
7397	5	20134	6	1485
7398	5	20135	4	7726
7399	3	20135	3	7726
7400	4	20136	7	6791
7401	3	20141	2	3616
7402	3	20143	5	5004
7403	5	20145	2	3076
7404	4	20146	7	6055
7405	2	20147	1	7761
7406	4	20147	5	7761
7407	5	20150	7	2305
7408	4	20153	3	7751
7409	5	20154	1	7796
7410	5	20155	6	4705
7411	3	20157	1	2588
7412	5	20158	7	3452
7413	5	20159	2	7766
7414	5	20160	1	677
7415	3	20162	3	3730
7416	3	20164	3	6203
7417	5	20165	1	82
7418	4	20168	7	7730
7419	1	20169	6	7750
7420	4	20170	4	2185
7421	4	20171	5	5903
7422	5	20172	4	599
7423	3	20174	7	7780
7424	3	20176	1	2391
7425	5	20183	1	4034
7426	5	20185	2	7774
7427	5	20187	2	7799
7428	5	20188	4	1579
7429	4	20190	5	6238
7430	5	20197	3	3611
7431	4	20202	7	5292
7432	5	20204	2	7791
7433	5	20206	4	7779
7434	5	20210	7	7737
7435	5	20215	2	1657
7436	5	20217	7	4342
7437	5	20221	6	6722
7438	3	20222	1	3971
7439	3	20223	1	7748
7440	5	20226	5	6949
7441	5	20227	3	1068
7442	5	20228	6	7758
7443	4	20229	4	7790
7444	5	20234	2	7177
7445	5	20243	6	7329
7446	3	20247	2	7773
7447	3	20247	5	7773
7448	3	20252	4	1754
7449	5	20257	6	7798
7450	5	20261	6	3129
7451	3	20264	6	6096
7452	5	20268	3	184
7453	4	20271	2	1457
7454	4	20273	7	6163
7455	5	20275	3	7743
7456	3	20276	3	3812
7457	3	20281	5	7763
7458	5	20283	3	3784
7459	5	20284	4	7784
7460	5	20286	6	7794
7461	5	20286	5	7794
7462	3	20290	1	7756
7463	4	20293	6	4498
7464	5	20297	3	788
7465	5	20299	4	6000
7466	4	20301	4	7643
7467	5	20302	7	4220
7468	5	20304	4	7746
7469	5	20307	2	1107
7470	5	20308	4	7770
7471	3	20309	5	310
7472	5	20310	6	7768
7473	3	20313	1	444
7474	5	20316	5	7739
7475	3	20318	3	7802
7476	5	20324	1	1736
7477	5	20325	6	7869
7478	5	20327	5	7801
7479	1	20328	6	1005
7480	5	20331	5	3493
7481	5	20333	5	5520
7482	5	20335	6	6914
7483	4	20336	3	2670
7484	5	20342	1	281
7485	5	20343	4	7620
7486	5	20344	4	1228
7487	5	20349	6	7838
7488	5	20359	6	3125
7489	5	20360	7	6341
7490	5	20361	2	1316
7491	4	20362	2	7846
7492	5	20365	3	7866
7493	5	20368	4	7800
7494	5	20371	1	7826
7495	5	20373	1	5004
7496	5	20374	6	4737
7497	5	20376	2	7808
7498	5	20377	6	3187
7499	5	20378	7	1897
7500	4	20379	2	3399
7501	5	20380	2	1810
7502	4	20381	3	2055
7503	4	20383	4	7865
7504	5	20387	6	7814
7505	3	20388	5	7851
7506	2	20395	6	7830
7507	5	20396	1	5141
7508	3	20397	3	3135
7509	1	20400	6	7807
7510	5	20401	6	4621
7511	4	20401	5	4621
7512	5	20402	2	4235
7513	4	20403	1	73
7514	4	20404	7	7853
7515	5	20405	6	5945
7516	5	20414	6	7862
7517	5	20415	6	7852
7518	5	20416	2	15
7519	3	20417	7	7816
7520	5	20418	6	7868
7521	5	20419	2	136
7522	4	20422	7	265
7523	5	20424	7	7390
7524	4	20426	5	7842
7525	4	20431	7	7833
7526	5	20447	3	2081
7527	5	20449	2	7860
7528	3	20451	2	1317
7529	5	20451	3	1317
7530	5	20453	3	4860
7531	5	20454	6	7840
7532	4	20455	5	7864
7533	4	20458	2	4735
7534	5	20460	2	5792
7535	3	20461	1	7836
7536	4	20462	1	2970
7537	5	20469	2	7859
7538	5	20475	3	4577
7539	5	20477	1	3251
7540	3	20479	5	5743
7541	5	20480	1	7854
7542	5	20481	7	7819
7543	5	20482	1	2662
7544	4	20484	1	1929
7545	5	20491	4	7891
7546	5	20493	3	7895
7547	4	20494	4	7198
7548	5	20495	4	2426
7549	5	20496	6	7902
7550	5	20497	2	7925
7551	4	20500	2	4193
7552	5	20505	6	7899
7553	5	20507	3	3445
7554	4	20508	7	7935
7555	5	20511	7	7920
7556	5	20514	2	7888
7557	5	20518	6	544
7558	5	20519	3	2838
7559	5	20520	4	3996
7560	1	20524	6	931
7561	3	20536	5	730
7562	3	20537	7	7903
7563	5	20539	7	386
7564	5	20542	1	7880
7565	4	20545	3	7906
7566	5	20549	4	7892
7567	5	20555	2	7874
7568	5	20557	2	7884
7569	5	20558	6	7887
7570	5	20560	4	3126
7571	5	20563	4	2130
7572	3	20564	1	7341
7573	5	20567	5	7936
7574	5	20572	1	6168
7575	3	20572	4	6168
7576	3	20575	7	7932
7577	5	20576	1	7881
7578	5	20577	2	3871
7579	4	20579	2	7871
7580	5	20580	6	7938
7581	5	20581	6	3340
7582	5	20583	6	3429
7583	3	20590	5	7280
7584	5	20592	7	7921
7585	5	20592	2	7921
7586	4	20596	7	2932
7587	3	20601	5	1525
7588	5	20601	4	1525
7589	4	20605	5	7872
7590	5	20614	2	7928
7591	3	20625	3	6330
7592	5	20626	2	6176
7593	4	20633	2	7918
7594	5	20634	4	7041
7595	3	20638	5	7910
7596	5	20638	7	7910
7597	5	20640	3	6254
7598	5	20642	7	1508
7599	5	20645	4	7965
7600	4	20646	7	187
7601	3	20649	1	7975
7602	3	20651	1	5387
7603	5	20652	2	2068
7604	3	20659	5	3086
7605	5	20660	6	7912
7606	3	20664	6	6044
7607	3	20665	5	7954
7608	5	20669	6	6301
7609	4	20672	5	7972
7610	5	20676	3	49
7611	2	20677	3	4458
7612	5	20681	2	3616
7613	5	20684	7	7130
7614	4	20687	7	8010
7615	4	20690	5	802
7616	1	20691	6	6125
7617	4	20696	1	7363
7618	3	20700	7	8016
7619	5	20701	1	6058
7620	5	20705	7	585
7621	4	20707	1	7994
7622	4	20708	4	5854
7623	5	20709	3	4996
7624	4	20710	1	8005
7625	3	20711	1	4591
7626	5	20713	5	8013
7627	4	20715	7	1084
7628	1	20717	6	4655
7629	5	20719	7	2570
7630	5	20720	3	1724
7631	5	20723	2	8032
7632	4	20724	4	8029
7633	4	20727	1	1053
7634	5	20729	5	8015
7635	5	20730	1	4436
7636	5	20739	3	2520
7637	2	20740	2	4658
7638	3	20741	3	7943
7639	5	20746	2	7953
7640	5	20747	2	5024
7641	2	20747	6	5024
7642	5	20748	6	7987
7643	5	20749	3	2596
7644	5	20751	6	7971
7645	5	20752	1	788
7646	5	20753	1	8009
7647	4	20756	1	8014
7648	5	20757	1	4222
7649	4	20757	2	4222
7650	4	20763	1	7997
7651	5	20767	4	7106
7652	5	20767	6	7106
7653	5	20768	2	7977
7654	4	20770	6	3443
7655	3	20772	4	1470
7656	4	20774	1	6282
7657	3	20778	3	7959
7658	5	20778	4	7959
7659	5	20783	6	6790
7660	4	20784	4	2821
7661	5	20789	6	32
7662	5	20798	1	7962
7663	5	20802	5	5244
7664	5	20808	4	6134
7665	4	20811	4	6533
7666	5	20814	7	2978
7667	4	20816	7	4937
7668	5	20823	7	7986
7669	5	20825	6	7948
7670	1	20826	1	1244
7671	5	20827	2	7980
7672	5	20832	2	832
7673	5	20833	6	8006
7674	5	20840	7	7960
7675	5	20842	6	2633
7676	5	20843	2	2492
7677	4	20844	6	8018
7678	4	20847	6	5575
7679	5	20849	1	8017
7680	5	20850	6	7990
7681	4	20853	1	1076
7682	5	20854	5	8024
7683	4	20855	4	6641
7684	5	20858	5	8034
7685	4	20859	5	5356
7686	5	20862	2	7979
7687	3	20863	1	7945
7688	3	20867	7	3863
7689	4	20869	7	8082
7690	1	20873	1	8069
7691	4	20876	1	187
7692	3	20881	1	6515
7693	5	20885	4	5994
7694	5	20888	4	4566
7695	5	20889	2	3759
7696	5	20891	6	4060
7697	5	20892	2	7529
7698	2	20894	6	5500
7699	5	20896	1	4636
7700	3	20900	5	496
7701	5	20903	5	8095
7702	5	20910	6	8094
7703	3	20915	5	7587
7704	1	20921	7	4262
7705	4	20922	3	8044
7706	5	20923	2	3614
7707	5	20926	2	6202
7708	5	20932	3	8042
7709	5	20933	7	8058
7710	5	20934	1	8065
7711	3	20936	6	8060
7712	5	20939	4	8038
7713	4	20940	5	7906
7714	5	20944	6	8076
7715	5	20947	4	4186
7716	4	20949	6	7249
7717	4	20955	4	4256
7718	5	20957	2	3817
7719	5	20960	2	8041
7720	3	20962	3	239
7721	5	20964	3	8053
7722	2	20970	5	959
7723	3	20973	5	8087
7724	5	20974	5	8059
7725	5	20976	4	8080
7726	4	20982	6	8103
7727	5	20983	7	8067
7728	5	20984	3	5484
7729	3	20986	1	8048
7730	3	20986	5	8048
7731	4	20987	3	7229
7732	4	20990	1	1415
7733	5	20991	2	8049
7734	5	20993	6	8070
7735	4	20995	1	8036
7736	5	20996	6	8043
7737	5	20999	2	3919
7738	5	21001	4	2980
7739	5	21002	6	1078
7740	5	21003	1	8066
7741	5	21009	1	3289
7742	3	21010	7	4593
7743	5	21011	5	8107
7744	5	21012	4	466
7745	5	21014	6	4287
7746	5	21015	1	6164
7747	5	21017	5	1263
7748	5	21020	1	5006
7749	5	21022	1	3002
7750	4	21025	7	8073
7751	5	21026	6	461
7752	5	21030	6	5345
7753	5	21033	2	8046
7754	5	21034	7	8100
7755	5	21040	2	424
7756	5	21045	7	944
7757	5	21050	3	3705
7758	5	21053	7	8035
7759	1	21055	7	4445
7760	1	21065	6	8097
7761	4	21066	7	4932
7762	2	21068	6	536
7763	5	21069	2	2416
7764	3	21070	5	6154
7765	5	21071	7	8091
7766	4	21076	7	5338
7767	4	21077	7	8093
7768	5	21082	5	1406
7769	5	21083	2	8054
7770	5	21084	6	8050
7771	5	21085	2	3153
7772	4	21086	5	55
7773	5	21088	2	8072
7774	5	21091	4	3686
7775	4	21092	6	8108
7776	5	21093	5	4311
7777	5	21095	4	1549
7778	4	21096	6	676
7779	3	21097	2	7361
7780	5	21098	7	4149
7781	5	21105	6	7525
7782	5	21108	1	3065
7783	4	21110	1	4325
7784	5	21117	4	3536
7785	2	21121	3	8185
7786	5	21122	6	3540
7787	3	21122	5	3540
7788	5	21126	1	3684
7789	4	21128	7	8129
7790	5	21129	1	3567
7791	5	21130	6	7383
7792	5	21131	7	8164
7793	4	21139	2	340
7794	5	21141	2	8157
7795	5	21145	2	2312
7796	5	21146	3	6901
7797	4	21151	7	8132
7798	5	21156	1	1321
7799	5	21159	5	2740
7800	4	21163	2	8120
7801	5	21164	7	4601
7802	4	21169	3	5326
7803	5	21170	2	6579
7804	4	21178	5	8138
7805	3	21179	3	1146
7806	5	21183	6	8160
7807	5	21184	4	8024
7808	3	21188	5	8147
7809	4	21191	5	8186
7810	4	21192	3	8179
7811	5	21193	4	5808
7812	5	21194	6	8115
7813	5	21195	2	8045
7814	4	21196	7	6467
7815	5	21200	6	8139
7816	4	21200	3	8139
7817	3	21201	7	6074
7818	5	21202	6	8175
7819	5	21203	2	8142
7820	5	21204	6	7582
7821	3	21207	5	8146
7822	4	21210	6	585
7823	5	21215	2	8130
7824	5	21216	7	8180
7825	5	21220	7	1293
7826	5	21225	6	1200
7827	5	21229	4	7156
7828	2	21230	4	4929
7829	5	21231	1	1994
7830	5	21232	2	8231
7831	5	21233	2	3380
7832	5	21234	4	8247
7833	3	21241	1	8084
7834	4	21245	7	381
7835	5	21247	4	5066
7836	5	21249	4	1833
7837	5	21252	6	8266
7838	5	21253	3	8206
7839	5	21254	4	1893
7840	5	21256	2	6053
7841	5	21262	7	8254
7842	5	21263	4	7131
7843	5	21264	3	8196
7844	4	21265	3	1213
7845	3	21266	1	8197
7846	5	21272	2	4622
7847	4	21276	5	6342
7848	5	21282	6	8237
7849	5	21284	4	8208
7850	5	21285	6	8191
7851	5	21286	4	1989
7852	3	21289	4	4996
7853	4	21290	2	4495
7854	3	21292	1	8219
7855	5	21293	7	7918
7856	5	21296	6	8205
7857	4	21302	4	2434
7858	3	21308	7	8195
7859	5	21312	2	1269
7860	3	21320	7	8210
7861	3	21324	6	2265
7862	5	21328	3	8220
7863	5	21332	2	8246
7864	3	21341	3	8248
7865	3	21344	4	8256
7866	5	21350	4	7387
7867	5	21350	2	7387
7868	4	21351	7	3820
7869	3	21355	1	8245
7870	5	21355	2	8245
7871	5	21363	4	8225
7872	5	21364	7	7480
7873	5	21365	6	2491
7874	5	21369	4	436
7875	5	21373	4	1329
7876	5	21373	3	1329
7877	5	21374	6	1311
7878	5	21377	2	8234
7879	5	21380	6	7690
7880	5	21384	3	5758
7881	5	21385	6	6347
7882	4	21391	2	8324
7883	5	21396	7	8323
7884	3	21399	7	622
7885	4	21401	5	2783
7886	5	21402	5	1846
7887	5	21405	6	8317
7888	3	21409	5	709
7889	4	21413	5	8314
7890	5	21418	5	7975
7891	5	21420	4	4120
7892	5	21424	7	8291
7893	5	21425	2	29
7894	4	21427	3	8283
7895	4	21428	1	6201
7896	4	21431	7	3705
7897	2	21434	6	8302
7898	4	21435	2	8307
7899	4	21436	5	8303
7900	5	21439	6	788
7901	5	21448	5	8304
7902	5	21449	7	4744
7903	5	21450	6	1969
7904	3	21451	5	8339
7905	5	21453	1	8293
7906	5	21458	4	8313
7907	4	21466	7	477
7908	4	21468	7	8274
7909	5	21470	6	3212
7910	5	21471	6	8269
7911	3	21473	7	511
7912	5	21476	1	3083
7913	3	21483	7	8294
7914	5	21484	2	4927
7915	3	21487	7	122
7916	5	21491	2	7773
7917	5	21493	4	8284
7918	3	21494	5	7211
7919	5	21495	4	4442
7920	5	21499	6	8281
7921	5	21500	6	8277
7922	4	21501	2	8290
7923	5	21502	1	8306
7924	5	21508	3	902
7925	4	21512	3	8335
7926	5	21513	4	48
7927	5	21514	3	6195
7928	4	21516	4	4624
7929	5	21518	7	8288
7930	4	21522	7	8297
7931	5	21526	4	2823
7932	5	21533	3	8296
7933	4	21534	1	5808
7934	5	21536	6	7486
7935	5	21538	7	8340
7936	3	21542	5	8311
7937	5	21543	4	2061
7938	2	21547	3	5359
7939	5	21547	1	5359
7940	4	21549	5	4284
7941	3	21550	1	1624
7942	4	21551	4	1407
7943	1	21553	6	8316
7944	5	21554	5	8282
7945	4	21558	1	8285
7946	5	21560	4	8315
7947	5	21564	1	6886
7948	4	21566	2	7706
7949	4	21567	7	6190
7950	5	21568	6	4862
7951	4	21571	7	3997
7952	5	21572	4	1322
7953	5	21575	4	8305
7954	5	21577	4	1947
7955	5	21582	1	7041
7956	4	21583	4	1233
7957	5	21584	7	2604
7958	5	21591	7	5633
7959	3	21592	7	8371
7960	4	21593	5	8394
7961	5	21603	6	8368
7962	4	21604	3	8351
7963	5	21605	4	8375
7964	3	21606	3	8370
7965	3	21607	5	7007
7966	5	21608	2	2552
7967	5	21612	3	519
7968	1	21613	4	2561
7969	3	21619	1	1087
7970	5	21621	2	4604
7971	5	21622	1	8399
7972	5	21629	5	8348
7973	5	21629	2	8348
7974	5	21630	2	420
7975	5	21634	4	7158
7976	5	21636	2	245
7977	4	21644	7	8397
7978	3	21651	1	3173
7979	3	21654	2	7293
7980	4	21655	4	80
7981	2	21656	1	5935
7982	5	21658	7	8350
7983	3	21659	5	8384
7984	4	21661	2	2551
7985	4	21664	3	8381
7986	4	21665	6	6544
7987	5	21666	1	378
7988	3	21667	1	8406
7989	5	21673	1	506
7990	4	21676	1	8377
7991	5	21677	5	2264
7992	5	21680	6	1949
7993	5	21683	4	8386
7994	5	21685	6	62
7995	4	21687	3	5627
7996	5	21688	7	464
7997	4	21690	3	8390
7998	5	21694	2	6733
7999	5	21696	6	8362
8000	5	21699	4	826
8001	3	21703	3	27
8002	4	21704	6	8366
8003	5	21706	6	3997
8004	3	21707	5	8378
8005	3	21709	5	8409
8006	5	21717	1	376
8007	2	21718	6	8389
8008	4	21721	3	8374
8009	4	21725	2	1214
8010	5	21726	1	4800
8011	5	21727	2	1376
8012	3	21730	4	2951
8013	5	21735	2	970
8014	5	21737	1	6248
8015	1	21739	4	8346
8016	3	21741	3	3449
8017	4	21742	7	8427
8018	4	21745	1	8412
8019	5	21747	7	3886
8020	5	21748	1	6496
8021	5	21760	7	6959
8022	2	21760	6	6959
8023	5	21763	6	803
8024	5	21771	2	8439
8025	4	21775	7	1239
8026	5	21778	5	4439
8027	5	21781	6	3268
8028	5	21783	3	3870
8029	5	21790	2	8453
8030	4	21792	7	2440
8031	5	21794	6	8481
8032	3	21795	1	4132
8033	5	21797	7	8304
8034	5	21798	6	4035
8035	5	21799	7	7431
8036	4	21803	5	7491
8037	5	21806	4	5265
8038	5	21807	2	1245
8039	5	21808	1	2521
8040	5	21809	6	3461
8041	4	21810	1	8444
8042	5	21812	7	7667
8043	5	21813	3	8470
8044	5	21814	3	704
8045	4	21815	3	8475
8046	5	21816	4	8421
8047	5	21819	2	3497
8048	2	21820	4	8465
8049	4	21822	4	8455
8050	5	21824	6	6957
8051	3	21826	7	846
8052	3	21828	5	1247
8053	5	21831	4	2420
8054	4	21833	7	2739
8055	5	21834	5	3512
8056	4	21840	5	6708
8057	2	21840	3	6708
8058	4	21841	1	7397
8059	5	21842	4	7651
8060	5	21843	2	709
8061	3	21845	7	3336
8062	3	21847	3	6814
8063	4	21852	7	8436
8064	5	21854	5	8411
8065	5	21855	7	8425
8066	5	21860	6	8451
8067	5	21862	5	5483
8068	3	21863	7	2552
8069	5	21866	2	415
8070	5	21867	4	8467
8071	3	21876	7	8462
8072	5	21878	6	8295
8073	5	21879	3	8419
8074	5	21880	2	5071
8075	5	21881	2	8426
8076	3	21882	4	5440
8077	5	21884	2	5986
8078	5	21884	5	5986
8079	3	21887	4	1059
8080	5	21893	4	8435
8081	4	21894	7	2789
8082	5	21895	1	7019
8083	5	21896	2	1597
8084	5	21900	7	8452
8085	4	21901	6	1436
8086	4	21904	6	5516
8087	3	21904	5	5516
8088	3	21905	2	8433
8089	5	21907	5	7559
8090	5	21908	5	8440
8091	5	21909	7	8472
8092	3	21912	5	4943
8093	4	21912	2	4943
8094	5	21915	1	5740
8095	4	21924	4	8504
8096	1	21926	6	8553
8097	2	21927	6	3437
8098	5	21928	3	8543
8099	5	21933	7	8535
8100	4	21937	5	4558
8101	5	21939	2	3836
8102	5	21942	7	3619
8103	3	21944	6	1053
8104	3	21946	3	5050
8105	5	21948	5	8568
8106	5	21950	5	8570
8107	5	21955	6	8554
8108	5	21956	2	8508
8109	1	21959	7	8505
8110	5	21963	7	8516
8111	5	21963	4	8516
8112	5	21969	4	8575
8113	5	21980	4	3480
8114	2	21982	6	8311
8115	5	21985	3	8542
8116	5	21986	3	2821
8117	4	21991	4	2768
8118	5	21994	5	691
8119	5	21997	6	8492
8120	4	22001	5	8056
8121	5	22002	6	5097
8122	3	22004	2	8471
8123	4	22006	7	5880
8124	3	22007	1	7726
8125	5	22008	2	8576
8126	5	22011	5	8539
8127	5	22013	2	5154
8128	5	22017	1	8550
8129	5	22018	2	2216
8130	4	22019	5	2791
8131	5	22020	1	924
8132	4	22021	4	8483
8133	5	22023	7	2332
8134	3	22027	4	2728
8135	4	22029	7	6788
8136	5	22032	2	8577
8137	5	22034	1	4171
8138	5	22037	7	8517
8139	5	22039	7	8548
8140	3	22041	5	8563
8141	2	22043	3	8574
8142	4	22044	3	4798
8143	5	22053	1	2848
8144	5	22054	7	2526
8145	5	22058	5	8512
8146	5	22060	5	7888
8147	4	22064	7	376
8148	5	22066	2	8503
8149	3	22070	7	5473
8150	3	22070	5	5473
8151	4	22071	6	6930
8152	3	22072	4	7069
8153	5	22073	6	7007
8154	4	22076	2	7885
8155	4	22078	7	6505
8156	5	22085	5	8564
8157	5	22085	4	8564
8158	5	22087	5	6729
8159	5	22089	6	5194
8160	5	22098	7	3718
8161	4	22099	7	8557
8162	3	22101	1	2698
8163	4	22103	2	5865
8164	3	22104	5	7190
8165	2	22104	6	7190
8166	5	22107	5	5360
8167	5	22109	2	2191
8168	5	22110	5	7186
8169	5	22112	3	8552
8170	4	22114	3	3399
8171	5	22115	6	1134
8172	5	22118	7	7446
8173	5	22119	1	506
8174	4	22120	4	8507
8175	4	22121	7	8486
8176	5	22121	2	8486
8177	4	22126	7	8527
8178	3	22127	5	8487
8179	5	22128	3	5913
8180	5	22130	1	8520
8181	3	22135	5	4478
8182	5	22140	1	8523
8183	4	22141	5	8490
8184	3	22142	1	8502
8185	4	22144	5	7368
8186	4	22147	3	8509
8187	4	22150	5	5453
8188	5	22152	4	8528
8189	5	22157	6	8510
8190	5	22158	1	1328
8191	5	22161	7	8499
8192	4	22168	7	7638
8193	4	22174	2	3414
8194	5	22178	1	4731
8195	3	22179	3	1363
8196	4	22180	7	8485
8197	5	22181	7	585
8198	2	22183	1	8489
8199	5	22191	4	1548
8200	5	22192	1	4783
8201	5	22193	4	5958
8202	3	22200	7	5069
8203	3	22200	6	5069
8204	3	22204	7	5479
8205	5	22205	2	8641
8206	4	22207	7	2662
8207	5	22208	2	749
8208	3	22209	5	5526
8209	5	22213	1	2817
8210	3	22214	5	154
8211	5	22219	7	2257
8212	5	22222	6	6792
8213	4	22224	4	3365
8214	4	22233	7	1862
8215	5	22234	6	8596
8216	4	22235	7	4347
8217	5	22236	2	8656
8218	3	22239	6	8660
8219	5	22243	4	2517
8220	5	22244	6	1163
8221	4	22245	1	8623
8222	1	22250	3	5006
8223	5	22251	6	4730
8224	5	22255	6	2706
8225	5	22257	3	3449
8226	4	22259	3	6526
8227	4	22261	1	8587
8228	5	22262	6	8593
8229	3	22264	7	8654
8230	5	22265	2	8619
8231	5	22266	2	2590
8232	3	22267	3	7538
8233	4	22270	2	8665
8234	4	22273	2	8668
8235	5	22274	5	486
8236	5	22276	7	6483
8237	4	22278	2	8581
8238	4	22279	5	8655
8239	5	22283	1	8599
8240	4	22283	6	8599
8241	4	22288	4	5337
8242	4	22294	7	8643
8243	4	22295	3	8633
8244	5	22296	1	4688
8245	4	22298	7	8636
8246	4	22299	4	790
8247	5	22300	7	1495
8248	3	22300	2	1495
8249	5	22303	4	3916
8250	4	22306	6	5091
8251	5	22308	3	8615
8252	3	22308	4	8615
8253	4	22309	3	1255
8254	5	22315	4	8583
8255	5	22318	3	3168
8256	5	22322	2	8645
8257	5	22323	2	8659
8258	4	22324	3	1457
8259	5	22325	2	8174
8260	5	22327	6	3534
8261	4	22327	1	3534
8262	4	22328	7	4400
8263	5	22330	6	8594
8264	5	22335	3	5023
8265	5	22335	7	5023
8266	4	22337	3	7110
8267	1	22341	6	8313
8268	5	22345	1	1860
8269	5	22348	7	8588
8270	5	22349	4	7200
8271	4	22350	4	5681
8272	5	22351	6	8605
8273	5	22355	4	8584
8274	4	22356	2	8622
8275	5	22357	6	7186
8276	5	22358	4	361
8277	5	22359	2	1044
8278	4	22360	5	3260
8279	5	22361	7	5193
8280	5	22362	4	8600
8281	4	22365	7	3730
8282	5	22367	2	734
8283	4	22375	5	4992
8284	5	22379	1	4887
8285	4	22380	3	3965
8286	5	22385	2	6651
8287	4	22389	5	4196
8288	4	22392	4	5361
8289	4	22395	3	6565
8290	5	22398	4	1375
8291	5	22399	5	4116
8292	4	22399	7	4116
8293	3	22405	7	8586
8294	5	22407	6	8661
8295	3	22407	5	8661
8296	5	22409	7	5630
8297	5	22410	1	5667
8298	5	22415	2	8650
8299	5	22416	2	8644
8300	5	22418	7	8663
8301	5	22419	6	1174
8302	2	22420	4	8614
8303	3	22421	7	2524
8304	4	22424	7	7125
8305	5	22426	5	8648
8306	5	22426	6	8648
8307	4	22432	7	3358
8308	2	22434	3	1075
8309	5	22435	6	880
8310	5	22436	7	5822
8311	4	22437	6	8620
8312	3	22440	1	8651
8313	5	22441	2	3558
8314	5	22442	6	8608
8315	3	22443	3	588
8316	5	22443	1	588
8317	3	22450	5	8602
8318	5	22452	4	4246
8319	5	22456	5	4921
8320	5	22457	3	8601
8321	3	22458	5	8634
8322	3	22467	4	8631
8323	3	22469	7	7137
8324	5	22475	1	8687
8325	5	22477	4	6754
8326	4	22478	2	2023
8327	3	22479	4	2841
8328	5	22480	6	8685
8329	5	22484	7	2439
8330	5	22487	1	8682
8331	5	22488	2	776
8332	5	22489	4	1445
8333	5	22491	5	8688
8334	3	22494	5	4986
8335	3	22503	5	4570
8336	5	22505	5	8693
8337	5	22506	6	68
8338	4	22508	1	7522
8339	5	22512	5	7374
8340	4	22515	1	8701
8341	4	22517	7	2509
8342	4	22519	7	8715
8343	4	22520	5	6042
8344	5	22521	6	6163
8345	5	22530	7	8731
8346	5	22533	7	6153
8347	5	22535	2	8095
8348	4	22538	3	2627
8349	5	22539	7	8699
8350	4	22546	7	1843
8351	5	22549	4	3910
8352	5	22551	4	7891
8353	5	22554	7	466
8354	5	22555	2	8723
8355	5	22560	6	8677
8356	5	22561	3	8696
8357	1	22564	6	3784
8358	3	22568	2	4592
8359	4	22570	7	3948
8360	3	22571	2	8676
8361	5	22580	2	4292
8362	5	22581	1	482
8363	5	22582	6	8719
8364	4	22588	2	1638
8365	5	22589	4	8747
8366	5	22591	2	5270
8367	5	22594	5	972
8368	1	22596	6	2520
8369	5	22606	1	6631
8370	5	22620	4	8762
8371	5	22623	2	7622
8372	3	22624	7	2383
8373	4	22625	2	8323
8374	3	22627	3	3006
8375	5	22628	4	7415
8376	5	22630	2	640
8377	3	22636	7	5293
8378	5	22637	5	753
8379	5	22640	5	8755
8380	5	22645	6	8765
8381	3	22647	3	8776
8382	5	22653	4	4223
8383	3	22654	2	4539
8384	5	22656	1	6034
8385	3	22657	5	1314
8386	2	22660	5	3579
8387	5	22661	7	8825
8388	5	22662	1	2189
8389	5	22665	2	1580
8390	4	22666	2	8758
8391	4	22668	5	8768
8392	2	22669	6	5318
8393	4	22671	1	7379
8394	5	22673	6	8609
8395	5	22675	7	8791
8396	5	22676	3	76
8397	3	22678	1	8824
8398	4	22680	6	8753
8399	5	22685	5	6247
8400	2	22687	1	4323
8401	4	22689	4	8802
8402	5	22690	4	8305
8403	3	22691	4	5947
8404	5	22694	6	2360
8405	5	22696	2	3817
8406	5	22697	6	5236
8407	4	22701	7	8804
8408	5	22702	1	2608
8409	3	22703	2	8779
8410	4	22705	6	8788
8411	5	22709	4	1656
8412	1	22710	5	7691
8413	5	22710	6	7691
8414	5	22713	4	3459
8415	5	22717	4	8826
8416	5	22718	1	8784
8417	5	22721	7	8669
8418	5	22723	7	3990
8419	4	22724	7	8795
8420	3	22726	7	787
8421	5	22727	4	2932
8422	3	22728	2	8898
8423	5	22729	3	8850
8424	4	22730	6	8841
8425	4	22732	4	4060
8426	3	22733	2	8871
8427	5	22736	2	8835
8428	5	22739	1	1087
8429	5	22741	2	6015
8430	4	22743	5	3248
8431	5	22747	5	4833
8432	3	22755	5	6282
8433	5	22760	6	5878
8434	4	22762	7	2140
8435	3	22763	1	1679
8436	5	22764	4	2776
8437	5	22765	5	5113
8438	5	22765	1	5113
8439	4	22766	1	3139
8440	4	22766	5	3139
8441	3	22769	1	8840
8442	4	22771	7	2052
8443	5	22772	6	3008
8444	3	22773	7	3127
8445	5	22778	1	1228
8446	5	22783	3	8891
8447	5	22784	7	8148
8448	5	22792	2	8896
8449	4	22794	6	8852
8450	4	22798	1	2941
8451	3	22800	1	5050
8452	4	22801	5	8834
8453	3	22808	6	8879
8454	4	22811	7	8884
8455	3	22814	4	4949
8456	3	22818	7	1140
8457	5	22820	6	4072
8458	4	22824	7	2857
8459	1	22825	6	8140
8460	1	22840	6	8842
8461	4	22841	6	7334
8462	4	22842	1	1174
8463	4	22842	7	1174
8464	5	22843	5	8865
8465	5	22844	6	8828
8466	5	22845	2	6347
8467	5	22849	5	5546
8468	4	22850	7	6182
8469	5	22851	5	8878
8470	5	22852	6	4110
8471	5	22854	5	5723
8472	5	22855	7	8836
8473	4	22858	4	8844
8474	5	22861	3	1685
8475	3	22863	7	337
8476	5	22864	6	4983
8477	3	22870	2	5325
8478	5	22871	4	7916
8479	5	22876	2	8851
8480	4	22877	3	1334
8481	3	22879	3	8888
8482	5	22884	6	8876
8483	4	22886	7	549
8484	4	22890	4	4704
8485	5	22891	6	8903
8486	3	22894	4	8640
8487	5	22895	1	292
8488	5	22898	6	8856
8489	5	22902	3	1581
8490	5	22903	5	491
8491	4	22905	6	3166
8492	5	22908	5	8954
8493	5	22909	6	8924
8494	4	22912	1	8938
8495	5	22917	6	8941
8496	4	22919	3	1070
8497	5	22920	6	8976
8498	1	22924	6	8939
8499	3	22927	2	4819
8500	1	22928	6	5768
8501	3	22929	6	8922
8502	5	22930	2	8947
8503	4	22932	3	8975
8504	5	22933	5	2595
8505	3	22934	1	4409
8506	4	22938	7	1517
8507	3	22949	4	8528
8508	5	22952	4	4585
8509	5	22960	1	5750
8510	3	22963	4	8913
8511	5	22966	2	1282
8512	5	22971	4	3621
8513	3	22972	1	5683
8514	5	22973	6	5456
8515	4	22974	6	5058
8516	5	22975	6	2190
8517	4	22980	5	6460
8518	5	22982	4	1257
8519	5	22983	6	1445
8520	5	22984	6	128
8521	5	22990	7	6012
8522	5	22990	2	6012
8523	4	22993	1	1755
8524	4	22995	1	1984
8525	5	22997	3	8972
8526	4	22998	5	4081
8527	5	22999	2	8942
8528	3	23001	3	8966
8529	4	23002	7	8951
8530	3	23003	5	5322
8531	5	23008	1	3858
8532	5	23009	6	1727
8533	3	23011	5	4094
8534	4	23013	7	6848
8535	5	23016	6	8973
8536	3	23016	5	8973
8537	4	23021	7	8918
8538	3	23023	3	3835
8539	5	23025	2	6444
8540	5	23025	6	6444
8541	4	23026	6	2172
8542	4	23027	1	8904
8543	5	23038	5	2845
8544	5	23039	5	8921
8545	5	23040	6	8929
8546	3	23043	4	1119
8547	4	23046	7	8907
8548	4	23047	1	3115
8549	5	23049	3	8237
8550	5	23051	6	3965
8551	5	23053	6	1985
8552	5	23056	2	799
8553	5	23059	2	4251
8554	3	23060	5	8908
8555	4	23063	1	3449
8556	2	23069	1	8933
8557	5	23073	4	6787
8558	5	23073	2	6787
8559	5	23077	6	8927
8560	5	23078	1	8605
8561	5	23079	5	7165
8562	5	23080	4	1228
8563	4	23084	5	8917
8564	5	23086	3	3198
8565	5	23091	3	9037
8566	4	23092	3	2358
8567	5	23095	3	7084
8568	5	23099	2	4818
8569	5	23100	4	2124
8570	5	23101	6	9029
8571	3	23102	5	8204
8572	5	23104	4	3445
8573	5	23108	5	8984
8574	3	23109	5	8985
8575	4	23110	1	9048
8576	3	23112	4	3316
8577	5	23119	7	8601
8578	5	23119	4	8601
8579	3	23120	5	9019
8580	1	23122	6	9022
8581	5	23123	7	9016
8582	4	23124	5	9059
8583	4	23126	4	9003
8584	5	23127	5	9006
8585	5	23128	4	677
8586	1	23131	3	2585
8587	4	23136	6	8994
8588	2	23139	4	8885
8589	5	23141	6	2447
8590	3	23142	2	6516
8591	5	23145	6	9009
8592	5	23146	6	8988
8593	1	23147	6	2806
8594	4	23148	6	1700
8595	5	23149	1	8998
8596	1	23151	7	1212
8597	5	23153	2	8980
8598	5	23154	4	5078
8599	4	23156	7	5447
8600	5	23158	6	143
8601	5	23162	2	1073
8602	5	23170	6	9012
8603	3	23171	5	8981
8604	5	23174	7	6097
8605	3	23179	2	2089
8606	5	23180	6	9026
8607	3	23180	5	9026
8608	4	23181	7	4980
8609	4	23186	7	9049
8610	5	23187	1	9056
8611	1	23192	6	9020
8612	3	23193	2	6364
8613	5	23196	6	8978
8614	5	23197	1	9035
8615	5	23198	6	6357
8616	5	23203	7	9005
8617	5	23204	5	7596
8618	5	23208	6	4502
8619	5	23211	3	8990
8620	4	23213	1	997
8621	5	23214	4	9058
8622	5	23215	6	8101
8623	5	23216	6	2669
8624	4	23217	2	7792
8625	5	23218	4	8995
8626	4	23223	5	3624
8627	5	23224	2	1119
8628	4	23229	7	7827
8629	4	23231	1	519
8630	4	23232	5	8991
8631	3	23234	4	2902
8632	3	23236	7	7183
8633	3	23236	5	7183
8634	3	23239	4	7282
8635	3	23240	7	8997
8636	5	23241	6	6341
8637	3	23246	6	2723
8638	5	23247	6	9041
8639	5	23249	2	7112
8640	5	23250	2	4245
8641	4	23251	5	8989
8642	4	23251	2	8989
8643	4	23254	1	8987
8644	5	23255	4	2077
8645	5	23257	6	8797
8646	4	23262	6	2374
8647	5	23263	6	9068
8648	1	23265	6	9088
8649	5	23267	5	9078
8650	3	23270	7	9089
8651	5	23274	2	4970
8652	5	23276	7	9069
8653	5	23279	4	239
8654	5	23280	6	9131
8655	5	23281	1	9113
8656	4	23283	5	925
8657	4	23284	7	981
8658	3	23286	5	1545
8659	4	23287	3	4206
8660	5	23291	4	8654
8661	5	23292	3	9136
8662	3	23293	1	4428
8663	5	23296	2	312
8664	4	23303	1	9109
8665	3	23304	1	3902
8666	5	23306	1	9142
8667	5	23315	2	6429
8668	5	23318	4	9079
8669	4	23319	5	4373
8670	4	23320	5	191
8671	3	23321	5	4469
8672	3	23322	7	5189
8673	5	23323	6	5265
8674	5	23325	7	9130
8675	4	23326	5	9110
8676	3	23329	2	3323
8677	5	23330	2	826
8678	4	23335	7	7530
8679	3	23338	5	9102
8680	5	23339	1	9119
8681	5	23342	7	8980
8682	5	23344	6	9101
8683	5	23347	3	7574
8684	3	23350	6	1568
8685	3	23352	3	3045
8686	2	23353	6	7518
8687	5	23354	2	9125
8688	2	23355	1	9077
8689	5	23356	7	9128
8690	5	23356	4	9128
8691	4	23357	3	9098
8692	4	23357	5	9098
8693	4	23358	1	9123
8694	3	23360	7	3006
8695	4	23360	2	3006
8696	5	23362	2	9140
8697	5	23363	5	7092
8698	3	23365	3	1880
8699	3	23366	2	9075
8700	5	23368	6	9137
8701	1	23371	5	3129
8702	3	23376	5	4294
8703	3	23377	4	3964
8704	2	23378	4	1076
8705	5	23382	6	5984
8706	4	23384	5	7465
8707	5	23385	4	4054
8708	5	23389	6	9124
8709	3	23393	2	9074
8710	4	23394	7	9135
8711	5	23397	7	586
8712	5	23401	7	9064
8713	5	23406	2	9103
8714	3	23409	6	3268
8715	5	23412	3	2691
8716	4	23414	6	5146
8717	4	23423	7	9143
8718	5	23425	2	5935
8719	5	23427	3	3442
8720	4	23430	2	7098
8721	4	23434	1	76
8722	5	23436	7	9065
8723	5	23437	5	5272
8724	4	23438	5	4902
8725	5	23441	5	4050
8726	5	23445	1	9081
8727	5	23446	7	2032
8728	5	23448	3	5892
8729	5	23450	4	9063
8730	3	23452	4	9092
8731	3	23457	2	9111
8732	5	23460	4	1938
8733	5	23461	2	6857
8734	5	23464	4	8016
8735	5	23465	4	8332
8736	2	23470	3	4154
8737	5	23471	4	7679
8738	5	23472	7	4966
8739	4	23474	4	3629
8740	5	23476	6	356
8741	5	23479	6	9099
8742	5	23481	6	4190
8743	4	23482	7	1582
8744	5	23483	1	9072
8745	5	23487	3	4682
8746	2	23492	7	9118
8747	3	23493	5	9090
8748	5	23495	2	9178
8749	3	23497	2	1255
8750	4	23499	7	9146
8751	3	23502	5	9222
8752	5	23503	2	2276
8753	3	23505	3	9181
8754	5	23506	5	5795
8755	5	23509	6	4347
8756	4	23510	5	9179
8757	5	23511	3	9213
8758	4	23512	4	9155
8759	4	23515	5	9163
8760	5	23517	7	9162
8761	5	23519	4	654
8762	4	23521	4	3241
8763	5	23525	2	4120
8764	5	23531	6	2404
8765	5	23536	4	5891
8766	4	23538	1	9152
8767	5	23541	6	517
8768	5	23543	1	9198
8769	4	23546	3	9218
8770	2	23548	3	1306
8771	5	23552	6	5134
8772	5	23562	7	4069
8773	4	23563	5	8813
8774	4	23565	3	9168
8775	4	23567	3	9204
8776	5	23568	2	8397
8777	5	23570	4	931
8778	5	23577	6	9232
8779	3	23578	3	9212
8780	3	23583	7	2317
8781	5	23586	5	9221
8782	5	23587	3	2783
8783	3	23589	5	9207
8784	5	23590	2	7458
8785	4	23597	2	9186
8786	5	23598	6	3744
8787	5	23601	6	440
8788	4	23604	7	585
8789	5	23606	4	5099
8790	3	23610	2	360
8791	4	23615	6	5237
8792	3	23616	2	9219
8793	5	23618	6	9196
8794	3	23620	7	9161
8795	3	23624	4	7742
8796	5	23626	3	150
8797	5	23627	6	9154
8798	5	23629	1	8660
8799	4	23631	7	9203
8800	5	23631	2	9203
8801	5	23632	6	5724
8802	5	23634	6	9208
8803	4	23635	2	1387
8804	4	23644	7	3811
8805	5	23647	2	7537
8806	3	23648	1	9206
8807	5	23651	2	9171
8808	5	23652	7	9217
8809	3	23653	5	9150
8810	5	23655	7	9194
8811	5	23655	6	9194
8812	4	23656	7	6705
8813	4	23658	1	9210
8814	2	23658	6	9210
8815	5	23660	3	8570
8816	4	23664	1	8375
8817	5	23665	5	7747
8818	4	23666	2	143
8819	5	23670	3	381
8820	5	23673	5	3062
8821	4	23676	7	9242
8822	5	23681	4	2076
8823	5	23683	6	9173
8824	5	23685	2	9165
8825	5	23687	6	5903
8826	4	23688	3	4034
8827	5	23690	4	6769
8828	5	23691	6	4523
8829	5	23693	5	7358
8830	3	23694	7	4342
8831	4	23697	3	4432
8832	4	23699	1	2540
8833	2	23700	4	35
8834	3	23702	1	9184
8835	5	23704	4	9183
8836	5	23705	3	4185
8837	5	23706	6	5210
8838	5	23707	6	4646
8839	5	23716	1	736
8840	4	23725	4	9234
8841	2	23734	4	3734
8842	5	23737	6	4490
8843	5	23741	4	5361
8844	5	23742	4	9199
8845	5	23743	5	5253
8846	3	23745	5	9159
8847	1	23748	6	2369
8848	5	23749	1	9149
8849	3	23757	6	4850
8850	4	23759	6	9170
8851	4	23759	4	9170
8852	5	23760	4	7624
8853	5	23761	6	9224
8854	5	23761	4	9224
8855	3	23762	6	8108
8856	5	23763	2	1626
8857	5	23768	4	2044
8858	5	23770	5	3281
8859	3	23773	3	9274
8860	5	23781	7	9318
8861	5	23783	6	519
8862	5	23788	7	2845
8863	4	23789	7	9306
8864	5	23792	2	9263
8865	5	23794	4	9284
8866	3	23801	4	4624
8867	5	23805	5	761
8868	5	23808	3	2041
8869	5	23810	7	9290
8870	5	23813	2	9313
8871	3	23814	3	9270
8872	5	23816	7	9281
8873	5	23821	2	8149
8874	5	23826	6	7378
8875	5	23827	3	3380
8876	4	23828	1	9304
8877	5	23830	2	7717
8878	5	23831	2	2477
8879	3	23832	3	9261
8880	5	23832	6	9261
8881	4	23835	5	9292
8882	5	23836	6	964
8883	4	23837	5	4912
8884	5	23842	1	9294
8885	4	23844	3	4370
8886	5	23846	3	2442
8887	5	23846	7	2442
8888	5	23850	6	9272
8889	3	23851	7	2871
8890	4	23856	6	9245
8891	4	23857	5	7253
8892	5	23858	7	4249
8893	4	23859	7	5094
8894	4	23861	7	9296
8895	4	23862	1	9310
8896	3	23867	5	5236
8897	5	23872	3	2823
8898	5	23873	4	8275
8899	5	23875	7	9262
8900	5	23877	6	440
8901	5	23878	3	9283
8902	3	23879	5	4100
8903	4	23880	1	9280
8904	3	23882	7	3137
8905	5	23886	3	9311
8906	5	23887	5	8367
8907	4	23891	3	9273
8908	4	23902	4	7053
8909	5	23907	7	9329
8910	2	23908	2	6894
8911	3	23908	5	6894
8912	5	23909	2	7915
8913	2	23910	7	3604
8914	3	23911	5	9320
8915	5	23912	7	7551
8916	4	23914	7	9388
8917	3	23914	5	9388
8918	5	23916	3	627
8919	5	23917	1	5523
8920	4	23918	3	2832
8921	5	23938	2	9391
8922	4	23939	3	9376
8923	5	23940	4	8866
8924	5	23942	1	3045
8925	4	23944	5	688
8926	5	23946	6	9356
8927	2	23953	4	9366
8928	3	23957	7	9386
8929	3	23961	4	3472
8930	5	23968	7	9334
8931	4	23973	3	4086
8932	5	23977	3	5933
8933	3	23978	4	340
8934	3	23983	4	7785
8935	5	23987	6	6276
8936	4	23989	3	9372
8937	4	23991	2	2238
8938	4	23992	2	7356
8939	5	23996	2	9364
8940	5	23998	2	9398
8941	5	23999	4	2303
8942	5	24000	6	2670
8943	1	24002	4	5303
8944	5	24004	4	9387
8945	5	24004	1	9387
8946	5	24005	2	9397
8947	3	24014	5	9395
8948	2	24018	1	9358
8949	5	24019	6	9065
8950	4	24021	2	6950
8951	5	24023	7	820
8952	5	24028	7	4687
8953	5	24029	7	9385
8954	4	24029	6	9385
8955	3	24030	4	7796
8956	5	24032	6	9076
8957	5	24032	5	9076
8958	4	24035	5	1862
8959	5	24041	1	9407
8960	5	24042	5	9480
8961	5	24045	7	466
8962	4	24048	1	612
8963	3	24049	5	9453
8964	5	24051	4	5917
8965	5	24052	5	7987
8966	4	24053	7	1581
8967	5	24059	2	7461
8968	4	24071	7	9418
8969	5	24073	5	5975
8970	3	24075	1	2467
8971	5	24078	6	2082
8972	4	24080	4	9484
8973	3	24081	4	9406
8974	5	24085	2	2790
8975	5	24088	2	9402
8976	5	24092	3	7019
8977	5	24092	6	7019
8978	5	24094	2	9439
8979	5	24095	6	9449
8980	5	24096	4	2786
8981	5	24097	2	9411
8982	3	24099	6	9416
8983	4	24101	5	271
8984	5	24102	6	9409
8985	5	24104	5	1753
8986	4	24106	2	3657
8987	5	24109	4	3127
8988	4	24113	7	9412
8989	2	24121	6	9024
8990	5	24122	3	5875
8991	5	24123	7	9482
8992	5	24124	5	9424
8993	4	24127	7	9443
8994	5	24127	3	9443
8995	3	24129	3	3968
8996	5	24131	3	7594
8997	5	24136	6	7806
8998	3	24137	7	2193
8999	2	24139	7	4526
9000	5	24143	7	9465
9001	2	24143	4	9465
9002	5	24146	1	1657
9003	5	24158	7	9457
9004	5	24159	6	9469
9005	5	24161	6	9432
9006	4	24162	2	9451
9007	4	24168	6	1736
9008	1	24171	6	668
9009	5	24172	6	9419
9010	5	24179	7	4841
9011	5	24181	5	3690
9012	5	24182	5	9446
9013	5	24183	5	1993
9014	5	24184	6	7491
9015	2	24187	5	7678
9016	5	24192	1	2233
9017	3	24193	5	9410
9018	4	24197	7	9440
9019	5	24201	6	7533
9020	5	24202	7	2807
9021	5	24203	7	9436
9022	4	24204	1	912
9023	3	24208	7	9454
9024	3	24209	3	883
9025	3	24211	5	9414
9026	5	24213	4	1627
9027	4	24217	5	9423
9028	4	24218	5	9472
9029	4	24219	7	660
9030	5	24222	4	9112
9031	4	24223	6	8180
9032	4	24226	6	381
9033	5	24227	1	4413
9034	4	24232	2	1053
9035	5	24233	7	9456
9036	3	24234	7	7050
9037	3	24235	4	9468
9038	5	24236	6	6987
9039	5	24240	7	9425
9040	5	24242	1	9470
9041	4	24244	2	1693
9042	3	24244	7	1693
9043	5	24246	1	118
9044	5	24248	2	800
9045	5	24251	7	5056
9046	5	24257	5	2477
9047	5	24260	5	8410
9048	1	24261	4	6622
9049	4	24262	7	9494
9050	5	24266	6	7918
9051	4	24273	5	8450
9052	3	24275	5	6873
9053	5	24277	6	9552
9054	5	24284	4	4825
9055	3	24285	3	7591
9056	5	24286	6	398
9057	5	24288	4	9563
9058	3	24291	5	640
9059	3	24296	7	9529
9060	5	24300	4	9495
9061	2	24304	2	9561
9062	3	24305	7	9527
9063	5	24305	6	9527
9064	5	24307	4	1231
9065	5	24310	3	2752
9066	5	24313	1	7462
9067	2	24313	6	7462
9068	5	24317	3	9507
9069	4	24318	4	9542
9070	3	24320	5	9503
9071	5	24321	6	9530
9072	5	24324	7	9553
9073	3	24325	4	9040
9074	4	24333	7	9488
9075	5	24334	6	9534
9076	2	24335	6	519
9077	4	24341	2	7188
9078	5	24343	6	3547
9079	5	24345	6	4804
9080	4	24347	6	8877
9081	3	24347	4	8877
9082	5	24348	4	9490
9083	5	24351	7	2980
9084	4	24352	7	5654
9085	5	24355	3	1293
9086	4	24357	4	4453
9087	5	24358	1	9393
9088	4	24361	5	5675
9089	3	24367	5	3730
9090	5	24369	7	9524
9091	5	24370	6	5963
9092	3	24376	6	9501
9093	5	24379	1	7259
9094	5	24388	5	9493
9095	5	24390	4	9569
9096	4	24392	5	568
9097	5	24400	2	1854
9098	4	24407	4	7125
9099	4	24408	3	9554
9100	3	24410	1	9510
9101	4	24412	4	9508
9102	5	24413	6	9506
9103	3	24414	2	9487
9104	5	24415	4	9492
9105	5	24416	3	6366
9106	5	24421	4	6341
9107	4	24426	7	9205
9108	4	24427	3	9511
9109	3	24428	5	9500
9110	5	24429	4	3909
9111	4	24431	5	7942
9112	5	24433	6	213
9113	3	24435	3	9560
9114	4	24437	1	3623
9115	5	24440	6	9556
9116	3	24441	4	2443
9117	3	24444	1	2386
9118	4	24446	5	9543
9119	3	24449	5	6775
9120	4	24452	7	8656
9121	4	24454	1	3318
9122	4	24457	2	304
9123	4	24458	5	9544
9124	4	24459	7	9538
9125	5	24468	6	7509
9126	3	24470	4	9497
9127	5	24476	3	9572
9128	5	24477	5	4140
9129	5	24477	4	4140
9130	5	24478	6	9547
9131	3	24479	2	902
9132	4	24481	4	4255
9133	5	24488	1	3887
9134	5	24494	4	9610
9135	5	24498	2	9654
9136	5	24499	3	9603
9137	4	24500	2	4546
9138	5	24502	5	310
9139	5	24504	2	9614
9140	4	24507	5	9619
9141	5	24508	3	6729
9142	3	24509	7	3659
9143	5	24513	2	9612
9144	5	24520	2	9583
9145	4	24523	3	4547
9146	5	24524	4	1409
9147	5	24525	7	5943
9148	5	24529	1	8956
9149	1	24534	6	4592
9150	5	24535	5	8397
9151	5	24536	2	8358
9152	5	24537	2	9597
9153	5	24538	4	9659
9154	5	24539	7	9650
9155	4	24540	7	1183
9156	3	24541	4	660
9157	4	24543	1	5095
9158	2	24544	1	4963
9159	4	24547	7	4794
9160	4	24551	4	9663
9161	5	24552	2	1545
9162	5	24555	1	9664
9163	4	24556	2	9588
9164	5	24559	6	2791
9165	5	24560	3	9644
9166	5	24563	4	143
9167	5	24565	2	1491
9168	5	24566	1	9613
9169	4	24568	7	9595
9170	5	24571	3	1293
9171	3	24574	4	5077
9172	5	24576	3	3364
9173	5	24577	2	9657
9174	5	24584	7	3695
9175	5	24594	6	9641
9176	5	24595	4	8820
9177	5	24597	6	7828
9178	3	24601	5	4061
9179	4	24602	4	7261
9180	5	24603	4	2139
9181	5	24610	3	4870
9182	1	24611	6	7183
9183	4	24611	5	7183
9184	5	24614	7	9625
9185	5	24616	2	9637
9186	3	24618	5	7490
9187	4	24619	3	281
9188	5	24623	2	2368
9189	3	24624	2	9660
9190	5	24627	6	2519
9191	5	24634	6	4330
9192	3	24638	2	5186
9193	5	24638	6	5186
9194	5	24640	5	9661
9195	3	24641	3	6515
9196	4	24641	2	6515
9197	4	24644	1	9580
9198	4	24645	7	2664
9199	4	24648	4	9371
9200	4	24649	7	71
9201	4	24651	7	535
9202	5	24654	2	9628
9203	4	24656	4	2123
9204	5	24658	2	257
9205	5	24659	5	3736
9206	5	24662	1	484
9207	5	24664	1	4139
9208	4	24667	1	9629
9209	5	24668	1	9622
9210	4	24674	3	9740
9211	5	24680	6	9695
9212	5	24682	5	464
9213	5	24689	4	9743
9214	4	24691	6	9669
9215	3	24692	4	408
9216	5	24696	4	2513
9217	5	24699	5	9690
9218	4	24702	2	4407
9219	5	24706	5	9670
9220	4	24707	7	9725
9221	5	24711	4	7217
9222	5	24712	2	5790
9223	4	24714	2	5843
9224	4	24718	6	81
9225	4	24720	7	9758
9226	5	24721	7	9668
9227	4	24722	4	6674
9228	4	24725	7	9724
9229	4	24727	1	9746
9230	3	24731	3	3170
9231	5	24733	2	1765
9232	5	24734	2	9685
9233	5	24735	1	9714
9234	5	24736	4	9767
9235	5	24737	5	9770
9236	5	24737	6	9770
9237	4	24740	7	9735
9238	4	24741	5	9713
9239	5	24747	4	5143
9240	3	24749	5	2619
9241	5	24749	1	2619
9242	4	24750	1	1597
9243	5	24751	2	806
9244	5	24752	3	9674
9245	4	24753	5	4135
9246	3	24755	7	7584
9247	5	24759	7	7682
9248	5	24759	6	7682
9249	5	24761	6	4205
9250	3	24762	5	9741
9251	4	24765	5	6489
9252	3	24766	6	68
9253	5	24767	6	8628
9254	5	24773	7	5546
9255	5	24774	7	9736
9256	3	24779	5	8234
9257	4	24780	3	3403
9258	4	24782	5	707
9259	5	24783	2	9748
9260	5	24785	6	1993
9261	4	24786	7	8312
9262	4	24788	1	9712
9263	5	24788	4	9712
9264	4	24789	1	9706
9265	3	24794	5	9755
9266	5	24796	4	4722
9267	5	24797	7	9750
9268	5	24803	6	9742
9269	4	24807	7	6147
9270	5	24808	5	9733
9271	5	24809	1	9680
9272	5	24811	7	9222
9273	5	24813	6	6977
9274	3	24814	5	5325
9275	3	24816	3	9717
9276	1	24818	4	3790
9277	4	24820	5	9693
9278	5	24825	6	5798
9279	5	24826	3	1013
9280	3	24827	4	5066
9281	4	24829	5	1693
9282	5	24832	2	389
9283	5	24834	3	9710
9284	5	24834	1	9710
9285	5	24839	6	9752
9286	3	24840	5	6366
9287	5	24850	7	9732
9288	3	24852	2	9769
9289	5	24854	4	9754
9290	5	24861	4	4281
9291	3	24862	6	3268
9292	5	24863	7	9692
9293	5	24865	4	3457
9294	5	24866	6	8743
9295	4	24869	2	1232
9296	5	24870	6	5786
9297	4	24874	1	5979
9298	5	24874	6	5979
9299	2	24875	7	9744
9300	5	24884	5	5110
9301	3	24885	7	2684
9302	3	24886	7	9723
9303	5	24890	7	7479
9304	5	24891	7	9681
9305	3	24894	5	9679
9306	5	24896	7	2065
9307	5	24900	6	2536
9308	4	24901	6	9753
9309	4	24902	6	9771
9310	4	24904	5	5613
9311	5	24905	6	6167
9312	5	24906	7	4899
9313	4	24909	3	5623
9314	5	24911	4	9756
9315	5	24914	7	9745
9316	5	24917	6	9689
9317	4	24919	4	29
9318	3	24920	5	3180
9319	5	24921	4	3228
9320	3	24926	7	3314
9321	5	24927	7	337
9322	5	24928	3	7740
9323	4	24929	1	5281
9324	5	24936	6	8123
9325	5	24942	4	5730
9326	5	24943	4	9852
9327	5	24951	4	9786
9328	2	24952	3	5094
9329	4	24954	2	3142
9330	4	24956	6	3968
9331	4	24960	3	1992
9332	3	24961	7	9819
9333	4	24968	2	9805
9334	5	24969	5	2291
9335	3	24970	6	9797
9336	5	24971	5	4655
9337	4	24972	1	3898
9338	5	24977	1	2633
9339	3	24978	5	1970
9340	5	24981	3	4281
9341	3	24982	2	1529
9342	5	24986	4	9830
9343	4	24989	4	9814
9344	1	24990	7	9798
9345	4	24996	3	1101
9346	5	24997	3	6062
9347	3	24998	5	9815
9348	3	25000	3	9826
9349	5	25001	4	7242
9350	4	25002	7	8319
9351	3	25007	5	9834
9352	5	25011	3	124
9353	4	25011	7	124
9354	5	25012	1	2494
9355	3	25013	5	2367
9356	5	25014	2	8394
9357	5	25017	7	7970
9358	4	25019	5	6133
9359	5	25021	3	9836
9360	4	25021	1	9836
9361	4	25023	5	9559
9362	3	25026	5	2928
9363	5	25027	4	8178
9364	5	25029	6	5182
9365	5	25030	7	9795
9366	5	25032	1	8784
9367	3	25032	5	8784
9368	4	25039	5	1834
9369	5	25040	6	9839
9370	5	25043	6	6160
9371	5	25046	5	8708
9372	3	25050	4	3556
9373	5	25051	3	4636
9374	5	25052	4	285
9375	5	25053	4	1574
9376	3	25056	4	9403
9377	4	25057	6	1963
9378	3	25059	5	5148
9379	3	25060	5	9779
9380	5	25063	4	8448
9381	5	25064	5	9838
9382	5	25068	6	4137
9383	4	25069	7	1385
9384	4	25070	7	1914
9385	4	25074	6	28
9386	3	25079	7	9774
9387	5	25080	6	8945
9388	3	25082	7	2868
9389	5	25084	4	9846
9390	5	25086	1	9835
9391	2	25087	6	9844
9392	5	25088	1	6085
9393	4	25089	7	154
9394	5	25090	4	4216
9395	5	25090	1	4216
9396	4	25093	1	7177
9397	5	25096	3	6027
9398	4	25096	6	6027
9399	4	25098	6	9460
9400	5	25100	6	9773
9401	5	25103	4	7200
9402	5	25106	2	9794
9403	5	25109	2	9803
9404	3	25111	7	2441
9405	5	25116	3	754
9406	5	25117	4	2126
9407	5	25121	1	4124
9408	5	25126	4	382
9409	5	25127	1	396
9410	5	25128	3	3314
9411	4	25129	3	2937
9412	5	25129	4	2937
9413	5	25130	4	9837
9414	5	25131	6	9017
9415	3	25133	4	6568
9416	4	25138	6	2072
9417	5	25140	6	9785
9418	4	25144	4	6274
9419	5	25149	6	2842
9420	3	25151	5	9821
9421	5	25153	6	9818
9422	5	25155	2	9849
9423	4	25156	6	9817
9424	5	25160	2	9525
9425	5	25161	5	2694
9426	5	25163	1	4712
9427	5	25166	1	5580
9428	4	25173	3	9812
9429	4	25174	3	9053
9430	5	25175	5	4172
9431	5	25176	1	9828
9432	3	25182	1	9502
9433	3	25183	3	9780
9434	4	25187	6	9824
9435	5	25189	2	2021
9436	5	25191	3	9793
9437	5	25195	4	3204
9438	3	25197	1	6202
9439	4	25198	7	9810
9440	4	25204	4	2602
9441	5	25210	1	8503
9442	5	25210	7	8503
9443	5	25212	6	8623
9444	3	25213	1	886
9445	5	25214	3	9801
9446	5	25215	4	4021
9447	3	25221	3	5870
9448	5	25225	7	9813
9449	5	25226	6	1495
9450	5	25231	4	8798
9451	5	25236	4	9866
9452	5	25238	1	8265
9453	5	25239	1	8655
9454	5	25240	3	3320
9455	4	25243	5	3294
9456	3	25244	3	9878
9457	3	25246	2	9904
9458	5	25247	3	3647
9459	2	25248	6	6369
9460	5	25250	6	7597
9461	4	25253	1	8474
9462	5	25254	3	2577
9463	3	25259	2	2181
9464	4	25261	1	3821
9465	5	25270	3	2647
9466	5	25271	7	4190
9467	4	25273	3	9894
9468	5	25274	6	4870
9469	4	25275	6	164
9470	5	25277	3	1630
9471	5	25283	7	5249
9472	4	25287	7	5765
9473	4	25288	2	9906
9474	5	25289	2	4624
9475	3	25291	1	9043
9476	3	25292	2	7007
9477	4	25293	6	9871
9478	4	25295	7	6154
9479	5	25296	2	6265
9480	1	25298	6	3116
9481	5	25302	6	9924
9482	2	25305	6	3123
9483	2	25307	3	2798
9484	5	25307	2	2798
9485	3	25308	4	9890
9486	4	25308	7	9890
9487	2	25310	1	5629
9488	5	25312	4	5679
9489	3	25313	1	3202
9490	3	25316	1	9860
9491	5	25319	2	6393
9492	2	25326	6	5886
9493	3	25327	1	9858
9494	3	25328	2	3640
9495	5	25329	1	9915
9496	5	25334	5	371
9497	5	25336	4	1179
9498	5	25338	2	9909
9499	3	25340	2	9854
9500	3	25342	7	9872
9501	4	25343	7	9917
9502	4	25343	5	9917
9503	5	25344	3	475
9504	4	25345	7	3507
9505	4	25348	2	5790
9506	3	25349	4	9892
9507	3	25352	4	6600
9508	4	25358	7	2440
9509	5	25364	2	9929
9510	3	25365	4	2004
9511	3	25366	5	9885
9512	5	25368	4	996
9513	4	25370	4	9868
9514	3	25375	3	1026
9515	3	25376	3	8583
9516	3	25381	2	4685
9517	4	25384	1	9880
9518	4	25389	7	2956
9519	5	25392	6	10017
9520	5	25400	2	2706
9521	5	25401	7	8971
9522	5	25402	4	8716
9523	4	25407	6	6825
9524	4	25412	5	9956
9525	3	25413	5	372
9526	5	25414	2	6894
9527	5	25421	4	9977
9528	4	25424	7	2770
9529	3	25432	7	9963
9530	5	25439	4	2420
9531	5	25445	1	9984
9532	3	25453	1	265
9533	4	25455	5	3755
9534	5	25456	5	2116
9535	4	25458	5	9737
9536	4	25460	5	5473
9537	5	25463	4	291
9538	5	25468	5	2604
9539	4	25469	1	10011
9540	4	25473	1	4634
9541	5	25474	2	3871
9542	5	25475	7	7000
9543	5	25477	6	9942
9544	5	25478	4	9021
9545	4	25481	6	10006
9546	4	25482	5	9982
9547	5	25484	5	9587
9548	5	25487	3	5764
9549	4	25496	7	7143
9550	3	25499	7	1072
9551	1	25502	4	9992
9552	1	25504	6	5423
9553	4	25507	7	1055
9554	3	25509	4	9891
9555	5	25510	6	5475
9556	5	25510	4	5475
9557	5	25515	5	9996
9558	5	25516	5	9285
9559	4	25517	7	9964
9560	3	25522	4	6062
9561	4	25523	2	9967
9562	3	25525	5	3509
9563	5	25526	7	5635
9564	5	25527	4	3366
9565	4	25533	1	10002
9566	5	25534	6	10000
9567	4	25535	5	9948
9568	1	25537	6	9950
9569	5	25540	2	9957
9570	5	25545	7	5570
9571	4	25546	3	7476
9572	5	25547	7	2007
9573	5	25549	3	10101
9574	5	25555	1	10078
9575	4	25556	1	10050
9576	4	25558	5	7821
9577	2	25559	3	1638
9578	3	25561	5	10091
9579	5	25562	7	10081
9580	5	25565	7	7259
9581	5	25566	7	3449
9582	5	25567	3	10098
9583	3	25568	5	9076
9584	4	25571	7	3831
9585	5	25577	4	10027
9586	4	25578	1	9612
9587	5	25579	2	10056
9588	5	25580	6	10052
9589	4	25581	5	6885
9590	5	25582	2	6221
9591	3	25584	3	10029
9592	5	25590	6	591
9593	5	25593	4	10038
9594	5	25596	3	8355
9595	5	25600	2	10048
9596	5	25602	4	9039
9597	5	25614	4	2729
9598	5	25616	1	10073
9599	3	25620	2	1000
9600	5	25624	4	505
9601	4	25626	7	10051
9602	5	25629	5	379
9603	3	25631	3	6879
9604	4	25638	5	10069
9605	3	25639	2	8068
9606	5	25641	7	1960
9607	4	25644	5	2504
9608	3	25646	5	10025
9609	3	25655	5	7178
9610	1	25658	6	10031
9611	5	25661	2	10083
9612	3	25664	1	1742
9613	3	25666	6	10071
9614	5	25671	5	1243
9615	5	25673	1	6121
9616	3	25678	5	10103
9617	5	25679	3	4748
9618	5	25681	5	10060
9619	3	25683	7	10093
9620	5	25684	5	10090
9621	5	25685	2	6987
9622	5	25688	4	10095
9623	5	25689	2	10075
9624	5	25693	2	7261
9625	4	25695	5	10034
9626	3	25696	4	3491
9627	5	25698	6	6871
9628	5	25700	7	9587
9629	3	25702	1	10046
9630	5	25703	2	1720
9631	5	25704	4	10077
9632	4	25709	4	1795
9633	3	25711	5	10070
9634	2	25712	3	10099
9635	5	25713	7	6398
9636	5	25716	1	4028
9637	3	25726	5	10094
9638	5	25728	6	1445
9639	3	25730	5	9272
9640	4	25731	7	5812
9641	3	25734	5	5691
9642	5	25735	6	9733
9643	1	25738	6	10066
9644	4	25740	5	33
9645	4	25741	7	4321
9646	4	25744	4	10061
9647	5	25748	7	10092
9648	5	25755	3	10053
9649	5	25756	6	7297
9650	3	25757	1	626
9651	4	25758	6	10167
9652	5	25761	2	10179
9653	5	25766	1	10133
9654	5	25767	7	4595
9655	5	25771	2	10171
9656	3	25772	5	3831
9657	4	25776	3	1923
9658	4	25778	3	10147
9659	3	25779	2	4344
9660	5	25783	1	431
9661	5	25786	3	6881
9662	4	25787	1	2712
9663	3	25789	6	7061
9664	5	25790	1	2729
9665	3	25791	2	4519
9666	5	25795	6	4592
9667	4	25797	6	9358
9668	5	25799	5	8261
9669	4	25801	6	10135
9670	5	25805	6	10178
9671	4	25806	7	10148
9672	2	25809	1	2634
9673	1	25811	4	10159
9674	3	25812	3	10122
9675	4	25813	1	10142
9676	5	25814	2	5470
9677	5	25815	1	481
9678	3	25816	5	883
9679	2	25817	6	7806
9680	4	25826	7	10131
9681	5	25829	2	9894
9682	5	25829	4	9894
9683	4	25834	5	4336
9684	5	25836	3	1257
9685	5	25837	5	1522
9686	4	25840	7	10152
9687	4	25841	5	10126
9688	5	25842	6	5082
9689	3	25844	1	1076
9690	3	25846	3	4230
9691	3	25847	2	8666
9692	5	25849	2	10084
9693	5	25849	7	10084
9694	3	25850	7	10170
9695	3	25851	1	148
9696	5	25852	6	10114
9697	3	25853	4	6641
9698	3	25854	5	9825
9699	3	25854	1	9825
9700	4	25855	4	6200
9701	5	25856	2	10165
9702	4	25857	2	10134
9703	5	25860	6	9695
9704	4	25861	2	6732
9705	5	25862	1	1177
9706	5	25864	6	5468
9707	5	25865	6	7589
9708	5	25866	6	5865
9709	5	25866	1	5865
9710	5	25867	7	3800
9711	5	25868	4	8596
9712	4	25870	7	10111
9713	5	25875	3	2888
9714	5	25877	1	9106
9715	5	25879	2	10116
9716	5	25880	2	593
9717	5	25882	5	10140
9718	5	25888	4	3679
9719	5	25889	4	6962
9720	5	25894	7	1796
9721	2	25898	5	4459
9722	5	25898	1	4459
9723	5	25900	3	10160
9724	4	25901	6	414
9725	5	25903	4	5768
9726	5	25905	7	3480
9727	2	25909	6	4101
9728	5	25912	7	1834
9729	1	25913	6	3172
9730	4	25919	5	7690
9731	4	25920	6	10177
9732	4	25921	2	6556
9733	4	25922	6	10157
9734	5	25923	5	638
9735	4	25924	7	9265
9736	4	25926	1	6090
9737	5	25927	3	3078
9738	5	25930	7	7620
9739	5	25931	2	10117
9740	5	25934	1	10119
9741	4	25938	7	10137
9742	5	25939	5	1777
9743	1	25941	1	10139
9744	5	25945	1	3600
9745	5	25953	1	10132
9746	4	25955	5	10118
9747	5	25955	6	10118
9748	3	25961	5	10115
9749	5	25962	4	10150
9750	5	25965	2	10130
9751	4	25967	5	3321
9752	5	25969	3	32
9753	4	25977	7	10229
9754	3	25980	7	5884
9755	5	25982	4	8185
9756	5	25985	5	852
9757	5	25990	5	5460
9758	3	25995	6	9167
9759	5	25996	6	5961
9760	4	25997	7	6074
9761	5	25999	2	10210
9762	4	26000	3	6816
9763	5	26002	7	10280
9764	4	26004	1	7784
9765	3	26005	5	10242
9766	5	26008	7	5164
9767	5	26009	6	2055
9768	5	26014	4	456
9769	4	26018	2	9404
9770	4	26020	1	8311
9771	5	26022	7	10226
9772	5	26024	2	10169
9773	2	26026	6	10268
9774	5	26029	1	471
9775	5	26031	2	10272
9776	5	26032	2	10267
9777	5	26037	6	10197
9778	5	26038	3	10249
9779	4	26040	6	2332
9780	3	26041	2	187
9781	5	26045	4	1419
9782	4	26047	3	970
9783	5	26048	2	10257
9784	3	26049	7	1166
9785	4	26050	4	6347
9786	5	26051	2	3002
9787	5	26054	4	5793
9788	5	26058	3	9334
9789	1	26062	4	10244
9790	4	26064	5	10278
9791	4	26066	6	10266
9792	5	26066	3	10266
9793	5	26067	3	9043
9794	5	26073	2	10263
9795	5	26077	5	10264
9796	4	26080	5	10198
9797	5	26083	2	2540
9798	5	26086	6	10251
9799	5	26088	4	8327
9800	5	26092	2	10209
9801	4	26092	7	10209
9802	5	26095	1	10215
9803	5	26097	6	10261
9804	4	26100	2	10225
9805	5	26103	2	9989
9806	5	26104	5	10259
9807	5	26105	4	10233
9808	3	26107	3	10217
9809	5	26113	1	4912
9810	1	26116	3	3482
9811	3	26118	5	3901
9812	3	26119	5	8993
9813	5	26120	5	4967
9814	5	26120	6	4967
9815	1	26123	6	4374
9816	5	26128	7	5315
9817	3	26131	5	10271
9818	5	26132	7	3588
9819	5	26133	7	8270
9820	5	26135	5	8016
9821	3	26138	1	5933
9822	5	26139	2	2959
9823	5	26140	7	10247
9824	3	26143	1	1942
9825	4	26144	3	8237
9826	4	26147	7	10240
9827	5	26149	2	334
9828	5	26150	2	2089
9829	5	26152	2	2085
9830	5	26157	4	1795
9831	5	26160	5	5760
9832	3	26164	3	5972
9833	5	26165	3	8825
9834	5	26166	6	10232
9835	5	26168	3	10190
9836	4	26173	5	10349
9837	5	26175	7	10375
9838	5	26176	1	10324
9839	4	26180	1	10288
9840	2	26181	6	10327
9841	5	26183	4	8900
9842	2	26186	6	2697
9843	3	26191	5	5141
9844	4	26194	6	6609
9845	4	26198	5	10333
9846	5	26200	1	491
9847	5	26202	3	6874
9848	5	26205	6	6037
9849	4	26206	6	3598
9850	4	26209	1	9941
9851	5	26214	2	378
9852	5	26215	1	10282
9853	5	26217	7	10310
9854	5	26219	4	10301
9855	5	26219	7	10301
9856	5	26227	7	10348
9857	5	26229	6	8702
9858	3	26229	1	8702
9859	5	26230	7	10307
9860	4	26233	3	5992
9861	5	26235	2	236
9862	3	26242	3	7539
9863	5	26243	6	6439
9864	4	26244	7	10340
9865	3	26247	7	2276
9866	4	26249	2	2392
9867	5	26251	2	3174
9868	5	26253	7	851
9869	4	26254	5	10374
9870	5	26255	2	5427
9871	4	26260	6	10292
9872	5	26264	6	5929
9873	3	26266	2	2472
9874	5	26270	2	1387
9875	3	26271	5	10352
9876	5	26272	7	10336
9877	1	26276	1	123
9878	4	26277	5	3647
9879	5	26279	1	3399
9880	3	26281	2	7791
9881	4	26282	2	10322
9882	4	26290	5	10335
9883	5	26291	4	10317
9884	5	26292	1	2959
9885	3	26294	6	10240
9886	3	26296	2	10353
9887	5	26297	4	10286
9888	3	26302	3	7178
9889	5	26303	4	8505
9890	3	26305	4	10329
9891	4	26306	5	5462
9892	5	26307	1	10337
9893	4	26307	7	10337
9894	5	26309	1	5099
9895	5	26311	1	10283
9896	5	26312	5	3996
9897	3	26313	5	286
9898	5	26315	4	8526
9899	3	26320	7	7550
9900	5	26320	6	7550
9901	4	26321	4	39
9902	4	26322	3	8090
9903	5	26323	2	1394
9904	3	26324	1	7017
9905	4	26332	7	4374
9906	4	26334	6	10379
9907	3	26336	1	6675
9908	5	26341	2	6938
9909	4	26345	5	2806
9910	5	26346	6	10339
9911	5	26350	6	10297
9912	4	26354	1	10296
9913	4	26355	7	8010
9914	3	26356	5	2244
9915	5	26357	2	1907
9916	5	26359	3	4090
9917	3	26365	1	4125
9918	3	26366	4	10309
9919	3	26367	4	754
9920	3	26373	3	8622
9921	5	26374	6	10311
9922	5	26376	6	6894
9923	3	26376	7	6894
9924	5	26381	5	10368
9925	3	26382	5	3676
9926	4	26385	4	10334
9927	1	26386	6	10364
9928	3	26387	3	4836
9929	5	26388	6	10325
9930	3	26393	5	8239
9931	5	26395	4	10306
9932	4	26395	6	10306
9933	5	26397	3	10321
9934	5	26399	6	10308
9935	5	26400	1	2237
9936	4	26401	7	10363
9937	5	26402	1	10380
9938	3	26402	5	10380
9939	4	26404	2	229
9940	4	26406	1	10365
9941	3	26411	7	10341
9942	4	26417	5	4682
9943	5	26419	6	1021
9944	5	26420	3	612
9945	4	26423	7	5457
9946	3	26426	7	9405
9947	5	26428	3	2902
9948	4	26433	4	3268
9949	5	26434	4	9924
9950	5	26436	4	6331
9951	4	26437	7	8717
9952	4	26441	2	10274
9953	2	26442	2	10316
9954	3	26444	4	6728
9955	5	26446	1	8410
9956	5	26448	2	4592
9957	3	26451	7	2651
9958	1	26452	6	10354
9959	4	26453	5	6573
9960	4	26455	6	9979
9961	5	26460	6	1266
9962	4	26464	4	10299
9963	5	26466	5	4163
9964	4	26469	7	10291
9965	5	26473	1	10319
9966	4	26477	3	7215
9967	5	26479	2	880
9968	5	26480	6	8347
9969	5	26482	6	2878
9970	5	26483	6	7411
9971	5	26486	3	6647
9972	5	26487	3	2175
9973	5	26494	4	10271
9974	5	26499	7	7122
9975	5	26510	7	10409
9976	5	26512	6	1791
9977	5	26513	3	10417
9978	5	26514	3	10399
9979	5	26518	4	475
9980	5	26520	6	3411
9981	5	26528	7	4356
9982	4	26529	6	1781
9983	2	26530	6	6557
9984	4	26539	7	10450
9985	4	26542	4	2556
9986	3	26551	4	7048
9987	5	26555	3	2564
9988	5	26555	7	2564
9989	4	26556	7	10476
9990	3	26557	3	10435
9991	5	26560	5	10423
9992	5	26560	7	10423
9993	5	26561	4	1736
9994	5	26563	6	4486
9995	5	26571	7	10455
9996	5	26572	2	10454
9997	5	26573	6	10432
9998	3	26575	5	2631
9999	4	26583	1	6174
10000	5	26596	3	143
10001	3	26601	4	10475
10002	5	26602	3	10388
10003	5	26605	3	2519
10004	5	26608	5	10407
10005	5	26609	6	10419
10006	4	26612	5	2000
10007	5	26615	3	9355
10008	5	26616	2	10430
10009	5	26619	6	10397
10010	5	26620	1	10431
10011	5	26622	2	245
10012	5	26623	6	511
10013	4	26625	3	10469
10014	4	26629	7	7916
10015	4	26630	7	1676
10016	4	26636	5	10429
10017	4	26636	7	10429
10018	3	26638	5	226
10019	5	26640	3	4760
10020	5	26641	5	5485
10021	1	26644	7	10389
10022	5	26646	6	45
10023	5	26648	4	9996
10024	5	26651	1	8628
10025	3	26652	7	6509
10026	5	26656	2	7679
10027	3	26658	7	5430
10028	4	26659	7	710
10029	5	26660	6	10402
10030	5	26661	1	10468
10031	4	26663	1	4590
10032	5	26664	2	7248
10033	4	26665	7	7143
10034	5	26667	2	7865
10035	5	26668	5	7168
10036	2	26671	3	10354
10037	5	26672	5	7873
10038	5	26676	1	10471
10039	5	26676	4	10471
10040	5	26679	5	2416
10041	5	26681	6	6247
10042	4	26682	5	10426
10043	5	26687	5	10401
10044	2	26688	4	3628
10045	4	26690	5	9120
10046	5	26698	4	10472
10047	3	26699	2	4809
10048	5	26700	6	8273
10049	3	26701	5	10404
10050	5	26704	1	10433
10051	4	26706	1	10462
10052	5	26707	5	4324
10053	3	26713	5	10383
10054	4	26714	2	6101
10055	3	26716	1	10458
10056	4	26718	1	10473
10057	5	26723	6	10415
10058	5	26724	2	3692
10059	3	26725	3	8244
10060	4	26732	1	10463
10061	2	26736	6	10449
10062	5	26738	6	7164
10063	5	26741	6	10461
10064	5	26745	3	9574
10065	5	26746	2	10392
10066	4	26748	1	6865
10067	4	26749	7	7227
10068	5	26752	3	6151
10069	1	26756	4	10382
10070	5	26757	7	1055
10071	1	26762	6	10413
10072	5	26765	6	10421
10073	5	26767	5	10412
10074	5	26772	4	5935
10075	4	26776	2	1092
10076	3	26778	5	3796
10077	5	26780	1	5054
10078	4	26785	3	6987
10079	4	26786	6	8352
10080	5	26788	6	2531
10081	4	26792	2	2075
10082	5	26793	6	6108
10083	4	26795	7	10527
10084	5	26796	2	4139
10085	4	26798	5	10523
10086	4	26799	5	2897
10087	4	26800	7	1055
10088	3	26801	5	7050
10089	4	26802	1	8010
10090	4	26803	6	10536
10091	5	26804	7	10525
10092	5	26807	7	10495
10093	3	26808	5	3366
10094	4	26809	4	92
10095	5	26810	6	6429
10096	4	26811	5	4144
10097	5	26812	5	10323
10098	4	26818	4	701
10099	5	26819	4	3524
10100	5	26823	5	8057
10101	4	26824	4	10517
10102	5	26827	7	10486
10103	4	26837	1	10542
10104	5	26841	1	1166
10105	5	26843	6	721
10106	3	26846	5	4867
10107	5	26849	3	10490
10108	5	26850	4	138
10109	4	26850	5	138
10110	4	26851	5	10507
10111	3	26852	6	3565
10112	5	26855	6	1144
10113	5	26858	6	10479
10114	1	26859	6	9012
10115	4	26861	3	10502
10116	5	26870	3	6154
10117	5	26871	1	10488
10118	2	26872	6	5818
10119	5	26881	6	6297
10120	5	26886	5	6647
10121	5	26890	2	8410
10122	3	26892	2	1914
10123	5	26896	2	9836
10124	3	26897	6	9736
10125	3	26899	1	5846
10126	2	26901	2	10526
10127	3	26902	6	10492
10128	5	26903	4	5523
10129	5	26905	7	10103
10130	5	26909	2	3711
10131	5	26910	2	828
10132	5	26912	2	5380
10133	5	26913	2	10543
10134	4	26916	6	1087
10135	5	26918	6	10478
10136	3	26921	1	3000
10137	5	26923	3	7675
10138	5	26927	1	10529
10139	5	26931	1	2828
10140	5	26935	3	158
10141	4	26936	7	1188
10142	5	26940	2	10515
10143	5	26946	7	10518
10144	3	26949	5	10512
10145	5	26950	2	6032
10146	5	26951	1	10642
10147	5	26952	3	7526
10148	5	26956	3	10643
10149	5	26958	5	950
10150	1	26959	6	10194
10151	5	26961	1	4607
10152	4	26962	7	10597
10153	4	26964	7	10605
10154	5	26965	2	10609
10155	5	26975	4	3813
10156	5	26977	5	3546
10157	5	26979	6	8471
10158	3	26981	3	1069
10159	5	26982	1	7581
10160	5	26983	5	10586
10161	5	26984	1	1304
10162	3	26988	1	3684
10163	5	26988	7	3684
10164	5	26991	1	2613
10165	3	26995	1	493
10166	5	26997	7	10595
10167	4	26998	5	10571
10168	4	27000	1	10591
10169	5	27001	5	6362
10170	3	27003	1	330
10171	3	27008	4	10623
10172	5	27013	1	10203
10173	4	27014	4	10576
10174	1	27017	1	78
10175	5	27018	2	10632
10176	4	27027	5	1592
10177	5	27029	3	1922
10178	5	27030	7	9261
10179	5	27031	2	10566
10180	5	27032	2	7431
10181	5	27035	2	10564
10182	3	27039	5	10572
10183	4	27043	5	2107
10184	5	27044	7	10599
10185	3	27046	6	9011
10186	5	27051	2	7782
10187	3	27052	7	398
10188	5	27056	2	10635
10189	3	27059	2	3111
10190	5	27061	3	10581
10191	4	27065	4	10615
10192	5	27068	4	3570
10193	5	27071	4	10620
10194	5	27074	6	4390
10195	4	27077	2	2889
10196	5	27079	4	1645
10197	5	27083	3	2384
10198	5	27084	2	1442
10199	3	27086	7	4356
10200	5	27087	4	10626
10201	5	27087	5	10626
10202	5	27088	4	1297
10203	5	27088	5	1297
10204	4	27090	2	10613
10205	2	27099	3	9874
10206	4	27101	3	8177
10207	4	27103	7	10567
10208	5	27104	3	472
10209	1	27106	6	10627
10210	5	27108	6	7821
10211	5	27109	2	10602
10212	2	27112	2	2668
10213	5	27118	1	946
10214	5	27118	6	946
10215	5	27119	3	10007
10216	5	27122	4	8815
10217	4	27126	5	847
10218	5	27126	7	847
10219	4	27127	3	10639
10220	5	27128	5	8700
10221	3	27129	2	8546
10222	3	27135	7	10647
10223	3	27140	3	7530
10224	5	27145	1	10656
10225	3	27146	7	10653
10226	5	27147	1	10714
10227	5	27149	4	7508
10228	5	27149	6	7508
10229	4	27152	6	1529
10230	3	27160	7	10747
10231	3	27161	7	10673
10232	3	27163	7	9264
10233	5	27169	3	8110
10234	5	27171	4	2557
10235	5	27174	6	10730
10236	5	27177	2	1627
10237	3	27180	1	9071
10238	3	27181	7	10693
10239	5	27184	2	2944
10240	1	27185	7	2109
10241	3	27186	5	10723
10242	1	27186	6	10723
10243	1	27188	6	10722
10244	5	27190	5	10685
10245	4	27191	4	7987
10246	4	27194	6	2362
10247	5	27198	5	10686
10248	5	27198	2	10686
10249	5	27201	1	10140
10250	5	27205	7	7924
10251	4	27209	7	10208
10252	5	27211	4	2418
10253	4	27213	5	10678
10254	5	27214	7	10637
10255	4	27216	6	730
10256	4	27218	1	10712
10257	5	27219	4	2605
10258	5	27221	4	10704
10259	5	27227	1	10652
10260	5	27228	7	10667
10261	5	27230	6	10664
10262	5	27232	2	1252
10263	4	27234	7	8651
10264	5	27240	6	480
10265	5	27242	6	822
10266	5	27243	2	8240
10267	4	27247	7	10715
10268	5	27254	5	10671
10269	3	27262	2	5845
10270	5	27267	5	10695
10271	5	27274	3	5227
10272	4	27276	7	10742
10273	5	27278	6	9920
10274	5	27280	1	9193
10275	5	27280	3	9193
10276	5	27281	3	3976
10277	5	27282	4	1343
10278	3	27291	7	346
10279	3	27293	7	6058
10280	3	27304	5	5526
10281	4	27311	7	3404
10282	5	27312	2	10733
10283	5	27314	4	9902
10284	4	27317	2	2119
10285	5	27318	2	10681
10286	3	27320	7	5649
10287	5	27321	6	10660
10288	4	27323	2	10740
10289	5	27324	4	10666
10290	5	27325	6	8884
10291	3	27327	5	10662
10292	4	27329	5	10650
10293	5	27330	2	8666
10294	3	27333	1	10725
10295	5	27334	7	2107
10296	5	27338	2	3452
10297	4	27340	6	5099
10298	5	27342	4	9830
10299	5	27342	6	9830
10300	3	27348	5	10690
10301	5	27348	6	10690
10302	5	27349	7	6883
10303	5	27351	2	6496
10304	3	27359	7	10716
10305	5	27359	6	10716
10306	5	27362	7	10370
10307	5	27363	7	4411
10308	5	27364	2	10739
10309	3	27367	3	7247
10310	3	27369	7	7156
10311	4	27371	7	10750
10312	5	27383	6	5044
10313	3	27388	7	10815
10314	5	27390	7	10797
10315	5	27391	6	4782
10316	3	27392	3	4190
10317	5	27394	5	916
10318	5	27395	4	10767
10319	3	27396	7	10808
10320	4	27398	2	4828
10321	5	27400	3	9943
10322	4	27403	1	1848
10323	5	27404	7	10170
10324	5	27406	6	2520
10325	3	27413	7	5832
10326	5	27414	7	338
10327	5	27417	4	8054
10328	5	27419	6	10776
10329	5	27420	2	9348
10330	4	27421	6	77
10331	5	27422	1	10809
10332	4	27423	5	10823
10333	5	27431	3	10765
10334	3	27435	1	10813
10335	5	27436	2	5416
10336	5	27437	4	7123
10337	3	27438	2	2780
10338	5	27439	4	10802
10339	5	27441	3	2573
10340	4	27442	6	4074
10341	5	27443	3	10805
10342	5	27444	7	10794
10343	5	27448	4	1697
10344	5	27449	1	2523
10345	5	27451	7	10388
10346	5	27453	4	4172
10347	4	27454	3	8646
10348	5	27455	1	1069
10349	5	27459	7	2569
10350	3	27462	4	4794
10351	3	27464	1	10759
10352	4	27468	1	10818
10353	4	27469	2	10231
10354	3	27471	3	9075
10355	5	27473	2	6057
10356	5	27480	7	4453
10357	4	27483	7	10831
10358	5	27485	4	1855
10359	4	27486	6	1079
10360	3	27487	1	10806
10361	4	27489	7	10782
10362	3	27490	1	4088
10363	1	27492	6	3797
10364	5	27498	2	223
10365	5	27499	1	10829
10366	5	27500	7	10184
10367	5	27502	3	4818
10368	5	27504	7	10804
10369	3	27510	1	1661
10370	5	27517	3	5805
10371	5	27518	4	5691
10372	4	27519	1	10795
10373	5	27522	7	2743
10374	5	27523	6	1629
10375	5	27523	7	1629
10376	5	27528	3	1075
10377	3	27532	2	9039
10378	3	27535	7	10763
10379	1	27536	2	10816
10380	3	27546	6	8887
10381	3	27548	7	10811
10382	5	27550	1	10830
10383	3	27554	1	1958
10384	3	27560	3	910
10385	3	27561	5	10786
10386	4	27562	7	10821
10387	4	27569	7	5729
10388	4	27570	3	158
10389	3	27573	2	1460
10390	5	27574	2	10181
10391	4	27582	5	10509
10392	5	27588	2	6232
10393	4	27590	1	1531
10394	3	27591	5	10354
10395	4	27592	2	3112
10396	5	27593	6	3748
10397	3	27593	1	3748
10398	5	27597	7	285
10399	1	27600	4	8180
10400	5	27602	7	10901
10401	5	27603	2	883
10402	5	27606	7	10676
10403	3	27607	5	10888
10404	3	27607	3	10888
10405	3	27609	5	7047
10406	4	27610	7	6735
10407	5	27616	2	9082
10408	5	27625	5	10884
10409	5	27626	1	10860
10410	5	27629	7	10926
10411	5	27630	7	10851
10412	5	27634	2	10853
10413	5	27635	2	4008
10414	3	27637	7	5875
10415	4	27643	5	6147
10416	3	27646	3	8407
10417	4	27648	2	8866
10418	1	27652	6	10856
10419	5	27656	4	3827
10420	3	27662	1	1670
10421	5	27665	4	4737
10422	4	27667	2	3102
10423	5	27670	6	5186
10424	3	27670	4	5186
10425	4	27672	2	7341
10426	5	27673	5	10899
10427	3	27679	5	10864
10428	5	27681	6	10785
10429	5	27685	5	10425
10430	5	27687	6	10843
10431	5	27688	4	1481
10432	4	27693	6	10919
10433	5	27698	5	5963
10434	5	27701	4	2296
10435	4	27707	6	8298
10436	4	27710	5	6305
10437	5	27715	2	10924
10438	4	27717	4	10914
10439	5	27718	5	1780
10440	5	27732	3	10868
10441	4	27741	2	10880
10442	4	27743	4	10836
10443	4	27746	6	10894
10444	3	27751	7	5097
10445	5	27755	7	6373
10446	3	27758	3	10898
10447	4	27760	1	10867
10448	5	27766	3	10650
10449	4	27770	3	10150
10450	5	27771	6	6769
10451	4	27775	2	3527
10452	5	27776	4	4177
10453	5	27781	7	5966
10454	5	27783	2	10837
10455	4	27786	3	10844
10456	5	27788	1	10889
10457	3	27789	4	10911
10458	4	27790	4	10292
10459	5	27793	7	5649
10460	5	27795	6	4868
10461	5	27798	1	10964
10462	5	27805	2	10984
10463	4	27808	2	11012
10464	3	27809	3	10985
10465	3	27814	4	11001
10466	2	27815	6	5089
10467	5	27816	2	4562
10468	3	27818	3	2799
10469	5	27821	3	10993
10470	5	27823	1	11002
10471	5	27827	2	8963
10472	5	27828	2	3829
10473	5	27829	6	7527
10474	4	27830	5	7044
10475	4	27832	3	7171
10476	5	27839	4	10969
10477	3	27840	7	1806
10478	5	27841	4	7074
10479	4	27842	2	376
10480	3	27846	1	8410
10481	5	27849	3	1173
10482	5	27854	1	3404
10483	5	27859	1	2601
10484	5	27860	3	10024
10485	4	27862	3	10966
10486	5	27863	5	1355
10487	5	27866	5	8550
10488	5	27869	6	10979
10489	1	27870	6	10956
10490	5	27871	4	10384
10491	5	27872	2	5503
10492	3	27874	4	11011
10493	5	27881	3	5292
10494	5	27881	1	5292
10495	5	27882	4	10975
10496	5	27889	2	9563
10497	5	27891	5	10999
10498	5	27892	6	4120
10499	5	27894	7	158
10500	4	27895	7	7424
10501	5	27898	6	6628
10502	4	27899	1	10785
10503	5	27901	2	5215
10504	5	27906	3	10458
10505	5	27908	5	123
10506	5	27909	5	10480
10507	4	27910	5	10995
10508	4	27913	7	8584
10509	3	27922	1	2047
10510	4	27925	5	10961
10511	3	27926	4	8770
10512	5	27928	6	382
10513	5	27930	4	5050
10514	5	27932	6	3493
10515	2	27934	3	10962
10516	4	27936	7	543
10517	5	27940	3	10944
10518	5	27941	4	3651
10519	3	27946	5	7280
10520	4	27948	7	11007
10521	5	27949	6	11009
10522	5	27954	7	10929
10523	4	27955	2	664
10524	5	27957	4	3995
10525	5	27958	6	10936
10526	5	27959	1	1062
10527	1	27962	6	5970
10528	5	27963	2	4872
10529	5	27964	5	5400
10530	5	27967	5	11014
10531	5	27970	1	9489
10532	3	27974	5	7662
10533	5	27979	7	10947
10534	4	27982	4	9198
10535	5	27983	3	7206
10536	3	27987	4	207
10537	5	27994	2	3002
10538	4	27994	3	3002
10539	5	27996	5	4459
10540	5	27999	6	550
10541	5	28002	2	7953
10542	4	28006	1	9651
10543	5	28007	7	10939
10544	3	28008	1	5427
10545	5	28009	2	3654
10546	4	28015	4	10125
10547	4	28023	2	10981
10548	5	28024	6	9160
10549	3	28026	1	10941
10550	5	28029	1	10957
10551	3	28030	3	10960
10552	2	28036	6	10934
10553	4	28040	5	10992
10554	4	28041	5	9317
10555	4	28042	2	837
10556	5	28043	4	7963
10557	4	28048	7	34
10558	4	28050	6	6137
10559	5	28055	2	9330
10560	5	28056	1	7418
10561	5	28058	6	812
10562	3	28059	2	10982
10563	5	28060	1	808
10564	4	28061	5	10963
10565	5	28061	6	10963
10566	5	28063	1	10221
10567	5	28066	6	10954
10568	4	28070	7	10945
10569	5	28072	3	4059
10570	3	28074	3	11058
10571	5	28075	3	671
10572	5	28076	6	7081
10573	5	28077	6	5898
10574	5	28080	6	10440
10575	5	28081	4	10802
10576	5	28084	5	11020
10577	5	28085	3	8490
10578	4	28088	1	11091
10579	3	28091	3	6711
10580	5	28091	1	6711
10581	5	28092	4	1464
10582	5	28095	6	7237
10583	5	28097	3	2442
10584	4	28098	6	3566
10585	5	28099	5	7018
10586	5	28100	6	9642
10587	5	28102	6	6645
10588	5	28103	1	9320
10589	5	28104	4	3934
10590	4	28110	5	11069
10591	5	28112	1	3069
10592	4	28114	5	11021
10593	5	28115	5	9860
10594	5	28120	2	2935
10595	4	28121	2	11049
10596	5	28122	4	10895
10597	4	28123	1	3150
10598	4	28126	3	8587
10599	5	28127	4	8303
10600	5	28128	4	11038
10601	1	28129	6	9352
10602	5	28133	6	7552
10603	5	28134	1	1368
10604	5	28135	1	7924
10605	5	28137	6	11090
10606	5	28144	1	1092
10607	2	28147	6	11103
10608	4	28152	4	2933
10609	3	28154	1	10433
10610	5	28156	2	11093
10611	5	28156	7	11093
10612	3	28159	5	11068
10613	5	28160	6	9996
10614	3	28161	1	2474
10615	5	28163	6	11095
10616	5	28164	2	3106
10617	4	28164	7	3106
10618	5	28165	5	5784
10619	4	28166	1	11039
10620	5	28176	6	8142
10621	5	28179	1	2698
10622	1	28180	6	11096
10623	2	28182	3	8380
10624	5	28183	2	11083
10625	5	28185	1	5901
10626	5	28186	4	7603
10627	4	28189	7	11067
10628	4	28191	3	3869
10629	3	28192	7	11047
10630	4	28194	4	8809
10631	3	28196	1	11064
10632	5	28199	1	6255
10633	3	28200	5	11081
10634	5	28202	4	11107
10635	4	28203	3	11050
10636	5	28204	7	7896
10637	5	28207	3	11085
10638	3	28208	7	11052
10639	5	28215	1	11112
10640	3	28219	1	11036
10641	4	28223	7	9107
10642	5	28224	1	11098
10643	5	28226	2	2740
10644	5	28228	2	11066
10645	4	28230	3	2134
10646	4	28231	7	9296
10647	5	28232	6	1531
10648	5	28245	5	11092
10649	3	28247	6	7347
10650	3	28248	1	11042
10651	4	28250	3	11073
10652	4	28251	2	7502
10653	3	28254	4	697
10654	3	28255	7	3471
10655	1	28261	4	489
10656	5	28263	6	11031
10657	5	28264	6	4733
10658	4	28266	7	292
10659	5	28266	1	292
10660	5	28267	2	11100
10661	5	28272	7	300
10662	5	28274	6	6605
10663	4	28276	7	6951
10664	3	28281	5	3372
10665	3	28282	3	11109
10666	5	28288	2	11051
10667	5	28293	6	3540
10668	4	28294	7	11055
10669	5	28297	6	3314
10670	5	28299	2	2631
10671	4	28300	4	10151
10672	4	28301	3	4763
10673	5	28303	7	7870
10674	4	28303	6	7870
10675	3	28305	7	7684
10676	5	28306	2	2244
10677	4	28307	5	8448
10678	3	28313	5	1781
10679	5	28319	3	7046
10680	3	28320	5	9997
10681	5	28321	2	3887
10682	4	28325	7	5550
10683	5	28326	7	11077
10684	1	28327	6	10247
10685	5	28328	4	1427
10686	3	28330	2	10264
10687	5	28331	6	10330
10688	5	28332	5	11048
10689	4	28333	7	7318
10690	4	28334	2	11060
10691	5	28335	6	11015
10692	5	28337	7	10436
10693	5	28338	2	11037
10694	3	28339	4	856
10695	5	28341	6	10014
10696	3	28342	3	11030
10697	3	28346	3	5571
10698	5	28349	7	4983
10699	5	28350	2	11111
10700	3	28354	3	7187
10701	5	28355	1	11072
10702	5	28356	6	11075
10703	5	28362	3	1753
10704	5	28363	4	11044
10705	2	28364	3	5668
10706	5	28364	6	5668
10707	3	28366	7	11046
10708	5	28368	7	1729
10709	4	28371	7	11105
10710	4	28374	5	4314
10711	1	28377	6	11099
10712	5	28377	7	11099
10713	5	28380	1	4578
10714	5	28383	2	8651
10715	3	28384	4	4428
10716	5	28387	1	11025
10717	5	28389	1	9537
10718	4	28391	6	4343
10719	3	28392	7	9275
10720	3	28392	2	9275
10721	5	28395	3	11170
10722	5	28396	1	1313
10723	2	28399	6	1282
10724	5	28402	6	4695
10725	5	28408	6	880
10726	3	28411	5	128
10727	3	28415	7	11144
10728	5	28416	4	4947
10729	4	28418	5	11129
10730	5	28421	6	518
10731	5	28428	4	5396
10732	5	28429	4	4190
10733	5	28430	1	5174
10734	5	28433	7	6842
10735	2	28435	1	11157
10736	3	28436	4	11179
10737	5	28437	4	6212
10738	5	28440	3	310
10739	5	28444	4	3615
10740	1	28449	6	11215
10741	5	28450	6	9228
10742	2	28453	7	11186
10743	5	28453	6	11186
10744	5	28456	2	11220
10745	5	28459	2	541
10746	5	28464	5	11175
10747	5	28468	3	11222
10748	5	28475	2	11139
10749	4	28476	6	10629
10750	3	28478	1	11141
10751	3	28480	7	11150
10752	5	28482	3	7493
10753	3	28484	5	11160
10754	5	28487	7	359
10755	4	28487	3	359
10756	5	28489	4	2085
10757	4	28494	2	780
10758	5	28494	4	780
10759	2	28495	3	2422
10760	4	28506	2	1666
10761	3	28509	7	1223
10762	5	28513	6	1326
10763	5	28518	3	9364
10764	4	28519	7	9705
10765	5	28519	5	9705
10766	5	28523	3	11178
10767	5	28523	6	11178
10768	5	28526	4	4877
10769	4	28527	5	8884
10770	4	28528	1	11128
10771	2	28532	3	11130
10772	4	28532	1	11130
10773	3	28534	6	7910
10774	5	28534	1	7910
10775	5	28537	2	2798
10776	2	28538	7	11151
10777	5	28542	2	11159
10778	1	28543	2	11214
10779	5	28547	6	9769
10780	5	28547	2	9769
10781	3	28554	5	11270
10782	5	28557	7	3173
10783	4	28557	5	3173
10784	5	28558	2	11273
10785	5	28560	6	10879
10786	3	28562	1	7677
10787	5	28565	3	6277
10788	5	28568	3	3007
10789	5	28569	2	5183
10790	5	28573	7	11264
10791	5	28575	5	11227
10792	4	28588	3	11251
10793	5	28590	6	7293
10794	5	28592	6	4561
10795	4	28595	6	9192
10796	5	28597	6	11284
10797	5	28599	6	7053
10798	5	28601	5	10197
10799	5	28602	5	2366
10800	5	28609	5	11233
10801	4	28609	7	11233
10802	3	28610	4	3361
10803	4	28613	5	11299
10804	5	28615	6	11226
10805	5	28616	6	11246
10806	1	28618	6	11313
10807	1	28625	4	11230
10808	5	28626	6	7928
10809	4	28629	2	10130
10810	4	28632	6	3666
10811	5	28632	7	3666
10812	5	28636	4	11254
10813	5	28641	6	11231
10814	4	28647	3	8461
10815	5	28649	7	11265
10816	3	28651	7	8994
10817	5	28653	1	4867
10818	5	28662	5	11234
10819	3	28664	1	11240
10820	3	28669	2	1233
10821	2	28670	3	8223
10822	5	28674	6	11267
10823	4	28681	5	5875
10824	5	28681	6	5875
10825	3	28683	5	11303
10826	3	28689	3	9576
10827	5	28690	2	9798
10828	5	28692	2	11309
10829	5	28697	6	8189
10830	3	28698	3	6511
10831	3	28701	7	10406
10832	5	28704	5	4139
10833	3	28706	3	3149
10834	5	28708	6	2725
10835	5	28710	6	11293
10836	5	28711	6	1322
10837	5	28712	7	3048
10838	3	28714	3	684
10839	5	28714	2	684
10840	4	28719	4	11256
10841	3	28721	2	2767
10842	5	28722	2	2731
10843	5	28726	5	11294
10844	5	28727	4	11260
10845	3	28732	7	4869
10846	5	28737	2	1563
10847	2	28740	1	11378
10848	3	28749	2	3194
10849	4	28750	7	8558
10850	5	28752	4	10598
10851	4	28754	7	7516
10852	5	28758	7	11355
10853	4	28759	7	11285
10854	2	28762	6	11348
10855	5	28763	4	5729
10856	4	28766	1	541
10857	5	28771	6	1233
10858	5	28774	5	11331
10859	5	28779	2	10662
10860	5	28780	2	11389
10861	4	28780	5	11389
10862	5	28783	7	7533
10863	5	28784	5	4862
10864	5	28786	2	11375
10865	5	28786	3	11375
10866	4	28790	5	2706
10867	5	28791	3	9296
10868	5	28794	3	11347
10869	5	28795	4	11328
10870	5	28796	6	11349
10871	5	28797	5	5096
10872	3	28798	1	48
10873	5	28801	6	7205
10874	5	28804	6	1293
10875	5	28805	4	7670
10876	5	28806	2	11390
10877	5	28807	6	11379
10878	5	28810	1	11341
10879	1	28818	2	4284
10880	5	28818	6	4284
10881	2	28820	6	1370
10882	5	28823	4	11358
10883	4	28824	4	145
10884	4	28827	5	385
10885	5	28829	2	11320
10886	5	28830	4	477
10887	5	28832	4	5303
10888	5	28835	7	3393
10889	4	28836	6	1585
10890	4	28837	2	1923
10891	4	28839	5	6762
10892	5	28841	4	9647
10893	4	28842	6	4639
10894	4	28846	6	32
10895	5	28849	5	5078
10896	4	28850	3	11344
10897	4	28856	4	11172
10898	5	28857	1	11342
10899	3	28859	5	11332
10900	5	28860	4	292
10901	3	28861	5	6885
10902	5	28862	6	11356
10903	5	28863	3	10987
10904	4	28864	7	11318
10905	3	28865	4	11373
10906	4	28867	1	7220
10907	5	28868	2	1194
10908	3	28869	1	878
10909	3	28873	7	3378
10910	5	28875	4	11384
10911	2	28882	6	1541
10912	4	28884	7	5926
10913	5	28886	2	10159
10914	4	28893	3	7560
10915	5	28895	4	4982
10916	5	28896	6	2287
10917	1	28899	6	5183
10918	3	28903	2	5144
10919	3	28903	3	5144
10920	4	28907	1	9592
10921	5	28909	4	8631
10922	5	28910	6	5478
10923	5	28911	4	5453
10924	4	28914	7	11319
10925	5	28917	6	11337
10926	5	28919	6	11382
10927	3	28921	2	6568
10928	5	28924	6	7688
10929	5	28935	5	11376
10930	5	28939	5	8963
10931	4	28942	7	8380
10932	2	28943	4	11314
10933	4	28947	5	3940
10934	3	28950	7	7130
10935	5	28954	6	11381
10936	5	28956	2	11334
10937	4	28957	7	11372
10938	5	28959	6	11429
10939	5	28960	6	938
10940	5	28962	2	11427
10941	5	28963	5	11400
10942	5	28971	4	3241
10943	5	28972	7	1896
10944	5	28973	6	11466
10945	5	28978	6	1747
10946	5	28979	6	11437
10947	5	28983	4	11414
10948	5	28989	7	11394
10949	4	28991	5	5250
10950	5	28992	5	8998
10951	5	28998	7	10848
10952	4	29000	5	11415
10953	5	29001	4	9446
10954	5	29002	7	11468
10955	3	29005	6	2320
10956	5	29006	1	3886
10957	5	29014	3	9554
10958	5	29015	2	9533
10959	5	29016	4	9052
10960	4	29017	1	6946
10961	5	29019	3	3158
10962	5	29020	3	11343
10963	5	29021	2	9079
10964	4	29030	2	1061
10965	5	29032	3	11426
10966	3	29032	7	11426
10967	4	29035	4	9394
10968	5	29041	6	11441
10969	5	29042	7	7690
10970	5	29043	5	3396
10971	5	29045	5	8962
10972	4	29047	6	7541
10973	5	29050	7	7790
10974	5	29051	2	8947
10975	5	29055	2	11410
10976	4	29055	7	11410
10977	5	29056	5	4215
10978	3	29057	4	4309
10979	5	29066	2	69
10980	3	29068	7	11393
10981	5	29069	4	734
10982	5	29071	7	11409
10983	3	29075	5	10532
10984	5	29076	4	11419
10985	5	29078	4	4678
10986	3	29080	6	11471
10987	5	29081	5	3883
10988	5	29085	6	5354
10989	4	29087	7	11461
10990	3	29088	4	8173
10991	5	29089	2	4929
10992	5	29090	4	11398
10993	3	29092	5	8085
10994	4	29097	7	10033
10995	5	29100	2	11428
10996	5	29101	2	8640
10997	5	29101	7	8640
10998	5	29105	3	2761
10999	3	29106	6	11406
11000	5	29108	1	308
11001	5	29110	1	3768
11002	3	29111	7	7154
11003	4	29112	3	11435
11004	4	29114	7	1670
11005	5	29120	1	11432
11006	4	29121	7	6182
11007	3	29122	7	3140
11008	3	29123	7	337
11009	5	29124	2	11450
11010	1	29126	6	11418
11011	4	29127	5	7819
11012	5	29129	2	1366
11013	5	29132	4	11444
11014	5	29144	5	11399
11015	5	29145	1	10480
11016	4	29148	7	11412
11017	5	29152	6	880
11018	3	29153	7	11481
11019	5	29159	2	11479
11020	5	29162	4	11397
11021	5	29163	2	11447
11022	3	29164	3	10128
11023	5	29179	1	8298
11024	5	29180	7	11473
11025	4	29185	1	11462
11026	5	29189	4	2321
11027	3	29191	3	11253
11028	5	29193	6	3140
11029	3	29194	2	11555
11030	5	29196	2	11537
11031	5	29203	6	11486
11032	4	29211	5	11513
11033	4	29212	7	11483
11034	5	29213	5	11489
11035	5	29216	4	3654
11036	5	29218	3	7789
11037	5	29219	4	11512
11038	5	29225	2	5317
11039	3	29226	5	11563
11040	5	29226	3	11563
11041	2	29227	4	11505
11042	4	29230	5	4905
11043	4	29231	1	1820
11044	5	29233	2	9994
11045	5	29234	7	10122
11046	5	29235	3	7435
11047	3	29236	1	11542
11048	5	29242	1	6052
11049	5	29244	6	11572
11050	5	29245	2	11552
11051	4	29247	3	6831
11052	3	29248	1	377
11053	5	29253	2	11502
11054	5	29254	3	5926
11055	3	29254	6	5926
11056	5	29257	1	10388
11057	4	29258	7	11557
11058	4	29259	3	11239
11059	5	29261	6	138
11060	5	29263	6	9656
11061	4	29268	7	2081
11062	4	29270	2	4695
11063	5	29272	4	11524
11064	3	29277	4	8350
11065	4	29278	4	11496
11066	3	29279	3	628
11067	3	29285	1	1484
11068	4	29286	2	11560
11069	3	29287	1	3467
11070	4	29288	4	11503
11071	5	29291	6	6341
11072	5	29292	5	11556
11073	5	29296	4	11499
11074	2	29299	7	543
11075	4	29300	4	10715
11076	5	29302	2	11193
11077	4	29306	2	5303
11078	3	29306	5	5303
11079	5	29309	3	1965
11080	3	29312	7	9791
11081	5	29314	1	1659
11082	4	29316	1	424
11083	5	29320	7	11543
11084	5	29322	4	7361
11085	5	29325	2	11534
11086	3	29329	7	6882
11087	4	29331	4	10670
11088	5	29331	3	10670
11089	5	29332	5	11527
11090	5	29333	3	11579
11091	4	29338	6	7373
11092	4	29339	5	1280
11093	4	29341	6	1251
11094	5	29347	4	11493
11095	4	29350	7	11518
11096	5	29350	6	11518
11097	4	29351	1	3128
11098	3	29352	3	1941
11099	5	29356	1	4686
11100	5	29357	4	1128
11101	5	29358	2	7879
11102	5	29360	6	11564
11103	5	29362	1	11533
11104	5	29364	6	5780
11105	2	29365	4	4398
11106	5	29366	2	11565
11107	3	29371	1	8730
11108	5	29375	4	11504
11109	5	29380	2	2271
11110	4	29381	5	1889
11111	2	29384	4	10582
11112	5	29394	4	11539
11113	5	29396	3	6772
11114	4	29401	2	6364
11115	5	29404	6	11550
11116	4	29407	2	11575
11117	5	29412	6	11535
11118	4	29419	5	8256
11119	3	29421	1	2838
11120	5	29430	1	5790
11121	5	29431	6	10402
11122	5	29432	6	11621
11123	5	29433	5	6644
11124	5	29436	7	8140
11125	3	29437	1	11647
11126	5	29438	2	7676
11127	4	29445	5	343
11128	5	29446	1	720
11129	5	29448	6	4060
11130	5	29449	4	11610
11131	5	29454	7	9259
11132	4	29456	6	10954
11133	3	29458	6	7306
11134	5	29459	2	11597
11135	5	29460	2	1693
11136	5	29463	1	6116
11137	3	29467	7	11658
11138	5	29472	2	11627
11139	5	29473	5	11602
11140	5	29474	4	4762
11141	5	29477	6	4622
11142	2	29481	6	6398
11143	5	29482	6	9798
11144	5	29484	6	4929
11145	5	29489	1	3507
11146	5	29490	2	11608
11147	5	29491	2	4411
11148	2	29492	6	4184
11149	5	29498	1	1681
11150	5	29508	2	4433
11151	4	29509	7	8305
11152	4	29510	2	11671
11153	5	29513	6	11585
11154	2	29514	6	11591
11155	5	29514	2	11591
11156	5	29515	6	7300
11157	4	29516	7	2542
11158	3	29517	4	11667
11159	4	29520	6	996
11160	4	29522	3	3684
11161	2	29524	1	11681
11162	5	29525	4	2623
11163	2	29529	3	3389
11164	5	29530	6	6800
11165	4	29531	7	429
11166	3	29532	5	2867
11167	3	29534	4	11596
11168	5	29539	3	11686
11169	5	29540	4	5430
11170	5	29541	1	11133
11171	4	29543	4	11607
11172	5	29546	4	10952
11173	5	29552	4	11653
11174	5	29553	5	11599
11175	5	29554	7	11656
11176	4	29559	3	11679
11177	3	29560	5	10141
11178	3	29562	2	11604
11179	4	29562	3	11604
11180	4	29563	7	5483
11181	5	29564	1	11601
11182	4	29573	4	9610
11183	5	29575	1	11675
11184	4	29576	7	11630
11185	5	29579	1	11632
11186	5	29581	6	2888
11187	5	29582	7	11665
11188	4	29583	2	533
11189	5	29583	6	533
11190	5	29586	1	11605
11191	5	29588	4	2575
11192	5	29589	1	8149
11193	3	29593	3	11682
11194	3	29598	6	3715
11195	3	29600	6	11623
11196	5	29601	1	3519
11197	4	29602	7	11588
11198	4	29603	5	11624
11199	5	29605	1	315
11200	5	29613	6	7828
11201	5	29614	4	7613
11202	5	29616	2	2019
11203	5	29620	2	11104
11204	4	29625	3	10100
11205	5	29628	5	11649
11206	2	29629	2	11594
11207	5	29630	7	11584
11208	5	29631	4	5875
11209	5	29632	2	2092
11210	3	29633	4	3506
11211	5	29634	6	11612
11212	4	29637	1	11614
11213	5	29637	2	11614
11214	5	29641	6	966
11215	3	29642	2	424
11216	5	29643	1	11645
11217	3	29651	6	11609
11218	5	29658	4	5310
11219	5	29659	1	1101
11220	5	29661	5	11663
11221	5	29664	2	11631
11222	5	29666	4	7706
11223	4	29670	5	8919
11224	3	29671	5	11666
11225	5	29674	3	8423
11226	4	29674	4	8423
11227	4	29675	7	11654
11228	5	29685	7	1944
11229	5	29688	1	11617
11230	5	29690	4	11635
11231	3	29690	2	11635
11232	5	29694	4	4045
11233	5	29696	1	7668
11234	5	29700	6	11473
11235	5	29701	6	11685
11236	5	29704	5	578
11237	5	29706	5	7013
11238	4	29709	5	11672
11239	5	29710	2	11603
11240	4	29712	5	1767
11241	5	29715	6	11586
11242	5	29719	6	11733
11243	4	29720	4	11782
11244	5	29721	3	11756
11245	5	29727	1	11706
11246	3	29729	1	11732
11247	5	29736	2	11107
11248	5	29738	2	11699
11249	5	29740	6	5215
11250	3	29741	1	11759
11251	5	29742	2	10963
11252	5	29743	1	106
11253	4	29744	6	10452
11254	4	29745	5	11708
11255	5	29747	7	11720
11256	3	29752	5	11616
11257	4	29760	2	11793
11258	4	29766	7	655
11259	2	29767	6	5906
11260	5	29769	5	3110
11261	5	29771	1	11791
11262	5	29773	6	592
11263	4	29776	4	2550
11264	3	29777	5	11757
11265	5	29779	5	10373
11266	5	29780	1	11764
11267	4	29782	6	8483
11268	5	29785	6	8555
11269	5	29787	5	9775
11270	5	29788	4	11761
11271	5	29789	1	227
11272	4	29790	3	11778
11273	4	29791	7	11736
11274	3	29794	5	10930
11275	4	29797	7	11739
11276	4	29801	5	2115
11277	5	29803	3	1731
11278	4	29804	6	8470
11279	4	29807	2	11752
11280	1	29808	6	10200
11281	5	29809	4	1465
11282	3	29813	4	2085
11283	5	29814	5	2712
11284	3	29815	7	7796
11285	5	29820	2	3036
11286	5	29820	7	3036
11287	3	29822	3	11758
11288	3	29823	2	640
11289	3	29826	2	11776
11290	5	29827	7	6924
11291	4	29829	5	4562
11292	4	29830	5	11780
11293	3	29831	1	11722
11294	5	29832	7	5401
11295	3	29833	6	5924
11296	4	29835	1	5481
11297	5	29838	2	5318
11298	4	29839	2	11745
11299	4	29842	3	11730
11300	4	29846	1	8705
11301	5	29849	2	1996
11302	5	29851	6	11509
11303	4	29855	7	8574
11304	4	29858	4	11719
11305	4	29859	6	8265
11306	5	29860	2	11715
11307	3	29861	1	9009
11308	4	29865	2	8038
11309	5	29867	7	9270
11310	5	29870	5	11779
11311	5	29871	5	11790
11312	4	29872	6	4461
11313	5	29873	7	7050
11314	4	29874	5	5004
11315	5	29875	6	3235
11316	5	29880	6	11728
11317	4	29882	7	7338
11318	5	29886	2	10544
11319	1	29892	6	10715
11320	4	29895	1	2282
11321	5	29897	5	11774
11322	5	29899	4	11690
11323	4	29900	7	7388
11324	5	29901	6	11727
11325	4	29903	1	5558
11326	4	29905	4	11743
11327	3	29906	1	304
11328	4	29908	6	5979
11329	3	29908	5	5979
11330	4	29909	4	11704
11331	5	29911	4	4981
11332	5	29913	6	11276
11333	4	29915	7	11771
11334	5	29925	6	10287
11335	5	29937	3	8240
11336	5	29938	6	11713
11337	4	29939	5	9926
11338	5	29940	3	371
11339	4	29945	7	11735
11340	5	29946	6	11737
11341	5	29947	4	5354
11342	5	29948	2	136
11343	3	29954	5	11794
11344	3	29955	2	11765
11345	5	29957	4	4075
11346	3	29959	4	3361
11347	3	29961	7	5818
11348	1	29963	6	7274
11349	5	29965	4	9082
11350	5	29971	7	2332
11351	4	29975	1	6255
11352	4	29976	7	5078
11353	5	29976	6	5078
11354	5	29977	4	5082
11355	5	29978	1	6366
11356	5	29980	7	456
11357	5	29982	6	11687
11358	5	29983	5	11694
11359	5	29986	6	4714
11360	5	29988	2	10288
11361	3	29988	4	10288
11362	1	29992	6	7582
11363	5	29993	4	11729
11364	5	29997	3	609
11365	5	29997	6	609
11366	4	30001	7	11769
11367	5	30002	3	35
11368	4	30010	4	2391
11369	5	30015	2	11747
11370	4	30015	5	11747
11371	5	30016	3	10469
11372	1	30019	1	9296
11373	5	30024	2	6914
11374	4	30025	2	4612
11375	1	30028	2	2187
11376	4	30029	3	1850
11377	3	30036	7	11760
11378	5	30039	7	10157
11379	4	30041	1	8933
11380	5	30043	5	11712
11381	3	30045	5	11742
11382	4	30047	5	8206
11383	5	30048	4	176
11384	4	30050	7	11695
11385	3	30052	3	11698
11386	5	30052	6	11698
11387	5	30054	4	6088
11388	3	30056	7	788
11389	5	30062	7	316
11390	5	30063	6	10366
11391	4	30064	3	6848
11392	5	30066	7	8640
11393	5	30068	4	10421
11394	5	30069	3	11828
11395	5	30073	6	11858
11396	2	30074	6	8093
11397	4	30075	5	766
11398	5	30076	6	502
11399	4	30078	1	11802
11400	4	30079	2	11841
11401	5	30079	5	11841
11402	3	30082	5	5461
11403	5	30086	2	9034
11404	4	30087	5	11877
11405	4	30090	2	11882
11406	4	30091	4	8634
11407	4	30092	5	11830
11408	5	30095	6	11805
11409	5	30097	1	11876
11410	4	30097	7	11876
11411	5	30098	1	11836
11412	5	30100	3	11853
11413	5	30106	4	2814
11414	2	30107	6	11817
11415	1	30110	4	964
11416	5	30116	6	1680
11417	5	30120	6	8994
11418	4	30121	6	2605
11419	4	30128	7	11861
11420	5	30128	6	11861
11421	3	30132	1	2280
11422	3	30134	6	4094
11423	5	30141	4	11867
11424	5	30141	3	11867
11425	4	30142	4	4881
11426	5	30143	4	3434
11427	4	30149	1	7726
11428	4	30150	7	10269
11429	4	30153	3	1387
11430	5	30155	6	11849
11431	3	30157	1	8598
11432	4	30158	3	4770
11433	4	30160	7	5173
11434	5	30162	3	919
11435	3	30164	4	11804
11436	3	30167	3	946
11437	4	30169	7	371
11438	1	30174	1	5134
11439	4	30177	6	11686
11440	5	30178	5	11869
11441	5	30179	4	11870
11442	4	30180	7	7544
11443	1	30181	5	3660
11444	3	30182	1	4287
11445	3	30184	4	9609
11446	5	30186	4	11879
11447	5	30188	1	9021
11448	5	30200	1	4411
11449	5	30202	6	1110
11450	5	30205	7	9380
11451	5	30206	5	11816
11452	3	30208	2	3403
11453	3	30209	4	6424
11454	4	30213	7	2519
11455	2	30214	3	11886
11456	4	30217	5	4800
11457	4	30220	5	11823
11458	5	30222	5	9398
11459	5	30224	5	8865
11460	5	30224	2	8865
11461	5	30229	3	7706
11462	5	30233	3	11989
11463	4	30235	6	4546
11464	2	30246	4	5242
11465	5	30247	1	7710
11466	5	30250	2	11937
11467	4	30253	7	10792
11468	5	30254	6	11947
11469	5	30257	4	3534
11470	4	30260	7	4637
11471	3	30266	4	4590
11472	5	30267	4	11914
11473	3	30269	7	479
11474	4	30270	3	11958
11475	2	30271	1	8052
11476	3	30272	5	399
11477	5	30274	4	3481
11478	3	30277	5	7261
11479	5	30284	1	2024
11480	5	30286	1	4599
11481	5	30289	7	2894
11482	4	30290	5	11929
11483	4	30291	2	7903
11484	5	30291	4	7903
11485	5	30292	6	917
11486	5	30293	2	11971
11487	5	30294	3	5082
11488	5	30297	1	11997
11489	5	30298	6	5767
11490	4	30300	1	4389
11491	4	30302	4	7513
11492	5	30305	6	3761
11493	4	30306	2	7795
11494	4	30309	1	5642
11495	5	30311	6	10151
11496	3	30312	5	7834
11497	4	30317	4	2561
11498	5	30321	7	1176
11499	4	30324	1	4838
11500	5	30326	4	6355
11501	5	30328	1	6787
11502	5	30330	5	12000
11503	1	30334	6	7691
11504	3	30335	2	11920
11505	4	30342	1	52
11506	3	30343	6	5097
11507	4	30346	2	3067
11508	5	30346	1	3067
11509	5	30349	5	2928
11510	5	30350	7	7153
11511	5	30351	4	8146
11512	5	30352	4	7227
11513	3	30354	3	8435
11514	4	30358	6	3768
11515	5	30366	6	3367
11516	5	30368	3	11928
11517	4	30370	7	11905
11518	5	30373	2	8877
11519	5	30375	3	7277
11520	5	30378	6	9011
11521	5	30379	1	6448
11522	4	30379	5	6448
11523	4	30381	1	11898
11524	5	30382	4	11941
11525	3	30382	7	11941
11526	4	30383	7	9701
11527	5	30384	6	10267
11528	5	30386	6	11985
11529	5	30387	6	11968
11530	5	30390	1	2594
11531	5	30390	7	2594
11532	5	30391	3	11407
11533	5	30393	2	11735
11534	4	30394	2	1005
11535	5	30395	6	1457
11536	4	30396	7	8341
11537	4	30397	6	11977
11538	5	30398	4	11972
11539	5	30399	2	11964
11540	5	30402	2	29
11541	3	30405	5	4358
11542	5	30409	6	11979
11543	5	30409	2	11979
11544	5	30410	2	11913
11545	5	30414	5	8727
11546	3	30414	1	8727
11547	3	30415	7	9954
11548	3	30416	7	11960
11549	5	30418	6	11897
11550	4	30422	4	11930
11551	5	30423	6	11921
11552	4	30425	5	11973
11553	1	30427	7	11946
11554	3	30429	1	6998
11555	4	30430	5	11912
11556	5	30435	3	1597
11557	4	30436	5	11899
11558	2	30437	7	6202
11559	5	30438	2	11963
11560	3	30441	2	12078
11561	4	30442	3	44
11562	1	30447	4	12044
11563	5	30448	5	9271
11564	5	30450	2	4042
11565	5	30451	5	12033
11566	5	30452	5	12039
11567	5	30453	4	12084
11568	2	30454	3	4309
11569	5	30459	2	12057
11570	3	30464	5	1369
11571	4	30466	5	1860
11572	3	30467	7	10820
11573	5	30469	4	11342
11574	5	30471	3	12056
11575	5	30475	6	2100
11576	4	30483	3	3
11577	5	30484	3	8781
11578	3	30487	5	12087
11579	3	30489	2	10926
11580	5	30491	5	12005
11581	3	30493	1	7767
11582	5	30498	4	6359
11583	3	30499	2	10968
11584	5	30500	2	12030
11585	5	30501	7	12061
11586	3	30502	4	232
11587	5	30504	4	12089
11588	2	30506	6	8638
11589	2	30507	2	12013
11590	4	30514	1	12073
11591	4	30514	4	12073
11592	1	30515	4	4121
11593	5	30515	7	4121
11594	5	30516	6	7132
11595	5	30518	2	7094
11596	3	30519	5	9097
11597	5	30520	6	1670
11598	5	30523	6	12071
11599	5	30526	2	2965
11600	4	30527	7	9447
11601	5	30535	1	12062
11602	3	30540	6	12032
11603	5	30542	4	12053
11604	5	30544	5	4080
11605	3	30548	7	11720
11606	5	30552	2	12074
11607	4	30553	3	12051
11608	5	30556	5	12069
11609	5	30558	2	8770
11610	3	30559	2	12048
11611	5	30561	2	1639
11612	5	30563	6	9833
11613	5	30564	6	8543
11614	3	30565	7	3949
11615	4	30567	4	9905
11616	5	30568	2	12015
11617	4	30571	6	3168
11618	3	30576	7	184
11619	3	30579	5	704
11620	5	30584	7	12068
11621	3	30584	3	12068
11622	4	30585	7	6429
11623	5	30586	4	925
11624	4	30587	5	11151
11625	4	30588	1	12009
11626	4	30589	6	9175
11627	4	30593	3	12092
11628	5	30596	6	12034
11629	5	30597	6	9743
11630	5	30601	5	6444
11631	5	30603	6	3030
11632	5	30604	4	1963
11633	5	30605	7	12036
11634	5	30610	7	4898
11635	5	30612	7	12086
11636	5	30616	3	2009
11637	5	30618	4	3007
11638	5	30621	4	12004
11639	3	30622	1	7371
11640	3	30629	7	1531
11641	5	30632	7	8229
11642	5	30637	2	5047
11643	4	30639	6	11185
11644	1	30640	2	6032
11645	5	30644	6	12022
11646	5	30645	1	1170
11647	5	30647	7	11152
11648	4	30649	3	1762
11649	5	30649	2	1762
11650	4	30650	5	6326
11651	5	30652	5	11607
11652	4	30657	7	12038
11653	5	30660	1	8347
11654	5	30662	7	2417
11655	4	30663	1	4393
11656	3	30664	5	12065
11657	5	30666	5	6513
11658	5	30672	5	10219
11659	5	30674	5	12082
11660	5	30677	5	11941
11661	5	30680	6	11005
11662	3	30682	1	8877
11663	5	30684	7	7064
11664	4	30686	4	11810
11665	5	30687	6	6807
11666	5	30688	6	11317
11667	5	30692	6	7888
11668	5	30698	7	12201
11669	3	30699	3	7158
11670	5	30700	2	12107
11671	5	30707	4	11095
11672	3	30709	5	3106
11673	5	30710	6	12114
11674	5	30715	5	12143
11675	5	30717	2	12204
11676	4	30718	2	12192
11677	3	30720	1	7951
11678	5	30720	2	7951
11679	5	30721	4	12156
11680	4	30722	3	11431
11681	4	30723	5	12149
11682	5	30724	6	12136
11683	5	30727	5	12101
11684	4	30729	1	12103
11685	5	30733	7	5310
11686	3	30738	7	6429
11687	5	30738	6	6429
11688	5	30739	2	12203
11689	5	30747	7	12173
11690	4	30756	5	5518
11691	4	30760	5	12209
11692	3	30763	5	12174
11693	5	30764	5	3202
11694	3	30772	7	12164
11695	5	30773	6	7204
11696	3	30775	5	6729
11697	5	30781	2	2384
11698	4	30785	4	12124
11699	5	30786	4	8051
11700	5	30786	3	8051
11701	3	30787	7	12140
11702	2	30792	6	3689
11703	5	30797	7	6873
11704	5	30799	6	491
11705	4	30800	1	8045
11706	5	30801	7	5257
11707	4	30803	5	12123
11708	5	30804	6	3660
11709	4	30806	1	4342
11710	4	30807	7	5147
11711	3	30808	7	7049
11712	5	30811	4	7362
11713	3	30812	4	5474
11714	5	30813	7	12105
11715	3	30814	3	12132
11716	5	30815	2	10697
11717	5	30816	4	8588
11718	5	30818	4	12210
11719	4	30821	2	357
11720	4	30823	7	12202
11721	4	30824	7	8730
11722	3	30826	7	12211
11723	5	30827	7	6869
11724	4	30829	7	691
11725	5	30833	1	2492
11726	5	30834	2	8043
11727	3	30835	7	12171
11728	1	30838	6	9733
11729	5	30839	1	12141
11730	5	30841	2	1573
11731	3	30842	3	10272
11732	3	30845	3	6668
11733	5	30848	4	3885
11734	5	30851	7	2228
11735	2	30852	1	1088
11736	5	30853	7	1255
11737	5	30854	3	12168
11738	4	30855	2	4867
11739	5	30856	5	12160
11740	5	30861	5	739
11741	5	30862	7	12193
11742	4	30863	7	12176
11743	5	30863	4	12176
11744	5	30864	3	1026
11745	3	30866	4	11229
11746	5	30867	3	12152
11747	5	30869	2	12180
11748	5	30870	6	5719
11749	5	30876	5	1316
11750	5	30877	6	12161
11751	1	30881	4	3314
11752	5	30882	6	12116
11753	5	30882	2	12116
11754	3	30884	1	12138
11755	4	30887	7	12121
11756	5	30890	5	10210
11757	4	30893	3	8738
11758	4	30895	7	1429
11759	3	30896	7	12127
11760	5	30901	6	12142
11761	5	30905	1	5329
11762	5	30911	4	12206
11763	5	30912	7	12098
11764	3	30913	7	12186
11765	4	30916	7	12179
11766	5	30918	4	11878
11767	5	30922	6	12191
11768	4	30924	2	6591
11769	1	30926	7	12112
11770	3	30927	7	10679
11771	5	30928	1	12147
11772	3	30930	2	3473
11773	4	30937	1	396
11774	5	30938	4	12122
11775	4	30939	5	12187
11776	5	30947	2	4818
11777	5	30951	7	4072
11778	5	30952	6	3127
11779	3	30953	5	2568
11780	5	30954	6	8342
11781	4	30956	4	5857
11782	4	30957	6	12167
11783	5	30961	7	9902
11784	4	30963	7	12205
11785	4	30965	1	12197
11786	3	30966	6	11306
11787	3	30968	5	1813
11788	5	30974	6	8708
11789	5	30978	2	2447
11790	5	30980	7	1095
11791	3	30982	7	12313
11792	3	30983	5	4100
11793	5	30986	7	12243
11794	5	30988	3	11715
11795	5	30995	2	12299
11796	4	31005	4	12314
11797	5	31009	7	8101
11798	5	31011	2	2176
11799	4	31013	4	12258
11800	3	31014	3	6274
11801	3	31017	5	2705
11802	5	31018	1	7760
11803	3	31023	5	12281
11804	5	31024	2	12267
11805	5	31026	7	10052
11806	5	31026	3	10052
11807	5	31027	7	12311
11808	5	31028	7	11710
11809	5	31032	2	1656
11810	5	31040	7	12228
11811	3	31043	3	5649
11812	4	31046	5	12312
11813	4	31058	2	12223
11814	4	31058	7	12223
11815	3	31062	7	12244
11816	4	31065	3	9303
11817	5	31066	7	6273
11818	5	31067	7	12309
11819	5	31071	5	8988
11820	5	31073	7	8944
11821	3	31075	1	8311
11822	5	31076	2	12216
11823	5	31085	2	2700
11824	5	31087	2	6552
11825	5	31093	2	12278
11826	5	31094	5	4808
11827	4	31095	2	12320
11828	5	31096	6	12290
11829	5	31097	5	10946
11830	3	31098	3	5099
11831	1	31099	6	3705
11832	4	31101	4	12287
11833	5	31103	5	12300
11834	5	31108	6	2965
11835	4	31110	4	12234
11836	4	31111	1	5091
11837	4	31113	2	12235
11838	5	31116	7	12241
11839	3	31117	5	12269
11840	5	31118	2	10819
11841	4	31119	7	11187
11842	3	31125	5	12297
11843	3	31128	5	12315
11844	3	31132	2	4090
11845	4	31133	1	12230
11846	5	31138	6	12260
11847	4	31141	6	748
11848	3	31142	4	9788
11849	5	31144	2	313
11850	1	31150	7	12291
11851	5	31151	2	1359
11852	4	31154	2	5306
11853	5	31157	5	12282
11854	3	31157	7	12282
11855	5	31160	6	9920
11856	5	31162	2	4578
11857	4	31164	5	2415
11858	3	31166	3	12286
11859	4	31171	4	12257
11860	4	31174	7	12229
11861	4	31177	5	9467
11862	3	31178	5	11746
11863	4	31179	7	5407
11864	5	31181	5	1566
11865	5	31182	7	8075
11866	5	31182	4	8075
11867	5	31184	5	5650
11868	4	31187	2	12214
11869	5	31192	5	12252
11870	5	31194	5	6994
11871	3	31195	7	12292
11872	5	31196	1	11464
11873	5	31197	5	11981
11874	5	31199	2	4072
11875	3	31204	4	1643
11876	4	31211	4	11250
11877	4	31214	7	235
11878	5	31215	5	12293
11879	5	31216	5	1018
11880	5	31219	3	2228
11881	4	31220	6	213
11882	3	31222	5	9081
11883	4	31224	5	12272
11884	5	31231	4	12416
11885	4	31233	1	8486
11886	4	31234	4	7455
11887	4	31235	7	12345
11888	5	31236	3	12362
11889	4	31237	3	12363
11890	4	31238	2	7698
11891	3	31240	7	12374
11892	5	31241	5	1528
11893	5	31245	2	12379
11894	5	31246	4	5087
11895	1	31251	6	1303
11896	1	31254	4	9412
11897	5	31254	1	9412
11898	3	31257	4	12328
11899	4	31264	1	8503
11900	2	31265	6	790
11901	5	31278	4	2068
11902	5	31280	2	7806
11903	4	31284	3	7428
11904	4	31289	1	12329
11905	5	31291	1	10812
11906	3	31291	5	10812
11907	1	31292	6	12302
11908	5	31294	5	12409
11909	5	31296	2	8357
11910	4	31298	7	6469
11911	4	31299	5	5886
11912	4	31305	7	4223
11913	5	31308	5	6738
11914	5	31313	6	12383
11915	5	31314	3	1684
11916	5	31316	3	950
11917	4	31319	4	4445
11918	5	31321	7	12332
11919	5	31327	6	3712
11920	4	31328	3	11846
11921	3	31330	2	11969
11922	5	31332	6	10632
11923	5	31333	6	12371
11924	5	31334	7	9900
11925	5	31337	6	649
11926	3	31340	4	12365
11927	3	31343	5	408
11928	4	31344	3	6403
11929	2	31344	6	6403
11930	5	31346	2	3692
11931	5	31348	7	10835
11932	5	31353	7	12335
11933	5	31354	6	11674
11934	5	31355	7	12369
11935	4	31356	5	12375
11936	4	31359	2	12078
11937	5	31361	7	12323
11938	5	31364	7	12370
11939	2	31364	6	12370
11940	3	31367	7	10461
11941	5	31371	3	1690
11942	3	31379	7	1760
11943	4	31381	2	2608
11944	4	31386	5	9552
11945	4	31387	7	12263
11946	5	31389	5	9638
11947	3	31393	7	1097
11948	5	31394	2	986
11949	3	31395	1	2530
11950	3	31400	3	7744
11951	5	31407	7	12322
11952	5	31409	5	12408
11953	3	31410	5	2281
11954	3	31411	1	10241
11955	3	31411	4	10241
11956	3	31412	5	12358
11957	4	31413	5	11469
11958	4	31414	7	12342
11959	4	31417	1	12405
11960	5	31419	6	12401
11961	1	31421	4	12349
11962	5	31422	2	12378
11963	4	31423	5	12337
11964	5	31424	2	4982
11965	5	31427	7	12360
11966	5	31429	2	8115
11967	5	31430	6	12325
11968	5	31433	1	12102
11969	5	31434	6	2933
11970	3	31435	4	2715
11971	5	31442	6	8355
11972	3	31443	3	531
11973	2	31443	1	531
11974	5	31451	2	9846
11975	5	31452	5	12395
11976	4	31455	2	1724
11977	5	31455	6	1724
11978	4	31457	5	11550
11979	5	31459	2	2268
11980	5	31460	6	7167
11981	5	31465	6	4485
11982	3	31468	4	12404
11983	5	31469	5	12426
11984	5	31470	3	12402
11985	5	31470	4	12402
11986	5	31473	4	348
11987	4	31475	2	6817
11988	5	31479	2	2317
11989	5	31481	6	1325
11990	5	31483	4	2124
11991	5	31484	6	1425
11992	3	31486	5	8923
11993	5	31488	6	10292
11994	4	31489	5	12347
11995	5	31491	6	424
11996	3	31493	5	1986
11997	3	31496	5	12350
11998	5	31498	4	123
11999	5	31498	3	123
12000	5	31504	7	12391
12001	4	31506	2	9174
12002	3	31512	5	11491
12003	4	31513	4	3230
12004	5	31514	6	12398
12005	5	31518	3	438
12006	5	31519	5	10116
12007	5	31522	4	12509
12008	3	31529	5	2909
12009	4	31530	7	1460
12010	2	31534	6	12508
12011	5	31535	3	12531
12012	5	31540	4	12473
12013	4	31544	7	7310
12014	5	31546	2	2054
12015	5	31547	6	11417
12016	3	31548	1	12534
12017	4	31552	4	12338
12018	5	31559	6	3883
12019	5	31562	6	7491
12020	5	31563	6	12475
12021	5	31565	5	12512
12022	4	31568	7	8539
12023	5	31571	3	993
12024	5	31576	2	7186
12025	5	31578	2	4485
12026	3	31579	2	3261
12027	4	31580	6	12464
12028	4	31583	6	12488
12029	3	31587	5	9365
12030	5	31590	7	3543
12031	4	31592	7	8050
12032	4	31603	7	6055
12033	4	31605	3	5568
12034	3	31606	3	10863
12035	5	31607	5	12477
12036	5	31609	6	12510
12037	5	31612	7	10129
12038	4	31614	3	10000
12039	5	31621	2	2796
12040	4	31625	3	12459
12041	4	31626	4	9660
12042	4	31630	2	8149
12043	5	31631	2	12535
12044	4	31636	1	12452
12045	5	31639	3	3730
12046	2	31642	6	11511
12047	5	31643	5	12433
12048	4	31644	1	1291
12049	5	31644	4	1291
12050	1	31645	6	12483
12051	4	31645	4	12483
12052	3	31646	1	3211
12053	4	31649	5	10337
12054	5	31650	6	12088
12055	1	31651	4	9433
12056	5	31651	1	9433
12057	4	31653	4	9554
12058	5	31655	5	12455
12059	5	31661	5	12523
12060	1	31662	6	1179
12061	4	31664	7	12441
12062	5	31665	5	5886
12063	5	31668	7	2658
12064	5	31669	3	12507
12065	5	31674	2	12469
12066	5	31676	5	4160
12067	5	31677	6	3934
12068	5	31677	5	3934
12069	4	31678	3	5873
12070	4	31679	4	1832
12071	5	31680	7	5928
12072	5	31681	4	8511
12073	5	31685	6	3558
12074	5	31686	4	10905
12075	5	31688	7	12480
12076	4	31688	2	12480
12077	5	31690	1	3870
12078	5	31692	6	2615
12079	3	31696	4	12435
12080	1	31698	6	6364
12081	3	31699	5	12516
12082	5	31701	5	10394
12083	4	31703	3	12482
12084	5	31706	6	10427
12085	5	31708	5	6981
12086	5	31709	6	9043
12087	5	31711	6	8341
12088	5	31712	5	12530
12089	4	31716	6	11928
12090	3	31718	6	11766
12091	5	31720	6	12492
12092	5	31721	6	9195
12093	5	31726	2	2431
12094	5	31728	1	4914
12095	5	31731	4	12457
12096	5	31735	2	8032
12097	3	31737	7	10073
12098	5	31738	4	4592
12099	4	31738	7	4592
12100	4	31739	4	1352
12101	3	31741	7	12454
12102	4	31743	7	12450
12103	5	31744	6	2332
12104	5	31746	1	5194
12105	5	31754	6	12505
12106	5	31755	6	12522
12107	5	31756	4	1283
12108	3	31758	4	11605
12109	5	31776	6	7854
12110	5	31779	7	3532
12111	5	31781	5	12456
12112	4	31787	6	7660
12113	5	31788	6	1296
12114	5	31790	1	6457
12115	5	31791	1	5391
12116	5	31792	3	2736
12117	5	31793	7	12448
12118	4	31794	2	2699
12119	5	31797	6	12468
12120	1	31798	6	12517
12121	5	31799	7	7870
12122	5	31800	7	11709
12123	5	31802	6	11096
12124	5	31805	4	2783
12125	5	31812	3	6496
12126	5	31813	4	3502
12127	4	31815	7	10533
12128	3	31817	1	1889
12129	5	31818	4	9977
12130	5	31818	3	9977
12131	5	31819	7	1468
12132	5	31821	2	9164
12133	4	31822	3	12521
12134	4	31827	5	4953
12135	5	31828	4	12496
12136	4	31830	5	5331
12137	4	31832	3	6350
12138	5	31835	7	10488
12139	5	31835	4	10488
12140	5	31839	5	10356
12141	4	31840	4	8386
12142	5	31843	4	10354
12143	5	31844	2	1044
12144	5	31847	4	12524
12145	4	31848	7	12526
12146	1	31849	2	12511
12147	4	31851	1	601
12148	5	31854	4	3634
12149	1	31857	6	7197
12150	5	31858	2	2731
12151	5	31859	6	12515
12152	3	31862	7	9955
12153	5	31865	1	12465
12154	5	31868	2	2116
12155	5	31872	2	8653
12156	3	31881	4	654
12157	3	31881	7	654
12158	5	31882	1	12453
12159	5	31884	7	11237
12160	5	31887	7	1168
12161	5	31889	2	12576
12162	3	31891	3	2215
12163	5	31892	4	821
12164	4	31894	5	12620
12165	5	31907	7	11754
12166	1	31908	6	12641
12167	5	31915	6	9539
12168	5	31918	7	12560
12169	5	31922	3	123
12170	4	31923	7	1643
12171	4	31927	7	12582
12172	5	31930	6	2445
12173	5	31932	4	3356
12174	5	31933	2	7741
12175	5	31935	7	1322
12176	5	31936	3	1657
12177	4	31940	4	11612
12178	5	31941	6	3337
12179	5	31947	2	12599
12180	5	31956	1	6144
12181	5	31961	1	7163
12182	5	31963	2	12645
12183	4	31963	1	12645
12184	3	31964	3	12545
12185	4	31965	6	11771
12186	5	31966	5	11331
12187	5	31967	4	527
12188	5	31968	4	2314
12189	3	31970	7	12536
12190	5	31971	4	8435
12191	5	31980	4	12608
12192	1	31981	6	6396
12193	5	31982	4	6790
12194	5	31985	2	3840
12195	4	31987	7	8856
12196	3	31988	1	12204
12197	5	31989	6	12644
12198	4	31994	4	7109
12199	3	31994	5	7109
12200	3	31995	1	2717
12201	5	31998	5	9513
12202	4	32001	7	2523
12203	5	32003	6	7514
12204	5	32005	1	12617
12205	5	32007	3	12585
12206	5	32011	6	10287
12207	4	32013	5	2125
12208	4	32017	7	158
12209	3	32019	7	12643
12210	4	32021	7	401
12211	5	32022	6	7925
12212	5	32026	4	12636
12213	5	32032	3	12594
12214	5	32037	6	6201
12215	5	32040	2	2392
12216	5	32041	2	9818
12217	5	32043	5	2651
12218	3	32045	7	8884
12219	4	32052	6	12628
12220	5	32054	6	11947
12221	5	32057	4	1145
12222	4	32059	6	12596
12223	5	32061	2	10755
12224	4	32062	7	12597
12225	5	32066	5	1627
12226	4	32069	3	12691
12227	4	32072	1	10612
12228	5	32076	2	12714
12229	5	32077	2	4605
12230	5	32079	5	12692
12231	5	32080	5	9623
12232	5	32082	2	12713
12233	3	32083	7	10071
12234	5	32083	2	10071
12235	4	32084	4	7691
12236	2	32088	6	12709
12237	4	32094	1	12706
12238	3	32095	5	11922
12239	5	32098	2	8152
12240	5	32100	1	2604
12241	4	32101	4	10663
12242	5	32102	4	12730
12243	3	32103	7	12677
12244	4	32104	6	12679
12245	3	32106	7	6629
12246	3	32108	7	12676
12247	4	32109	2	12649
12248	4	32114	3	71
12249	5	32118	5	11826
12250	2	32120	6	236
12251	3	32122	5	7918
12252	4	32123	7	12146
12253	4	32125	3	12185
12254	5	32125	6	12185
12255	5	32128	2	7132
12256	4	32129	3	12724
12257	2	32131	6	12651
12258	3	32132	1	3932
12259	5	32133	6	6421
12260	5	32134	3	840
12261	5	32140	2	12661
12262	5	32148	2	10159
12263	4	32154	5	12725
12264	3	32154	2	12725
12265	5	32158	3	8773
12266	5	32159	2	12682
12267	3	32161	3	12663
12268	4	32162	2	11065
12269	4	32168	2	157
12270	5	32169	3	9077
12271	5	32171	2	12710
12272	5	32175	2	1712
12273	4	32178	6	12728
12274	5	32181	2	7017
12275	5	32183	7	7544
12276	5	32186	4	2386
12277	5	32187	3	8651
12278	4	32191	1	12700
12279	4	32192	7	8375
12280	5	32193	6	12607
12281	3	32194	5	8367
12282	3	32195	3	12674
12283	1	32202	6	11211
12284	5	32205	7	12043
12285	4	32207	3	1037
12286	5	32208	3	9884
12287	5	32210	7	8084
12288	4	32211	7	12723
12289	4	32215	6	4673
12290	5	32218	7	4007
12291	5	32220	3	4586
12292	5	32222	3	1044
12293	4	32224	1	8090
12294	4	32227	7	3126
12295	3	32228	7	790
12296	5	32229	7	12659
12297	5	32232	1	5994
12298	5	32237	4	7502
12299	4	32244	3	12660
12300	5	32248	6	1303
12301	5	32254	4	12666
12302	2	32255	7	4561
12303	1	32256	6	12681
12304	4	32258	4	3382
12305	4	32258	1	3382
12306	4	32260	6	5447
12307	5	32261	2	4904
12308	3	32263	6	12734
12309	4	32265	2	9728
12310	5	32266	7	12721
12311	3	32267	6	12729
12312	2	32268	6	12738
12313	5	32269	2	9534
12314	5	32272	2	12658
12315	5	32274	7	8561
12316	5	32275	6	5676
12317	5	32278	6	12758
12318	2	32279	7	9192
12319	3	32280	7	10375
12320	2	32281	2	5123
12321	5	32284	6	11507
12322	5	32285	3	12825
12323	4	32287	1	10209
12324	3	32288	3	4767
12325	4	32291	5	3153
12326	3	32292	6	3636
12327	3	32295	7	1215
12328	5	32297	4	12777
12329	5	32298	5	12839
12330	5	32301	4	12822
12331	3	32307	1	7666
12332	3	32308	5	12810
12333	5	32309	6	12823
12334	5	32310	6	7338
12335	3	32313	6	22
12336	3	32320	3	12744
12337	4	32321	2	7898
12338	5	32322	4	3173
12339	5	32324	4	12788
12340	5	32324	5	12788
12341	4	32325	6	12837
12342	5	32326	3	2189
12343	5	32328	4	3558
12344	4	32330	1	4797
12345	5	32330	4	4797
12346	5	32332	6	5509
12347	5	32333	5	9976
12348	4	32334	5	1183
12349	5	32336	2	1746
12350	5	32340	4	12833
12351	4	32346	1	12814
12352	4	32346	2	12814
12353	4	32349	3	11615
12354	4	32351	6	12848
12355	5	32352	2	12805
12356	4	32352	7	12805
12357	4	32353	2	8026
12358	4	32355	1	7019
12359	3	32357	5	12836
12360	4	32358	1	12824
12361	5	32360	5	7041
12362	4	32361	7	9929
12363	4	32362	7	12770
12364	3	32363	3	12811
12365	5	32366	7	12793
12366	5	32368	4	1581
12367	5	32372	2	418
12368	5	32373	6	4136
12369	5	32376	4	2216
12370	5	32382	2	11840
12371	3	32385	4	1343
12372	5	32388	6	9798
12373	4	32388	2	9798
12374	5	32389	7	8887
12375	5	32391	7	7574
12376	5	32395	2	7150
12377	5	32396	3	2434
12378	3	32399	5	10033
12379	5	32401	2	11834
12380	4	32403	1	12827
12381	5	32407	3	9335
12382	5	32408	6	12783
12383	4	32412	7	2422
12384	5	32415	1	12761
12385	5	32415	4	12761
12386	5	32420	2	1549
12387	5	32424	6	12750
12388	2	32426	3	3314
12389	5	32427	2	3443
12390	5	32428	5	2835
12391	5	32433	2	12791
12392	5	32436	1	1317
12393	5	32438	1	9015
12394	4	32440	6	10878
12395	3	32443	7	11735
12396	3	32446	3	11962
12397	5	32447	2	1076
12398	5	32449	3	12803
12399	5	32455	2	12843
12400	3	32456	6	12767
12401	3	32457	5	12769
12402	5	32463	3	199
12403	5	32468	6	1352
12404	1	32473	6	11061
12405	4	32475	6	5970
12406	2	32477	3	5169
12407	5	32479	5	6187
12408	4	32479	1	6187
12409	2	32482	2	12798
12410	5	32485	2	2838
12411	5	32487	7	5668
12412	5	32488	5	2176
12413	5	32491	1	2654
12414	1	32493	5	826
12415	3	32494	7	12766
12416	5	32496	6	12787
12417	3	32497	4	11018
12418	5	32499	6	3493
12419	5	32500	3	10565
12420	5	32500	7	10565
12421	3	32501	3	12809
12422	4	32504	3	12756
12423	4	32506	4	12842
12424	4	32507	5	8922
12425	5	32508	1	12818
12426	5	32511	2	740
12427	5	32512	2	4628
12428	4	32515	2	11270
12429	5	32522	2	2221
12430	5	32523	2	2317
12431	5	32525	3	5485
12432	4	32529	1	12320
12433	4	32529	5	12320
12434	5	32536	5	10740
12435	5	32537	7	12838
12436	5	32539	5	12790
12437	3	32542	7	5591
12438	5	32546	1	12760
12439	5	32546	2	12760
12440	5	32547	1	105
12441	5	32550	6	12306
12442	4	32552	1	7438
12443	1	32553	6	12830
12444	5	32557	7	8798
12445	3	32558	3	6689
12446	5	32567	3	12855
12447	5	32568	2	2398
12448	5	32570	2	8970
12449	4	32571	4	7491
12450	5	32572	5	204
12451	4	32573	3	1379
12452	5	32580	2	285
12453	4	32581	5	8236
12454	4	32582	2	12530
12455	5	32585	4	12899
12456	4	32586	1	10740
12457	4	32587	7	5242
12458	5	32589	7	12889
12459	5	32591	4	12571
12460	5	32592	7	12922
12461	3	32593	1	8799
12462	5	32596	1	12880
12463	5	32597	5	12775
12464	5	32599	6	12920
12465	5	32604	4	12877
12466	5	32606	1	4170
12467	3	32609	5	12873
12468	3	32611	7	10354
12469	5	32611	6	10354
12470	3	32612	3	12883
12471	4	32613	5	11962
12472	4	32614	3	2251
12473	3	32616	6	8460
12474	5	32619	4	12882
12475	5	32620	7	12850
12476	4	32621	5	3509
12477	3	32622	5	12905
12478	5	32625	7	12924
12479	4	32626	5	12863
12480	5	32630	4	12297
12481	3	32633	1	12935
12482	4	32634	1	1331
12483	5	32637	7	3977
12484	5	32640	1	12344
12485	4	32640	6	12344
12486	5	32644	3	9034
12487	5	32646	2	3293
12488	5	32648	6	7694
12489	5	32650	6	2894
12490	4	32653	7	12881
12491	3	32653	5	12881
12492	5	32669	4	12916
12493	1	32670	4	1534
12494	5	32673	3	12860
12495	5	32676	6	12914
12496	5	32677	3	10151
12497	5	32679	2	12864
12498	5	32681	2	4690
12499	5	32684	6	12532
12500	4	32689	4	12581
12501	5	32689	7	12581
12502	5	32692	3	299
12503	5	32693	2	6377
12504	5	32695	1	1170
12505	3	32696	4	12685
12506	5	32697	7	10670
12507	2	32703	5	9579
12508	5	32706	6	10095
12509	5	32709	3	12926
12510	5	32711	2	11695
12511	3	32713	5	10235
12512	3	32714	6	8961
12513	5	32715	5	6081
12514	5	32717	5	2633
12515	5	32721	3	10452
12516	5	32723	6	12885
12517	5	32726	5	12878
12518	1	32726	6	12878
12519	4	32727	6	12107
12520	4	32730	6	7279
12521	4	32730	4	7279
12522	5	32731	3	8676
12523	5	32732	2	12925
12524	5	32735	7	177
12525	5	32741	7	12854
12526	5	32742	5	11576
12527	5	32742	4	11576
12528	2	32745	6	12857
12529	3	32746	7	12897
12530	4	32754	4	7459
12531	5	32758	2	7521
12532	5	32760	7	7541
12533	5	32763	1	12888
12534	5	32765	1	2576
12535	5	32767	7	3380
12536	4	32768	3	1302
12537	4	32769	1	3309
12538	4	32770	2	12870
12539	4	32773	7	12874
12540	3	32779	5	12875
12541	3	32780	7	2446
12542	5	32784	7	12906
12543	3	32788	7	8361
12544	3	32790	4	12893
12545	4	32791	7	8765
12546	1	32792	6	1117
12547	5	32793	7	12876
12548	5	32796	6	12932
12549	5	32803	1	12931
12550	5	32808	5	552
12551	5	32809	3	12904
12552	5	32812	4	9097
12553	3	32818	5	10527
12554	4	32820	2	12940
12555	3	32822	2	13030
12556	3	32823	2	440
12557	5	32825	3	5318
12558	4	32830	2	7912
12559	5	32835	4	10909
12560	4	32839	7	1735
12561	5	32842	4	7743
12562	4	32842	6	7743
12563	5	32844	6	3688
12564	4	32846	5	11983
12565	4	32847	5	688
12566	5	32848	6	1830
12567	4	32850	6	1457
12568	3	32851	2	6453
12569	5	32853	3	318
12570	5	32855	4	5888
12571	1	32857	6	11792
12572	3	32859	1	12989
12573	5	32860	6	9052
12574	3	32861	1	12012
12575	5	32863	4	6037
12576	5	32866	4	13022
12577	5	32867	3	10706
12578	5	32870	5	10952
12579	4	32871	5	6305
12580	5	32874	7	13010
12581	5	32877	4	1118
12582	3	32881	7	13020
12583	5	32882	2	12952
12584	5	32883	6	12981
12585	3	32887	7	13012
12586	5	32888	7	10108
12587	5	32889	7	717
12588	5	32890	3	1289
12589	3	32891	5	7650
12590	2	32892	6	10142
12591	5	32894	7	537
12592	5	32895	2	12283
12593	3	32896	1	5020
12594	5	32897	6	3222
12595	3	32898	2	3987
12596	4	32899	2	10815
12597	5	32902	6	4704
12598	1	32903	6	12109
12599	4	32907	2	13004
12600	5	32910	4	2139
12601	5	32911	1	12974
12602	5	32911	3	12974
12603	5	32913	2	5979
12604	4	32914	2	12948
12605	4	32920	7	1076
12606	5	32922	7	13008
12607	4	32931	1	8121
12608	3	32931	4	8121
12609	3	32938	5	12945
12610	5	32939	2	10717
12611	4	32943	4	12985
12612	4	32945	1	12983
12613	5	32948	2	10366
12614	3	32948	4	10366
12615	3	32951	5	1526
12616	2	32954	3	12941
12617	4	32961	5	5585
12618	3	32964	7	11431
12619	3	32966	1	1233
12620	1	32967	6	11616
12621	5	32968	6	6811
12622	5	32970	4	957
12623	4	32976	5	12996
12624	4	32977	7	5640
12625	3	32978	6	354
12626	3	32979	7	11457
12627	4	32980	3	1751
12628	4	32986	1	4495
12629	5	32987	3	11187
12630	5	32988	1	12982
12631	5	32989	1	12964
12632	4	32991	5	13021
12633	3	32991	3	13021
12634	5	32992	7	5613
12635	5	32997	3	4274
12636	5	32998	4	7951
12637	5	33003	7	4235
12638	4	33005	4	13014
12639	5	33006	5	13002
12640	5	33007	5	8187
12641	5	33008	3	12864
12642	4	33008	4	12864
12643	3	33009	4	2263
12644	3	33010	3	2482
12645	4	33012	6	5274
12646	5	33013	2	12949
12647	5	33013	5	12949
12648	3	33017	1	13011
12649	5	33018	3	12979
12650	3	33020	7	11596
12651	3	33021	5	10458
12652	5	33025	3	3835
12653	3	33026	5	12971
12654	4	33027	4	12129
12655	3	33028	7	10367
12656	3	33033	7	9440
12657	3	33035	7	13007
12658	5	33036	7	12760
12659	5	33039	6	12991
12660	5	33041	3	12934
12661	5	33043	5	9746
12662	3	33046	5	10167
12663	5	33052	3	3174
12664	2	33054	1	12994
12665	5	33054	2	12994
12666	5	33055	2	3838
12667	5	33058	6	3730
12668	4	33059	6	12995
12669	5	33060	6	11586
12670	5	33062	6	1700
12671	5	33063	2	13028
12672	4	33065	5	382
12673	5	33067	4	13142
12674	4	33072	3	13032
12675	5	33073	3	4301
12676	5	33075	7	13120
12677	2	33077	3	111
12678	5	33079	4	2392
12679	4	33080	7	3052
12680	4	33083	2	5034
12681	4	33085	7	315
12682	1	33089	6	7815
12683	5	33091	6	10211
12684	3	33093	7	9581
12685	5	33094	2	6186
12686	3	33097	2	10389
12687	3	33099	7	5273
12688	3	33100	5	9052
12689	4	33101	4	3792
12690	5	33102	4	13137
12691	4	33106	2	1700
12692	4	33108	6	13143
12693	5	33110	7	13160
12694	5	33111	4	3611
12695	3	33113	7	4374
12696	5	33114	7	6645
12697	3	33115	5	9227
12698	4	33120	3	10097
12699	5	33122	4	13117
12700	5	33124	3	5768
12701	3	33129	7	10528
12702	4	33131	5	3483
12703	4	33132	7	11315
12704	4	33133	7	13068
12705	3	33134	2	13046
12706	5	33135	7	13169
12707	4	33136	3	8853
12708	5	33138	7	13164
12709	4	33139	5	13129
12710	5	33144	1	6015
12711	2	33146	2	2827
12712	5	33150	5	13044
12713	3	33154	4	6565
12714	3	33156	5	13035
12715	3	33161	3	13094
12716	5	33168	2	3547
12717	5	33170	1	3621
12718	5	33172	1	13039
12719	3	33176	5	11578
12720	5	33180	3	13033
12721	4	33181	7	9307
12722	4	33187	3	5945
12723	5	33188	1	7750
12724	3	33193	6	13037
12725	5	33198	4	13115
12726	4	33199	7	13031
12727	4	33200	2	7983
12728	3	33201	2	13034
12729	5	33209	6	13149
12730	5	33211	4	13111
12731	3	33213	7	3370
12732	5	33216	5	3634
12733	3	33217	5	13150
12734	3	33219	4	13098
12735	5	33220	2	13099
12736	5	33221	6	13041
12737	4	33226	3	8307
12738	4	33228	5	13050
12739	5	33229	7	8212
12740	5	33235	6	4691
12741	5	33238	2	13155
12742	2	33241	2	13148
12743	1	33243	6	7020
12744	5	33245	4	13114
12745	4	33245	7	13114
12746	4	33248	4	10799
12747	5	33252	6	13119
12748	3	33257	5	5183
12749	5	33258	1	7688
12750	5	33259	4	8535
12751	5	33266	6	13051
12752	5	33268	6	5048
12753	4	33270	2	8254
12754	1	33271	6	13040
12755	4	33272	4	1687
12756	5	33273	6	13101
12757	4	33275	1	13107
12758	4	33276	6	7524
12759	5	33276	5	7524
12760	5	33277	1	13118
12761	5	33279	6	13127
12762	5	33280	6	13105
12763	4	33285	5	5099
12764	4	33288	5	170
12765	4	33290	3	13062
12766	5	33296	6	13161
12767	4	33300	5	13123
12768	4	33303	7	11447
12769	1	33304	6	12067
12770	5	33305	4	10870
12771	5	33306	4	3540
12772	5	33307	3	13057
12773	5	33308	2	13122
12774	3	33309	5	8584
12775	4	33310	6	7268
12776	5	33312	4	12240
12777	4	33313	7	8636
12778	2	33315	4	13165
12779	4	33322	2	5633
12780	5	33323	4	3941
12781	4	33325	3	6871
12782	5	33330	6	13147
12783	5	33333	5	5310
12784	5	33338	2	13084
12785	4	33345	5	11217
12786	4	33349	7	2810
12787	3	33353	5	9163
12788	3	33355	2	13124
12789	5	33356	4	3054
12790	5	33357	5	13095
12791	5	33361	7	13052
12792	5	33365	1	13069
12793	4	33368	3	6641
12794	5	33369	2	13073
12795	3	33372	5	13103
12796	5	33373	4	11287
12797	5	33374	2	9103
12798	4	33374	3	9103
12799	3	33376	6	3640
12800	5	33377	4	13100
12801	1	33380	6	13156
12802	5	33382	4	13056
12803	5	33382	1	13056
12804	5	33385	7	8847
12805	5	33385	2	8847
12806	5	33386	2	13113
12807	3	33389	4	4006
12808	5	33390	3	11040
12809	3	33391	1	13102
12810	5	33394	6	2232
12811	5	33395	7	6439
12812	5	33397	2	3000
12813	4	33399	2	2380
12814	5	33404	6	13072
12815	5	33408	5	3629
12816	2	33409	3	13231
12817	5	33412	5	1228
12818	5	33416	6	13184
12819	3	33418	2	6962
12820	5	33420	1	10717
12821	3	33423	5	13239
12822	3	33430	1	13295
12823	4	33432	6	995
12824	5	33432	4	995
12825	5	33434	6	13248
12826	3	33437	5	13190
12827	4	33440	4	13217
12828	5	33445	2	5082
12829	3	33447	7	6800
12830	5	33457	3	13245
12831	4	33462	6	13256
12832	3	33465	1	13288
12833	4	33466	4	10968
12834	5	33467	3	13199
12835	5	33471	2	13262
12836	3	33472	6	11981
12837	5	33473	5	9339
12838	3	33475	5	13177
12839	3	33477	7	13266
12840	5	33478	2	8628
12841	3	33479	5	6990
12842	4	33481	1	352
12843	5	33482	5	1093
12844	4	33483	3	13283
12845	5	33484	2	1095
12846	4	33487	6	2882
12847	5	33493	2	7502
12848	5	33495	6	3779
12849	5	33497	6	13210
12850	5	33497	2	13210
12851	5	33499	2	3052
12852	4	33500	1	1241
12853	3	33501	7	13181
12854	5	33503	5	247
12855	3	33505	3	4578
12856	2	33511	4	4060
12857	5	33517	1	12823
12858	3	33519	7	11818
12859	5	33521	4	3382
12860	5	33522	2	4054
12861	5	33527	6	13198
12862	4	33528	3	707
12863	5	33533	4	2710
12864	5	33534	6	13278
12865	5	33534	7	13278
12866	5	33539	4	2450
12867	4	33540	2	13237
12868	5	33546	3	1440
12869	4	33547	1	6371
12870	5	33558	4	13244
12871	4	33560	5	10662
12872	5	33564	4	1813
12873	4	33572	5	13271
12874	4	33573	5	601
12875	5	33575	2	1143
12876	5	33576	5	6028
12877	5	33578	2	13232
12878	5	33586	2	13236
12879	3	33587	7	13209
12880	5	33590	7	13206
12881	3	33592	5	12185
12882	3	33594	2	3732
12883	5	33601	1	13289
12884	4	33607	1	1638
12885	5	33608	2	13292
12886	5	33613	2	7241
12887	4	33617	6	9166
12888	2	33618	6	13175
12889	5	33618	4	13175
12890	5	33620	1	4685
12891	5	33621	4	7288
12892	5	33622	6	13259
12893	4	33624	6	5308
12894	5	33626	2	807
12895	3	33630	4	5621
12896	5	33634	2	13176
12897	4	33635	7	13227
12898	3	33638	4	13178
12899	4	33640	6	13235
12900	5	33641	6	4696
12901	5	33646	6	13211
12902	5	33647	3	13252
12903	4	33653	7	7369
12904	4	33659	5	13261
12905	5	33660	2	10518
12906	3	33661	5	2604
12907	2	33663	5	13120
12908	4	33665	5	3996
12909	4	33666	6	11751
12910	5	33667	2	6137
12911	1	33669	5	10882
12912	5	33669	2	10882
12913	3	33673	2	5912
12914	5	33678	7	13192
12915	5	33679	6	13212
12916	5	33680	4	13208
12917	5	33683	3	1183
12918	5	33689	2	4459
12919	5	33692	1	11674
12920	5	33694	3	5491
12921	1	33698	4	11683
12922	5	33699	2	13290
12923	5	33702	6	9971
12924	5	33703	1	2943
12925	5	33705	1	13238
12926	5	33706	4	13287
12927	5	33709	4	13196
12928	4	33710	7	13241
12929	5	33714	7	3527
12930	5	33718	1	7414
12931	5	33722	1	6580
12932	4	33723	3	13172
12933	1	33724	6	13179
12934	5	33725	6	4680
12935	2	33733	1	7094
12936	5	33739	2	13182
12937	5	33742	6	8404
12938	4	33743	7	3371
12939	5	33744	4	11318
12940	3	33745	7	12377
12941	3	33746	1	3558
12942	5	33747	2	12292
12943	4	33750	2	2728
12944	5	33756	6	8884
12945	5	33758	2	3153
12946	5	33760	6	2980
12947	5	33761	2	13193
12948	3	33765	2	9859
12949	5	33767	7	13009
12950	5	33769	6	7791
12951	3	33781	1	2951
12952	5	33786	7	13226
12953	5	33787	5	13183
12954	5	33788	1	9633
12955	1	33789	1	8469
12956	5	33790	4	13247
12957	5	33793	4	8597
12958	5	33795	4	4605
12959	3	33798	5	13268
12960	5	33802	1	6243
12961	3	33805	5	8230
12962	5	33806	6	13362
12963	4	33808	4	13322
12964	5	33811	6	13404
12965	5	33813	2	13368
12966	3	33814	3	4622
12967	4	33819	3	10851
12968	4	33828	7	5630
12969	3	33829	5	5164
12970	5	33831	7	13415
12971	5	33834	5	12132
12972	4	33835	6	13365
12973	5	33841	7	13344
12974	5	33844	7	13392
12975	5	33847	7	11987
12976	3	33849	5	8361
12977	5	33851	6	13386
12978	5	33852	2	602
12979	5	33853	1	9218
12980	4	33855	2	2744
12981	4	33855	4	2744
12982	5	33856	2	4818
12983	5	33857	3	9808
12984	5	33862	1	3393
12985	4	33864	2	5744
12986	5	33866	7	13425
12987	3	33867	5	7908
12988	5	33868	5	13353
12989	4	33871	4	6328
12990	4	33873	7	13409
12991	3	33875	1	10872
12992	3	33876	5	5201
12993	5	33877	3	5318
12994	5	33879	1	13319
12995	4	33882	4	4479
12996	5	33885	2	13333
12997	5	33885	7	13333
12998	5	33887	2	13345
12999	5	33888	4	13331
13000	5	33889	2	13349
13001	3	33891	7	13383
13002	3	33891	4	13383
13003	1	33893	6	286
13004	5	33896	5	13411
13005	5	33897	1	11671
13006	5	33902	4	6609
13007	3	33903	7	1833
13008	4	33905	5	13326
13009	4	33909	7	9359
13010	5	33913	3	13424
13011	3	33913	1	13424
13012	3	33916	5	13399
13013	5	33919	1	3201
13014	3	33923	5	2731
13015	5	33926	7	1681
13016	4	33928	7	13310
13017	4	33930	6	315
13018	4	33935	2	5306
13019	5	33937	7	3017
13020	5	33938	7	10799
13021	3	33940	3	13347
13022	5	33941	2	2552
13023	5	33945	4	4655
13024	3	33946	1	3106
13025	5	33949	2	13327
13026	5	33950	2	5236
13027	3	33952	7	1813
13028	5	33953	3	7083
13029	5	33954	7	5325
13030	5	33956	1	4024
13031	2	33962	6	13354
13032	5	33963	3	2182
13033	5	33967	1	10321
13034	4	33968	2	10795
13035	5	33969	1	3286
13036	5	33970	2	5837
13037	3	33976	3	13388
13038	5	33982	6	13329
13039	5	33983	5	10018
13040	5	33985	4	13343
13041	5	33986	2	13385
13042	4	33990	4	552
13043	4	33991	7	10729
13044	5	33993	4	13363
13045	4	33994	3	9449
13046	5	33998	3	12784
13047	4	34000	1	11010
13048	5	34001	3	12240
13049	4	34002	5	13457
13050	4	34003	7	13460
13051	3	34005	5	11225
13052	5	34008	6	13520
13053	3	34015	7	13430
13054	3	34016	3	13505
13055	1	34016	6	13505
13056	5	34020	2	12728
13057	4	34023	7	6013
13058	3	34024	3	4281
13059	5	34027	4	9621
13060	3	34028	4	13487
13061	5	34030	6	2867
13062	5	34035	6	13507
13063	5	34037	7	13512
13064	5	34039	2	8380
13065	5	34043	2	13484
13066	5	34044	4	2552
13067	5	34050	7	4078
13068	4	34052	7	6477
13069	5	34053	7	1032
13070	4	34055	1	6783
13071	4	34060	7	13486
13072	1	34063	6	486
13073	5	34068	6	4328
13074	5	34069	6	13514
13075	5	34070	7	10730
13076	4	34077	6	1066
13077	5	34079	5	6975
13078	5	34087	6	13518
13079	3	34088	1	6235
13080	1	34090	4	13485
13081	5	34093	6	10601
13082	3	34101	3	5806
13083	3	34103	1	11531
13084	3	34106	7	8893
13085	5	34109	3	11728
13086	5	34113	2	5737
13087	4	34114	5	13439
13088	4	34115	5	13427
13089	5	34120	3	12849
13090	3	34121	2	13438
13091	5	34124	4	698
13092	2	34125	4	11839
13093	5	34126	2	5645
13094	3	34127	3	13465
13095	5	34129	6	5820
13096	5	34131	3	2071
13097	4	34135	7	13441
13098	3	34136	5	13437
13099	4	34137	3	6911
13100	5	34140	2	13497
13101	3	34141	6	7258
13102	4	34145	6	5656
13103	1	34152	2	6516
13104	4	34153	7	13524
13105	5	34154	4	13436
13106	1	34156	2	8307
13107	5	34158	7	13503
13108	4	34159	5	13489
13109	5	34160	4	691
13110	5	34161	5	13451
13111	5	34161	7	13451
13112	5	34162	6	7476
13113	5	34163	4	6130
13114	5	34164	6	507
13115	4	34166	2	3318
13116	5	34166	6	3318
13117	5	34169	6	9878
13118	5	34171	7	13526
13119	4	34172	2	6918
13120	5	34173	4	8311
13121	4	34174	1	13491
13122	5	34178	2	6104
13123	4	34179	1	5751
13124	5	34181	6	13462
13125	4	34183	1	10365
13126	4	34191	7	4187
13127	5	34194	7	7238
13128	3	34195	3	13476
13129	4	34197	7	13433
13130	3	34201	1	7133
13131	3	34202	3	9400
13132	4	34206	6	1429
13133	4	34208	3	8584
13134	5	34209	5	3549
13135	5	34217	2	4740
13136	3	34219	4	13605
13137	5	34230	7	2116
13138	5	34233	1	13570
13139	4	34234	1	4166
13140	5	34235	4	13625
13141	4	34236	7	12011
13142	5	34237	5	8502
13143	5	34240	4	13568
13144	1	34242	6	13551
13145	5	34244	6	13610
13146	5	34245	5	13536
13147	4	34248	1	13592
13148	5	34254	4	7049
13149	5	34254	2	7049
13150	5	34257	1	6133
13151	5	34257	5	6133
13152	4	34258	1	1978
13153	4	34263	4	3129
13154	5	34267	4	1365
13155	5	34268	2	6136
13156	3	34269	7	12602
13157	5	34271	5	9058
13158	4	34271	7	9058
13159	5	34272	3	13576
13160	4	34276	6	13542
13161	4	34277	1	10653
13162	5	34279	6	3883
13163	3	34280	3	13544
13164	4	34282	3	4403
13165	4	34283	7	13582
13166	5	34284	6	1867
13167	4	34285	5	7342
13168	5	34288	7	13611
13169	4	34289	7	13612
13170	5	34294	3	1408
13171	3	34297	3	13561
13172	4	34303	6	13595
13173	4	34307	5	3238
13174	5	34309	1	1760
13175	5	34312	1	13567
13176	2	34313	6	13624
13177	5	34315	6	10232
13178	5	34316	7	86
13179	5	34318	2	1826
13180	5	34321	6	7208
13181	5	34322	1	2450
13182	5	34323	3	13608
13183	5	34324	6	13614
13184	3	34327	7	13579
13185	5	34330	2	2907
13186	5	34331	7	13598
13187	5	34334	6	6521
13188	4	34338	3	12951
13189	3	34339	4	13537
13190	4	34341	7	13538
13191	3	34342	7	13580
13192	4	34344	7	10676
13193	5	34345	1	4595
13194	3	34347	3	13558
13195	4	34350	7	13546
13196	3	34350	5	13546
13197	5	34354	4	2333
13198	3	34358	7	12903
13199	4	34363	1	13594
13200	2	34367	6	684
13201	5	34370	2	4495
13202	5	34372	5	8081
13203	5	34375	7	8642
13204	5	34375	1	8642
13205	5	34380	4	4544
13206	4	34381	7	1229
13207	4	34387	4	6827
13208	5	34388	6	13578
13209	5	34391	3	13606
13210	5	34392	6	2231
13211	5	34396	6	13622
13212	3	34400	6	13556
13213	5	34402	2	13534
13214	5	34403	2	2980
13215	5	34404	4	13549
13216	5	34408	7	3323
13217	5	34410	3	1344
13218	4	34413	7	7709
13219	4	34415	5	9798
13220	1	34419	6	12981
13221	3	34420	1	10739
13222	5	34421	2	13531
13223	5	34422	4	5293
13224	5	34424	7	13553
13225	5	34425	5	12486
13226	5	34426	7	13535
13227	1	34428	6	13530
13228	5	34429	5	12657
13229	5	34430	1	3177
13230	3	34431	2	341
13231	2	34433	6	3833
13232	4	34434	2	9337
13233	4	34437	4	11978
13234	3	34438	2	12307
13235	3	34439	7	949
13236	5	34440	6	12764
13237	5	34442	7	4646
13238	3	34447	5	13615
13239	5	34449	2	820
13240	5	34450	7	7709
13241	4	34453	5	7888
13242	5	34460	2	9506
13243	5	34461	6	13709
13244	5	34463	2	13658
13245	4	34466	4	439
13246	5	34471	6	13708
13247	3	34478	4	13579
13248	5	34482	2	1483
13249	3	34484	5	4034
13250	4	34487	2	7573
13251	5	34492	6	2641
13252	5	34494	1	1554
13253	5	34495	2	13731
13254	4	34497	5	13665
13255	1	34499	6	13701
13256	5	34501	6	4870
13257	3	34502	5	8521
13258	3	34503	5	5570
13259	5	34505	2	7979
13260	5	34506	5	13702
13261	5	34507	1	8916
13262	5	34510	6	1344
13263	5	34512	1	13717
13264	5	34513	4	13666
13265	5	34516	1	13646
13266	5	34516	2	13646
13267	5	34519	4	3054
13268	5	34520	7	13649
13269	5	34522	5	13068
13270	5	34523	4	13713
13271	5	34525	1	11779
13272	5	34527	6	4736
13273	5	34529	4	6773
13274	5	34532	2	13335
13275	5	34537	4	2016
13276	5	34538	6	10712
13277	4	34538	1	10712
13278	5	34541	6	10008
13279	2	34543	3	7404
13280	5	34546	2	1821
13281	5	34547	5	13642
13282	3	34548	1	13673
13283	5	34550	5	8050
13284	5	34553	5	1376
13285	5	34556	6	4799
13286	5	34558	1	10436
13287	3	34559	5	337
13288	5	34560	4	1814
13289	5	34561	6	13700
13290	5	34562	7	7266
13291	5	34564	2	13693
13292	5	34565	4	9894
13293	4	34568	3	11093
13294	5	34572	4	1353
13295	4	34574	1	13672
13296	3	34578	3	3129
13297	5	34582	3	13652
13298	5	34583	1	13697
13299	4	34585	5	3498
13300	5	34589	1	13634
13301	5	34590	4	6805
13302	5	34596	6	13689
13303	4	34596	1	13689
13304	5	34599	5	13716
13305	5	34601	1	552
13306	3	34601	7	552
13307	3	34602	5	12393
13308	5	34603	1	8538
13309	4	34604	5	13670
13310	5	34604	6	13670
13311	5	34605	3	9885
13312	3	34607	7	5993
13313	4	34608	3	3423
13314	4	34612	2	6928
13315	5	34613	3	8756
13316	5	34615	2	10438
13317	4	34617	5	3499
13318	3	34622	2	13662
13319	1	34623	6	13691
13320	5	34626	5	13680
13321	4	34627	6	9737
13322	5	34628	6	12489
13323	3	34629	5	13637
13324	3	34633	7	13303
13325	4	34634	4	9631
13326	5	34636	4	8243
13327	3	34637	7	11172
13328	5	34638	1	13647
13329	4	34639	6	7019
13330	5	34639	2	7019
13331	4	34643	1	1650
13332	5	34646	7	13722
13333	4	34647	1	7253
13334	4	34649	1	1245
13335	1	34650	6	2021
13336	3	34651	4	1556
13337	4	34653	6	13685
13338	3	34659	6	13720
13339	5	34660	2	11102
13340	3	34668	3	13631
13341	4	34675	1	4689
13342	4	34677	4	4326
13343	4	34678	2	3482
13344	3	34679	2	1075
13345	5	34680	2	13656
13346	3	34683	6	13630
13347	2	34685	6	2406
13348	5	34687	7	9001
13349	4	34687	5	9001
13350	5	34688	5	13698
13351	4	34689	2	10589
13352	5	34694	1	12172
13353	3	34698	4	11247
13354	4	34700	4	13706
13355	5	34708	2	13695
13356	5	34709	4	13676
13357	5	34713	5	13257
13358	5	34715	5	13170
13359	5	34719	4	8110
13360	5	34724	4	11496
13361	3	34725	3	13441
13362	5	34727	5	13101
13363	5	34728	2	10142
13364	5	34730	6	41
13365	5	34731	5	13719
13366	5	34732	6	1104
13367	3	34737	5	13688
13368	3	34739	1	10156
13369	3	34739	5	10156
13370	4	34741	6	6465
13371	5	34743	2	12905
13372	5	34745	1	13726
13373	3	34746	7	11235
13374	4	34748	5	5558
13375	5	34750	2	10198
13376	5	34753	4	7156
13377	5	34754	4	13748
13378	5	34755	2	13753
13379	5	34759	1	13851
13380	4	34761	3	13779
13381	4	34764	1	13769
13382	5	34769	1	13771
13383	1	34771	6	11041
13384	4	34771	3	11041
13385	3	34781	5	13751
13386	4	34783	7	13808
13387	5	34784	2	3434
13388	4	34787	5	13847
13389	5	34789	3	13760
13390	5	34790	3	1317
13391	4	34791	2	10461
13392	5	34794	3	13766
13393	5	34796	3	11215
13394	5	34797	7	5057
13395	4	34798	7	13778
13396	5	34798	4	13778
13397	5	34799	1	13806
13398	4	34800	7	13018
13399	5	34801	2	13765
13400	5	34802	6	883
13401	5	34804	7	4137
13402	5	34806	3	1822
13403	4	34810	5	13852
13404	4	34811	2	13795
13405	5	34812	4	2838
13406	5	34815	6	1104
13407	3	34816	7	6987
13408	3	34824	1	680
13409	5	34825	2	1594
13410	5	34826	7	13812
13411	1	34827	6	1720
13412	4	34828	1	9653
13413	5	34828	7	9653
13414	3	34829	5	6276
13415	4	34832	7	11507
13416	5	34838	3	660
13417	5	34839	1	11710
13418	4	34842	6	13759
13419	4	34850	5	7093
13420	4	34851	3	8893
13421	5	34852	7	3838
13422	2	34853	1	9171
13423	5	34856	4	2917
13424	2	34859	6	5476
13425	3	34863	6	13837
13426	5	34865	5	1293
13427	4	34866	5	13855
13428	2	34867	4	13791
13429	3	34868	7	96
13430	3	34869	5	367
13431	4	34871	3	13850
13432	3	34872	5	12580
13433	5	34873	6	6076
13434	4	34874	7	13794
13435	5	34876	2	4911
13436	5	34885	2	13813
13437	5	34886	7	6798
13438	5	34888	6	6873
13439	5	34889	4	5506
13440	5	34890	4	13786
13441	5	34893	5	13745
13442	5	34895	1	13831
13443	4	34904	4	10679
13444	4	34909	4	13796
13445	3	34910	4	7631
13446	4	34912	3	2050
13447	4	34914	7	11237
13448	2	34914	4	11237
13449	5	34915	4	8205
13450	5	34917	7	8747
13451	5	34924	3	6416
13452	4	34925	6	13788
13453	5	34927	2	1273
13454	5	34931	1	13797
13455	5	34932	7	8187
13456	4	34941	6	13824
13457	4	34942	7	10660
13458	2	34943	6	2470
13459	5	34948	3	3509
13460	5	34949	1	13773
13461	3	34952	1	13803
13462	5	34955	2	13789
13463	3	34956	5	12266
13464	5	34962	2	4213
13465	2	34965	7	7186
13466	4	34967	4	1582
13467	5	34971	6	11574
13468	4	34972	2	7125
13469	4	34973	5	13758
13470	4	34977	4	8106
13471	3	34984	2	6385
13472	3	34985	2	4605
13473	5	34986	5	9733
13474	3	34987	5	2023
13475	4	34990	4	13842
13476	3	34993	3	7050
13477	5	34994	7	1860
13478	4	34995	4	13836
13479	4	34997	6	2765
13480	4	34998	3	13804
13481	5	35000	6	13743
13482	5	35000	2	13743
13483	5	35004	6	11983
13484	5	35005	2	11596
13485	4	35005	4	11596
13486	3	35010	7	3944
13487	3	35013	7	8966
13488	5	35019	4	641
13489	5	35020	2	5939
13490	3	35021	1	13750
13491	5	35024	4	1543
13492	5	35028	6	2885
13493	5	35032	2	7021
13494	3	35033	7	154
13495	5	35035	2	9435
13496	3	35036	2	9081
13497	3	35038	7	10880
13498	5	35039	7	4846
13499	5	35041	6	13862
13500	4	35049	7	13962
13501	5	35051	2	13931
13502	4	35052	7	13894
13503	3	35055	5	13934
13504	4	35060	4	11763
13505	3	35061	7	7003
13506	4	35069	2	563
13507	5	35071	2	13976
13508	4	35072	2	10828
13509	3	35073	5	5289
13510	5	35079	4	8627
13511	5	35080	5	13876
13512	2	35089	6	11239
13513	3	35091	5	7028
13514	4	35098	4	13958
13515	5	35098	6	13958
13516	3	35103	5	5707
13517	5	35106	3	13935
13518	3	35108	6	7444
13519	3	35111	1	612
13520	5	35113	5	11444
13521	5	35116	7	5396
13522	5	35118	2	6090
13523	5	35121	3	13987
13524	5	35124	2	13988
13525	5	35125	4	13188
13526	3	35126	7	9783
13527	5	35127	6	13971
13528	5	35130	6	7058
13529	4	35132	7	7387
13530	5	35134	2	7050
13531	5	35135	1	1705
13532	3	35137	2	3298
13533	4	35139	7	10517
13534	3	35144	5	4631
13535	5	35147	6	5857
13536	5	35157	6	13872
13537	5	35162	6	13870
13538	5	35163	6	5297
13539	4	35167	6	4622
13540	5	35171	6	13865
13541	3	35172	1	5095
13542	5	35174	2	9716
13543	3	35180	1	13953
13544	1	35181	6	13929
13545	3	35182	6	13908
13546	5	35184	1	3165
13547	5	35185	6	11382
13548	3	35186	4	5440
13549	5	35188	6	13968
13550	5	35189	6	2647
13551	5	35190	3	11973
13552	5	35194	4	5385
13553	3	35196	4	11096
13554	5	35196	6	11096
13555	1	35197	6	13975
13556	5	35198	3	13036
13557	5	35202	5	2110
13558	2	35203	3	13974
13559	5	35206	1	4090
13560	5	35207	4	1156
13561	4	35213	7	13913
13562	5	35215	6	13956
13563	5	35217	4	2378
13564	4	35221	3	13900
13565	3	35222	3	7688
13566	2	35229	6	13899
13567	3	35233	5	9845
13568	5	35234	7	13544
13569	1	35235	6	13943
13570	4	35237	4	13903
13571	5	35238	6	7358
13572	4	35239	4	9420
13573	5	35244	6	7431
13574	4	35246	3	13927
13575	5	35248	2	3731
13576	5	35251	6	3534
13577	3	35254	5	10321
13578	5	35256	3	13965
13579	5	35263	2	10729
13580	4	35267	7	13941
13581	3	35267	1	13941
13582	1	35269	6	5714
13583	5	35270	6	11560
13584	4	35271	1	6729
13585	5	35273	7	13924
13586	5	35274	5	3332
13587	5	35278	6	6864
13588	5	35281	1	696
13589	5	35283	6	13959
13590	5	35288	6	10807
13591	5	35289	4	13914
13592	5	35290	2	13880
13593	4	35291	7	13905
13594	4	35301	6	13948
13595	4	35302	5	13888
13596	5	35304	2	6066
13597	5	35306	6	13504
13598	5	35313	1	8333
13599	5	35315	4	9645
13600	5	35318	4	10401
13601	5	35318	2	10401
13602	5	35319	3	13940
13603	1	35324	6	3776
13604	5	35325	2	13944
13605	5	35326	6	304
13606	5	35327	6	3688
13607	5	35330	6	5669
13608	4	35332	5	1902
13609	5	35333	2	2819
13610	5	35335	6	1316
13611	5	35337	7	13892
13612	5	35341	1	5301
13613	4	35342	6	12717
13614	5	35343	2	13966
13615	5	35344	4	13983
13616	4	35345	2	4607
13617	5	35347	6	10494
13618	4	35348	7	7510
13619	3	35349	7	7803
13620	4	35350	2	13907
13621	5	35351	5	788
13622	3	35353	4	11583
13623	5	35354	6	13921
13624	5	35358	4	13916
13625	5	35358	6	13916
13626	5	35362	4	5823
13627	5	35362	6	5823
13628	5	35368	6	271
13629	5	35375	6	13667
13630	5	35379	6	7641
13631	3	35382	7	11283
13632	5	35383	4	13984
13633	5	35388	4	13864
13634	3	35390	5	3211
13635	4	35395	3	6272
13636	5	35395	7	6272
13637	5	35398	4	14002
13638	5	35399	6	12823
13639	5	35400	2	9300
13640	4	35403	4	12993
13641	4	35404	5	6482
13642	4	35407	7	4846
13643	2	35410	4	9198
13644	5	35410	2	9198
13645	5	35413	2	6848
13646	5	35415	6	1313
13647	4	35417	2	1295
13648	4	35419	6	14072
13649	5	35421	6	12285
13650	5	35425	2	9913
13651	5	35427	2	6851
13652	4	35427	6	6851
13653	4	35430	7	9525
13654	4	35432	7	5767
13655	5	35433	6	11507
13656	5	35435	6	4836
13657	3	35437	5	13634
13658	5	35438	6	2337
13659	2	35439	1	14046
13660	4	35448	1	13991
13661	3	35451	7	4589
13662	3	35452	5	13586
13663	4	35453	7	14042
13664	5	35454	4	12274
13665	4	35456	7	5636
13666	5	35457	1	11465
13667	4	35460	2	5689
13668	5	35461	6	13993
13669	4	35463	5	14004
13670	4	35464	1	397
13671	5	35464	7	397
13672	3	35467	2	2556
13673	3	35471	6	14057
13674	5	35472	2	11401
13675	4	35479	7	7863
13676	5	35481	3	7169
13677	3	35482	5	2157
13678	5	35486	7	9685
13679	1	35487	6	8994
13680	5	35488	5	14084
13681	3	35493	1	2615
13682	3	35498	3	14009
13683	4	35503	6	9181
13684	4	35508	6	9850
13685	5	35510	6	13990
13686	5	35510	2	13990
13687	5	35512	3	2491
13688	3	35514	3	3417
13689	3	35515	6	14087
13690	1	35517	6	3784
13691	2	35520	3	1633
13692	5	35521	6	7912
13693	5	35523	4	5220
13694	4	35525	5	13992
13695	5	35526	6	14055
13696	5	35528	1	2669
13697	4	35529	6	2339
13698	4	35530	1	1839
13699	4	35532	5	14033
13700	5	35541	4	14083
13701	3	35542	1	11325
13702	5	35546	6	13999
13703	3	35550	3	12248
13704	3	35551	5	8609
13705	3	35554	7	14074
13706	5	35555	6	9816
13707	4	35556	5	5982
13708	5	35560	6	7293
13709	3	35560	1	7293
13710	5	35565	7	13989
13711	4	35568	5	13102
13712	3	35572	5	14039
13713	4	35573	6	3031
13714	4	35574	7	14048
13715	5	35575	2	14100
13716	5	35576	5	14030
13717	5	35578	6	1424
13718	5	35586	7	13106
13719	5	35587	6	6409
13720	4	35595	1	14060
13721	5	35596	5	1860
13722	5	35597	2	6182
13723	4	35601	2	2188
13724	5	35603	5	4170
13725	5	35604	4	14098
13726	5	35606	1	2080
13727	5	35609	2	9536
13728	5	35610	2	14067
13729	5	35611	4	11342
13730	5	35612	6	14021
13731	5	35613	6	3749
13732	4	35614	5	8394
13733	5	35618	7	5064
13734	5	35619	2	14082
13735	2	35620	1	6589
13736	5	35621	6	14041
13737	5	35622	2	14058
13738	4	35626	2	12954
13739	3	35627	3	861
13740	5	35628	2	8382
13741	3	35629	2	184
13742	2	35632	3	372
13743	4	35633	3	8720
13744	3	35636	5	617
13745	4	35641	6	14068
13746	5	35642	1	3451
13747	4	35645	2	5831
13748	5	35650	4	13502
13749	5	35651	7	6051
13750	5	35658	2	12053
13751	4	35662	5	3868
13752	5	35663	6	3131
13753	5	35667	5	14085
13754	5	35672	6	9956
13755	5	35674	6	12934
13756	5	35677	7	11219
13757	4	35679	3	7387
13758	1	35681	6	14092
13759	5	35682	7	14099
13760	4	35684	1	10721
13761	3	35686	7	5524
13762	3	35688	7	4116
13763	4	35690	2	1677
13764	5	35691	2	14073
13765	5	35695	1	14094
13766	5	35696	4	1207
13767	5	35699	6	9384
13768	5	35700	2	14000
13769	4	35701	1	8366
13770	3	35702	7	11150
13771	5	35703	6	14038
13772	5	35705	6	14022
13773	4	35705	5	14022
13774	4	35710	4	14031
13775	5	35711	1	14013
13776	5	35712	6	14007
13777	4	35714	7	8910
13778	4	35716	2	12099
13779	5	35720	6	14028
13780	5	35723	2	9732
13781	5	35726	5	14052
13782	5	35727	2	1618
13783	4	35732	5	7898
13784	2	35733	6	7768
13785	5	35736	6	1494
13786	3	35737	7	14023
13787	5	35739	1	3051
13788	3	35740	5	9780
13789	5	35747	1	11117
13790	2	35750	6	1144
13791	5	35756	6	14089
13792	3	35757	4	10284
13793	5	35758	2	14066
13794	5	35759	6	10651
13795	3	35762	7	14090
13796	5	35764	5	9356
13797	3	35768	6	1044
13798	5	35770	2	4281
13799	5	35772	6	14097
13800	4	35773	5	4764
13801	5	35776	4	2083
13802	4	35781	5	8484
13803	4	35783	1	3002
13804	4	35784	2	14015
13805	4	35784	1	14015
13806	4	35787	7	8068
13807	5	35797	6	13827
13808	5	35799	6	14051
13809	5	35800	4	7119
13810	4	35802	4	13474
13811	3	35804	2	4952
13812	3	35805	7	8590
13813	5	35807	7	14113
13814	5	35809	6	6376
13815	5	35814	2	11358
13816	3	35816	6	14138
13817	4	35816	1	14138
13818	5	35820	6	14160
13819	5	35822	3	7086
13820	3	35827	7	10368
13821	3	35836	1	2699
13822	5	35837	2	14109
13823	5	35843	1	12612
13824	3	35844	4	14111
13825	5	35851	6	14106
13826	4	35853	5	2310
13827	3	35854	3	5648
13828	4	35856	7	14195
13829	5	35861	5	5911
13830	5	35863	4	14132
13831	5	35866	7	7330
13832	4	35867	7	6498
13833	1	35868	6	14196
13834	4	35869	3	14163
13835	4	35873	7	14145
13836	4	35873	1	14145
13837	5	35875	3	2402
13838	5	35876	5	4077
13839	5	35877	2	14119
13840	5	35877	1	14119
13841	5	35881	7	14117
13842	3	35882	5	14174
13843	2	35890	1	13274
13844	5	35891	7	5180
13845	5	35892	6	2684
13846	4	35893	1	14179
13847	1	35895	6	14141
13848	5	35896	7	14202
13849	5	35897	3	14178
13850	4	35902	7	9362
13851	5	35903	4	2753
13852	3	35910	7	10783
13853	5	35911	4	786
13854	4	35912	7	9300
13855	5	35914	6	11083
13856	5	35915	1	37
13857	5	35918	3	9325
13858	5	35919	1	10702
13859	4	35924	5	3363
13860	5	35926	6	14172
13861	4	35928	7	12057
13862	4	35934	4	14104
13863	5	35935	5	2303
13864	4	35936	3	2443
13865	1	35940	5	13041
13866	5	35942	3	14102
13867	4	35943	7	14140
13868	4	35945	2	4546
13869	3	35949	1	1427
13870	5	35951	2	1679
13871	3	35952	3	10175
13872	5	35953	6	2003
13873	5	35959	1	3155
13874	5	35959	5	3155
13875	5	35960	5	6302
13876	4	35961	4	4646
13877	3	35966	5	8240
13878	5	35968	2	13643
13879	5	35969	7	10418
13880	5	35969	6	10418
13881	1	35970	6	14183
13882	4	35972	5	9908
13883	5	35973	5	14186
13884	5	35974	2	1317
13885	4	35976	5	14127
13886	5	35979	6	9994
13887	4	35979	4	9994
13888	4	35980	7	14168
13889	4	35981	7	12204
13890	5	35982	5	3932
13891	5	35983	1	2507
13892	4	35988	6	14182
13893	5	35989	6	14031
13894	5	35991	4	3040
13895	5	35993	6	4397
13896	3	35994	3	14153
13897	4	35995	7	8955
13898	4	35995	1	8955
13899	5	35996	6	4652
13900	5	35998	7	14207
13901	5	36005	6	10221
13902	3	36007	5	7943
13903	3	36009	2	10622
13904	5	36012	2	1563
13905	5	36014	6	14287
13906	5	36014	4	14287
13907	5	36026	1	13257
13908	5	36028	3	6987
13909	5	36029	7	7444
13910	5	36030	1	11491
13911	5	36035	6	2633
13912	5	36037	4	1993
13913	3	36040	7	14329
13914	5	36044	4	14294
13915	4	36045	2	14251
13916	5	36046	7	3804
13917	5	36048	3	9061
13918	2	36049	6	14260
13919	3	36051	4	2072
13920	4	36068	5	14317
13921	3	36072	5	1156
13922	4	36075	7	6075
13923	5	36077	6	14221
13924	5	36079	2	14254
13925	4	36081	3	1594
13926	5	36085	6	14315
13927	5	36086	5	14288
13928	5	36087	4	684
13929	4	36090	3	3864
13930	3	36092	5	9671
13931	4	36093	7	640
13932	5	36095	2	2916
13933	4	36096	5	14257
13934	3	36098	7	1818
13935	5	36100	5	14244
13936	4	36101	3	7888
13937	4	36108	6	14311
13938	4	36110	7	14255
13939	5	36111	6	14219
13940	4	36118	5	3958
13941	5	36118	4	3958
13942	5	36121	6	14302
13943	4	36122	3	10791
13944	4	36123	2	14209
13945	3	36124	7	6472
13946	5	36124	2	6472
13947	5	36130	6	14228
13948	1	36132	4	891
13949	1	36137	4	14292
13950	4	36137	3	14292
13951	3	36141	3	8718
13952	5	36143	7	14249
13953	4	36147	7	5170
13954	5	36151	6	3000
13955	1	36156	6	14234
13956	4	36158	7	10235
13957	5	36159	5	14285
13958	4	36162	7	12725
13959	4	36163	3	14230
13960	4	36163	5	14230
13961	5	36166	4	1579
13962	4	36168	7	10429
13963	5	36169	6	5192
13964	4	36175	7	14286
13965	5	36177	6	12282
13966	5	36178	2	3127
13967	2	36184	5	14248
13968	5	36185	4	6901
13969	3	36189	1	7564
13970	3	36190	6	2706
13971	5	36195	1	1910
13972	5	36198	1	9878
13973	1	36199	6	10542
13974	5	36200	2	11261
13975	5	36204	1	2310
13976	5	36205	5	5431
13977	5	36209	6	14310
13978	5	36210	4	14290
13979	5	36212	4	14322
13980	3	36213	7	13636
13981	5	36214	4	14306
13982	4	36216	7	14281
13983	5	36217	1	14269
13984	5	36220	1	2512
13985	3	36223	5	14305
13986	3	36224	1	7853
13987	5	36225	6	9244
13988	4	36226	2	14277
13989	5	36230	4	5472
13990	5	36234	7	172
13991	5	36236	6	14300
13992	5	36247	1	8595
13993	5	36248	2	14253
13994	5	36249	5	4342
13995	5	36250	6	4429
13996	5	36251	7	2193
13997	5	36256	6	8642
13998	4	36257	1	1314
13999	5	36262	1	4309
14000	3	36268	3	7777
14001	5	36269	2	8737
14002	5	36271	2	14382
14003	5	36273	6	14333
14004	3	36274	3	14420
14005	5	36275	7	14397
14006	5	36276	5	12129
14007	5	36278	4	14408
14008	4	36279	7	730
14009	5	36280	4	14414
14010	5	36283	1	3350
14011	5	36284	2	14395
14012	3	36285	3	295
14013	3	36293	1	10706
14014	5	36294	1	6328
14015	4	36296	4	14406
14016	5	36297	6	14357
14017	5	36298	1	14386
14018	5	36301	6	3565
14019	5	36302	3	14407
14020	4	36303	2	10312
14021	4	36305	5	14428
14022	2	36306	6	14337
14023	5	36307	7	5428
14024	5	36309	6	14376
14025	4	36309	5	14376
14026	5	36310	6	14373
14027	5	36312	1	14343
14028	5	36313	7	14411
14029	3	36314	1	5945
14030	4	36315	4	5048
14031	5	36319	1	12035
14032	5	36324	4	218
14033	5	36325	7	5979
14034	3	36328	2	14394
14035	5	36329	7	14368
14036	5	36331	6	13835
14037	3	36334	5	4095
14038	3	36338	5	5935
14039	5	36339	2	4112
14040	5	36341	6	11760
14041	4	36343	7	14398
14042	5	36344	6	14415
14043	5	36345	5	12835
14044	1	36346	5	32
14045	5	36347	1	14424
14046	4	36349	4	14354
14047	3	36350	1	14372
14048	5	36351	2	2940
14049	5	36353	2	5144
14050	4	36354	7	7815
14051	3	36354	1	7815
14052	1	36355	5	5642
14053	5	36356	4	5174
14054	5	36357	4	14410
14055	3	36358	3	14002
14056	4	36360	7	14365
14057	1	36361	6	14375
14058	4	36362	6	14349
14059	4	36363	4	11491
14060	1	36371	4	14388
14061	4	36373	3	1343
14062	3	36375	4	14346
14063	5	36376	3	1999
14064	2	36378	6	4837
14065	1	36380	5	5833
14066	3	36383	5	360
14067	5	36384	6	14381
14068	5	36385	6	14416
14069	4	36389	4	14377
14070	4	36390	6	12772
14071	4	36392	1	968
14072	2	36393	3	14335
14073	5	36396	7	14413
14074	5	36399	6	14352
14075	3	36401	7	10688
14076	3	36402	3	14350
14077	1	36405	1	14358
14078	5	36416	4	2418
14079	5	36418	5	161
14080	5	36419	7	4782
14081	4	36420	1	1344
14082	4	36427	7	14342
14083	4	36432	5	13065
14084	5	36434	4	14418
14085	5	36435	4	12542
14086	4	36437	2	4089
14087	5	36441	1	2619
14088	4	36442	6	6326
14089	5	36444	1	10647
14090	4	36446	7	14400
14091	5	36449	4	2729
14092	5	36451	4	563
14093	2	36456	6	5854
14094	4	36464	7	13080
14095	5	36465	7	5768
14096	4	36468	2	13208
14097	3	36469	4	14363
14098	5	36470	5	2770
14099	3	36472	1	13535
14100	1	36474	5	13181
14101	5	36474	4	13181
14102	5	36478	7	14431
14103	4	36480	5	10902
14104	4	36487	7	8674
14105	1	36490	6	14332
14106	5	36497	2	1509
14107	4	36498	3	4326
14108	4	36500	5	2633
14109	5	36503	6	10408
14110	5	36508	3	14391
14111	4	36513	3	14393
14112	1	36514	6	5928
14113	5	36515	4	10676
14114	5	36516	7	9265
14115	1	36521	6	2208
14116	4	36522	5	7968
14117	5	36524	6	220
14118	4	36527	1	14522
14119	4	36528	2	14306
14120	4	36531	6	7923
14121	5	36534	2	14500
14122	5	36536	3	2623
14123	4	36538	2	8832
14124	5	36543	4	14537
14125	5	36546	2	8655
14126	3	36549	5	10710
14127	5	36551	3	9554
14128	3	36553	5	11183
14129	3	36559	6	13840
14130	5	36559	2	13840
14131	5	36563	1	14481
14132	5	36565	7	1976
14133	5	36566	2	4363
14134	4	36567	5	3963
14135	5	36567	3	3963
14136	3	36576	7	12565
14137	3	36580	2	7019
14138	4	36582	7	4636
14139	4	36585	7	6826
14140	5	36586	4	4064
14141	3	36589	6	14461
14142	5	36591	7	14539
14143	5	36593	7	1749
14144	4	36596	5	11570
14145	4	36597	5	14530
14146	5	36601	4	13885
14147	4	36602	4	5527
14148	5	36603	2	13911
14149	5	36604	4	14484
14150	5	36612	1	8785
14151	5	36613	3	14506
14152	3	36615	2	4546
14153	5	36616	3	14511
14154	5	36616	5	14511
14155	5	36617	7	4243
14156	5	36623	3	14488
14157	4	36624	2	6854
14158	5	36629	7	7995
14159	3	36631	5	14517
14160	3	36637	5	14427
14161	2	36639	2	3227
14162	5	36643	1	14504
14163	4	36643	2	14504
14164	5	36645	6	14325
14165	5	36652	2	14516
14166	5	36653	6	14446
14167	4	36658	6	14501
14168	3	36660	1	7921
14169	3	36661	2	10566
14170	4	36663	4	12885
14171	5	36665	4	6565
14172	4	36666	7	3585
14173	5	36667	6	273
14174	5	36668	7	14449
14175	5	36671	2	13656
14176	5	36673	2	14508
14177	5	36674	1	14486
14178	5	36678	7	8176
14179	5	36679	4	11222
14180	3	36680	4	2275
14181	5	36681	2	2893
14182	5	36682	6	14498
14183	5	36686	4	4969
14184	4	36688	1	2691
14185	5	36690	1	1958
14186	5	36690	7	1958
14187	3	36694	1	5111
14188	5	36695	1	9695
14189	5	36699	2	14448
14190	5	36700	1	4161
14191	5	36703	7	9789
14192	4	36706	6	14439
14193	5	36707	4	12288
14194	4	36708	7	2884
14195	4	36712	3	1427
14196	3	36713	1	10717
14197	3	36714	2	4480
14198	5	36715	2	4381
14199	5	36716	6	11181
14200	5	36717	2	62
14201	4	36726	1	14471
14202	5	36726	4	14471
14203	4	36731	1	14531
14204	5	36733	6	4298
14205	4	36735	2	14495
14206	5	36736	3	1095
14207	5	36738	7	14525
14208	5	36740	2	487
14209	3	36743	4	8126
14210	5	36745	2	14529
14211	3	36750	5	3676
14212	4	36752	5	12698
14213	5	36753	7	14460
14214	5	36757	6	13692
14215	5	36764	1	9989
14216	5	36765	1	7338
14217	5	36767	4	14533
14218	3	36770	5	14492
14219	3	36780	6	11105
14220	3	36781	4	6779
14221	5	36785	7	7660
14222	4	36788	2	12549
14223	5	36789	3	14442
14224	4	36793	7	14490
14225	4	36795	2	8068
14226	5	36796	5	48
14227	5	36802	7	3487
14228	4	36805	7	14526
14229	4	36807	4	14476
14230	5	36807	7	14476
14231	5	36811	7	7421
14232	5	36811	3	7421
14233	5	36812	3	14463
14234	5	36813	2	12792
14235	4	36813	7	12792
14236	5	36817	6	14513
14237	4	36819	2	9571
14238	5	36820	7	2058
14239	3	36824	5	13974
14240	5	36831	6	6664
14241	1	36837	6	14552
14242	5	36838	5	3741
14243	5	36839	3	14554
14244	1	36840	6	12207
14245	5	36841	3	13498
14246	2	36843	4	14586
14247	5	36845	4	14616
14248	3	36856	3	14580
14249	5	36858	4	14571
14250	5	36859	7	1208
14251	4	36862	4	14666
14252	5	36865	2	1343
14253	5	36867	7	9969
14254	5	36869	7	14545
14255	5	36869	4	14545
14256	5	36870	4	2734
14257	5	36872	2	784
14258	2	36873	3	5933
14259	2	36880	6	3812
14260	5	36884	4	14597
14261	5	36887	1	14567
14262	5	36888	2	14027
14263	5	36891	6	11000
14264	5	36892	7	4802
14265	3	36893	1	4735
14266	5	36894	2	9107
14267	5	36897	2	1668
14268	4	36898	7	14611
14269	5	36899	2	8148
14270	5	36900	6	7131
14271	4	36901	7	14602
14272	4	36901	1	14602
14273	5	36902	6	8816
14274	5	36907	6	14631
14275	4	36915	7	13400
14276	4	36916	2	14651
14277	3	36918	3	5743
14278	5	36929	2	677
14279	5	36931	4	14630
14280	3	36931	7	14630
14281	3	36934	7	14613
14282	3	36935	5	1695
14283	3	36940	1	14609
14284	5	36941	1	5289
14285	5	36942	7	14628
14286	4	36946	2	14605
14287	2	36950	1	3403
14288	2	36953	3	9312
14289	5	36960	6	14587
14290	3	36963	7	13668
14291	3	36965	2	14314
14292	4	36974	7	1821
14293	3	36976	3	10444
14294	4	36978	5	1072
14295	1	36985	6	9568
14296	3	36985	5	9568
14297	4	36987	3	14624
14298	4	36990	6	3788
14299	3	36998	5	1344
14300	5	36999	2	14565
14301	5	37000	1	2228
14302	5	37006	6	14566
14303	5	37008	2	14632
14304	3	37010	4	12388
14305	4	37011	4	14590
14306	4	37012	7	3711
14307	5	37017	7	14627
14308	4	37021	2	14598
14309	5	37022	6	1626
14310	5	37025	4	14647
14311	1	37032	6	5599
14312	4	37037	7	3898
14313	5	37041	2	3621
14314	4	37045	7	9214
14315	3	37049	5	7620
14316	4	37050	4	14480
14317	5	37052	2	14638
14318	5	37055	3	3889
14319	4	37056	2	821
14320	4	37057	2	10273
14321	5	37060	1	14617
14322	5	37064	3	6301
14323	4	37066	7	4857
14324	5	37073	6	12664
14325	4	37074	7	12824
14326	5	37075	7	10032
14327	5	37076	6	14563
14328	3	37077	1	12805
14329	4	37078	1	4024
14330	5	37082	6	12345
14331	4	37085	7	5886
14332	4	37089	5	14582
14333	3	37092	4	11142
14334	5	37095	1	9069
14335	5	37096	5	14556
14336	5	37100	2	4841
14337	5	37102	7	14551
14338	5	37104	7	14770
14339	4	37105	4	9728
14340	4	37107	7	1570
14341	5	37108	5	304
14342	5	37111	6	4404
14343	5	37112	2	14738
14344	5	37115	4	8583
14345	5	37116	7	3395
14346	4	37118	6	3064
14347	5	37124	6	14731
14348	2	37125	3	14703
14349	5	37130	7	9072
14350	3	37135	6	13667
14351	4	37137	5	4069
14352	5	37139	3	14769
14353	5	37140	6	14175
14354	4	37143	5	10576
14355	4	37145	5	3509
14356	5	37147	5	14779
14357	3	37150	5	2630
14358	3	37153	7	14784
14359	5	37154	2	3636
14360	4	37157	2	8629
14361	5	37159	7	14720
14362	5	37160	2	8325
14363	5	37161	4	14732
14364	4	37161	2	14732
14365	5	37162	6	6609
14366	5	37163	7	14718
14367	5	37165	6	10264
14368	4	37166	3	13236
14369	5	37168	3	14692
14370	5	37169	2	6754
14371	5	37170	2	4937
14372	3	37171	6	14749
14373	4	37172	7	313
14374	5	37179	1	14763
14375	4	37180	5	14746
14376	5	37182	2	14758
14377	5	37184	6	9154
14378	3	37186	3	9990
14379	4	37189	3	179
14380	5	37190	6	7119
14381	5	37193	1	5090
14382	5	37198	7	11744
14383	3	37201	5	14768
14384	4	37204	3	14685
14385	4	37207	7	3570
14386	5	37211	3	7186
14387	5	37216	2	7216
14388	5	37219	4	1442
14389	4	37220	2	7387
14390	4	37221	2	13844
14391	5	37228	6	14724
14392	5	37229	7	14674
14393	5	37230	5	2413
14394	5	37233	6	14142
14395	5	37236	1	10553
14396	3	37241	2	14777
14397	3	37242	4	10640
14398	5	37244	3	14794
14399	5	37245	1	14742
14400	3	37251	7	11172
14401	5	37256	4	12532
14402	3	37258	1	14762
14403	1	37260	1	14717
14404	5	37263	3	7163
14405	5	37264	5	14662
14406	4	37265	2	3910
14407	5	37266	6	9616
14408	5	37272	3	12440
14409	3	37274	7	14781
14410	3	37275	5	13669
14411	5	37277	6	9677
14412	5	37277	5	9677
14413	5	37279	6	14744
14414	5	37279	5	14744
14415	4	37280	2	6941
14416	3	37282	7	14730
14417	5	37288	5	14715
14418	5	37290	7	13230
14419	3	37295	1	2908
14420	5	37299	6	14745
14421	5	37300	6	742
14422	5	37310	1	9103
14423	3	37311	6	14748
14424	5	37315	6	14680
14425	3	37315	5	14680
14426	5	37319	6	3012
14427	5	37320	6	1379
14428	5	37323	7	733
14429	4	37325	4	14766
14430	5	37326	2	1961
14431	4	37328	7	14773
14432	5	37329	2	8286
14433	1	37333	6	14765
14434	5	37333	5	14765
14435	3	37339	7	14747
14436	5	37342	5	14789
14437	4	37345	7	14686
14438	3	37346	2	14678
14439	5	37351	4	12942
14440	2	37353	1	14796
14441	5	37354	3	1555
14442	3	37355	2	575
14443	3	37356	3	14127
14444	5	37357	4	14719
14445	4	37357	5	14719
14446	4	37359	1	7603
14447	1	37361	2	14761
14448	5	37364	2	3414
14449	3	37367	4	1694
14450	5	37369	5	14723
14451	5	37370	6	11231
14452	3	37371	5	7815
14453	4	37375	5	14739
14454	4	37376	5	8403
14455	5	37378	6	3546
14456	4	37381	7	12647
14457	4	37382	5	14716
14458	5	37388	6	14709
14459	5	37390	3	14741
14460	2	37391	7	14695
14461	5	37392	4	13324
14462	5	37394	3	13613
14463	3	37397	1	10066
14464	5	37400	6	14800
14465	4	37401	2	14712
14466	3	37404	7	14090
14467	4	37409	6	4841
14468	5	37410	6	3711
14469	4	37411	7	9977
14470	3	37414	4	207
14471	5	37415	7	14728
14472	5	37416	2	9907
14473	5	37418	3	14702
14474	4	37421	1	1368
14475	5	37424	4	638
14476	5	37426	6	14354
14477	5	37428	2	7211
14478	5	37429	6	14743
14479	3	37430	1	7053
14480	3	37430	6	7053
14481	2	37431	7	5840
14482	5	37432	1	14721
14483	1	37438	7	10142
14484	4	37439	1	14689
14485	5	37440	6	14722
14486	5	37443	7	14736
14487	5	37444	6	14196
14488	3	37446	1	11582
14489	5	37447	7	14760
14490	5	37450	6	4370
14491	4	37454	7	3315
14492	4	37461	2	14759
14493	5	37464	6	6296
14494	3	37466	4	980
14495	5	37471	6	14870
14496	5	37471	5	14870
14497	5	37472	2	14805
14498	3	37476	4	6515
14499	4	37477	2	9053
14500	4	37478	2	8579
14501	3	37482	5	13907
14502	5	37487	7	12062
14503	4	37488	1	14867
14504	2	37491	6	14857
14505	5	37492	4	14897
14506	5	37494	7	14836
14507	5	37499	6	14803
14508	5	37504	6	8601
14509	4	37507	7	7887
14510	2	37508	6	7451
14511	3	37509	6	10914
14512	5	37511	7	3253
14513	4	37513	5	5730
14514	5	37513	6	5730
14515	4	37514	1	14821
14516	3	37519	4	11320
14517	4	37520	3	2630
14518	5	37521	6	14824
14519	4	37522	1	8128
14520	5	37525	2	10888
14521	5	37532	3	11908
14522	4	37532	5	11908
14523	3	37533	1	14814
14524	3	37536	5	14715
14525	5	37541	4	8457
14526	5	37542	7	2897
14527	5	37545	2	2995
14528	5	37553	6	14841
14529	5	37557	6	5886
14530	3	37559	3	11892
14531	4	37560	7	2497
14532	4	37561	2	12514
14533	4	37563	5	10122
14534	5	37564	2	10518
14535	4	37565	2	9516
14536	5	37567	3	14891
14537	5	37570	1	9513
14538	4	37571	1	4060
14539	4	37574	7	5427
14540	4	37575	1	12180
14541	4	37579	5	14924
14542	3	37581	1	14809
14543	5	37582	5	3997
14544	4	37584	6	8919
14545	5	37586	6	8670
14546	5	37587	7	12287
14547	3	37590	1	14869
14548	4	37591	7	14822
14549	5	37593	6	7530
14550	4	37602	5	8468
14551	5	37605	6	14862
14552	4	37605	7	14862
14553	3	37613	5	10461
14554	5	37624	4	14844
14555	4	37626	1	14833
14556	3	37628	4	10244
14557	4	37631	4	821
14558	5	37633	2	12907
14559	5	37634	3	14815
14560	3	37636	7	14900
14561	5	37638	4	8355
14562	5	37640	6	14853
14563	3	37641	1	14922
14564	4	37642	6	14812
14565	5	37643	6	3851
14566	4	37644	4	14879
14567	4	37652	1	14849
14568	4	37658	5	14892
14569	5	37659	4	14882
14570	5	37660	1	1023
14571	5	37661	2	2420
14572	3	37671	5	14911
14573	5	37672	6	14696
14574	3	37673	4	5668
14575	4	37680	3	14672
14576	5	37681	7	1970
14577	4	37682	1	14165
14578	4	37685	2	14865
14579	3	37687	5	5501
14580	2	37689	7	11867
14581	5	37691	7	4989
14582	4	37691	6	4989
14583	5	37694	4	8539
14584	5	37700	7	2907
14585	3	37702	1	14839
14586	5	37703	7	14820
14587	5	37704	3	1497
14588	5	37710	4	4912
14589	4	37715	6	12232
14590	5	37716	6	11163
14591	5	37723	2	6271
14592	4	37724	7	14899
14593	4	37733	4	13857
14594	5	37736	2	14902
14595	5	37738	4	14854
14596	5	37740	7	12222
14597	3	37743	7	13764
14598	5	37744	6	14828
14599	5	37745	2	7766
14600	5	37746	5	3679
14601	4	37747	7	14806
14602	5	37748	6	1170
14603	2	37749	1	7957
14604	3	37749	5	7957
14605	5	37751	4	775
14606	3	37752	7	11215
14607	5	37756	7	13770
14608	5	37764	6	7370
14609	3	37765	4	9869
14610	4	37767	4	4233
14611	5	37770	4	9665
14612	5	37774	7	14810
14613	5	37776	6	251
14614	1	37781	6	14866
14615	5	37782	7	6737
14616	5	37783	6	10222
14617	3	37784	7	14835
14618	1	37785	6	8687
14619	5	37786	7	14807
14620	5	37789	6	3048
14621	5	37791	4	14818
14622	3	37794	2	1127
14623	2	37795	6	1846
14624	5	37798	2	14883
14625	4	37800	6	14896
14626	3	37801	5	12770
14627	5	37803	4	12081
14628	5	37804	2	9603
14629	3	37805	5	887
14630	5	37808	7	3810
14631	3	37808	3	3810
14632	2	37809	4	12681
14633	3	37812	4	14929
14634	5	37813	2	6441
14635	4	37815	3	14887
14636	2	37817	4	9304
14637	1	37818	6	3212
14638	5	37820	1	10196
14639	3	37821	5	14906
14640	5	37824	5	9166
14641	4	37826	3	1306
14642	5	37828	6	12677
14643	4	37835	7	7308
14644	5	37836	7	14933
14645	1	37840	6	748
14646	5	37840	7	748
14647	5	37841	7	3965
14648	5	37842	6	14926
14649	5	37844	7	14831
14650	5	37845	6	11865
14651	5	37848	1	7206
14652	4	37849	5	2645
14653	4	37853	2	13060
14654	5	37854	2	14872
14655	5	37855	7	14875
14656	4	37857	7	14895
14657	4	37864	4	14813
14658	5	37866	2	8986
14659	3	37869	5	14859
14660	3	37870	5	5772
14661	5	37871	4	2308
14662	3	37877	5	11094
14663	5	37880	6	7894
14664	5	37886	1	2367
14665	3	37888	5	5584
14666	3	37890	7	3041
14667	5	37893	1	7420
14668	4	37894	7	1450
14669	5	37896	3	3459
14670	5	37899	6	15041
14671	4	37900	2	5880
14672	4	37901	2	5571
14673	5	37902	1	1529
14674	5	37903	5	1289
14675	1	37904	6	15032
14676	5	37908	6	10799
14677	5	37911	6	13930
14678	4	37914	1	15031
14679	3	37916	5	7510
14680	5	37918	3	14940
14681	4	37918	2	14940
14682	5	37919	6	15042
14683	2	37920	6	14997
14684	5	37922	2	5024
14685	4	37923	5	8561
14686	4	37925	4	13507
14687	5	37928	6	14962
14688	1	37930	6	14990
14689	5	37933	3	3033
14690	4	37934	3	11311
14691	5	37935	6	14949
14692	5	37935	3	14949
14693	5	37936	5	14942
14694	5	37938	3	2662
14695	5	37940	7	12330
14696	3	37942	2	13802
14697	3	37944	5	5641
14698	2	37949	6	4546
14699	1	37953	5	13294
14700	4	37955	5	3655
14701	5	37957	1	2611
14702	5	37958	3	15028
14703	5	37959	5	13202
14704	3	37963	1	15015
14705	5	37964	7	8273
14706	4	37965	7	536
14707	5	37966	1	13528
14708	5	37970	4	11686
14709	1	37971	6	7770
14710	5	37973	2	5527
14711	3	37976	5	8777
14712	5	37978	1	4589
14713	5	37981	6	14943
14714	4	37984	2	14968
14715	4	37990	6	11560
14716	4	37991	5	12130
14717	5	38000	4	3701
14718	5	38010	6	3210
14719	3	38011	7	15009
14720	4	38013	4	2200
14721	5	38014	3	8052
14722	5	38020	2	1257
14723	3	38021	5	15027
14724	4	38021	1	15027
14725	4	38022	5	14979
14726	5	38022	1	14979
14727	5	38023	2	4607
14728	5	38027	7	14992
14729	5	38032	6	3629
14730	5	38033	5	11798
14731	3	38046	7	14957
14732	5	38050	6	13927
14733	5	38054	1	736
14734	2	38056	3	2446
14735	5	38060	3	14879
14736	4	38062	5	2140
14737	5	38063	2	9817
14738	4	38065	4	9855
14739	5	38067	7	1913
14740	3	38068	3	9361
14741	1	38070	4	15037
14742	5	38074	1	15000
14743	5	38075	2	15018
14744	4	38081	5	8041
14745	4	38082	7	2440
14746	4	38083	7	15179
14747	5	38084	6	15070
14748	3	38085	2	15077
14749	4	38086	1	15181
14750	1	38089	6	15096
14751	5	38090	6	4498
14752	4	38092	3	15082
14753	5	38093	1	10583
14754	3	38095	2	15119
14755	5	38095	7	15119
14756	3	38096	1	15080
14757	1	38098	6	7303
14758	5	38099	3	15053
14759	5	38100	7	15103
14760	5	38101	3	15065
14761	3	38103	4	5138
14762	5	38104	5	10469
14763	3	38105	2	8719
14764	5	38107	6	15142
14765	5	38109	7	11232
14766	5	38113	2	15160
14767	5	38118	2	15191
14768	5	38119	7	15054
14769	5	38122	6	11495
14770	1	38123	6	15161
14771	5	38129	2	3370
14772	4	38130	7	12297
14773	5	38132	6	2717
14774	5	38137	3	4440
14775	5	38138	7	11089
14776	5	38141	6	15104
14777	4	38146	2	14174
14778	4	38147	1	12631
14779	5	38149	4	15117
14780	3	38150	5	13837
14781	5	38159	7	3392
14782	4	38160	7	293
14783	5	38161	2	73
14784	5	38162	4	8025
14785	3	38166	5	10772
14786	4	38171	2	9813
14787	5	38175	3	10854
14788	5	38176	4	15149
14789	5	38176	6	15149
14790	5	38177	2	12518
14791	5	38179	2	601
14792	4	38180	5	15095
14793	4	38186	3	6396
14794	4	38188	6	10331
14795	5	38190	4	15144
14796	4	38192	1	295
14797	4	38193	7	1727
14798	3	38195	7	10154
14799	5	38195	6	10154
14800	5	38196	2	11039
14801	1	38197	6	15093
14802	3	38200	5	15121
14803	5	38202	6	6221
14804	5	38204	7	15134
14805	4	38210	4	2319
14806	3	38212	6	15173
14807	2	38216	6	15114
14808	5	38217	4	15088
14809	5	38219	4	14632
14810	5	38219	2	14632
14811	5	38221	1	1287
14812	2	38222	6	11023
14813	3	38223	5	9833
14814	5	38224	7	15069
14815	3	38231	5	15094
14816	5	38232	2	3976
14817	3	38235	1	8275
14818	5	38235	4	8275
14819	5	38239	7	6682
14820	5	38242	2	1810
14821	5	38244	7	15136
14822	1	38246	2	9073
14823	4	38248	4	15172
14824	4	38250	1	15128
14825	4	38251	4	8161
14826	4	38251	2	8161
14827	5	38252	7	10770
14828	5	38252	2	10770
14829	4	38255	4	13634
14830	5	38256	1	5570
14831	3	38256	3	5570
14832	5	38258	6	3446
14833	5	38259	6	2984
14834	5	38261	6	9021
14835	4	38265	5	8273
14836	4	38270	6	15113
14837	4	38271	2	8628
14838	5	38272	6	3221
14839	5	38274	2	11124
14840	5	38275	6	2653
14841	5	38276	4	15084
14842	5	38277	1	15163
14843	5	38281	2	13004
14844	1	38285	6	14555
14845	5	38285	2	14555
14846	3	38291	5	7350
14847	3	38292	1	6591
14848	3	38293	7	9733
14849	3	38293	5	9733
14850	5	38294	7	15090
14851	4	38295	1	8394
14852	5	38298	5	15062
14853	3	38299	1	4021
14854	4	38302	7	4836
14855	3	38303	7	15059
14856	4	38306	7	13267
14857	4	38307	5	4922
14858	5	38311	6	15131
14859	5	38318	5	15182
14860	4	38322	7	15127
14861	4	38323	6	2951
14862	4	38326	3	13467
14863	4	38328	3	15145
14864	5	38329	7	2401
14865	5	38329	3	2401
14866	4	38330	6	15167
14867	5	38331	2	15125
14868	5	38332	6	14944
14869	4	38339	5	7454
14870	4	38347	6	6675
14871	5	38354	2	1944
14872	4	38355	7	7796
14873	5	38356	2	11339
14874	4	38356	7	11339
14875	3	38360	3	10254
14876	5	38363	6	3878
14877	5	38365	4	6324
14878	5	38366	6	15303
14879	3	38367	3	4960
14880	4	38372	3	9575
14881	5	38380	3	3021
14882	3	38382	2	9017
14883	5	38383	7	15279
14884	5	38384	6	15233
14885	5	38385	2	3949
14886	4	38386	6	5311
14887	5	38388	2	8561
14888	5	38389	6	13614
14889	4	38391	5	2862
14890	4	38393	1	13758
14891	5	38397	2	12823
14892	3	38400	7	15270
14893	5	38404	6	9823
14894	4	38406	7	2272
14895	5	38407	5	15215
14896	5	38411	2	3314
14897	5	38412	4	6430
14898	5	38412	3	6430
14899	5	38415	6	9071
14900	4	38421	5	5723
14901	5	38422	7	15286
14902	5	38431	2	12187
14903	5	38433	1	15228
14904	5	38434	6	15273
14905	3	38439	7	15281
14906	4	38440	2	15203
14907	5	38441	4	13651
14908	4	38445	3	12849
14909	4	38446	1	6156
14910	5	38448	2	766
14911	5	38450	6	13929
14912	4	38451	4	15310
14913	5	38452	2	13391
14914	5	38461	5	15197
14915	5	38463	6	6282
14916	4	38465	2	15285
14917	5	38466	6	1761
14918	3	38467	1	2383
14919	5	38468	1	3659
14920	3	38474	7	15255
14921	5	38475	5	14364
14922	3	38476	5	15256
14923	5	38477	7	15218
14924	5	38478	3	8919
14925	5	38479	4	177
14926	3	38482	7	15205
14927	4	38483	2	6056
14928	5	38488	1	815
14929	5	38490	5	9158
14930	5	38491	3	15288
14931	5	38494	3	6389
14932	5	38495	4	15250
14933	5	38502	3	2227
14934	3	38503	5	15307
14935	3	38505	5	15217
14936	3	38506	4	12050
14937	5	38507	2	12110
14938	3	38510	1	3091
14939	3	38517	6	11316
14940	4	38518	7	11943
14941	4	38523	7	11919
14942	3	38525	5	7648
14943	5	38527	6	10825
14944	5	38528	3	15219
14945	5	38529	6	13955
14946	4	38530	7	15268
14947	5	38531	2	15312
14948	5	38532	6	4712
14949	4	38534	2	15263
14950	3	38535	5	468
14951	4	38536	3	13737
14952	3	38537	7	2392
14953	5	38540	6	15292
14954	3	38550	7	12210
14955	5	38551	6	15220
14956	5	38554	6	3736
14957	3	38555	3	15276
14958	5	38557	6	9404
14959	5	38558	6	10442
14960	5	38559	7	15308
14961	3	38562	5	15232
14962	3	38564	3	15192
14963	5	38565	1	15299
14964	5	38569	6	6624
14965	4	38574	5	11953
14966	5	38576	5	15302
14967	4	38580	6	15275
14968	5	38584	2	10268
14969	3	38590	7	802
14970	1	38591	6	3002
14971	5	38593	4	15238
14972	3	38594	5	14190
14973	5	38595	2	3507
14974	5	38596	6	15258
14975	5	38598	5	11891
14976	4	38599	3	5857
14977	5	38602	7	752
14978	5	38603	5	15251
14979	5	38604	6	15294
14980	4	38606	5	15236
14981	1	38607	6	3341
14982	5	38609	2	15261
14983	5	38612	6	15274
14984	5	38614	6	5074
14985	4	38617	2	15293
14986	5	38619	6	339
14987	4	38626	7	1892
14988	4	38627	6	4204
14989	5	38630	2	5138
14990	2	38631	4	15432
14991	2	38632	1	688
14992	4	38633	3	15396
14993	4	38639	7	15374
14994	2	38642	3	15401
14995	5	38647	1	8093
14996	3	38648	7	3393
14997	5	38655	4	389
14998	5	38657	2	15314
14999	3	38661	1	4451
15000	4	38664	7	5236
15001	5	38667	6	7542
15002	3	38668	5	13624
15003	3	38670	5	15400
15004	5	38671	2	15351
15005	5	38672	6	15375
15006	5	38678	7	15323
15007	4	38685	6	3571
15008	4	38686	7	15368
15009	5	38688	2	1259
15010	4	38691	1	4788
15011	3	38695	5	2771
15012	3	38700	6	9128
15013	4	38702	2	12605
15014	5	38703	7	15433
15015	5	38707	5	8012
15016	5	38712	2	7790
15017	5	38715	4	5597
15018	5	38716	4	9482
15019	5	38719	1	15385
15020	5	38721	2	3542
15021	3	38722	5	12760
15022	5	38724	7	15145
15023	5	38728	6	15422
15024	3	38729	2	9733
15025	5	38731	6	11525
15026	3	38734	5	4021
15027	5	38735	5	15367
15028	5	38737	1	2440
15029	4	38742	5	15398
15030	4	38744	7	15035
15031	5	38745	7	2653
15032	1	38750	6	6965
15033	5	38759	7	15430
15034	2	38761	6	10582
15035	4	38764	2	15330
15036	5	38771	3	5099
15037	5	38778	5	15429
15038	3	38780	4	1549
15039	5	38780	3	1549
15040	5	38783	6	15350
15041	4	38787	1	15328
15042	4	38788	6	27
15043	3	38789	5	6885
15044	3	38792	3	7733
15045	5	38793	5	2921
15046	3	38794	2	15381
15047	5	38796	7	15334
15048	4	38798	5	5641
15049	5	38802	2	9906
15050	4	38804	6	15402
15051	4	38808	7	14602
15052	3	38811	4	13352
15053	5	38812	2	15324
15054	4	38813	3	15388
15055	4	38814	5	10653
15056	5	38816	5	15359
15057	5	38819	2	11146
15058	5	38821	6	15349
15059	5	38824	2	11679
15060	5	38827	4	4414
15061	5	38832	4	8224
15062	3	38835	3	13303
15063	5	38840	7	2584
15064	3	38841	1	5483
15065	5	38842	6	10755
15066	5	38843	1	15365
15067	5	38845	4	15397
15068	5	38847	4	7410
15069	3	38848	5	12248
15070	5	38848	2	12248
15071	4	38853	4	10303
15072	5	38854	1	4408
15073	5	38855	2	10590
15074	5	38856	2	10023
15075	5	38856	6	10023
15076	4	38857	7	12705
15077	5	38858	2	13987
15078	5	38859	7	15318
15079	4	38861	7	15335
15080	5	38863	2	15363
15081	5	38865	2	15415
15082	5	38865	1	15415
15083	5	38868	4	609
15084	5	38870	4	12590
15085	5	38871	7	15419
15086	4	38873	7	10295
15087	5	38875	1	6224
15088	4	38877	3	2523
15089	5	38881	4	8548
15090	5	38886	1	5699
15091	4	38890	1	13429
15092	5	38891	1	14610
15093	5	38894	7	9795
15094	4	38895	1	15329
15095	5	38896	7	11329
15096	5	38898	4	13128
15097	5	38900	2	15373
15098	5	38905	2	15341
15099	2	38906	4	9941
15100	5	38907	6	15354
15101	5	38908	4	3385
15102	2	38912	3	3998
15103	4	38916	4	15436
15104	4	38921	7	15417
15105	5	38922	5	15394
15106	5	38923	2	6877
15107	1	38924	6	7041
15108	4	38927	6	6811
15109	4	38934	7	7947
15110	3	38938	4	2919
15111	4	38940	7	8760
15112	5	38941	5	15456
15113	4	38945	3	15457
15114	5	38946	7	15493
15115	5	38948	2	15505
15116	3	38949	5	15509
15117	5	38954	2	1681
15118	4	38956	7	12636
15119	4	38960	2	8128
15120	5	38961	6	15477
15121	4	38962	1	12217
15122	3	38962	7	12217
15123	3	38963	3	6101
15124	5	38970	3	15475
15125	4	38976	3	15544
15126	4	38978	5	13283
15127	5	38979	6	15539
15128	5	38986	1	10646
15129	5	38988	2	3604
15130	5	38989	4	11254
15131	5	38991	1	4967
15132	5	38995	2	4008
15133	5	38997	5	15520
15134	5	38999	7	4938
15135	5	38999	5	4938
15136	1	39002	6	903
15137	4	39004	2	7772
15138	5	39013	6	11563
15139	4	39015	3	15482
15140	4	39016	3	15488
15141	4	39017	6	11479
15142	5	39018	6	13911
15143	5	39018	3	13911
15144	3	39019	1	15553
15145	5	39019	7	15553
15146	5	39024	5	1834
15147	4	39025	4	12345
15148	5	39027	1	5278
15149	4	39031	5	9738
15150	4	39033	5	15533
15151	5	39036	2	15201
15152	4	39039	7	5888
15153	5	39040	1	15470
15154	5	39042	6	8963
15155	5	39042	3	8963
15156	5	39044	4	4825
15157	5	39045	4	590
15158	5	39046	1	15565
15159	4	39048	5	11101
15160	5	39053	5	5160
15161	5	39054	3	10828
15162	5	39056	6	15478
15163	2	39059	1	3296
15164	5	39061	7	5419
15165	5	39062	3	4732
15166	5	39063	7	13038
15167	5	39066	5	15489
15168	4	39071	1	15541
15169	3	39072	4	11383
15170	5	39074	1	13559
15171	5	39077	3	15445
15172	5	39078	1	15464
15173	4	39079	3	1790
15174	5	39082	1	4215
15175	4	39084	3	197
15176	4	39086	7	5109
15177	5	39087	4	7083
15178	4	39088	1	9145
15179	4	39089	7	6851
15180	5	39092	7	10763
15181	3	39093	7	15452
15182	4	39098	7	15554
15183	5	39099	6	15546
15184	4	39101	4	3770
15185	1	39103	6	10908
15186	5	39106	4	15486
15187	5	39108	2	15549
15188	3	39113	4	507
15189	4	39120	5	13790
15190	4	39121	3	3931
15191	5	39126	4	15496
15192	3	39128	7	15484
15193	4	39128	3	15484
15194	3	39129	5	15563
15195	3	39130	3	15531
15196	5	39130	4	15531
15197	5	39131	4	14316
15198	5	39134	4	1656
15199	5	39136	1	15472
15200	5	39137	5	508
15201	5	39139	1	6886
15202	4	39143	1	15504
15203	3	39144	4	15479
15204	5	39145	2	15545
15205	4	39146	2	15466
15206	4	39147	4	5094
15207	5	39149	6	5329
15208	5	39150	2	15441
15209	5	39159	6	15498
15210	4	39163	3	9450
15211	3	39165	2	15476
15212	5	39167	7	15453
15213	4	39170	1	14281
15214	5	39171	5	15569
15215	4	39176	7	1375
15216	3	39177	3	15534
15217	4	39180	3	15558
15218	5	39181	7	15499
15219	4	39182	7	15491
15220	3	39185	5	13892
15221	1	39186	6	135
15222	5	39193	1	15514
15223	1	39196	6	15562
15224	1	39197	6	15573
15225	5	39197	2	15573
15226	5	39200	4	3135
15227	4	39202	7	13837
15228	5	39204	2	8448
15229	4	39212	5	4060
15230	5	39218	6	12732
15231	1	39221	6	15586
15232	5	39223	6	11955
15233	5	39224	2	9431
15234	3	39228	4	15724
15235	5	39229	6	15684
15236	4	39231	3	5550
15237	3	39231	7	5550
15238	5	39232	4	15648
15239	5	39237	5	9523
15240	3	39244	7	3943
15241	5	39251	1	15656
15242	4	39252	1	15585
15243	5	39253	7	15577
15244	4	39262	3	11694
15245	5	39265	1	7387
15246	4	39269	6	15670
15247	4	39273	6	4195
15248	3	39275	5	12169
15249	1	39276	7	2007
15250	3	39277	1	15604
15251	5	39278	5	15668
15252	5	39278	1	15668
15253	5	39281	6	419
15254	5	39282	5	15589
15255	5	39284	2	3634
15256	5	39285	3	15691
15257	3	39286	3	12285
15258	5	39290	6	15591
15259	5	39292	7	15603
15260	5	39295	6	11045
15261	5	39300	6	15690
15262	5	39302	4	4951
15263	5	39305	1	1044
15264	4	39307	6	9260
15265	5	39308	2	10394
15266	2	39309	6	7019
15267	5	39316	2	207
15268	5	39319	6	15661
15269	5	39320	4	3257
15270	5	39324	1	11788
15271	5	39328	6	15721
15272	5	39337	3	2050
15273	4	39340	2	15592
15274	5	39341	6	9296
15275	5	39346	2	4983
15276	5	39352	3	12636
15277	5	39352	6	12636
15278	5	39353	2	8812
15279	5	39356	4	2431
15280	5	39357	7	15609
15281	5	39361	2	8019
15282	5	39362	4	2995
15283	3	39366	4	15709
15284	5	39369	5	15640
15285	4	39370	2	11491
15286	5	39371	2	1914
15287	3	39373	5	15638
15288	3	39376	1	6198
15289	4	39384	4	15590
15290	5	39385	4	11806
15291	5	39387	6	15635
15292	4	39388	7	15621
15293	4	39390	1	6666
15294	1	39392	7	5064
15295	4	39394	6	15649
15296	4	39395	3	11095
15297	5	39396	4	15654
15298	4	39397	4	6923
15299	3	39398	1	15637
15300	5	39400	3	15653
15301	5	39403	1	14775
15302	4	39403	5	14775
15303	5	39404	6	1523
15304	5	39407	3	15687
15305	3	39408	3	15117
15306	2	39413	3	15584
15307	5	39416	1	12224
15308	5	39418	2	8235
15309	5	39419	4	908
15310	3	39430	1	788
15311	4	39435	6	9039
15312	5	39439	2	6333
15313	5	39442	7	15693
15314	5	39445	7	15646
15315	4	39449	3	1457
15316	4	39450	4	8981
15317	5	39451	2	5296
15318	3	39454	4	11237
15319	3	39455	1	15701
15320	5	39458	2	8455
15321	5	39459	7	15729
15322	5	39460	1	584
15323	4	39461	4	15588
15324	5	39462	3	9394
15325	3	39463	5	5106
15326	5	39465	3	8771
15327	3	39465	7	8771
15328	4	39467	7	15669
15329	4	39469	6	9525
15330	3	39472	6	2021
15331	5	39477	2	9053
15332	4	39478	2	12102
15333	4	39479	6	7131
15334	4	39487	5	15629
15335	5	39488	4	15579
15336	5	39489	2	1589
15337	3	39490	5	5950
15338	5	39492	5	15707
15339	5	39493	6	11779
15340	5	39494	6	15623
15341	5	39495	7	15605
15342	4	39496	3	15595
15343	5	39498	6	12579
15344	2	39499	3	9924
15345	4	39502	6	1373
15346	5	39505	6	15596
15347	5	39506	7	15666
15348	3	39507	2	6644
15349	4	39512	5	6142
15350	5	39513	2	15631
15351	4	39514	6	15725
15352	5	39515	7	15716
15353	5	39516	6	15658
15354	1	39517	6	12061
15355	5	39521	4	7192
15356	4	39521	2	7192
15357	5	39522	7	15677
15358	4	39525	1	15620
15359	4	39534	6	15626
15360	5	39535	4	3065
15361	3	39537	1	12464
15362	5	39538	1	15614
15363	5	39540	7	15371
15364	5	39542	2	10858
15365	5	39545	1	9749
15366	5	39547	7	15641
15367	4	39549	2	14073
15368	5	39551	4	7690
15369	4	39552	2	14773
15370	4	39553	1	11754
15371	4	39556	4	15651
15372	5	39557	4	7957
15373	5	39560	3	12348
15374	5	39561	6	15728
15375	5	39562	1	15578
15376	5	39562	5	15578
15377	2	39565	6	14369
15378	4	39566	6	15634
15379	5	39567	5	14389
15380	4	39568	3	15597
15381	4	39568	5	15597
15382	5	39571	7	12131
15383	5	39581	7	5020
15384	5	39584	4	13397
15385	4	39586	5	7919
15386	5	39589	4	15712
15387	5	39591	6	3935
15388	3	39592	5	13108
15389	5	39598	5	10425
15390	5	39601	3	12473
15391	4	39605	5	15760
15392	5	39606	6	1104
15393	5	39607	1	10575
15394	5	39610	5	15819
15395	3	39614	6	13172
15396	5	39615	2	7440
15397	4	39619	7	13023
15398	5	39619	6	13023
15399	5	39620	5	14920
15400	5	39622	4	403
15401	5	39627	2	8555
15402	5	39628	4	15459
15403	4	39630	1	7304
15404	3	39638	1	8813
15405	1	39640	6	15833
15406	5	39641	7	13185
15407	4	39644	7	15813
15408	3	39649	4	4825
15409	5	39651	2	15839
15410	4	39654	7	6301
15411	1	39655	6	4420
15412	3	39658	5	11564
15413	4	39660	7	13797
15414	3	39662	2	7774
15415	5	39664	2	5000
15416	4	39666	4	11595
15417	3	39668	7	9014
15418	5	39670	2	10505
15419	5	39671	2	14415
15420	3	39675	3	15829
15421	4	39676	6	8068
15422	5	39679	2	15810
15423	5	39679	4	15810
15424	5	39680	6	15846
15425	4	39683	1	6496
15426	5	39685	7	12880
15427	5	39687	4	5507
15428	5	39689	4	3398
15429	4	39690	5	4191
15430	4	39697	5	15808
15431	5	39699	7	7532
15432	5	39702	4	9103
15433	5	39703	3	15786
15434	4	39704	7	8397
15435	4	39705	5	15850
15436	5	39707	3	15806
15437	3	39709	5	11858
15438	3	39710	5	12034
15439	1	39713	6	6235
15440	5	39714	6	950
15441	4	39715	3	12457
15442	4	39717	7	873
15443	5	39718	7	15744
15444	3	39721	5	1666
15445	5	39723	2	1924
15446	3	39725	3	15782
15447	5	39728	4	10180
15448	1	39734	7	951
15449	3	39735	4	15787
15450	5	39736	6	2657
15451	5	39737	6	15845
15452	5	39739	4	1271
15453	5	39741	6	15789
15454	4	39744	4	15803
15455	5	39750	6	2517
15456	5	39751	4	15761
15457	5	39753	6	15831
15458	3	39754	3	15834
15459	4	39757	3	1176
15460	3	39759	4	8546
15461	4	39767	7	1518
15462	4	39769	1	11255
15463	4	39774	5	15743
15464	3	39775	7	1581
15465	5	39776	4	15797
15466	5	39777	7	12934
15467	4	39780	7	12760
15468	5	39783	1	15678
15469	4	39788	2	6145
15470	5	39789	6	6202
15471	3	39791	7	4517
15472	5	39792	2	6935
15473	5	39793	6	204
15474	3	39793	7	204
15475	5	39798	1	15843
15476	5	39801	6	10568
15477	3	39809	1	1813
15478	1	39812	6	11427
15479	4	39817	7	15765
15480	3	39817	3	15765
15481	4	39819	7	15777
15482	4	39827	6	15836
15483	5	39830	7	11560
15484	3	39834	7	11535
15485	5	39836	6	7731
15486	5	39837	2	1258
15487	5	39840	2	5654
15488	4	39841	1	15243
15489	5	39842	2	13713
15490	5	39844	5	5917
15491	3	39845	7	7204
15492	3	39850	6	15478
15493	4	39852	5	15820
15494	3	39853	7	15758
15495	4	39867	6	6139
15496	4	39867	4	6139
15497	3	39871	7	15823
15498	4	39875	7	13478
15499	5	39880	2	15781
15500	5	39881	7	15837
15501	5	39884	6	15853
15502	5	39887	2	15800
15503	5	39890	5	15747
15504	5	39892	2	707
15505	5	39893	2	778
15506	4	39894	2	15110
15507	5	39898	5	15822
15508	4	39899	5	15770
15509	5	39900	4	5795
15510	4	39902	2	7549
15511	3	39904	5	15793
15512	4	39908	6	15752
15513	4	39910	1	15824
15514	5	39912	6	7042
15515	5	39913	2	15780
15516	1	39913	3	15780
15517	3	39916	5	12409
15518	4	39922	7	3315
15519	3	39926	2	3388
15520	5	39931	1	4622
15521	4	39937	1	12541
15522	5	39938	2	15805
15523	4	39939	5	11020
15524	2	39940	1	5437
15525	5	39941	3	14819
15526	4	39945	2	15733
15527	3	39947	3	15807
15528	3	39949	3	9891
15529	5	39954	3	3031
15530	4	39955	5	15085
15531	5	39956	4	15768
15532	2	39957	4	1970
15533	5	39960	2	2311
15534	1	39965	4	13776
15535	5	39968	4	2771
15536	1	39969	6	15778
15537	3	39971	5	15814
15538	5	39976	2	4870
15539	5	39980	6	15852
15540	5	39981	6	15726
15541	5	39982	5	15759
15542	5	39989	1	6609
15543	5	39991	2	7959
15544	2	39991	6	7959
15545	5	39993	7	12823
15546	4	39995	7	4137
15547	4	39998	3	1609
15548	4	40000	1	1490
15549	4	40004	3	371
15550	5	40008	1	1832
15551	3	40013	1	3116
15552	3	40016	2	5112
15553	4	40017	7	15922
15554	5	40018	2	15779
15555	5	40024	7	1244
15556	2	40026	5	2629
15557	4	40030	2	15948
15558	4	40033	3	15885
15559	5	40033	7	15885
15560	4	40034	3	5844
15561	4	40035	4	9957
15562	4	40036	6	15911
15563	5	40040	4	6173
15564	4	40042	7	12150
15565	5	40044	6	4075
15566	5	40046	4	456
15567	5	40050	6	8583
15568	4	40051	7	15879
15569	5	40053	6	15953
15570	5	40058	2	15907
15571	5	40061	5	15958
15572	5	40061	4	15958
15573	4	40063	5	15936
15574	5	40064	2	15146
15575	5	40068	7	10058
15576	5	40069	3	2653
15577	5	40071	1	9727
15578	5	40071	2	9727
15579	5	40072	3	12106
15580	5	40072	1	12106
15581	3	40073	3	15909
15582	5	40074	6	15874
15583	4	40078	1	7228
15584	3	40082	3	15927
15585	5	40083	7	7527
15586	5	40084	3	12643
15587	5	40087	7	15876
15588	4	40090	5	6780
15589	4	40092	7	15861
15590	4	40096	6	15880
15591	3	40097	7	11367
15592	4	40098	1	15902
15593	3	40102	2	14470
15594	4	40103	6	15939
15595	5	40104	6	11908
15596	5	40106	1	10976
15597	1	40108	7	8437
15598	5	40114	5	11010
15599	4	40116	5	15857
15600	2	40117	4	14503
15601	5	40119	1	13583
15602	5	40122	4	15938
15603	3	40123	7	15858
15604	1	40125	4	9081
15605	5	40127	6	9771
15606	3	40131	7	10813
15607	4	40139	1	15905
15608	2	40140	6	10391
15609	4	40143	2	15964
15610	5	40145	2	15934
15611	4	40146	3	7543
15612	5	40147	7	507
15613	5	40147	6	507
15614	4	40151	4	15954
15615	5	40154	4	14679
15616	5	40157	1	15882
15617	2	40158	1	14935
15618	5	40160	2	15870
15619	4	40166	4	15919
15620	2	40167	6	15898
15621	5	40172	6	292
15622	4	40174	6	1723
15623	4	40175	7	15878
15624	5	40177	6	15925
15625	3	40179	3	7282
15626	5	40180	7	3929
15627	5	40186	4	5699
15628	5	40192	6	15914
15629	4	40195	6	15859
15630	5	40196	7	12823
15631	3	40197	6	15916
15632	5	40199	5	12148
15633	5	40205	4	15952
15634	5	40206	4	13649
15635	5	40210	1	5768
15636	5	40213	1	15944
15637	5	40215	3	15908
15638	4	40216	2	15872
15639	4	40217	5	11723
15640	5	40221	5	14431
15641	1	40222	2	15943
15642	2	40223	2	3421
15643	4	40224	7	16066
15644	5	40227	2	10717
15645	5	40229	1	15427
15646	3	40230	6	16038
15647	5	40234	6	3558
15648	5	40236	5	8380
15649	5	40239	7	9701
15650	4	40243	7	16093
15651	5	40244	7	16040
15652	5	40246	1	16027
15653	5	40248	5	11388
15654	4	40249	1	16039
15655	5	40250	7	2958
15656	4	40252	3	15990
15657	5	40253	2	16056
15658	5	40256	1	3945
15659	5	40257	4	9082
15660	5	40262	5	4562
15661	4	40264	7	16043
15662	5	40270	6	10354
15663	5	40270	4	10354
15664	4	40271	7	16019
15665	5	40273	3	16098
15666	4	40274	6	13481
15667	1	40275	6	8242
15668	5	40277	6	16096
15669	4	40278	4	16057
15670	4	40280	6	3065
15671	4	40284	1	16017
15672	5	40285	3	16006
15673	3	40290	5	13871
15674	4	40290	7	13871
15675	4	40291	7	16071
15676	2	40294	4	6600
15677	5	40298	4	7782
15678	5	40300	7	4913
15679	4	40300	4	4913
15680	5	40303	6	3187
15681	3	40304	7	16052
15682	5	40305	4	16059
15683	5	40307	2	11350
15684	4	40322	2	1921
15685	5	40331	3	8561
15686	4	40334	6	15144
15687	5	40335	6	13578
15688	5	40339	7	16092
15689	4	40340	5	4628
15690	5	40342	4	16002
15691	1	40342	6	16002
15692	3	40343	5	16077
15693	5	40344	7	44
15694	5	40352	1	16042
15695	5	40353	4	15978
15696	4	40354	4	15972
15697	1	40358	7	16015
15698	5	40361	4	1581
15699	5	40366	2	8521
15700	3	40371	7	16076
15701	5	40377	3	16007
15702	5	40379	1	7956
15703	5	40382	7	16088
15704	3	40388	2	16048
15705	5	40388	4	16048
15706	5	40391	3	15998
15707	5	40394	2	15977
15708	1	40398	6	11005
15709	5	40400	6	3439
15710	5	40403	2	7306
15711	5	40406	7	13482
15712	3	40408	3	1676
15713	5	40412	5	16046
15714	5	40415	2	14336
15715	3	40417	1	153
15716	5	40420	2	8043
15717	4	40420	5	8043
15718	4	40424	7	399
15719	3	40425	2	3477
15720	3	40429	3	16061
15721	3	40430	2	8019
15722	4	40432	2	15988
15723	4	40434	6	2611
15724	5	40437	2	16044
15725	4	40438	4	4560
15726	5	40440	5	11006
15727	5	40442	2	16227
15728	3	40443	5	4794
15729	3	40444	7	2228
15730	5	40446	5	16187
15731	5	40449	7	16152
15732	5	40449	2	16152
15733	4	40455	2	11921
15734	4	40455	5	11921
15735	3	40462	6	10841
15736	3	40463	1	13002
15737	3	40464	1	16190
15738	5	40468	2	7542
15739	3	40469	5	11642
15740	5	40470	6	14532
15741	4	40472	5	2
15742	3	40473	5	16150
15743	3	40475	5	14444
15744	5	40478	4	3784
15745	4	40481	3	5359
15746	4	40483	5	11735
15747	5	40485	6	16153
15748	5	40486	2	5939
15749	5	40487	2	16145
15750	5	40487	6	16145
15751	5	40489	1	16226
15752	4	40491	7	15171
15753	5	40492	6	16124
15754	5	40496	4	78
15755	3	40500	4	4701
15756	4	40504	5	16175
15757	3	40508	5	16205
15758	5	40509	5	7530
15759	5	40510	7	9965
15760	5	40514	4	5003
15761	5	40514	1	5003
15762	3	40515	2	2384
15763	5	40518	7	4694
15764	5	40518	4	4694
15765	5	40520	6	3631
15766	5	40521	1	14691
15767	5	40523	5	16106
15768	4	40525	4	3168
15769	4	40526	7	8625
15770	3	40528	2	7293
15771	5	40531	6	16212
15772	4	40533	5	4085
15773	5	40534	5	16148
15774	1	40535	6	11506
15775	3	40542	6	16182
15776	3	40544	5	16169
15777	2	40548	1	11140
15778	5	40549	6	7899
15779	4	40549	5	7899
15780	4	40550	6	16147
15781	5	40552	2	16133
15782	5	40556	2	12843
15783	5	40557	6	16220
15784	5	40558	6	16116
15785	4	40558	1	16116
15786	5	40559	1	16137
15787	5	40561	3	16122
15788	5	40564	4	7572
15789	5	40568	2	16219
15790	5	40571	5	6153
15791	4	40573	5	1293
15792	5	40574	7	12765
15793	3	40576	5	12287
15794	1	40578	6	11303
15795	3	40583	5	9044
15796	4	40584	4	62
15797	4	40590	5	4678
15798	4	40592	2	10729
15799	5	40592	5	10729
15800	4	40594	3	16171
15801	5	40595	3	5337
15802	5	40597	4	10249
15803	5	40600	5	16146
15804	5	40603	2	1424
15805	5	40604	4	7796
15806	4	40606	6	16221
15807	5	40610	3	12323
15808	5	40610	2	12323
15809	4	40612	1	16181
15810	4	40612	5	16181
15811	5	40615	5	4125
15812	5	40619	7	7001
15813	3	40623	7	3621
15814	3	40624	7	15720
15815	5	40624	5	15720
15816	5	40627	6	15286
15817	3	40629	5	5975
15818	5	40631	6	9610
15819	5	40635	3	3077
15820	5	40638	4	2630
15821	5	40640	5	1379
15822	5	40642	3	16130
15823	5	40644	4	4375
15824	5	40645	6	41
15825	4	40648	4	337
15826	5	40649	4	16136
15827	4	40651	7	16119
15828	5	40653	3	11760
15829	4	40654	1	16186
15830	4	40661	3	2965
15831	3	40665	1	8408
15832	4	40665	4	8408
15833	3	40667	7	8068
15834	4	40668	7	10870
15835	3	40672	1	16154
15836	5	40675	2	16184
15837	5	40675	7	16184
15838	5	40676	2	13864
15839	5	40680	2	16114
15840	5	40680	3	16114
15841	5	40683	5	16159
15842	5	40685	1	7782
15843	5	40686	7	16163
15844	5	40687	6	4367
15845	5	40692	2	12552
15846	5	40693	4	3856
15847	5	40695	6	16125
15848	4	40696	4	11630
15849	5	40697	4	798
15850	5	40698	5	8145
15851	1	40700	6	16200
15852	5	40703	1	14354
15853	5	40705	6	16104
15854	5	40707	5	7852
15855	5	40708	1	14566
15856	5	40713	4	16160
15857	3	40715	5	12760
15858	4	40719	4	14174
15859	5	40722	2	5110
15860	5	40725	6	7304
15861	5	40726	4	3761
15862	5	40727	2	16202
15863	4	40734	2	8607
15864	4	40735	4	293
15865	5	40737	2	16224
15866	5	40738	2	16179
15867	4	40740	7	9695
15868	2	40742	1	16180
15869	5	40743	2	12095
15870	3	40744	3	11014
15871	3	40747	2	2579
15872	4	40748	7	15153
15873	5	40751	2	10331
15874	4	40752	6	15230
15875	4	40758	5	16195
15876	4	40765	2	4380
15877	5	40768	2	8181
15878	5	40771	4	16254
15879	5	40775	6	11822
15880	3	40777	5	16277
15881	1	40778	1	14984
15882	5	40781	3	8763
15883	3	40782	6	7339
15884	3	40783	5	13948
15885	3	40785	1	8370
15886	5	40787	4	16286
15887	5	40789	5	10580
15888	4	40793	3	13942
15889	4	40794	7	1407
15890	4	40799	6	16354
15891	5	40801	5	9317
15892	5	40802	7	16236
15893	5	40803	6	16298
15894	2	40804	6	1489
15895	3	40806	6	5325
15896	5	40807	5	12334
15897	5	40810	7	1765
15898	3	40818	4	16276
15899	5	40821	6	16347
15900	5	40826	7	16269
15901	5	40826	2	16269
15902	5	40827	3	16295
15903	5	40829	4	6869
15904	4	40830	4	2187
15905	5	40830	6	2187
15906	5	40836	5	12911
15907	4	40839	5	553
15908	4	40842	5	6106
15909	5	40843	5	15037
15910	4	40844	2	14411
15911	5	40845	6	12522
15912	5	40849	6	16352
15913	4	40850	7	3382
15914	5	40857	7	15955
15915	3	40858	5	12999
15916	5	40862	3	507
15917	3	40869	1	16307
15918	3	40872	7	5824
15919	4	40873	5	11519
15920	5	40876	3	9457
15921	3	40877	3	6666
15922	5	40882	4	11287
15923	4	40885	7	16365
15924	4	40887	5	6542
15925	5	40891	4	16309
15926	3	40892	3	15829
15927	5	40894	6	3064
15928	5	40896	6	13944
15929	4	40903	3	11867
15930	4	40904	7	8684
15931	3	40905	5	11122
15932	5	40906	2	4766
15933	5	40907	3	16312
15934	3	40908	5	13000
15935	4	40908	7	13000
15936	5	40912	4	4787
15937	3	40915	3	16274
15938	5	40919	6	16346
15939	4	40920	5	16250
15940	5	40926	5	14963
15941	3	40927	3	4435
15942	3	40928	4	12236
15943	5	40928	6	12236
15944	4	40929	1	16342
15945	5	40932	1	2241
15946	4	40936	2	1674
15947	5	40939	7	11478
15948	4	40939	1	11478
15949	5	40940	4	4506
15950	5	40941	1	7615
15951	3	40942	5	8212
15952	5	40944	5	16324
15953	5	40950	1	16361
15954	5	40951	1	16323
15955	5	40953	6	6778
15956	5	40957	1	16247
15957	4	40961	4	87
15958	5	40962	2	7053
15959	5	40963	6	10892
15960	5	40965	2	7312
15961	4	40971	2	2875
15962	4	40975	5	6668
15963	5	40976	6	16237
15964	4	40976	2	16237
15965	5	40980	7	4263
15966	3	40983	5	16283
15967	5	40986	1	16304
15968	5	40988	1	1461
15969	5	40990	2	10090
15970	2	40991	5	16255
15971	4	40998	5	1810
15972	5	41001	5	16305
15973	5	41002	6	15679
15974	5	41002	7	15679
15975	5	41003	4	7441
15976	4	41004	1	16243
15977	2	41004	4	16243
15978	4	41006	2	3615
15979	5	41007	6	16291
15980	5	41013	1	16316
15981	5	41014	2	1592
15982	5	41015	1	11789
15983	4	41016	7	12687
15984	2	41016	4	12687
15985	3	41019	7	16345
15986	4	41020	7	9291
15987	5	41024	5	12852
15988	5	41025	5	3830
15989	3	41031	7	8057
15990	1	41035	6	14622
15991	5	41036	4	1676
15992	4	41038	1	14726
15993	1	41040	6	16287
15994	5	41041	7	16026
15995	3	41041	6	16026
15996	4	41043	2	154
15997	4	41045	2	688
15998	5	41046	2	128
15999	5	41047	4	16329
16000	5	41047	6	16329
16001	5	41050	1	12546
16002	5	41050	2	12546
16003	3	41053	3	12928
16004	5	41054	5	3864
16005	4	41057	3	3077
16006	3	41058	5	11181
16007	3	41061	4	14558
16008	3	41064	4	930
16009	3	41066	7	9906
16010	3	41068	5	16252
16011	3	41070	2	16339
16012	4	41074	5	16263
16013	5	41075	6	996
16014	5	41076	5	16364
16015	4	41082	2	10277
16016	2	41085	5	16349
16017	5	41087	2	5201
16018	5	41092	1	3557
16019	2	41093	1	16266
16020	3	41097	4	16325
16021	4	41101	3	1656
16022	5	41102	4	8538
16023	3	41103	5	12649
16024	5	41106	7	9974
16025	5	41108	6	4983
16026	5	41109	7	16340
16027	4	41110	1	11373
16028	5	41110	4	11373
16029	4	41113	5	16234
16030	5	41116	7	7622
16031	5	41117	7	16299
16032	5	41118	4	14668
16033	5	41119	5	1185
16034	5	41120	6	7813
16035	3	41123	5	16450
16036	5	41125	3	12823
16037	4	41127	7	5427
16038	5	41132	7	14202
16039	5	41134	4	16473
16040	4	41136	1	16471
16041	5	41140	7	3576
16042	5	41142	4	6817
16043	3	41145	6	12078
16044	5	41150	1	16439
16045	5	41151	5	2897
16046	5	41152	6	13828
16047	5	41153	2	7530
16048	5	41154	4	2200
16049	3	41155	2	6276
16050	5	41156	3	16344
16051	5	41157	7	16426
16052	3	41158	2	16449
16053	5	41159	4	16481
16054	5	41166	3	5110
16055	5	41166	7	5110
16056	4	41167	3	2575
16057	4	41169	7	16388
16058	4	41170	7	16482
16059	5	41171	5	10815
16060	5	41172	4	1715
16061	5	41174	6	7279
16062	4	41189	6	2062
16063	3	41192	1	9057
16064	4	41196	2	6901
16065	4	41199	6	16458
16066	5	41203	2	9303
16067	5	41204	4	6733
16068	4	41204	2	6733
16069	5	41206	4	3099
16070	3	41206	7	3099
16071	3	41207	3	5771
16072	5	41211	5	3493
16073	3	41214	5	16468
16074	5	41219	2	16387
16075	5	41230	1	16418
16076	4	41234	2	2997
16077	5	41236	5	16372
16078	4	41239	3	271
16079	4	41240	3	11152
16080	3	41241	5	16480
16081	3	41244	4	6097
16082	4	41245	7	14073
16083	5	41248	7	16464
16084	5	41249	3	16427
16085	5	41250	3	16443
16086	5	41252	1	16466
16087	5	41254	3	11418
16088	5	41256	4	13829
16089	5	41257	2	12229
16090	3	41263	7	6666
16091	5	41263	2	6666
16092	5	41267	5	351
16093	5	41268	5	16423
16094	5	41270	7	16148
16095	5	41271	2	2818
16096	2	41272	6	9096
16097	3	41273	4	2631
16098	3	41277	4	3659
16099	3	41280	7	3480
16100	4	41281	7	8982
16101	5	41282	1	7295
16102	5	41283	6	16111
16103	4	41287	4	1773
16104	5	41289	7	2706
16105	5	41299	3	16415
16106	3	41299	7	16415
16107	4	41300	5	14826
16108	5	41304	4	4210
16109	5	41307	1	13048
16110	5	41308	2	836
16111	5	41310	7	12546
16112	3	41311	4	5075
16113	5	41311	1	5075
16114	4	41315	7	16457
16115	4	41316	5	12827
16116	4	41319	7	16416
16117	5	41320	2	12942
16118	5	41329	6	16437
16119	4	41332	1	16389
16120	1	41334	6	12952
16121	5	41335	3	1231
16122	4	41337	7	14475
16123	5	41339	1	14227
16124	5	41343	1	12905
16125	4	41344	5	4556
16126	1	41346	6	4843
16127	3	41348	5	16397
16128	5	41349	2	4100
16129	5	41352	6	16379
16130	3	41355	5	16424
16131	5	41358	4	14125
16132	3	41360	1	7793
16133	5	41362	7	15041
16134	4	41363	1	458
16135	4	41365	4	4646
16136	5	41366	4	2278
16137	4	41367	7	975
16138	3	41368	1	16068
16139	5	41371	1	16410
16140	3	41375	3	2054
16141	5	41376	3	16455
16142	4	41376	6	16455
16143	5	41378	6	3256
16144	5	41380	4	16384
16145	4	41381	5	1228
16146	5	41384	4	14263
16147	4	41386	3	16386
16148	5	41388	6	16371
16149	5	41390	5	11739
16150	4	41391	5	16578
16151	5	41394	3	16532
16152	5	41394	2	16532
16153	3	41395	2	16627
16154	5	41398	7	5094
16155	3	41399	2	3155
16156	3	41400	6	10766
16157	3	41407	1	13885
16158	5	41408	7	4655
16159	5	41409	2	16620
16160	5	41411	5	16631
16161	3	41412	6	16619
16162	5	41416	2	16524
16163	2	41418	6	16506
16164	4	41418	2	16506
16165	5	41420	1	16529
16166	5	41424	1	5894
16167	5	41425	2	8506
16168	5	41429	6	16622
16169	3	41432	5	16530
16170	5	41434	5	15995
16171	5	41437	6	6104
16172	5	41438	6	16614
16173	3	41439	7	12224
16174	3	41441	4	8531
16175	5	41442	1	14847
16176	5	41445	2	9503
16177	4	41446	6	16501
16178	5	41449	7	7460
16179	3	41453	4	12519
16180	5	41458	2	203
16181	5	41460	7	16598
16182	3	41461	2	16642
16183	5	41463	6	16494
16184	3	41465	5	16580
16185	5	41468	2	8645
16186	3	41469	5	878
16187	5	41470	5	16485
16188	5	41471	1	6487
16189	5	41472	4	1876
16190	4	41479	7	4447
16191	4	41481	7	16544
16192	5	41484	7	820
16193	5	41486	6	12001
16194	3	41493	7	2513
16195	5	41495	1	16183
16196	2	41498	6	993
16197	5	41499	1	16556
16198	5	41501	3	4133
16199	5	41504	2	6848
16200	5	41509	2	5064
16201	4	41510	6	16607
16202	3	41511	1	6443
16203	4	41513	3	3096
16204	5	41515	4	14742
16205	4	41516	7	16603
16206	2	41520	6	3360
16207	5	41524	6	16562
16208	5	41527	2	1862
16209	3	41528	6	16617
16210	5	41528	2	16617
16211	5	41529	1	16495
16212	5	41533	5	6163
16213	4	41535	4	16579
16214	5	41539	1	6498
16215	3	41542	1	16629
16216	4	41543	7	16626
16217	5	41547	6	5964
16218	4	41548	2	16647
16219	1	41549	6	16531
16220	5	41551	4	13477
16221	4	41552	4	16534
16222	5	41554	4	5923
16223	3	41557	6	16621
16224	5	41558	3	5811
16225	3	41559	3	16561
16226	5	41562	7	3709
16227	2	41563	4	9073
16228	4	41564	5	12449
16229	5	41565	6	16613
16230	5	41570	2	16600
16231	4	41572	4	14941
16232	5	41575	4	16526
16233	5	41576	2	16596
16234	3	41579	3	5520
16235	5	41582	7	15852
16236	5	41587	2	16504
16237	3	41588	1	16625
16238	5	41589	1	16641
16239	5	41590	2	16515
16240	5	41591	2	15294
16241	5	41599	2	16584
16242	5	41602	6	16583
16243	5	41604	5	16587
16244	4	41605	5	13584
16245	3	41606	4	4287
16246	4	41607	5	16581
16247	4	41609	5	16541
16248	5	41612	1	10394
16249	4	41616	7	4339
16250	4	41617	7	8342
16251	5	41622	6	6251
16252	3	41623	2	16553
16253	2	41625	4	16548
16254	2	41627	4	1760
16255	5	41629	7	16606
16256	3	41631	2	1415
16257	5	41636	4	8640
16258	1	41638	6	16604
16259	4	41640	2	9115
16260	3	41646	5	16566
16261	4	41647	6	16609
16262	5	41649	2	2647
16263	5	41650	2	7204
16264	4	41652	7	16517
16265	5	41655	4	3099
16266	5	41659	5	12361
16267	3	41663	5	16588
16268	3	41665	4	16508
16269	3	41667	7	16540
16270	5	41667	6	16540
16271	5	41668	6	16499
16272	5	41669	2	13089
16273	5	41670	6	15576
16274	5	41672	5	16591
16275	5	41675	6	5311
16276	5	41677	2	15514
16277	5	41680	6	16594
16278	2	41683	3	16610
16279	5	41684	2	16648
16280	5	41686	4	5452
16281	5	41689	7	11104
16282	1	41690	6	16615
16283	4	41693	7	5117
16284	4	41694	7	16570
16285	3	41697	5	16634
16286	4	41697	3	16634
16287	5	41699	3	12984
16288	4	41701	5	3867
16289	5	41701	6	3867
16290	5	41704	1	16538
16291	5	41704	6	16538
16292	1	41705	6	6190
16293	3	41706	2	5035
16294	1	41710	6	16577
16295	5	41711	1	13275
16296	4	41714	6	15019
16297	4	41719	7	16638
16298	4	41726	7	16573
16299	2	41731	1	6075
16300	5	41731	5	6075
16301	5	41732	3	10066
16302	5	41733	2	1819
16303	4	41736	5	2876
16304	5	41737	1	332
16305	5	41738	7	6506
16306	5	41740	5	2780
16307	3	41741	7	16543
16308	5	41742	2	11534
16309	5	41743	6	12290
16310	5	41745	7	16507
16311	5	41747	7	4943
16312	5	41748	4	8098
16313	3	41749	7	10616
16314	5	41751	1	16635
16315	3	41752	5	691
16316	5	41753	2	163
16317	5	41757	1	16520
16318	4	41757	3	16520
16319	4	41759	2	5044
16320	5	41761	5	8828
16321	5	41762	2	5120
16322	5	41764	1	16567
16323	4	41765	1	13651
16324	5	41766	2	16574
16325	5	41770	6	6958
16326	3	41772	7	12758
16327	4	41773	7	16497
16328	5	41779	4	12846
16329	5	41781	4	16576
16330	5	41785	1	9197
16331	5	41787	1	7091
16332	4	41793	1	2041
16333	4	41795	3	16643
16334	5	41796	2	14792
16335	5	41800	5	314
16336	5	41801	3	11063
16337	5	41804	5	16741
16338	5	41809	4	16731
16339	5	41810	5	621
16340	3	41812	7	13844
16341	5	41813	7	3489
16342	4	41815	6	1424
16343	5	41819	4	16733
16344	5	41826	2	16746
16345	5	41829	2	15829
16346	4	41830	3	16628
16347	5	41831	5	5555
16348	5	41833	2	16627
16349	5	41834	6	16695
16350	4	41838	4	6022
16351	5	41838	5	6022
16352	5	41842	6	13097
16353	3	41844	5	9172
16354	5	41850	7	5830
16355	4	41859	5	7765
16356	3	41860	5	12129
16357	3	41862	2	16775
16358	5	41863	1	1174
16359	4	41864	4	15437
16360	3	41865	5	4593
16361	5	41866	5	13673
16362	4	41867	3	11859
16363	5	41868	1	8146
16364	5	41870	6	16442
16365	3	41871	4	15057
16366	4	41872	2	16342
16367	2	41873	6	9048
16368	5	41875	6	4313
16369	4	41882	1	5812
16370	4	41884	1	16429
16371	4	41889	5	6326
16372	4	41891	2	1968
16373	3	41892	3	3251
16374	4	41892	7	3251
16375	3	41894	2	15018
16376	4	41896	5	16771
16377	5	41898	5	11
16378	4	41900	2	14519
16379	5	41903	3	16777
16380	5	41906	7	16764
16381	5	41911	6	4007
16382	5	41915	6	16753
16383	5	41916	6	8629
16384	4	41917	3	16246
16385	4	41924	1	10883
16386	5	41926	7	16700
16387	4	41927	4	6941
16388	4	41928	4	16650
16389	5	41930	2	197
16390	5	41931	4	16254
16391	5	41933	2	8088
16392	4	41935	5	16744
16393	1	41936	6	16780
16394	5	41937	5	11518
16395	5	41938	6	2142
16396	5	41939	5	5960
16397	5	41941	5	2032
16398	5	41942	6	16694
16399	3	41944	7	16668
16400	4	41946	5	15096
16401	4	41954	5	8962
16402	3	41955	5	16671
16403	4	41957	5	16690
16404	5	41959	7	6869
16405	5	41960	6	7427
16406	4	41962	2	2477
16407	3	41966	1	786
16408	3	41967	4	466
16409	5	41968	6	16786
16410	5	41969	1	6509
16411	5	41972	2	15079
16412	4	41973	7	5159
16413	5	41975	4	16693
16414	4	41975	3	16693
16415	3	41977	2	16669
16416	5	41977	3	16669
16417	5	41980	3	10584
16418	5	41981	5	16709
16419	5	41982	4	16752
16420	4	41984	6	13087
16421	4	41985	7	16784
16422	4	41986	4	16706
16423	3	41986	3	16706
16424	5	41988	2	14256
16425	5	41991	3	16785
16426	5	41994	4	16736
16427	1	42000	2	6299
16428	5	42003	3	2055
16429	5	42006	2	7688
16430	3	42010	7	2081
16431	4	42015	5	4075
16432	4	42017	5	9194
16433	4	42018	7	439
16434	5	42023	2	15120
16435	3	42025	5	16721
16436	2	42028	3	5048
16437	5	42031	7	16686
16438	5	42034	1	16231
16439	5	42035	7	15110
16440	4	42036	7	16665
16441	2	42037	2	16680
16442	5	42039	6	14198
16443	5	42043	1	1731
16444	5	42044	3	6895
16445	3	42045	2	1924
16446	5	42045	6	1924
16447	5	42047	7	14067
16448	4	42049	2	1905
16449	5	42051	5	4595
16450	4	42053	7	10434
16451	4	42056	5	5310
16452	5	42061	6	8448
16453	3	42064	3	14701
16454	2	42064	1	14701
16455	5	42065	7	16630
16456	5	42066	5	6705
16457	5	42067	1	16712
16458	4	42068	3	3595
16459	5	42070	5	16666
16460	5	42071	4	16649
16461	3	42073	1	9728
16462	4	42074	7	7986
16463	5	42076	7	1996
16464	5	42079	2	1499
16465	3	42081	4	3624
16466	5	42083	1	16696
16467	1	42086	6	14068
16468	4	42088	1	12392
16469	3	42090	2	10106
16470	5	42092	5	16787
16471	5	42094	3	16657
16472	3	42096	2	16759
16473	5	42097	1	16778
16474	4	42097	5	16778
16475	5	42098	4	9737
16476	4	42104	3	16724
16477	2	42105	1	16659
16478	5	42107	4	16723
16479	4	42112	1	2686
16480	3	42113	4	10394
16481	5	42115	4	11156
16482	4	42121	7	16663
16483	5	42130	5	16730
16484	4	42131	3	15663
16485	5	42132	4	16661
16486	5	42137	5	6150
16487	3	42137	7	6150
16488	4	42138	7	16781
16489	2	42139	2	12184
16490	5	42142	7	16228
16491	5	42143	6	16683
16492	5	42145	1	1213
16493	5	42149	7	13773
16494	5	42151	3	16689
16495	2	42154	6	16340
16496	5	42158	6	2265
16497	2	42159	1	12236
16498	5	42165	3	654
16499	4	42172	5	16720
16500	3	42178	5	7327
16501	5	42181	4	8054
16502	5	42185	4	15614
16503	1	42190	5	5451
16504	5	42191	3	16738
16505	4	42195	7	16751
16506	4	42199	4	3579
16507	5	42200	7	14943
16508	1	42202	4	16688
16509	3	42206	6	16773
16510	5	42209	6	16654
16511	4	42209	3	16654
16512	5	42214	2	16749
16513	5	42216	1	16715
16514	3	42220	1	10003
16515	4	42226	6	16761
16516	5	42227	4	11495
16517	4	42231	7	16652
16518	5	42236	4	3961
16519	4	42237	4	3647
16520	4	42243	2	16685
16521	5	42244	2	7156
16522	5	42247	4	16754
16523	5	42251	3	5624
16524	2	42252	4	15594
16525	5	42253	4	1681
16526	2	42255	6	2556
16527	3	42256	3	2552
16528	5	42257	1	16766
16529	5	42258	6	2195
16530	5	42259	6	5324
16531	4	42266	5	3364
16532	3	42274	5	16867
16533	4	42277	7	16791
16534	5	42278	2	16870
16535	4	42281	1	698
16536	5	42284	5	16798
16537	5	42286	1	16803
16538	5	42292	2	3918
16539	4	42294	1	16834
16540	5	42296	4	16804
16541	5	42297	2	10235
16542	4	42299	7	16871
16543	5	42302	7	1837
16544	4	42303	1	6510
16545	4	42304	4	16127
16546	4	42309	3	10930
16547	4	42310	7	16831
16548	3	42311	3	950
16549	5	42313	2	16886
16550	3	42315	7	6701
16551	4	42322	2	2506
16552	5	42325	2	5742
16553	4	42331	6	6155
16554	5	42332	1	2440
16555	5	42334	4	13439
16556	4	42340	7	16802
16557	5	42343	7	6950
16558	3	42344	5	5325
16559	5	42345	4	16869
16560	5	42346	7	14216
16561	4	42348	7	6075
16562	5	42349	2	9859
16563	5	42351	2	14559
16564	5	42352	4	16863
16565	3	42355	5	379
16566	4	42358	3	11964
16567	5	42360	2	5930
16568	3	42362	5	16528
16569	5	42367	7	11864
16570	4	42370	2	11000
16571	4	42373	7	11395
16572	3	42374	6	16665
16573	5	42376	6	480
16574	5	42380	7	16832
16575	4	42382	7	16898
16576	5	42385	1	271
16577	5	42386	6	10011
16578	5	42390	6	16877
16579	5	42391	7	16805
16580	3	42394	5	496
16581	5	42398	1	16873
16582	5	42399	5	11887
16583	5	42404	3	15159
16584	4	42405	2	2227
16585	4	42406	5	4150
16586	5	42407	3	9170
16587	5	42410	3	3125
16588	5	42411	1	1895
16589	5	42412	6	14775
16590	3	42415	6	8340
16591	5	42416	3	9251
16592	5	42422	6	16818
16593	5	42427	2	1614
16594	5	42431	6	12204
16595	1	42432	2	16811
16596	3	42437	1	8123
16597	4	42439	1	16887
16598	5	42441	6	3304
16599	5	42443	6	8852
16600	4	42445	4	10033
16601	5	42447	6	2339
16602	5	42449	6	16823
16603	5	42450	6	13723
16604	4	42452	6	16876
16605	5	42453	2	11591
16606	5	42455	5	16842
16607	5	42458	6	4710
16608	3	42459	2	16794
16609	3	42462	7	3558
16610	5	42465	7	8656
16611	4	42466	5	3618
16612	3	42468	1	16799
16613	5	42469	1	16894
16614	4	42472	1	8291
16615	5	42472	5	8291
16616	3	42476	6	8043
16617	4	42481	7	14134
16618	5	42482	7	16965
16619	1	42483	6	8081
16620	5	42485	2	16944
16621	5	42488	6	16929
16622	5	42490	4	4629
16623	5	42491	4	16928
16624	4	42495	1	16938
16625	5	42497	5	599
16626	4	42501	5	17026
16627	5	42503	3	16913
16628	4	42503	7	16913
16629	5	42505	6	7668
16630	4	42506	1	13746
16631	5	42506	7	13746
16632	5	42509	3	15143
16633	4	42513	5	16976
16634	1	42515	2	749
16635	4	42516	3	17017
16636	4	42518	3	3820
16637	5	42519	7	16968
16638	3	42522	5	15026
16639	4	42527	2	1470
16640	3	42529	7	9151
16641	5	42533	2	17025
16642	3	42540	3	1293
16643	3	42543	5	12183
16644	5	42544	2	9531
16645	4	42547	7	11208
16646	3	42551	7	12827
16647	5	42552	3	10464
16648	5	42553	7	16974
16649	3	42555	5	1453
16650	4	42556	6	4342
16651	5	42558	4	11878
16652	5	42560	5	4677
16653	4	42563	7	10244
16654	4	42564	7	17012
16655	5	42565	5	17018
16656	4	42572	7	16271
16657	5	42577	4	16945
16658	5	42579	2	16903
16659	5	42581	2	16993
16660	4	42585	7	16962
16661	4	42586	7	28
16662	5	42587	6	675
16663	5	42588	6	10091
16664	5	42589	7	992
16665	5	42591	2	6738
16666	4	42593	7	8194
16667	4	42598	1	12274
16668	3	42599	2	16921
16669	5	42600	3	16922
16670	4	42603	1	3656
16671	5	42605	6	2339
16672	4	42606	3	270
16673	3	42607	7	1924
16674	5	42608	6	8880
16675	3	42609	3	424
16676	4	42612	7	11028
16677	4	42615	2	524
16678	5	42617	2	10867
16679	3	42618	6	13743
16680	3	42626	4	15725
16681	5	42630	3	16936
16682	5	42631	4	13042
16683	5	42633	4	16994
16684	3	42636	7	1045
16685	4	42640	6	14205
16686	4	42642	6	17028
16687	3	42646	3	7565
16688	5	42650	4	3858
16689	5	42652	6	12725
16690	3	42653	5	17009
16691	1	42657	6	16911
16692	4	42658	2	3709
16693	1	42660	6	17001
16694	4	42660	7	17001
16695	5	42663	1	12841
16696	2	42664	4	16989
16697	5	42668	2	14823
16698	5	42670	4	9870
16699	3	42671	7	5158
16700	1	42674	2	13197
16701	5	42677	1	1633
16702	5	42678	6	1588
16703	5	42680	5	16996
16704	5	42681	6	16942
16705	5	42685	2	13528
16706	5	42687	5	7014
16707	5	42693	5	3640
16708	4	42695	6	9838
16709	4	42697	4	12316
16710	3	42702	5	10796
16711	5	42703	7	12808
16712	5	42704	6	5802
16713	5	42705	2	8363
16714	5	42709	2	938
16715	5	42712	5	16982
16716	4	42720	1	15288
16717	3	42727	5	4872
16718	1	42730	6	7766
16719	5	42732	4	10246
16720	5	42733	7	9525
16721	4	42734	7	9491
16722	4	42737	3	7860
16723	5	42740	6	7106
16724	5	42742	6	17020
16725	3	42743	5	16907
16726	3	42744	7	5191
16727	5	42746	2	6987
16728	4	42748	6	5091
16729	5	42749	5	6241
16730	4	42750	1	2420
16731	5	42757	1	1497
16732	5	42758	3	12949
16733	4	42760	6	9101
16734	5	42761	3	17085
16735	1	42762	6	17096
16736	5	42763	7	13130
16737	5	42769	6	2123
16738	5	42774	2	14232
16739	5	42775	6	17094
16740	3	42783	5	7863
16741	5	42787	7	15639
16742	5	42794	6	16914
16743	3	42795	4	14630
16744	4	42797	5	11785
16745	5	42799	6	13308
16746	4	42803	1	17089
16747	5	42808	3	17095
16748	5	42810	3	15094
16749	5	42811	6	1968
16750	5	42812	7	17103
16751	5	42813	7	14210
16752	3	42816	5	3420
16753	3	42818	1	6470
16754	4	42822	2	4302
16755	5	42823	5	6102
16756	3	42824	7	14677
16757	5	42825	5	11534
16758	4	42828	5	13497
16759	3	42830	7	7357
16760	5	42834	4	9766
16761	4	42835	5	2546
16762	5	42837	4	7095
16763	5	42837	6	7095
16764	4	42839	1	12588
16765	5	42845	6	4994
16766	4	42850	4	17036
16767	4	42852	4	17071
16768	4	42861	7	13934
16769	5	42861	6	13934
16770	5	42862	7	17043
16771	4	42865	6	17098
16772	3	42865	1	17098
16773	5	42867	2	17062
16774	1	42868	6	17086
16775	5	42871	6	14534
16776	5	42871	4	14534
16777	1	42872	6	14765
16778	5	42879	7	17093
16779	4	42880	7	16998
16780	3	42880	5	16998
16781	1	42881	3	1373
16782	5	42884	2	17100
16783	5	42888	1	8066
16784	5	42893	6	12905
16785	3	42894	5	4161
16786	5	42895	1	11806
16787	5	42896	4	2989
16788	5	42899	7	11183
16789	5	42900	6	17111
16790	4	42901	4	3238
16791	5	42904	6	11369
16792	4	42907	7	17119
16793	5	42909	6	5531
16794	5	42911	4	8609
16795	5	42915	7	1245
16796	4	42916	7	6364
16797	5	42917	6	14134
16798	4	42922	7	13158
16799	5	42926	5	16361
16800	5	42927	7	2739
16801	5	42935	4	12755
16802	3	42936	5	2076
16803	4	42937	7	16052
16804	3	42938	5	11723
16805	5	42940	7	13324
16806	4	42941	2	9957
16807	5	42942	2	13507
16808	3	42947	5	17106
16809	5	42948	6	2783
16810	5	42949	3	17059
16811	3	42950	6	1017
16812	5	42951	5	17091
16813	4	42953	7	10442
16814	4	42955	6	8554
16815	1	42956	6	8050
16816	5	42959	4	424
16817	3	42963	5	1922
16818	5	42966	4	17058
16819	4	42967	3	11266
16820	5	42972	3	17069
16821	5	42974	1	17052
16822	5	42976	3	17141
16823	3	42977	1	17057
16824	2	42980	2	17060
16825	4	42981	5	347
16826	5	42983	4	17133
16827	3	42985	5	5741
16828	5	42986	1	6455
16829	3	42986	2	6455
16830	4	42987	6	1395
16831	5	42990	6	6755
16832	3	42992	7	13237
16833	1	42994	6	17129
16834	5	42996	6	4267
16835	5	42998	1	1854
16836	5	42999	6	17137
16837	3	43001	5	5120
16838	5	43005	3	8730
16839	1	43006	6	5306
16840	5	43008	6	4100
16841	3	43011	7	17053
16842	4	43015	4	8382
16843	2	43022	4	17054
16844	4	43023	1	17092
16845	5	43024	4	17048
16846	4	43025	5	17140
16847	5	43025	3	17140
16848	5	43032	2	11509
16849	5	43040	2	6348
16850	5	43044	6	13787
16851	5	43046	6	3913
16852	5	43050	6	389
16853	5	43052	7	9623
16854	2	43056	3	17046
16855	4	43058	7	17099
16856	4	43061	5	17187
16857	5	43064	2	17239
16858	3	43065	2	3848
16859	4	43074	1	401
16860	5	43076	6	914
16861	4	43079	7	9175
16862	2	43088	3	3459
16863	5	43096	4	2320
16864	5	43097	1	1079
16865	4	43099	5	17201
16866	4	43103	5	10423
16867	5	43105	7	203
16868	5	43108	6	5775
16869	5	43115	1	2409
16870	5	43117	5	8646
16871	3	43118	5	9559
16872	4	43120	5	7899
16873	5	43121	6	15933
16874	5	43122	5	17256
16875	4	43123	4	4748
16876	3	43126	7	13195
16877	5	43127	1	3578
16878	5	43128	6	10729
16879	4	43132	7	17189
16880	5	43134	5	1273
16881	5	43135	4	17265
16882	4	43140	7	17271
16883	2	43141	6	9990
16884	2	43145	6	17157
16885	5	43146	6	4021
16886	5	43148	1	17178
16887	5	43154	1	8884
16888	4	43155	4	1707
16889	3	43156	1	17169
16890	4	43158	2	17278
16891	5	43159	6	17153
16892	3	43171	1	17208
16893	4	43174	7	15368
16894	5	43180	4	17171
16895	4	43184	5	17250
16896	5	43185	5	17246
16897	5	43193	3	743
16898	5	43198	6	17207
16899	3	43199	3	11615
16900	4	43204	5	17176
16901	4	43205	2	17231
16902	5	43219	7	9014
16903	4	43221	6	17244
16904	1	43224	6	10758
16905	4	43227	1	17241
16906	4	43228	7	2975
16907	5	43232	7	4354
16908	5	43233	4	1228
16909	5	43235	3	17213
16910	5	43236	2	1070
16911	5	43239	7	6511
16912	5	43240	2	17191
16913	3	43246	3	11756
16914	3	43248	7	5675
16915	5	43249	4	17159
16916	5	43254	5	12420
16917	4	43259	2	13906
16918	3	43260	2	17253
16919	5	43264	1	4231
16920	5	43267	1	2275
16921	5	43268	3	4072
16922	5	43272	6	15867
16923	3	43276	6	17156
16924	5	43276	4	17156
16925	5	43282	6	17230
16926	4	43288	1	13662
16927	5	43292	4	1540
16928	5	43294	5	17272
16929	4	43295	5	13437
16930	5	43295	6	13437
16931	3	43297	5	17248
16932	4	43298	1	16883
16933	3	43298	7	16883
16934	5	43299	3	2875
16935	5	43301	6	17267
16936	5	43305	7	10375
16937	5	43308	6	8240
16938	5	43309	6	8305
16939	3	43314	5	15114
16940	3	43315	7	1991
16941	5	43316	3	9295
16942	4	43319	6	15213
16943	5	43321	1	13775
16944	3	43326	1	9144
16945	3	43332	1	17258
16946	5	43333	2	10180
16947	5	43340	2	7702
16948	5	43341	6	12242
16949	4	43346	7	17196
16950	4	43347	5	11101
16951	5	43348	1	17235
16952	4	43354	5	11519
16953	5	43356	2	11183
16954	5	43357	6	17203
16955	5	43358	6	3010
16956	4	43364	7	11543
16957	5	43365	3	14926
16958	3	43369	3	14475
16959	4	43374	2	8065
16960	4	43376	4	17154
16961	5	43378	3	1582
16962	5	43379	2	5094
16963	4	43384	3	17237
16964	5	43386	6	13370
16965	5	43387	1	898
16966	5	43389	2	15449
16967	4	43390	7	16789
16968	5	43391	3	3530
16969	5	43395	6	9020
16970	5	43397	7	10145
16971	3	43397	5	10145
16972	4	43403	1	15864
16973	5	43406	2	2706
16974	5	43407	1	17185
16975	5	43409	6	17174
16976	4	43409	2	17174
16977	5	43410	6	3638
16978	5	43411	5	17240
16979	5	43413	4	12231
16980	5	43414	1	2599
16981	5	43415	6	12999
16982	4	43421	3	2850
16983	4	43428	3	17329
16984	4	43429	5	17411
16985	1	43431	7	16407
16986	5	43431	2	16407
16987	5	43432	6	17353
16988	4	43433	1	640
16989	5	43434	6	17327
16990	5	43438	4	17368
16991	4	43440	7	11346
16992	5	43441	2	15449
16993	5	43442	4	9106
16994	5	43444	2	4949
16995	3	43444	4	4949
16996	5	43446	6	6987
16997	5	43447	7	17385
16998	5	43448	4	4307
16999	3	43451	5	9964
17000	3	43452	6	17404
17001	5	43456	6	17413
17002	4	43459	3	17379
17003	4	43461	2	14897
17004	5	43463	6	17428
17005	4	43470	6	17420
17006	3	43475	4	11480
17007	5	43475	7	11480
17008	3	43476	7	16363
17009	4	43477	2	17394
17010	5	43480	5	17396
17011	5	43482	4	17314
17012	5	43492	7	17296
17013	4	43494	6	5035
17014	4	43495	7	5229
17015	1	43502	6	4735
17016	5	43506	4	17328
17017	5	43507	6	17357
17018	5	43511	5	8211
17019	5	43518	1	9541
17020	5	43522	6	17390
17021	1	43525	6	13240
17022	5	43525	4	13240
17023	5	43527	6	17312
17024	4	43531	2	17366
17025	5	43532	3	776
17026	5	43533	5	14680
17027	4	43534	4	17307
17028	4	43536	7	3054
17029	2	43540	6	17304
17030	5	43541	4	8448
17031	5	43542	7	17355
17032	3	43544	7	13432
17033	5	43545	6	17323
17034	2	43550	3	17330
17035	5	43554	2	17414
17036	4	43555	4	12367
17037	5	43560	3	6894
17038	2	43562	6	6914
17039	5	43565	5	3811
17040	3	43567	3	17388
17041	5	43568	2	7542
17042	5	43569	6	17409
17043	1	43570	4	6202
17044	4	43571	5	17282
17045	5	43572	4	17387
17046	5	43574	7	13413
17047	5	43575	2	17326
17048	5	43577	3	7428
17049	5	43578	7	10651
17050	5	43579	4	17382
17051	3	43581	1	413
17052	5	43584	6	433
17053	5	43587	6	17400
17054	3	43593	3	17360
17055	5	43603	2	1656
17056	3	43605	5	17333
17057	3	43606	7	4029
17058	5	43607	2	17283
17059	4	43608	3	17375
17060	5	43611	7	17285
17061	4	43614	6	3835
17062	5	43615	6	17346
17063	4	43618	7	518
17064	5	43620	6	17336
17065	5	43621	4	11932
17066	4	43625	4	5298
17067	3	43627	5	17370
17068	4	43628	7	11708
17069	4	43628	2	11708
17070	5	43630	1	4125
17071	5	43634	7	2216
17072	5	43637	6	17334
17073	1	43638	6	17386
17074	5	43642	6	15773
17075	5	43648	3	12290
17076	5	43649	1	8020
17077	5	43651	2	1118
17078	1	43654	6	13518
17079	4	43654	5	13518
17080	4	43655	2	11172
17081	4	43658	1	17293
17082	4	43658	5	17293
17083	4	43662	5	11760
17084	5	43669	4	17318
17085	3	43675	4	688
17086	5	43676	6	12803
17087	3	43677	6	5832
17088	3	43679	5	10306
17089	4	43687	6	17320
17090	3	43689	3	7465
17091	2	43693	3	8884
17092	3	43694	5	2477
17093	3	43694	7	2477
17094	5	43699	3	17325
17095	5	43700	2	14523
17096	5	43703	6	5165
17097	5	43704	6	2119
17098	3	43707	5	3788
17099	5	43708	2	17331
17100	3	43709	3	17284
17101	5	43710	1	1068
17102	5	43713	2	15417
17103	3	43718	3	1689
17104	4	43727	2	595
17105	5	43728	1	17487
17106	3	43732	5	17520
17107	5	43733	1	17514
17108	1	43735	6	7385
17109	5	43736	4	3227
17110	5	43737	6	12313
17111	3	43738	1	2068
17112	5	43739	5	2780
17113	2	43744	3	7451
17114	5	43748	4	17528
17115	5	43754	2	17499
17116	3	43755	3	14954
17117	4	43755	2	14954
17118	3	43756	4	6000
17119	5	43757	4	17509
17120	5	43763	5	11360
17121	5	43766	3	11756
17122	5	43768	4	15609
17123	5	43771	7	16660
17124	5	43772	7	5950
17125	5	43773	5	14337
17126	4	43778	6	7113
17127	5	43779	4	8139
17128	4	43780	7	17552
17129	5	43785	7	11973
17130	5	43787	4	10772
17131	4	43791	2	15383
17132	5	43793	2	17500
17133	4	43798	5	213
17134	3	43799	1	3093
17135	4	43805	3	9451
17136	5	43809	2	9735
17137	3	43812	5	17545
17138	5	43815	5	12327
17139	5	43820	2	17553
17140	4	43825	7	1820
17141	5	43826	2	3112
17142	1	43828	6	14991
17143	3	43829	5	16749
17144	3	43830	5	10462
17145	4	43833	1	15159
17146	3	43834	7	17538
17147	5	43835	3	17443
17148	4	43837	4	11671
17149	3	43838	3	15855
17150	3	43842	7	8319
17151	5	43844	5	9838
17152	5	43845	7	13478
17153	5	43845	3	13478
17154	4	43847	1	7509
17155	2	43848	6	12240
17156	4	43849	3	17212
17157	3	43850	6	17546
17158	4	43851	2	2416
17159	5	43852	2	17483
17160	1	43852	7	17483
17161	5	43853	2	1095
17162	5	43854	5	15326
17163	3	43857	6	14915
17164	1	43858	6	2021
17165	3	43859	1	14710
17166	5	43861	2	17507
17167	5	43863	4	3230
17168	3	43880	2	6821
17169	5	43883	6	17558
17170	4	43884	3	1885
17171	3	43889	2	17543
17172	3	43891	2	13087
17173	5	43895	6	17477
17174	4	43897	7	3172
17175	5	43904	2	17560
17176	5	43905	4	7279
17177	5	43908	6	10180
17178	3	43908	1	10180
17179	5	43912	1	8448
17180	5	43914	2	3289
17181	5	43915	1	1491
17182	5	43916	2	6074
17183	5	43929	5	17484
17184	4	43930	2	12670
17185	3	43931	5	2277
17186	5	43932	4	3621
17187	5	43936	6	17527
17188	5	43937	4	431
17189	5	43938	4	9222
17190	4	43943	6	17451
17191	5	43944	7	17504
17192	5	43946	4	17430
17193	5	43950	7	10434
17194	3	43953	3	8031
17195	2	43958	3	6567
17196	5	43958	1	6567
17197	4	43959	1	6528
17198	4	43960	2	17465
17199	5	43962	7	17521
17200	5	43963	2	17564
17201	4	43964	5	14316
17202	3	43967	7	16754
17203	3	43969	5	9503
17204	5	43971	2	8389
17205	4	43974	5	17551
17206	5	43976	7	93
17207	4	43983	2	17473
17208	5	43985	5	550
17209	3	43989	5	17489
17210	5	43990	4	2383
17211	4	43991	7	17497
17212	4	43994	5	12396
17213	4	43998	4	17449
17214	5	44002	6	13162
17215	5	44004	2	15332
17216	5	44006	2	16809
17217	5	44007	1	3827
17218	4	44008	4	17445
17219	4	44011	6	7467
17220	5	44012	5	17457
17221	5	44016	5	1760
17222	4	44024	5	17533
17223	5	44027	7	7158
17224	5	44028	6	6434
17225	5	44030	5	17488
17226	5	44034	1	14777
17227	5	44037	3	15193
17228	4	44039	2	17557
17229	5	44040	4	10088
17230	4	44043	7	17554
17231	3	44047	5	14492
17232	4	44049	6	2418
17233	4	44050	7	9927
17234	3	44053	6	17522
17235	3	44056	3	17516
17236	5	44059	4	6458
17237	5	44061	1	5238
17238	4	44062	6	7022
17239	5	44068	5	17446
17240	5	44069	6	5578
17241	5	44073	1	11091
17242	5	44074	1	5048
17243	4	44074	7	5048
17244	5	44078	2	8067
17245	5	44080	4	2153
17246	4	44084	7	17519
17247	4	44085	7	17525
17248	5	44087	6	5509
17249	5	44088	3	17485
17250	1	44089	6	17547
17251	5	44090	6	1021
17252	4	44095	7	16004
17253	5	44097	2	16178
17254	3	44101	7	2415
17255	5	44102	5	17515
17256	1	44106	6	2879
17257	4	44110	4	207
17258	5	44114	2	11802
17259	3	44117	5	4081
17260	4	44121	6	9281
17261	5	44122	6	9761
17262	5	44124	2	7388
17263	5	44125	5	15348
17264	5	44129	4	17429
17265	4	44131	3	17537
17266	4	44133	6	6996
17267	5	44136	3	626
17268	4	44138	6	17505
17269	5	44139	2	14804
17270	5	44143	2	995
17271	3	44143	3	995
17272	4	44147	5	1582
17273	5	44155	1	11956
17274	4	44158	3	12011
17275	5	44159	4	17695
17276	4	44160	6	17703
17277	3	44161	1	3054
17278	3	44162	1	1907
17279	3	44164	2	2894
17280	5	44167	3	16171
17281	5	44169	6	15594
17282	3	44170	6	3574
17283	5	44173	7	13058
17284	3	44180	5	17579
17285	5	44181	6	17580
17286	2	44184	6	17622
17287	5	44188	7	12951
17288	5	44189	3	14972
17289	5	44191	6	17635
17290	5	44192	2	17594
17291	4	44192	3	17594
17292	2	44194	7	17691
17293	4	44195	5	17607
17294	3	44198	1	10575
17295	3	44206	1	2691
17296	3	44207	1	9356
17297	5	44208	2	17613
17298	1	44209	6	1638
17299	5	44210	2	719
17300	3	44211	3	13859
17301	5	44213	1	17610
17302	5	44214	1	8065
17303	5	44215	6	15350
17304	5	44220	5	6233
17305	2	44222	6	17588
17306	4	44225	5	17628
17307	5	44226	4	7083
17308	4	44227	5	627
17309	3	44231	2	7247
17310	5	44235	6	6221
17311	3	44236	4	344
17312	3	44238	5	11520
17313	4	44239	2	15563
17314	5	44240	1	12623
17315	5	44241	6	10151
17316	3	44245	4	17596
17317	5	44245	5	17596
17318	5	44246	2	14585
17319	4	44251	6	17258
17320	5	44257	7	17684
17321	4	44261	7	17612
17322	5	44265	1	6367
17323	5	44268	6	3485
17324	5	44269	6	12574
17325	4	44271	1	16160
17326	5	44272	1	3158
17327	4	44273	7	10538
17328	5	44274	1	10444
17329	4	44275	1	17660
17330	5	44279	6	1536
17331	1	44280	4	17690
17332	3	44281	4	17679
17333	3	44284	3	15752
17334	5	44285	7	7585
17335	1	44287	6	17575
17336	4	44288	1	11225
17337	5	44293	6	17678
17338	4	44297	2	3870
17339	5	44298	4	15417
17340	4	44298	5	15417
17341	5	44299	4	2891
17342	4	44299	7	2891
17343	3	44301	5	6480
17344	3	44303	3	17677
17345	5	44304	2	17584
17346	5	44305	7	76
17347	5	44310	2	9509
17348	5	44310	3	9509
17349	3	44311	7	17589
17350	3	44312	5	17698
17351	5	44313	6	1049
17352	4	44317	7	13621
17353	5	44321	7	4871
17354	4	44322	7	17694
17355	4	44324	1	9514
17356	4	44327	4	1380
17357	5	44330	5	17597
17358	4	44331	4	17581
17359	5	44333	1	9743
17360	5	44334	2	6276
17361	4	44336	1	2845
17362	5	44337	6	2632
17363	3	44337	3	2632
17364	5	44338	4	17633
17365	3	44338	7	17633
17366	5	44339	7	2005
17367	5	44342	3	12378
17368	5	44343	1	2551
17369	1	44344	6	12831
17370	5	44345	6	17647
17371	5	44346	2	17682
17372	3	44346	6	17682
17373	3	44347	4	17629
17374	3	44347	1	17629
17375	5	44351	6	4644
17376	5	44356	2	13049
17377	5	44358	2	17623
17378	5	44359	5	17583
17379	3	44363	4	6980
17380	5	44364	6	11932
17381	5	44367	1	17645
17382	5	44368	6	17617
17383	4	44369	3	17571
17384	5	44372	3	10159
17385	5	44372	4	10159
17386	4	44374	4	17576
17387	3	44375	3	17627
17388	5	44378	7	11846
17389	5	44379	6	17666
17390	1	44380	6	14496
17391	5	44381	2	13466
17392	1	44382	6	9904
17393	3	44384	5	17574
17394	5	44385	7	17665
17395	5	44386	6	13164
17396	5	44387	4	17652
17397	5	44390	4	17687
17398	4	44390	7	17687
17399	5	44391	4	17681
17400	5	44394	2	1747
17401	5	44396	5	17638
17402	5	44397	5	10429
17403	5	44407	6	8767
17404	4	44409	3	17664
17405	3	44412	1	11764
17406	5	44417	2	1677
17407	4	44418	5	17701
17408	5	44419	5	17657
17409	2	44420	2	14341
17410	5	44422	4	12990
17411	4	44423	4	7626
17412	4	44423	7	7626
17413	3	44426	1	12178
17414	5	44428	6	16952
17415	5	44432	7	1387
17416	4	44437	6	17573
17417	5	44442	2	2493
17418	4	44445	6	17646
17419	3	44446	7	9264
17420	4	44449	5	10026
17421	5	44450	3	17585
17422	4	44451	4	17566
17423	4	44452	1	17659
17424	4	44457	3	3741
17425	4	44459	4	6001
17426	5	44462	2	17611
17427	4	44463	5	17667
17428	5	44463	1	17667
17429	1	44465	4	10356
17430	5	44474	2	13187
17431	5	44475	7	17619
17432	5	44476	2	15793
17433	4	44477	2	17675
17434	5	44479	2	7632
17435	5	44480	6	7798
17436	4	44481	2	466
17437	2	44483	6	17614
17438	5	44489	3	10792
17439	5	44490	2	1741
17440	3	44497	3	14663
17441	4	44498	2	17697
17442	3	44499	5	1659
17443	3	44499	7	1659
17444	5	44501	2	17658
17445	5	44502	5	17625
17446	5	44505	7	3659
17447	4	44507	7	6787
17448	4	44508	7	17656
17449	3	44511	4	141
17450	5	44512	6	3006
17451	5	44519	7	4127
17452	5	44519	1	4127
17453	4	44521	5	17632
17454	5	44522	6	17606
17455	3	44523	3	17706
17456	1	44525	2	17595
17457	3	44526	7	66
17458	2	44527	4	6445
17459	5	44528	3	13951
17460	5	44531	6	17653
17461	5	44533	6	7277
17462	4	44538	1	17704
17463	2	44539	5	17608
17464	3	44541	7	9750
17465	5	44544	1	17081
17466	5	44546	7	105
17467	5	44555	5	3494
17468	5	44557	2	17651
17469	5	44560	4	3181
17470	5	44561	3	12965
17471	4	44565	6	8903
17472	3	44566	6	4210
17473	5	44567	7	7252
17474	4	44569	1	6470
17475	5	44572	3	17641
17476	2	44573	3	1025
17477	2	44574	6	17639
17478	3	44575	1	17069
17479	5	44581	2	11881
17480	5	44582	1	17601
17481	4	44585	7	17637
17482	5	44586	4	14647
17483	5	44587	7	8495
17484	4	44591	7	17590
17485	5	44592	4	2706
17486	4	44593	3	15353
17487	4	44595	3	2089
17488	5	44599	7	11822
17489	4	44603	7	17796
17490	5	44604	2	16450
17491	4	44606	5	11298
17492	5	44609	6	17318
17493	5	44616	2	17716
17494	5	44618	3	15120
17495	5	44620	5	17757
17496	4	44622	3	5031
17497	5	44622	2	5031
17498	5	44627	7	8398
17499	4	44633	7	17711
17500	4	44635	2	17791
17501	5	44636	6	5872
17502	4	44637	7	17719
17503	5	44639	5	14218
17504	5	44641	4	9308
17505	4	44644	4	14533
17506	5	44646	2	17764
17507	5	44649	6	14144
17508	4	44655	3	17758
17509	3	44658	7	17769
17510	5	44659	1	12577
17511	5	44660	4	12793
17512	5	44660	6	12793
17513	3	44662	1	17258
17514	3	44665	3	10810
17515	5	44666	5	17773
17516	5	44667	2	4170
17517	5	44670	3	17805
17518	5	44671	2	17811
17519	5	44672	3	2504
17520	5	44674	2	17053
17521	5	44675	6	15491
17522	1	44675	5	15491
17523	4	44679	3	7494
17524	4	44680	6	17756
17525	5	44691	4	9562
17526	5	44695	2	9287
17527	5	44696	3	4793
17528	3	44706	1	17800
17529	4	44707	6	17821
17530	5	44711	4	16897
17531	5	44712	5	13415
17532	3	44713	7	15444
17533	5	44715	6	14175
17534	5	44716	6	10210
17535	5	44718	4	5977
17536	5	44719	6	9825
17537	5	44721	7	15052
17538	5	44723	1	1736
17539	5	44724	3	17787
17540	3	44728	4	10866
17541	5	44737	4	3463
17542	5	44739	2	5663
17543	4	44740	1	11170
17544	3	44740	7	11170
17545	5	44744	4	4398
17546	5	44745	6	17734
17547	2	44746	4	75
17548	5	44747	4	749
17549	3	44748	5	15880
17550	5	44752	2	13082
17551	4	44753	5	17751
17552	5	44758	1	3726
17553	5	44759	3	17816
17554	5	44761	4	15709
17555	4	44764	4	17737
17556	5	44765	7	17762
17557	3	44769	2	8477
17558	4	44772	7	1993
17559	5	44772	6	1993
17560	3	44775	3	9315
17561	3	44777	1	17715
17562	5	44780	6	11037
17563	5	44780	1	11037
17564	5	44783	4	7235
17565	3	44784	1	5822
17566	5	44786	6	11467
17567	4	44787	7	13735
17568	5	44789	6	17795
17569	4	44793	2	126
17570	5	44798	7	17741
17571	5	44800	1	9975
17572	5	44801	2	15313
17573	5	44803	6	17789
17574	5	44805	6	7217
17575	4	44806	5	11760
17576	4	44808	7	15022
17577	4	44809	2	396
17578	5	44811	6	11104
17579	5	44812	7	17722
17580	4	44813	6	14840
17581	5	44815	5	17740
17582	5	44816	5	3452
17583	1	44817	2	10883
17584	5	44820	2	8418
17585	4	44821	2	17812
17586	5	44823	6	17792
17587	5	44824	4	2928
17588	5	44826	3	8632
17589	5	44827	5	12474
17590	5	44836	5	4710
17591	4	44837	5	15795
17592	4	44838	5	16404
17593	5	44841	6	13101
17594	5	44843	5	17788
17595	4	44844	7	8792
17596	5	44845	2	17771
17597	4	44848	7	17728
17598	5	44849	6	1896
17599	5	44857	3	17864
17600	5	44858	4	16874
17601	5	44866	7	17923
17602	5	44867	1	17878
17603	5	44869	5	12733
17604	4	44872	7	17949
17605	5	44876	7	17922
17606	5	44880	7	13662
17607	5	44881	3	21
17608	5	44882	2	15749
17609	3	44885	3	13183
17610	5	44888	6	11591
17611	4	44890	5	17919
17612	5	44892	5	12564
17613	3	44894	2	17936
17614	5	44895	5	4802
17615	3	44896	6	15263
17616	3	44897	7	1792
17617	5	44899	1	283
17618	5	44904	6	3115
17619	5	44905	2	11197
17620	3	44907	1	1373
17621	5	44912	6	12894
17622	5	44914	3	7298
17623	4	44917	7	2343
17624	5	44917	6	2343
17625	5	44919	6	9188
17626	5	44920	2	17861
17627	5	44922	3	8726
17628	5	44924	6	17830
17629	5	44928	7	17840
17630	3	44931	7	6234
17631	5	44933	2	15009
17632	3	44934	4	10748
17633	4	44936	7	17835
17634	4	44940	7	5453
17635	3	44942	3	9226
17636	5	44945	4	17938
17637	5	44946	6	17913
17638	5	44948	5	9937
17639	5	44957	5	2780
17640	4	44957	4	2780
17641	4	44958	7	17866
17642	5	44959	3	1393
17643	3	44965	2	13685
17644	3	44966	3	17910
17645	5	44967	6	8269
17646	2	44970	7	17943
17647	5	44970	1	17943
17648	4	44971	7	17912
17649	5	44972	2	5016
17650	5	44974	2	777
17651	5	44983	5	14558
17652	4	44984	7	17833
17653	3	44985	3	1523
17654	5	44986	5	17859
17655	5	44987	7	17916
17656	4	44993	7	16342
17657	5	45000	2	17902
17658	4	45005	2	732
17659	5	45006	4	17945
17660	3	45007	3	7383
17661	2	45008	2	17868
17662	5	45011	2	17328
17663	5	45011	6	17328
17664	3	45014	5	7352
17665	4	45015	7	15603
17666	4	45015	6	15603
17667	5	45016	6	17944
17668	5	45017	7	11999
17669	4	45018	1	3781
17670	5	45019	7	17917
17671	5	45021	7	17863
17672	4	45022	2	15578
17673	5	45022	7	15578
17674	5	45028	6	17903
17675	5	45031	6	13676
17676	5	45033	1	17856
17677	5	45034	6	17932
17678	4	45044	7	2036
17679	4	45045	7	17921
17680	3	45046	7	10089
17681	5	45048	6	2311
17682	5	45051	7	16778
17683	5	45055	4	13209
17684	3	45056	1	17842
17685	4	45059	7	1382
17686	5	45061	4	15929
17687	5	45063	7	3446
17688	5	45064	3	8379
17689	5	45068	2	17908
17690	5	45071	4	314
17691	5	45074	3	17843
17692	5	45076	6	13044
17693	3	45079	1	1533
17694	5	45080	4	15512
17695	5	45082	1	13731
17696	4	45083	2	8054
17697	4	45086	7	2483
17698	5	45087	6	2806
17699	5	45088	6	11401
17700	4	45089	6	10354
17701	5	45093	1	7260
17702	3	45094	4	17836
17703	4	45094	5	17836
17704	4	45095	6	13734
17705	4	45098	5	3917
17706	5	45098	1	3917
17707	5	45100	3	3086
17708	5	45101	7	11254
17709	1	45110	6	17929
17710	5	45114	5	17818
17711	5	45116	6	17925
17712	4	45119	7	2040
17713	5	45125	6	16947
17714	4	45127	1	12377
17715	3	45128	7	17832
17716	3	45131	4	17442
17717	4	45132	2	3981
17718	3	45132	4	3981
17719	4	45137	6	5575
17720	4	45139	1	17899
17721	5	45140	7	10282
17722	3	45141	7	4016
17723	4	45142	5	17906
17724	5	45143	5	17421
17725	5	45144	4	5574
17726	5	45145	1	4924
17727	5	45154	7	9107
17728	4	45155	2	2714
17729	5	45156	6	17984
17730	5	45157	7	2450
17731	4	45159	7	18012
17732	5	45160	4	17955
17733	5	45167	6	13136
17734	5	45169	1	108
17735	5	45171	6	15565
17736	4	45173	3	13479
17737	3	45174	5	16293
17738	5	45179	6	5279
17739	4	45180	6	4587
17740	5	45184	4	9833
17741	4	45187	7	18031
17742	5	45188	1	18070
17743	5	45190	6	12699
17744	4	45191	5	17969
17745	4	45194	6	12555
17746	5	45195	6	18043
17747	5	45198	5	7779
17748	3	45199	6	7451
17749	4	45201	2	10876
17750	5	45202	6	18035
17751	3	45212	4	12506
17752	5	45214	4	18044
17753	3	45224	7	4695
17754	5	45225	6	15344
17755	2	45226	3	17970
17756	5	45227	6	17971
17757	5	45230	2	18015
17758	5	45231	4	18047
17759	5	45233	6	18074
17760	5	45234	3	11431
17761	5	45237	5	9147
17762	5	45238	4	18062
17763	3	45242	1	17091
17764	5	45243	2	18029
17765	4	45247	4	12159
17766	5	45249	6	18026
17767	5	45255	3	17005
17768	3	45258	2	11285
17769	5	45259	6	9227
17770	5	45262	6	13189
17771	5	45265	6	3101
17772	5	45268	3	18017
17773	4	45269	5	5006
17774	3	45270	3	17421
17775	4	45272	2	1979
17776	5	45275	1	6419
17777	5	45282	3	10948
17778	5	45283	2	10843
17779	5	45286	5	14448
17780	5	45289	5	17991
17781	5	45290	1	5049
17782	5	45292	5	10362
17783	1	45293	4	15713
17784	5	45294	1	17996
17785	4	45298	7	5293
17786	5	45303	6	4158
17787	5	45308	7	18045
17788	5	45311	5	4362
17789	4	45313	7	11994
17790	3	45314	7	18060
17791	4	45315	2	18008
17792	5	45317	1	18064
17793	5	45319	5	17975
17794	4	45321	2	18054
17795	5	45321	5	18054
17796	4	45322	2	16656
17797	5	45325	6	17960
17798	5	45327	1	15103
17799	5	45329	4	9680
17800	5	45332	4	3283
17801	3	45336	4	14290
17802	5	45338	7	17809
17803	5	45339	6	12990
17804	4	45343	7	16014
17805	5	45344	4	1659
17806	5	45347	4	15294
17807	4	45348	7	17985
17808	5	45349	3	17968
17809	5	45351	2	17977
17810	4	45353	4	11586
17811	5	45353	6	11586
17812	3	45356	6	17711
17813	5	45357	1	9346
17814	4	45358	3	18056
17815	5	45360	2	18020
17816	5	45364	6	6798
17817	5	45365	7	17981
17818	4	45366	5	763
17819	1	45369	6	15425
17820	4	45370	7	3401
17821	3	45379	5	5338
17822	5	45383	5	4588
17823	4	45385	3	3260
17824	4	45388	3	15599
17825	5	45392	5	17629
17826	4	45393	6	10922
17827	4	45396	2	7844
17828	5	45397	2	10907
17829	4	45398	2	5153
17830	3	45399	1	17976
17831	5	45402	1	10814
17832	5	45402	6	10814
17833	4	45403	3	1044
17834	5	45408	6	6354
17835	5	45411	2	18077
17836	5	45413	6	18040
17837	5	45415	7	4094
17838	4	45416	5	18061
17839	4	45417	5	5169
17840	3	45418	3	15931
17841	5	45420	7	17935
17842	5	45422	2	6396
17843	5	45423	7	18078
17844	5	45424	2	16585
17845	5	45426	2	17964
17846	5	45428	1	10000
17847	5	45436	4	7566
17848	5	45437	7	10719
17849	5	45441	2	17967
17850	3	45444	7	9798
17851	5	45445	1	18085
17852	5	45448	3	15815
17853	5	45450	6	18013
17854	4	45453	7	16916
17855	3	45457	3	12210
17856	4	45463	5	17997
17857	5	45466	1	2224
17858	4	45468	7	7994
17859	5	45469	2	1166
17860	5	45470	1	17961
17861	1	45473	4	13625
17862	5	45475	2	13950
17863	3	45476	4	18069
17864	1	45478	6	5643
17865	5	45479	4	17966
17866	5	45481	2	12462
17867	5	45483	7	9933
17868	5	45483	6	9933
17869	4	45486	6	18172
17870	5	45487	4	18214
17871	4	45490	3	6216
17872	1	45499	6	3410
17873	4	45501	7	9805
17874	5	45506	2	13442
17875	5	45508	5	5676
17876	4	45509	3	18208
17877	1	45512	4	12166
17878	4	45518	1	4710
17879	4	45523	7	18211
17880	3	45524	1	12139
17881	3	45525	3	18205
17882	5	45531	6	5930
17883	4	45539	7	18164
17884	5	45540	6	12666
17885	3	45541	7	18147
17886	3	45547	4	15864
17887	4	45552	5	18097
17888	3	45554	5	18197
17889	5	45556	1	6276
17890	4	45559	5	980
17891	5	45561	3	9107
17892	5	45562	2	12936
17893	5	45563	6	18117
17894	5	45564	6	11822
17895	5	45568	7	9017
17896	3	45571	7	14075
17897	5	45578	6	6341
17898	3	45579	4	18158
17899	4	45581	6	5486
17900	5	45584	6	15027
17901	2	45585	6	7190
17902	5	45588	5	14052
17903	1	45589	6	15384
17904	5	45592	1	13341
17905	2	45598	1	18105
17906	3	45601	3	18222
17907	5	45603	7	11969
17908	4	45610	6	18206
17909	5	45612	4	21
17910	4	45618	4	5064
17911	5	45620	7	8112
17912	5	45622	6	18146
17913	5	45623	4	18167
17914	5	45625	1	16162
17915	5	45626	4	12368
17916	3	45631	1	15236
17917	3	45634	6	11888
17918	5	45635	4	18091
17919	4	45635	2	18091
17920	4	45637	3	4600
17921	5	45637	4	4600
17922	5	45638	6	18102
17923	5	45647	3	511
17924	3	45648	2	13613
17925	5	45648	1	13613
17926	5	45651	2	17116
17927	5	45652	6	13185
17928	4	45657	7	5314
17929	4	45658	7	18116
17930	5	45659	2	18103
17931	5	45660	7	16207
17932	5	45664	6	18093
17933	3	45665	5	18104
17934	5	45666	1	1727
17935	4	45667	1	17685
17936	4	45667	5	17685
17937	5	45669	3	931
17938	5	45672	2	18155
17939	5	45674	2	18171
17940	5	45677	4	3251
17941	3	45678	4	12628
17942	5	45684	7	18087
17943	5	45686	3	7395
17944	5	45690	7	18216
17945	3	45691	5	18190
17946	4	45695	7	4124
17947	4	45696	7	16280
17948	4	45701	6	18086
17949	5	45702	6	18223
17950	3	45710	2	11244
17951	3	45712	1	12600
17952	4	45718	7	7700
17953	5	45721	1	18128
17954	5	45721	2	18128
17955	3	45722	7	16607
17956	4	45726	1	18195
17957	3	45727	5	33
17958	4	45728	5	18196
17959	5	45731	6	18201
17960	5	45733	3	18185
17961	4	45734	3	18135
17962	5	45736	6	18160
17963	5	45738	2	1330
17964	3	45740	4	11890
17965	4	45747	4	3568
17966	4	45754	4	5075
17967	3	45759	7	3066
17968	5	45763	1	2392
17969	4	45765	3	12538
17970	2	45766	4	18156
17971	5	45767	6	12268
17972	5	45768	6	876
17973	4	45770	3	654
17974	2	45772	4	11389
17975	5	45774	6	13290
17976	3	45775	3	18184
17977	4	45779	5	5680
17978	3	45786	3	5183
17979	4	45788	1	14775
17980	5	45790	4	8009
17981	2	45791	1	18204
17982	5	45797	6	3095
17983	5	45801	6	15284
17984	4	45802	2	5325
17985	5	45803	2	18137
17986	5	45804	2	10331
17987	4	45807	3	13042
17988	3	45808	4	9452
17989	5	45810	1	17527
17990	5	45812	4	18157
17991	5	45815	7	6525
17992	5	45816	4	9985
17993	4	45818	1	12426
17994	5	45820	6	3316
17995	5	45826	2	15076
17996	5	45830	6	3659
17997	4	45833	4	18089
17998	3	45834	3	8622
17999	5	45836	2	18191
18000	5	45837	6	12952
18001	3	45840	6	8317
18002	5	45842	6	3648
18003	5	45843	1	18114
18004	3	45846	2	5097
18005	5	45849	3	18173
18006	5	45849	6	18173
18007	5	45851	6	6123
18008	5	45855	6	7834
18009	3	45857	2	18300
18010	2	45859	4	9584
18011	5	45860	4	1110
18012	4	45861	3	97
18013	5	45863	1	12383
18014	5	45865	6	18250
18015	3	45866	7	6355
18016	4	45868	6	17607
18017	4	45870	6	3996
18018	5	45874	5	6690
18019	4	45874	4	6690
18020	3	45877	5	15283
18021	3	45881	4	18323
18022	5	45882	6	18339
18023	5	45883	6	18358
18024	5	45889	4	12294
18025	3	45889	1	12294
18026	4	45890	5	18241
18027	4	45891	4	18321
18028	3	45895	4	13893
18029	5	45897	5	11628
18030	5	45905	2	13850
18031	5	45907	6	15683
18032	5	45909	2	16288
18033	5	45911	2	18343
18034	4	45915	3	4794
18035	5	45918	7	6917
18036	5	45919	2	18330
18037	5	45923	1	13711
18038	5	45927	5	63
18039	5	45927	7	63
18040	3	45928	5	18317
18041	5	45931	5	18280
18042	5	45933	5	619
18043	5	45936	2	12550
18044	3	45937	1	4685
18045	5	45940	2	7582
18046	5	45944	7	14701
18047	5	45944	1	14701
18048	5	45948	2	5630
18049	3	45950	2	18304
18050	1	45953	6	3040
18051	3	45958	4	15594
18052	3	45959	6	3065
18053	4	45960	4	18271
18054	5	45962	7	18286
18055	5	45964	6	18359
18056	4	45964	3	18359
18057	5	45967	3	5097
18058	4	45970	4	113
18059	4	45972	5	7823
18060	3	45973	6	18257
18061	5	45974	4	13935
18062	4	45980	7	10690
18063	4	45981	7	15855
18064	4	45982	4	8600
18065	5	45983	6	18236
18066	5	45984	5	18283
18067	5	45987	2	11052
18068	4	45989	1	17128
18069	3	45990	5	13191
18070	4	45993	3	3445
18071	5	45994	2	13779
18072	5	45995	2	11731
18073	3	45999	5	18276
18074	4	46003	7	12073
18075	4	46005	4	6891
18076	3	46006	5	9847
18077	5	46008	6	18227
18078	4	46009	7	17841
18079	4	46012	4	2089
18080	4	46014	7	15122
18081	5	46016	7	18341
18082	4	46017	3	16850
18083	5	46019	6	10444
18084	4	46020	5	18311
18085	3	46031	1	18297
18086	5	46034	4	17328
18087	5	46040	6	8574
18088	4	46041	1	18331
18089	5	46042	7	18344
18090	5	46044	5	18289
18091	5	46045	3	5580
18092	5	46050	1	6846
18093	5	46052	1	14852
18094	5	46055	4	18329
18095	5	46056	4	18274
18096	4	46057	2	9713
18097	5	46059	1	16295
18098	3	46063	5	7798
18099	5	46065	2	14484
18100	5	46066	6	18239
18101	4	46069	6	4594
18102	5	46070	7	18242
18103	5	46079	3	17683
18104	4	46080	7	18273
18105	5	46081	6	6276
18106	5	46082	6	5768
18107	5	46084	6	16901
18108	5	46085	6	18306
18109	5	46087	3	16996
18110	3	46089	4	17366
18111	5	46096	7	16500
18112	4	46098	2	18303
18113	5	46098	6	18303
18114	4	46099	2	18268
18115	4	46100	7	18263
18116	5	46102	1	18255
18117	4	46118	7	12089
18118	5	46119	2	1013
18119	5	46120	6	18302
18120	5	46122	6	466
18121	5	46125	5	3971
18122	5	46129	4	4986
18123	3	46130	3	13461
18124	5	46135	4	13707
18125	2	46140	1	10972
18126	5	46142	1	11172
18127	4	46144	7	1735
18128	5	46148	2	18258
18129	3	46152	7	11010
18130	4	46155	5	12180
18131	1	46157	6	18259
18132	5	46160	1	18279
18133	4	46161	5	6168
18134	5	46162	5	1759
18135	5	46166	4	17084
18136	5	46167	6	18464
18137	4	46168	4	18380
18138	5	46169	1	11298
18139	5	46170	3	13335
18140	5	46172	1	1369
18141	4	46175	4	15350
18142	5	46181	4	5426
18143	5	46182	6	8355
18144	5	46184	7	7766
18145	5	46185	6	18365
18146	1	46186	6	6811
18147	4	46188	5	11284
18148	4	46193	7	790
18149	3	46195	4	10461
18150	5	46198	2	18393
18151	3	46200	6	17784
18152	4	46202	7	12615
18153	4	46202	5	12615
18154	4	46203	1	18443
18155	5	46206	3	34
18156	5	46207	6	14844
18157	4	46209	7	1485
18158	5	46210	2	5787
18159	4	46213	2	5379
18160	4	46215	6	13578
18161	5	46217	1	18441
18162	1	46218	6	10144
18163	5	46222	6	985
18164	5	46223	2	10497
18165	5	46225	3	5382
18166	3	46226	7	6499
18167	4	46229	7	8877
18168	5	46230	6	3740
18169	5	46232	6	4
18170	5	46237	1	17205
18171	4	46237	6	17205
18172	1	46241	3	18398
18173	5	46243	2	169
18174	4	46245	3	18487
18175	5	46246	7	1674
18176	5	46247	2	18456
18177	5	46250	6	16823
18178	5	46251	3	18439
18179	5	46254	2	3521
18180	4	46255	4	18412
18181	3	46256	6	5997
18182	5	46259	4	9166
18183	4	46260	7	18433
18184	5	46261	6	18471
18185	3	46263	7	18445
18186	5	46264	7	15121
18187	5	46264	5	15121
18188	4	46266	3	6235
18189	4	46268	7	4649
18190	5	46269	2	7289
18191	5	46270	6	18396
18192	3	46271	5	18457
18193	5	46272	3	14221
18194	3	46273	7	8659
18195	5	46274	4	3002
18196	5	46275	7	18372
18197	5	46276	6	10729
18198	5	46277	6	16366
18199	5	46278	2	18474
18200	5	46279	3	2912
18201	5	46282	6	18437
18202	5	46282	2	18437
18203	4	46284	6	18374
18204	5	46289	5	3137
18205	3	46290	6	3992
18206	4	46291	7	16341
18207	5	46292	5	7418
18208	4	46294	3	18432
18209	5	46295	4	7730
18210	4	46298	5	18468
18211	4	46299	7	877
18212	4	46300	4	15966
18213	5	46304	6	14201
18214	3	46306	5	18446
18215	4	46308	5	18470
18216	5	46310	3	10935
18217	3	46311	5	13131
18218	3	46313	1	18400
18219	4	46314	6	18478
18220	5	46318	1	4870
18221	5	46321	7	15727
18222	3	46323	4	18363
18223	5	46327	2	10317
18224	4	46328	1	1988
18225	4	46329	5	8920
18226	4	46330	5	12546
18227	5	46330	4	12546
18228	4	46331	4	2933
18229	4	46334	3	431
18230	5	46336	7	11603
18231	5	46341	7	18257
18232	3	46341	5	18257
18233	4	46346	1	18394
18234	5	46347	6	18391
18235	2	46349	6	5002
18236	5	46351	1	18410
18237	4	46352	5	14816
18238	5	46355	5	18408
18239	3	46359	7	6916
18240	5	46362	6	18377
18241	4	46363	4	18369
18242	2	46365	3	11260
18243	3	46366	7	18486
18244	5	46368	5	7933
18245	5	46371	1	591
18246	5	46376	2	3472
18247	5	46378	4	11735
18248	5	46382	4	18381
18249	3	46383	7	18458
18250	5	46384	6	3312
18251	4	46385	5	3392
18252	3	46386	1	18417
18253	4	46387	7	18429
18254	4	46388	4	3825
18255	3	46389	3	18427
18256	4	46390	5	18406
18257	4	46391	5	18390
18258	5	46395	1	3401
18259	4	46397	5	17046
18260	3	46404	5	14421
18261	2	46404	3	14421
18262	5	46406	7	18438
18263	5	46409	1	2850
18264	4	46410	2	18483
18265	5	46410	6	18483
18266	4	46413	7	4436
18267	5	46415	5	5574
18268	5	46415	4	5574
18269	5	46418	6	13620
18270	5	46425	2	3007
18271	5	46426	6	18482
18272	3	46429	1	18414
18273	5	46431	6	8856
18274	5	46432	7	7806
18275	5	46433	3	6798
18276	4	46443	5	18477
18277	4	46448	5	6296
18278	5	46449	1	7204
18279	4	46451	7	18453
18280	4	46452	2	18479
18281	5	46453	5	4797
18282	5	46455	2	18469
18283	5	46455	5	18469
18284	5	46458	3	18397
18285	5	46460	4	5311
18286	5	46463	5	845
18287	5	46465	6	4594
18288	5	46466	7	18489
18289	5	46467	1	18413
18290	5	46469	4	13570
18291	3	46470	3	18476
18292	5	46476	3	12819
18293	5	46479	7	5822
18294	3	46482	1	18385
18295	5	46484	2	18364
18296	4	46486	6	4937
18297	5	46487	5	11353
18298	5	46489	4	18379
18299	4	46490	7	184
18300	4	46491	1	3059
18301	5	46493	7	12206
18302	3	46495	3	15284
18303	4	46498	1	15109
18304	3	46500	5	8613
18305	5	46503	4	18435
18306	5	46505	4	15283
18307	3	46506	1	17002
18308	3	46507	5	4022
18309	5	46512	5	15201
18310	4	46515	7	14392
18311	3	46517	7	18465
18312	5	46518	4	18401
18313	5	46519	2	5882
18314	5	46520	4	227
18315	5	46522	4	17667
18316	3	46523	5	15022
18317	3	46524	5	18382
18318	5	46525	6	7410
18319	4	46529	7	7862
18320	2	46530	6	18454
18321	5	46531	7	11395
18322	5	46535	7	18367
18323	5	46538	6	9367
18324	3	46539	7	18472
18325	5	46540	6	13228
18326	5	46545	2	18031
18327	1	46546	6	1513
18328	5	46549	3	16250
18329	5	46550	4	18466
18330	5	46554	6	12500
18331	4	46556	5	749
18332	5	46558	1	18079
18333	5	46562	7	18459
18334	5	46564	4	8363
18335	4	46565	1	18420
18336	5	46567	4	11091
18337	4	46568	4	5667
18338	4	46570	4	3509
18339	5	46576	2	18632
18340	5	46576	7	18632
18341	4	46578	7	10829
18342	5	46583	4	7388
18343	5	46583	7	7388
18344	5	46586	2	18502
18345	3	46587	4	14739
18346	5	46590	6	18577
18347	5	46591	4	15722
18348	4	46596	2	15126
18349	4	46597	7	3851
18350	5	46600	7	18555
18351	4	46601	2	18590
18352	3	46604	7	18606
18353	4	46605	7	18592
18354	4	46608	2	10023
18355	5	46611	7	8546
18356	5	46615	2	12559
18357	4	46617	6	11017
18358	3	46626	2	16549
18359	5	46630	4	18579
18360	5	46632	6	778
18361	4	46633	4	17884
18362	4	46634	6	3605
18363	5	46635	4	16992
18364	5	46637	6	1928
18365	3	46638	4	14190
18366	4	46642	7	18644
18367	5	46645	3	111
18368	4	46648	7	2748
18369	1	46649	4	4979
18370	5	46654	6	18607
18371	5	46658	4	17807
18372	5	46665	4	11491
18373	5	46666	6	135
18374	5	46667	1	2867
18375	3	46668	1	1946
18376	5	46668	3	1946
18377	4	46669	7	11276
18378	4	46671	6	14127
18379	5	46675	6	907
18380	5	46676	4	12265
18381	5	46678	3	1129
18382	3	46680	2	260
18383	4	46681	7	6200
18384	5	46684	2	18585
18385	4	46685	3	17531
18386	5	46688	2	9554
18387	4	46689	3	18596
18388	4	46692	3	6652
18389	4	46693	1	18509
18390	5	46697	1	18545
18391	5	46700	5	6163
18392	5	46701	6	12414
18393	3	46703	5	11397
18394	5	46706	2	15267
18395	3	46709	5	18613
18396	3	46710	7	6219
18397	5	46712	6	18518
18398	3	46718	3	16680
18399	3	46721	5	9225
18400	5	46722	2	18505
18401	5	46723	6	8730
18402	4	46726	2	18520
18403	5	46728	6	15384
18404	5	46729	2	12268
18405	4	46730	7	4855
18406	5	46739	5	18568
18407	5	46745	6	1006
18408	5	46746	7	18639
18409	5	46753	2	18528
18410	5	46754	6	18619
18411	5	46761	5	4356
18412	4	46765	1	13950
18413	4	46766	5	10354
18414	5	46767	3	14756
18415	5	46768	3	18626
18416	1	46768	6	18626
18417	3	46771	2	18610
18418	3	46772	7	5707
18419	5	46773	2	11488
18420	4	46775	1	18532
18421	5	46776	1	10032
18422	4	46777	5	10772
18423	5	46778	1	13948
18424	5	46779	3	14807
18425	5	46782	4	4994
18426	5	46785	2	18608
18427	5	46786	5	18603
18428	5	46787	2	18589
18429	5	46787	6	18589
18430	3	46790	4	13907
18431	3	46793	7	3476
18432	4	46795	1	18506
18433	5	46801	5	9348
18434	5	46802	4	623
18435	5	46803	3	3289
18436	4	46811	4	11923
18437	5	46814	4	3619
18438	5	46819	3	132
18439	5	46820	4	9867
18440	5	46821	4	4876
18441	4	46822	1	18627
18442	5	46826	6	18612
18443	5	46829	2	1657
18444	3	46830	3	18563
18445	5	46833	4	3616
18446	4	46837	4	659
18447	3	46839	5	3609
18448	5	46845	4	18637
18449	5	46847	3	13708
18450	3	46850	4	1309
18451	3	46851	4	1546
18452	5	46864	6	18514
18453	4	46866	7	15452
18454	5	46871	7	10552
18455	1	46872	1	16384
18456	5	46873	6	18624
18457	5	46876	2	18375
18458	5	46878	6	18567
18459	5	46891	4	2320
18460	5	46892	2	2020
18461	4	46893	7	18633
18462	5	46898	6	18609
18463	3	46900	4	6680
18464	5	46901	2	18529
18465	5	46905	3	7687
18466	5	46908	3	18554
18467	4	46909	7	18566
18468	5	46910	6	11366
18469	3	46911	4	9295
18470	5	46914	4	18628
18471	3	46915	4	13055
18472	1	46918	1	18564
18473	3	46924	7	11693
18474	1	46930	6	3703
18475	3	46931	4	13639
18476	5	46932	5	13758
18477	5	46933	2	12997
18478	5	46937	2	3415
18479	5	46938	7	18625
18480	5	46942	4	18586
18481	3	46942	6	18586
18482	3	46946	4	18548
18483	5	46948	7	3519
18484	4	46950	2	18540
18485	5	46951	1	18521
18486	5	46953	6	18611
18487	5	46956	6	11543
18488	3	46957	1	18500
18489	4	46958	7	17870
18490	5	46960	2	16603
18491	3	46960	1	16603
18492	4	46961	5	18549
18493	4	46964	3	1215
18494	4	46965	7	351
18495	3	46966	4	1731
18496	5	46967	1	18636
18497	3	46969	5	16670
18498	3	46975	7	18578
18499	4	46975	4	18578
18500	5	46976	1	7025
18501	4	46979	7	2847
18502	5	46983	4	11040
18503	4	46986	7	1106
18504	5	46988	6	3211
18505	5	46992	1	18507
18506	5	46993	6	11983
18507	4	46994	1	18472
18508	4	46995	6	18635
18509	5	46998	6	17268
18510	5	46999	2	18588
18511	3	47002	6	17013
18512	5	47009	7	18498
18513	4	47011	1	5761
18514	3	47016	3	1174
18515	5	47017	6	18504
18516	5	47018	4	15780
18517	5	47021	2	9182
18518	5	47026	1	18492
18519	5	47027	4	9733
18520	4	47028	5	3447
18521	3	47031	7	16039
18522	2	47032	6	18512
18523	5	47033	6	2689
18524	2	47034	6	18621
18525	5	47036	3	18616
18526	4	47037	6	14475
18527	3	47038	5	10738
18528	5	47040	6	18386
18529	3	47041	5	7918
18530	3	47045	3	18643
18531	4	47050	2	13012
18532	2	47052	3	18571
18533	3	47053	3	18573
18534	1	47056	6	18572
18535	4	47060	7	18595
18536	4	47061	7	18497
18537	5	47066	6	13933
18538	4	47067	5	18620
18539	5	47074	2	17423
18540	5	47077	2	18227
18541	4	47079	7	9810
18542	5	47081	6	17100
18543	4	47085	1	16822
18544	5	47089	7	18730
18545	4	47093	7	18721
18546	2	47094	6	8094
18547	5	47097	1	8213
18548	5	47098	7	7852
18549	5	47099	3	3567
18550	4	47100	2	18714
18551	5	47101	5	16298
18552	5	47102	4	18710
18553	4	47105	5	4605
18554	5	47108	6	3887
18555	4	47114	2	7050
18556	5	47115	5	499
18557	1	47120	6	17351
18558	3	47124	7	18666
18559	5	47128	2	15048
18560	4	47129	5	18773
18561	3	47130	5	17436
18562	5	47132	4	18745
18563	1	47138	6	18658
18564	3	47139	3	18646
18565	5	47140	2	16041
18566	5	47141	6	16498
18567	5	47142	4	18668
18568	4	47149	7	18680
18569	5	47151	1	18652
18570	4	47152	4	5843
18571	5	47153	4	6137
18572	5	47160	2	4786
18573	4	47161	2	18682
18574	5	47163	4	13167
18575	5	47166	1	9102
18576	3	47167	2	18765
18577	4	47169	2	8822
18578	2	47170	1	12198
18579	5	47171	6	11570
18580	1	47173	6	2210
18581	4	47173	5	2210
18582	4	47174	6	17732
18583	4	47176	5	16687
18584	5	47179	2	17777
18585	4	47181	4	7815
18586	5	47182	7	17329
18587	5	47185	6	4342
18588	5	47186	7	8010
18589	5	47188	1	2054
18590	5	47191	6	11402
18591	5	47199	4	18766
18592	4	47200	5	9908
18593	3	47201	6	7450
18594	5	47205	6	16406
18595	5	47209	1	18724
18596	4	47212	2	10218
18597	5	47213	1	18657
18598	5	47219	7	18739
18599	4	47226	6	15837
18600	3	47227	5	17467
18601	3	47231	1	2056
18602	5	47235	2	8322
18603	3	47236	1	12596
18604	3	47238	5	4522
18605	5	47240	7	18655
18606	4	47241	2	18723
18607	5	47242	5	18735
18608	5	47244	3	18744
18609	4	47249	5	4396
18610	4	47250	2	4973
18611	5	47257	4	18692
18612	5	47259	7	5735
18613	5	47261	5	13450
18614	4	47264	7	18742
18615	5	47269	7	18769
18616	4	47270	2	11944
18617	5	47272	6	16136
18618	4	47272	1	16136
18619	5	47273	7	10533
18620	5	47277	2	12098
18621	5	47278	1	14651
18622	4	47282	2	17739
18623	5	47284	6	18699
18624	5	47285	5	18687
18625	5	47289	4	6221
18626	4	47290	7	13352
18627	3	47291	5	5310
18628	3	47293	7	18757
18629	4	47296	7	3616
18630	3	47297	7	18688
18631	4	47299	4	2289
18632	4	47299	5	2289
18633	5	47300	2	1055
18634	3	47300	5	1055
18635	2	47304	5	7258
18636	5	47307	2	13643
18637	5	47308	4	17941
18638	5	47310	1	9231
18639	5	47311	6	18780
18640	5	47316	6	4982
18641	5	47317	5	18803
18642	5	47319	2	18865
18643	3	47322	5	3626
18644	5	47323	7	18879
18645	3	47324	5	9374
18646	1	47324	6	9374
18647	5	47330	4	1837
18648	5	47334	7	18801
18649	5	47338	3	18816
18650	5	47342	6	3760
18651	3	47342	7	3760
18652	4	47346	4	6403
18653	5	47347	5	17038
18654	4	47349	1	3372
18655	4	47354	7	18779
18656	4	47355	7	13947
18657	5	47358	1	10350
18658	5	47358	3	10350
18659	5	47363	6	3012
18660	5	47365	6	18869
18661	5	47366	5	18791
18662	3	47375	4	398
18663	5	47378	4	5473
18664	4	47381	7	14972
18665	5	47382	6	8421
18666	5	47383	1	14735
18667	5	47384	4	17622
18668	3	47387	1	5030
18669	5	47389	2	18283
18670	5	47390	6	18792
18671	4	47395	5	18903
18672	5	47399	2	5003
18673	5	47401	4	17839
18674	5	47402	6	16834
18675	3	47409	2	18813
18676	5	47409	4	18813
18677	5	47413	2	14644
18678	4	47414	5	18852
18679	5	47416	6	18853
18680	4	47416	4	18853
18681	4	47418	7	17251
18682	5	47420	5	188
18683	5	47421	7	18815
18684	5	47429	1	8977
18685	5	47429	4	8977
18686	5	47432	7	8521
18687	3	47433	7	4638
18688	5	47437	7	18822
18689	3	47438	1	14290
18690	5	47439	3	18893
18691	5	47442	7	18798
18692	5	47444	2	17100
18693	5	47445	6	1316
18694	5	47446	1	12254
18695	3	47448	7	229
18696	4	47449	2	6965
18697	5	47453	4	18894
18698	5	47459	6	2543
18699	5	47460	2	1618
18700	3	47462	5	9058
18701	3	47464	7	12231
18702	2	47467	2	18808
18703	3	47470	3	16911
18704	5	47473	4	15365
18705	5	47476	6	11418
18706	5	47479	7	18871
18707	4	47481	4	600
18708	3	47484	7	18835
18709	5	47485	7	12043
18710	4	47487	1	8519
18711	5	47489	4	18875
18712	4	47490	1	3835
18713	5	47496	2	3066
18714	5	47502	1	1352
18715	5	47503	5	18827
18716	5	47505	2	18882
18717	5	47510	6	18810
18718	5	47511	6	10823
18719	1	47514	2	18836
18720	5	47523	3	6192
18721	5	47523	2	6192
18722	5	47524	4	6390
18723	3	47525	4	18795
18724	5	47525	6	18795
18725	5	47526	6	4503
18726	5	47527	6	6287
18727	4	47529	7	18782
18728	5	47530	6	3540
18729	5	47532	4	44
18730	5	47533	2	17363
18731	3	47534	3	11187
18732	3	47537	1	61
18733	5	47538	7	16594
18734	5	47539	5	3318
18735	3	47540	1	18828
18736	3	47541	7	18885
18737	4	47544	2	11374
18738	3	47545	5	2668
18739	4	47545	3	2668
18740	4	47548	7	6462
18741	3	47549	1	18823
18742	5	47550	4	18834
18743	5	47552	6	11590
18744	5	47554	6	18870
18745	1	47555	6	18863
18746	5	47556	2	18883
18747	4	47559	6	18794
18748	4	47559	4	18794
18749	5	47561	5	18968
18750	4	47564	5	13720
18751	4	47567	7	11041
18752	3	47568	5	2287
18753	2	47570	3	20
18754	5	47575	2	18906
18755	4	47576	7	18375
18756	4	47577	6	4564
18757	4	47580	5	9060
18758	5	47581	6	18910
18759	3	47581	3	18910
18760	5	47583	2	8834
18761	4	47587	6	519
18762	4	47588	7	13221
18763	2	47589	6	18990
18764	5	47592	1	17667
18765	5	47593	6	15407
18766	2	47595	6	217
18767	3	47597	2	14686
18768	5	47598	6	14820
18769	5	47606	6	8202
18770	3	47609	5	15155
18771	3	47610	1	10062
18772	5	47617	7	16483
18773	5	47621	7	8781
18774	4	47625	5	12359
18775	4	47627	6	19025
18776	5	47630	6	806
18777	3	47634	5	11458
18778	5	47636	3	5928
18779	5	47637	2	18937
18780	4	47638	2	18981
18781	4	47639	5	9355
18782	4	47640	1	15114
18783	5	47641	2	2951
18784	5	47646	5	9839
18785	4	47647	3	16147
18786	5	47647	6	16147
18787	3	47649	7	16346
18788	5	47651	4	1435
18789	3	47654	1	11156
18790	4	47656	3	11635
18791	4	47657	5	18302
18792	5	47665	2	19003
18793	3	47666	1	2579
18794	4	47667	1	3912
18795	4	47669	1	2367
18796	5	47671	6	19049
18797	5	47674	2	4981
18798	5	47678	6	18940
18799	5	47681	4	7416
18800	5	47682	3	18927
18801	3	47684	1	1780
18802	4	47691	7	19007
18803	5	47694	2	13012
18804	5	47695	1	9449
18805	4	47696	6	10679
18806	5	47697	7	1577
18807	4	47698	6	17227
18808	5	47701	7	19033
18809	4	47701	4	19033
18810	4	47704	5	10161
18811	5	47708	6	15966
18812	5	47714	4	14258
18813	5	47715	6	6182
18814	4	47717	2	10442
18815	3	47718	7	18962
18816	4	47723	5	13079
18817	4	47724	1	6028
18818	4	47725	1	138
18819	3	47727	5	19024
18820	5	47729	7	18938
18821	5	47737	6	19036
18822	5	47739	2	6634
18823	5	47740	1	18963
18824	4	47742	7	19018
18825	3	47744	4	1212
18826	5	47745	5	19028
18827	2	47747	6	8054
18828	5	47748	1	19041
18829	5	47750	7	16681
18830	5	47751	6	6404
18831	3	47753	5	16277
18832	5	47759	4	18985
18833	5	47761	2	11729
18834	3	47761	7	11729
18835	2	47766	5	4057
18836	4	47770	5	10966
18837	4	47772	5	6945
18838	5	47776	2	552
18839	5	47777	3	5141
18840	3	47778	3	2425
18841	4	47784	1	19044
18842	5	47785	7	344
18843	3	47792	7	19016
18844	5	47795	1	19035
18845	5	47797	5	5691
18846	5	47799	6	14002
18847	5	47800	2	2059
18848	4	47801	5	18972
18849	4	47803	2	13512
18850	3	47805	2	19015
18851	4	47808	1	6134
18852	5	47809	4	18996
18853	4	47811	6	18935
18854	5	47811	7	18935
18855	5	47812	2	18912
18856	5	47814	7	8903
18857	5	47816	7	1097
18858	5	47817	5	7891
18859	3	47821	5	2618
18860	5	47825	5	19000
18861	3	47829	1	2890
18862	4	47830	2	12699
18863	5	47831	2	18929
18864	5	47832	6	8901
18865	3	47834	2	15202
18866	3	47835	5	5264
18867	5	47839	1	10103
18868	5	47840	4	18965
18869	5	47841	6	18945
18870	5	47842	6	12095
18871	5	47843	4	14417
18872	5	47844	2	5361
18873	3	47846	7	784
18874	4	47847	6	19032
18875	5	47849	2	18920
18876	3	47857	4	3332
18877	5	47862	1	15241
18878	5	47863	5	17649
18879	5	47873	7	2748
18880	5	47875	6	19023
18881	3	47876	4	18960
18882	5	47881	6	6229
18883	1	47882	6	837
18884	4	47883	1	5642
18885	5	47885	7	18926
18886	5	47890	6	9787
18887	4	47898	2	13734
18888	4	47900	5	2557
18889	4	47907	3	399
18890	5	47908	1	5407
18891	5	47912	6	5817
18892	5	47913	6	17683
18893	4	47915	5	15828
18894	1	47916	6	18917
18895	4	47918	1	19006
18896	5	47920	2	19010
18897	4	47921	7	7157
18898	5	47922	4	12613
18899	3	47923	1	19166
18900	5	47924	6	8242
18901	5	47928	1	7022
18902	5	47930	6	286
18903	4	47931	1	19167
18904	4	47932	3	19089
18905	5	47935	6	15437
18906	5	47939	3	19159
18907	5	47942	5	13418
18908	3	47943	7	19090
18909	5	47944	7	19073
18910	3	47948	6	19162
18911	3	47949	5	19115
18912	4	47952	5	11115
18913	4	47954	1	9934
18914	3	47958	3	13477
18915	5	47960	6	19145
18916	5	47963	1	14764
18917	4	47964	4	15410
18918	3	47965	1	10289
18919	3	47966	2	11159
18920	5	47968	3	14997
18921	5	47969	2	1149
18922	2	47972	6	3619
18923	5	47973	4	17775
18924	4	47974	5	12930
18925	5	47976	6	15889
18926	5	47980	2	10950
18927	4	47981	7	2085
18928	5	47982	2	10690
18929	5	47985	6	1072
18930	5	47988	5	11320
18931	3	47989	3	13412
18932	4	47994	6	14737
18933	5	47997	6	6548
18934	5	48002	7	11587
18935	5	48003	5	19163
18936	4	48004	7	16320
18937	5	48007	2	19061
18938	5	48011	4	2739
18939	5	48013	1	1889
18940	4	48017	2	19176
18941	5	48018	3	839
18942	5	48025	6	19144
18943	3	48028	5	3887
18944	4	48031	2	18434
18945	4	48033	5	19063
18946	3	48034	2	17278
18947	5	48035	1	13324
18948	5	48037	2	19153
18949	5	48038	7	19076
18950	4	48045	5	15361
18951	5	48046	6	19093
18952	4	48048	5	19112
18953	3	48050	7	19132
18954	5	48051	6	19081
18955	4	48055	3	6202
18956	4	48056	3	10365
18957	5	48057	1	19059
18958	5	48058	4	8934
18959	4	48062	5	6901
18960	5	48063	4	2131
18961	3	48064	3	19105
18962	5	48066	3	12666
18963	5	48072	4	18755
18964	5	48073	3	19104
18965	5	48076	2	6950
18966	3	48081	2	11385
18967	1	48085	6	5400
18968	3	48089	5	6566
18969	4	48094	7	18514
18970	5	48095	1	6645
18971	3	48099	5	19155
18972	5	48100	4	12772
18973	3	48102	5	17171
18974	4	48106	1	18306
18975	4	48107	5	19164
18976	3	48108	5	19054
18977	4	48109	6	19075
18978	4	48110	4	584
18979	5	48111	5	19055
18980	3	48113	3	543
18981	5	48113	4	543
18982	5	48116	2	17652
18983	4	48119	5	19100
18984	4	48120	4	6905
18985	4	48120	1	6905
18986	4	48121	5	19103
18987	3	48123	3	11932
18988	5	48124	4	3689
18989	3	48130	7	3125
18990	4	48132	4	12150
18991	5	48134	4	18032
18992	5	48135	6	19096
18993	5	48138	1	9466
18994	5	48139	2	4912
18995	5	48139	6	4912
18996	5	48140	2	19052
18997	5	48145	4	10954
18998	4	48147	2	9442
18999	4	48148	7	19092
19000	5	48154	2	456
19001	5	48159	2	13559
19002	3	48160	1	17116
19003	5	48161	5	4865
19004	5	48170	4	19168
19005	5	48176	2	2952
19006	4	48179	4	14392
19007	3	48182	5	13542
19008	5	48183	2	4856
19009	4	48184	4	19143
19010	4	48187	7	18612
19011	3	48189	5	19160
19012	4	48190	5	19150
19013	1	48193	6	15009
19014	5	48194	6	13047
19015	5	48195	1	2492
19016	3	48197	1	15563
19017	5	48198	2	19106
19018	5	48200	7	15034
19019	5	48207	4	2729
19020	5	48209	3	9467
19021	5	48211	4	12541
19022	3	48213	3	16431
19023	4	48216	2	19072
19024	3	48217	7	15407
19025	5	48219	3	19101
19026	4	48220	2	19062
19027	1	48221	6	15902
19028	5	48224	6	10244
19029	5	48228	2	11093
19030	5	48228	7	11093
19031	5	48229	6	13261
19032	4	48230	7	8454
19033	4	48232	7	6444
19034	5	48233	2	3730
19035	5	48235	1	11647
19036	5	48240	3	19161
19037	3	48243	7	19070
19038	5	48244	1	12650
19039	5	48246	6	7
19040	4	48248	7	19175
19041	4	48249	7	19120
19042	3	48254	7	7017
19043	5	48257	6	10284
19044	5	48260	3	15189
19045	4	48262	3	19131
19046	1	48265	6	19156
19047	4	48266	2	9563
19048	5	48268	3	10313
19049	5	48270	2	19066
19050	5	48271	4	14089
19051	5	48272	2	9628
19052	4	48273	5	19141
19053	4	48276	4	807
19054	5	48277	4	4342
19055	4	48280	2	13413
19056	5	48282	7	19246
19057	4	48283	1	19276
19058	3	48287	2	2078
19059	5	48289	2	17664
19060	3	48291	4	372
19061	3	48294	4	19179
19062	3	48299	5	19185
19063	4	48303	7	19260
19064	5	48306	2	19232
19065	5	48308	4	2415
19066	3	48309	7	8002
19067	5	48312	6	19258
19068	5	48321	6	19326
19069	3	48322	5	18330
19070	5	48325	5	15766
19071	5	48327	6	19251
19072	3	48327	5	19251
19073	5	48328	6	19277
19074	5	48331	1	19234
19075	5	48333	6	19305
19076	3	48335	5	19228
19077	3	48336	1	8339
19078	5	48337	3	19218
19079	5	48342	7	19213
19080	3	48348	7	9235
19081	3	48349	1	3940
19082	1	48350	4	7341
19083	5	48351	2	13951
19084	5	48353	4	19205
19085	3	48356	3	19320
19086	5	48359	4	19269
19087	5	48360	1	12648
19088	5	48362	6	19294
19089	3	48363	2	6371
19090	5	48364	2	2384
19091	4	48369	2	10666
19092	1	48372	1	16443
19093	2	48373	6	19257
19094	5	48375	6	19291
19095	4	48377	2	2556
19096	3	48378	5	19308
19097	3	48379	1	7983
19098	5	48380	6	19242
19099	5	48380	2	19242
19100	3	48383	7	9535
19101	5	48388	7	15426
19102	5	48391	6	19183
19103	5	48394	1	12263
19104	5	48395	1	18602
19105	5	48397	2	11031
19106	5	48399	4	19236
19107	5	48400	1	17794
19108	3	48403	1	2434
19109	4	48404	5	10296
19110	5	48408	2	17412
19111	5	48409	3	19198
19112	5	48411	7	1106
19113	3	48413	5	19323
19114	4	48417	1	15490
19115	3	48423	7	19315
19116	3	48424	2	19283
19117	5	48425	6	19203
19118	5	48427	2	19322
19119	4	48428	3	18122
19120	5	48430	7	19235
19121	3	48431	5	11283
19122	5	48432	4	7682
19123	4	48433	7	7044
19124	5	48435	2	17889
19125	4	48437	2	14248
19126	5	48438	1	268
19127	5	48439	1	7338
19128	4	48440	7	15528
19129	5	48445	2	1638
19130	5	48447	4	19262
19131	4	48448	1	19267
19132	3	48450	1	19204
19133	5	48451	6	3979
19134	5	48452	6	13602
19135	4	48453	3	11146
19136	1	48454	7	19083
19137	4	48454	3	19083
19138	5	48459	7	15235
19139	4	48465	7	3231
19140	4	48469	5	13303
19141	5	48472	6	4471
19142	3	48473	5	19244
19143	5	48475	7	15690
19144	5	48477	5	15600
19145	5	48479	6	16501
19146	5	48485	7	10651
19147	3	48486	3	18409
19148	5	48487	4	5975
19149	5	48487	2	5975
19150	4	48489	3	11681
19151	5	48492	5	19216
19152	5	48493	6	6526
19153	5	48494	2	8188
19154	5	48497	2	497
19155	4	48500	2	19195
19156	3	48502	5	7103
19157	3	48504	3	3332
19158	4	48505	3	2780
19159	5	48506	6	11217
19160	5	48508	6	18500
19161	5	48509	2	19290
19162	4	48511	1	19212
19163	5	48515	1	11334
19164	3	48519	7	14711
19165	4	48520	6	19264
19166	5	48523	5	19263
19167	5	48525	4	16677
19168	3	48529	2	5511
19169	5	48532	3	719
19170	2	48532	6	719
19171	2	48534	6	12199
19172	3	48537	1	72
19173	3	48538	1	12811
19174	5	48539	2	12180
19175	5	48541	6	5523
19176	4	48543	1	17472
19177	4	48544	1	4465
19178	4	48547	2	8074
19179	5	48549	6	19333
19180	4	48557	6	19192
19181	1	48558	5	19295
19182	4	48560	1	19239
19183	3	48568	7	19288
19184	5	48578	6	19226
19185	5	48579	3	4641
19186	5	48580	5	19280
19187	5	48583	7	4061
19188	3	48586	4	16749
19189	4	48588	5	19271
19190	5	48589	5	562
19191	5	48592	2	7705
19192	3	48593	5	19328
19193	5	48594	2	5019
19194	3	48596	4	19219
19195	5	48597	4	18793
19196	5	48599	7	19292
19197	5	48601	6	16840
19198	4	48603	5	9725
19199	5	48604	2	527
19200	5	48608	2	19307
19201	5	48609	2	7451
19202	4	48614	5	19191
19203	5	48617	5	1079
19204	2	48618	4	19266
19205	4	48628	6	4618
19206	5	48629	6	19509
19207	5	48631	5	17370
19208	2	48631	4	17370
19209	3	48632	2	17431
19210	3	48636	7	14813
19211	4	48637	7	16951
19212	5	48639	1	14089
19213	5	48642	1	3040
19214	5	48646	1	11686
19215	3	48648	5	19343
19216	5	48650	7	3579
19217	4	48652	5	19459
19218	4	48652	3	19459
19219	3	48656	2	12024
19220	5	48657	7	16954
19221	5	48661	4	19418
19222	4	48663	3	14547
19223	5	48664	6	9976
19224	5	48665	6	5292
19225	3	48666	2	15776
19226	4	48668	2	14081
19227	5	48673	4	14263
19228	4	48675	5	6740
19229	5	48678	3	19447
19230	5	48682	2	19511
19231	5	48685	2	3964
19232	3	48686	7	14290
19233	3	48689	7	19475
19234	5	48690	2	19453
19235	5	48693	5	19371
19236	5	48695	7	15829
19237	5	48696	4	19407
19238	5	48697	5	19500
19239	5	48697	6	19500
19240	5	48700	2	19375
19241	5	48701	1	19436
19242	5	48703	6	19445
19243	3	48706	1	17790
19244	3	48708	6	4060
19245	4	48710	5	19380
19246	3	48711	7	11260
19247	5	48713	3	19457
19248	4	48714	1	19351
19249	3	48716	7	11087
19250	4	48724	7	12907
19251	5	48725	4	9941
19252	5	48726	7	19485
19253	5	48727	3	14167
19254	5	48728	1	204
19255	5	48729	6	19346
19256	5	48730	6	19419
19257	4	48738	4	19424
19258	4	48739	7	19498
19259	5	48740	7	19411
19260	5	48744	4	9742
19261	4	48747	4	44
19262	5	48749	4	10809
19263	4	48750	2	10590
19264	5	48752	2	6918
19265	4	48755	1	19451
19266	5	48759	4	19250
19267	3	48761	2	19448
19268	4	48762	1	19480
19269	1	48762	2	19480
19270	5	48764	7	19491
19271	5	48769	2	6163
19272	4	48771	6	19348
19273	1	48772	6	17066
19274	1	48775	6	19431
19275	5	48778	4	13977
19276	5	48783	1	5894
19277	3	48794	6	19402
19278	5	48800	5	935
19279	4	48801	4	15292
19280	5	48801	3	15292
19281	5	48803	6	1557
19282	5	48805	7	17154
19283	3	48806	2	3440
19284	5	48808	6	12127
19285	5	48809	1	786
19286	5	48811	7	8706
19287	4	48812	6	19483
19288	3	48821	3	19377
19289	3	48823	6	19363
19290	4	48828	6	8861
19291	5	48829	4	16261
19292	4	48831	6	15768
19293	3	48838	3	19444
19294	5	48839	6	4489
19295	5	48842	2	19383
19296	5	48843	7	19496
19297	5	48845	2	19482
19298	5	48849	7	19501
19299	4	48850	5	7741
19300	3	48854	1	4411
19301	5	48855	5	2662
19302	5	48857	2	11735
19303	5	48858	2	9910
19304	5	48859	5	19464
19305	4	48861	7	19422
19306	5	48862	2	19512
19307	3	48866	4	11666
19308	3	48868	7	19502
19309	4	48870	5	16045
19310	5	48877	4	19387
19311	4	48879	5	19484
19312	5	48882	1	15525
19313	5	48882	6	15525
19314	3	48883	7	19361
19315	4	48885	6	19489
19316	5	48888	7	11535
19317	5	48889	2	5654
19318	4	48890	5	17725
19319	3	48892	5	7647
19320	4	48899	5	2799
19321	5	48902	4	15249
19322	5	48904	2	6206
19323	5	48905	3	6164
19324	4	48907	7	19362
19325	4	48910	3	19470
19326	3	48912	1	1087
19327	4	48913	1	7527
19328	5	48915	5	2753
19329	5	48916	7	17186
19330	5	48919	4	13754
19331	3	48925	4	7306
19332	5	48927	2	19473
19333	4	48928	7	1943
19334	5	48931	5	11077
19335	5	48934	2	1113
19336	5	48935	7	19366
19337	3	48936	2	3251
19338	5	48939	5	4869
19339	5	48943	3	138
19340	5	48944	2	18916
19341	5	48947	2	9560
19342	5	48951	1	19374
19343	5	48952	7	19349
19344	5	48954	1	17736
19345	3	48956	2	6661
19346	5	48958	7	4594
19347	4	48961	1	7771
19348	5	48962	3	14330
19349	5	48962	4	14330
19350	5	48970	6	9991
19351	3	48973	5	6301
19352	4	48977	2	19401
19353	5	48978	4	10013
19354	4	48979	1	19417
19355	5	48980	3	4502
19356	2	48981	1	1581
19357	5	48984	2	19458
19358	5	48989	2	16550
19359	5	48991	4	19460
19360	3	48993	4	10945
19361	5	48996	2	19378
19362	5	48996	3	19378
19363	2	48997	4	4645
19364	5	48998	5	3944
19365	4	49002	1	19443
19366	5	49003	6	1155
19367	5	49004	4	18036
19368	5	49010	6	19479
19369	4	49011	3	2064
19370	3	49014	7	19416
19371	5	49014	2	19416
19372	3	49015	5	19391
19373	4	49017	7	19397
19374	5	49018	3	440
19375	3	49020	5	13520
19376	5	49023	6	5666
19377	5	49025	2	3010
19378	5	49026	2	2932
19379	5	49027	4	15029
19380	4	49029	4	19446
19381	4	49037	2	6249
19382	4	49038	3	19505
19383	4	49039	7	8705
19384	5	49041	6	16916
19385	5	49042	3	1021
19386	3	49043	6	19404
19387	5	49044	4	15468
19388	5	49045	6	7772
19389	5	49050	4	14211
19390	5	49051	7	12675
19391	3	49053	5	8884
19392	5	49058	3	16803
19393	5	49060	7	19339
19394	5	49062	6	4271
19395	4	49066	7	19384
19396	3	49069	3	4216
19397	5	49070	4	1266
19398	5	49071	4	19439
19399	4	49072	1	19410
19400	5	49073	6	15365
19401	4	49076	5	19386
19402	5	49077	2	11973
19403	5	49083	6	5838
19404	4	49084	5	3467
19405	5	49087	6	887
19406	4	49090	5	17036
19407	4	49094	7	15752
19408	4	49099	2	6056
19409	5	49100	4	2464
19410	4	49102	5	4356
19411	4	49104	3	74
19412	5	49111	4	19630
19413	5	49112	5	12800
19414	5	49113	5	19652
19415	5	49115	1	1727
19416	4	49117	7	12263
19417	4	49119	1	19647
19418	4	49120	5	2843
19419	4	49121	7	9520
19420	3	49126	5	12208
19421	5	49126	6	12208
19422	5	49128	1	7354
19423	5	49129	2	9273
19424	5	49138	4	9685
19425	5	49144	6	19623
19426	4	49149	1	3494
19427	5	49150	7	19544
19428	5	49151	4	15187
19429	4	49152	3	19618
19430	5	49154	2	15555
19431	5	49155	3	16693
19432	5	49161	7	19535
19433	5	49163	2	6489
19434	5	49168	3	8939
19435	4	49169	3	14526
19436	3	49170	5	502
19437	3	49175	3	8797
19438	5	49183	6	237
19439	5	49184	2	519
19440	5	49184	6	519
19441	5	49185	7	19527
19442	3	49186	5	14074
19443	5	49188	2	5901
19444	3	49191	2	15022
19445	4	49193	3	19542
19446	4	49197	3	8977
19447	1	49200	5	19531
19448	5	49202	6	7125
19449	3	49204	5	5700
19450	5	49205	4	3256
19451	4	49207	4	19632
19452	5	49212	3	19563
19453	5	49217	5	8397
19454	4	49218	7	371
19455	3	49219	5	2595
19456	5	49222	2	19595
19457	5	49225	3	18040
19458	5	49226	3	9099
19459	5	49227	4	19569
19460	4	49229	3	1592
19461	5	49229	4	1592
19462	5	49232	4	13939
19463	4	49234	2	10951
19464	3	49236	1	5192
19465	5	49239	6	1049
19466	4	49245	2	19644
19467	4	49248	2	10787
19468	5	49248	3	10787
19469	5	49249	7	4515
19470	4	49252	1	13953
19471	5	49255	6	16422
19472	5	49259	4	19616
19473	4	49265	7	4794
19474	4	49266	2	6885
19475	5	49267	4	18392
19476	5	49268	2	19621
19477	4	49269	7	4055
19478	5	49270	2	11339
19479	4	49272	2	14233
19480	4	49276	6	19620
19481	5	49278	7	19539
19482	5	49281	2	19113
19483	4	49283	5	11366
19484	3	49284	5	6970
19485	5	49285	2	19628
19486	5	49286	6	13673
19487	3	49294	3	19562
19488	5	49294	6	19562
19489	4	49295	1	17792
19490	5	49297	3	1166
19491	4	49298	1	19590
19492	4	49299	7	16672
19493	4	49301	7	6049
19494	5	49305	6	11564
19495	5	49307	7	17306
19496	3	49309	4	19548
19497	5	49310	4	19583
19498	5	49311	6	19587
19499	3	49313	7	19574
19500	5	49316	1	9135
19501	3	49320	7	18558
19502	5	49323	6	19604
19503	3	49324	2	2026
19504	5	49331	1	7388
19505	4	49335	7	19557
19506	2	49336	6	19532
19507	5	49338	2	9850
19508	1	49341	6	7142
19509	5	49345	5	19545
19510	5	49346	1	19536
19511	5	49351	4	440
19512	5	49357	7	19640
19513	3	49358	3	19637
19514	5	49361	4	1537
19515	3	49363	2	19585
19516	3	49364	7	1582
19517	3	49368	3	5817
19518	3	49371	1	5975
19519	5	49372	6	9348
19520	3	49373	7	10432
19521	3	49374	7	15178
19522	4	49378	2	19379
19523	4	49379	7	201
19524	5	49380	7	12207
19525	5	49382	1	17874
19526	5	49382	6	17874
19527	5	49390	5	19651
19528	5	49392	2	1659
19529	4	49394	5	10499
19530	5	49399	1	3913
19531	5	49399	7	3913
19532	5	49400	7	4190
19533	4	49401	5	19556
19534	3	49404	2	19599
19535	5	49407	5	10796
19536	4	49407	3	10796
19537	3	49409	6	19634
19538	3	49410	3	37
19539	3	49412	5	10694
19540	4	49415	7	2209
19541	5	49417	7	15483
19542	5	49418	2	19600
19543	5	49419	2	19540
19544	5	49425	1	19577
19545	5	49426	3	12234
19546	5	49426	7	12234
19547	4	49432	5	19530
19548	2	49435	6	19553
19549	4	49437	3	12056
19550	5	49439	2	7148
19551	1	49444	2	18649
19552	5	49445	6	18403
19553	5	49446	3	10815
19554	5	49448	6	14726
19555	5	49449	3	19602
19556	5	49450	3	19558
19557	3	49450	5	19558
19558	2	49454	6	19573
19559	5	49454	7	19573
19560	4	49458	3	19610
19561	5	49459	6	6905
19562	3	49461	1	7589
19563	5	49462	2	13911
19564	2	49469	1	19636
19565	5	49478	5	19635
19566	3	49482	5	2498
19567	5	49485	6	17461
19568	4	49487	6	5942
19569	5	49493	2	15730
19570	1	49496	6	19524
19571	5	49498	3	15822
19572	4	49499	7	15394
19573	2	49500	6	19589
19574	3	49502	7	14493
19575	5	49505	7	19517
19576	4	49506	7	19565
19577	5	49507	6	7681
19578	4	49508	7	15327
19579	3	49510	4	9111
19580	4	49511	5	19648
19581	5	49512	7	18567
19582	5	49515	5	13711
19583	5	49516	5	4765
19584	5	49521	7	10807
19585	5	49522	3	16569
19586	5	49522	1	16569
19587	3	49523	3	5459
19588	3	49532	4	14299
19589	4	49535	4	9565
19590	5	49536	1	8877
19591	5	49538	1	9375
19592	5	49539	5	8185
19593	2	49540	4	19078
19594	4	49545	7	19613
19595	5	49552	4	19516
19596	3	49554	3	1423
19597	3	49557	3	5180
19598	4	49559	1	18031
19599	3	49560	4	7041
19600	3	49562	1	4862
19601	4	49564	2	19631
19602	4	49566	2	10206
19603	1	49570	6	584
19604	4	49571	5	8940
19605	5	49573	1	14737
19606	5	49574	4	1310
19607	5	49574	2	1310
19608	3	49578	7	6074
19609	4	49579	5	14691
19610	5	49581	7	15326
19611	5	49581	4	15326
19612	5	49582	1	3427
19613	5	49584	7	784
19614	5	49585	6	19601
19615	4	49586	5	6820
19616	5	49587	2	19608
19617	5	49589	5	8461
19618	5	49592	6	15855
19619	5	49593	6	8742
19620	4	49594	3	2310
19621	4	49597	7	19633
19622	5	49599	4	9116
19623	5	49603	1	19727
19624	4	49606	7	19670
19625	5	49607	7	2071
19626	5	49618	2	19700
19627	3	49619	3	19747
19628	5	49624	7	19749
19629	5	49629	6	11527
19630	4	49634	5	19669
19631	4	49636	5	14519
19632	5	49638	6	19668
19633	4	49639	7	19800
19634	4	49640	1	19735
19635	1	49641	6	19782
19636	3	49646	7	18729
19637	4	49648	1	15872
19638	4	49651	7	19753
19639	5	49652	4	12387
19640	5	49658	6	19690
19641	5	49659	2	15787
19642	5	49660	2	5213
19643	5	49662	4	12793
19644	5	49666	4	19741
19645	5	49667	2	10321
19646	5	49669	5	19733
19647	5	49671	1	6701
19648	5	49675	7	19798
19649	5	49680	2	1079
19650	5	49682	4	17794
19651	3	49682	1	17794
19652	4	49685	7	14742
19653	5	49687	2	19715
19654	1	49689	6	19785
19655	5	49694	6	19743
19656	5	49695	2	16958
19657	4	49696	7	19666
19658	5	49697	7	19689
19659	3	49699	3	19809
19660	4	49700	3	19812
19661	5	49703	2	19792
19662	5	49706	1	1984
19663	5	49707	6	19730
19664	5	49708	5	19808
19665	5	49709	5	12315
19666	4	49711	4	19720
19667	5	49716	6	19772
19668	4	49718	7	19740
19669	5	49720	7	8597
19670	3	49726	5	19507
19671	5	49731	2	19796
19672	5	49732	6	4175
19673	5	49734	1	2116
19674	5	49735	4	6055
19675	5	49741	2	8065
19676	1	49743	6	19779
19677	4	49745	6	18976
19678	3	49752	5	19696
19679	5	49753	1	4929
19680	3	49760	5	5473
19681	5	49761	5	841
19682	5	49763	6	922
19683	5	49768	2	19677
19684	5	49769	4	18981
19685	5	49770	2	19660
19686	5	49774	1	7540
19687	3	49781	7	19813
19688	4	49783	3	2541
19689	4	49785	5	19683
19690	5	49786	2	19736
19691	5	49789	2	10258
19692	5	49790	3	14668
19693	5	49792	2	19698
19694	4	49792	3	19698
19695	3	49796	7	19814
19696	5	49798	6	19769
19697	5	49798	7	19769
19698	4	49800	2	4960
19699	5	49803	1	19738
19700	5	49812	3	11233
19701	4	49813	6	19765
19702	5	49814	7	8566
19703	2	49814	4	8566
19704	5	49816	2	5941
19705	5	49819	1	17949
19706	4	49822	4	9128
19707	1	49822	6	9128
19708	5	49825	6	19877
19709	3	49829	7	6221
19710	5	49831	6	15212
19711	5	49832	7	19839
19712	5	49836	2	5661
19713	5	49839	4	19928
19714	2	49842	3	19880
19715	5	49843	2	1077
19716	5	49844	1	19845
19717	5	49846	2	19955
19718	5	49848	6	10818
19719	4	49849	6	7611
19720	3	49851	5	19830
19721	5	49858	2	17720
19722	2	49858	3	17720
19723	4	49869	2	11996
19724	5	49869	1	11996
19725	4	49870	5	19947
19726	4	49871	5	981
19727	3	49873	5	5569
19728	1	49877	6	7845
19729	5	49878	7	19897
19730	5	49882	3	11870
19731	5	49888	7	635
19732	4	49891	1	19957
19733	5	49893	1	15188
19734	5	49895	1	15565
19735	4	49896	5	12214
19736	5	49898	1	19828
19737	5	49900	1	3763
19738	5	49901	7	19903
19739	5	49905	1	10287
19740	5	49907	2	19233
19741	5	49909	2	13308
19742	5	49912	6	8560
19743	3	49912	5	8560
19744	5	49914	6	13232
19745	5	49916	3	14410
19746	3	49917	7	19909
19747	5	49919	2	6178
19748	3	49921	1	3863
19749	5	49924	2	1820
19750	1	49925	6	19951
19751	3	49929	5	9214
19752	5	49930	2	16404
19753	5	49934	6	19948
19754	5	49935	4	19848
19755	4	49937	2	19919
19756	5	49938	2	7835
19757	5	49940	3	4546
19758	3	49942	5	13713
19759	4	49945	2	19834
19760	5	49946	4	6502
19761	5	49951	2	6746
19762	4	49952	6	8877
19763	5	49953	2	6163
19764	5	49955	6	6295
19765	4	49957	1	12602
19766	4	49965	5	19849
19767	4	49965	6	19849
19768	5	49967	6	12954
19769	5	49968	7	18143
19770	4	49970	2	9116
19771	5	49971	4	18962
19772	4	49975	5	19552
19773	5	49976	3	19762
19774	4	49982	4	19864
19775	3	49983	5	837
19776	5	49985	6	13026
19777	5	49987	2	5970
19778	5	49988	7	19833
19779	4	49991	5	10217
19780	5	49992	2	19865
19781	4	49993	7	18293
19782	5	49994	6	19870
19783	4	49995	2	19898
19784	5	50001	3	16483
19785	5	50002	7	18078
19786	4	50003	5	66
19787	5	50007	5	19887
19788	5	50010	5	16584
19789	3	50013	5	19027
19790	5	50013	2	19027
19791	4	50018	7	13320
19792	3	50019	5	12904
19793	5	50020	6	18787
19794	4	50025	4	2359
19795	5	50029	2	19908
19796	5	50030	4	19840
19797	5	50033	7	19891
19798	5	50034	4	18936
19799	4	50035	3	19911
19800	5	50039	4	18436
19801	4	50040	7	19916
19802	5	50041	6	19920
19803	4	50045	1	11991
19804	5	50047	6	19842
19805	2	50049	1	15791
19806	5	50052	6	16047
19807	5	50053	4	19930
19808	5	50055	4	19936
19809	1	50056	6	10147
19810	4	50058	1	7005
19811	5	50060	3	19956
19812	5	50061	7	16226
19813	5	50062	7	10316
19814	5	50064	1	19901
19815	5	50065	2	6093
19816	5	50073	5	2911
19817	5	50077	2	18411
19818	5	50081	5	15612
19819	5	50082	4	17185
19820	5	50084	6	19161
19821	5	50086	2	19941
19822	3	50087	5	2056
19823	4	50090	5	19852
19824	4	50090	4	19852
19825	3	50091	1	18141
19826	5	50092	5	2915
19827	4	50092	6	2915
19828	3	50093	7	17941
19829	4	50094	7	19927
19830	5	50097	3	9407
19831	5	50101	2	16704
19832	1	50102	6	19995
19833	4	50105	3	19124
19834	5	50106	2	14090
19835	5	50109	1	20002
19836	1	50110	6	19984
19837	3	50112	5	20101
19838	5	50113	6	20077
19839	4	50114	5	20025
19840	2	50115	3	10386
19841	5	50116	7	19347
19842	5	50116	6	19347
19843	5	50117	1	12018
19844	5	50122	6	20079
19845	4	50122	5	20079
19846	5	50124	6	20068
19847	4	50126	4	18271
19848	4	50127	4	20014
19849	5	50127	6	20014
19850	4	50128	7	12021
19851	4	50134	7	20109
19852	5	50139	3	20044
19853	5	50141	4	17330
19854	5	50143	5	17046
19855	5	50145	2	19989
19856	5	50147	5	20091
19857	2	50159	4	12821
19858	3	50162	3	20000
19859	5	50163	2	19979
19860	5	50163	4	19979
19861	4	50173	3	20095
19862	5	50173	2	20095
19863	3	50179	7	3393
19864	3	50180	4	8036
19865	3	50182	5	9580
19866	5	50188	7	14459
19867	5	50189	7	19996
19868	5	50192	6	6107
19869	4	50192	7	6107
19870	3	50195	1	2599
19871	5	50205	1	13789
19872	5	50206	7	16240
19873	1	50209	4	11624
19874	4	50211	2	1537
19875	5	50219	7	19971
19876	5	50222	5	14634
19877	4	50226	3	20024
19878	5	50228	6	7093
19879	5	50229	1	11295
19880	5	50231	2	9185
19881	5	50235	6	18108
19882	5	50236	7	11942
19883	5	50241	5	15692
19884	4	50242	3	3659
19885	5	50245	6	15159
19886	5	50245	4	15159
19887	5	50246	7	20106
19888	4	50247	5	9182
19889	5	50250	6	8573
19890	5	50251	6	19994
19891	3	50254	4	20037
19892	5	50257	6	15376
19893	5	50260	4	20043
19894	5	50260	5	20043
19895	5	50264	6	17384
19896	4	50266	7	5174
19897	5	50268	6	1101
19898	4	50271	6	20102
19899	4	50275	6	193
19900	4	50276	2	20055
19901	3	50277	2	6664
19902	5	50278	7	20110
19903	5	50280	6	5422
19904	5	50281	6	13881
19905	1	50283	6	12973
19906	5	50286	2	18291
19907	5	50291	6	19991
19908	5	50294	6	20063
19909	4	50298	6	8781
19910	4	50300	5	10234
19911	5	50302	5	20122
19912	3	50303	5	20065
19913	3	50307	5	20003
19914	5	50308	7	16268
19915	5	50309	4	7122
19916	3	50313	2	20007
19917	3	50314	7	10867
19918	4	50326	4	5097
19919	4	50327	5	18592
19920	3	50330	3	8813
19921	3	50332	6	20026
19922	5	50333	6	20118
19923	1	50334	5	11517
19924	5	50335	2	8145
19925	5	50336	2	20075
19926	4	50337	7	2934
19927	5	50340	5	11444
19928	5	50342	3	130
19929	4	50349	4	8762
19930	5	50349	6	8762
19931	5	50351	6	12020
19932	3	50352	1	714
19933	4	50358	4	19982
19934	5	50359	1	1566
19935	5	50359	4	1566
19936	5	50360	6	18012
19937	5	50370	1	11407
19938	3	50377	5	3767
19939	3	50378	5	20050
19940	4	50380	1	19118
19941	3	50380	5	19118
19942	5	50381	2	360
19943	2	50382	7	16710
19944	5	50383	7	20097
19945	5	50384	2	13568
19946	4	50385	6	19817
19947	3	50388	2	14112
19948	1	50393	6	9593
19949	4	50396	2	20048
19950	3	50398	2	6296
19951	5	50405	1	20108
19952	5	50407	1	16560
19953	5	50411	7	1730
19954	4	50413	1	12364
19955	5	50417	1	2050
19956	5	50418	2	13172
19957	4	50418	3	13172
19958	4	50419	6	8410
19959	4	50421	4	140
19960	5	50424	4	8791
19961	4	50425	7	19967
19962	3	50427	5	20064
19963	5	50429	6	7833
19964	4	50431	7	3949
19965	5	50432	6	20052
19966	5	50433	6	13698
19967	4	50434	6	20085
19968	4	50437	5	1557
19969	5	50439	4	15834
19970	5	50440	5	19965
19971	5	50444	6	20004
19972	5	50450	1	2752
19973	5	50451	5	384
19974	5	50452	6	20038
19975	5	50454	7	9833
19976	5	50455	1	12217
19977	5	50462	2	15109
19978	3	50472	3	19993
19979	5	50474	6	9984
19980	5	50476	7	1387
19981	5	50477	2	19988
19982	3	50478	3	6535
19983	5	50479	1	8770
19984	4	50481	7	437
19985	5	50482	7	1612
19986	4	50483	6	20045
19987	5	50484	2	5440
19988	3	50485	6	5715
19989	5	50488	2	4885
19990	5	50491	1	20184
19991	5	50496	6	20150
19992	5	50498	6	20124
19993	5	50501	6	20256
19994	5	50502	1	20273
19995	4	50505	2	3102
19996	5	50509	6	4281
19997	4	50513	5	20138
19998	4	50515	7	17480
19999	3	50521	5	20212
20000	1	50522	6	5207
20001	5	50527	6	20176
20002	4	50528	6	16183
20003	5	50533	5	20196
20004	4	50535	1	20128
20005	5	50536	1	15658
20006	4	50537	4	20210
20007	5	50542	4	18114
20008	5	50544	3	17326
20009	5	50546	7	19686
20010	5	50548	6	20220
20011	5	50549	1	495
20012	3	50551	3	19518
20013	3	50555	1	5945
20014	3	50556	3	17038
20015	4	50557	3	2613
20016	4	50559	4	20243
20017	5	50559	6	20243
20018	5	50562	4	20236
20019	5	50566	1	7670
20020	4	50567	4	9816
20021	2	50568	6	440
20022	5	50576	2	20140
20023	4	50577	6	17868
20024	5	50581	7	19197
20025	5	50582	6	20209
20026	5	50583	6	9991
20027	3	50584	1	20239
20028	3	50584	7	20239
20029	3	50586	7	11219
20030	5	50587	3	20125
20031	4	50589	7	20257
20032	5	50590	5	20200
20033	5	50591	7	12906
20034	5	50592	7	4660
20035	5	50593	6	10993
20036	5	50604	2	7396
20037	5	50605	3	2658
20038	5	50607	6	3784
20039	4	50611	2	13913
20040	4	50616	7	13231
20041	4	50618	6	378
20042	5	50621	6	20265
20043	3	50621	3	20265
20044	5	50625	5	20147
20045	5	50628	2	9737
20046	5	50635	2	831
20047	3	50636	2	318
20048	4	50638	7	3052
20049	3	50639	6	12614
20050	5	50644	6	16581
20051	2	50645	6	5388
20052	5	50646	1	16569
20053	4	50656	4	19421
20054	5	50658	1	5445
20055	5	50658	7	5445
20056	5	50663	2	20261
20057	3	50664	1	6990
20058	5	50669	4	5605
20059	5	50671	1	20218
20060	5	50672	6	7330
20061	5	50679	2	18157
20062	5	50680	3	18928
20063	3	50684	4	4793
20064	3	50686	3	20225
20065	4	50687	2	3614
20066	5	50689	4	20269
20067	5	50691	2	17695
20068	4	50692	7	20219
20069	5	50693	6	20173
20070	5	50695	1	18738
20071	1	50697	6	10489
20072	5	50700	1	12833
20073	5	50701	1	20260
20074	3	50701	7	20260
20075	5	50709	6	20274
20076	4	50711	6	15822
20077	5	50714	5	17455
20078	5	50715	6	20197
20079	4	50715	7	20197
20080	5	50718	6	18863
20081	4	50721	4	13257
20082	1	50721	6	13257
20083	5	50733	6	20127
20084	4	50740	2	6680
20085	5	50741	3	1239
20086	4	50748	1	19249
20087	4	50753	5	20247
20088	5	50754	6	20211
20089	5	50759	2	20244
20090	4	50765	3	18440
20091	5	50769	6	16286
20092	5	50772	4	20159
20093	5	50773	2	20139
20094	4	50773	4	20139
20095	5	50777	5	6166
20096	4	50779	4	20242
20097	4	50782	5	20137
20098	3	50783	4	4862
20099	4	50784	3	14263
20100	5	50789	2	9284
20101	5	50794	6	16231
20102	4	50801	5	20157
20103	5	50803	5	14607
20104	4	50809	3	2691
20105	5	50812	2	13012
20106	3	50816	4	726
20107	3	50817	4	16416
20108	5	50823	2	13570
20109	4	50824	5	15400
20110	5	50834	6	4414
20111	3	50837	5	230
20112	5	50840	6	7298
20113	4	50848	2	12007
20114	5	50849	6	20224
20115	4	50853	6	20223
20116	4	50854	5	18837
20117	5	50855	6	20262
20118	4	50856	7	5962
20119	3	50857	7	10287
20120	5	50859	7	19464
20121	4	50865	5	20204
20122	4	50874	2	20174
20123	5	50876	6	20178
20124	5	50878	2	4206
20125	5	50881	3	4120
20126	5	50882	3	20253
20127	5	50884	7	20266
20128	1	50886	6	20167
20129	3	50886	2	20167
20130	5	50888	6	6019
20131	5	50890	3	20161
20132	3	50893	3	366
20133	2	50895	2	20186
20134	3	50897	5	13723
20135	5	50900	5	20275
20136	3	50904	4	15188
20137	3	50907	5	5312
20138	5	50907	3	5312
20139	5	50908	2	13440
20140	5	50910	4	2054
20141	5	50911	6	12390
20142	5	50912	5	19735
20143	4	50914	3	1755
20144	5	50915	4	498
20145	5	50918	1	3859
20146	5	50919	7	12639
20147	3	50921	5	11841
20148	4	50924	2	302
20149	4	50926	5	20295
20150	5	50928	3	15456
20151	5	50929	3	1516
20152	3	50930	4	18870
20153	3	50932	5	20377
20154	3	50937	5	11490
20155	4	50940	3	7061
20156	4	50941	7	1340
20157	5	50941	1	1340
20158	5	50942	5	2341
20159	5	50943	6	7831
20160	5	50944	5	19566
20161	3	50945	6	20460
20162	5	50946	1	10772
20163	4	50947	4	20320
20164	5	50950	3	2515
20165	4	50951	6	20424
20166	5	50955	4	4655
20167	5	50955	1	4655
20168	3	50958	1	20290
20169	5	50959	2	20352
20170	4	50966	5	1461
20171	5	50968	4	20356
20172	5	50969	4	2733
20173	5	50970	7	5768
20174	4	50975	2	20331
20175	4	50977	5	17641
20176	5	50980	3	9305
20177	5	50982	2	7017
20178	5	50983	7	20442
20179	4	50985	7	18172
20180	4	50987	6	8592
20181	5	50989	1	20346
20182	4	50989	3	20346
20183	3	50990	7	20384
20184	5	50994	7	20355
20185	5	50996	7	15215
20186	3	50996	3	15215
20187	3	50998	2	20285
20188	3	51001	7	18771
20189	4	51002	3	20329
20190	5	51003	7	20451
20191	5	51004	2	20369
20192	3	51005	1	111
20193	5	51006	1	7857
20194	5	51007	7	3278
20195	4	51011	5	20357
20196	5	51012	2	143
20197	3	51014	7	20328
20198	5	51015	7	20455
20199	4	51021	7	13400
20200	5	51023	2	1687
20201	4	51025	3	20372
20202	5	51027	2	19485
20203	5	51028	7	8041
20204	3	51034	4	9287
20205	4	51035	5	10070
20206	4	51036	3	149
20207	5	51037	7	6369
20208	4	51040	7	20333
20209	5	51043	2	2774
20210	5	51045	4	20443
20211	4	51048	1	17636
20212	5	51049	3	7109
20213	5	51050	7	20392
20214	5	51055	2	20458
20215	3	51055	6	20458
20216	4	51061	4	8556
20217	1	51061	6	8556
20218	3	51066	5	19596
20219	5	51067	2	184
20220	5	51068	7	20427
20221	5	51068	6	20427
20222	4	51069	2	18220
20223	4	51069	4	18220
20224	4	51070	2	17654
20225	4	51071	1	11039
20226	5	51073	7	20340
20227	4	51075	1	20417
20228	5	51076	1	14964
20229	3	51079	5	20322
20230	4	51081	2	11625
20231	5	51083	2	6439
20232	5	51084	2	11464
20233	5	51085	3	12697
20234	5	51085	5	12697
20235	4	51086	4	1415
20236	5	51088	7	8126
20237	5	51090	2	9014
20238	5	51093	7	20149
20239	4	51094	1	1722
20240	5	51098	2	2892
20241	5	51100	7	20373
20242	1	51101	6	20414
20243	5	51105	7	18316
20244	1	51109	4	20298
20245	4	51110	7	2051
20246	3	51111	1	20321
20247	5	51113	1	20394
20248	5	51114	6	20314
20249	4	51115	7	9565
20250	1	51118	1	20381
20251	5	51121	2	18209
20252	3	51129	4	14931
20253	3	51130	5	17207
20254	4	51131	5	9107
20255	4	51134	1	10254
20256	4	51135	5	18004
20257	4	51136	2	3268
20258	3	51141	3	20363
20259	5	51144	6	20289
20260	4	51146	7	20349
20261	4	51147	3	14735
20262	4	51148	2	11723
20263	5	51150	6	5403
20264	4	51150	7	5403
20265	3	51151	7	9816
20266	5	51155	3	20344
20267	5	51156	1	18849
20268	5	51160	1	20410
20269	5	51162	1	20282
20270	5	51163	6	6763
20271	5	51165	1	16254
20272	5	51167	7	20336
20273	5	51169	4	12192
20274	3	51173	7	20436
20275	5	51175	6	5094
20276	5	51177	2	20428
20277	3	51180	3	5701
20278	4	51184	2	20060
20279	5	51185	3	874
20280	3	51194	1	20370
20281	5	51195	2	20446
20282	4	51196	5	20317
20283	5	51197	4	20412
20284	3	51198	2	10452
20285	3	51199	2	20375
20286	5	51200	2	10364
20287	4	51204	7	4120
20288	1	51206	6	5144
20289	3	51207	3	20399
20290	5	51211	6	7391
20291	4	51216	4	20305
20292	5	51218	4	3439
20293	5	51222	6	20284
20294	5	51223	4	7213
20295	3	51226	5	11119
20296	2	51231	3	20422
20297	4	51232	2	20395
20298	4	51234	7	20452
20299	5	51236	6	18756
20300	5	51237	2	9237
20301	5	51239	2	10903
20302	5	51242	2	12226
20303	5	51244	2	20313
20304	2	51248	4	11754
20305	4	51249	7	16993
20306	4	51252	6	20307
20307	5	51254	5	20454
20308	5	51257	6	10145
20309	2	51258	2	4279
20310	5	51259	6	20438
20311	5	51261	1	20434
20312	5	51262	5	20459
20313	5	51264	4	20423
20314	4	51267	2	19
20315	4	51270	5	16136
20316	5	51274	2	4594
20317	4	51275	7	20453
20318	5	51277	6	1453
20319	3	51284	3	1311
20320	5	51288	1	20366
20321	5	51290	6	3744
20322	4	51292	4	10518
20323	4	51293	3	6873
20324	4	51294	3	2989
20325	5	51296	6	20345
20326	4	51297	3	20429
20327	5	51298	6	19742
20328	4	51303	2	981
20329	3	51304	4	14288
20330	5	51305	2	13105
20331	5	51306	6	9478
20332	4	51307	5	2544
20333	5	51314	1	841
20334	3	51316	3	12000
20335	5	51317	3	16678
20336	5	51319	2	1571
20337	5	51320	6	16962
20338	5	51322	6	20500
20339	5	51324	6	17038
20340	5	51327	4	5097
20341	4	51329	5	20567
20342	5	51331	7	826
20343	5	51332	7	17106
20344	5	51333	1	1900
20345	5	51334	6	12018
20346	5	51335	6	1824
20347	5	51340	6	7007
20348	3	51342	7	20572
20349	3	51343	5	20553
20350	2	51346	6	18137
20351	3	51347	1	1654
20352	4	51348	4	2333
20353	5	51352	1	20311
20354	5	51353	4	9001
20355	5	51357	2	20590
20356	3	51359	2	17884
20357	5	51360	2	20586
20358	4	51365	1	20474
20359	4	51367	7	20592
20360	4	51367	3	20592
20361	5	51369	7	5885
20362	3	51370	1	13311
20363	5	51374	6	14256
20364	4	51375	6	2721
20365	5	51376	2	32
20366	3	51378	7	14491
20367	5	51378	2	14491
20368	4	51379	5	13914
20369	5	51383	1	20490
20370	5	51385	6	15896
20371	5	51391	2	1306
20372	4	51392	5	3714
20373	5	51393	5	20513
20374	4	51394	7	20532
20375	5	51396	7	11157
20376	4	51397	6	3949
20377	3	51403	3	20541
20378	5	51404	3	15597
20379	3	51406	6	20529
20380	5	51409	1	1118
20381	5	51410	4	643
20382	4	51411	7	17763
20383	5	51413	6	20568
20384	5	51416	2	20527
20385	5	51421	5	17669
20386	3	51422	1	12954
20387	2	51423	5	10591
20388	5	51424	1	20611
20389	5	51427	2	11389
20390	5	51428	4	1285
20391	4	51429	6	20547
20392	5	51434	2	3199
20393	2	51436	3	16159
20394	5	51438	2	20501
20395	5	51443	7	1176
20396	4	51447	2	1818
20397	5	51447	4	1818
20398	5	51449	4	6137
20399	3	51450	5	1563
20400	5	51454	1	5048
20401	5	51457	2	20507
20402	2	51459	2	16755
20403	3	51463	3	20483
20404	4	51464	4	2025
20405	5	51466	1	7046
20406	2	51467	3	3326
20407	3	51469	6	5886
20408	5	51470	6	20531
20409	5	51471	7	6469
20410	5	51472	1	20596
20411	5	51478	2	11040
20412	5	51481	7	20536
20413	4	51482	2	3403
20414	5	51484	4	20485
20415	5	51492	1	20302
20416	5	51494	6	708
20417	3	51499	7	20602
20418	4	51502	6	13613
20419	4	51504	2	20597
20420	5	51506	2	9976
20421	4	51507	7	20468
20422	4	51508	7	20516
20423	5	51509	2	2272
20424	3	51512	2	13425
20425	3	51513	3	18174
20426	4	51519	7	20482
20427	5	51521	7	6549
20428	3	51523	4	19701
20429	4	51526	2	19075
20430	4	51528	5	20521
20431	4	51530	4	19486
20432	5	51534	2	20191
20433	4	51536	7	6885
20434	4	51538	4	6704
20435	4	51543	1	1727
20436	5	51545	4	1535
20437	5	51548	2	18025
20438	5	51550	2	11785
20439	3	51550	4	11785
20440	5	51551	6	11718
20441	2	51553	4	20464
20442	4	51554	2	20600
20443	3	51557	3	8772
20444	5	51559	2	15294
20445	4	51560	2	11973
20446	5	51563	3	14862
20447	5	51564	7	4199
20448	3	51566	2	20551
20449	5	51571	5	20522
20450	4	51572	6	5644
20451	5	51576	4	1780
20452	3	51577	7	20486
20453	5	51581	5	7025
20454	4	51581	2	7025
20455	4	51582	1	20526
20456	3	51586	5	20578
20457	2	51588	3	2653
20458	5	51589	7	20571
20459	5	51591	3	18580
20460	4	51592	6	20502
20461	3	51593	5	20560
20462	5	51598	2	13473
20463	5	51601	1	7035
20464	4	51602	5	4737
20465	3	51602	1	4737
20466	3	51605	6	6491
20467	5	51606	4	10646
20468	4	51608	3	9627
20469	4	51610	2	3185
20470	3	51611	4	20550
20471	4	51614	3	20504
20472	5	51616	2	15386
20473	3	51617	4	20562
20474	5	51618	1	17657
20475	5	51622	4	19628
20476	5	51625	3	20582
20477	4	51627	5	20581
20478	5	51628	4	7547
20479	5	51630	7	473
20480	5	51631	6	13663
20481	2	51633	4	7766
20482	5	51634	6	3599
20483	5	51636	1	13233
20484	5	51637	2	391
20485	5	51638	2	10535
20486	5	51639	1	20528
20487	5	51640	2	17519
20488	5	51641	6	20587
20489	3	51642	2	19313
20490	5	51645	6	19971
20491	5	51646	6	15352
20492	5	51646	7	15352
20493	5	51648	1	15848
20494	2	51650	6	13568
20495	5	51651	4	7729
20496	3	51652	5	20509
20497	5	51654	6	17392
20498	4	51655	2	6901
20499	5	51657	2	20544
20500	5	51657	7	20544
20501	3	51658	3	7875
20502	5	51664	6	20583
20503	4	51668	7	15533
20504	5	51671	3	12150
20505	5	51678	5	13825
20506	5	51681	6	8308
20507	4	51682	1	20503
20508	4	51683	4	11627
20509	4	51684	5	20607
20510	3	51686	3	20491
20511	5	51687	2	20537
20512	4	51693	2	13027
20513	5	51694	4	568
20514	5	51699	4	11511
20515	3	51700	4	1781
20516	5	51701	6	20591
20517	4	51702	6	17412
20518	5	51705	7	20573
20519	5	51707	5	20492
20520	4	51708	1	9081
20521	5	51710	7	1309
20522	5	51712	2	8872
20523	5	51713	7	20511
20524	5	51714	3	20609
20525	5	51716	2	20497
20526	4	51717	2	20472
20527	5	51720	7	135
20528	5	51721	4	20543
20529	5	51722	6	13060
20530	4	51723	6	20535
20531	3	51723	2	20535
20532	2	51727	2	5491
20533	5	51729	1	6565
20534	4	51732	6	9886
20535	2	51733	4	5169
20536	5	51735	7	9438
20537	5	51737	6	16345
20538	5	51740	7	15194
20539	5	51741	7	12796
20540	5	51743	1	20584
20541	4	51745	1	578
20542	4	51747	5	11193
20543	4	51748	7	20579
20544	5	51751	7	964
20545	4	51753	7	5082
20546	3	51761	1	20494
20547	5	51764	2	20517
20548	3	51766	5	20505
20549	1	51767	6	10311
20550	3	51772	1	3447
20551	5	51777	4	20731
20552	5	51778	2	4547
20553	5	51779	2	1678
20554	4	51792	7	20634
20555	5	51797	4	20638
20556	5	51798	6	10074
20557	3	51802	4	13329
20558	5	51804	2	20728
20559	4	51805	5	19036
20560	5	51806	1	20683
20561	4	51808	7	20011
20562	2	51809	3	20714
20563	4	51810	7	4162
20564	5	51812	6	559
20565	3	51818	4	411
20566	4	51820	4	5334
20567	5	51822	6	20736
20568	5	51825	7	18519
20569	4	51826	1	20694
20570	4	51827	2	20741
20571	4	51827	7	20741
20572	5	51828	2	9663
20573	5	51828	5	9663
20574	4	51831	7	20677
20575	2	51832	5	20675
20576	4	51834	5	4346
20577	5	51836	5	20670
20578	5	51837	7	20737
20579	4	51839	1	4562
20580	4	51843	1	9975
20581	5	51847	4	8846
20582	5	51850	6	5354
20583	4	51851	2	5526
20584	5	51855	3	4996
20585	5	51861	2	153
20586	4	51863	2	20673
20587	4	51867	5	3364
20588	3	51870	5	20717
20589	5	51872	6	9021
20590	5	51873	7	20654
20591	5	51875	6	13432
20592	3	51877	2	15907
20593	5	51878	3	20724
20594	5	51881	4	6465
20595	5	51883	7	16648
20596	5	51884	4	20744
20597	5	51888	7	20727
20598	5	51889	5	9307
20599	4	51891	6	2875
20600	5	51896	2	13476
20601	4	51897	5	639
20602	3	51900	5	20657
20603	5	51905	3	7342
20604	4	51910	6	8153
20605	5	51912	2	17011
20606	4	51912	1	17011
20607	5	51914	5	12255
20608	5	51915	6	20620
20609	4	51917	4	15776
20610	5	51931	2	20647
20611	5	51931	7	20647
20612	5	51932	7	2074
20613	4	51932	2	2074
20614	3	51933	5	9716
20615	4	51936	5	20623
20616	5	51938	7	15544
20617	4	51939	5	5111
20618	3	51942	5	7994
20619	5	51944	2	628
20620	5	51946	3	20743
20621	4	51949	5	20655
20622	5	51952	6	12935
20623	5	51954	4	13968
20624	5	51957	4	20667
20625	1	51959	6	9095
20626	4	51961	2	20462
20627	4	51964	2	15460
20628	4	51965	2	15682
20629	4	51968	2	18840
20630	5	51971	5	4274
20631	3	51973	5	19452
20632	5	51974	6	14293
20633	5	51978	7	11938
20634	5	51981	7	20641
20635	5	51981	3	20641
20636	5	51983	3	20702
20637	5	51990	4	7205
20638	5	51993	4	8027
20639	1	51994	6	16974
20640	4	51995	4	8196
20641	4	51996	5	20738
20642	5	51999	1	17928
20643	5	52000	2	10873
20644	5	52005	1	2836
20645	5	52009	1	9053
20646	3	52012	3	19490
20647	5	52013	2	13923
20648	5	52014	6	14173
20649	5	52015	6	8966
20650	3	52016	5	20644
20651	5	52018	5	1626
20652	3	52018	7	1626
20653	3	52022	7	12700
20654	5	52025	2	9106
20655	3	52030	2	10238
20656	4	52032	6	20689
20657	5	52034	6	9804
20658	3	52036	3	20691
20659	4	52042	5	20107
20660	4	52043	4	3567
20661	5	52048	7	8036
20662	1	52049	6	19857
20663	5	52050	2	2567
20664	5	52051	6	6609
20665	5	52054	4	12718
20666	5	52054	7	12718
20667	5	52058	1	13240
20668	5	52060	4	5706
20669	5	52062	6	19135
20670	5	52065	2	8233
20671	5	52069	6	2938
20672	5	52070	1	11802
20673	4	52072	2	10484
20674	4	52073	2	20648
20675	3	52074	4	15284
20676	4	52075	5	13738
20677	5	52076	4	20650
20678	4	52080	7	20690
20679	5	52081	1	352
20680	5	52085	4	6960
20681	4	52087	1	6915
20682	4	52088	7	2712
20683	5	52089	3	11146
20684	4	52090	7	3341
20685	4	52091	2	6046
20686	4	52096	2	20666
20687	4	52103	7	20753
20688	5	52105	6	7595
20689	4	52106	7	20359
20690	5	52108	4	20642
20691	3	52109	1	20631
20692	4	52113	1	6231
20693	5	52115	7	10101
20694	5	52116	5	7485
20695	5	52117	3	20748
20696	4	52119	5	20652
20697	5	52120	3	13438
20698	4	52121	3	20635
20699	5	52122	2	6748
20700	5	52123	2	20726
20701	3	52123	3	20726
20702	4	52126	5	7853
20703	5	52127	3	18723
20704	3	52128	7	20636
20705	5	52131	5	788
20706	4	52138	5	19301
20707	3	52139	7	10354
20708	5	52142	4	19284
20709	5	52146	5	3923
20710	5	52148	3	20734
20711	5	52150	5	16896
20712	4	52150	7	16896
20713	1	52151	7	1548
20714	4	52152	1	3997
20715	5	52153	6	981
20716	3	52158	5	2139
20717	5	52159	6	6728
20718	5	52161	2	6564
20719	5	52163	5	19628
20720	5	52164	2	19322
20721	3	52165	5	20676
20722	5	52166	3	20080
20723	4	52167	2	3622
20724	4	52171	5	20751
20725	3	52172	5	9103
20726	4	52173	7	19847
20727	5	52175	7	17874
20728	5	52178	5	6444
20729	4	52181	7	19334
20730	5	52182	5	20625
20731	3	52183	7	20633
20732	3	52190	3	17176
20733	4	52191	7	20706
20734	5	52193	7	5236
20735	5	52194	3	16939
20736	4	52195	6	10147
20737	4	52196	5	10072
20738	5	52197	2	754
20739	5	52198	7	19817
20740	5	52202	5	20711
20741	5	52203	6	20733
20742	4	52210	3	2659
20743	4	52211	2	10180
20744	5	52212	2	12455
20745	5	52213	4	10578
20746	3	52215	5	13236
20747	3	52218	7	19432
20748	4	52219	2	16461
20749	5	52221	3	1070
20750	3	52222	1	4673
20751	5	52223	2	16829
20752	5	52224	6	12091
20753	5	52225	6	3010
20754	5	52228	6	13994
20755	3	52228	5	13994
20756	4	52237	3	20617
20757	5	52238	4	15851
20758	4	52239	3	13082
20759	5	52240	4	12615
20760	5	52243	1	1481
20761	1	52249	2	6807
20762	3	52251	7	7298
20763	5	52258	6	20684
20764	5	52261	6	4897
20765	4	52262	6	13799
20766	4	52266	6	11181
20767	5	52271	6	7746
20768	4	52272	2	7530
20769	5	52274	2	7050
20770	4	52277	3	3544
20771	5	52281	7	8866
20772	4	52282	3	15140
20773	3	52285	5	3125
20774	3	52289	5	15001
20775	4	52290	7	7821
20776	5	52291	4	20757
20777	4	52295	7	16394
20778	3	52296	5	18150
20779	3	52298	3	20662
20780	3	52299	1	7388
20781	3	52300	7	11690
20782	4	52301	1	3000
20783	5	52302	6	20740
20784	5	52303	2	11376
20785	5	52304	5	19994
20786	5	52305	1	8773
20787	5	52306	6	20688
20788	5	52307	6	2519
20789	5	52308	4	11518
20790	5	52308	6	11518
20791	4	52309	1	7566
20792	4	52310	6	12160
20793	4	52312	4	19760
20794	5	52313	4	20852
20795	4	52316	7	20905
20796	4	52317	1	17688
20797	5	52318	6	20768
20798	5	52318	2	20768
20799	5	52321	2	14864
20800	4	52322	4	19348
20801	5	52324	6	20848
20802	5	52343	4	13775
20803	5	52347	4	20800
20804	5	52347	1	20800
20805	2	52349	4	1714
20806	5	52351	2	20803
20807	5	52351	4	20803
20808	5	52352	2	20892
20809	5	52354	2	20836
20810	5	52356	2	515
20811	5	52360	5	3953
20812	4	52360	2	3953
20813	5	52361	6	2843
20814	5	52366	6	20834
20815	1	52369	6	20827
20816	3	52373	5	15350
20817	5	52376	1	20811
20818	4	52378	3	20767
20819	3	52379	1	10403
20820	5	52380	1	17770
20821	5	52386	7	16761
20822	3	52394	5	20894
20823	5	52398	2	2275
20824	5	52400	7	20864
20825	5	52402	4	20831
20826	5	52403	4	20861
20827	3	52404	2	12878
20828	5	52406	4	10651
20829	4	52408	6	3129
20830	5	52409	2	20776
20831	5	52412	3	14165
20832	5	52414	2	3754
20833	5	52415	5	16483
20834	4	52417	1	389
20835	5	52419	1	15271
20836	4	52420	1	20900
20837	3	52422	1	3604
20838	3	52423	5	7161
20839	4	52427	7	20824
20840	5	52436	4	20847
20841	5	52440	6	20841
20842	5	52440	2	20841
20843	4	52441	5	20883
20844	3	52442	2	10472
20845	4	52445	3	20819
20846	3	52450	2	13699
20847	5	52450	1	13699
20848	4	52451	7	20822
20849	1	52452	6	20809
20850	5	52452	4	20809
20851	4	52453	3	6778
20852	5	52456	3	16755
20853	3	52459	4	30
20854	4	52462	7	13718
20855	3	52463	7	12506
20856	5	52464	1	20778
20857	5	52465	7	20869
20858	3	52465	3	20869
20859	3	52467	5	16164
20860	4	52471	7	7888
20861	3	52472	1	20792
20862	3	52473	7	4728
20863	3	52476	7	17030
20864	2	52478	6	14869
20865	5	52482	2	3111
20866	4	52483	2	3545
20867	5	52487	4	20781
20868	4	52488	7	20814
20869	5	52495	4	13049
20870	3	52496	2	18414
20871	4	52498	1	4130
20872	4	52499	5	20891
20873	5	52502	5	17225
20874	5	52505	2	20901
20875	5	52507	4	20825
20876	5	52508	7	20794
20877	5	52514	6	20774
20878	3	52514	5	20774
20879	5	52517	5	20838
20880	1	52530	6	2618
20881	5	52532	2	20832
20882	5	52533	7	8555
20883	5	52534	1	14093
20884	5	52535	2	187
20885	5	52538	4	3065
20886	5	52541	2	20804
20887	5	52543	1	20866
20888	4	52544	1	20870
20889	5	52546	1	12664
20890	5	52548	2	13363
20891	3	52551	7	20785
20892	5	52554	3	11010
20893	5	52554	4	11010
20894	4	52557	7	20763
20895	5	52562	4	20837
20896	5	52565	3	20846
20897	4	52568	1	4733
20898	5	52569	6	9988
20899	1	52570	6	11910
20900	1	52571	6	1334
20901	5	52572	4	2419
20902	5	52577	3	12236
20903	2	52580	6	8869
20904	3	52582	7	5658
20905	5	52588	2	20879
20906	3	52589	7	1108
20907	5	52592	1	10993
20908	5	52592	3	10993
20909	4	52594	4	20936
20910	1	52598	5	11783
20911	5	52600	2	21048
20912	4	52601	7	1075
20913	4	52603	1	688
20914	5	52605	2	12920
20915	5	52606	4	13320
20916	1	52607	6	21062
20917	5	52609	3	12180
20918	4	52609	1	12180
20919	3	52616	5	10876
20920	5	52617	7	7491
20921	5	52620	2	20977
20922	3	52622	5	20929
20923	5	52623	2	16475
20924	5	52624	7	21026
20925	5	52627	2	2496
20926	4	52629	7	20994
20927	5	52638	3	4116
20928	5	52639	6	21028
20929	1	52642	6	10598
20930	3	52643	5	9193
20931	5	52645	2	20985
20932	3	52647	7	21039
20933	5	52653	4	20972
20934	5	52656	3	15995
20935	3	52661	6	20919
20936	5	52663	7	21071
20937	5	52666	2	20953
20938	3	52673	4	20938
20939	5	52674	2	20949
20940	4	52675	5	15361
20941	4	52676	5	12282
20942	3	52691	3	12204
20943	5	52695	6	1406
20944	5	52696	2	12646
20945	5	52703	6	21031
20946	3	52704	4	21004
20947	5	52706	4	19583
20948	5	52710	1	21081
20949	4	52714	4	13502
20950	5	52715	6	20959
20951	4	52715	3	20959
20952	5	52721	5	21054
20953	5	52721	2	21054
20954	5	52723	3	20967
20955	5	52726	5	20930
20956	5	52727	6	11822
20957	5	52728	3	1677
20958	5	52729	7	2599
20959	4	52733	3	7680
20960	4	52734	1	18667
20961	5	52734	7	18667
20962	3	52738	7	3640
20963	5	52741	5	981
20964	5	52744	7	20991
20965	5	52748	2	20859
20966	4	52749	4	6323
20967	5	52749	7	6323
20968	5	52753	3	8561
20969	3	52758	7	20974
20970	5	52759	6	8000
20971	5	52761	3	21000
20972	5	52763	1	21045
20973	3	52765	4	17383
20974	5	52766	6	20918
20975	3	52768	7	20984
20976	2	52769	5	14922
20977	3	52769	1	14922
20978	3	52777	7	8361
20979	5	52780	4	7217
20980	4	52781	1	21050
20981	4	52789	5	20717
20982	1	52791	4	17088
20983	4	52797	7	19346
20984	4	52801	4	11719
20985	5	52802	4	691
20986	5	52805	4	14239
20987	5	52809	4	6600
20988	4	52811	7	20955
20989	4	52812	6	8729
20990	3	52816	5	1098
20991	4	52819	5	9722
20992	5	52820	6	3207
20993	1	52821	2	2523
20994	3	52823	5	17503
20995	5	52826	4	20983
20996	5	52827	6	8392
20997	3	52828	5	10749
20998	5	52829	3	9266
20999	5	52833	2	3527
21000	5	52839	6	4436
21001	4	52840	5	21024
21002	4	52844	3	1569
21003	5	52847	4	20905
21004	4	52853	6	20951
21005	3	52855	3	20993
21006	5	52856	4	3230
21007	3	52857	7	21053
21008	4	52858	2	4360
21009	5	52860	4	1693
21010	5	52862	6	20944
21011	5	52864	2	17811
21012	5	52865	5	11118
21013	5	52866	1	3180
21014	5	52868	2	21016
21015	5	52869	6	21015
21016	5	52876	6	4260
21017	5	52877	1	2196
21018	1	52883	6	20971
21019	4	52885	2	6221
21020	4	52886	5	20923
21021	4	52889	4	21023
21022	4	52895	5	6668
21023	5	52896	2	7074
21024	5	52897	6	13871
21025	5	52898	5	20968
21026	1	52903	7	21043
21027	5	52904	2	21021
21028	3	52906	3	20926
21029	5	52910	6	8822
21030	5	52912	7	418
21031	5	52913	6	20990
21032	5	52914	4	21059
21033	4	52915	7	18901
21034	5	52917	4	20962
21035	4	52918	5	9626
21036	3	52921	6	7304
21037	4	52923	7	487
21038	5	52924	6	15578
21039	5	52927	3	14857
21040	4	52928	3	6469
21041	5	52928	6	6469
21042	4	52929	7	13783
21043	2	52940	6	7105
21044	5	52941	4	18579
21045	5	52942	1	3321
21046	3	52945	7	5028
21047	3	52948	7	5619
21048	5	52950	1	21147
21049	5	52950	2	21147
21050	5	52951	5	17650
21051	5	52955	2	21099
21052	5	52958	5	21201
21053	5	52959	6	17534
21054	4	52961	3	10580
21055	5	52963	2	3688
21056	3	52963	5	3688
21057	3	52966	4	5966
21058	5	52968	6	14572
21059	4	52971	1	19207
21060	5	52978	5	1170
21061	5	52979	5	17422
21062	3	52987	5	2752
21063	5	52988	4	16613
21064	3	52989	4	7595
21065	4	52990	5	6417
21066	5	52991	6	1665
21067	5	52994	6	18307
21068	5	53000	1	1509
21069	5	53001	2	640
21070	3	53003	4	21180
21071	5	53004	4	4330
21072	1	53008	6	7505
21073	4	53009	4	2333
21074	5	53010	7	9219
21075	4	53013	2	4976
21076	5	53016	5	7766
21077	2	53021	4	12937
21078	4	53024	7	21089
21079	3	53026	2	21167
21080	2	53027	4	688
21081	3	53027	7	688
21082	5	53028	2	21191
21083	4	53032	6	15690
21084	4	53035	7	12461
21085	3	53037	7	21197
21086	5	53038	6	9108
21087	5	53040	2	21175
21088	3	53042	5	14518
21089	4	53043	3	16042
21090	4	53050	7	6962
21091	4	53050	2	6962
21092	4	53053	1	21209
21093	3	53055	7	5110
21094	5	53056	6	21145
21095	5	53059	2	10442
21096	4	53063	1	19916
21097	3	53063	7	19916
21098	5	53067	1	21134
21099	5	53071	4	11160
21100	5	53072	6	7815
21101	1	53075	1	2287
21102	5	53081	2	7033
21103	5	53083	5	11096
21104	1	53083	6	11096
21105	4	53084	1	21199
21106	5	53086	6	21109
21107	5	53091	4	15300
21108	5	53093	4	21116
21109	5	53099	6	21135
21110	4	53100	5	21205
21111	5	53100	6	21205
21112	5	53101	6	21185
21113	5	53103	6	21162
21114	5	53105	5	21173
21115	5	53105	6	21173
21116	5	53106	2	19056
21117	3	53112	7	4800
21118	5	53113	4	19597
21119	5	53120	4	21132
21120	5	53122	7	11181
21121	5	53123	7	21149
21122	5	53125	6	8683
21123	2	53128	4	21085
21124	1	53129	6	21152
21125	5	53129	4	21152
21126	3	53135	5	14110
21127	4	53137	6	5345
21128	5	53140	2	17209
21129	4	53141	7	18616
21130	4	53143	3	21114
21131	4	53145	1	14461
21132	4	53152	7	21126
21133	5	53154	6	7161
21134	3	53157	3	21107
21135	5	53158	4	3869
21136	5	53159	3	21158
21137	5	53160	7	9327
21138	5	53161	6	14841
21139	2	53164	6	21151
21140	4	53168	3	9465
21141	5	53169	5	16869
21142	5	53170	6	21187
21143	3	53174	4	80
21144	3	53179	2	17725
21145	5	53181	2	21206
21146	5	53181	5	21206
21147	4	53185	3	1513
21148	5	53187	5	21165
21149	5	53190	2	21174
21150	5	53192	6	21127
21151	5	53196	2	21196
21152	5	53200	3	12855
21153	5	53202	2	15301
21154	5	53204	6	4772
21155	2	53211	3	21163
21156	5	53212	4	21100
21157	4	53214	5	21186
21158	5	53217	1	17700
21159	5	53221	6	16272
21160	5	53222	2	11766
21161	3	53224	5	4347
21162	5	53232	4	21133
21163	5	53233	6	2885
21164	5	53234	4	2272
21165	3	53239	5	21096
21166	5	53250	3	16230
21167	5	53251	1	14956
21168	5	53256	6	1194
21169	3	53259	5	21120
21170	1	53260	2	21179
21171	5	53261	2	1384
21172	5	53263	6	4325
21173	5	53264	6	13967
21174	5	53268	1	21090
21175	5	53268	6	21090
21176	3	53270	6	21140
21177	4	53272	5	19039
21178	3	53273	5	7532
21179	2	53274	6	13667
21180	5	53275	7	17359
21181	5	53277	2	21328
21182	3	53278	3	21342
21183	4	53279	2	21236
21184	1	53280	6	21232
21185	2	53281	6	21243
21186	3	53286	1	21221
21187	5	53288	2	295
21188	5	53289	4	10019
21189	3	53291	3	11992
21190	5	53292	6	16797
21191	4	53293	7	20209
21192	5	53296	5	21295
21193	2	53298	4	10072
21194	4	53299	6	10556
21195	5	53301	4	21231
21196	5	53302	7	4325
21197	4	53309	1	8512
21198	3	53310	5	2416
21199	4	53312	5	21220
21200	5	53312	6	21220
21201	4	53315	2	10159
21202	5	53317	1	14813
21203	3	53318	1	21324
21204	5	53319	4	21065
21205	5	53328	3	16081
21206	5	53328	1	16081
21207	4	53331	1	19243
21208	1	53332	6	21333
21209	5	53333	6	13987
21210	3	53334	4	21242
21211	5	53338	4	20327
21212	5	53339	6	204
21213	5	53340	2	7098
21214	3	53343	3	10108
21215	4	53343	6	10108
21216	4	53346	2	12108
21217	3	53347	2	21217
21218	4	53347	1	21217
21219	2	53349	4	21337
21220	5	53355	1	14155
21221	5	53357	7	3709
21222	4	53357	5	3709
21223	3	53362	7	15044
21224	5	53363	2	21335
21225	5	53364	5	12442
21226	4	53365	4	480
21227	2	53373	6	13241
21228	4	53375	4	4982
21229	4	53376	2	6101
21230	3	53380	5	21326
21231	4	53380	3	21326
21232	4	53381	6	8214
21233	4	53384	5	179
21234	5	53385	6	14384
21235	5	53386	4	10518
21236	5	53387	3	21317
21237	5	53392	4	8071
21238	3	53393	6	15005
21239	5	53394	4	9286
21240	3	53398	3	4339
21241	5	53400	2	707
21242	3	53401	4	20182
21243	3	53402	7	17720
21244	3	53404	7	4400
21245	4	53406	1	19052
21246	5	53409	6	15375
21247	3	53411	3	21315
21248	3	53412	1	7983
21249	5	53413	1	8705
21250	5	53416	6	21212
21251	3	53417	3	15407
21252	5	53418	4	21307
21253	3	53420	1	20091
21254	4	53426	5	21277
21255	3	53427	5	15334
21256	5	53427	2	15334
21257	4	53428	7	5023
21258	4	53436	5	2119
21259	3	53439	5	21303
21260	5	53440	6	2728
21261	4	53443	7	21284
21262	2	53445	6	186
21263	5	53446	7	21280
21264	3	53453	1	19114
21265	5	53454	2	11988
21266	4	53455	7	519
21267	4	53456	2	21336
21268	5	53457	6	5130
21269	3	53460	1	2752
21270	5	53462	2	20912
21271	5	53463	1	20990
21272	5	53463	6	20990
21273	5	53465	6	15881
21274	5	53467	4	4137
21275	4	53469	7	4030
21276	5	53472	7	10729
21277	3	53473	7	19663
21278	5	53474	6	7633
21279	5	53478	5	21306
21280	5	53478	7	21306
21281	5	53480	2	7546
21282	5	53482	2	11756
21283	5	53488	3	106
21284	4	53490	1	10209
21285	5	53493	6	4694
21286	3	53497	3	1472
21287	5	53498	3	21334
21288	5	53501	5	21302
21289	5	53505	4	7485
21290	5	53511	5	397
21291	5	53512	2	21223
21292	4	53512	5	21223
21293	5	53517	4	1568
21294	4	53519	7	21301
21295	5	53523	5	17333
21296	4	53524	3	21281
21297	5	53525	6	18490
21298	5	53527	1	21267
21299	3	53528	4	21340
21300	5	53531	2	21271
21301	4	53532	7	11898
21302	4	53538	6	12935
21303	3	53540	1	20138
21304	5	53542	7	12167
21305	3	53544	5	12841
21306	4	53545	3	21299
21307	3	53551	1	21252
21308	5	53553	6	7204
21309	5	53557	2	21297
21310	3	53558	5	14817
21311	3	53561	4	8747
21312	5	53563	6	16342
21313	3	53568	7	21293
21314	5	53570	5	15184
21315	5	53571	6	15639
21316	4	53573	5	19741
21317	4	53573	1	19741
21318	4	53577	2	5276
21319	5	53580	4	17578
21320	4	53582	7	21230
21321	4	53585	6	16622
21322	3	53586	3	1316
21323	1	53588	6	15280
21324	5	53589	7	4346
21325	5	53592	5	21245
21326	1	53592	6	21245
21327	4	53593	1	17085
21328	5	53599	6	21247
21329	5	53607	2	9845
21330	4	53608	4	10669
21331	4	53610	3	19978
21332	5	53611	5	8212
21333	5	53613	2	21300
21334	5	53614	7	11481
21335	4	53615	2	4110
21336	3	53622	6	3389
21337	3	53624	7	12420
21338	3	53625	3	3181
21339	5	53627	6	21283
21340	5	53628	6	12330
21341	5	53633	4	7572
21342	4	53635	2	11962
21343	5	53636	1	13414
21344	5	53639	3	5406
21345	4	53641	2	7571
21346	5	53644	6	3837
21347	5	53645	1	14024
21348	4	53647	2	21332
21349	4	53649	6	4292
21350	5	53650	2	11100
21351	5	53651	6	21261
21352	4	53651	7	21261
21353	5	53653	4	21170
21354	5	53654	6	17489
21355	4	53655	5	3042
21356	5	53659	2	5354
21357	5	53661	4	1900
21358	5	53663	7	7756
21359	3	53665	5	21224
21360	5	53669	1	21239
21361	5	53674	4	6239
21362	5	53687	7	15437
21363	5	53689	7	17869
21364	4	53690	5	5574
21365	5	53691	3	1810
21366	5	53692	6	21290
21367	3	53693	4	8683
21368	5	53696	6	9960
21369	5	53704	6	21508
21370	5	53705	6	21353
21371	4	53705	7	21353
21372	5	53708	2	21410
21373	3	53709	5	10896
21374	3	53710	5	21448
21375	4	53711	7	12610
21376	5	53712	6	21355
21377	5	53718	6	21457
21378	3	53721	7	21493
21379	5	53721	5	21493
21380	5	53722	4	21374
21381	5	53723	6	21398
21382	5	53724	7	21367
21383	5	53728	6	21449
21384	4	53729	7	5433
21385	5	53729	5	5433
21386	5	53730	1	8928
21387	5	53731	4	1317
21388	3	53734	4	3560
21389	4	53735	5	21437
21390	5	53736	7	21483
21391	4	53738	2	21392
21392	5	53739	4	21469
21393	5	53740	1	13940
21394	5	53741	5	17657
21395	3	53747	7	21433
21396	5	53748	5	12476
21397	5	53749	1	20573
21398	5	53754	7	13020
21399	5	53757	6	12070
21400	1	53759	6	21366
21401	4	53766	1	1163
21402	5	53769	6	17198
21403	5	53770	3	21510
21404	2	53772	3	17131
21405	5	53773	6	21462
21406	4	53777	6	21394
21407	5	53778	6	21399
21408	5	53779	5	21445
21409	5	53780	2	21430
21410	5	53781	4	21503
21411	5	53784	6	21470
21412	4	53785	1	5234
21413	4	53793	2	9450
21414	3	53794	3	21405
21415	5	53794	4	21405
21416	5	53795	6	15777
21417	4	53801	3	169
21418	4	53802	3	256
21419	4	53802	6	256
21420	4	53806	4	21404
21421	5	53808	5	21395
21422	5	53811	5	801
21423	5	53814	7	3871
21424	5	53816	5	21473
21425	5	53817	5	21417
21426	5	53817	4	21417
21427	5	53827	2	21512
21428	3	53830	1	16569
21429	4	53833	3	21514
21430	5	53834	1	21500
21431	3	53837	3	9949
21432	4	53838	3	21464
21433	3	53841	5	21387
21434	5	53846	2	21518
21435	3	53850	1	21373
21436	4	53851	6	17569
21437	3	53852	3	18770
21438	5	53853	5	21513
21439	5	53854	2	4319
21440	2	53856	1	122
21441	5	53858	5	1979
21442	4	53867	1	21364
21443	5	53873	7	3278
21444	4	53878	4	9194
21445	5	53881	6	21384
21446	5	53883	5	21358
21447	5	53884	6	21511
21448	3	53886	1	2474
21449	5	53892	2	1676
21450	5	53900	7	1722
21451	5	53901	3	9423
21452	3	53902	7	21527
21453	5	53905	6	1804
21454	1	53907	4	7190
21455	4	53917	5	13621
21456	2	53920	6	21326
21457	4	53925	1	13115
21458	1	53927	6	21465
21459	3	53928	1	6080
21460	1	53938	3	17197
21461	4	53940	4	3481
21462	4	53945	2	2360
21463	5	53946	7	21505
21464	5	53947	5	21529
21465	5	53948	5	29
21466	3	53951	6	11292
21467	3	53954	6	21501
21468	5	53956	1	21446
21469	5	53961	4	847
21470	5	53965	5	21504
21471	5	53966	4	7455
21472	5	53967	6	21499
21473	5	53969	7	11961
21474	4	53969	2	11961
21475	4	53970	5	21391
21476	5	53973	7	21381
21477	4	53976	7	15661
21478	5	53976	5	15661
21479	4	53977	3	11716
21480	5	53979	4	12737
21481	4	53981	7	21402
21482	3	53983	3	20147
21483	3	53984	3	21386
21484	4	53985	7	21451
21485	1	53986	6	21354
21486	4	53987	5	21491
21487	5	53988	7	5884
21488	5	53989	3	15995
21489	5	53990	2	3403
21490	2	53993	6	21348
21491	4	53994	3	21400
21492	4	53995	4	21352
21493	5	54000	1	21477
21494	5	54003	6	21476
21495	5	54005	7	8372
21496	5	54007	7	15108
21497	5	54008	3	21516
21498	5	54012	4	17610
21499	3	54018	4	1674
21500	1	54019	6	786
21501	4	54025	1	21485
21502	1	54027	6	7623
21503	5	54029	7	21383
21504	5	54030	1	7220
21505	5	54035	3	21425
21506	1	54037	7	21432
21507	5	54039	5	2821
21508	5	54040	4	21481
21509	5	54046	6	10387
21510	4	54047	4	13568
21511	5	54049	2	21343
21512	3	54050	1	17596
21513	5	54052	7	636
21514	5	54053	3	20606
21515	5	54061	5	21682
21516	3	54067	6	21545
21517	5	54073	3	16530
21518	5	54074	6	559
21519	2	54075	6	14558
21520	5	54078	6	3938
21521	5	54082	2	12367
21522	4	54084	5	14694
21523	5	54085	6	21621
21524	3	54089	3	21703
21525	4	54092	7	5888
21526	5	54093	7	19529
21527	5	54097	4	12265
21528	5	54099	6	16627
21529	5	54100	1	11793
21530	5	54102	3	21599
21531	5	54104	5	7159
21532	5	54105	1	21640
21533	4	54109	7	9296
21534	5	54110	6	16836
21535	5	54114	2	21686
21536	3	54120	5	10494
21537	3	54121	5	21606
21538	5	54122	3	10365
21539	5	54125	1	970
21540	5	54127	2	11867
21541	5	54128	2	10850
21542	5	54129	6	5154
21543	5	54130	4	21329
21544	3	54131	5	21669
21545	4	54132	4	10706
21546	2	54133	6	10027
21547	5	54136	4	7465
21548	5	54139	7	13411
21549	3	54140	5	5060
21550	5	54142	6	18419
21551	3	54143	7	13488
21552	5	54143	1	13488
21553	4	54145	5	3286
21554	5	54148	6	15888
21555	5	54149	6	5642
21556	5	54150	5	21531
21557	5	54155	6	21580
21558	5	54156	2	268
21559	5	54157	1	21537
21560	5	54158	7	13153
21561	5	54159	2	21578
21562	4	54163	6	21677
21563	5	54167	6	10589
21564	4	54169	7	12780
21565	5	54172	3	21666
21566	5	54174	4	7631
21567	5	54179	2	8379
21568	4	54181	5	1507
21569	2	54184	6	21592
21570	5	54185	6	21567
21571	5	54191	7	21634
21572	5	54195	3	12827
21573	5	54196	2	8184
21574	5	54199	4	21623
21575	5	54203	6	8775
21576	2	54209	6	14222
21577	3	54210	7	489
21578	4	54213	7	16239
21579	4	54218	4	16710
21580	5	54220	7	21613
21581	5	54224	4	21696
21582	5	54226	4	21685
21583	5	54232	4	21561
21584	4	54234	4	467
21585	4	54236	2	21694
21586	5	54237	7	2025
21587	5	54239	7	21648
21588	3	54239	5	21648
21589	3	54244	3	9852
21590	5	54247	6	21626
21591	2	54253	5	11412
21592	5	54254	3	17145
21593	4	54257	7	4824
21594	5	54261	5	21630
21595	4	54262	7	2897
21596	4	54264	4	11768
21597	4	54265	4	7374
21598	3	54268	4	2696
21599	5	54270	2	21556
21600	5	54273	7	6116
21601	5	54276	6	17003
21602	4	54278	2	3868
21603	5	54280	6	5082
21604	5	54282	2	17831
21605	2	54285	6	4532
21606	4	54289	7	21702
21607	5	54290	3	21550
21608	5	54292	4	21576
21609	4	54294	6	21536
21610	4	54295	1	293
21611	5	54296	1	2354
21612	5	54297	5	18658
21613	5	54302	1	11825
21614	4	54303	7	21684
21615	5	54305	3	14572
21616	5	54307	4	21560
21617	3	54312	5	21540
21618	5	54314	2	21608
21619	5	54315	2	6519
21620	5	54319	4	9778
21621	5	54322	2	13649
21622	3	54325	1	21660
21623	5	54326	4	3684
21624	4	54327	7	1315
21625	3	54329	5	17511
21626	5	54330	6	16829
21627	5	54335	6	11779
21628	1	54340	2	14775
21629	1	54341	1	12791
21630	5	54343	2	21618
21631	3	54344	5	6603
21632	5	54345	4	995
21633	5	54346	2	19212
21634	3	54348	2	7834
21635	5	54349	7	12094
21636	3	54350	2	566
21637	5	54351	1	19892
21638	4	54352	4	6104
21639	4	54353	6	21594
21640	2	54355	2	8757
21641	5	54357	3	1922
21642	4	54361	7	21562
21643	5	54363	3	10694
21644	5	54364	7	4917
21645	5	54365	6	21664
21646	5	54370	2	9266
21647	3	54371	1	6799
21648	4	54374	1	4757
21649	5	54376	7	21639
21650	5	54377	7	9934
21651	3	54378	2	21638
21652	3	54379	1	11777
21653	4	54383	6	7501
21654	5	54385	1	16749
21655	5	54388	4	2477
21656	5	54390	7	6117
21657	5	54392	3	756
21658	3	54392	2	756
21659	4	54395	5	4495
21660	3	54400	5	21689
21661	1	54402	6	21589
21662	5	54404	1	21644
21663	3	54406	4	21611
21664	3	54408	7	10626
21665	5	54411	5	21675
21666	3	54412	1	4088
21667	5	54418	4	171
21668	5	54419	4	20573
21669	5	54424	6	21609
21670	3	54426	1	9973
21671	5	54427	5	21646
21672	5	54432	6	21555
21673	3	54433	6	21543
21674	5	54434	5	16624
21675	3	54435	6	19488
21676	4	54440	6	21667
21677	5	54441	7	21656
21678	5	54443	5	21564
21679	5	54445	3	16044
21680	4	54449	5	21558
21681	5	54456	5	21649
21682	5	54456	2	21649
21683	5	54457	6	3957
21684	5	54458	7	21657
21685	5	54462	6	21676
21686	3	54465	5	21701
21687	3	54468	7	9057
21688	3	54471	4	21672
21689	4	54474	5	21586
21690	5	54475	7	17803
21691	5	54477	2	1088
21692	5	54478	5	21538
21693	5	54480	2	9957
21694	5	54480	6	9957
21695	3	54482	6	12934
21696	5	54484	2	21698
21697	5	54486	7	21273
21698	4	54489	7	15429
21699	5	54490	1	10980
21700	5	54491	2	10852
21701	4	54494	3	12164
21702	5	54495	5	16152
21703	5	54499	2	15101
21704	5	54503	2	14970
21705	4	54504	1	8090
21706	3	54505	7	19122
21707	4	54506	6	21670
21708	3	54510	5	21426
21709	5	54511	1	15437
21710	5	54521	2	21654
21711	5	54521	7	21654
21712	5	54522	6	21596
21713	3	54528	5	3997
21714	4	54530	2	2784
21715	5	54534	4	21627
21716	4	54539	5	3542
21717	5	54539	4	3542
21718	5	54543	6	4651
21719	3	54544	7	21619
21720	5	54545	6	4141
21721	3	54547	5	4347
21722	4	54548	7	6366
21723	4	54549	7	546
21724	5	54551	7	21590
21725	4	54551	3	21590
21726	1	54553	6	15000
21727	2	54556	3	21617
21728	4	54560	7	21695
21729	3	54561	6	21583
21730	5	54562	7	15749
21731	3	54565	5	7526
21732	5	54566	7	6248
21733	5	54567	2	21620
21734	5	54568	7	21602
21735	5	54570	3	644
21736	5	54572	1	6477
21737	5	54574	6	19107
21738	5	54575	2	2420
21739	3	54575	5	2420
21740	5	54580	6	6202
21741	3	54581	5	16503
21742	4	54588	5	14972
21743	3	54590	5	13178
21744	3	54593	5	7821
21745	5	54597	5	21713
21746	5	54598	5	12786
21747	3	54599	5	18658
21748	4	54606	1	18980
21749	4	54607	7	7387
21750	5	54609	7	21808
21751	3	54612	5	21849
21752	5	54613	7	21881
21753	3	54615	7	18304
21754	5	54619	6	189
21755	5	54622	6	1720
21756	3	54622	7	1720
21757	5	54623	5	11141
21758	4	54625	7	14707
21759	4	54626	3	2182
21760	3	54627	7	13634
21761	4	54629	5	21743
21762	5	54631	7	8442
21763	5	54633	2	13740
21764	4	54634	6	13540
21765	3	54637	3	18751
21766	4	54638	7	8295
21767	5	54643	2	10073
21768	5	54644	6	5176
21769	4	54649	3	7871
21770	5	54650	7	5822
21771	5	54651	2	18568
21772	4	54652	5	10362
21773	5	54653	5	7627
21774	4	54656	2	661
21775	4	54666	7	1369
21776	5	54669	4	21865
21777	4	54676	2	2905
21778	5	54677	4	21822
21779	5	54681	3	21717
21780	4	54682	2	21867
21781	5	54689	6	16952
21782	3	54690	4	21774
21783	5	54693	2	21726
21784	3	54695	5	9113
21785	5	54696	6	19840
21786	3	54697	4	8234
21787	5	54700	6	865
21788	4	54703	7	8810
21789	5	54704	2	21725
21790	5	54706	7	16985
21791	4	54707	7	21352
21792	5	54708	7	17934
21793	5	54709	2	21872
21794	3	54710	1	5708
21795	3	54713	7	20852
21796	5	54716	3	10679
21797	4	54717	1	21856
21798	3	54718	7	15995
21799	5	54719	7	10763
21800	4	54720	7	8344
21801	5	54725	4	482
21802	4	54728	3	9375
21803	3	54731	1	21860
21804	4	54735	3	16253
21805	5	54738	2	21536
21806	2	54739	3	12387
21807	4	54742	5	21821
21808	5	54744	4	21873
21809	3	54746	7	7545
21810	3	54748	7	11023
21811	5	54749	1	21854
21812	2	54753	6	5310
21813	5	54757	6	21783
21814	4	54758	2	21800
21815	4	54765	5	2079
21816	5	54766	2	21810
21817	3	54773	7	12629
21818	4	54775	2	21749
21819	5	54777	2	21851
21820	5	54778	1	5075
21821	5	54778	2	5075
21822	3	54782	4	13387
21823	5	54783	6	18412
21824	5	54785	6	3377
21825	5	54793	7	1858
21826	4	54795	2	6092
21827	4	54798	7	21857
21828	4	54800	7	9141
21829	5	54809	2	1352
21830	5	54812	2	1505
21831	5	54815	5	10713
21832	3	54818	7	15105
21833	5	54820	7	21871
21834	4	54824	2	3466
21835	2	54826	3	9559
21836	4	54827	4	2653
21837	3	54828	5	21724
21838	5	54832	6	17754
21839	5	54839	4	15099
21840	5	54841	2	2158
21841	5	54844	7	14344
21842	4	54845	5	20942
21843	4	54845	2	20942
21844	3	54847	5	15162
21845	3	54851	2	3260
21846	5	54852	1	18353
21847	5	54853	2	3696
21848	3	54856	5	15189
21849	5	54861	1	8250
21850	5	54861	7	8250
21851	4	54863	7	4009
21852	4	54864	3	13674
21853	5	54866	6	2190
21854	5	54867	5	21769
21855	5	54871	2	3509
21856	1	54873	6	21875
21857	5	54874	1	408
21858	5	54878	4	21863
21859	4	54879	2	2031
21860	5	54883	7	17435
21861	4	54884	7	21737
21862	5	54893	3	21845
21863	4	54896	2	16872
21864	4	54897	5	21804
21865	5	54901	7	21734
21866	4	54903	7	17152
21867	4	54910	4	259
21868	3	54917	5	19290
21869	4	54921	3	1063
21870	5	54922	7	21886
21871	5	54929	2	2662
21872	5	54930	5	13621
21873	5	54931	4	11515
21874	5	54932	1	21721
21875	5	54936	2	21844
21876	4	54939	7	19506
21877	5	54941	5	21754
21878	5	54941	6	21754
21879	4	54943	1	21820
21880	5	54945	3	14124
21881	5	54947	6	13507
21882	4	54949	1	21762
21883	4	54949	5	21762
21884	5	54954	6	2981
21885	5	54955	7	21842
21886	5	54962	6	1239
21887	3	54967	7	19981
21888	5	54968	3	21718
21889	5	54969	6	2972
21890	4	54970	6	8298
21891	5	54973	6	9082
21892	5	54975	6	21832
21893	4	54979	7	2971
21894	1	54980	6	17428
21895	5	54982	6	3940
21896	3	54984	4	21386
21897	4	54987	7	16289
21898	5	54988	7	19467
21899	4	54991	4	457
21900	3	54997	3	4414
21901	4	54999	7	21888
21902	4	55003	6	21719
21903	4	55004	5	21819
21904	5	55005	5	13639
21905	5	55006	5	1616
21906	5	55011	1	21850
21907	4	55016	5	15781
21908	5	55017	2	21509
21909	5	55021	3	21876
21910	5	55023	2	21751
21911	3	55024	2	1810
21912	5	55025	5	13236
21913	5	55029	6	21773
21914	3	55033	1	21752
21915	4	55037	4	21818
21916	4	55038	7	18159
21917	4	55041	1	21890
21918	5	55044	5	21793
21919	5	55045	1	21887
21920	5	55046	6	4710
21921	4	55048	1	18016
21922	5	55055	2	8212
21923	5	55056	4	13596
21924	5	55059	7	21861
21925	4	55062	7	19011
21926	3	55063	5	14411
21927	3	55066	2	593
21928	5	55067	4	9246
21929	5	55072	6	21782
21930	5	55076	4	15069
21931	5	55077	4	2119
21932	4	55080	4	15930
21933	4	55081	3	15180
21934	4	55082	6	19459
21935	3	55083	7	21578
21936	5	55084	1	8508
21937	4	55086	4	3863
21938	5	55088	6	14662
21939	3	55091	4	21830
21940	4	55094	7	19229
21941	4	55104	6	21802
21942	5	55106	1	8552
21943	3	55109	5	19523
21944	3	55112	6	5850
21945	2	55113	6	15194
21946	5	55118	6	18379
21947	3	55120	7	21720
21948	2	55120	6	21720
21949	4	55121	1	6819
21950	3	55122	3	19857
21951	1	55123	4	2277
21952	4	55129	5	14237
21953	5	55130	1	21712
21954	4	55134	5	21715
21955	3	55135	3	12532
21956	5	55138	7	2298
21957	3	55138	5	2298
21958	5	55142	5	8406
21959	2	55146	6	21843
21960	5	55147	1	18475
21961	3	55149	1	20144
21962	5	55157	3	21848
21963	5	55157	7	21848
21964	3	55158	1	2231
21965	5	55162	6	18348
21966	4	55164	6	21776
21967	5	55165	3	14660
21968	4	55165	5	14660
21969	3	55166	4	13958
21970	4	55167	2	12168
21971	5	55171	1	14795
21972	4	55172	2	14616
21973	5	55175	1	9344
21974	5	55178	6	5251
21975	5	55187	4	6499
21976	4	55189	5	11789
21977	5	55193	1	18948
21978	5	55195	6	8651
21979	3	55199	3	21952
21980	5	55203	7	21917
21981	3	55205	3	6347
21982	5	55205	5	6347
21983	5	55206	4	3092
21984	5	55209	2	14165
21985	4	55212	5	11241
21986	4	55213	1	16272
21987	5	55217	2	7952
21988	5	55218	5	19820
21989	3	55224	5	16678
21990	5	55225	2	10983
21991	4	55228	5	19566
21992	4	55230	3	8589
21993	4	55237	7	20528
21994	5	55240	3	203
21995	3	55241	5	8834
21996	4	55245	2	9449
21997	3	55246	6	17910
21998	3	55252	2	22028
21999	3	55253	4	8382
22000	4	55255	1	20215
22001	5	55256	6	15032
22002	5	55259	4	21897
22003	4	55260	1	21930
22004	3	55261	6	7440
22005	5	55267	5	21990
22006	4	55268	7	12907
22007	5	55272	6	21977
22008	4	55273	3	21943
22009	3	55274	2	21987
22010	5	55279	3	22023
22011	4	55280	6	6707
22012	5	55282	7	21898
22013	3	55284	4	19160
22014	5	55287	2	21934
22015	5	55291	1	21262
22016	5	55292	4	7586
22017	1	55294	7	21086
22018	1	55294	6	21086
22019	4	55295	7	3459
22020	4	55296	5	21984
22021	4	55299	5	10594
22022	5	55302	6	7244
22023	4	55302	4	7244
22024	4	55304	1	21953
22025	5	55305	6	20250
22026	5	55308	2	21968
22027	3	55309	1	3509
22028	3	55310	5	22006
22029	5	55311	6	5707
22030	4	55312	7	21957
22031	5	55316	3	22003
22032	5	55317	2	14900
22033	5	55317	5	14900
22034	5	55318	6	21955
22035	5	55321	6	13704
22036	5	55324	4	18685
22037	3	55327	3	6104
22038	4	55328	2	15015
22039	4	55332	2	6959
22040	5	55333	2	15944
22041	5	55334	6	14775
22042	5	55335	4	17541
22043	3	55340	5	8666
22044	3	55341	5	19504
22045	5	55343	6	189
22046	1	55344	6	15669
22047	3	55351	7	16216
22048	5	55352	4	120
22049	3	55354	5	22004
22050	5	55354	2	22004
22051	5	55355	6	17669
22052	5	55358	7	21935
22053	5	55360	4	22026
22054	5	55364	4	21991
22055	5	55366	4	16135
22056	4	55369	3	8320
22057	5	55369	2	8320
22058	5	55371	2	21969
22059	3	55375	4	22012
22060	3	55378	5	21983
22061	5	55379	4	21975
22062	5	55384	1	20852
22063	2	55384	6	20852
22064	5	55388	2	17256
22065	4	55389	1	21945
22066	5	55389	3	21945
22067	5	55391	1	22001
22068	5	55392	3	21901
22069	5	55393	5	19817
22070	5	55394	2	7691
22071	5	55398	6	12876
22072	3	55399	5	7217
22073	4	55400	5	21854
22074	3	55402	5	9199
22075	3	55403	4	8548
22076	5	55408	2	6699
22077	2	55411	3	11624
22078	3	55415	3	5028
22079	5	55416	6	21976
22080	3	55419	2	2000
22081	4	55422	4	18353
22082	5	55423	5	15929
22083	4	55426	6	8866
22084	5	55428	4	15603
22085	5	55433	6	1100
22086	3	55436	7	16565
22087	3	55437	5	21938
22088	5	55443	4	2961
22089	5	55444	6	21944
22090	5	55445	4	4901
22091	5	55447	3	6366
22092	5	55447	6	6366
22093	5	55450	5	6813
22094	5	55451	6	21910
22095	3	55456	1	14344
22096	5	55461	4	22076
22097	5	55462	4	16834
22098	4	55465	5	22154
22099	3	55467	4	4362
22100	4	55469	3	22042
22101	5	55472	7	17435
22102	5	55475	7	11377
22103	3	55480	4	22115
22104	1	55482	5	9859
22105	3	55485	2	11041
22106	5	55488	4	21368
22107	5	55489	5	4281
22108	5	55494	2	12054
22109	5	55498	2	20911
22110	5	55499	7	22039
22111	3	55502	5	19093
22112	5	55503	6	120
22113	5	55506	4	12883
22114	2	55507	2	2980
22115	3	55509	5	22131
22116	4	55509	7	22131
22117	5	55510	6	18938
22118	3	55512	5	5581
22119	5	55513	6	22184
22120	4	55515	3	22045
22121	5	55519	5	9139
22122	5	55520	3	5460
22123	5	55525	3	9312
22124	5	55526	2	8692
22125	5	55526	4	8692
22126	5	55528	2	22168
22127	3	55530	4	22117
22128	3	55534	7	22085
22129	4	55536	5	22164
22130	4	55537	6	3640
22131	5	55538	4	4376
22132	4	55539	1	22072
22133	5	55541	3	11685
22134	5	55542	5	193
22135	4	55544	3	1992
22136	3	55550	7	22064
22137	5	55553	7	22087
22138	5	55558	2	6015
22139	4	55559	4	11507
22140	5	55560	6	2590
22141	5	55562	6	5835
22142	3	55565	1	18928
22143	5	55566	2	19978
22144	5	55566	4	19978
22145	5	55567	4	16270
22146	5	55571	6	4644
22147	5	55573	4	22197
22148	2	55581	4	9898
22149	5	55582	7	14743
22150	4	55587	2	21386
22151	5	55590	4	3992
22152	5	55594	1	22106
22153	3	55595	5	17995
22154	4	55600	5	20443
22155	5	55602	5	9103
22156	5	55605	4	6201
22157	3	55608	1	3626
22158	1	55610	6	22043
22159	1	55611	1	15110
22160	5	55612	7	20092
22161	4	55614	6	14495
22162	3	55621	3	22063
22163	5	55624	3	5857
22164	4	55625	3	20524
22165	5	55626	2	16516
22166	5	55628	2	22070
22167	4	55630	1	4033
22168	5	55635	7	22163
22169	5	55638	7	1537
22170	5	55639	2	5181
22171	5	55641	6	7208
22172	4	55643	2	15265
22173	3	55645	2	8954
22174	5	55646	6	22145
22175	5	55648	7	12224
22176	3	55651	7	14068
22177	5	55652	1	16831
22178	5	55653	6	10499
22179	5	55654	7	6480
22180	5	55655	6	16084
22181	3	55656	3	22074
22182	5	55659	4	741
22183	3	55660	7	20271
22184	5	55668	3	21945
22185	5	55670	6	22078
22186	5	55672	4	511
22187	5	55673	1	22190
22188	5	55675	2	22066
22189	5	55678	6	22139
22190	4	55679	7	22200
22191	2	55680	2	18392
22192	3	55681	7	22208
22193	5	55684	5	11266
22194	1	55685	6	6950
22195	5	55687	4	993
22196	5	55689	3	21431
22197	4	55690	4	22165
22198	5	55692	7	16001
22199	5	55692	3	16001
22200	5	55694	7	22186
22201	4	55697	3	17950
22202	5	55697	6	17950
22203	4	55699	7	22133
22204	5	55704	7	22125
22205	4	55705	5	22112
22206	5	55708	1	17550
22207	5	55711	6	18133
22208	5	55714	4	22193
22209	5	55714	5	22193
22210	5	55718	5	4232
22211	4	55721	4	19375
22212	4	55722	5	22135
22213	3	55725	5	2050
22214	5	55726	6	22119
22215	4	55729	7	22082
22216	3	55730	7	16771
22217	4	55735	2	22185
22218	5	55739	6	16307
22219	3	55741	7	12228
22220	5	55747	6	22180
22221	5	55748	6	11283
22222	5	55749	6	20413
22223	5	55752	6	11403
22224	3	55755	1	22101
22225	5	55756	6	10567
22226	5	55761	2	8705
22227	5	55762	2	22124
22228	4	55763	3	5792
22229	5	55764	6	22080
22230	5	55766	5	2838
22231	5	55767	1	10541
22232	5	55768	3	20803
22233	5	55768	7	20803
22234	5	55769	6	22202
22235	3	55774	7	1765
22236	5	55777	3	287
22237	4	55783	7	2185
22238	5	55785	2	13307
22239	5	55786	3	586
22240	4	55787	7	12701
22241	4	55788	1	16632
22242	4	55791	6	15902
22243	3	55794	7	22071
22244	4	55795	2	1288
22245	4	55799	5	10729
22246	1	55801	5	22037
22247	1	55804	6	9851
22248	5	55808	4	22214
22249	2	55809	4	22308
22250	5	55815	2	5339
22251	5	55818	6	7261
22252	4	55820	7	13881
22253	5	55821	6	14357
22254	3	55823	5	3511
22255	4	55824	7	22349
22256	5	55825	6	6154
22257	4	55826	7	22378
22258	5	55827	7	22313
22259	3	55828	1	11190
22260	5	55829	2	1808
22261	5	55830	7	22377
22262	2	55831	7	22350
22263	5	55832	6	502
22264	3	55833	3	22260
22265	4	55835	4	6591
22266	4	55845	4	2366
22267	5	55846	7	22226
22268	5	55846	5	22226
22269	3	55853	6	22280
22270	2	55857	3	16152
22271	5	55860	2	10264
22272	2	55862	2	22279
22273	3	55864	1	22329
22274	5	55871	7	22228
22275	4	55872	1	9892
22276	4	55876	7	22217
22277	5	55879	3	5526
22278	4	55880	7	9313
22279	5	55881	6	22259
22280	5	55883	6	1055
22281	4	55884	5	22364
22282	5	55887	2	20832
22283	5	55888	6	13188
22284	3	55890	3	22309
22285	5	55895	6	22367
22286	4	55898	7	16444
22287	5	55901	2	11550
22288	4	55902	3	7706
22289	4	55903	7	4577
22290	5	55905	6	3111
22291	3	55908	1	18035
22292	5	55909	5	5791
22293	1	55910	7	22271
22294	5	55911	6	22236
22295	5	55915	2	22305
22296	4	55923	5	22357
22297	5	55924	1	21304
22298	5	55926	2	8521
22299	3	55927	7	1306
22300	2	55928	6	22353
22301	4	55929	7	22317
22302	5	55930	4	21826
22303	4	55932	2	19857
22304	4	55935	5	22306
22305	5	55936	7	20820
22306	5	55939	4	22358
22307	5	55947	3	22213
22308	2	55949	4	808
22309	4	55955	2	9312
22310	5	55956	3	22247
22311	5	55958	2	6941
22312	4	55964	3	3447
22313	4	55965	2	29
22314	5	55968	4	5267
22315	5	55969	4	22253
22316	4	55971	2	22362
22317	3	55972	5	11277
22318	5	55976	2	2806
22319	3	55980	5	22276
22320	5	55983	1	2954
22321	4	55988	5	15565
22322	5	55991	1	10968
22323	5	55992	1	22348
22324	5	55996	1	13303
22325	5	56000	2	22285
22326	1	56000	6	22285
22327	1	56002	4	22369
22328	3	56005	2	18119
22329	4	56007	5	10444
22330	5	56008	1	18980
22331	5	56009	6	22316
22332	5	56010	5	21133
22333	4	56011	1	4560
22334	5	56012	4	7179
22335	5	56013	2	6232
22336	4	56020	6	14002
22337	5	56023	2	18520
22338	5	56024	3	18815
22339	4	56027	5	12231
22340	5	56031	4	12853
22341	5	56032	2	2252
22342	5	56034	2	9086
22343	5	56035	5	2543
22344	5	56037	2	4837
22345	3	56040	5	9103
22346	5	56042	4	22351
22347	5	56046	4	22211
22348	4	56050	2	3888
22349	2	56051	1	17306
22350	5	56052	6	809
22351	4	56052	3	809
22352	5	56054	7	9166
22353	5	56055	5	11267
22354	5	56057	6	15679
22355	5	56057	4	15679
22356	5	56062	5	2731
22357	3	56063	6	22346
22358	5	56064	3	22122
22359	2	56065	6	11070
22360	4	56067	4	18171
22361	4	56068	4	15314
22362	5	56074	7	19372
22363	5	56077	7	22361
22364	5	56080	1	19434
22365	5	56081	6	14529
22366	1	56095	6	3333
22367	3	56096	5	5655
22368	5	56102	3	19729
22369	5	56103	3	22335
22370	5	56106	6	22291
22371	5	56115	7	12019
22372	4	56120	6	14924
22373	3	56121	2	22252
22374	5	56123	6	6519
22375	3	56124	5	18951
22376	3	56128	5	7200
22377	3	56129	5	1715
22378	3	56130	7	7888
22379	3	56132	1	22231
22380	5	56138	3	22333
22381	4	56139	7	12467
22382	4	56143	5	22225
22383	4	56149	7	22250
22384	5	56151	5	22355
22385	5	56153	4	22222
22386	3	56155	2	20154
22387	5	56156	4	22293
22388	5	56159	6	22312
22389	4	56163	7	22371
22390	4	56167	2	17190
22391	4	56176	2	22218
22392	5	56179	4	22299
22393	5	56180	6	16844
22394	3	56181	3	10507
22395	5	56183	6	13713
22396	5	56183	5	13713
22397	5	56188	4	22270
22398	4	56193	7	21502
22399	5	56194	7	11922
22400	5	56196	7	11543
22401	5	56197	4	10279
22402	5	56198	6	3835
22403	5	56199	7	20029
22404	3	56200	4	22289
22405	5	56201	1	22212
22406	5	56201	4	22212
22407	5	56204	3	13452
22408	5	56206	4	20993
22409	1	56207	6	21177
22410	5	56209	6	22273
22411	3	56210	5	22354
22412	5	56213	3	22311
22413	4	56214	6	22300
22414	5	56215	4	8612
22415	5	56216	7	14032
22416	5	56217	4	20844
22417	5	56220	6	6786
22418	5	56221	4	21078
22419	5	56226	1	22474
22420	4	56227	7	18124
22421	5	56229	1	6957
22422	5	56230	4	22128
22423	5	56232	6	22400
22424	4	56237	1	20946
22425	5	56238	5	20840
22426	5	56239	6	22504
22427	3	56247	7	16193
22428	4	56253	2	17701
22429	3	56255	6	4689
22430	4	56259	7	22418
22431	5	56262	6	4841
22432	4	56263	7	6752
22433	5	56264	7	4939
22434	4	56265	7	3289
22435	5	56266	6	14907
22436	5	56267	6	17986
22437	3	56268	7	8980
22438	5	56269	1	1854
22439	5	56271	4	22401
22440	3	56272	7	806
22441	3	56274	5	22414
22442	5	56278	6	22431
22443	4	56279	6	21806
22444	1	56280	6	8538
22445	4	56281	7	22384
22446	3	56282	5	18680
22447	3	56285	6	7476
22448	5	56290	4	14081
22449	2	56291	6	4671
22450	4	56294	7	585
22451	4	56297	5	7119
22452	3	56300	3	6164
22453	3	56302	7	11367
22454	5	56303	7	11312
22455	5	56304	6	2547
22456	4	56305	6	6885
22457	5	56306	7	13694
22458	5	56312	7	22487
22459	3	56313	2	16952
22460	5	56317	1	12078
22461	5	56318	2	18593
22462	5	56319	6	7731
22463	3	56321	1	12615
22464	5	56322	4	22440
22465	4	56324	7	22421
22466	5	56328	6	10328
22467	4	56332	2	6168
22468	4	56334	3	8176
22469	5	56335	4	16912
22470	5	56337	6	1945
22471	3	56338	2	5710
22472	5	56339	2	22494
22473	3	56340	4	16999
22474	5	56341	3	22466
22475	5	56342	1	22399
22476	2	56342	6	22399
22477	3	56343	5	8897
22478	5	56352	7	5954
22479	5	56358	2	20413
22480	2	56361	4	8014
22481	4	56362	6	10416
22482	3	56363	2	8109
22483	3	56365	7	22438
22484	5	56374	4	22428
22485	5	56378	4	22499
22486	4	56379	7	22422
22487	4	56382	5	13272
22488	3	56385	5	11789
22489	2	56386	3	22457
22490	5	56386	2	22457
22491	4	56388	3	1748
22492	3	56389	7	10496
22493	5	56391	7	22420
22494	5	56397	1	15496
22495	4	56399	7	7176
22496	3	56403	1	21142
22497	3	56404	4	8585
22498	5	56406	5	19493
22499	2	56409	3	22465
22500	4	56410	1	22410
22501	3	56411	5	10999
22502	5	56413	3	22444
22503	4	56414	7	8791
22504	5	56420	2	3324
22505	5	56420	6	3324
22506	2	56421	3	4782
22507	5	56422	1	21438
22508	1	56425	6	22483
22509	1	56429	6	1627
22510	5	56430	1	18627
22511	4	56432	3	6026
22512	5	56433	6	6113
22513	5	56436	6	22486
22514	5	56444	2	22396
22515	5	56447	1	17190
22516	5	56448	6	11454
22517	5	56450	4	11961
22518	5	56452	5	22398
22519	4	56453	2	19030
22520	4	56455	2	16042
22521	5	56458	3	22473
22522	3	56459	5	2591
22523	5	56464	1	1068
22524	1	56466	6	22392
22525	5	56470	2	13426
22526	3	56471	3	4828
22527	5	56475	4	22478
22528	3	56477	6	1700
22529	5	56479	1	22497
22530	5	56480	6	14842
22531	5	56481	7	22382
22532	5	56481	4	22382
22533	5	56482	7	22388
22534	4	56484	5	19198
22535	5	56487	7	7319
22536	4	56493	6	19647
22537	5	56495	1	14662
22538	3	56496	4	456
22539	5	56506	4	21703
22540	5	56509	4	12490
22541	5	56510	7	22467
22542	5	56512	7	19679
22543	5	56513	7	16323
22544	4	56515	2	9682
22545	4	56516	5	17610
22546	5	56520	2	22433
22547	1	56524	2	7293
22548	4	56525	3	2478
22549	1	56530	3	22472
22550	5	56535	3	4287
22551	5	56536	1	19172
22552	3	56537	2	22404
22553	4	56541	7	14475
22554	5	56542	6	17485
22555	4	56544	2	21143
22556	5	56546	4	7776
22557	3	56548	7	1541
22558	3	56550	4	19008
22559	5	56551	3	22492
22560	5	56552	6	22406
22561	5	56553	7	5225
22562	5	56556	6	16156
22563	4	56557	2	21847
22564	3	56559	4	15728
22565	5	56560	3	22385
22566	4	56562	7	2674
22567	4	56566	7	22409
22568	5	56569	4	3490
22569	4	56570	7	22450
22570	4	56572	6	8644
22571	4	56573	5	19535
22572	4	56576	4	22480
22573	5	56577	6	22470
22574	5	56577	4	22470
22575	5	56579	7	3851
22576	2	56580	6	3332
22577	5	56583	4	22506
22578	2	56584	4	16571
22579	5	56586	6	6326
22580	5	56587	1	12894
22581	2	56592	6	22436
22582	5	56594	6	22498
22583	3	56599	1	22489
22584	5	56600	4	22383
22585	5	56603	6	3689
22586	5	56606	6	14555
22587	5	56607	1	10662
22588	5	56612	6	18683
22589	4	56613	7	3661
22590	5	56615	2	20883
22591	5	56616	6	4938
22592	5	56618	2	15356
22593	4	56619	7	22451
22594	4	56621	7	16839
22595	5	56623	4	932
22596	3	56628	5	19490
22597	5	56631	6	13521
22598	4	56635	7	19372
22599	3	56640	4	913
22600	5	56641	7	9530
22601	5	56642	6	234
22602	5	56644	4	12872
22603	4	56645	4	19243
22604	4	56646	7	22434
22605	4	56649	7	20771
22606	3	56650	5	11493
22607	5	56652	6	2178
22608	5	56655	2	20000
22609	5	56657	6	13437
22610	2	56660	2	4307
22611	5	56665	6	2908
22612	5	56672	7	22557
22613	5	56674	7	17331
22614	2	56675	4	22656
22615	5	56676	7	10421
22616	5	56686	6	2428
22617	4	56689	6	22577
22618	5	56690	6	14984
22619	1	56691	6	3518
22620	4	56694	7	22555
22621	3	56698	7	12982
22622	5	56699	6	12364
22623	4	56702	2	22525
22624	5	56705	6	5148
22625	4	56706	7	22567
22626	5	56707	7	22612
22627	5	56709	1	9167
22628	5	56711	4	18376
22629	5	56712	4	22625
22630	5	56713	1	10039
22631	4	56714	5	291
22632	3	56717	7	274
22633	5	56717	1	274
22634	5	56721	6	22655
22635	4	56724	7	22229
22636	2	56725	3	9097
22637	5	56731	6	22601
22638	3	56736	2	19774
22639	1	56737	4	22591
22640	4	56740	6	10933
22641	3	56744	5	7734
22642	5	56745	1	22654
22643	5	56756	4	14775
22644	4	56759	5	19663
22645	5	56760	2	16634
22646	4	56762	5	9728
22647	5	56764	1	11016
22648	5	56764	2	11016
22649	4	56765	2	14520
22650	5	56765	4	14520
22651	5	56766	6	22607
22652	4	56769	6	5248
22653	5	56772	5	13907
22654	3	56774	4	22554
22655	5	56777	6	8385
22656	5	56778	6	22551
22657	4	56779	1	22634
22658	5	56783	7	22622
22659	5	56785	1	22648
22660	4	56790	3	20951
22661	5	56791	7	1442
22662	4	56792	2	12581
22663	4	56798	5	22592
22664	3	56799	5	7706
22665	4	56804	6	20785
22666	5	56806	3	22602
22667	5	56809	2	22553
22668	5	56810	5	22580
22669	2	56813	1	13287
22670	4	56814	6	15629
22671	5	56815	2	22677
22672	5	56817	4	16622
22673	5	56820	1	22700
22674	3	56822	5	21257
22675	5	56826	1	22675
22676	4	56829	7	22697
22677	5	56833	3	22561
22678	5	56836	3	4825
22679	5	56838	5	18903
22680	4	56840	7	6379
22681	5	56841	2	10603
22682	5	56842	6	22562
22683	5	56844	7	4424
22684	5	56845	7	22369
22685	4	56849	7	4674
22686	4	56851	3	17460
22687	3	56852	2	22573
22688	5	56856	7	18596
22689	5	56857	1	4265
22690	5	56859	1	22603
22691	5	56862	6	2341
22692	3	56864	7	15179
22693	4	56864	6	15179
22694	4	56873	3	13320
22695	4	56874	2	8813
22696	5	56876	5	9633
22697	4	56877	5	4559
22698	5	56886	1	2894
22699	4	56892	3	22663
22700	5	56894	1	7444
22701	5	56895	7	22584
22702	5	56898	6	639
22703	4	56901	5	22670
22704	5	56902	4	22671
22705	4	56905	6	22559
22706	4	56906	1	22546
22707	4	56907	5	11983
22708	4	56908	4	17006
22709	3	56908	5	17006
22710	3	56909	5	2275
22711	5	56911	2	22524
22712	3	56911	5	22524
22713	1	56912	4	2443
22714	5	56916	1	21518
22715	2	56918	3	9238
22716	5	56919	6	22633
22717	4	56921	5	16987
22718	5	56922	2	12934
22719	5	56922	5	12934
22720	3	56924	1	6637
22721	5	56927	5	22564
22722	2	56929	6	22535
22723	5	56930	1	22568
22724	5	56931	5	16434
22725	4	56931	1	16434
22726	3	56933	3	7007
22727	5	56933	4	7007
22728	5	56939	1	12057
22729	3	56942	7	20262
22730	5	56946	6	22556
22731	4	56947	2	4767
22732	4	56949	5	22620
22733	3	56950	5	17391
22734	5	56951	6	6104
22735	3	56951	3	6104
22736	3	56956	7	22563
22737	5	56958	2	10159
22738	2	56960	3	22630
22739	4	56962	2	5201
22740	3	56965	7	22516
22741	5	56966	2	22534
22742	5	56969	2	546
22743	4	56970	4	22686
22744	3	56970	7	22686
22745	4	56974	7	19894
22746	5	56975	4	22646
22747	5	56976	2	22552
22748	3	56977	3	19506
22749	4	56978	6	22528
22750	5	56984	6	22595
22751	4	56987	1	20024
22752	5	56989	3	17372
22753	5	56996	6	4905
22754	3	56996	5	4905
22755	5	57001	4	6848
22756	5	57003	2	19434
22757	5	57006	5	22541
22758	4	57007	2	22611
22759	5	57008	2	586
22760	4	57012	7	22533
22761	4	57025	5	22662
22762	5	57026	7	1670
22763	5	57028	1	475
22764	4	57029	7	13758
22765	5	57030	2	3812
22766	5	57031	7	21263
22767	3	57035	3	2071
22768	5	57037	4	4191
22769	4	57039	5	8705
22770	5	57040	5	3618
22771	4	57041	7	22606
22772	5	57042	5	22694
22773	2	57046	4	22645
22774	5	57050	7	22621
22775	3	57051	5	15218
22776	4	57052	2	3989
22777	4	57054	6	8189
22778	5	57055	3	22519
22779	5	57056	1	8349
22780	5	57058	1	17083
22781	4	57061	6	3989
22782	5	57062	5	22713
22783	4	57063	7	19793
22784	5	57065	6	5886
22785	5	57066	3	22835
22786	1	57070	6	7190
22787	2	57071	6	22716
22788	5	57087	6	16350
22789	5	57088	2	22747
22790	5	57092	6	22778
22791	5	57094	1	22787
22792	5	57099	5	15027
22793	5	57101	6	22802
22794	5	57102	2	22826
22795	4	57102	7	22826
22796	4	57105	1	5093
22797	5	57108	6	11648
22798	4	57110	3	18468
22799	5	57113	2	22744
22800	4	57113	7	22744
22801	5	57118	2	2785
22802	5	57121	7	20746
22803	5	57122	4	22785
22804	1	57122	7	22785
22805	5	57128	7	20008
22806	5	57132	1	17286
22807	3	57135	5	22776
22808	5	57142	5	22847
22809	3	57142	2	22847
22810	5	57144	2	18263
22811	5	57147	1	22836
22812	4	57152	7	22866
22813	3	57156	6	3408
22814	5	57158	1	1432
22815	4	57167	5	22750
22816	5	57168	2	1722
22817	5	57174	4	22850
22818	5	57177	6	22755
22819	5	57178	4	19916
22820	5	57180	2	22791
22821	5	57181	4	3119
22822	5	57182	7	22767
22823	4	57183	7	16072
22824	4	57184	7	13262
22825	4	57186	7	18420
22826	5	57190	3	22786
22827	4	57194	1	22861
22828	5	57196	1	22443
22829	3	57199	6	8022
22830	2	57201	7	14286
22831	5	57202	2	8830
22832	4	57205	5	16614
22833	4	57205	6	16614
22834	5	57206	6	15123
22835	5	57209	7	10336
22836	3	57213	7	800
22837	5	57218	6	22706
22838	5	57219	1	22865
22839	4	57221	4	22718
22840	4	57222	7	22871
22841	5	57224	2	22766
22842	5	57228	6	6116
22843	4	57229	7	10266
22844	5	57231	4	16182
22845	5	57231	7	16182
22846	5	57233	2	19602
22847	4	57239	4	22720
22848	3	57241	1	22857
22849	5	57243	1	22860
22850	5	57250	7	9290
22851	5	57254	3	22727
22852	3	57257	1	9110
22853	5	57258	4	11245
22854	5	57260	6	22830
22855	3	57263	7	22736
22856	4	57265	6	22109
22857	5	57268	4	22790
22858	3	57270	7	22726
22859	5	57274	2	2516
22860	3	57277	7	12454
22861	4	57278	3	15443
22862	4	57280	5	18244
22863	5	57281	6	11806
22864	5	57283	5	4841
22865	5	57284	7	22853
22866	3	57285	1	3819
22867	4	57290	2	22789
22868	5	57291	3	7813
22869	4	57292	5	7097
22870	4	57296	1	22812
22871	3	57296	2	22812
22872	5	57298	6	22831
22873	4	57299	5	22799
22874	3	57309	5	94
22875	4	57311	2	14015
22876	5	57314	6	22873
22877	5	57317	6	22782
22878	5	57321	5	7782
22879	1	57321	6	7782
22880	4	57323	5	22158
22881	5	57324	5	22723
22882	5	57326	6	15120
22883	3	57327	2	22759
22884	1	57336	7	10834
22885	4	57341	1	3458
22886	5	57343	2	20187
22887	3	57344	2	22811
22888	5	57344	6	22811
22889	5	57345	7	22764
22890	5	57346	2	1509
22891	5	57349	6	18162
22892	5	57351	4	22722
22893	5	57353	2	1040
22894	5	57357	1	2140
22895	5	57358	6	8708
22896	4	57359	5	14169
22897	5	57362	3	20711
22898	3	57364	3	22771
22899	5	57364	7	22771
22900	3	57366	2	3509
22901	3	57371	3	5503
22902	4	57380	4	22868
22903	5	57383	2	22833
22904	3	57383	1	22833
22905	4	57386	4	22729
22906	3	57388	3	1118
22907	4	57389	6	22874
22908	5	57392	3	2065
22909	3	57394	5	21490
22910	4	57397	6	1335
22911	3	57398	5	14280
22912	3	57400	6	14542
22913	3	57402	4	22867
22914	5	57405	5	10461
22915	5	57407	2	17738
22916	3	57407	1	17738
22917	4	57408	4	7811
22918	3	57408	3	7811
22919	5	57409	2	5761
22920	3	57410	5	15187
22921	5	57413	6	22815
22922	5	57414	5	22809
22923	5	57415	1	6204
22924	5	57416	6	15873
22925	4	57417	5	22754
22926	1	57418	5	22780
22927	4	57419	5	22748
22928	5	57426	1	22711
22929	5	57427	3	8456
22930	3	57428	3	2252
22931	5	57433	6	22854
22932	5	57436	6	8553
22933	3	57440	4	22810
22934	5	57443	4	3421
22935	5	57444	1	22762
22936	1	57446	4	3010
22937	1	57447	6	20068
22938	4	57448	2	2110
22939	5	57458	2	22845
22940	5	57463	2	6270
22941	5	57464	1	19277
22942	4	57466	4	22869
22943	5	57476	4	7757
22944	5	57477	2	10802
22945	3	57484	3	13238
22946	5	57486	1	17556
22947	4	57488	1	22739
22948	5	57489	1	622
22949	4	57490	7	22749
22950	5	57494	4	554
22951	4	57496	5	19693
22952	4	57499	7	22877
22953	3	57500	1	22769
22954	5	57501	2	22805
22955	5	57502	1	1145
22956	5	57504	2	13656
22957	5	57507	7	22840
22958	5	57510	7	11172
22959	5	57511	4	22228
22960	5	57512	7	22332
22961	5	57514	3	1387
22962	3	57517	3	13091
22963	4	57519	7	14979
22964	4	57525	2	22757
22965	2	57525	1	22757
22966	3	57529	7	1453
22967	5	57531	6	8598
22968	1	57534	6	17366
22969	4	57536	7	22712
22970	5	57539	2	22829
22971	2	57540	3	8420
22972	1	57541	6	7533
22973	4	57542	3	22725
22974	5	57542	5	22725
22975	1	57546	6	1597
22976	5	57547	2	136
22977	4	57548	5	22839
22978	3	57549	7	11491
22979	5	57550	4	7028
22980	5	57555	2	3115
22981	5	57558	2	3197
22982	5	57559	2	22702
22983	4	57560	7	17503
22984	4	57561	7	22756
22985	5	57563	2	22320
22986	5	57564	6	19641
22987	5	57566	6	22803
22988	5	57567	2	7905
22989	4	57568	5	5167
22990	4	57576	2	15136
22991	5	57577	2	4695
22992	5	57578	4	4393
22993	5	57579	1	22947
22994	5	57580	7	13842
22995	5	57581	4	22957
22996	4	57585	7	22929
22997	2	57590	5	23017
22998	2	57592	7	10996
22999	3	57593	5	16413
23000	4	57593	2	16413
23001	5	57594	6	23049
23002	5	57597	2	2601
23003	4	57601	1	21887
23004	4	57602	3	22988
23005	2	57604	6	20558
23006	4	57606	7	23001
23007	5	57608	2	5427
23008	1	57609	6	22928
23009	3	57610	7	7906
23010	5	57610	3	7906
23011	5	57611	3	22973
23012	5	57615	7	21672
23013	5	57616	2	22951
23014	5	57618	6	23079
23015	5	57619	4	18375
23016	5	57619	7	18375
23017	4	57620	2	15110
23018	5	57622	6	17503
23019	4	57629	1	14086
23020	3	57630	4	23061
23021	5	57638	6	22910
23022	5	57638	7	22910
23023	5	57642	7	9230
23024	5	57648	6	23057
23025	5	57649	7	12914
23026	5	57653	6	22970
23027	5	57657	2	22889
23028	5	57664	1	22950
23029	3	57666	7	6148
23030	5	57668	6	23016
23031	5	57672	4	19875
23032	5	57677	5	23026
23033	5	57682	6	22898
23034	4	57684	7	23071
23035	5	57694	7	13110
23036	5	57695	4	12598
23037	3	57699	5	20413
23038	5	57699	7	20413
23039	5	57704	6	1155
23040	3	57705	7	11878
23041	4	57706	1	15381
23042	3	57708	7	16921
23043	5	57709	3	17470
23044	4	57710	1	769
23045	5	57715	4	11575
23046	2	57716	7	1771
23047	4	57723	3	11806
23048	5	57724	2	22974
23049	5	57725	4	11260
23050	5	57730	5	278
23051	5	57731	6	17174
23052	1	57736	6	22948
23053	3	57737	4	19865
23054	5	57738	5	8091
23055	5	57740	1	22905
23056	5	57740	2	22905
23057	5	57744	4	22971
23058	3	57746	3	23075
23059	5	57749	2	17799
23060	4	57750	7	23018
23061	4	57752	7	752
23062	5	57753	4	2874
23063	2	57754	6	14638
23064	5	57755	4	5899
23065	4	57756	7	1649
23066	5	57756	6	1649
23067	5	57759	6	22966
23068	5	57760	2	491
23069	4	57767	2	14411
23070	4	57773	4	19500
23071	5	57777	2	22884
23072	5	57778	4	7205
23073	4	57779	6	18818
23074	5	57780	6	4436
23075	3	57781	3	22995
23076	5	57782	2	18976
23077	4	57785	2	8537
23078	5	57786	7	371
23079	5	57787	1	5461
23080	4	57788	7	22946
23081	5	57791	7	22888
23082	5	57793	6	10776
23083	4	57794	1	23013
23084	4	57797	2	19905
23085	5	57800	4	11754
23086	5	57801	1	21178
23087	3	57803	3	18958
23088	5	57805	2	23066
23089	5	57806	4	21352
23090	5	57809	7	18102
23091	4	57809	3	18102
23092	3	57811	2	22969
23093	5	57812	1	3293
23094	4	57813	7	12548
23095	5	57814	6	23043
23096	5	57814	3	23043
23097	4	57815	2	17533
23098	5	57816	2	18567
23099	3	57817	3	22363
23100	4	57819	5	23046
23101	5	57820	4	22979
23102	4	57820	5	22979
23103	3	57824	5	22989
23104	3	57825	7	18810
23105	3	57826	7	13823
23106	5	57831	7	8230
23107	4	57833	7	22956
23108	5	57834	6	23044
23109	4	57840	5	15876
23110	2	57847	3	9014
23111	4	57848	4	23025
23112	4	57849	5	5174
23113	5	57850	5	22893
23114	5	57854	2	22456
23115	3	57858	7	8233
23116	4	57860	5	23003
23117	5	57863	4	23084
23118	5	57865	1	7528
23119	5	57870	2	13176
23120	4	57871	7	14027
23121	5	57874	6	23027
23122	5	57876	2	5508
23123	4	57878	5	22943
23124	5	57879	3	11528
23125	5	57880	2	19955
23126	5	57881	6	23000
23127	5	57882	6	22895
23128	5	57882	5	22895
23129	5	57890	6	6243
23130	5	57891	1	22338
23131	1	57892	6	16247
23132	3	57895	5	9597
23133	3	57904	5	14894
23134	5	57909	6	8629
23135	5	57910	5	12604
23136	5	57911	4	8057
23137	5	57914	5	22740
23138	5	57915	6	11849
23139	3	57919	5	23002
23140	5	57920	3	17558
23141	5	57921	4	23028
23142	3	57922	4	22952
23143	5	57923	6	22993
23144	5	57926	3	23005
23145	5	57926	6	23005
23146	5	57928	3	34
23147	4	57929	1	17800
23148	5	57931	2	20803
23149	5	57938	3	23020
23150	5	57938	1	23020
23151	4	57940	7	11744
23152	5	57942	2	22919
23153	5	57946	2	19893
23154	3	57947	7	12097
23155	5	57951	7	23021
23156	5	57952	3	18666
23157	2	57953	4	22980
23158	5	57954	6	2470
23159	4	57956	5	2995
23160	4	57957	7	23052
23161	4	57960	6	23078
23162	4	57960	5	23078
23163	5	57963	6	1736
23164	5	57964	2	20374
23165	5	57965	1	23064
23166	5	57966	2	14754
23167	5	57971	2	22983
23168	5	57974	6	22934
23169	4	57976	2	2922
23170	4	57978	1	17790
23171	5	57981	2	16186
23172	5	57982	5	6150
23173	5	57984	3	21273
23174	5	57991	7	22901
23175	4	57995	7	2908
23176	5	57997	2	6947
23177	4	57998	1	22918
23178	5	57999	6	21502
23179	5	58000	4	2889
23180	1	58008	4	841
23181	4	58009	4	22987
23182	4	58010	7	15903
23183	2	58013	3	23039
23184	4	58016	4	12012
23185	5	58019	6	22933
23186	5	58020	6	22958
23187	5	58021	1	15741
23188	5	58021	5	15741
23189	5	58022	7	22914
23190	4	58023	1	22945
23191	4	58024	7	22953
23192	5	58027	3	8145
23193	5	58030	6	22991
23194	5	58032	7	19162
23195	1	58033	4	13528
23196	5	58034	2	20595
23197	5	58036	6	20843
23198	1	58037	6	20338
23199	4	58041	7	12686
23200	5	58044	2	23019
23201	4	58044	1	23019
23202	5	58045	5	23058
23203	5	58047	6	22976
23204	5	58050	7	3385
23205	4	58056	4	5747
23206	5	58057	4	22311
23207	3	58061	7	15600
23208	5	58064	3	1754
23209	3	58064	1	1754
23210	4	58066	1	21262
23211	3	58067	3	12489
23212	4	58068	7	14151
23213	5	58074	7	9055
23214	5	58075	4	8210
23215	3	58078	5	12650
23216	5	58079	1	456
23217	4	58080	4	22902
23218	4	58082	5	22920
23219	5	58083	6	23082
23220	3	58088	1	1674
23221	3	58090	7	23015
23222	5	58094	6	22937
23223	3	58096	7	22931
23224	1	58099	6	15456
23225	5	58100	2	16916
23226	5	58102	3	13198
23227	3	58103	2	22990
23228	4	58104	5	5883
23229	5	58108	6	23012
23230	5	58110	6	20792
23231	3	58112	7	22996
23232	5	58115	6	2359
23233	5	58116	4	7891
23234	5	58117	6	3082
23235	5	58119	6	17353
23236	4	58120	7	13309
23237	5	58123	1	23070
23238	1	58124	4	23077
23239	4	58126	6	8496
23240	3	58127	1	22915
23241	4	58132	5	22967
23242	4	58132	7	22967
23243	3	58135	5	19252
23244	3	58136	3	21170
23245	5	58139	3	23045
23246	3	58140	5	12384
23247	3	58144	5	14795
23248	4	58150	2	23055
23249	3	58153	2	23053
23250	1	58155	1	906
23251	5	58156	2	23069
23252	3	58161	7	3820
23253	3	58164	3	3119
23254	5	58165	1	2627
23255	5	58166	5	2538
23256	5	58168	6	22986
23257	5	58170	6	22930
23258	5	58171	1	22925
23259	5	58174	4	23034
23260	4	58176	5	22932
23261	5	58178	2	15549
23262	3	58180	1	22845
23263	4	58182	1	15679
23264	5	58186	7	10488
23265	4	58187	1	17020
23266	5	58188	5	6800
23267	4	58191	3	2927
23268	5	58193	2	92
23269	5	58193	7	92
23270	5	58194	7	8628
23271	5	58195	6	18161
23272	4	58195	2	18161
23273	1	58201	6	8234
23274	3	58203	5	7533
23275	5	58207	3	12228
23276	5	58207	4	12228
23277	5	58211	6	10304
23278	5	58214	2	3022
23279	5	58215	6	13561
23280	5	58219	2	4281
23281	5	58224	1	22992
23282	5	58231	4	16346
23283	4	58233	1	9963
23284	4	58235	5	1844
23285	5	58239	2	16335
23286	3	58240	5	22718
23287	5	58241	4	23113
23288	3	58242	6	23096
23289	3	58244	7	23135
23290	3	58247	4	23228
23291	5	58249	5	15557
23292	3	58253	7	6157
23293	5	58256	6	23146
23294	5	58256	4	23146
23295	5	58257	7	23175
23296	5	58260	6	10808
23297	5	58262	2	3378
23298	3	58266	7	13753
23299	5	58268	2	22685
23300	2	58269	3	23116
23301	5	58274	1	23180
23302	5	58275	6	19720
23303	3	58278	2	171
23304	4	58280	7	20868
23305	5	58282	6	22900
23306	4	58283	7	15006
23307	5	58288	6	5875
23308	5	58290	6	6802
23309	4	58291	2	6328
23310	5	58292	7	2562
23311	5	58293	7	15757
23312	4	58294	7	23140
23313	5	58295	1	9466
23314	5	58301	6	19931
23315	5	58302	7	11192
23316	5	58304	5	5931
23317	5	58305	6	18102
23318	5	58306	6	15644
23319	3	58306	3	15644
23320	5	58312	4	10143
23321	5	58318	4	23163
23322	5	58323	1	7179
23323	5	58324	2	10895
23324	5	58330	4	23231
23325	5	58334	4	18445
23326	5	58335	7	23152
23327	4	58335	5	23152
23328	5	58337	2	23236
23329	4	58338	3	7975
23330	4	58340	3	6818
23331	3	58340	4	6818
23332	5	58341	2	23205
23333	3	58344	5	8536
23334	3	58345	7	13922
23335	3	58347	3	17067
23336	5	58349	7	17917
23337	5	58350	2	23232
23338	3	58351	5	17707
23339	4	58355	7	7341
23340	5	58356	1	23105
23341	4	58358	7	23198
23342	3	58360	7	981
23343	3	58362	4	19909
23344	5	58364	2	21076
23345	5	58366	1	5699
23346	5	58367	6	23168
23347	5	58368	7	10770
23348	5	58373	4	6450
23349	5	58381	4	23114
23350	3	58382	7	2922
23351	4	58384	7	23252
23352	5	58387	1	23257
23353	5	58389	6	20487
23354	5	58390	6	23259
23355	4	58392	7	7644
23356	3	58393	7	12954
23357	2	58394	4	17091
23358	5	58395	2	23243
23359	3	58396	5	5932
23360	3	58399	4	16592
23361	4	58400	7	23097
23362	5	58403	7	23234
23363	3	58404	5	17900
23364	5	58405	4	23131
23365	1	58411	6	23124
23366	2	58412	6	16488
23367	5	58417	2	2827
23368	1	58418	4	18512
23369	4	58419	7	14411
23370	5	58420	1	10381
23371	5	58424	2	23187
23372	2	58426	3	16000
23373	5	58427	6	2585
23374	5	58427	2	2585
23375	5	58430	5	23161
23376	5	58434	3	23086
23377	4	58436	1	20512
23378	5	58438	4	23212
23379	4	58439	1	23227
23380	4	58441	3	9214
23381	4	58448	7	23254
23382	3	58449	7	23245
23383	5	58450	7	22311
23384	4	58455	5	23109
23385	5	58456	1	23253
23386	5	58458	6	23242
23387	5	58462	1	18302
23388	5	58463	2	23170
23389	5	58470	6	9081
23390	5	58479	7	23159
23391	3	58484	1	8564
23392	4	58489	3	23145
23393	5	58490	6	23193
23394	5	58492	7	9352
23395	3	58496	5	23111
23396	5	58497	2	623
23397	4	58499	5	6907
23398	5	58501	4	18864
23399	3	58502	5	12642
23400	1	58503	5	23251
23401	5	58504	1	11513
23402	4	58504	5	11513
23403	3	58510	5	20959
23404	5	58510	7	20959
23405	5	58511	2	23183
23406	5	58512	3	998
23407	3	58514	3	11367
23408	3	58515	7	21358
23409	5	58516	2	13930
23410	5	58518	6	23174
23411	5	58519	4	7506
23412	1	58520	7	23130
23413	5	58521	6	13136
23414	5	58523	7	19281
23415	3	58530	1	23238
23416	4	58532	2	23233
23417	5	58533	6	23210
23418	4	58533	7	23210
23419	2	58536	5	23261
23420	5	58538	4	7182
23421	5	58541	6	13288
23422	5	58545	5	18650
23423	3	58549	2	5341
23424	3	58550	2	23169
23425	5	58552	3	13371
23426	3	58553	4	12184
23427	3	58555	5	10238
23428	5	58558	6	13082
23429	4	58560	1	9914
23430	5	58562	3	23338
23431	4	58568	7	23378
23432	5	58570	2	23374
23433	1	58571	6	16436
23434	5	58572	1	23392
23435	4	58573	1	23370
23436	5	58578	2	22873
23437	4	58580	5	10254
23438	5	58583	3	17852
23439	3	58588	5	18195
23440	5	58594	2	2875
23441	5	58598	3	23368
23442	4	58604	1	9142
23443	5	58608	5	23414
23444	5	58608	7	23414
23445	5	58610	6	23267
23446	4	58618	1	13245
23447	4	58620	4	23315
23448	5	58620	6	23315
23449	3	58624	5	23342
23450	5	58625	2	17569
23451	5	58626	6	23380
23452	5	58627	7	23270
23453	3	58629	5	23292
23454	3	58630	5	17511
23455	5	58633	2	13033
23456	4	58636	2	2750
23457	3	58637	7	9258
23458	5	58641	6	4347
23459	5	58642	1	6326
23460	4	58645	7	21373
23461	4	58645	3	21373
23462	5	58650	4	2632
23463	3	58652	6	23279
23464	5	58655	6	2788
23465	4	58656	6	23420
23466	1	58657	4	6195
23467	5	58658	1	1992
23468	5	58659	6	23273
23469	3	58661	5	23361
23470	5	58661	7	23361
23471	5	58665	6	14759
23472	5	58666	4	23430
23473	4	58675	7	14475
23474	3	58681	6	13790
23475	3	58683	3	23337
23476	5	58691	6	23372
23477	5	58693	6	12656
23478	3	58694	5	15727
23479	5	58696	7	21102
23480	5	58700	7	23411
23481	5	58701	1	3616
23482	5	58702	4	1569
23483	5	58704	2	23274
23484	2	58707	1	2526
23485	5	58709	4	23428
23486	5	58709	2	23428
23487	4	58710	5	19746
23488	1	58713	6	23344
23489	5	58716	3	23309
23490	3	58721	3	23419
23491	5	58723	4	23248
23492	5	58725	5	23385
23493	5	58726	5	23422
23494	4	58735	7	1002
23495	3	58737	3	23403
23496	1	58741	4	11139
23497	1	58742	6	12944
23498	3	58747	3	3382
23499	5	58748	5	23296
23500	5	58751	6	12249
23501	4	58758	1	23314
23502	5	58761	5	112
23503	5	58767	6	14202
23504	3	58768	1	12847
23505	3	58769	5	16610
23506	5	58770	4	11893
23507	5	58773	4	23340
23508	5	58775	6	19220
23509	5	58777	2	14204
23510	4	58778	5	19132
23511	4	58779	6	16367
23512	5	58783	1	12416
23513	5	58785	6	21865
23514	3	58786	5	15269
23515	5	58788	7	10957
23516	4	58790	2	17056
23517	4	58793	1	23324
23518	4	58794	5	12634
23519	5	58795	7	23353
23520	3	58797	5	21426
23521	5	58798	4	3820
23522	4	58802	1	19623
23523	5	58803	3	23401
23524	5	58805	3	22208
23525	5	58806	4	10551
23526	5	58808	7	23358
23527	5	58809	5	23371
23528	5	58816	5	11050
23529	5	58817	4	23326
23530	3	58820	1	23360
23531	3	58821	7	6696
23532	3	58822	4	23408
23533	3	58827	2	4321
23534	5	58831	4	10642
23535	5	58835	7	12475
23536	4	58837	4	23307
23537	5	58843	4	23405
23538	4	58846	7	11985
23539	3	58848	3	3324
23540	5	58850	1	23363
23541	5	58851	1	6842
23542	5	58854	7	20407
23543	5	58859	7	11822
23544	3	58865	2	10820
23545	5	58866	1	18201
23546	5	58869	4	15507
23547	4	58874	3	21562
23548	3	58875	5	7772
23549	5	58876	2	23311
23550	4	58877	5	4775
23551	4	58888	7	22511
23552	4	58889	3	23533
23553	4	58890	5	23465
23554	5	58894	1	23036
23555	5	58897	2	23461
23556	5	58901	2	4624
23557	5	58902	7	755
23558	4	58905	7	2429
23559	5	58907	7	23482
23560	5	58909	3	23560
23561	5	58909	7	23560
23562	4	58910	4	3330
23563	4	58917	2	23452
23564	5	58920	2	23438
23565	5	58921	1	484
23566	3	58923	3	12476
23567	5	58926	2	23487
23568	3	58927	7	23573
23569	5	58928	3	23441
23570	5	58928	4	23441
23571	5	58929	5	21183
23572	5	58931	4	23574
23573	3	58933	7	5866
23574	4	58943	1	23578
23575	5	58946	7	23431
23576	5	58949	2	23457
23577	5	58951	1	17038
23578	5	58953	5	13422
23579	1	58960	6	6326
23580	5	58962	6	23446
23581	5	58964	7	17504
23582	5	58965	7	3224
23583	5	58966	1	563
23584	5	58967	2	14672
23585	3	58968	4	16652
23586	4	58969	6	8298
23587	3	58971	7	15502
23588	3	58976	3	16405
23589	5	58980	6	6894
23590	5	58985	4	17600
23591	3	58986	5	1140
23592	4	58987	2	21390
23593	2	58990	5	23481
23594	4	58994	2	23498
23595	3	58995	5	13758
23596	5	58998	2	4303
23597	3	59000	3	1770
23598	5	59001	4	5478
23599	4	59001	2	5478
23600	2	59003	6	23493
23601	3	59003	7	23493
23602	3	59006	5	12132
23603	5	59010	4	5619
23604	5	59012	5	23467
23605	5	59013	6	23557
23606	3	59014	7	1457
23607	5	59016	5	23552
23608	3	59021	3	6664
23609	5	59022	6	8008
23610	5	59026	5	10479
23611	3	59029	5	15776
23612	3	59031	3	16359
23613	2	59035	6	23466
23614	5	59036	2	2498
23615	4	59039	2	2590
23616	5	59040	6	19157
23617	4	59041	3	10474
23618	4	59042	5	2715
23619	5	59043	6	2482
23620	3	59045	5	10757
23621	5	59045	4	10757
23622	5	59046	1	21338
23623	4	59046	6	21338
23624	5	59051	5	6451
23625	5	59052	5	5811
23626	4	59053	6	19313
23627	4	59054	1	21747
23628	5	59055	6	23451
23629	5	59056	3	23470
23630	5	59058	2	23544
23631	5	59060	3	3478
23632	4	59062	2	8421
23633	5	59064	2	23443
23634	5	59067	4	14715
23635	4	59070	3	12418
23636	3	59073	7	23497
23637	3	59084	7	19448
23638	5	59088	6	11667
23639	5	59091	6	9986
23640	4	59093	4	23503
23641	5	59098	2	7593
23642	4	59099	3	3940
23643	5	59102	2	170
23644	4	59105	6	5720
23645	5	59107	7	18468
23646	5	59109	7	14740
23647	5	59113	3	10664
23648	3	59115	2	23525
23649	5	59117	2	11756
23650	4	59121	6	23536
23651	5	59122	4	14559
23652	5	59127	6	23571
23653	4	59128	2	10314
23654	5	59129	2	12078
23655	3	59131	5	14433
23656	5	59132	5	23524
23657	3	59133	4	21675
23658	3	59134	5	23334
23659	5	59140	7	23554
23660	5	59145	6	5184
23661	5	59146	6	12946
23662	5	59149	2	23539
23663	3	59150	2	22429
23664	4	59151	1	23530
23665	5	59152	6	23510
23666	4	59154	2	2470
23667	1	59156	2	23496
23668	3	59165	4	23580
23669	4	59166	4	21631
23670	3	59167	1	13114
23671	5	59168	6	5491
23672	4	59172	7	2849
23673	5	59173	2	15481
23674	2	59174	2	13827
23675	5	59175	6	23501
23676	5	59177	2	5180
23677	4	59177	4	5180
23678	2	59180	3	946
23679	3	59181	4	23464
23680	4	59195	5	15732
23681	5	59196	5	14088
23682	4	59199	1	2770
23683	5	59203	6	4211
23684	5	59205	6	23488
23685	4	59206	4	23549
23686	3	59208	1	14454
23687	4	59208	2	14454
23688	5	59214	7	3689
23689	5	59215	7	18873
23690	4	59218	2	23546
23691	5	59219	1	5050
23692	4	59220	2	15032
23693	5	59221	7	16167
23694	4	59223	5	23520
23695	5	59224	5	23528
23696	3	59230	4	23486
23697	3	59231	5	996
23698	5	59234	3	23547
23699	5	59234	6	23547
23700	4	59235	2	23298
23701	3	59236	7	23538
23702	3	59239	7	18348
23703	3	59240	4	16784
23704	4	59244	7	23543
23705	5	59245	4	883
23706	4	59247	6	10005
23707	4	59251	5	7979
23708	5	59252	4	6689
23709	5	59252	6	6689
23710	5	59260	5	20495
23711	5	59261	5	23506
23712	5	59264	4	7437
23713	4	59265	1	9254
23714	4	59272	2	13435
23715	4	59273	7	5725
23716	4	59279	4	23489
23717	4	59281	7	16747
23718	4	59282	3	23515
23719	5	59287	5	12924
23720	4	59294	4	10951
23721	2	59298	6	23480
23722	4	59299	5	6816
23723	5	59301	2	10245
23724	3	59305	3	482
23725	3	59305	2	482
23726	5	59312	4	18180
23727	5	59313	2	7786
23728	5	59313	3	7786
23729	5	59316	6	10152
23730	5	59318	6	23640
23731	4	59320	1	8290
23732	5	59321	6	4622
23733	5	59327	1	23607
23734	5	59328	2	18201
23735	5	59328	6	18201
23736	4	59329	1	7925
23737	5	59332	3	1681
23738	5	59333	6	3227
23739	5	59334	6	23705
23740	4	59335	6	11046
23741	4	59340	6	18390
23742	5	59347	7	11788
23743	2	59348	6	23662
23744	4	59351	6	17790
23745	1	59351	4	17790
23746	4	59352	5	23590
23747	5	59353	6	15829
23748	5	59354	6	5213
23749	5	59355	4	8116
23750	5	59356	5	23701
23751	4	59357	3	12832
23752	3	59358	7	2569
23753	3	59360	5	547
23754	5	59361	6	23686
23755	5	59363	5	2193
23756	5	59371	7	22787
23757	2	59376	3	23587
23758	3	59381	5	23731
23759	4	59384	7	23638
23760	5	59391	7	22568
23761	5	59392	2	23659
23762	3	59394	5	23649
23763	5	59395	6	14034
23764	5	59399	6	23665
23765	5	59404	5	23613
23766	5	59405	7	11464
23767	3	59407	4	5286
23768	3	59408	3	23687
23769	5	59409	2	10771
23770	4	59410	6	18102
23771	5	59416	7	10389
23772	4	59418	6	15769
23773	5	59421	4	11297
23774	5	59423	6	5632
23775	3	59425	5	23630
23776	3	59426	5	23673
23777	3	59429	7	11531
23778	5	59430	2	15124
23779	5	59431	6	23615
23780	5	59431	1	23615
23781	5	59433	2	12297
23782	4	59436	2	21649
23783	4	59437	2	20209
23784	5	59439	3	6648
23785	5	59440	2	17641
23786	4	59441	7	7123
23787	5	59442	2	23716
23788	4	59444	1	4436
23789	2	59445	1	231
23790	3	59446	1	12912
23791	3	59448	5	1581
23792	4	59449	6	6489
23793	3	59450	5	23599
23794	1	59451	6	6701
23795	4	59452	6	7761
23796	4	59455	5	23689
23797	5	59457	6	23608
23798	5	59460	5	23728
23799	4	59463	2	6296
23800	3	59465	5	23694
23801	3	59467	5	23588
23802	5	59468	7	22550
23803	4	59469	6	2947
23804	5	59470	6	8724
23805	3	59470	7	8724
23806	3	59471	4	15243
23807	5	59474	2	11208
23808	1	59475	4	23668
23809	3	59478	1	18652
23810	5	59483	4	3061
23811	5	59484	7	23697
23812	4	59487	4	2055
23813	4	59490	7	7130
23814	4	59491	7	23606
23815	5	59494	5	8461
23816	5	59495	4	3153
23817	2	59497	3	5570
23818	5	59500	7	10228
23819	5	59501	5	22208
23820	5	59502	6	6335
23821	5	59503	4	21961
23822	5	59504	2	14413
23823	5	59506	4	23648
23824	5	59508	2	23699
23825	4	59509	5	20196
23826	4	59512	7	4368
23827	3	59514	5	19480
23828	3	59515	5	4624
23829	5	59516	1	6257
23830	1	59519	7	7651
23831	5	59520	3	23679
23832	5	59521	4	23691
23833	5	59521	5	23691
23834	5	59522	3	23414
23835	5	59523	1	19250
23836	5	59524	1	2766
23837	5	59528	2	5426
23838	4	59531	1	19177
23839	5	59533	2	20136
23840	5	59534	5	14207
23841	4	59537	3	23722
23842	3	59538	7	7998
23843	5	59539	6	22647
23844	3	59541	6	23603
23845	2	59543	4	661
23846	5	59545	5	12849
23847	5	59546	2	655
23848	5	59547	6	12527
23849	3	59549	7	23719
23850	4	59551	2	16447
23851	5	59552	3	2612
23852	5	59555	2	4580
23853	3	59558	2	23729
23854	4	59562	5	23303
23855	4	59563	7	23591
23856	5	59564	7	23631
23857	4	59564	3	23631
23858	4	59565	7	19783
23859	5	59566	5	3232
23860	5	59567	7	23637
23861	5	59570	2	5790
23862	1	59573	6	23676
23863	3	59574	2	18620
23864	4	59576	5	23626
23865	5	59576	6	23626
23866	5	59577	5	5803
23867	3	59582	7	23641
23868	5	59588	4	7623
23869	3	59589	5	12753
23870	5	59591	5	3534
23871	5	59592	4	17257
23872	5	59594	4	3023
23873	4	59600	2	14161
23874	2	59603	1	13987
23875	4	59604	1	3870
23876	5	59605	6	23720
23877	4	59608	7	17068
23878	4	59614	7	73
23879	3	59617	5	22925
23880	5	59622	4	23684
23881	5	59623	2	23663
23882	5	59624	4	19699
23883	5	59625	2	5280
23884	5	59627	6	23632
23885	3	59628	1	2715
23886	5	59629	1	23623
23887	4	59631	5	11686
23888	5	59635	6	1677
23889	4	59636	1	23709
23890	3	59639	5	23669
23891	4	59643	3	18959
23892	5	59644	6	23618
23893	2	59646	2	23702
23894	5	59649	7	23605
23895	5	59653	1	19248
23896	5	59654	6	8448
23897	5	59658	2	5935
23898	5	59659	6	22116
23899	5	59662	5	2517
23900	4	59668	7	22832
23901	3	59673	1	23633
23902	5	59674	6	23724
23903	5	59676	2	23653
23904	5	59676	7	23653
23905	5	59681	7	3463
23906	5	59682	3	2172
23907	4	59684	5	7399
23908	4	59686	6	2067
23909	5	59688	7	19121
23910	5	59690	1	17286
23911	5	59695	6	21461
23912	4	59701	7	2843
23913	1	59705	6	2280
23914	5	59706	7	23671
23915	4	59707	3	6589
23916	4	59713	7	23682
23917	5	59714	2	3205
23918	4	59719	4	18299
23919	5	59721	2	20239
23920	5	59723	2	20027
23921	3	59723	5	20027
23922	5	59724	3	4395
23923	4	59726	4	14824
23924	5	59727	4	22969
23925	5	59728	2	1138
23926	5	59729	6	6097
23927	4	59730	4	16737
23928	5	59735	2	1104
23929	5	59739	2	9439
23930	5	59741	6	18374
23931	4	59745	3	23883
23932	5	59746	1	23841
23933	3	59748	7	23786
23934	5	59752	6	12975
23935	3	59753	5	16637
23936	4	59757	7	23854
23937	3	59759	3	15191
23938	5	59759	2	15191
23939	5	59764	7	12332
23940	5	59766	2	23750
23941	3	59768	7	18847
23942	3	59773	2	399
23943	1	59778	6	12876
23944	5	59778	5	12876
23945	3	59780	4	23797
23946	5	59784	7	2753
23947	4	59785	7	6919
23948	5	59786	5	23775
23949	3	59786	4	23775
23950	1	59789	3	23897
23951	5	59789	6	23897
23952	1	59790	6	7572
23953	3	59792	4	16091
23954	4	59793	7	23729
23955	4	59798	1	18951
23956	5	59799	7	23882
23957	5	59800	4	23909
23958	5	59801	3	1128
23959	5	59802	3	14882
23960	5	59804	4	8082
23961	5	59807	4	22948
23962	4	59809	5	18347
23963	2	59813	6	4546
23964	4	59815	7	23785
23965	3	59819	7	9610
23966	5	59820	4	23736
23967	5	59822	2	2572
23968	3	59823	7	23862
23969	3	59826	5	8238
23970	5	59828	4	23907
23971	1	59831	6	23759
23972	5	59834	2	23861
23973	5	59835	6	9728
23974	5	59838	5	10354
23975	4	59839	1	23887
23976	5	59845	4	5899
23977	5	59846	2	5668
23978	4	59847	3	4847
23979	4	59851	5	4479
23980	3	59852	5	23762
23981	5	59853	5	9632
23982	4	59857	7	23877
23983	5	59858	4	440
23984	5	59859	4	3399
23985	5	59860	4	19507
23986	5	59861	7	23829
23987	5	59862	7	23891
23988	4	59868	1	2266
23989	5	59869	6	12949
23990	5	59871	6	19172
23991	4	59877	7	15894
23992	5	59878	6	10452
23993	4	59879	5	3063
23994	4	59882	6	19485
23995	1	59884	2	23914
23996	4	59885	2	3996
23997	5	59888	2	22713
23998	5	59889	6	5663
23999	1	59897	6	13713
24000	5	59908	3	23299
24001	3	59910	7	15262
24002	4	59912	7	12132
24003	3	59915	7	23834
24004	4	59918	4	3289
24005	5	59920	1	138
24006	5	59923	3	23906
24007	5	59924	7	10245
24008	5	59925	3	19867
24009	5	59932	6	19100
24010	4	59933	7	13404
24011	4	59934	2	2250
24012	5	59935	2	23904
24013	3	59937	7	10690
24014	5	59942	6	3835
24015	5	59943	6	5109
24016	4	59946	6	23892
24017	5	59953	3	4136
24018	4	59956	5	23905
24019	3	59957	7	23917
24020	5	59958	6	2173
24021	4	59959	7	23878
24022	5	59962	7	17770
24023	5	59963	2	15236
24024	5	59967	2	10862
24025	5	59968	4	22598
24026	5	59969	1	11295
24027	5	59972	2	23742
24028	3	59982	5	23814
24029	3	59983	6	23745
24030	5	59984	1	23828
24031	3	59985	6	23792
24032	3	59986	7	2208
24033	5	59988	6	23795
24034	5	59989	7	11667
24035	5	59990	3	23756
24036	5	59994	4	23804
24037	3	59998	1	19554
24038	3	59999	5	11543
24039	4	60004	5	23761
24040	5	60005	2	11963
24041	5	60008	3	5387
24042	5	60009	6	23739
24043	4	60011	2	12905
24044	4	60012	1	23784
24045	5	60012	6	23784
24046	5	60016	6	8279
24047	4	60022	1	8711
24048	4	60025	6	23798
24049	4	60027	4	2082
24050	3	60028	7	19104
24051	4	60036	2	22647
24052	5	60038	3	17874
24053	4	60038	2	17874
24054	5	60040	7	934
24055	5	60043	4	17784
24056	4	60044	5	23757
24057	5	60045	4	22115
24058	5	60045	2	22115
24059	5	60048	2	19985
24060	3	60049	1	4042
24061	5	60050	3	19957
24062	5	60051	2	11172
24063	3	60052	6	23827
24064	5	60054	5	11150
24065	5	60059	4	18126
24066	4	60059	2	18126
24067	5	60065	6	4640
24068	2	60067	1	8444
24069	4	60070	6	23225
24070	3	60070	5	23225
24071	5	60074	6	23799
24072	5	60078	5	9914
24073	5	60079	6	199
24074	5	60080	7	21904
24075	3	60084	5	23899
24076	4	60085	2	11200
24077	5	60096	6	23819
24078	3	60102	3	3887
24079	4	60104	4	5677
24080	5	60106	6	23451
24081	5	60108	6	23835
24082	5	60108	5	23835
24083	4	60110	1	6458
24084	3	60115	4	6221
24085	4	60117	6	13603
24086	5	60118	5	20671
24087	5	60118	2	20671
24088	5	60119	7	11360
24089	3	60122	7	11232
24090	5	60124	5	8101
24091	4	60125	2	23067
24092	5	60126	2	5778
24093	5	60128	2	15398
24094	5	60130	2	14662
24095	5	60131	4	23969
24096	5	60134	5	20084
24097	5	60135	7	14894
24098	5	60139	6	23943
24099	2	60142	1	24031
24100	5	60142	5	24031
24101	5	60143	5	19708
24102	5	60146	2	10796
24103	1	60147	6	23920
24104	5	60150	6	23984
24105	3	60151	7	14557
24106	5	60156	2	4052
24107	5	60159	6	24081
24108	5	60160	2	24024
24109	5	60163	6	23948
24110	5	60166	6	24080
24111	1	60170	3	3540
24112	5	60173	5	3940
24113	3	60174	6	972
24114	5	60176	7	11709
24115	5	60178	3	6507
24116	5	60180	1	11177
24117	4	60181	4	10051
24118	5	60185	7	24077
24119	1	60186	3	17342
24120	4	60187	7	24074
24121	5	60189	6	24051
24122	5	60190	5	24061
24123	5	60191	1	14116
24124	5	60193	6	23925
24125	5	60194	2	14550
24126	5	60196	2	1832
24127	4	60202	3	23933
24128	5	60202	2	23933
24129	5	60210	2	20492
24130	4	60212	4	13674
24131	5	60214	5	23945
24132	4	60215	6	6168
24133	4	60215	5	6168
24134	4	60217	4	23964
24135	5	60217	1	23964
24136	4	60218	2	24001
24137	5	60219	1	17098
24138	5	60221	6	20803
24139	5	60224	1	24006
24140	5	60224	6	24006
24141	5	60228	7	13635
24142	5	60228	1	13635
24143	4	60230	3	23997
24144	5	60232	6	24039
24145	5	60233	6	5428
24146	5	60235	1	1461
24147	5	60241	4	1358
24148	3	60241	1	1358
24149	5	60243	7	23975
24150	4	60244	7	24012
24151	3	60246	4	23946
24152	3	60246	5	23946
24153	3	60247	3	5109
24154	5	60249	6	7766
24155	4	60251	2	23285
24156	5	60252	2	19032
24157	5	60254	5	24007
24158	4	60258	6	18646
24159	4	60264	4	13733
24160	5	60265	2	10159
24161	2	60267	6	7278
24162	5	60268	2	24036
24163	4	60271	6	21426
24164	4	60273	7	24035
24165	3	60273	2	24035
24166	5	60276	6	3164
24167	4	60280	1	21084
24168	1	60282	6	20903
24169	4	60291	4	7144
24170	2	60292	3	1035
24171	5	60294	7	24021
24172	4	60297	4	4841
24173	5	60300	2	23932
24174	5	60301	2	3328
24175	5	60304	3	22876
24176	5	60306	7	23996
24177	4	60307	7	11992
24178	4	60308	6	12032
24179	5	60310	6	1106
24180	3	60311	5	23988
24181	5	60316	5	21599
24182	2	60321	6	24066
24183	3	60325	5	500
24184	5	60329	3	21229
24185	4	60330	3	3119
24186	5	60331	7	10688
24187	5	60332	5	10495
24188	5	60336	6	23940
24189	4	60337	7	8801
24190	5	60341	2	23704
24191	5	60344	6	4409
24192	4	60344	7	4409
24193	4	60345	4	23918
24194	4	60347	4	5759
24195	5	60349	2	4166
24196	5	60350	3	23961
24197	5	60350	7	23961
24198	5	60352	7	23982
24199	5	60354	4	10316
24200	5	60356	1	24017
24201	5	60357	2	24079
24202	5	60359	2	6465
24203	5	60365	7	12136
24204	5	60367	2	24005
24205	5	60371	5	24055
24206	5	60372	1	24038
24207	5	60374	2	23801
24208	4	60375	5	17918
24209	5	60377	3	12274
24210	5	60379	4	23999
24211	2	60383	6	6530
24212	5	60385	5	16815
24213	5	60387	5	24032
24214	5	60387	6	24032
24215	5	60388	3	9646
24216	5	60388	5	9646
24217	5	60398	6	9418
24218	4	60399	4	24065
24219	5	60403	2	4484
24220	5	60404	3	9068
24221	5	60405	5	7782
24222	5	60406	5	6853
24223	4	60408	3	24088
24224	4	60409	5	24075
24225	5	60410	4	23831
24226	3	60411	5	6950
24227	4	60414	4	24086
24228	4	60416	1	8452
24229	3	60419	5	19750
24230	3	60421	6	263
24231	5	60424	6	23993
24232	3	60429	4	10601
24233	5	60431	7	24027
24234	5	60435	5	10993
24235	5	60437	2	21802
24236	5	60440	6	14580
24237	1	60442	6	24003
24238	4	60445	5	24059
24239	5	60445	4	24059
24240	4	60449	2	22865
24241	5	60452	1	23955
24242	5	60454	1	23947
24243	3	60456	5	11311
24244	5	60458	7	24069
24245	5	60459	4	2373
24246	3	60461	5	11754
24247	5	60462	2	6786
24248	3	60463	3	12387
24249	4	60467	7	7901
24250	4	60468	2	3040
24251	3	60468	5	3040
24252	5	60470	1	11330
24253	5	60471	6	24040
24254	4	60472	4	24089
24255	3	60474	5	7375
24256	4	60475	4	11277
24257	5	60480	2	24029
24258	5	60483	2	975
24259	5	60484	6	7772
24260	5	60488	2	22945
24261	4	60489	2	4288
24262	4	60491	1	12484
24263	3	60494	5	21553
24264	5	60495	7	8103
24265	4	60498	4	23749
24266	4	60499	5	20427
24267	1	60501	4	23919
24268	5	60505	5	13049
24269	5	60507	2	4779
24270	1	60511	6	24058
24271	3	60512	6	24020
24272	3	60514	5	4278
24273	3	60515	5	24044
24274	5	60519	6	23980
24275	4	60523	4	2492
24276	5	60524	6	11983
24277	5	60532	2	3186
24278	3	60533	1	24072
24279	5	60543	7	19480
24280	5	60545	5	24047
24281	5	60546	3	23941
24282	5	60547	4	11760
24283	5	60547	3	11760
24284	3	60552	2	953
24285	5	60561	1	20485
24286	4	60565	5	24063
24287	3	60566	7	23942
24288	4	60567	1	18343
24289	3	60571	2	23953
24290	5	60571	4	23953
24291	5	60577	1	23974
24292	5	60577	3	23974
24293	2	60578	6	24042
24294	5	60580	6	6720
24295	4	60582	1	401
24296	3	60584	7	5303
24297	5	60587	1	15880
24298	3	60591	3	24046
24299	5	60594	4	24002
24300	3	60595	6	12349
24301	5	60598	3	20109
24302	5	60600	3	14529
24303	5	60601	2	10971
24304	3	60605	3	18618
24305	5	60611	4	23985
24306	5	60612	2	9126
24307	5	60613	3	15022
24308	5	60614	1	9607
24309	5	60631	2	14631
24310	5	60632	2	11336
24311	4	60634	4	24057
24312	5	60638	6	23114
24313	5	60643	1	20983
24314	4	60648	7	23921
24315	4	60650	1	16818
24316	3	60656	1	10330
24317	5	60658	3	24224
24318	4	60659	5	18885
24319	4	60661	4	2832
24320	4	60665	5	2190
24321	5	60666	5	6282
24322	5	60669	7	3436
24323	4	60671	7	24283
24324	5	60680	4	16114
24325	4	60684	7	18575
24326	4	60691	5	22259
24327	5	60693	6	10106
24328	3	60695	4	23853
24329	5	60698	5	7041
24330	4	60699	7	24157
24331	4	60700	7	24190
24332	4	60700	6	24190
24333	5	60702	5	24158
24334	4	60703	6	24243
24335	5	60703	2	24243
24336	3	60704	4	24110
24337	5	60705	5	6456
24338	4	60706	6	8512
24339	5	60707	2	1670
24340	4	60708	7	6836
24341	3	60710	2	10862
24342	5	60711	1	18398
24343	3	60712	5	24205
24344	5	60715	6	11756
24345	1	60716	4	24137
24346	5	60720	4	19876
24347	4	60721	3	24254
24348	4	60726	6	24150
24349	3	60728	1	24059
24350	5	60731	4	24246
24351	1	60733	4	24104
24352	5	60734	7	9419
24353	4	60736	1	24217
24354	2	60741	7	6385
24355	5	60741	6	6385
24356	5	60744	6	24249
24357	5	60745	2	6609
24358	5	60746	6	18921
24359	5	60747	2	24280
24360	3	60748	4	20970
24361	5	60750	2	3366
24362	5	60753	3	4825
24363	5	60755	7	24230
24364	4	60757	6	5879
24365	5	60760	6	6623
24366	5	60762	4	16433
24367	5	60762	7	16433
24368	4	60763	5	7888
24369	4	60767	5	24170
24370	2	60774	5	23949
24371	3	60775	4	3002
24372	5	60779	7	12879
24373	4	60780	7	19507
24374	4	60782	7	24095
24375	4	60785	3	7431
24376	5	60786	3	24123
24377	3	60789	4	22061
24378	5	60791	1	24176
24379	5	60793	4	9816
24380	5	60794	1	6586
24381	5	60795	1	11509
24382	5	60797	4	20136
24383	3	60801	1	7094
24384	3	60802	5	2032
24385	5	60804	7	13854
24386	3	60809	4	14479
24387	2	60811	6	24255
24388	5	60812	1	20161
24389	5	60815	5	24101
24390	5	60817	6	1432
24391	5	60818	4	24204
24392	5	60821	3	24155
24393	4	60822	6	18471
24394	5	60824	6	881
24395	4	60828	3	14652
24396	5	60830	3	3073
24397	4	60834	2	13950
24398	5	60835	5	21860
24399	3	60835	2	21860
24400	3	60836	7	1321
24401	5	60837	2	6091
24402	4	60838	3	6591
24403	4	60844	5	24128
24404	5	60845	6	8493
24405	4	60846	5	17451
24406	4	60846	1	17451
24407	4	60847	5	23420
24408	5	60847	4	23420
24409	3	60848	6	24253
24410	5	60854	2	24098
24411	5	60855	2	16710
24412	5	60861	2	22606
24413	4	60864	6	24213
24414	5	60866	1	15726
24415	4	60869	6	21690
24416	3	60871	4	5144
24417	5	60875	2	3871
24418	5	60876	7	15373
24419	4	60877	3	11156
24420	5	60884	7	24219
24421	1	60886	7	14825
24422	4	60890	5	1905
24423	5	60892	6	7759
24424	5	60894	2	20407
24425	5	60896	1	15495
24426	5	60899	4	4325
24427	5	60902	1	24180
24428	5	60907	7	18475
24429	4	60908	5	4592
24430	4	60909	7	15048
24431	3	60910	4	274
24432	3	60914	2	24102
24433	3	60916	4	5730
24434	5	60918	7	21562
24435	4	60919	7	24121
24436	3	60924	1	9031
24437	1	60926	6	24184
24438	4	60934	3	18634
24439	5	60939	4	7122
24440	5	60940	4	24216
24441	3	60942	5	22292
24442	5	60944	5	24258
24443	4	60949	4	24208
24444	5	60950	2	2498
24445	3	60952	2	12480
24446	3	60956	7	17723
24447	3	60957	7	24212
24448	5	60957	4	24212
24449	3	60959	1	24282
24450	4	60962	4	24177
24451	5	60964	4	24232
24452	5	60964	3	24232
24453	3	60966	1	4801
24454	1	60967	6	6966
24455	5	60969	7	24203
24456	5	60971	4	24229
24457	5	60972	6	8027
24458	4	60974	7	24242
24459	2	60981	1	24140
24460	5	60981	6	24140
24461	5	60982	2	17994
24462	5	60983	7	20907
24463	5	60984	7	24279
24464	4	60984	5	24279
24465	5	60985	6	22056
24466	5	60987	6	8205
24467	5	60989	4	24260
24468	5	60991	2	3455
24469	3	60995	7	24160
24470	5	60996	3	9956
24471	4	60999	5	24182
24472	3	61001	6	24165
24473	4	61003	5	18287
24474	5	61004	2	1911
24475	5	61009	7	20480
24476	5	61011	7	21835
24477	5	61012	6	12930
24478	4	61013	7	24275
24479	3	61015	2	8550
24480	5	61016	4	8034
24481	5	61018	2	24145
24482	5	61019	2	24169
24483	4	61021	2	2806
24484	5	61021	6	2806
24485	4	61023	2	10359
24486	4	61027	7	23115
24487	5	61028	6	22839
24488	3	61029	2	19019
24489	4	61034	3	887
24490	4	61035	2	20993
24491	5	61037	6	24238
24492	3	61039	5	24135
24493	5	61047	1	24122
24494	5	61049	3	12185
24495	5	61050	7	3664
24496	5	61051	2	17094
24497	5	61057	1	24116
24498	5	61057	7	24116
24499	4	61060	7	3190
24500	5	61064	5	19230
24501	1	61064	3	19230
24502	5	61068	1	12314
24503	5	61069	2	2956
24504	4	61072	4	20780
24505	3	61074	7	18987
24506	1	61075	6	16774
24507	5	61075	3	16774
24508	3	61077	2	19657
24509	4	61077	7	19657
24510	1	61079	6	24215
24511	5	61082	1	19601
24512	4	61084	4	2630
24513	5	61085	7	18125
24514	3	61089	1	21038
24515	4	61090	5	17953
24516	4	61092	3	24237
24517	5	61093	5	5668
24518	5	61097	2	1593
24519	4	61097	5	1593
24520	4	61098	7	4447
24521	3	61101	6	14273
24522	5	61102	7	24018
24523	5	61103	7	17123
24524	1	61104	6	24189
24525	3	61107	2	1457
24526	5	61109	6	3668
24527	5	61115	7	4947
24528	5	61116	6	18879
24529	3	61116	5	18879
24530	3	61117	7	4290
24531	4	61119	7	13825
24532	3	61121	4	20806
24533	3	61125	5	24221
24534	5	61128	3	24117
24535	5	61133	3	2959
24536	3	61134	6	24171
24537	4	61135	7	5792
24538	4	61136	6	791
24539	1	61139	6	18870
24540	3	61142	7	20138
24541	4	61146	3	22232
24542	5	61150	7	11039
24543	4	61151	7	20842
24544	4	61155	3	24114
24545	5	61157	5	2714
24546	5	61168	5	14476
24547	3	61169	2	22099
24548	5	61170	2	18367
24549	4	61173	5	24240
24550	4	61175	6	21170
24551	5	61179	1	24202
24552	5	61180	5	24113
24553	5	61181	6	24132
24554	4	61186	3	6235
24555	3	61187	5	24136
24556	2	61191	3	24173
24557	3	61192	7	482
24558	2	61194	3	13945
24559	5	61202	2	12648
24560	5	61204	6	24127
24561	3	61209	1	17569
24562	4	61209	7	17569
24563	5	61210	6	7371
24564	5	61212	2	10273
24565	3	61213	2	24162
24566	5	61214	2	3404
24567	1	61215	6	18854
24568	4	61216	6	10159
24569	5	61218	5	4565
24570	4	61226	1	9282
24571	5	61227	7	24118
24572	4	61230	6	3274
24573	5	61236	2	24109
24574	5	61237	3	17596
24575	4	61241	4	292
24576	4	61242	3	17566
24577	5	61246	2	13960
24578	3	61250	5	24268
24579	5	61251	5	18949
24580	4	61252	4	2048
24581	5	61253	2	24119
24582	3	61256	7	6890
24583	5	61257	4	24200
24584	5	61258	5	10987
24585	5	61262	3	9893
24586	5	61262	6	9893
24587	5	61264	2	1896
24588	4	61270	4	21371
24589	5	61275	5	24225
24590	5	61277	7	24107
24591	5	61278	5	9402
24592	5	61281	2	24125
24593	5	61285	4	24141
24594	4	61290	5	1700
24595	4	61292	7	24153
24596	5	61295	4	11490
24597	3	61302	5	7443
24598	5	61303	6	21492
24599	5	61304	1	18666
24600	3	61306	7	11347
24601	5	61307	7	8588
24602	4	61308	1	21026
24603	5	61309	2	22767
24604	5	61314	6	17981
24605	5	61315	7	1267
24606	2	61316	3	22302
24607	5	61319	4	12699
24608	5	61322	2	3073
24609	5	61324	3	20329
24610	5	61325	5	22988
24611	5	61328	6	11331
24612	5	61329	3	15590
24613	3	61333	3	19838
24614	4	61336	4	13527
24615	4	61337	1	24333
24616	5	61339	7	8056
24617	5	61341	2	20493
24618	5	61346	5	13105
24619	5	61346	1	13105
24620	4	61347	2	9702
24621	3	61348	7	21499
24622	5	61349	4	24366
24623	3	61352	7	16091
24624	4	61359	2	24349
24625	5	61360	2	4412
24626	5	61364	2	24315
24627	4	61367	2	16055
24628	5	61369	1	22663
24629	3	61371	5	20336
24630	5	61373	7	24321
24631	3	61374	6	10576
24632	5	61375	5	11834
24633	5	61376	7	24371
24634	2	61378	6	24398
24635	3	61379	4	14358
24636	5	61380	6	24339
24637	1	61385	6	24410
24638	5	61387	6	16754
24639	5	61389	7	23307
24640	5	61389	2	23307
24641	5	61390	6	24382
24642	5	61391	3	7098
24643	5	61393	7	24414
24644	4	61396	4	18593
24645	2	61400	4	24386
24646	5	61403	4	19792
24647	5	61405	6	1140
24648	5	61408	4	23961
24649	3	61410	1	21829
24650	4	61415	2	7897
24651	3	61415	6	7897
24652	5	61416	2	24274
24653	2	61417	1	2066
24654	4	61419	6	18929
24655	4	61421	1	24399
24656	5	61421	3	24399
24657	5	61423	3	24365
24658	4	61425	3	12337
24659	3	61430	5	16525
24660	3	61436	5	24308
24661	5	61437	6	7827
24662	5	61437	2	7827
24663	5	61438	7	22679
24664	5	61439	7	24285
24665	5	61440	4	24391
24666	3	61445	7	5124
24667	4	61449	6	4766
24668	5	61449	7	4766
24669	4	61450	7	24338
24670	5	61452	3	17116
24671	4	61453	7	22414
24672	4	61462	7	18425
24673	4	61463	6	24310
24674	4	61464	6	24293
24675	5	61465	6	24294
24676	5	61466	2	17703
24677	5	61468	4	22966
24678	3	61469	7	24075
24679	4	61471	2	24373
24680	5	61472	4	1988
24681	4	61473	2	4346
24682	3	61474	5	7924
24683	5	61475	6	376
24684	3	61476	4	288
24685	3	61479	2	13501
24686	4	61483	7	24357
24687	5	61483	1	24357
24688	5	61484	6	14010
24689	4	61487	7	24332
24690	5	61492	3	24411
24691	5	61492	4	24411
24692	4	61495	2	9995
24693	3	61496	5	24375
24694	5	61497	1	17227
24695	4	61501	5	4684
24696	5	61503	1	7677
24697	4	61505	2	8877
24698	4	61506	3	5933
24699	4	61508	7	24397
24700	4	61511	7	8180
24701	4	61513	6	19750
24702	4	61515	5	16470
24703	5	61516	7	14207
24704	4	61520	1	337
24705	5	61522	1	4582
24706	5	61524	2	10518
24707	5	61525	3	11183
24708	5	61529	6	21542
24709	3	61530	7	232
24710	5	61531	6	24355
24711	5	61532	5	5004
24712	4	61534	5	460
24713	4	61534	7	460
24714	5	61535	2	24329
24715	5	61537	6	5800
24716	5	61542	2	18173
24717	4	61543	4	13806
24718	5	61544	4	24396
24719	5	61545	6	11979
24720	5	61548	3	18304
24721	5	61549	2	6255
24722	4	61551	7	24255
24723	5	61552	6	24298
24724	5	61555	6	11952
24725	4	61556	1	20315
24726	5	61559	5	18831
24727	5	61560	4	24286
24728	4	61562	5	8216
24729	5	61563	2	24311
24730	4	61566	7	24314
24731	3	61570	2	11666
24732	5	61571	4	13876
24733	5	61571	2	13876
24734	4	61574	7	511
24735	2	61577	4	24309
24736	5	61582	6	9633
24737	5	61583	1	7675
24738	4	61586	7	10671
24739	5	61588	6	24381
24740	5	61590	5	24353
24741	5	61598	6	13904
24742	3	61598	2	13904
24743	3	61600	1	24416
24744	4	61602	7	24306
24745	3	61603	7	2662
24746	5	61604	2	19686
24747	5	61605	5	24376
24748	4	61606	7	24363
24749	4	61609	3	1118
24750	4	61609	1	1118
24751	5	61611	4	24362
24752	5	61614	7	7907
24753	5	61615	6	19416
24754	5	61616	6	13803
24755	5	61617	1	24337
24756	3	61619	7	15407
24757	5	61621	2	24439
24758	5	61624	7	3610
24759	3	61624	4	3610
24760	3	61628	7	24449
24761	5	61629	6	18845
24762	5	61632	6	4632
24763	1	61633	6	22080
24764	5	61634	7	10433
24765	3	61635	7	24578
24766	4	61637	3	24588
24767	1	61642	6	24484
24768	2	61646	2	24537
24769	5	61648	6	22016
24770	5	61649	4	24553
24771	5	61654	6	10515
24772	5	61657	7	24538
24773	5	61660	1	7444
24774	1	61662	7	24536
24775	5	61663	6	18997
24776	5	61665	4	8823
24777	4	61666	7	16114
24778	4	61667	1	24521
24779	5	61669	6	18778
24780	4	61671	3	24471
24781	5	61673	5	5071
24782	3	61676	7	23855
24783	5	61677	6	23699
24784	4	61680	7	24468
24785	2	61684	6	24488
24786	4	61685	6	8434
24787	3	61685	3	8434
24788	4	61686	5	11368
24789	5	61687	1	19279
24790	5	61691	6	24559
24791	5	61692	3	24513
24792	5	61694	4	24510
24793	3	61696	3	24486
24794	4	61698	7	19259
24795	2	61699	6	19393
24796	5	61700	2	24482
24797	4	61703	7	7341
24798	5	61706	2	24431
24799	3	61710	7	5783
24800	5	61714	2	13651
24801	4	61717	4	2731
24802	5	61718	4	7140
24803	4	61720	5	24583
24804	2	61722	4	24528
24805	4	61723	5	24592
24806	2	61723	6	24592
24807	5	61726	6	12418
24808	4	61735	6	21214
24809	5	61738	6	14780
24810	5	61740	6	5668
24811	5	61741	6	14539
24812	5	61743	5	3545
24813	5	61748	6	10051
24814	4	61750	1	24507
24815	4	61750	7	24507
24816	2	61751	1	6351
24817	5	61754	6	10203
24818	3	61755	4	24535
24819	5	61758	5	1131
24820	4	61759	1	2272
24821	5	61760	4	17363
24822	4	61760	6	17363
24823	4	61761	1	24590
24824	5	61762	6	6959
24825	4	61764	7	10575
24826	5	61765	4	24573
24827	5	61766	5	24541
24828	5	61771	7	8770
24829	5	61773	3	16295
24830	5	61774	1	11764
24831	5	61775	4	16549
24832	5	61778	4	11794
24833	4	61779	3	24575
24834	4	61780	7	24560
24835	3	61782	7	15127
24836	4	61787	2	18539
24837	5	61789	6	24504
24838	3	61791	5	12934
24839	2	61797	3	18222
24840	4	61800	5	6286
24841	3	61809	5	32
24842	5	61813	1	24565
24843	4	61814	5	10463
24844	4	61815	7	20711
24845	3	61817	5	22942
24846	5	61819	6	17769
24847	3	61822	7	7955
24848	5	61822	2	7955
24849	1	61825	4	24474
24850	5	61827	6	24494
24851	5	61828	6	24563
24852	5	61830	7	24442
24853	5	61833	2	18958
24854	4	61834	5	24505
24855	5	61837	4	24441
24856	3	61839	1	15498
24857	5	61841	4	6046
24858	4	61842	5	14190
24859	2	61845	1	6927
24860	3	61846	2	5979
24861	5	61848	2	5098
24862	5	61851	6	3447
24863	3	61857	5	9796
24864	5	61858	2	24480
24865	5	61859	6	7396
24866	5	61861	5	8990
24867	3	61864	7	1914
24868	3	61866	1	24454
24869	5	61868	3	24503
24870	4	61869	2	10392
24871	5	61870	5	1361
24872	3	61871	5	5201
24873	1	61872	4	24544
24874	3	61876	2	22077
24875	3	61877	7	24463
24876	5	61881	2	14127
24877	5	61883	1	24450
24878	5	61886	7	24572
24879	5	61886	2	24572
24880	5	61887	6	24485
24881	5	61888	2	11026
24882	5	61889	1	22308
24883	5	61890	7	24473
24884	3	61894	2	10763
24885	5	61897	3	3048
24886	5	61898	6	19488
24887	5	61900	6	8540
24888	4	61902	3	8748
24889	5	61903	4	15044
24890	4	61904	3	24489
24891	5	61906	2	12022
24892	1	61908	7	3430
24893	5	61910	4	932
24894	5	61912	2	13324
24895	5	61914	1	2123
24896	5	61918	6	24469
24897	5	61924	1	14010
24898	4	61925	4	14932
24899	5	61929	6	1485
24900	3	61930	7	1255
24901	4	61932	7	22656
24902	5	61933	6	12019
24903	4	61934	2	24547
24904	4	61936	2	24585
24905	5	61937	5	22398
24906	5	61938	3	24554
24907	5	61940	4	24005
24908	4	61941	3	3920
24909	5	61942	7	24584
24910	5	61946	6	950
24911	3	61947	7	12557
24912	4	61955	2	24436
24913	5	61961	4	8591
24914	3	61962	7	20054
24915	5	61964	4	24551
24916	5	61965	7	13265
24917	1	61969	6	24508
24918	5	61973	6	2107
24919	4	61977	7	4100
24920	5	61977	6	4100
24921	5	61979	6	17014
24922	5	61980	6	14793
24923	3	61982	5	11683
24924	4	61984	2	24618
24925	2	61984	6	24618
24926	5	61985	4	20138
24927	5	61986	5	23500
24928	5	61988	2	12160
24929	4	61989	7	24672
24930	5	61993	2	18641
24931	5	61994	3	24650
24932	4	61999	5	24678
24933	4	62001	5	396
24934	5	62007	2	7465
24935	5	62010	1	24668
24936	3	62011	6	21532
24937	5	62014	6	24710
24938	1	62015	4	24689
24939	3	62017	5	20494
24940	5	62019	4	1258
24941	5	62023	6	4576
24942	4	62025	5	12335
24943	3	62026	7	9949
24944	4	62027	4	4782
24945	4	62030	6	24717
24946	5	62032	3	24632
24947	5	62037	3	6533
24948	5	62040	6	16089
24949	5	62047	4	24670
24950	1	62048	6	11634
24951	2	62049	6	24707
24952	5	62050	5	22994
24953	5	62052	1	18335
24954	5	62052	4	18335
24955	5	62056	5	22523
24956	5	62057	3	10954
24957	5	62063	5	17750
24958	4	62065	2	24715
24959	5	62071	7	3227
24960	4	62073	2	7433
24961	5	62080	4	4486
24962	4	62083	5	24675
24963	5	62089	1	1024
24964	5	62092	6	11147
24965	5	62094	3	16514
24966	5	62095	1	6150
24967	5	62096	4	18286
24968	5	62097	1	1759
24969	5	62099	1	21495
24970	5	62100	1	15849
24971	5	62103	6	8424
24972	5	62104	5	2850
24973	5	62105	2	11279
24974	4	62107	7	6791
24975	4	62108	4	14035
24976	3	62113	6	24649
24977	5	62114	2	24680
24978	2	62115	1	8372
24979	5	62119	6	12578
24980	4	62121	3	24485
24981	3	62122	7	17434
24982	5	62122	2	17434
24983	5	62125	3	22975
24984	3	62127	5	12290
24985	4	62128	6	24636
24986	5	62130	2	14068
24987	5	62132	1	4804
24988	5	62134	4	10353
24989	5	62134	5	10353
24990	5	62135	4	7638
24991	4	62136	7	24607
24992	5	62137	2	1280
24993	5	62138	4	16613
24994	5	62140	4	24665
24995	5	62142	2	5670
24996	5	62150	2	17713
24997	4	62155	3	9413
24998	3	62157	3	8839
24999	4	62160	1	11038
25000	3	62161	2	3382
25001	4	62162	2	20060
25002	5	62165	2	24623
25003	5	62171	2	24698
25004	5	62173	1	24711
25005	5	62176	5	8780
25006	4	62177	1	24643
25007	5	62188	6	3656
25008	5	62190	5	2631
25009	5	62195	1	4498
25010	4	62196	4	24663
25011	4	62201	7	7076
25012	5	62203	5	13954
25013	4	62207	1	17421
25014	5	62210	2	24708
25015	4	62213	6	3410
25016	3	62215	4	11840
25017	5	62218	5	24687
25018	3	62218	7	24687
25019	5	62219	7	1839
25020	4	62220	3	10670
25021	5	62221	2	4673
25022	4	62224	3	13705
25023	3	62225	3	22070
25024	2	62226	3	3616
25025	5	62228	6	24679
25026	5	62230	6	15397
25027	5	62234	4	1663
25028	5	62235	4	24705
25029	5	62240	1	3470
25030	4	62247	7	15592
25031	5	62248	2	22208
25032	5	62249	7	23650
25033	5	62250	5	23633
25034	5	62254	2	24655
25035	5	62257	6	581
25036	5	62258	7	24651
25037	3	62260	3	19755
25038	5	62262	5	8199
25039	5	62264	6	8225
25040	5	62268	2	20381
25041	3	62271	2	24646
25042	3	62273	5	24719
25043	3	62274	2	17170
25044	5	62275	4	10340
25045	4	62276	3	24653
25046	5	62276	6	24653
25047	4	62278	7	24624
25048	5	62280	6	17956
25049	5	62285	2	7126
25050	3	62294	2	12541
25051	5	62295	7	24630
25052	1	62297	6	15979
25053	5	62300	3	2425
25054	5	62302	1	9570
25055	4	62304	3	7197
25056	2	62308	2	24674
25057	4	62308	7	24674
25058	4	62316	5	23123
25059	5	62317	1	11998
25060	5	62318	1	24158
25061	5	62319	6	24629
25062	3	62321	5	4621
25063	4	62324	6	2366
25064	5	62327	3	24550
25065	3	62331	1	24600
25066	5	62332	2	1147
25067	5	62333	7	5133
25068	5	62333	1	5133
25069	4	62335	5	6801
25070	5	62337	5	24633
25071	2	62341	6	5526
25072	5	62344	1	24171
25073	5	62347	6	22564
25074	5	62348	4	15948
25075	5	62351	1	20310
25076	5	62352	2	14066
25077	4	62354	2	15515
25078	5	62356	7	2055
25079	5	62360	2	24659
25080	5	62361	2	9566
25081	5	62362	3	6284
25082	5	62363	2	24647
25083	5	62372	2	24712
25084	5	62375	3	18613
25085	4	62376	5	24723
25086	5	62377	5	24631
25087	2	62378	6	1517
25088	4	62380	3	7571
25089	5	62384	5	24691
25090	5	62386	4	1145
25091	5	62387	2	12022
25092	4	62390	1	4738
25093	5	62391	6	14124
25094	4	62395	6	20729
25095	4	62396	1	24734
25096	4	62397	2	24807
25097	5	62398	7	2078
25098	5	62399	2	2959
25099	5	62407	6	5397
25100	1	62412	6	23264
25101	4	62413	1	20987
25102	4	62415	7	424
25103	5	62416	2	17805
25104	4	62418	7	17743
25105	4	62420	7	24809
25106	5	62420	4	24809
25107	5	62422	2	312
25108	4	62423	7	6187
25109	3	62424	5	9208
25110	5	62425	5	24835
25111	4	62426	7	24737
25112	5	62426	1	24737
25113	5	62427	1	12189
25114	5	62428	5	24812
25115	5	62429	2	15799
25116	4	62429	1	15799
25117	3	62430	6	24878
25118	5	62431	6	24577
25119	4	62432	5	772
25120	2	62434	5	24834
25121	5	62435	7	21427
25122	5	62438	6	2649
25123	5	62439	4	24858
25124	3	62448	1	21575
25125	5	62451	6	9470
25126	5	62454	6	24769
25127	5	62455	7	24819
25128	4	62462	2	3820
25129	5	62463	2	18566
25130	5	62465	5	24777
25131	5	62466	4	24869
25132	4	62469	3	23951
25133	1	62472	4	17392
25134	5	62475	6	20573
25135	4	62476	4	8447
25136	5	62477	6	5739
25137	4	62481	4	1820
25138	5	62484	5	9752
25139	4	62485	6	24806
25140	4	62489	5	14090
25141	5	62490	4	11967
25142	4	62496	1	24817
25143	5	62499	5	24862
25144	4	62502	5	24745
25145	4	62503	3	23226
25146	3	62505	3	6232
25147	5	62511	1	5916
25148	4	62513	5	24820
25149	5	62515	2	19891
25150	5	62520	7	22209
25151	4	62525	2	24889
25152	3	62528	7	1541
25153	3	62529	5	17303
25154	5	62533	3	20787
25155	5	62534	7	11145
25156	3	62535	4	2916
25157	5	62536	6	11216
25158	5	62537	5	16208
25159	3	62539	5	14944
25160	5	62551	5	23556
25161	5	62554	6	24754
25162	5	62558	2	24832
25163	4	62560	1	5987
25164	4	62565	6	24882
25165	5	62566	2	9087
25166	5	62567	5	7505
25167	5	62568	6	24843
25168	5	62568	1	24843
25169	5	62570	1	6836
25170	3	62573	7	24795
25171	5	62574	6	22920
25172	4	62578	6	24787
25173	5	62578	4	24787
25174	3	62579	3	24729
25175	3	62586	6	24730
25176	4	62587	6	24755
25177	4	62589	4	12827
25178	5	62597	4	5712
25179	5	62600	1	23306
25180	5	62604	3	24900
25181	4	62609	6	24605
25182	4	62610	2	24887
25183	4	62612	7	24888
25184	5	62615	6	236
25185	4	62616	5	24758
25186	4	62622	5	739
25187	5	62624	6	3730
25188	3	62626	5	24773
25189	5	62627	6	24579
25190	5	62631	4	10785
25191	4	62636	7	16185
25192	5	62639	6	14028
25193	5	62640	6	22346
25194	5	62642	5	24870
25195	5	62643	4	24534
25196	5	62644	6	3663
25197	5	62647	4	9106
25198	3	62648	3	13004
25199	5	62650	6	24800
25200	5	62651	6	17909
25201	3	62651	7	17909
25202	5	62652	1	24688
25203	4	62653	1	19737
25204	5	62654	2	16772
25205	5	62658	3	24785
25206	5	62659	7	24902
25207	5	62660	3	3570
25208	5	62660	4	3570
25209	1	62662	6	24731
25210	5	62663	3	10151
25211	4	62663	1	10151
25212	4	62665	6	11488
25213	4	62666	7	17415
25214	5	62668	1	24749
25215	5	62672	4	15662
25216	5	62673	4	24778
25217	4	62677	5	12201
25218	5	62678	6	8866
25219	5	62681	2	24860
25220	4	62683	1	24852
25221	4	62685	3	9193
25222	3	62686	5	24905
25223	3	62686	4	24905
25224	3	62688	6	7802
25225	5	62689	4	24899
25226	5	62689	6	24899
25227	5	62690	3	787
25228	3	62691	7	4931
25229	5	62691	2	4931
25230	5	62692	5	14991
25231	5	62693	2	24815
25232	4	62695	5	1927
25233	5	62696	3	24784
25234	4	62697	5	24743
25235	4	62697	3	24743
25236	3	62705	5	24796
25237	5	62708	6	24735
25238	4	62709	6	5588
25239	4	62710	7	24747
25240	2	62711	6	20803
25241	5	62712	6	23204
25242	5	62712	2	23204
25243	1	62713	6	24791
25244	3	62715	7	22103
25245	5	62717	1	4040
25246	3	62718	2	20970
25247	4	62722	4	13454
25248	4	62722	6	13454
25249	5	62727	5	12024
25250	3	62730	5	7289
25251	5	62731	6	21577
25252	3	62734	1	24105
25253	3	62738	2	4646
25254	5	62740	6	9682
25255	5	62741	7	7086
25256	3	62744	1	24790
25257	5	62745	5	10434
25258	5	62747	4	24898
25259	5	62750	7	24810
25260	5	62751	1	18177
25261	4	62751	4	18177
25262	5	62754	5	11834
25263	4	62755	4	8837
25264	4	62758	7	19813
25265	5	62760	2	2334
25266	5	62762	1	17197
25267	5	62764	2	9008
25268	3	62767	5	22864
25269	5	62767	6	22864
25270	4	62768	2	11456
25271	4	62769	6	10444
25272	5	62774	4	24740
25273	5	62775	5	24783
25274	3	62778	5	3294
25275	5	62779	5	8071
25276	5	62780	4	20357
25277	3	62782	1	13501
25278	4	62791	7	24741
25279	5	62791	4	24741
25280	5	62794	2	5123
25281	3	62797	4	24274
25282	5	62798	2	5407
25283	4	62802	1	23990
25284	5	62805	1	24846
25285	4	62807	7	12598
25286	5	62809	7	24849
25287	5	62812	5	12862
25288	3	62813	6	24757
25289	1	62815	6	12294
25290	3	62816	1	24824
25291	5	62817	2	24753
25292	5	62822	7	5722
25293	5	62827	1	16134
25294	5	62829	4	757
25295	5	62834	6	5829
25296	5	62834	2	5829
25297	3	62838	3	13548
25298	3	62839	4	24789
25299	4	62841	5	25039
25300	1	62845	6	14475
25301	4	62846	4	2762
25302	5	62855	1	13776
25303	5	62864	2	25040
25304	4	62864	4	25040
25305	4	62870	7	24928
25306	5	62871	4	20302
25307	5	62874	5	25037
25308	5	62878	2	14213
25309	3	62880	2	3041
25310	5	62883	2	527
25311	5	62885	7	20200
25312	5	62888	3	8379
25313	4	62889	7	17691
25314	3	62897	7	24917
25315	5	62899	1	11383
25316	5	62903	2	24908
25317	3	62903	3	24908
25318	4	62904	5	19566
25319	5	62909	3	23188
25320	4	62910	4	21893
25321	5	62912	6	24946
25322	3	62913	5	25051
25323	3	62914	1	23767
25324	5	62916	5	9761
25325	4	62917	7	456
25326	4	62918	1	9073
25327	5	62919	7	24995
25328	3	62921	6	11054
25329	4	62922	5	7119
25330	5	62924	4	11401
25331	4	62925	6	20524
25332	4	62929	7	4133
25333	3	62930	1	25078
25334	5	62932	3	12623
25335	1	62933	6	15321
25336	1	62934	6	19813
25337	4	62935	5	21496
25338	4	62940	7	24981
25339	5	62941	2	20723
25340	5	62948	6	24949
25341	2	62949	6	8880
25342	3	62953	1	25058
25343	5	62955	5	24998
25344	3	62958	3	3444
25345	5	62960	7	9779
25346	5	62961	6	17332
25347	5	62963	5	15085
25348	5	62964	4	21483
25349	5	62967	4	24953
25350	5	62968	6	25022
25351	4	62969	2	25069
25352	5	62971	4	12286
25353	3	62975	6	7675
25354	5	62978	6	18330
25355	5	62981	3	20506
25356	5	62982	1	25070
25357	3	62984	1	22597
25358	3	62987	7	24983
25359	5	62993	6	15359
25360	3	62994	3	8102
25361	3	62996	2	17610
25362	5	62996	7	17610
25363	3	62999	7	25067
25364	3	63000	5	25003
25365	4	63000	4	25003
25366	5	63007	6	24912
25367	5	63009	2	24985
25368	3	63011	5	7361
25369	3	63012	5	24996
25370	4	63015	4	3823
25371	5	63016	6	19488
25372	1	63017	6	13375
25373	4	63020	7	4132
25374	5	63021	2	3887
25375	5	63025	1	11298
25376	5	63026	3	24969
25377	3	63031	7	23046
25378	5	63032	2	25021
25379	5	63034	7	21018
25380	5	63035	2	23729
25381	4	63044	5	13303
25382	5	63046	6	3825
25383	5	63048	1	2889
25384	3	63062	1	25031
25385	4	63063	4	8011
25386	5	63066	2	1635
25387	4	63067	7	25072
25388	5	63068	5	7982
25389	4	63069	1	25080
25390	5	63070	4	25060
25391	3	63074	5	24965
25392	2	63076	3	25007
25393	3	63078	5	13547
25394	2	63081	4	18280
25395	3	63082	5	24980
25396	5	63084	1	17046
25397	5	63085	6	18505
25398	5	63086	4	24962
25399	4	63088	6	20182
25400	5	63088	5	20182
25401	3	63090	5	24392
25402	4	63091	1	24945
25403	5	63099	6	6232
25404	3	63104	7	2492
25405	1	63108	5	22890
25406	5	63109	6	17594
25407	5	63110	6	24924
25408	5	63116	2	16627
25409	5	63117	4	25016
25410	4	63118	4	24991
25411	4	63125	7	22311
25412	5	63128	6	25084
25413	4	63129	5	22062
25414	5	63130	1	4801
25415	5	63134	6	24978
25416	3	63136	7	2310
25417	5	63139	4	17003
25418	5	63143	7	24934
25419	5	63145	2	15052
25420	4	63147	7	24386
25421	4	63149	6	22523
25422	4	63151	4	24975
25423	5	63153	4	25062
25424	5	63158	6	14970
25425	4	63159	7	4828
25426	5	63160	6	24960
25427	4	63161	6	2232
25428	5	63162	6	11965
25429	3	63163	5	17144
25430	5	63164	3	25030
25431	4	63165	5	15883
25432	4	63169	6	17148
25433	5	63175	6	24914
25434	5	63176	3	1266
25435	5	63179	5	25033
25436	5	63182	2	25075
25437	3	63185	4	22242
25438	5	63188	2	14652
25439	5	63189	4	19816
25440	3	63191	7	24961
25441	5	63193	6	1155
25442	4	63194	7	11862
25443	4	63200	7	9462
25444	3	63204	6	24982
25445	4	63208	7	6182
25446	5	63215	1	6825
25447	3	63217	7	23614
25448	5	63225	1	18050
25449	5	63227	4	20211
25450	5	63231	6	22512
25451	5	63234	7	11038
25452	5	63235	1	19786
25453	3	63236	7	23896
25454	2	63237	6	8355
25455	4	63238	7	25018
25456	5	63242	1	25071
25457	5	63243	6	13026
25458	4	63244	6	16754
25459	5	63249	2	25074
25460	5	63250	6	17747
25461	5	63252	2	24913
25462	4	63255	5	4725
25463	5	63257	2	20690
25464	5	63258	7	24977
25465	4	63258	1	24977
25466	5	63260	2	18064
25467	3	63260	3	18064
25468	3	63261	7	2447
25469	3	63262	5	25006
25470	5	63264	4	24920
25471	2	63265	5	3705
25472	4	63268	7	25055
25473	5	63274	6	12384
25474	5	63275	6	893
25475	4	63277	2	25059
25476	4	63281	5	24951
25477	5	63282	6	25042
25478	2	63283	4	22620
25479	4	63286	4	20187
25480	4	63286	3	20187
25481	3	63287	5	25061
25482	5	63288	2	25008
25483	5	63289	2	9038
25484	4	63292	1	20643
25485	5	63295	2	25081
25486	4	63295	5	25081
25487	1	63298	2	21258
25488	4	63298	6	21258
25489	2	63299	5	11723
25490	4	63300	6	2669
25491	5	63301	6	25180
25492	3	63302	3	25141
25493	5	63304	2	20635
25494	3	63305	5	21405
25495	5	63307	4	25119
25496	3	63308	6	12150
25497	5	63308	3	12150
25498	5	63309	6	546
25499	4	63313	6	9525
25500	5	63314	3	7623
25501	5	63317	6	21607
25502	5	63319	6	2680
25503	2	63320	1	25152
25504	5	63321	2	25208
25505	5	63323	6	20447
25506	4	63324	6	8323
25507	5	63325	2	22987
25508	1	63326	6	16127
25509	4	63329	2	6449
25510	4	63329	1	6449
25511	4	63331	1	2333
25512	5	63333	3	19316
25513	5	63337	1	2604
25514	4	63338	3	11254
25515	5	63339	1	25272
25516	5	63340	3	25182
25517	5	63342	7	7591
25518	4	63347	4	2512
25519	5	63350	1	6516
25520	4	63355	7	25189
25521	4	63356	7	12289
25522	3	63359	5	25121
25523	5	63360	6	18036
25524	2	63368	3	25128
25525	5	63369	7	25212
25526	5	63370	1	21660
25527	4	63376	5	25160
25528	5	63379	1	19234
25529	3	63384	3	21038
25530	3	63385	2	18615
25531	5	63386	7	8761
25532	5	63386	5	8761
25533	5	63390	3	5503
25534	5	63392	4	25109
25535	5	63393	2	25155
25536	5	63395	2	19191
25537	4	63401	2	4682
25538	5	63403	7	25231
25539	2	63406	6	21453
25540	2	63408	6	8339
25541	3	63410	1	25116
25542	5	63411	4	22521
25543	5	63412	6	12072
25544	2	63415	6	25224
25545	5	63418	3	8109
25546	5	63420	3	25205
25547	5	63421	4	25151
25548	5	63428	6	15097
25549	5	63429	4	20312
25550	4	63432	7	25158
25551	3	63435	5	25187
25552	3	63442	5	25193
25553	5	63442	6	25193
25554	5	63444	6	25124
25555	5	63444	7	25124
25556	5	63447	4	929
25557	3	63450	7	24262
25558	5	63450	1	24262
25559	5	63451	4	25173
25560	5	63452	5	25170
25561	5	63456	6	25196
25562	1	63456	2	25196
25563	5	63459	4	12792
25564	5	63460	4	25188
25565	5	63461	7	13095
25566	5	63464	5	22368
25567	4	63465	1	11614
25568	4	63467	6	14795
25569	2	63471	6	25194
25570	4	63473	3	8185
25571	2	63475	4	23070
25572	5	63478	1	25120
25573	5	63479	6	2420
25574	4	63481	5	25172
25575	3	63486	7	22249
25576	5	63490	4	23074
25577	5	63490	2	23074
25578	5	63496	6	25110
25579	1	63496	4	25110
25580	5	63498	7	9996
25581	5	63501	1	25201
25582	3	63505	5	25148
25583	5	63506	4	708
25584	5	63510	4	10287
25585	5	63517	4	6328
25586	5	63518	7	6088
25587	3	63519	5	21123
25588	5	63520	7	25215
25589	1	63523	6	13681
25590	4	63525	2	2339
25591	5	63526	4	18025
25592	3	63528	7	25143
25593	4	63530	6	10350
25594	4	63535	4	25219
25595	3	63539	7	8045
25596	5	63541	6	21803
25597	5	63543	7	17421
25598	5	63544	4	13432
25599	1	63551	6	3127
25600	5	63553	6	25156
25601	4	63554	2	25198
25602	5	63555	7	4347
25603	5	63557	7	25159
25604	3	63559	4	15768
25605	5	63560	4	25269
25606	2	63563	4	25162
25607	4	63564	1	7676
25608	4	63565	5	25233
25609	3	63576	5	8867
25610	4	63583	5	25242
25611	4	63584	7	25230
25612	3	63587	2	25240
25613	3	63589	2	15556
25614	5	63591	2	25123
25615	1	63592	7	14281
25616	4	63593	5	20723
25617	5	63594	1	25061
25618	2	63595	6	5182
25619	4	63599	6	15822
25620	5	63602	7	19321
25621	5	63603	6	25211
25622	5	63604	3	1223
25623	3	63606	3	5875
25624	3	63607	1	7902
25625	3	63607	5	7902
25626	4	63612	4	6507
25627	3	63616	4	25199
25628	5	63617	5	14622
25629	5	63619	2	25246
25630	5	63621	1	16098
25631	5	63624	5	11228
25632	5	63624	4	11228
25633	5	63628	4	25154
25634	5	63629	5	996
25635	3	63629	1	996
25636	5	63630	1	25134
25637	5	63634	6	25129
25638	5	63634	3	25129
25639	5	63635	5	25227
25640	3	63636	1	25260
25641	5	63637	1	25239
25642	5	63638	4	7544
25643	4	63640	4	25279
25644	5	63643	7	25192
25645	5	63645	4	25135
25646	5	63648	5	25222
25647	5	63650	6	13699
25648	5	63652	2	10686
25649	4	63658	5	23023
25650	1	63659	6	5433
25651	5	63659	2	5433
25652	4	63660	4	4077
25653	4	63661	7	22364
25654	3	63662	7	25102
25655	3	63663	5	25268
25656	5	63669	4	25277
25657	5	63673	3	855
25658	5	63675	6	3870
25659	3	63676	5	11403
25660	5	63682	2	22774
25661	5	63685	7	11624
25662	3	63688	7	20818
25663	3	63694	6	23992
25664	4	63698	1	25115
25665	5	63699	4	9650
25666	5	63700	6	24794
25667	5	63701	2	22177
25668	4	63702	1	4592
25669	3	63708	5	25270
25670	5	63709	2	1684
25671	4	63718	5	2582
25672	5	63720	4	14284
25673	3	63726	7	25225
25674	5	63735	6	8098
25675	3	63737	1	25209
25676	3	63739	4	25267
25677	3	63742	5	25140
25678	4	63744	2	10122
25679	5	63745	1	25138
25680	3	63749	5	2687
25681	4	63750	5	9669
25682	5	63751	6	25256
25683	5	63753	6	3534
25684	5	63754	4	25253
25685	5	63756	6	25132
25686	1	63759	3	25106
25687	4	63760	7	19939
25688	5	63761	3	25202
25689	5	63765	4	25103
25690	5	63766	2	25235
25691	5	63768	1	25112
25692	4	63770	1	25204
25693	4	63779	5	23502
25694	5	63780	3	25257
25695	5	63782	3	13751
25696	5	63785	7	1481
25697	5	63788	4	10235
25698	4	63791	3	15120
25699	5	63792	4	25200
25700	5	63793	2	5361
25701	5	63798	4	4246
25702	5	63799	4	15042
25703	3	63801	1	22935
25704	5	63803	2	3658
25705	3	63809	2	25206
25706	5	63810	2	5606
25707	5	63811	2	25176
25708	5	63814	6	25114
25709	3	63815	3	21142
25710	4	63817	6	3332
25711	5	63818	2	6143
25712	5	63821	3	7527
25713	5	63822	1	11148
25714	5	63824	1	13159
25715	4	63827	7	8145
25716	3	63828	3	9440
25717	5	63829	6	13685
25718	5	63829	7	13685
25719	5	63831	2	25191
25720	5	63834	4	25275
25721	4	63837	4	23132
25722	5	63838	7	6818
25723	2	63840	6	20407
25724	5	63843	5	19783
25725	5	63847	2	10560
25726	5	63848	5	14695
25727	5	63855	6	757
25728	5	63856	3	229
25729	5	63859	6	5585
25730	5	63861	2	12344
25731	5	63863	5	25325
25732	4	63863	4	25325
25733	1	63870	6	6953
25734	4	63875	6	18307
25735	3	63877	5	24297
25736	5	63880	6	25286
25737	4	63881	7	24538
25738	4	63881	5	24538
25739	5	63885	7	2208
25740	5	63888	7	7383
25741	5	63893	6	3393
25742	5	63895	1	25282
25743	4	63899	7	9738
25744	4	63901	2	7594
25745	4	63904	3	22414
25746	4	63908	3	12592
25747	5	63908	1	12592
25748	5	63910	2	25378
25749	1	63912	6	18959
25750	4	63914	1	25395
25751	3	63918	5	440
25752	5	63920	1	11419
25753	5	63921	4	25363
25754	1	63927	7	14183
25755	5	63931	2	14999
25756	5	63932	7	5642
25757	5	63934	4	25420
25758	4	63937	7	19686
25759	2	63940	4	23939
25760	3	63941	7	25358
25761	5	63943	2	15314
25762	3	63944	7	20819
25763	5	63945	4	9669
25764	3	63946	3	7293
25765	4	63949	7	24040
25766	5	63949	2	24040
25767	5	63952	2	12755
25768	4	63952	4	12755
25769	5	63958	5	25318
25770	5	63960	7	8863
25771	3	63961	5	10597
25772	3	63962	7	21749
25773	2	63962	5	21749
25774	5	63965	1	10266
25775	3	63967	7	24310
25776	4	63969	7	25312
25777	4	63970	1	15956
25778	5	63971	4	15407
25779	2	63974	6	3125
25780	5	63977	2	25412
25781	4	63979	5	15326
25782	2	63980	6	17812
25783	3	63982	1	19976
25784	5	63983	3	20170
25785	3	63983	1	20170
25786	5	63987	6	25376
25787	2	63989	2	18529
25788	4	63990	5	8988
25789	5	63996	4	22952
25790	5	63997	3	25302
25791	5	63998	1	25323
25792	3	64001	7	7483
25793	5	64007	5	25371
25794	5	64008	4	2708
25795	5	64012	6	13523
25796	5	64015	3	15059
25797	5	64018	7	17153
25798	1	64022	6	25437
25799	4	64024	7	23642
25800	4	64027	1	25283
25801	5	64028	6	14291
25802	5	64029	3	22393
25803	4	64032	5	9833
25804	4	64036	6	25305
25805	5	64038	6	2761
25806	5	64039	3	12080
25807	4	64041	6	9801
25808	3	64045	1	15510
25809	5	64047	2	4825
25810	5	64048	5	9365
25811	5	64049	2	14018
25812	4	64050	1	18957
25813	3	64050	3	18957
25814	5	64052	5	25316
25815	2	64053	6	9855
25816	5	64058	1	19817
25817	5	64060	2	19800
25818	3	64062	7	16934
25819	5	64063	7	1676
25820	5	64064	5	25423
25821	5	64066	6	18344
25822	4	64067	5	12182
25823	4	64070	6	11624
25824	4	64070	7	11624
25825	5	64071	6	25349
25826	4	64074	7	25384
25827	5	64080	2	5478
25828	4	64083	5	25342
25829	5	64084	5	17839
25830	3	64088	3	1161
25831	5	64089	7	22263
25832	5	64090	4	25296
25833	5	64099	4	25332
25834	5	64101	6	12050
25835	1	64103	6	20755
25836	5	64104	2	25333
25837	2	64112	4	25321
25838	5	64115	6	16158
25839	5	64120	7	24281
25840	5	64126	1	135
25841	5	64127	1	6950
25842	5	64128	5	13563
25843	4	64132	5	25369
25844	5	64136	1	17594
25845	5	64138	7	3898
25846	5	64143	2	14711
25847	4	64143	5	14711
25848	3	64144	6	25379
25849	4	64146	7	8311
25850	3	64148	7	20271
25851	3	64149	4	7431
25852	3	64153	2	3799
25853	3	64156	3	8640
25854	5	64157	6	12974
25855	3	64157	5	12974
25856	3	64158	3	17821
25857	5	64162	6	1212
25858	4	64166	6	10732
25859	4	64168	7	25290
25860	5	64170	6	16788
25861	1	64174	7	21869
25862	5	64176	7	25309
25863	5	64177	4	25311
25864	4	64179	7	5945
25865	3	64184	1	25326
25866	4	64186	2	6127
25867	5	64190	2	7283
25868	4	64191	6	25308
25869	4	64193	3	1015
25870	3	64194	3	24441
25871	5	64195	7	8139
25872	5	64198	4	7387
25873	4	64199	5	5970
25874	4	64200	3	24766
25875	4	64202	2	23362
25876	5	64205	5	20711
25877	5	64206	2	2270
25878	5	64208	1	17582
25879	5	64210	4	19582
25880	4	64217	3	25424
25881	3	64220	3	25413
25882	3	64222	4	23289
25883	5	64223	7	4331
25884	3	64228	1	25336
25885	5	64229	2	4924
25886	3	64233	5	17387
25887	5	64233	1	17387
25888	4	64237	7	25404
25889	3	64240	4	25434
25890	4	64241	3	21488
25891	5	64242	7	17501
25892	5	64252	1	14572
25893	5	64257	2	23470
25894	5	64258	6	25428
25895	4	64259	6	9435
25896	5	64264	1	15907
25897	4	64265	4	24408
25898	5	64266	2	16810
25899	4	64270	7	2541
25900	4	64272	4	25405
25901	4	64273	1	25433
25902	5	64274	6	25298
25903	5	64274	4	25298
25904	4	64279	2	25435
25905	5	64281	1	25319
25906	4	64288	3	16084
25907	5	64291	1	23996
25908	5	64292	4	25381
25909	5	64292	6	25381
25910	5	64293	4	4468
25911	5	64295	2	18773
25912	3	64298	1	9985
25913	4	64300	5	14227
25914	4	64301	5	25362
25915	2	64302	6	24245
25916	5	64306	6	25293
25917	4	64307	4	11826
25918	3	64310	5	25313
25919	2	64313	6	25426
25920	5	64316	7	23144
25921	5	64317	4	19065
25922	5	64320	3	25359
25923	5	64321	2	136
25924	5	64325	6	2317
25925	5	64326	4	3314
25926	3	64329	7	25398
25927	4	64331	3	25382
25928	5	64335	1	18195
25929	5	64336	3	19953
25930	1	64338	2	25335
25931	4	64340	3	4737
25932	4	64341	1	2855
25933	4	64342	2	1164
25934	5	64343	6	13060
25935	5	64346	5	5473
25936	5	64350	7	17805
25937	5	64351	2	14103
25938	5	64352	6	25389
25939	4	64356	1	21624
25940	5	64356	6	21624
25941	5	64357	6	9816
25942	5	64362	4	3112
25943	3	64366	7	21321
25944	5	64371	6	18546
25945	5	64373	4	25340
25946	4	64374	1	25392
25947	2	64375	1	3797
25948	4	64379	6	10312
25949	5	64380	7	19883
25950	2	64380	6	19883
25951	5	64384	6	25346
25952	2	64390	3	19553
25953	5	64394	3	2085
25954	3	64395	1	25406
25955	3	64396	3	12425
25956	3	64400	1	7147
25957	4	64400	2	7147
25958	1	64401	3	25315
25959	4	64403	1	6678
25960	5	64404	1	16190
25961	4	64407	4	2185
25962	4	64409	2	25387
25963	5	64412	6	10399
25964	4	64413	1	13056
25965	5	64414	7	5647
25966	5	64424	6	15933
25967	5	64425	5	25341
25968	4	64426	6	1531
25969	4	64427	3	17363
25970	5	64427	6	17363
25971	5	64430	2	15025
25972	3	64432	7	20633
25973	5	64433	3	25366
25974	5	64435	2	25345
25975	5	64439	1	22523
25976	4	64441	7	13267
25977	4	64442	7	22730
25978	1	64443	6	11485
25979	2	64443	7	11485
25980	4	64445	7	12361
25981	5	64447	5	20345
25982	3	64461	1	4195
25983	5	64471	3	9451
25984	4	64472	7	9631
25985	5	64474	3	25550
25986	4	64475	7	24038
25987	2	64476	3	599
25988	4	64477	5	292
25989	3	64478	5	10479
25990	1	64480	5	25580
25991	5	64482	3	25582
25992	5	64486	3	25531
25993	5	64489	3	12420
25994	4	64491	6	11124
25995	5	64493	5	25464
25996	5	64496	2	25486
25997	5	64497	2	5930
25998	4	64499	4	21138
25999	2	64503	3	18874
26000	4	64505	7	25504
26001	4	64506	7	25456
26002	3	64507	7	2444
26003	5	64509	6	13191
26004	3	64509	4	13191
26005	5	64512	5	6250
26006	5	64516	4	4624
26007	5	64517	2	19971
26008	5	64518	1	25487
26009	5	64526	7	12546
26010	5	64532	2	25557
26011	5	64534	7	25517
26012	5	64535	3	17018
26013	5	64536	4	25524
26014	5	64536	1	25524
26015	4	64537	3	14711
26016	5	64540	2	25446
26017	1	64542	6	22928
26018	5	64544	2	21173
26019	4	64546	1	18840
26020	5	64548	5	7650
26021	4	64549	7	23555
26022	4	64552	5	485
26023	3	64553	7	25543
26024	3	64555	5	21617
26025	4	64559	3	837
26026	5	64566	2	25533
26027	3	64568	3	25608
26028	3	64572	5	23350
26029	4	64576	1	7076
26030	3	64578	3	11529
26031	4	64579	3	25483
26032	3	64579	5	25483
26033	3	64581	1	784
26034	3	64587	3	25577
26035	5	64588	2	25549
26036	5	64589	7	11030
26037	4	64590	5	25493
26038	5	64595	7	25565
26039	5	64596	1	25599
26040	5	64597	1	16578
26041	2	64598	3	25600
26042	3	64600	4	10798
26043	5	64602	1	2761
26044	4	64611	7	25555
26045	5	64614	1	10250
26046	2	64624	3	25447
26047	5	64626	7	11670
26048	5	64628	7	23903
26049	3	64631	1	23486
26050	3	64631	3	23486
26051	4	64634	4	9215
26052	5	64638	6	25508
26053	5	64639	1	25519
26054	5	64643	2	25498
26055	5	64645	1	4973
26056	5	64647	1	13064
26057	3	64649	7	7821
26058	5	64650	2	2415
26059	4	64652	6	17404
26060	2	64653	6	8347
26061	5	64657	4	6348
26062	5	64662	5	144
26063	4	64666	7	5146
26064	4	64669	5	18459
26065	1	64670	4	25461
26066	5	64671	6	25440
26067	4	64672	2	25609
26068	5	64672	6	25609
26069	3	64673	5	25503
26070	5	64675	7	25588
26071	3	64677	2	15271
26072	5	64678	6	20277
26073	3	64686	2	14954
26074	5	64690	6	25450
26075	5	64691	4	7510
26076	5	64697	4	25594
26077	3	64699	2	16669
26078	5	64701	4	25515
26079	3	64702	2	24605
26080	4	64704	7	25559
26081	3	64706	4	25505
26082	5	64710	6	23453
26083	5	64712	6	25482
26084	5	64713	1	25556
26085	5	64713	3	25556
26086	5	64714	1	333
26087	3	64717	7	21392
26088	5	64718	1	25470
26089	2	64720	6	25488
26090	5	64722	6	19429
26091	4	64725	2	12108
26092	3	64731	5	25445
26093	4	64732	7	7426
26094	5	64733	2	25540
26095	5	64738	6	21370
26096	5	64741	5	25575
26097	5	64744	4	16230
26098	4	64745	3	23040
26099	5	64746	7	25598
26100	5	64747	5	6824
26101	4	64748	7	25520
26102	5	64748	2	25520
26103	5	64749	2	16223
26104	1	64752	6	9364
26105	2	64755	1	2185
26106	5	64758	5	25475
26107	5	64760	7	25507
26108	3	64761	2	18764
26109	3	64766	5	409
26110	4	64766	1	409
26111	5	64768	6	25585
26112	3	64774	7	20796
26113	5	64777	7	4079
26114	4	64778	6	17697
26115	4	64779	4	6855
26116	3	64781	2	25654
26117	5	64784	2	20524
26118	5	64789	7	23061
26119	4	64789	5	23061
26120	1	64791	6	14144
26121	5	64795	2	2351
26122	5	64796	6	2783
26123	5	64799	7	16183
26124	3	64801	4	6484
26125	5	64802	1	1885
26126	3	64804	7	517
26127	5	64805	2	14065
26128	4	64807	7	6957
26129	5	64809	1	25749
26130	4	64812	5	14649
26131	3	64813	3	13371
26132	4	64815	7	20424
26133	3	64818	6	6796
26134	5	64819	2	24585
26135	1	64819	4	24585
26136	5	64820	1	14519
26137	5	64821	4	25740
26138	4	64822	1	16438
26139	5	64823	4	6947
26140	5	64826	4	18929
26141	5	64827	4	3903
26142	3	64828	5	25625
26143	2	64829	6	17114
26144	4	64830	4	25676
26145	3	64831	3	17526
26146	4	64832	1	25665
26147	4	64832	5	25665
26148	5	64833	6	11825
26149	3	64836	4	74
26150	4	64841	7	21038
26151	3	64842	2	25794
26152	5	64842	5	25794
26153	4	64843	5	25673
26154	5	64844	2	25653
26155	4	64845	7	7390
26156	3	64847	4	14228
26157	5	64849	6	48
26158	5	64849	2	48
26159	3	64854	4	17698
26160	1	64855	6	2761
26161	5	64862	6	1822
26162	5	64863	5	23201
26163	5	64865	4	1176
26164	1	64872	4	2436
26165	5	64875	4	20805
26166	5	64877	2	6576
26167	5	64883	4	17570
26168	5	64884	1	12532
26169	5	64888	2	25633
26170	3	64894	4	7465
26171	5	64897	2	16480
26172	4	64902	2	18152
26173	5	64903	5	10481
26174	5	64910	6	20534
26175	5	64917	5	25788
26176	5	64919	2	25727
26177	4	64920	7	25760
26178	4	64923	5	25614
26179	3	64923	3	25614
26180	5	64925	4	21236
26181	5	64927	2	25649
26182	5	64929	3	20615
26183	4	64930	4	2384
26184	4	64931	6	25655
26185	5	64932	2	4757
26186	5	64933	6	9420
26187	4	64937	2	11822
26188	4	64938	2	25648
26189	5	64940	1	23535
26190	5	64941	4	2602
26191	5	64942	3	25758
26192	5	64946	5	20915
26193	5	64947	4	16002
26194	5	64948	6	25738
26195	5	64952	7	20996
26196	5	64954	1	3318
26197	5	64955	2	22478
26198	4	64957	2	19490
26199	5	64958	2	8884
26200	5	64960	5	25744
26201	5	64965	7	25739
26202	5	64966	5	12078
26203	3	64969	7	13263
26204	3	64970	5	25670
26205	5	64972	2	11754
26206	5	64974	1	22000
26207	5	64974	4	22000
26208	5	64976	6	9821
26209	5	64980	2	25669
26210	5	64982	2	15368
26211	3	64987	2	20371
26212	5	64989	3	24093
26213	1	64991	4	25679
26214	5	64992	6	25678
26215	4	64996	7	21724
26216	4	64997	7	25726
26217	5	64998	2	25728
26218	3	65006	7	25757
26219	4	65007	2	25782
26220	5	65009	6	25716
26221	4	65010	5	14984
26222	4	65012	5	25702
26223	3	65013	5	25703
26224	5	65015	6	12788
26225	4	65016	6	25729
26226	5	65017	1	5622
26227	4	65020	2	17434
26228	5	65020	4	17434
26229	5	65027	2	7089
26230	5	65029	6	10350
26231	4	65036	7	8557
26232	5	65046	5	6095
26233	3	65049	1	23863
26234	4	65050	2	9364
26235	1	65056	6	24690
26236	3	65057	1	2083
26237	1	65059	4	9718
26238	3	65060	6	25089
26239	5	65063	7	10488
26240	5	65068	2	1258
26241	2	65070	4	15127
26242	5	65072	6	25675
26243	5	65072	1	25675
26244	3	65075	1	9594
26245	4	65077	7	25645
26246	3	65080	7	3030
26247	5	65081	6	8802
26248	3	65084	2	6883
26249	5	65086	2	19541
26250	1	65087	6	25619
26251	5	65089	6	22098
26252	3	65092	5	20136
26253	5	65093	6	24987
26254	5	65094	2	25786
26255	4	65097	7	25723
26256	5	65101	7	1893
26257	5	65102	6	16686
26258	4	65105	1	10369
26259	5	65110	2	581
26260	3	65112	4	25772
26261	5	65113	7	25713
26262	4	65116	4	6469
26263	4	65121	6	25651
26264	5	65124	1	11256
26265	4	65131	3	23917
26266	5	65133	1	1883
26267	5	65133	7	1883
26268	5	65134	3	8323
26269	3	65135	5	15902
26270	5	65136	6	4546
26271	4	65137	5	25696
26272	3	65142	6	3828
26273	4	65143	1	19697
26274	5	65144	3	4872
26275	4	65145	2	24620
26276	3	65152	7	19798
26277	5	65158	7	25701
26278	5	65159	7	11276
26279	4	65161	7	25781
26280	5	65163	3	15233
26281	4	65165	6	25751
26282	5	65170	6	25853
26283	5	65175	3	25875
26284	5	65175	5	25875
26285	5	65180	7	9688
26286	4	65183	5	14805
26287	5	65185	7	25883
26288	5	65188	1	19706
26289	5	65190	6	2293
26290	5	65192	1	11289
26291	3	65195	5	2006
26292	2	65196	3	16710
26293	5	65197	6	2336
26294	5	65198	6	5032
26295	5	65201	1	15807
26296	5	65202	2	11151
26297	3	65208	5	25949
26298	5	65211	6	4684
26299	3	65211	1	4684
26300	3	65212	3	454
26301	5	65214	6	11756
26302	5	65216	5	9977
26303	5	65218	2	6037
26304	3	65220	7	15105
26305	5	65227	6	25689
26306	4	65229	7	14202
26307	4	65231	4	11425
26308	4	65232	1	24643
26309	5	65234	7	3289
26310	2	65236	3	25939
26311	4	65237	7	6114
26312	3	65240	3	16279
26313	5	65242	3	25847
26314	3	65245	5	20326
26315	4	65246	1	10039
26316	5	65248	7	11534
26317	5	65251	2	1258
26318	4	65256	4	25825
26319	4	65258	6	25940
26320	5	65260	5	22188
26321	4	65267	5	3705
26322	5	65272	2	25830
26323	5	65273	5	25287
26324	5	65274	1	25860
26325	5	65275	1	6163
26326	4	65276	5	22863
26327	5	65277	4	21624
26328	1	65286	6	24807
26329	5	65287	2	25040
26330	5	65293	2	2776
26331	5	65295	5	10461
26332	5	65296	2	25815
26333	4	65299	7	25928
26334	5	65301	6	25963
26335	5	65303	3	7628
26336	5	65306	3	25880
26337	4	65307	3	21612
26338	5	65309	3	10679
26339	5	65310	2	25831
26340	4	65312	5	17430
26341	4	65313	2	13786
26342	2	65320	1	9947
26343	4	65321	3	2333
26344	1	65323	6	4951
26345	2	65324	4	3948
26346	5	65332	3	2755
26347	5	65334	6	25952
26348	5	65337	1	3835
26349	5	65338	5	6553
26350	4	65339	3	25936
26351	5	65344	6	25944
26352	5	65345	3	24566
26353	3	65349	6	25870
26354	5	65349	2	25870
26355	4	65352	5	22251
26356	5	65353	6	25920
26357	5	65356	6	19025
26358	3	65358	6	4888
26359	3	65360	5	6915
26360	3	65361	5	16538
26361	4	65366	3	7056
26362	5	65367	4	3268
26363	5	65367	7	3268
26364	5	65372	2	20415
26365	3	65375	5	25821
26366	4	65378	7	13444
26367	5	65379	6	25219
26368	5	65382	7	17703
26369	5	65385	2	24658
26370	5	65386	7	25850
26371	5	65387	1	23060
26372	4	65388	5	11732
26373	5	65390	2	15335
26374	5	65391	7	25844
26375	5	65393	1	12991
26376	5	65393	7	12991
26377	5	65397	2	7253
26378	5	65400	2	7691
26379	5	65401	4	20277
26380	5	65403	6	18166
26381	4	65409	1	19248
26382	5	65410	4	8670
26383	5	65411	6	286
26384	5	65411	3	286
26385	1	65414	6	17511
26386	5	65415	4	9621
26387	3	65420	4	25886
26388	4	65421	3	4622
26389	4	65422	1	19342
26390	4	65423	6	21774
26391	5	65427	1	536
26392	1	65430	6	25888
26393	4	65430	4	25888
26394	5	65433	5	25902
26395	3	65434	6	25943
26396	4	65435	4	1956
26397	5	65439	2	5354
26398	3	65440	7	25946
26399	5	65444	5	20124
26400	5	65455	5	14929
26401	5	65456	6	25911
26402	5	65457	1	25901
26403	5	65459	1	12254
26404	5	65460	5	12189
26405	3	65461	5	23929
26406	4	65463	3	25892
26407	5	65465	6	25906
26408	3	65466	5	16195
26409	4	65468	7	20673
26410	4	65475	3	10273
26411	4	65477	7	3825
26412	1	65478	6	21771
26413	2	65479	6	16831
26414	5	65481	3	25805
26415	4	65485	2	25842
26416	5	65486	4	18807
26417	5	65488	6	25938
26418	5	65491	2	12945
26419	3	65492	7	22695
26420	4	65497	5	25855
26421	5	65498	2	21386
26422	3	65499	7	25814
26423	5	65503	7	14496
26424	4	65506	3	25828
26425	3	65509	2	25932
26426	5	65512	1	20288
26427	5	65513	6	25942
26428	5	65514	3	12415
26429	3	65517	4	25864
26430	5	65518	6	15528
26431	4	65519	5	25877
26432	5	65521	6	20245
26433	4	65523	6	25835
26434	4	65524	5	25926
26435	4	65530	7	11298
26436	4	65530	1	11298
26437	5	65532	7	8583
26438	1	65538	6	25869
26439	2	65539	6	3593
26440	5	65542	7	184
26441	5	65542	2	184
26442	5	65543	4	21483
26443	5	65544	3	3927
26444	5	65544	2	3927
26445	3	65545	7	25266
26446	4	65554	7	25959
26447	4	65555	7	8176
26448	5	65557	2	25951
26449	4	65558	7	4247
26450	5	65558	6	4247
26451	5	65559	7	1025
26452	3	65561	4	9964
26453	5	65562	4	11772
26454	5	65566	3	9005
26455	4	65570	5	15659
26456	3	65572	1	25881
26457	5	65573	5	23990
26458	5	65575	7	14332
26459	3	65576	3	21888
26460	4	65577	7	25941
26461	5	65578	2	1309
26462	5	65585	6	25820
26463	5	65586	7	25806
26464	3	65590	7	25846
26465	5	65592	4	3344
26466	5	65593	2	8663
26467	5	65595	6	25918
26468	1	65596	6	25934
26469	5	65597	7	25872
26470	5	65599	3	25661
26471	3	65601	7	13698
26472	1	65603	6	17103
26473	4	65603	4	17103
26474	5	65614	3	1897
26475	5	65617	3	17582
26476	5	65618	5	4792
26477	5	65620	7	371
26478	4	65623	1	16110
26479	3	65625	5	6773
26480	5	65627	4	25992
26481	5	65629	4	10421
26482	3	65630	7	13241
26483	5	65631	1	26109
26484	5	65632	6	20229
26485	5	65637	6	15408
26486	4	65642	7	16496
26487	1	65643	1	16361
26488	5	65644	2	8181
26489	5	65646	6	8230
26490	4	65647	6	23665
26491	5	65649	6	12093
26492	3	65653	2	5958
26493	5	65656	7	23907
26494	5	65663	3	2416
26495	4	65667	2	20055
26496	5	65672	7	3077
26497	1	65673	4	26117
26498	4	65675	5	24511
26499	4	65678	4	16039
26500	3	65680	1	15105
26501	2	65681	3	16010
26502	5	65684	7	23815
26503	3	65686	2	10061
26504	4	65688	5	6862
26505	5	65689	6	2401
26506	5	65692	6	21084
26507	4	65695	4	6412
26508	5	65699	6	26041
26509	5	65700	7	26015
26510	5	65702	6	1215
26511	5	65705	1	26004
26512	5	65706	2	26110
26513	5	65710	3	26087
26514	5	65711	2	25981
26515	4	65714	3	25350
26516	4	65718	2	26022
26517	5	65721	4	26036
26518	4	65724	7	4588
26519	3	65729	3	25003
26520	5	65736	2	10329
26521	5	65740	7	9061
26522	5	65741	7	12389
26523	1	65742	6	26083
26524	4	65747	5	12304
26525	5	65748	6	25989
26526	4	65757	2	12905
26527	5	65763	2	11005
26528	4	65765	3	25331
26529	5	65773	5	16160
26530	5	65776	2	26076
26531	3	65779	7	26005
26532	4	65780	7	11203
26533	5	65783	4	7203
26534	5	65786	4	1376
26535	5	65787	5	26032
26536	3	65788	2	16840
26537	5	65789	5	18202
26538	5	65790	6	8471
26539	5	65792	2	1490
26540	5	65793	4	12772
26541	5	65800	5	23033
26542	4	65804	7	15550
26543	5	65807	2	2424
26544	4	65810	6	26139
26545	5	65812	5	13969
26546	4	65813	3	3887
26547	5	65817	2	13844
26548	5	65819	6	16190
26549	2	65820	6	26125
26550	5	65822	6	26137
26551	5	65830	6	11503
26552	5	65833	7	7510
26553	5	65836	2	2310
26554	4	65838	4	26049
26555	5	65842	4	7673
26556	5	65848	4	5343
26557	5	65852	6	6419
26558	3	65854	1	1343
26559	5	65855	1	6957
26560	1	65856	6	13527
26561	5	65858	5	26105
26562	5	65861	4	26138
26563	5	65863	4	25971
26564	5	65864	1	26089
26565	4	65866	7	19172
26566	4	65869	7	25918
26567	5	65870	6	26073
26568	5	65873	4	26008
26569	4	65874	2	16621
26570	3	65879	3	3243
26571	3	65880	5	22966
26572	5	65881	4	2743
26573	5	65882	7	730
26574	5	65885	5	25977
26575	3	65887	1	3260
26576	4	65890	2	25995
26577	4	65893	6	26131
26578	4	65906	6	26027
26579	4	65906	3	26027
26580	4	65908	7	26096
26581	3	65910	5	26052
26582	5	65913	5	26045
26583	5	65913	4	26045
26584	2	65915	3	2318
26585	5	65916	5	4293
26586	5	65916	1	4293
26587	4	65919	3	19399
26588	4	65921	5	16907
26589	5	65923	4	26095
26590	4	65924	3	26038
26591	5	65925	4	26062
26592	3	65928	1	26031
26593	5	65929	6	17826
26594	4	65929	7	17826
26595	5	65931	4	26012
26596	4	65932	7	26134
26597	5	65934	6	26107
26598	3	65936	2	4436
26599	4	65939	7	9395
26600	4	65957	6	16252
26601	4	65960	7	4022
26602	4	65961	6	25979
26603	5	65963	2	25976
26604	5	65968	3	22981
26605	5	65970	5	26101
26606	5	65973	6	9107
26607	5	65976	2	1055
26608	5	65977	6	16150
26609	3	65980	1	13413
26610	4	65983	5	13677
26611	4	65986	1	26018
26612	5	65993	7	8050
26613	3	65995	5	8482
26614	5	65996	2	14526
26615	5	65997	3	8811
26616	4	65998	7	10243
26617	5	66001	2	24625
26618	5	66002	2	22558
26619	4	66012	5	13876
26620	3	66015	7	11038
26621	5	66016	1	21061
26622	3	66017	7	424
26623	5	66018	3	23213
26624	5	66020	5	26088
26625	5	66021	2	26102
26626	5	66022	6	17503
26627	5	66029	6	21934
26628	4	66031	5	5099
26629	5	66033	4	25970
26630	5	66037	4	26009
26631	4	66044	3	26047
26632	5	66046	5	25966
26633	4	66052	5	26082
26634	5	66054	3	17899
26635	3	66055	6	7378
26636	5	66056	2	21494
26637	2	66058	6	26069
26638	4	66061	5	19817
26639	4	66065	5	26123
26640	5	66067	6	18754
26641	3	66067	2	18754
26642	5	66070	7	26111
26643	4	66076	1	25061
26644	4	66079	5	12154
26645	5	66080	4	136
26646	3	66081	4	22564
26647	5	66088	6	26057
26648	3	66091	1	585
26649	5	66092	1	5461
26650	5	66094	6	10430
26651	4	66095	7	11254
26652	5	66098	1	21528
26653	5	66100	7	26085
26654	5	66104	1	7019
26655	3	66105	4	24665
26656	4	66106	1	26213
26657	5	66106	3	26213
26658	4	66107	3	1709
26659	5	66111	5	1559
26660	4	66116	7	22320
26661	4	66121	3	13249
26662	5	66122	4	26313
26663	5	66124	4	26182
26664	5	66125	2	1361
26665	5	66126	4	21601
26666	5	66127	4	26202
26667	5	66132	6	10707
26668	5	66134	1	26249
26669	3	66135	4	26153
26670	5	66141	6	22605
26671	4	66142	2	7096
26672	1	66144	6	25839
26673	5	66148	6	24134
26674	5	66150	7	22464
26675	5	66151	6	26278
26676	5	66154	4	6535
26677	5	66155	2	6009
26678	3	66155	4	6009
26679	4	66156	2	14887
26680	3	66160	5	4962
26681	4	66164	6	15151
26682	5	66165	1	24964
26683	5	66168	6	5097
26684	4	66172	2	15244
26685	5	66173	2	2425
26686	5	66174	1	1760
26687	5	66178	4	26320
26688	5	66180	3	12851
26689	3	66181	7	12090
26690	4	66182	5	14993
26691	5	66183	4	26218
26692	5	66185	5	25077
26693	2	66188	6	11250
26694	5	66189	1	26211
26695	5	66190	7	26270
26696	5	66192	7	1309
26697	5	66194	3	20963
26698	5	66195	2	26212
26699	3	66196	7	26259
26700	5	66203	6	24035
26701	5	66206	2	1132
26702	5	66208	2	26263
26703	5	66214	4	7112
26704	5	66216	6	26319
26705	4	66220	7	26327
26706	3	66221	5	1266
26707	5	66224	6	3031
26708	2	66226	6	5570
26709	5	66232	7	26312
26710	4	66237	2	13866
26711	3	66238	5	11102
26712	5	66241	2	26207
26713	5	66244	3	10759
26714	5	66246	5	17861
26715	3	66248	1	10507
26716	5	66250	2	5293
26717	5	66252	4	19307
26718	1	66253	6	20426
26719	5	66254	5	6600
26720	4	66257	7	15597
26721	5	66258	4	15829
26722	4	66259	3	26162
26723	5	66261	2	10484
26724	5	66261	1	10484
26725	5	66263	7	1919
26726	3	66267	7	11311
26727	5	66272	7	22756
26728	5	66274	7	25397
26729	3	66275	5	24872
26730	5	66277	4	13767
26731	5	66278	4	3263
26732	5	66283	2	26310
26733	5	66285	6	14479
26734	5	66288	7	12462
26735	5	66288	2	12462
26736	5	66289	6	5322
26737	3	66289	5	5322
26738	3	66295	1	24789
26739	3	66295	2	24789
26740	5	66298	3	26187
26741	5	66299	7	25714
26742	5	66300	4	26237
26743	3	66301	5	26294
26744	5	66302	1	21383
26745	5	66305	4	2197
26746	3	66308	7	11174
26747	4	66308	5	11174
26748	5	66309	6	26179
26749	5	66310	1	688
26750	5	66311	6	18306
26751	5	66317	2	23928
26752	5	66329	6	24629
26753	5	66333	6	4983
26754	4	66334	5	842
26755	5	66336	7	10935
26756	5	66337	2	25270
26757	3	66340	7	23207
26758	5	66340	6	23207
26759	5	66344	6	26293
26760	4	66346	1	15730
26761	3	66351	1	17652
26762	5	66351	6	17652
26763	5	66353	6	24600
26764	4	66359	7	9135
26765	2	66362	3	5302
26766	5	66367	4	26147
26767	5	66367	5	26147
26768	3	66368	2	11540
26769	3	66369	5	11136
26770	4	66371	1	3265
26771	5	66373	4	22068
26772	4	66376	3	9021
26773	1	66377	6	8382
26774	5	66381	5	11860
26775	5	66383	2	26160
26776	4	66384	7	26154
26777	3	66385	7	26224
26778	5	66387	4	4836
26779	5	66392	6	8763
26780	4	66394	7	19493
26781	2	66396	6	26229
26782	3	66397	3	9733
26783	4	66398	2	26274
26784	3	66401	7	26146
26785	5	66406	2	997
26786	5	66407	6	25997
26787	5	66408	6	26194
26788	5	66413	4	2317
26789	5	66420	3	11454
26790	5	66422	5	12481
26791	5	66427	6	26269
26792	5	66428	6	8192
26793	5	66431	1	12011
26794	5	66432	2	7675
26795	3	66433	4	23621
26796	3	66438	5	10258
26797	5	66441	1	8546
26798	5	66442	7	25296
26799	4	66444	6	2906
26800	5	66445	6	22299
26801	5	66452	3	1202
26802	5	66453	1	5466
26803	5	66454	6	26174
26804	3	66456	4	18348
26805	5	66457	6	20495
26806	3	66458	5	25308
26807	4	66461	7	26305
26808	5	66462	1	24619
26809	3	66466	7	8639
26810	4	66467	3	9358
26811	5	66470	6	18843
26812	5	66472	1	16018
26813	5	66473	7	13960
26814	3	66476	3	3004
26815	5	66477	7	21280
26816	5	66478	6	9191
26817	3	66479	2	16703
26818	5	66480	7	24975
26819	5	66481	2	26181
26820	4	66483	5	4201
26821	5	66484	1	19945
26822	5	66485	5	11442
26823	4	66486	6	6489
26824	3	66487	7	26306
26825	4	66496	3	26326
26826	5	66499	4	26292
26827	5	66500	5	4953
26828	1	66501	6	10461
26829	5	66504	1	24602
26830	5	66505	3	26190
26831	4	66508	4	26271
26832	4	66511	3	26264
26833	5	66512	3	26151
26834	5	66513	4	26157
26835	3	66514	5	3853
26836	5	66514	2	3853
26837	3	66520	4	5568
26838	3	66522	5	6760
26839	4	66525	3	19212
26840	3	66526	5	26277
26841	3	66527	3	4929
26842	5	66531	2	26223
26843	4	66532	1	5380
26844	4	66533	1	18602
26845	5	66535	1	21867
26846	5	66537	6	6919
26847	5	66540	6	6820
26848	5	66543	6	14682
26849	3	66546	3	8404
26850	5	66548	5	14739
26851	1	66550	6	11296
26852	5	66555	3	20965
26853	4	66557	1	26452
26854	5	66558	6	26549
26855	5	66563	3	10785
26856	4	66567	7	519
26857	5	66568	7	25637
26858	5	66569	2	25550
26859	5	66571	1	11268
26860	4	66572	7	26407
26861	5	66572	4	26407
26862	2	66574	4	15042
26863	3	66575	6	26330
26864	3	66575	4	26330
26865	4	66578	4	17209
26866	5	66582	7	26101
26867	5	66584	2	7084
26868	5	66586	3	24788
26869	3	66586	2	24788
26870	5	66588	6	12390
26871	5	66589	6	26470
26872	3	66593	7	5843
26873	3	66597	5	9894
26874	5	66600	6	26523
26875	3	66601	6	2153
26876	3	66604	1	10482
26877	5	66606	1	26357
26878	5	66607	6	25718
26879	3	66617	7	26414
26880	5	66619	2	9296
26881	5	66621	4	26459
26882	5	66623	2	5144
26883	4	66629	2	26416
26884	5	66642	5	7912
26885	4	66642	4	7912
26886	4	66643	7	22934
26887	5	66645	2	14283
26888	4	66646	7	26436
26889	5	66649	2	16404
26890	2	66652	3	3000
26891	5	66653	7	26369
26892	4	66655	7	24792
26893	5	66657	7	26530
26894	5	66658	6	4356
26895	3	66659	7	26454
26896	5	66661	6	26485
26897	5	66665	6	5158
26898	4	66667	3	6880
26899	4	66672	7	15122
26900	5	66672	6	15122
26901	5	66673	3	12412
26902	3	66676	6	2012
26903	4	66678	7	20469
26904	3	66679	7	11869
26905	5	66680	6	18541
26906	4	66682	3	12378
26907	5	66684	6	26537
26908	4	66685	3	26321
26909	5	66686	4	7781
26910	5	66687	4	19495
26911	5	66689	6	12823
26912	5	66692	5	2564
26913	3	66693	7	26379
26914	5	66695	1	13188
26915	4	66697	6	24058
26916	5	66710	4	15048
26917	4	66711	6	14140
26918	5	66713	6	24870
26919	5	66714	6	26335
26920	4	66716	4	21436
26921	3	66717	2	2627
26922	5	66719	1	1655
26923	5	66720	5	23507
26924	4	66721	5	26444
26925	5	66723	2	26446
26926	1	66725	5	26433
26927	1	66732	5	7748
26928	5	66735	1	5642
26929	4	66737	5	17268
26930	5	66737	7	17268
26931	3	66740	3	1314
26932	3	66742	5	26441
26933	5	66745	2	6455
26934	5	66746	1	26366
26935	5	66750	2	26542
26936	4	66751	3	26114
26937	4	66752	6	424
26938	3	66753	1	26376
26939	5	66754	6	26412
26940	5	66758	2	21675
26941	4	66759	2	9061
26942	3	66762	5	26494
26943	5	66766	4	26431
26944	5	66768	5	15853
26945	5	66768	4	15853
26946	5	66770	1	26556
26947	5	66773	6	22414
26948	4	66776	1	26513
26949	5	66777	4	16349
26950	5	66779	1	26380
26951	5	66782	2	26457
26952	3	66784	5	25342
26953	5	66788	6	21321
26954	5	66791	4	26538
26955	5	66791	3	26538
26956	5	66795	6	9841
26957	5	66798	7	26516
26958	4	66802	5	26458
26959	4	66804	7	285
26960	5	66808	2	26465
26961	5	66811	3	19100
26962	4	66813	1	24048
26963	3	66814	2	26534
26964	4	66815	2	26475
26965	4	66819	6	2386
26966	5	66820	7	13719
26967	5	66823	3	9554
26968	5	66825	3	9362
26969	5	66831	1	2238
26970	5	66832	2	20968
26971	5	66834	6	14463
26972	5	66835	7	26351
26973	3	66838	3	6168
26974	3	66839	7	5293
26975	5	66840	2	26350
26976	3	66841	5	3580
26977	5	66842	2	26496
26978	5	66843	3	24228
26979	4	66847	3	26395
26980	5	66848	2	16460
26981	4	66849	6	23405
26982	5	66850	4	26384
26983	3	66852	4	2017
26984	5	66852	6	2017
26985	5	66854	5	26374
26986	5	66856	1	10632
26987	3	66860	5	9598
26988	5	66860	1	9598
26989	3	66866	1	354
26990	4	66870	6	17794
26991	3	66871	7	26406
26992	3	66873	2	3285
26993	3	66876	5	26365
26994	5	66879	7	26345
26995	5	66880	2	13563
26996	5	66883	5	24349
26997	5	66886	2	26474
26998	4	66887	7	18610
26999	5	66888	6	25721
27000	5	66893	3	4368
27001	3	66894	5	26536
27002	3	66895	5	26417
27003	4	66896	4	26501
27004	5	66903	3	11774
27005	1	66904	6	26339
27006	4	66905	5	26386
27007	3	66907	5	13517
27008	5	66909	4	5041
27009	5	66910	6	26442
27010	5	66914	1	23512
27011	4	66915	6	14756
27012	3	66916	1	21434
27013	5	66917	3	18915
27014	5	66918	7	26410
27015	5	66919	4	26387
27016	5	66923	7	26355
27017	5	66924	2	19783
27018	5	66925	6	18457
27019	5	66926	5	6365
27020	4	66927	7	22888
27021	5	66928	4	26460
27022	4	66929	7	11014
27023	2	66930	1	26388
27024	4	66933	7	26506
27025	5	66934	2	2855
27026	5	66936	1	26071
27027	5	66938	5	26440
27028	5	66942	5	26333
27029	4	66943	3	26476
27030	5	66945	7	21664
27031	5	66946	2	26432
27032	5	66946	1	26432
27033	4	66947	4	26338
27034	5	66949	2	26448
27035	5	66950	4	26405
27036	2	66951	3	15731
27037	5	66952	7	23606
27038	5	66953	6	26512
27039	4	66954	7	26353
27040	5	66957	6	26429
27041	5	66958	2	26550
27042	4	66960	6	26389
27043	4	66961	4	26479
27044	5	66962	1	5994
27045	1	66963	6	9377
27046	5	66964	7	10673
27047	4	66966	7	26490
27048	5	66967	3	26466
27049	5	66970	3	5649
27050	5	66971	6	26394
27051	5	66972	1	26461
27052	5	66973	7	12701
27053	5	66974	7	26517
27054	4	66976	4	9259
27055	5	66977	7	7444
27056	5	66979	7	25364
27057	5	66981	4	15679
27058	5	66986	4	2907
27059	4	66990	3	26361
27060	5	66995	4	10872
27061	5	66996	6	5740
27062	5	66999	5	19926
27063	5	66999	7	19926
27064	1	67000	6	21167
27065	5	67001	2	1572
27066	4	67002	4	26334
27067	4	67008	7	26472
27068	5	67009	5	626
27069	5	67010	4	26464
27070	4	67011	7	26477
27071	4	67012	2	18227
27072	3	67013	2	14722
27073	3	67017	6	4546
27074	1	67020	6	12261
27075	5	67022	2	24229
27076	3	67024	4	9236
27077	3	67026	7	10129
27078	4	67029	3	26500
27079	5	67029	7	26500
27080	4	67031	1	10479
27081	5	67032	2	23844
27082	3	67033	5	26408
27083	5	67035	6	26346
27084	3	67036	4	20285
27085	5	67040	3	7250
27086	4	67042	4	12224
27087	1	67043	6	26499
27088	5	67045	2	26424
27089	3	67046	1	1862
27090	5	67047	4	26495
27091	4	67048	1	12039
27092	5	67051	2	26478
27093	5	67055	7	5527
27094	4	67059	2	21363
27095	4	67059	3	21363
27096	4	67060	4	23457
27097	3	67060	7	23457
27098	4	67061	1	8385
27099	5	67063	1	24807
27100	4	67065	3	26526
27101	4	67068	1	26467
27102	4	67070	6	21551
27103	4	67071	5	26548
27104	3	67072	2	12711
27105	5	67074	7	15768
27106	5	67075	2	6848
27107	5	67076	1	26504
27108	3	67079	7	26438
27109	4	67086	7	26422
27110	5	67089	4	7067
27111	3	67091	5	26473
27112	3	67094	1	6573
27113	3	67098	7	18643
27114	5	67099	4	3493
27115	4	67100	1	48
27116	4	67101	2	20910
27117	5	67103	6	26557
27118	3	67106	6	4355
27119	5	67108	2	26347
27120	5	67116	4	25573
27121	5	67117	5	14611
27122	4	67120	7	26544
27123	5	67123	2	22529
27124	4	67124	2	16324
27125	4	67127	4	7001
27126	5	67128	2	15383
27127	3	67129	7	1618
27128	3	67130	4	26456
27129	4	67133	5	13521
27130	5	67134	2	26409
27131	5	67135	4	26543
27132	4	67140	4	245
27133	1	67142	6	26437
27134	4	67143	2	14373
27135	3	67147	4	26488
27136	3	67148	1	3174
27137	5	67149	2	7891
27138	4	67150	6	19192
27139	5	67151	3	14625
27140	4	67153	6	8673
27141	5	67156	6	8656
27142	3	67159	7	15910
27143	4	67168	6	23551
27144	5	67169	4	552
27145	5	67170	6	26701
27146	3	67170	1	26701
27147	3	67172	4	26750
27148	5	67178	6	1756
27149	5	67183	6	9344
27150	5	67184	7	17941
27151	4	67188	7	16006
27152	5	67192	7	13623
27153	5	67193	5	26666
27154	5	67195	4	24350
27155	5	67196	1	26630
27156	4	67198	6	20841
27157	5	67199	1	4426
27158	5	67202	4	6553
27159	5	67203	2	21496
27160	5	67204	3	26610
27161	5	67207	2	26591
27162	4	67209	7	10083
27163	5	67209	2	10083
27164	5	67212	7	6215
27165	5	67213	7	13317
27166	5	67216	4	10880
27167	5	67219	6	4198
27168	5	67220	6	15903
27169	5	67227	5	21374
27170	5	67227	7	21374
27171	5	67230	5	26144
27172	1	67231	6	24047
27173	2	67233	1	8771
27174	5	67237	2	1789
27175	3	67239	5	3688
27176	5	67240	2	26570
27177	5	67241	6	7491
27178	2	67245	6	26679
27179	5	67246	4	26641
27180	4	67246	5	26641
27181	4	67248	7	26638
27182	5	67251	7	15888
27183	5	67256	1	3567
27184	4	67259	1	26703
27185	4	67260	5	26714
27186	5	67263	2	26593
27187	4	67263	4	26593
27188	4	67269	7	16498
27189	5	67277	1	5301
27190	5	67278	6	9318
27191	5	67280	6	20494
27192	3	67284	7	7710
27193	5	67285	4	7251
27194	5	67287	7	205
27195	4	67288	1	23484
27196	3	67292	6	26678
27197	1	67294	6	25512
27198	2	67295	1	8020
27199	3	67296	7	3535
27200	5	67298	1	5180
27201	5	67306	7	15371
27202	5	67310	6	4075
27203	5	67311	4	1303
27204	5	67314	6	8098
27205	5	67318	6	26612
27206	3	67321	7	13048
27207	5	67322	6	8600
27208	4	67323	7	26681
27209	5	67330	6	19973
27210	3	67334	1	26718
27211	4	67334	5	26718
27212	5	67336	5	19386
27213	4	67338	7	26676
27214	4	67346	5	26749
27215	5	67348	2	13453
27216	5	67351	3	26677
27217	5	67353	2	11254
27218	1	67354	6	17964
27219	5	67362	2	8024
27220	5	67363	2	13172
27221	3	67364	3	26603
27222	5	67367	6	17977
27223	4	67368	7	8683
27224	5	67372	7	1979
27225	5	67375	3	11834
27226	3	67378	1	2071
27227	4	67382	2	2170
27228	4	67385	2	22713
27229	5	67386	7	26608
27230	3	67395	7	26745
27231	5	67396	7	18700
27232	4	67397	6	5771
27233	5	67399	4	1343
27234	5	67400	7	26585
27235	5	67401	4	26615
27236	3	67402	3	5286
27237	2	67403	5	11535
27238	5	67404	3	26743
27239	5	67405	6	26493
27240	5	67408	1	26595
27241	4	67410	6	23990
27242	5	67414	6	9682
27243	5	67416	7	26675
27244	4	67417	2	25550
27245	4	67420	2	26707
27246	5	67421	6	3115
27247	5	67422	2	26644
27248	1	67423	7	13461
27249	5	67424	1	3230
27250	4	67428	3	21151
27251	3	67428	7	21151
27252	5	67430	6	12231
27253	5	67431	7	11835
27254	3	67432	4	8872
27255	5	67435	2	26696
27256	5	67438	2	9030
27257	2	67442	4	5449
27258	5	67446	6	4577
27259	4	67446	4	4577
27260	4	67447	4	26658
27261	5	67450	6	26625
27262	4	67452	6	3531
27263	5	67453	2	24727
27264	5	67455	2	16383
27265	4	67455	7	16383
27266	3	67460	5	25299
27267	5	67463	3	26702
27268	5	67467	6	26656
27269	4	67469	5	7709
27270	4	67470	3	18271
27271	3	67471	5	26640
27272	4	67472	2	26248
27273	5	67473	6	26583
27274	5	67475	6	26632
27275	5	67478	3	11806
27276	5	67482	7	26592
27277	5	67483	2	26621
27278	5	67484	1	26635
27279	5	67489	6	26596
27280	5	67504	2	26689
27281	4	67506	7	11934
27282	4	67507	1	26732
27283	5	67509	2	23552
27284	4	67513	7	7790
27285	3	67516	2	26662
27286	3	67517	4	10287
27287	5	67522	6	26617
27288	4	67523	7	23099
27289	2	67525	5	6019
27290	5	67526	7	17721
27291	5	67528	1	13355
27292	5	67532	1	11208
27293	4	67533	1	23006
27294	4	67534	7	26607
27295	3	67535	4	2252
27296	5	67536	2	1255
27297	3	67538	1	22871
27298	5	67541	6	26713
27299	3	67543	1	19767
27300	5	67545	4	26731
27301	5	67548	6	22535
27302	5	67552	6	17879
27303	3	67553	7	26587
27304	4	67556	7	412
27305	5	67559	6	22137
27306	5	67561	2	16422
27307	4	67563	3	26576
27308	4	67564	7	14504
27309	5	67569	4	26605
27310	5	67572	4	292
27311	4	67574	6	26343
27312	5	67581	1	6869
27313	5	67583	4	16037
27314	3	67587	7	19313
27315	3	67590	2	23764
27316	5	67594	5	26568
27317	4	67595	7	3911
27318	4	67596	5	26720
27319	5	67599	5	13371
27320	4	67600	7	26577
27321	5	67605	2	1514
27322	4	67605	6	1514
27323	1	67606	2	22201
27324	5	67609	5	12709
27325	4	67610	5	11600
27326	4	67611	2	22740
27327	4	67612	7	26700
27328	4	67615	6	5140
27329	3	67616	6	26751
27330	5	67617	6	5873
27331	4	67617	1	5873
27332	5	67621	7	15616
27333	3	67623	7	15244
27334	5	67626	7	23312
27335	4	67627	5	26581
27336	5	67628	3	26643
27337	3	67630	5	22912
27338	5	67631	4	4995
27339	5	67634	5	5527
27340	5	67637	5	22326
27341	4	67637	7	22326
27342	4	67639	7	26657
27343	4	67641	1	10988
27344	5	67646	7	17503
27345	5	67647	6	26627
27346	5	67649	6	22827
27347	3	67651	2	21862
27348	2	67652	4	10644
27349	5	67652	2	10644
27350	4	67653	3	15131
27351	5	67655	5	13613
27352	5	67657	6	25772
27353	5	67659	4	24663
27354	4	67659	1	24663
27355	5	67660	1	9011
27356	4	67660	7	9011
27357	5	67661	6	8934
27358	4	67667	4	4825
27359	3	67670	5	3858
27360	5	67675	6	9946
27361	5	67676	2	3314
27362	4	67677	3	7869
27363	4	67678	1	26740
27364	5	67679	4	26636
27365	4	67688	7	26730
27366	5	67689	2	12679
27367	5	67690	6	5817
27368	4	67692	3	19694
27369	5	67695	5	7419
27370	5	67699	7	26719
27371	4	67701	6	26664
27372	4	67703	5	10570
27373	5	67704	6	581
27374	4	67705	7	17268
27375	5	67706	1	737
27376	3	67709	7	26571
27377	5	67709	5	26571
27378	5	67710	6	7349
27379	3	67716	5	20398
27380	3	67716	6	20398
27381	4	67718	7	6367
27382	4	67722	7	8648
27383	3	67729	3	15603
27384	5	67735	6	10432
27385	5	67736	5	9727
27386	5	67737	2	3343
27387	3	67738	5	11999
27388	3	67741	6	20330
27389	4	67742	3	14454
27390	5	67746	2	21048
27391	5	67747	2	20835
27392	5	67751	7	2555
27393	3	67757	3	628
27394	5	67763	6	23747
27395	5	67768	6	26704
27396	4	67773	6	1166
27397	3	67774	1	26686
27398	4	67776	7	26606
27399	5	67781	2	26672
27400	5	67782	2	26682
27401	5	67784	1	12205
27402	4	67791	1	7988
27403	4	67792	7	8678
27404	3	67793	5	3578
27405	5	67795	4	113
27406	3	67796	1	18745
27407	5	67797	3	16909
27408	5	67803	4	20745
27409	2	67804	6	1941
27410	5	67806	3	23561
27411	5	67806	4	23561
27412	3	67807	1	26673
27413	4	67810	7	9278
27414	5	67813	3	2993
27415	5	67817	4	16672
27416	3	67818	3	19163
27417	4	67821	6	15901
27418	5	67825	7	15457
27419	5	67826	4	26932
27420	5	67828	2	8179
27421	5	67829	3	12489
27422	5	67830	6	13560
27423	5	67835	2	26951
27424	3	67836	5	26827
27425	5	67837	6	26770
27426	4	67839	5	9813
27427	5	67843	3	26913
27428	3	67844	7	26855
27429	5	67846	5	23871
27430	5	67849	5	26902
27431	4	67850	1	19212
27432	4	67852	5	8950
27433	5	67852	6	8950
27434	3	67856	1	26786
27435	5	67862	6	26795
27436	5	67863	5	26955
27437	3	67867	5	22377
27438	3	67870	4	26962
27439	3	67871	5	19428
27440	5	67874	2	17402
27441	3	67876	6	18343
27442	5	67882	2	11608
27443	4	67882	6	11608
27444	5	67883	2	23029
27445	3	67885	1	25533
27446	5	67887	6	17268
27447	3	67888	1	26938
27448	3	67892	5	26956
27449	5	67894	6	5936
27450	5	67895	2	26874
27451	3	67896	7	26862
27452	5	67898	2	18010
27453	5	67901	5	17799
27454	5	67902	6	25279
27455	5	67906	5	19019
27456	5	67910	7	26823
27457	5	67913	5	17937
27458	5	67916	1	18344
27459	5	67920	6	16524
27460	4	67927	7	26908
27461	5	67929	1	26866
27462	5	67930	1	24536
27463	5	67932	6	381
27464	1	67933	6	26826
27465	2	67935	4	16896
27466	4	67936	2	17895
27467	5	67936	4	17895
27468	5	67937	3	2672
27469	3	67940	5	26906
27470	5	67940	7	26906
27471	5	67943	7	21854
27472	4	67945	3	26963
27473	5	67949	3	23549
27474	5	67949	4	23549
27475	4	67951	7	26921
27476	5	67954	4	26812
27477	5	67957	7	379
27478	4	67959	5	16229
27479	5	67961	4	15563
27480	3	67962	7	7536
27481	4	67968	7	9266
27482	5	67969	2	6836
27483	2	67971	2	18223
27484	3	67972	7	2495
27485	5	67979	2	6835
27486	4	67982	1	24674
27487	5	67985	2	24943
27488	4	67987	7	13068
27489	4	67988	7	26777
27490	5	67989	6	6093
27491	5	67990	3	4967
27492	5	67992	1	25324
27493	4	67993	1	23831
27494	4	67995	4	5494
27495	4	67997	7	26801
27496	4	67998	1	4620
27497	5	67999	3	643
27498	5	68001	4	26837
27499	3	68001	2	26837
27500	5	68005	5	456
27501	4	68006	5	14295
27502	5	68008	7	13308
27503	5	68010	6	556
27504	5	68011	6	26818
27505	5	68012	6	26948
27506	5	68013	6	12912
27507	5	68019	1	6238
27508	5	68021	2	22845
27509	5	68023	6	1475
27510	5	68025	2	2420
27511	4	68026	1	16052
27512	4	68031	7	9977
27513	4	68032	2	26794
27514	4	68034	4	17527
27515	4	68035	6	18400
27516	3	68040	1	26934
27517	5	68040	2	26934
27518	2	68041	3	22774
27519	5	68052	6	4763
27520	5	68055	5	23935
27521	5	68058	3	13579
27522	5	68062	3	25363
27523	3	68064	3	18739
27524	1	68065	5	26833
27525	4	68066	7	15597
27526	5	68068	1	26754
27527	5	68070	2	26828
27528	5	68077	3	18565
27529	5	68078	6	26775
27530	5	68082	7	784
27531	5	68083	7	19566
27532	5	68087	6	26959
27533	4	68089	5	26804
27534	4	68090	6	6301
27535	4	68091	1	24672
27536	5	68094	7	24325
27537	5	68096	1	26846
27538	5	68097	3	11005
27539	5	68098	4	5050
27540	3	68101	5	26879
27541	5	68102	4	9485
27542	5	68103	6	5292
27543	3	68104	5	26761
27544	5	68106	7	7574
27545	4	68107	5	22640
27546	4	68107	3	22640
27547	4	68108	4	25089
27548	5	68109	6	26819
27549	3	68112	5	26802
27550	5	68114	7	24401
27551	5	68115	5	11696
27552	3	68117	4	12183
27553	4	68118	2	26900
27554	5	68119	5	26903
27555	3	68121	2	6746
27556	4	68123	3	25627
27557	3	68128	3	26930
27558	5	68132	7	6638
27559	5	68133	7	26925
27560	5	68134	4	26865
27561	3	68136	4	5293
27562	5	68141	4	26814
27563	3	68145	4	21089
27564	4	68146	5	19456
27565	3	68150	5	12772
27566	4	68151	1	26914
27567	2	68154	3	2434
27568	5	68155	4	26832
27569	5	68156	4	23790
27570	2	68157	4	4295
27571	4	68159	7	14175
27572	5	68162	6	27057
27573	5	68162	4	27057
27574	5	68166	4	27103
27575	5	68169	6	26295
27576	5	68173	6	26706
27577	5	68173	7	26706
27578	1	68177	6	21634
27579	5	68177	2	21634
27580	4	68180	6	23074
27581	5	68183	6	27089
27582	4	68183	7	27089
27583	5	68184	1	10746
27584	5	68185	4	27012
27585	5	68185	5	27012
27586	5	68188	6	4697
27587	5	68190	5	22259
27588	5	68190	2	22259
27589	1	68196	6	11276
27590	4	68201	4	27106
27591	4	68204	1	8700
27592	4	68207	5	17085
27593	5	68208	3	12615
27594	5	68211	6	23143
27595	4	68211	1	23143
27596	5	68212	3	22993
27597	4	68215	5	13326
27598	5	68215	7	13326
27599	3	68219	1	27164
27600	4	68222	5	21555
27601	5	68222	6	21555
27602	5	68223	1	27157
27603	5	68225	2	113
27604	5	68227	6	27101
27605	4	68230	5	3647
27606	4	68232	7	27046
27607	4	68232	5	27046
27608	3	68233	5	27152
27609	5	68234	7	14678
27610	4	68241	1	7137
27611	4	68243	5	27179
27612	5	68251	1	13634
27613	3	68253	7	11635
27614	5	68257	2	20378
27615	3	68258	1	19507
27616	1	68260	7	27027
27617	5	68264	3	1479
27618	2	68266	3	27166
27619	5	68269	3	26993
27620	5	68270	4	27070
27621	5	68271	7	4006
27622	4	68273	7	16508
27623	5	68276	4	13383
27624	3	68279	5	15118
27625	5	68280	6	27060
27626	4	68280	7	27060
27627	4	68281	7	2309
27628	2	68282	3	1536
27629	5	68283	1	27128
27630	5	68284	2	27120
27631	5	68287	3	4105
27632	4	68289	3	27099
27633	4	68295	1	12098
27634	3	68296	3	26977
27635	5	68297	6	12997
27636	3	68300	6	380
27637	3	68305	5	6561
27638	5	68310	5	2406
27639	5	68312	4	20325
27640	1	68313	4	27016
27641	5	68314	7	14072
27642	4	68317	2	24459
27643	5	68321	5	27083
27644	5	68322	7	6113
27645	3	68324	4	7118
27646	4	68326	5	6231
27647	5	68331	2	23356
27648	3	68335	5	26971
27649	5	68339	1	15679
27650	1	68344	6	6233
27651	5	68345	7	7934
27652	4	68347	6	25003
27653	5	68349	6	26984
27654	4	68350	3	2467
27655	5	68351	5	22633
27656	3	68351	7	22633
27657	3	68353	2	27085
27658	3	68359	7	21867
27659	4	68362	1	14422
27660	5	68364	6	27173
27661	5	68367	2	2927
27662	5	68369	5	5965
27663	5	68373	6	27118
27664	5	68378	7	23772
27665	5	68379	6	9021
27666	5	68389	7	27035
27667	5	68390	6	18321
27668	4	68391	4	20783
27669	5	68392	3	10780
27670	3	68393	5	7342
27671	5	68395	5	18499
27672	3	68401	5	13010
27673	3	68408	7	1151
27674	5	68408	6	1151
27675	1	68410	6	23588
27676	5	68415	4	23923
27677	5	68416	2	18057
27678	4	68419	4	27015
27679	4	68421	1	9901
27680	3	68426	1	27050
27681	3	68427	5	27071
27682	5	68428	1	14025
27683	5	68429	4	1964
27684	3	68429	2	1964
27685	4	68434	4	27161
27686	4	68437	3	24125
27687	5	68441	1	27065
27688	4	68442	1	27136
27689	5	68443	2	8873
27690	3	68446	3	8542
27691	5	68447	6	27007
27692	4	68448	4	27014
27693	3	68454	2	5107
27694	5	68454	4	5107
27695	5	68456	6	17837
27696	5	68459	1	27108
27697	2	68461	3	13218
27698	5	68462	7	26990
27699	5	68463	5	27153
27700	5	68464	5	16903
27701	3	68468	4	16498
27702	5	68469	2	26770
27703	5	68471	5	27110
27704	5	68474	4	27009
27705	3	68474	7	27009
27706	4	68478	5	16126
27707	2	68484	6	4834
27708	2	68490	3	6024
27709	4	68492	3	21779
27710	4	68498	6	26997
27711	3	68501	1	16682
27712	3	68510	3	27125
27713	4	68511	7	4398
27714	5	68512	1	27107
27715	5	68513	7	23637
27716	5	68517	2	338
27717	4	68518	7	27022
27718	4	68518	5	27022
27719	5	68521	6	27005
27720	3	68526	5	25861
27721	4	68532	4	18312
27722	5	68533	2	27068
27723	5	68538	2	27159
27724	5	68538	4	27159
27725	5	68540	4	24275
27726	5	68546	5	6152
27727	3	68549	3	5152
27728	4	68554	6	15924
27729	4	68555	5	21606
27730	5	68558	2	27116
27731	3	68560	4	14146
27732	5	68562	4	21079
27733	5	68566	2	27162
27734	5	68567	6	2690
27735	5	68569	7	26625
27736	5	68570	3	27078
27737	5	68572	6	27030
27738	3	68573	2	4567
27739	5	68575	6	3277
27740	5	68576	2	14039
27741	5	68577	2	17588
27742	3	68578	3	22684
27743	5	68579	7	1319
27744	5	68580	6	6326
27745	4	68581	5	5397
27746	4	68582	4	27178
27747	5	68583	5	23568
27748	5	68585	1	26734
27749	4	68586	3	25948
27750	3	68588	7	2507
27751	5	68589	2	26998
27752	5	68589	6	26998
27753	4	68590	5	15617
27754	5	68590	2	15617
27755	5	68591	5	23314
27756	3	68596	3	1956
27757	1	68599	5	26979
27758	5	68600	6	27024
27759	3	68601	7	26978
27760	5	68602	2	27067
27761	2	68603	4	26994
27762	5	68606	3	27222
27763	5	68608	6	4058
27764	5	68610	6	18493
27765	2	68611	1	27216
27766	5	68614	6	5053
27767	3	68614	5	5053
27768	5	68615	6	10434
27769	1	68616	4	27237
27770	4	68619	7	13858
27771	1	68621	6	26931
27772	3	68625	3	15321
27773	1	68631	6	3228
27774	1	68634	4	6321
27775	5	68639	1	1541
27776	3	68641	7	17335
27777	4	68644	7	27291
27778	5	68645	4	27355
27779	4	68649	5	5886
27780	5	68654	7	17892
27781	5	68655	4	27288
27782	4	68655	5	27288
27783	5	68656	7	25291
27784	4	68658	7	27294
27785	4	68661	1	27373
27786	3	68663	1	10029
27787	5	68665	7	21174
27788	5	68675	7	27384
27789	3	68676	1	27371
27790	4	68677	7	20818
27791	3	68681	7	27335
27792	3	68683	5	27392
27793	5	68684	6	20697
27794	4	68685	4	15143
27795	5	68687	5	9787
27796	5	68689	1	289
27797	5	68690	2	27374
27798	4	68692	6	22176
27799	5	68693	7	15786
27800	5	68694	6	27301
27801	5	68694	7	27301
27802	5	68695	6	5808
27803	5	68696	4	541
27804	5	68698	3	27207
27805	5	68701	2	27347
27806	3	68705	7	11118
27807	3	68707	4	22963
27808	5	68708	1	27368
27809	4	68710	2	14306
27810	5	68712	3	27204
27811	4	68715	5	27200
27812	5	68717	1	12024
27813	5	68719	3	3024
27814	4	68722	5	8494
27815	5	68724	1	16652
27816	5	68726	2	27364
27817	3	68727	5	27277
27818	3	68729	4	27201
27819	3	68730	7	24771
27820	5	68731	5	17304
27821	3	68732	2	11352
27822	4	68733	7	7009
27823	5	68737	5	17534
27824	5	68738	3	27385
27825	5	68739	7	3372
27826	5	68741	4	27191
27827	3	68748	5	27267
27828	5	68749	2	26510
27829	3	68751	1	27341
27830	5	68752	3	16423
27831	5	68754	7	27323
27832	3	68760	5	20579
27833	5	68761	4	14711
27834	1	68762	6	1839
27835	4	68763	4	9715
27836	1	68769	6	27349
27837	4	68772	7	19282
27838	4	68774	7	27239
27839	5	68776	5	27271
27840	4	68777	4	9960
27841	5	68780	1	27274
27842	5	68785	5	16091
27843	5	68786	4	27308
27844	5	68790	6	27337
27845	5	68794	7	7739
27846	5	68795	6	9966
27847	4	68796	3	16162
27848	5	68799	3	27202
27849	5	68800	6	27262
27850	5	68801	7	12248
27851	5	68803	2	27362
27852	5	68809	4	2068
27853	5	68811	1	5912
27854	3	68812	3	13621
27855	5	68820	2	12327
27856	5	68820	3	12327
27857	5	68822	3	5116
27858	5	68827	6	3659
27859	1	68828	6	27287
27860	4	68830	3	12183
27861	4	68832	5	12242
27862	5	68833	2	13413
27863	5	68834	3	9925
27864	5	68836	4	27390
27865	4	68836	7	27390
27866	5	68841	6	27228
27867	5	68842	2	22451
27868	3	68844	5	27381
27869	5	68848	2	27197
27870	5	68849	4	27342
27871	4	68852	1	6727
27872	5	68855	3	27333
27873	5	68861	3	18386
27874	4	68864	7	4590
27875	5	68866	7	5503
27876	5	68871	6	27313
27877	3	68877	1	314
27878	4	68881	4	27206
27879	3	68883	7	27352
27880	2	68890	3	20948
27881	5	68899	4	401
27882	5	68903	1	17691
27883	5	68908	2	19365
27884	5	68913	7	540
27885	1	68918	6	27293
27886	5	68920	3	27273
27887	5	68921	1	20852
27888	5	68924	3	27382
27889	4	68927	5	6281
27890	5	68928	1	1593
27891	5	68930	5	19524
27892	3	68931	7	25681
27893	3	68932	4	27241
27894	5	68933	1	27187
27895	4	68935	2	27311
27896	4	68940	1	3785
27897	4	68945	1	19075
27898	4	68946	4	13991
27899	5	68947	6	2439
27900	3	68950	7	9861
27901	5	68956	7	27212
27902	3	68961	7	12942
27903	4	68962	2	27365
27904	5	68966	6	17908
27905	4	68969	7	18770
27906	5	68974	2	27303
27907	3	68976	7	7318
27908	5	68987	2	25171
27909	5	68990	6	11924
27910	3	68991	6	2873
27911	5	68992	6	8655
27912	3	68998	3	27184
27913	5	68999	3	27268
27914	4	69000	6	8412
27915	2	69005	6	27302
27916	5	69006	1	18390
27917	5	69012	3	4652
27918	5	69018	7	10704
27919	4	69020	2	27324
27920	5	69021	2	8120
27921	4	69021	3	8120
27922	4	69024	6	21770
27923	3	69029	7	5788
27924	5	69031	1	22511
27925	5	69033	2	20985
27926	5	69035	1	27214
27927	4	69036	4	27275
27928	5	69041	1	27230
27929	5	69042	4	21894
27930	5	69049	7	27189
27931	5	69051	6	5639
27932	3	69057	2	27379
27933	5	69058	2	11983
27934	3	69059	5	27397
27935	5	69060	1	27229
27936	4	69067	2	7060
27937	2	69072	4	27289
27938	5	69073	7	27389
27939	5	69074	1	4217
27940	5	69077	5	27314
27941	4	69081	7	12250
27942	5	69082	3	1409
27943	5	69083	5	27292
27944	3	69085	6	20506
27945	2	69087	3	27307
27946	5	69091	5	11148
27947	5	69092	1	15229
27948	5	69095	2	14022
27949	3	69096	5	27278
27950	5	69097	4	27329
27951	4	69100	1	19818
27952	3	69101	6	3028
27953	4	69106	2	27357
27954	5	69108	6	18690
27955	1	69113	4	15361
27956	5	69114	4	8170
27957	5	69117	6	27224
27958	1	69118	6	21601
27959	1	69122	6	18671
27960	5	69123	3	17594
27961	3	69125	4	27360
27962	4	69127	3	7030
27963	5	69135	7	27317
27964	4	69138	6	27188
27965	5	69140	7	27182
27966	5	69141	6	24121
27967	4	69150	6	9243
27968	3	69151	5	5699
27969	5	69154	2	27491
27970	5	69160	4	9760
27971	5	69162	4	27422
27972	4	69166	3	5886
27973	5	69168	6	27471
27974	3	69172	5	1207
27975	3	69173	1	27006
27976	5	69175	7	18351
27977	5	69176	4	27535
27978	4	69181	3	14069
27979	5	69182	7	11342
27980	4	69183	4	27503
27981	5	69184	3	16272
27982	5	69185	1	20400
27983	1	69188	6	24062
27984	4	69193	7	19280
27985	5	69195	6	27519
27986	5	69196	1	27516
27987	5	69198	1	26862
27988	5	69199	6	27440
27989	5	69202	7	16311
27990	3	69213	3	8018
27991	4	69216	6	27477
27992	5	69217	6	16464
27993	5	69219	6	17326
27994	1	69222	6	26928
27995	5	69224	6	22901
27996	3	69226	5	8813
27997	5	69227	4	8341
27998	5	69228	2	27560
27999	3	69237	5	5817
28000	5	69239	1	5920
28001	4	69240	7	11314
28002	3	69242	3	27478
28003	3	69245	7	19553
28004	5	69246	2	10710
28005	3	69247	1	27306
28006	5	69247	5	27306
28007	5	69248	1	18445
28008	5	69252	6	2683
28009	4	69253	7	27532
28010	3	69256	5	27527
28011	4	69263	6	27502
28012	5	69264	4	27443
28013	4	69267	4	17882
28014	4	69268	5	24292
28015	5	69272	4	27552
28016	5	69274	7	13303
28017	3	69280	2	27528
28018	5	69281	6	19953
28019	4	69281	2	19953
28020	4	69284	4	24547
28021	4	69288	5	6738
28022	2	69289	3	4682
28023	4	69292	4	197
28024	1	69295	6	20999
28025	3	69297	5	314
28026	4	69302	3	1801
28027	3	69304	7	1380
28028	3	69306	3	27411
28029	5	69308	6	2443
28030	3	69309	5	27547
28031	4	69310	5	27409
28032	3	69312	5	18173
28033	5	69313	4	477
28034	5	69314	2	8616
28035	5	69315	2	27498
28036	5	69316	2	27455
28037	5	69316	3	27455
28038	3	69317	6	27545
28039	5	69321	2	1700
28040	4	69325	6	10528
28041	3	69326	5	27425
28042	5	69332	2	13694
28043	5	69333	4	27401
28044	5	69336	6	9896
28045	5	69338	5	27542
28046	5	69341	4	9395
28047	4	69343	7	16891
28048	5	69344	3	9942
28049	5	69346	7	14110
28050	5	69346	1	14110
28051	3	69350	7	27569
28052	3	69351	3	4403
28053	4	69352	3	18132
28054	5	69356	1	13930
28055	4	69360	7	15591
28056	5	69367	4	11018
28057	3	69368	7	12565
28058	3	69369	3	3198
28059	4	69372	7	27465
28060	3	69374	5	19163
28061	5	69376	1	23697
28062	5	69379	2	27463
28063	4	69388	6	22477
28064	5	69390	5	1684
28065	5	69392	4	27446
28066	5	69393	5	27400
28067	4	69396	7	15104
28068	5	69397	4	12836
28069	5	69398	5	19646
28070	4	69399	5	27531
28071	5	69400	6	14323
28072	3	69407	5	13528
28073	5	69408	1	10058
28074	5	69414	1	2783
28075	5	69415	3	19944
28076	1	69417	6	7478
28077	5	69419	6	19806
28078	5	69421	5	4898
28079	5	69421	4	4898
28080	4	69424	1	17805
28081	4	69427	5	11518
28082	5	69428	5	27480
28083	5	69431	4	27538
28084	5	69441	4	11083
28085	4	69442	5	11004
28086	5	69443	3	27550
28087	4	69448	1	9935
28088	1	69449	7	27424
28089	3	69454	3	27445
28090	4	69455	7	12484
28091	5	69456	4	27437
28092	5	69457	6	19638
28093	5	69459	2	2504
28094	5	69463	5	27449
28095	4	69464	3	21496
28096	2	69465	4	1387
28097	5	69467	4	27452
28098	4	69471	2	22436
28099	4	69472	6	23519
28100	5	69473	3	27456
28101	5	69474	6	23208
28102	5	69475	6	7451
28103	5	69476	1	27405
28104	5	69480	3	21854
28105	5	69480	6	21854
28106	3	69481	5	6820
28107	5	69482	7	12942
28108	5	69486	2	27506
28109	4	69489	5	992
28110	3	69497	4	27421
28111	5	69503	1	20276
28112	5	69504	1	19892
28113	4	69505	7	27559
28114	5	69506	6	20697
28115	4	69507	5	3343
28116	5	69508	7	2901
28117	5	69510	1	21063
28118	5	69510	5	21063
28119	5	69512	4	25296
28120	5	69513	4	27442
28121	5	69514	6	20877
28122	5	69519	5	27563
28123	5	69523	3	1032
28124	4	69526	4	24987
28125	4	69527	4	27481
28126	4	69528	1	378
28127	4	69529	3	13906
28128	5	69531	4	27427
28129	5	69532	6	25524
28130	3	69533	4	27433
28131	5	69534	6	6319
28132	5	69535	2	10519
28133	5	69536	2	19476
28134	5	69537	4	18850
28135	5	69541	2	9051
28136	5	69543	3	684
28137	5	69544	2	13479
28138	3	69545	3	21759
28139	4	69549	5	21600
28140	4	69552	4	27436
28141	5	69554	5	7431
28142	4	69555	1	12935
28143	4	69556	1	1223
28144	2	69558	6	3284
28145	5	69561	1	27426
28146	4	69562	6	14202
28147	5	69564	2	11618
28148	4	69568	7	17823
28149	5	69570	4	27418
28150	5	69571	5	25228
28151	5	69576	7	27504
28152	5	69578	7	11857
28153	5	69581	7	27403
28154	5	69584	4	27482
28155	5	69588	7	27423
28156	5	69592	6	3155
28157	5	69593	5	1468
28158	4	69594	3	3617
28159	4	69595	6	9774
28160	5	69597	6	27441
28161	5	69600	4	11921
28162	3	69601	5	27507
28163	5	69602	1	27525
28164	3	69602	7	27525
28165	4	69604	5	8801
28166	5	69605	4	9657
28167	4	69606	3	11232
28168	5	69607	6	27490
28169	5	69612	4	17769
28170	5	69619	6	6080
28171	3	69621	7	23318
28172	1	69623	6	24
28173	4	69636	5	12098
28174	5	69639	1	14528
28175	5	69642	6	22385
28176	4	69643	1	26152
28177	5	69650	6	12675
28178	5	69651	6	799
28179	3	69655	7	27716
28180	5	69656	2	15230
28181	5	69657	4	27705
28182	3	69658	1	17610
28183	3	69660	4	27626
28184	5	69661	2	21372
28185	5	69663	2	26361
28186	3	69664	4	5156
28187	3	69667	7	27682
28188	5	69668	4	19229
28189	4	69673	1	2338
28190	5	69673	4	2338
28191	3	69677	1	27638
28192	5	69679	1	3382
28193	4	69680	4	27656
28194	5	69681	1	2862
28195	4	69682	3	26247
28196	5	69684	4	4488
28197	5	69686	4	22287
28198	5	69687	2	482
28199	5	69688	1	1901
28200	5	69690	1	27731
28201	4	69691	4	9184
28202	5	69694	6	27619
28203	5	69695	7	27579
28204	4	69696	1	9478
28205	5	69700	6	19502
28206	3	69701	5	27637
28207	5	69705	7	27737
28208	5	69706	6	27665
28209	3	69709	5	15350
28210	5	69711	2	13042
28211	3	69714	5	12848
28212	4	69716	6	27676
28213	4	69717	5	12993
28214	3	69718	4	27612
28215	5	69724	6	23022
28216	4	69728	4	7348
28217	4	69729	7	27724
28218	4	69732	2	7164
28219	5	69733	2	25675
28220	3	69736	7	27603
28221	5	69742	1	27749
28222	5	69747	1	23535
28223	3	69748	7	1988
28224	5	69749	7	7035
28225	5	69750	7	446
28226	4	69751	2	17211
28227	4	69751	6	17211
28228	5	69753	1	27709
28229	4	69754	5	8402
28230	5	69755	6	26959
28231	2	69758	7	3454
28232	5	69760	7	24135
28233	5	69761	1	27636
28234	5	69762	7	27738
28235	3	69763	3	21607
28236	5	69765	5	27690
28237	5	69766	3	11215
28238	4	69767	5	27652
28239	5	69768	4	745
28240	3	69770	5	27721
28241	5	69770	3	27721
28242	5	69772	4	27732
28243	5	69773	6	13880
28244	3	69776	3	27627
28245	5	69780	6	2067
28246	5	69781	4	27585
28247	4	69782	3	20226
28248	5	69793	1	11756
28249	5	69795	4	5141
28250	5	69797	6	27672
28251	5	69800	1	27625
28252	5	69802	4	7859
28253	5	69804	1	5077
28254	5	69808	6	27762
28255	3	69810	6	26436
28256	4	69811	5	5959
28257	5	69812	6	27618
28258	5	69812	2	27618
28259	5	69817	6	27629
28260	1	69817	7	27629
28261	5	69818	1	23268
28262	4	69819	7	11389
28263	4	69819	1	11389
28264	3	69821	7	27663
28265	3	69824	5	27623
28266	5	69829	2	15534
28267	5	69831	4	27320
28268	5	69833	7	27620
28269	4	69836	2	7253
28270	3	69840	1	3459
28271	5	69844	3	6609
28272	4	69848	6	25425
28273	4	69851	5	27651
28274	3	69853	7	14354
28275	5	69859	6	12132
28276	4	69863	7	27581
28277	4	69866	1	10393
28278	3	69868	7	4644
28279	5	69869	1	7963
28280	4	69872	2	815
28281	4	69876	7	6552
28282	5	69878	6	27689
28283	1	69879	6	27649
28284	1	69880	7	4206
28285	4	69883	6	27763
28286	5	69885	5	27633
28287	1	69886	3	27318
28288	5	69895	1	188
28289	5	69896	6	13213
28290	4	69899	5	27765
28291	5	69903	7	17571
28292	1	69904	1	15013
28293	3	69905	5	27622
28294	4	69908	2	27605
28295	5	69910	1	24653
28296	5	69912	6	27583
28297	3	69917	4	23924
28298	5	69918	6	27719
28299	5	69925	6	27706
28300	5	69926	2	16957
28301	4	69927	1	20396
28302	3	69928	5	26072
28303	5	69929	5	10937
28304	3	69930	5	1079
28305	4	69931	4	10499
28306	5	69932	3	12552
28307	5	69935	1	20573
28308	5	69945	2	13767
28309	5	69946	6	18692
28310	3	69947	5	16679
28311	4	69948	2	27621
28312	5	69952	2	7444
28313	5	69952	5	7444
28314	5	69953	5	6273
28315	5	69956	7	27702
28316	5	69957	7	23904
28317	2	69959	6	27643
28318	5	69960	5	26911
28319	5	69964	5	16914
28320	5	69971	2	24500
28321	5	69974	5	18103
28322	5	69974	7	18103
28323	5	69979	6	27639
28324	5	69982	2	5070
28325	4	69985	1	27734
28326	5	69987	7	19750
28327	5	69992	3	6722
28328	3	69994	4	12592
28329	4	69995	2	360
28330	1	69996	6	23424
28331	3	70002	2	8801
28332	3	70004	6	24618
28333	4	70007	6	22014
28334	3	70010	5	20684
28335	5	70012	2	22022
28336	5	70013	4	27691
28337	5	70015	3	4655
28338	5	70016	2	21600
28339	5	70018	6	18871
28340	1	70019	6	16754
28341	4	70020	1	5701
28342	4	70021	5	16608
28343	5	70024	7	27604
28344	5	70024	5	27604
28345	4	70025	6	27686
28346	5	70026	6	13089
28347	5	70028	6	27631
28348	4	70030	7	3463
28349	5	70034	2	2562
28350	5	70039	5	11419
28351	5	70046	7	6070
28352	5	70047	7	13667
28353	5	70048	5	2443
28354	3	70049	6	13975
28355	5	70051	6	27692
28356	5	70056	4	27650
28357	5	70058	3	13344
28358	3	70059	5	27571
28359	4	70061	1	4155
28360	3	70070	3	25003
28361	5	70071	1	27848
28362	5	70073	3	13522
28363	5	70073	5	13522
28364	5	70075	1	3688
28365	5	70083	5	27959
28366	4	70087	4	2063
28367	3	70088	1	27962
28368	2	70092	4	11519
28369	5	70093	2	27860
28370	5	70095	5	3703
28371	5	70101	7	27410
28372	5	70101	3	27410
28373	4	70102	5	16498
28374	4	70104	4	27845
28375	4	70106	1	27768
28376	3	70108	6	1021
28377	4	70110	3	14423
28378	3	70112	5	18714
28379	5	70113	5	27687
28380	4	70116	7	27776
28381	5	70120	4	5886
28382	5	70120	6	5886
28383	3	70124	5	27828
28384	5	70125	5	27882
28385	3	70128	5	5001
28386	5	70129	2	24482
28387	5	70130	7	3227
28388	5	70131	3	13193
28389	5	70133	6	15020
28390	4	70138	7	23074
28391	5	70139	7	5460
28392	5	70142	6	27915
28393	5	70144	6	17790
28394	5	70146	4	27792
28395	5	70155	4	8616
28396	5	70158	6	27814
28397	3	70159	1	27857
28398	4	70162	3	16867
28399	4	70164	4	8620
28400	5	70165	2	27196
28401	1	70168	6	27825
28402	4	70169	2	25302
28403	1	70170	6	10635
28404	3	70177	3	11454
28405	4	70178	4	16301
28406	5	70180	1	27976
28407	5	70181	7	27902
28408	5	70182	5	1794
28409	5	70186	6	27116
28410	4	70188	1	27821
28411	4	70189	5	27931
28412	5	70190	6	24745
28413	4	70193	1	4995
28414	5	70195	5	13855
28415	5	70197	5	27917
28416	2	70199	6	27770
28417	4	70202	2	16752
28418	2	70207	3	3364
28419	3	70209	7	23910
28420	3	70210	6	27856
28421	5	70211	1	13930
28422	3	70212	7	4450
28423	3	70213	5	27942
28424	5	70214	5	27842
28425	5	70216	3	27867
28426	5	70219	6	4473
28427	5	70220	3	11451
28428	4	70222	7	27953
28429	1	70223	6	10991
28430	5	70224	5	4857
28431	5	70225	4	11323
28432	3	70232	5	25446
28433	3	70233	3	27879
28434	5	70239	4	16831
28435	5	70241	2	17500
28436	5	70242	6	27918
28437	4	70242	7	27918
28438	5	70243	6	21322
28439	4	70244	7	27781
28440	5	70245	2	6003
28441	5	70248	1	22900
28442	5	70252	4	16346
28443	5	70254	7	17405
28444	5	70261	6	20489
28445	5	70265	4	26324
28446	5	70268	1	6641
28447	5	70269	5	9001
28448	3	70271	5	27970
28449	4	70272	2	1651
28450	3	70281	3	27949
28451	3	70283	5	8431
28452	5	70285	6	27885
28453	5	70287	3	8332
28454	3	70288	7	8664
28455	3	70289	5	18683
28456	4	70290	2	27881
28457	5	70291	1	27967
28458	2	70292	6	23594
28459	4	70293	5	27
28460	4	70294	2	27889
28461	5	70296	6	27816
28462	3	70302	5	22678
28463	4	70306	5	13187
28464	5	70310	2	21089
28465	5	70311	6	27886
28466	4	70315	7	23928
28467	5	70317	4	23982
28468	5	70318	4	17481
28469	5	70322	5	21162
28470	5	70325	2	27961
28471	5	70325	6	27961
28472	5	70327	2	20925
28473	5	70331	4	27836
28474	5	70332	3	27945
28475	5	70334	6	27818
28476	4	70335	1	6080
28477	3	70337	5	5473
28478	5	70339	5	27964
28479	5	70339	6	27964
28480	3	70340	3	10828
28481	5	70342	2	7280
28482	5	70343	7	3507
28483	4	70346	3	26255
28484	5	70349	6	20817
28485	5	70350	6	27919
28486	5	70351	6	17838
28487	5	70353	4	23528
28488	5	70355	6	20994
28489	4	70357	6	23338
28490	4	70358	5	27787
28491	3	70362	3	23681
28492	5	70363	4	27965
28493	5	70364	6	27832
28494	5	70371	6	27852
28495	4	70372	7	292
28496	4	70374	2	11874
28497	5	70376	2	27955
28498	5	70378	2	16295
28499	5	70379	3	3450
28500	3	70385	5	12935
28501	3	70395	4	27869
28502	4	70397	7	3169
28503	5	70398	5	4429
28504	5	70399	6	25420
28505	3	70400	4	10457
28506	4	70404	4	24943
28507	5	70405	4	738
28508	1	70406	6	27791
28509	3	70408	1	14775
28510	5	70413	7	16749
28511	3	70417	4	37
28512	5	70418	4	5379
28513	4	70420	7	16440
28514	4	70423	5	27843
28515	4	70426	1	6113
28516	5	70428	1	27951
28517	3	70429	3	27892
28518	4	70430	2	2870
28519	5	70431	2	27788
28520	3	70433	4	3492
28521	5	70435	3	7536
28522	5	70436	3	17687
28523	5	70438	6	27808
28524	2	70440	4	24884
28525	5	70442	5	26999
28526	4	70443	5	27804
28527	4	70444	5	27864
28528	5	70445	3	13936
28529	5	70445	4	13936
28530	4	70446	5	5378
28531	5	70446	4	5378
28532	5	70450	6	21770
28533	4	70454	7	5380
28534	5	70455	6	8177
28535	4	70456	7	27973
28536	4	70457	7	27926
28537	3	70460	5	9011
28538	4	70461	5	20372
28539	3	70463	7	27948
28540	5	70465	7	1780
28541	3	70469	5	27872
28542	5	70474	5	26567
28543	5	70481	7	13858
28544	4	70483	2	19006
28545	4	70484	4	27846
28546	5	70485	7	27851
28547	4	70487	7	19959
28548	5	70487	2	19959
28549	5	70488	5	27827
28550	5	70488	2	27827
28551	4	70489	7	24326
28552	5	70491	3	1684
28553	5	70495	6	19380
28554	5	70496	2	27876
28555	5	70497	2	6539
28556	4	70501	5	7206
28557	5	70503	5	27801
28558	5	70508	3	5478
28559	4	70508	5	5478
28560	3	70510	5	15407
28561	5	70513	2	27930
28562	5	70514	6	3950
28563	5	70515	6	21107
28564	4	70519	1	5553
28565	3	70520	7	27871
28566	4	70521	2	27944
28567	4	70523	1	3293
28568	5	70524	2	27847
28569	5	70525	4	27849
28570	3	70526	7	18050
28571	5	70529	2	10433
28572	4	70532	7	27817
28573	4	70533	7	6231
28574	3	70533	6	6231
28575	3	70535	3	4551
28576	3	70538	4	27923
28577	5	70539	4	27772
28578	2	70547	1	2987
28579	3	70548	1	3066
28580	3	70549	5	24276
28581	5	70549	1	24276
28582	5	70551	3	27780
28583	3	70552	1	27850
28584	3	70554	7	27771
28585	4	70561	7	17094
28586	5	70567	5	27890
28587	5	70568	1	13424
28588	1	70570	2	27971
28589	4	70573	5	26068
28590	5	70574	4	22841
28591	5	70575	6	27943
28592	5	70576	2	27854
28593	3	70582	5	18007
28594	5	70583	6	397
28595	4	70585	6	7125
28596	3	70587	5	23998
28597	5	70588	7	27773
28598	5	70590	3	15511
28599	5	70592	6	17805
28600	5	70593	5	23926
28601	4	70596	4	23978
28602	5	70597	5	18688
28603	2	70604	6	53
28604	3	70605	3	13771
28605	5	70608	7	6714
28606	5	70610	2	4760
28607	5	70611	6	17678
28608	5	70613	4	2967
28609	5	70615	3	17353
28610	4	70617	2	27809
28611	5	70619	3	27779
28612	5	70620	6	21620
28613	3	70622	5	27799
28614	5	70624	6	8113
28615	4	70628	7	18064
28616	5	70628	5	18064
28617	4	70630	5	6470
28618	5	70633	2	27893
28619	4	70639	3	1885
28620	4	70642	7	16839
28621	5	70643	2	16239
28622	5	70645	5	26754
28623	5	70645	2	26754
28624	4	70647	6	7798
28625	3	70648	5	4248
28626	5	70649	2	27797
28627	5	70653	4	2139
28628	5	70654	5	5794
28629	5	70656	6	11979
28630	4	70657	6	2909
28631	4	70663	6	17027
28632	2	70666	4	20215
28633	4	70669	7	19056
28634	4	70671	5	10281
28635	5	70676	6	27660
28636	3	70677	7	18863
28637	4	70677	5	18863
28638	5	70682	1	1705
28639	5	70685	2	4097
28640	3	70687	1	21393
28641	1	70689	4	27805
28642	5	70690	4	27839
28643	3	70699	5	19463
28644	4	70700	3	27956
28645	5	70700	4	27956
28646	3	70702	7	17415
28647	5	70703	5	27097
28648	3	70705	3	4683
28649	4	70706	4	27911
28650	4	70707	5	28136
28651	5	70710	2	5527
28652	4	70714	3	28121
28653	3	70716	2	12690
28654	4	70722	2	27217
28655	5	70723	7	2748
28656	3	70724	7	28055
28657	5	70728	5	28152
28658	5	70729	6	28085
28659	5	70731	2	28009
28660	5	70732	4	17562
28661	4	70733	1	27987
28662	1	70735	6	27980
28663	1	70739	3	9716
28664	4	70741	3	28131
28665	4	70743	7	28078
28666	5	70743	6	28078
28667	5	70744	7	28114
28668	5	70744	6	28114
28669	3	70746	2	28148
28670	5	70750	6	28139
28671	5	70753	1	27589
28672	3	70756	2	12185
28673	3	70757	3	13455
28674	3	70758	1	28102
28675	5	70761	4	7119
28676	5	70762	2	10268
28677	5	70764	2	28112
28678	3	70764	3	28112
28679	5	70765	3	2564
28680	4	70767	7	9523
28681	4	70768	5	28030
28682	5	70770	3	10857
28683	4	70770	7	10857
28684	3	70771	4	28089
28685	5	70773	2	2556
28686	5	70774	6	23614
28687	4	70776	2	28086
28688	5	70777	7	22639
28689	4	70779	4	15567
28690	5	70779	1	15567
28691	3	70781	5	12815
28692	5	70786	6	24413
28693	5	70787	2	1269
28694	5	70788	7	16346
28695	1	70790	6	2695
28696	1	70793	6	21201
28697	5	70795	2	2827
28698	5	70796	2	23507
28699	5	70800	2	3971
28700	5	70801	7	27114
28701	4	70802	6	28082
28702	5	70803	1	28068
28703	5	70806	1	5144
28704	4	70807	7	5664
28705	3	70814	3	5661
28706	4	70815	3	8748
28707	5	70824	5	14366
28708	4	70826	6	28058
28709	3	70827	2	27011
28710	4	70827	5	27011
28711	5	70829	7	1654
28712	4	70832	1	27951
28713	5	70834	2	21700
28714	4	70835	6	28035
28715	4	70839	6	17421
28716	5	70840	4	28099
28717	4	70841	3	16754
28718	5	70842	6	28145
28719	4	70845	7	8799
28720	5	70847	4	22534
28721	4	70853	2	27992
28722	5	70854	2	23551
28723	1	70855	6	16107
28724	5	70856	5	17288
28725	5	70857	7	17446
28726	4	70858	2	12502
28727	5	70859	7	28023
28728	5	70862	2	27970
28729	4	70870	6	7048
28730	2	70872	3	28018
28731	5	70874	5	15083
28732	5	70876	7	8993
28733	5	70878	5	5817
28734	4	70879	7	25018
28735	3	70882	3	28065
28736	4	70885	4	8394
28737	5	70886	4	22090
28738	3	70888	2	7491
28739	4	70889	7	18821
28740	5	70896	4	1215
28741	3	70898	1	22177
28742	4	70899	7	13859
28743	5	70900	3	21175
28744	5	70902	6	17031
28745	3	70907	5	28128
28746	4	70908	7	16732
28747	4	70909	7	9206
28748	1	70910	6	28024
28749	5	70912	1	9996
28750	5	70915	2	28022
28751	4	70919	6	23615
28752	5	70920	4	28087
28753	4	70924	1	28014
28754	3	70924	4	28014
28755	5	70927	3	28138
28756	5	70928	6	27918
28757	4	70929	5	28122
28758	5	70930	6	22680
28759	3	70932	4	2708
28760	4	70933	5	14702
28761	4	70933	7	14702
28762	5	70935	4	7279
28763	5	70939	6	17488
28764	4	70944	7	28142
28765	5	70949	6	10652
28766	3	70955	5	28039
28767	3	70958	2	17734
28768	4	70958	7	17734
28769	5	70962	4	28071
28770	3	70963	3	28123
28771	5	70964	7	7717
28772	2	70967	4	28107
28773	5	70968	5	27289
28774	1	70969	2	28075
28775	3	70972	4	13634
28776	5	70974	5	23831
28777	3	70975	5	10851
28778	3	70978	7	10670
28779	5	70980	1	23835
28780	5	70981	6	6158
28781	4	70985	5	28109
28782	3	70988	3	5520
28783	3	70989	1	28127
28784	5	70990	2	18102
28785	2	70991	6	25891
28786	5	70992	2	4872
28787	4	70993	4	23244
28788	5	70995	7	28004
28789	5	70996	4	5625
28790	3	70998	4	28044
28791	3	71000	2	24755
28792	5	71000	7	24755
28793	4	71003	2	28007
28794	5	71004	2	28001
28795	4	71004	5	28001
28796	3	71006	7	28066
28797	3	71006	3	28066
28798	5	71007	4	3708
28799	5	71009	4	27997
28800	4	71012	7	21188
28801	5	71015	6	28133
28802	4	71017	1	8323
28803	4	71018	2	19862
28804	4	71022	3	28141
28805	4	71023	7	210
28806	5	71027	3	13258
28807	2	71029	1	28051
28808	3	71030	3	5272
28809	4	71032	7	26096
28810	5	71033	6	18936
28811	5	71036	7	14812
28812	5	71038	6	5155
28813	4	71038	3	5155
28814	3	71039	1	25507
28815	5	71042	6	12841
28816	3	71043	4	28073
28817	3	71044	2	7222
28818	4	71047	2	7688
28819	4	71048	2	28008
28820	5	71048	6	28008
28821	5	71049	6	12447
28822	5	71052	2	26478
28823	4	71054	7	28084
28824	5	71055	2	28063
28825	4	71057	7	10002
28826	5	71059	4	4646
28827	5	71062	6	28003
28828	3	71065	7	24405
28829	5	71069	1	3570
28830	3	71073	5	28000
28831	5	71076	3	5110
28832	5	71078	2	47
28833	4	71079	2	9136
28834	5	71080	4	16592
28835	5	71088	2	15239
28836	4	71090	1	9439
28837	3	71090	5	9439
28838	5	71091	4	18755
28839	3	71093	5	28092
28840	5	71095	6	17189
28841	5	71096	6	14705
28842	5	71097	3	17968
28843	5	71098	6	25299
28844	4	71098	3	25299
28845	3	71100	7	11183
28846	4	71102	6	28149
28847	3	71103	1	28040
28848	5	71105	7	28120
28849	5	71107	2	1919
28850	1	71108	6	11543
28851	4	71110	6	28072
28852	4	71111	4	23509
28853	3	71112	7	14449
28854	5	71115	6	15159
28855	5	71117	6	15394
28856	4	71121	6	14290
28857	5	71122	1	3293
28858	3	71123	2	12745
28859	3	71125	1	2126
28860	4	71126	6	9139
28861	4	71126	5	9139
28862	5	71127	3	5683
28863	5	71128	3	9420
28864	4	71129	4	27999
28865	5	71132	6	28027
28866	5	71134	6	25477
28867	5	71135	7	26556
28868	3	71137	5	8722
28869	5	71139	2	14127
28870	5	71142	2	27981
28871	1	71143	6	14143
28872	4	71144	5	28113
28873	4	71145	3	28081
28874	3	71151	5	10410
28875	3	71157	4	6916
28876	3	71157	2	6916
28877	4	71160	7	1006
28878	5	71163	1	28069
28879	4	71164	1	3211
28880	5	71167	5	1379
28881	5	71168	2	14364
28882	5	71173	1	22259
28883	5	71174	5	2434
28884	4	71177	7	26178
28885	2	71178	1	28118
28886	4	71180	7	25933
28887	2	71180	2	25933
28888	5	71181	6	16358
28889	5	71184	2	9151
28890	4	71185	1	27986
28891	5	71186	4	24869
28892	3	71188	4	3896
28893	5	71190	6	28062
28894	5	71191	4	19492
28895	5	71199	6	21750
28896	5	71202	2	19395
28897	3	71206	5	4008
28898	3	71207	5	12166
28899	4	71209	6	1723
28900	4	71210	1	28151
28901	5	71212	2	20972
28902	4	71218	1	16831
28903	4	71223	2	8229
28904	5	71224	7	28017
28905	3	71226	7	12602
28906	3	71227	3	13172
28907	4	71228	1	4800
28908	5	71230	5	23271
28909	5	71233	4	10356
28910	4	71238	7	27998
28911	2	71240	6	28125
28912	5	71242	1	123
28913	5	71243	6	2561
28914	5	71244	2	9021
28915	1	71246	6	11770
28916	4	71247	2	15369
28917	5	71248	2	28045
28918	4	71250	7	28005
28919	5	71252	7	13563
28920	5	71254	2	11806
28921	5	71255	4	24975
28922	3	71258	5	24718
28923	5	71261	5	5332
28924	5	71264	1	12481
28925	5	71268	3	20261
28926	5	71276	7	1408
28927	2	71281	7	17291
28928	5	71283	5	21657
28929	4	71284	4	5234
28930	4	71285	3	2352
28931	5	71286	5	6780
28932	4	71290	5	7388
28933	1	71291	1	21492
28934	4	71296	2	28093
28935	5	71298	4	28047
28936	3	71299	7	11194
28937	5	71302	6	16958
28938	5	71303	6	17373
28939	5	71311	6	9669
28940	5	71313	1	28054
28941	5	71314	2	8068
28942	5	71315	4	15686
28943	2	71320	4	15187
28944	3	71323	2	18526
28945	5	71329	4	18859
28946	3	71331	7	3629
28947	4	71332	6	10302
28948	5	71333	3	21575
28949	5	71334	1	22319
28950	5	71336	2	28025
28951	4	71341	3	28116
28952	5	71342	6	6356
28953	5	71345	2	25147
28954	3	71348	3	17931
28955	5	71350	1	18063
28956	5	71356	7	27183
28957	5	71357	2	729
28958	5	71359	6	24798
28959	5	71359	1	24798
28960	3	71362	5	28016
28961	4	71363	6	25003
28962	5	71367	7	27989
28963	5	71367	6	27989
28964	3	71368	2	2961
28965	5	71369	7	28150
28966	5	71372	6	14631
28967	5	71373	5	28153
28968	5	71374	1	16219
28969	5	71377	7	28287
28970	3	71385	1	28087
28971	5	71386	2	16959
28972	5	71387	6	11254
28973	5	71392	5	20729
28974	4	71393	1	28239
28975	5	71395	5	25547
28976	4	71396	6	2301
28977	5	71397	4	22561
28978	5	71399	1	28271
28979	4	71401	3	10743
28980	5	71402	6	14785
28981	4	71403	2	10590
28982	4	71407	5	2646
28983	4	71408	5	28231
28984	4	71409	2	28264
28985	4	71410	5	12966
28986	5	71411	5	28198
28987	4	71413	5	20062
28988	5	71414	7	28318
28989	5	71415	6	28332
28990	2	71416	3	6361
28991	5	71419	6	27448
28992	4	71420	7	24221
28993	5	71422	5	28240
28994	1	71423	6	18772
28995	4	71426	6	12845
28996	5	71428	7	11817
28997	4	71429	5	16464
28998	5	71432	4	15082
28999	4	71433	7	12650
29000	5	71434	4	28236
29001	3	71435	5	23783
29002	3	71438	4	7146
29003	3	71443	6	28273
29004	5	71444	5	7025
29005	5	71446	4	14884
29006	5	71453	2	28326
29007	5	71455	2	4798
29008	4	71461	3	5917
29009	3	71462	1	28242
29010	2	71464	3	28196
29011	4	71465	3	2756
29012	3	71469	7	12378
29013	5	71472	4	10019
29014	4	71474	3	1369
29015	4	71475	6	28228
29016	5	71476	5	13105
29017	3	71477	5	28269
29018	5	71477	1	28269
29019	5	71480	4	28229
29020	4	71480	6	28229
29021	1	71482	4	28187
29022	5	71486	5	28263
29023	5	71491	3	1929
29024	3	71493	5	28324
29025	3	71494	2	28168
29026	4	71497	4	2585
29027	5	71501	3	6953
29028	1	71501	6	6953
29029	5	71502	3	28177
29030	4	71503	2	17270
29031	1	71504	7	28262
29032	3	71505	3	13947
29033	5	71506	6	28232
29034	4	71510	6	28182
29035	4	71511	7	28257
29036	2	71518	6	4287
29037	5	71523	2	28268
29038	5	71530	5	23203
29039	5	71531	2	28252
29040	5	71532	6	28243
29041	5	71535	6	6005
29042	5	71538	6	28171
29043	1	71543	5	27007
29044	4	71544	2	24411
29045	3	71545	1	2116
29046	5	71546	5	18542
29047	3	71547	6	23268
29048	5	71551	2	3127
29049	3	71554	3	3877
29050	3	71556	2	7181
29051	5	71560	7	12184
29052	4	71562	4	10334
29053	5	71569	5	16165
29054	5	71570	7	20183
29055	5	71574	5	14177
29056	3	71575	2	18090
29057	5	71575	5	18090
29058	5	71576	4	24156
29059	5	71579	3	28291
29060	5	71579	7	28291
29061	4	71580	3	12282
29062	4	71581	4	7622
29063	5	71583	6	28207
29064	5	71584	2	28185
29065	5	71587	1	28339
29066	5	71589	7	21915
29067	3	71592	2	28258
29068	4	71595	7	28184
29069	5	71598	6	17394
29070	4	71599	1	17095
29071	4	71600	1	28284
29072	5	71603	4	15120
29073	5	71606	6	18096
29074	5	71610	5	28230
29075	5	71611	6	23401
29076	3	71612	5	23954
29077	5	71613	2	6589
29078	3	71614	5	28333
29079	3	71615	4	27798
29080	5	71616	1	28234
29081	5	71620	2	28285
29082	4	71621	2	6322
29083	5	71625	6	19793
29084	5	71629	6	13875
29085	3	71629	7	13875
29086	5	71630	2	28181
29087	5	71631	1	28227
29088	4	71633	6	19371
29089	5	71635	7	15018
29090	3	71637	3	16041
29091	5	71641	2	28301
29092	5	71645	3	24697
29093	5	71646	3	22338
29094	3	71648	7	12949
29095	1	71649	3	13662
29096	3	71651	4	20302
29097	5	71653	3	14313
29098	5	71656	2	19172
29099	5	71657	5	11812
29100	5	71659	7	28274
29101	3	71659	2	28274
29102	3	71660	2	5353
29103	4	71661	3	28323
29104	5	71662	7	26255
29105	5	71663	2	28217
29106	5	71664	6	281
29107	5	71664	4	281
29108	5	71667	3	21838
29109	5	71668	6	13660
29110	5	71669	4	5302
29111	5	71669	1	5302
29112	4	71672	5	28312
29113	5	71673	5	28314
29114	5	71675	1	594
29115	2	71678	1	26536
29116	3	71682	3	28281
29117	5	71683	4	22443
29118	5	71685	6	21907
29119	5	71687	2	28307
29120	3	71689	3	28158
29121	1	71693	5	16450
29122	1	71694	6	9296
29123	5	71703	5	28174
29124	1	71705	6	28277
29125	4	71706	2	24252
29126	3	71706	1	24252
29127	4	71709	7	356
29128	3	71721	5	9696
29129	5	71722	3	28267
29130	4	71723	3	14637
29131	3	71726	5	18477
29132	4	71729	2	28213
29133	5	71730	2	18210
29134	4	71731	5	10238
29135	4	71732	4	28235
29136	2	71736	4	24246
29137	3	71739	6	1387
29138	3	71739	3	1387
29139	5	71742	6	14025
29140	4	71744	5	28516
29141	5	71749	7	28433
29142	5	71751	4	26333
29143	2	71753	3	14689
29144	5	71756	2	1460
29145	3	71757	2	28475
29146	5	71759	3	13644
29147	4	71761	2	28473
29148	4	71766	2	28404
29149	4	71771	2	28320
29150	5	71772	3	28437
29151	5	71773	7	8105
29152	5	71777	7	11074
29153	3	71780	4	13858
29154	5	71781	4	15983
29155	4	71782	7	1768
29156	5	71786	7	6669
29157	5	71789	6	17378
29158	1	71790	4	28414
29159	5	71791	4	5528
29160	5	71792	2	16257
29161	5	71793	6	5682
29162	3	71795	5	28427
29163	3	71796	5	17835
29164	5	71798	7	14824
29165	5	71799	4	360
29166	5	71800	7	12117
29167	3	71801	4	8145
29168	5	71801	3	8145
29169	4	71804	1	2756
29170	5	71810	1	4685
29171	5	71814	7	12314
29172	4	71815	7	21489
29173	5	71817	4	16959
29174	4	71821	2	28486
29175	5	71822	5	25331
29176	5	71824	5	982
29177	5	71828	4	24081
29178	3	71829	7	9556
29179	4	71832	5	28471
29180	5	71833	3	14378
29181	4	71834	7	28484
29182	5	71836	4	11554
29183	5	71838	2	28477
29184	3	71838	5	28477
29185	5	71839	4	12596
29186	3	71840	7	3642
29187	5	71840	2	3642
29188	5	71841	2	26199
29189	4	71842	3	28424
29190	1	71846	6	23077
29191	5	71848	6	15189
29192	4	71850	7	14679
29193	5	71852	6	15018
29194	1	71852	5	15018
29195	5	71853	6	28526
29196	5	71855	2	12969
29197	5	71858	4	22731
29198	5	71859	2	806
29199	5	71863	4	28529
29200	4	71868	5	25104
29201	5	71869	2	23099
29202	3	71870	4	9706
29203	3	71873	5	14573
29204	4	71876	5	28425
29205	5	71877	6	27931
29206	5	71878	2	9613
29207	3	71879	7	19061
29208	1	71882	6	13697
29209	5	71883	4	28401
29210	5	71885	3	26359
29211	3	71885	1	26359
29212	4	71887	7	1761
29213	3	71888	2	28496
29214	3	71889	6	351
29215	1	71890	6	23130
29216	5	71894	6	28378
29217	5	71896	3	28466
29218	5	71897	3	28463
29219	5	71900	4	28527
29220	5	71901	1	28249
29221	5	71902	4	25651
29222	5	71902	2	25651
29223	5	71904	6	15164
29224	5	71905	6	18222
29225	5	71906	2	28410
29226	5	71907	6	20524
29227	5	71908	1	1170
29228	5	71909	2	25862
29229	5	71916	3	7716
29230	5	71921	2	15302
29231	5	71926	1	1317
29232	5	71928	2	28445
29233	3	71929	2	28374
29234	5	71930	5	28429
29235	4	71933	7	7137
29236	4	71934	5	26351
29237	5	71936	7	27257
29238	4	71937	1	19717
29239	3	71938	7	28464
29240	5	71945	7	28469
29241	5	71948	4	439
29242	5	71950	4	28435
29243	5	71951	6	28514
29244	5	71952	5	28376
29245	4	71957	7	28458
29246	3	71959	3	28403
29247	1	71962	6	8597
29248	5	71963	1	5382
29249	4	71964	1	15816
29250	4	71965	2	511
29251	3	71972	5	28380
29252	4	71973	7	10627
29253	5	71976	6	19816
29254	5	71980	6	581
29255	4	71981	2	24129
29256	5	71986	1	4072
29257	5	71988	5	17026
29258	5	71989	5	5041
29259	5	71993	6	20017
29260	5	71994	1	19621
29261	4	71996	1	27618
29262	5	71997	6	19852
29263	5	72001	3	7464
29264	4	72003	3	28474
29265	5	72004	1	28501
29266	3	72005	2	464
29267	5	72006	3	28456
29268	5	72009	3	10563
29269	4	72010	4	4996
29270	3	72010	1	4996
29271	4	72011	6	20560
29272	5	72012	6	8003
29273	4	72014	7	28306
29274	4	72015	4	14418
29275	5	72015	2	14418
29276	5	72017	6	10022
29277	5	72019	6	6958
29278	4	72021	1	8866
29279	5	72022	3	28355
29280	5	72023	7	3106
29281	1	72024	6	28498
29282	2	72028	2	28507
29283	5	72030	3	28361
29284	3	72031	7	28418
29285	4	72032	1	24766
29286	5	72033	7	16876
29287	4	72034	4	13689
29288	3	72037	4	19202
29289	4	72038	2	25444
29290	3	72042	5	11896
29291	1	72047	6	8490
29292	5	72050	4	28377
29293	4	72051	5	28493
29294	5	72062	3	8583
29295	5	72066	6	28450
29296	4	72067	7	28465
29297	5	72069	6	28283
29298	4	72071	7	23154
29299	5	72072	1	7979
29300	5	72073	3	7258
29301	4	72075	5	28422
29302	5	72079	2	3624
29303	2	72080	4	28351
29304	3	72081	7	4894
29305	5	72082	1	11678
29306	5	72084	2	6650
29307	4	72085	7	4835
29308	5	72088	6	26921
29309	4	72089	2	28510
29310	5	72090	6	20805
29311	5	72092	1	28522
29312	5	72095	7	28415
29313	4	72096	1	28375
29314	3	72098	7	16834
29315	4	72100	4	9001
29316	1	72101	1	28400
29317	5	72102	4	16621
29318	5	72103	2	20712
29319	3	72107	5	28482
29320	3	72108	2	7918
29321	4	72111	3	3765
29322	4	72113	7	28442
29323	5	72119	5	28432
29324	3	72120	5	26954
29325	5	72128	7	1914
29326	5	72129	4	11715
29327	5	72131	2	1208
29328	5	72133	6	28372
29329	4	72133	2	28372
29330	5	72134	2	28520
29331	4	72134	1	28520
29332	5	72135	4	3568
29333	5	72138	6	28468
29334	4	72139	5	1420
29335	4	72140	5	28478
29336	4	72142	1	22320
29337	4	72144	5	14682
29338	5	72145	2	28597
29339	4	72145	4	28597
29340	5	72146	6	7280
29341	3	72150	2	28678
29342	4	72153	2	22605
29343	5	72156	1	1432
29344	3	72157	1	5752
29345	4	72159	3	28621
29346	5	72161	6	28721
29347	4	72164	5	8057
29348	5	72166	6	28642
29349	5	72169	2	28724
29350	3	72170	7	17851
29351	5	72178	6	2148
29352	5	72181	7	3705
29353	4	72183	2	28619
29354	5	72184	6	18003
29355	5	72186	6	28541
29356	5	72187	6	27443
29357	4	72188	3	26409
29358	5	72191	2	28557
29359	5	72192	3	14290
29360	5	72194	2	1280
29361	5	72195	6	11766
29362	5	72200	6	28575
29363	5	72201	6	9014
29364	5	72203	1	15852
29365	5	72204	7	8546
29366	5	72207	6	27517
29367	5	72209	6	26371
29368	4	72213	7	19201
29369	4	72214	7	28685
29370	1	72216	6	7333
29371	5	72218	1	24547
29372	5	72224	6	11603
29373	4	72225	1	17948
29374	4	72227	6	17056
29375	3	72232	7	28583
29376	5	72236	3	10500
29377	5	72237	1	28710
29378	5	72238	2	1322
29379	5	72243	5	25580
29380	5	72245	2	5898
29381	5	72247	2	26642
29382	4	72250	2	6233
29383	4	72252	1	28629
29384	5	72253	6	16336
29385	4	72254	5	7130
29386	4	72261	2	28571
29387	4	72262	1	17398
29388	3	72269	4	28706
29389	1	72270	1	23126
29390	4	72271	7	28663
29391	5	72275	6	28677
29392	5	72279	4	21794
29393	5	72280	2	7591
29394	5	72286	1	18983
29395	5	72287	7	126
29396	5	72289	1	17085
29397	4	72291	5	28594
29398	3	72295	1	28628
29399	3	72297	5	28650
29400	4	72299	7	3297
29401	2	72300	3	28565
29402	3	72301	1	28589
29403	5	72302	1	27790
29404	1	72304	6	28666
29405	5	72304	3	28666
29406	4	72308	7	21537
29407	3	72309	5	28707
29408	5	72311	6	6027
29409	5	72311	7	6027
29410	5	72312	6	26603
29411	4	72312	7	26603
29412	5	72314	2	347
29413	5	72321	7	11700
29414	5	72324	6	1591
29415	4	72326	6	2191
29416	5	72327	6	28643
29417	2	72334	2	23705
29418	3	72337	7	10931
29419	1	72341	6	28726
29420	5	72343	4	28660
29421	5	72344	6	25086
29422	3	72346	7	13821
29423	5	72346	2	13821
29424	3	72347	3	28606
29425	4	72348	4	4062
29426	4	72349	5	28697
29427	3	72350	7	28626
29428	3	72351	7	20246
29429	4	72352	7	8574
29430	5	72353	7	18045
29431	3	72355	3	28584
29432	5	72356	3	28561
29433	5	72358	1	11858
29434	4	72359	5	20517
29435	3	72361	2	1442
29436	5	72362	6	24807
29437	4	72367	5	14725
29438	3	72368	2	11469
29439	5	72369	6	377
29440	5	72372	6	21600
29441	5	72374	6	14422
29442	4	72380	7	14262
29443	3	72381	5	28545
29444	5	72382	2	28564
29445	4	72384	1	12482
29446	5	72385	5	8594
29447	3	72389	1	27114
29448	4	72390	1	4594
29449	5	72399	6	28579
29450	5	72400	2	9459
29451	5	72401	7	10297
29452	5	72404	3	13636
29453	5	72406	4	3869
29454	5	72406	2	3869
29455	5	72408	5	2517
29456	5	72409	4	18227
29457	5	72412	7	8987
29458	5	72414	5	6693
29459	4	72417	2	18343
29460	3	72417	5	18343
29461	5	72419	5	11585
29462	5	72423	4	28630
29463	5	72426	7	17548
29464	3	72429	5	27137
29465	5	72430	6	28661
29466	5	72437	6	17347
29467	3	72439	7	25071
29468	5	72442	6	11386
29469	5	72443	3	23061
29470	5	72444	5	26700
29471	5	72444	3	26700
29472	4	72446	1	12565
29473	5	72449	6	18981
29474	5	72451	3	28713
29475	5	72452	2	14662
29476	5	72453	2	12650
29477	5	72460	2	28690
29478	3	72460	7	28690
29479	3	72464	5	6664
29480	4	72467	3	23316
29481	3	72469	2	14349
29482	4	72471	4	28624
29483	5	72472	2	28676
29484	5	72473	7	20126
29485	4	72474	5	2264
29486	5	72477	3	23037
29487	5	72478	7	20511
29488	5	72479	6	25625
29489	5	72480	3	8305
29490	5	72484	3	12552
29491	5	72487	6	28649
29492	5	72489	3	20814
29493	5	72489	7	20814
29494	4	72491	3	23994
29495	3	72493	5	3156
29496	5	72495	6	2052
29497	4	72498	1	9603
29498	5	72499	4	17229
29499	3	72500	5	16324
29500	1	72503	6	27201
29501	5	72504	4	28577
29502	5	72505	1	2413
29503	5	72506	3	18896
29504	1	72510	6	11586
29505	5	72511	1	8467
29506	5	72512	4	22311
29507	4	72513	5	28542
29508	3	72514	5	26195
29509	5	72515	5	16264
29510	4	72516	5	13165
29511	1	72518	6	11298
29512	4	72522	3	28647
29513	4	72523	6	28537
29514	5	72525	6	19747
29515	5	72526	2	28563
29516	5	72529	3	28648
29517	5	72535	5	17550
29518	4	72538	1	4982
29519	3	72541	2	9489
29520	4	72545	7	28617
29521	5	72545	6	28617
29522	5	72546	3	28715
29523	4	72550	4	28705
29524	3	72552	1	4321
29525	4	72553	5	12305
29526	3	72557	3	2695
29527	5	72564	3	28704
29528	3	72565	5	15595
29529	1	72570	4	23585
29530	4	72571	4	28684
29531	3	72576	4	28555
29532	5	72577	2	2741
29533	3	72579	3	28548
29534	1	72585	6	27403
29535	3	72588	5	11635
29536	5	72591	2	11214
29537	1	72594	6	28641
29538	3	72595	4	16556
29539	4	72601	1	28669
29540	4	72607	1	5343
29541	4	72610	7	20920
29542	5	72612	6	28670
29543	4	72614	7	28651
29544	5	72618	1	28703
29545	2	72621	6	8201
29546	5	72622	7	7760
29547	5	72624	6	28588
29548	4	72625	2	6894
29549	5	72626	4	5888
29550	3	72628	1	28600
29551	5	72632	6	28667
29552	3	72637	3	10690
29553	3	72638	7	28615
29554	5	72639	6	28558
29555	2	72644	6	6883
29556	3	72645	7	28680
29557	3	72647	2	24368
29558	5	72649	4	28169
29559	5	72651	4	15109
29560	4	72653	7	28613
29561	3	72656	5	28691
29562	3	72658	2	28552
29563	5	72659	6	28699
29564	2	72660	3	28682
29565	4	72663	7	11983
29566	5	72665	6	9573
29567	1	72669	1	9023
29568	4	72672	5	26689
29569	3	72676	7	13477
29570	5	72679	7	1537
29571	5	72682	7	2605
29572	5	72684	4	21795
29573	5	72686	1	22747
29574	5	72688	7	6871
29575	4	72691	2	28518
29576	5	72694	5	28888
29577	5	72695	4	20953
29578	4	72697	7	17652
29579	5	72698	1	14566
29580	5	72699	2	3127
29581	5	72700	2	28908
29582	3	72701	3	3454
29583	4	72707	7	14411
29584	4	72708	2	19953
29585	5	72709	1	28790
29586	3	72710	5	28890
29587	4	72715	2	28886
29588	5	72717	2	6190
29589	4	72718	7	28833
29590	5	72718	2	28833
29591	5	72723	1	21659
29592	4	72726	7	28167
29593	5	72734	7	28871
29594	5	72741	5	28808
29595	5	72742	6	1309
29596	1	72744	7	23890
29597	4	72747	7	28902
29598	3	72749	5	4989
29599	5	72751	4	14309
29600	5	72754	6	28791
29601	5	72757	3	18326
29602	1	72761	4	28924
29603	4	72765	2	931
29604	3	72769	3	3931
29605	5	72770	6	7758
29606	5	72772	7	13449
29607	5	72775	4	16829
29608	4	72778	4	28776
29609	4	72779	7	21148
29610	3	72779	5	21148
29611	4	72782	1	12855
29612	5	72784	1	8521
29613	5	72786	6	28910
29614	5	72787	7	6563
29615	5	72789	6	19783
29616	5	72793	7	10003
29617	5	72796	2	324
29618	5	72798	7	4393
29619	4	72799	6	28821
29620	3	72802	3	26163
29621	5	72804	1	8546
29622	5	72806	3	17245
29623	3	72808	2	28862
29624	5	72809	6	23921
29625	5	72814	5	25585
29626	5	72820	5	7023
29627	4	72824	7	17743
29628	5	72826	7	14612
29629	5	72829	6	9386
29630	4	72830	2	13504
29631	4	72833	7	3999
29632	3	72835	5	28912
29633	5	72836	4	23558
29634	5	72838	3	12240
29635	5	72847	7	17654
29636	4	72848	7	7051
29637	5	72854	4	17352
29638	4	72859	2	10007
29639	5	72861	5	10436
29640	3	72863	5	28831
29641	3	72864	5	654
29642	5	72865	2	18597
29643	5	72866	6	15927
29644	5	72869	4	20134
29645	3	72870	5	3417
29646	3	72871	4	3600
29647	5	72872	4	28814
29648	4	72873	4	25293
29649	3	72878	5	28922
29650	2	72879	4	8139
29651	5	72880	6	28830
29652	4	72881	6	28852
29653	5	72885	6	2959
29654	2	72890	4	19554
29655	4	72891	7	26127
29656	5	72893	1	28770
29657	1	72895	6	2320
29658	4	72896	4	9191
29659	5	72897	3	5494
29660	4	72898	3	2570
29661	2	72901	6	18612
29662	4	72903	4	19432
29663	4	72906	7	5412
29664	5	72909	4	11182
29665	5	72911	4	28869
29666	4	72912	3	24899
29667	3	72916	5	28225
29668	2	72917	4	2122
29669	3	72919	4	7769
29670	4	72919	5	7769
29671	5	72921	7	28866
29672	5	72922	6	28876
29673	3	72925	4	16569
29674	3	72926	1	4378
29675	5	72931	4	28761
29676	2	72932	7	28895
29677	2	72937	1	28736
29678	4	72941	5	11750
29679	4	72942	6	3331
29680	1	72945	4	1343
29681	4	72947	6	14103
29682	5	72949	1	28892
29683	4	72950	7	8716
29684	4	72951	6	28906
29685	5	72956	3	28756
29686	5	72959	4	28805
29687	3	72960	5	6135
29688	5	72961	7	28860
29689	5	72962	2	28344
29690	5	72964	7	28845
29691	5	72966	2	1317
29692	5	72967	6	6900
29693	5	72969	7	27724
29694	3	72970	3	16784
29695	3	72978	7	28873
29696	5	72978	6	28873
29697	5	72979	1	28839
29698	5	72983	6	28738
29699	4	72984	5	2923
29700	1	72987	6	13843
29701	5	72988	3	21825
29702	3	72992	5	6124
29703	5	72995	5	21499
29704	4	72998	7	28884
29705	4	73000	6	19946
29706	4	73002	3	15750
29707	4	73002	5	15750
29708	5	73006	4	25895
29709	4	73007	1	28828
29710	5	73012	7	28914
29711	5	73014	6	28905
29712	5	73015	5	28754
29713	3	73019	1	28748
29714	5	73023	1	2076
29715	5	73026	6	22523
29716	5	73029	6	28766
29717	4	73033	5	12992
29718	5	73035	6	7582
29719	4	73039	5	3645
29720	3	73043	7	28913
29721	5	73044	2	28737
29722	4	73046	5	1509
29723	3	73047	6	28074
29724	4	73049	4	13529
29725	3	73053	7	5678
29726	3	73055	1	757
29727	4	73061	4	21019
29728	5	73062	2	6020
29729	1	73064	6	17534
29730	3	73065	3	8524
29731	5	73066	1	28899
29732	5	73069	2	11684
29733	4	73070	7	23856
29734	3	73071	5	10120
29735	5	73074	2	28752
29736	3	73076	5	1293
29737	3	73076	2	1293
29738	3	73078	3	28800
29739	4	73080	2	28768
29740	3	73081	1	11969
29741	4	73082	3	8762
29742	5	73086	6	27695
29743	5	73088	1	28838
29744	4	73094	5	6140
29745	5	73095	2	13874
29746	5	73097	2	14881
29747	4	73102	2	28734
29748	5	73107	2	6684
29749	3	73108	5	8101
29750	3	73109	4	28893
29751	3	73112	5	13987
29752	5	73115	6	28840
29753	5	73118	2	9040
29754	2	73119	7	19502
29755	3	73121	5	11038
29756	4	73122	2	2485
29757	3	73124	7	28759
29758	5	73125	6	28848
29759	4	73126	1	28832
29760	5	73127	6	26101
29761	4	73130	6	28777
29762	4	73134	3	28746
29763	3	73137	6	23610
29764	5	73138	6	9277
29765	5	73140	4	23939
29766	5	73142	5	11495
29767	5	73145	6	310
29768	5	73146	6	12210
29769	3	73148	5	17656
29770	4	73151	6	28784
29771	3	73153	1	28801
29772	5	73154	2	3444
29773	3	73159	2	11373
29774	5	73163	4	12236
29775	5	73164	1	236
29776	5	73165	6	6232
29777	5	73174	5	21831
29778	5	73176	7	227
29779	5	73179	6	23805
29780	5	73180	2	5047
29781	5	73182	6	22156
29782	4	73183	3	28789
29783	5	73184	5	28856
29784	5	73190	2	26217
29785	5	73204	1	24301
29786	3	73205	7	18078
29787	3	73207	7	28765
29788	5	73208	6	10281
29789	4	73208	2	10281
29790	5	73209	7	20894
29791	4	73210	5	8385
29792	5	73214	2	9232
29793	5	73218	6	9554
29794	4	73219	5	28918
29795	5	73223	7	28812
29796	5	73230	2	2055
29797	4	73231	1	7217
29798	5	73233	3	21273
29799	5	73234	6	10002
29800	5	73236	3	28865
29801	4	73239	7	10519
29802	5	73241	7	28751
29803	4	73243	1	29073
29804	5	73250	5	20846
29805	3	73252	4	29156
29806	5	73253	5	28947
29807	5	73254	2	29121
29808	5	73254	6	29121
29809	4	73255	6	29071
29810	5	73258	6	29114
29811	5	73258	3	29114
29812	3	73261	5	29028
29813	5	73262	3	29103
29814	1	73266	6	20138
29815	5	73267	6	837
29816	3	73273	5	28962
29817	4	73274	3	9480
29818	4	73275	7	18211
29819	5	73276	6	29067
29820	3	73277	7	28986
29821	3	73281	7	16550
29822	5	73286	2	28984
29823	2	73293	3	27567
29824	5	73297	7	29026
29825	5	73299	4	29117
29826	5	73301	2	10191
29827	4	73302	6	5255
29828	5	73303	4	26993
29829	5	73304	6	11903
29830	4	73305	7	3842
29831	5	73311	2	3260
29832	1	73312	6	29042
29833	4	73314	3	28998
29834	5	73321	7	7576
29835	4	73323	5	16574
29836	3	73325	7	3072
29837	4	73327	7	28952
29838	5	73330	2	28931
29839	5	73330	4	28931
29840	5	73332	3	5507
29841	5	73334	4	28939
29842	3	73335	1	5149
29843	2	73337	6	28936
29844	3	73338	1	14178
29845	5	73340	6	23268
29846	3	73341	2	29167
29847	4	73345	5	28970
29848	3	73345	1	28970
29849	5	73349	6	29060
29850	5	73351	1	27870
29851	5	73354	4	28933
29852	5	73358	2	14566
29853	4	73359	4	13148
29854	1	73361	4	29107
29855	5	73364	4	10840
29856	4	73367	7	11181
29857	5	73369	6	29120
29858	5	73370	2	28942
29859	5	73371	4	28946
29860	1	73372	7	26573
29861	4	73379	4	5886
29862	5	73380	5	28988
29863	5	73381	7	25839
29864	4	73384	6	14227
29865	4	73386	3	28963
29866	2	73387	6	22233
29867	4	73388	5	23633
29868	4	73389	6	19127
29869	5	73390	7	29083
29870	5	73390	5	29083
29871	5	73393	4	2189
29872	5	73395	2	8404
29873	5	73400	4	28941
29874	2	73401	7	22259
29875	3	73403	7	29145
29876	5	73407	2	12024
29877	3	73407	1	12024
29878	5	73408	7	29005
29879	5	73409	7	22143
29880	5	73413	4	22952
29881	5	73414	6	29152
29882	5	73424	2	29048
29883	5	73426	6	10802
29884	5	73427	2	29079
29885	5	73429	2	20815
29886	4	73430	2	13679
29887	5	73431	1	6900
29888	5	73436	1	885
29889	5	73437	4	29022
29890	3	73440	6	28979
29891	5	73443	7	28756
29892	5	73447	1	2633
29893	5	73449	5	6069
29894	3	73453	7	4453
29895	5	73455	6	28790
29896	4	73456	1	6752
29897	4	73458	3	29111
29898	5	73459	7	11342
29899	2	73461	6	29095
29900	4	73464	7	29125
29901	3	73466	1	16453
29902	3	73467	1	2082
29903	5	73471	4	13200
29904	4	73472	7	29023
29905	5	73473	2	29097
29906	5	73477	2	28935
29907	4	73478	3	29104
29908	5	73480	1	16459
29909	5	73489	7	4445
29910	5	73498	5	13568
29911	5	73499	1	29109
29912	5	73500	1	29108
29913	4	73502	1	28593
29914	5	73502	6	28593
29915	3	73503	5	24628
29916	3	73503	7	24628
29917	5	73508	6	22331
29918	5	73509	1	11187
29919	4	73511	5	29113
29920	3	73512	1	10339
29921	5	73518	6	29110
29922	5	73521	3	24473
29923	3	73523	7	28965
29924	3	73523	3	28965
29925	5	73531	1	19953
29926	5	73532	4	29000
29927	1	73533	4	29146
29928	3	73536	2	29112
29929	5	73538	5	27931
29930	4	73538	7	27931
29931	4	73539	2	11638
29932	5	73540	3	29033
29933	4	73547	4	29150
29934	5	73550	5	28997
29935	5	73551	5	28954
29936	4	73554	6	13183
29937	1	73560	2	29038
29938	4	73563	5	29002
29939	3	73564	2	19321
29940	4	73571	3	13149
29941	5	73573	1	29047
29942	5	73580	4	28091
29943	4	73581	4	7958
29944	4	73581	3	7958
29945	3	73582	3	29164
29946	5	73585	3	3451
29947	4	73587	2	29031
29948	4	73590	3	29128
29949	3	73591	2	432
29950	5	73592	7	29147
29951	2	73593	4	22230
29952	5	73594	5	11006
29953	5	73594	1	11006
29954	3	73598	5	21452
29955	4	73600	7	14954
29956	1	73601	6	29138
29957	3	73602	5	28928
29958	5	73603	1	23405
29959	5	73604	7	28976
29960	5	73609	6	24018
29961	5	73610	4	26860
29962	5	73610	2	26860
29963	4	73611	2	28930
29964	3	73612	7	23111
29965	3	73613	4	14133
29966	3	73616	5	20757
29967	5	73617	3	5701
29968	3	73625	6	28974
29969	5	73626	5	20852
29970	3	73627	7	21971
29971	1	73628	6	27023
29972	5	73632	1	28961
29973	5	73633	4	4793
29974	5	73634	7	2909
29975	4	73635	2	16206
29976	5	73636	4	29130
29977	5	73637	7	366
29978	4	73640	7	20390
29979	5	73644	2	3851
29980	5	73645	5	28978
29981	5	73645	1	28978
29982	5	73649	6	16060
29983	5	73650	3	29094
29984	5	73655	7	29076
29985	5	73660	2	7279
29986	3	73664	2	28981
29987	3	73664	7	28981
29988	5	73665	3	28951
29989	2	73666	4	1957
29990	5	73667	6	20739
29991	5	73668	6	13065
29992	5	73670	2	6062
29993	3	73673	7	14905
29994	5	73675	1	10578
29995	5	73683	6	28996
29996	5	73684	2	14751
29997	5	73686	6	29116
29998	5	73687	2	3136
29999	4	73688	4	20901
30000	4	73689	4	1309
30001	3	73694	7	28953
30002	5	73697	5	29099
30003	4	73699	5	5293
30004	5	73704	6	25160
30005	4	73705	3	2897
30006	4	73710	6	29072
30007	2	73711	5	4120
30008	4	73712	7	25799
30009	5	73713	7	29139
30010	5	73715	3	24356
30011	4	73717	5	8388
30012	4	73721	4	22878
30013	2	73722	4	8634
30014	5	73726	2	2640
30015	5	73726	4	2640
30016	5	73727	6	6809
30017	4	73730	7	27664
30018	5	73731	1	29304
30019	5	73733	3	3629
30020	5	73739	2	2801
30021	5	73744	6	21572
30022	5	73745	6	26359
30023	5	73747	5	29278
30024	4	73748	1	10337
30025	4	73749	7	29206
30026	5	73751	4	29339
30027	4	73752	1	12338
30028	5	73753	7	28755
30029	5	73755	6	26571
30030	3	73760	3	24513
30031	5	73764	3	29362
30032	5	73764	1	29362
30033	5	73767	2	8726
30034	4	73769	7	29173
30035	5	73770	3	7200
30036	2	73771	7	29371
30037	5	73774	6	29281
30038	5	73778	1	22204
30039	3	73780	5	4728
30040	5	73781	3	21370
30041	3	73782	4	17530
30042	4	73785	6	24052
30043	5	73788	7	16434
30044	4	73789	4	29274
30045	5	73789	5	29274
30046	4	73793	7	2291
30047	4	73794	7	2561
30048	5	73795	7	14495
30049	5	73796	7	17467
30050	5	73797	2	7740
30051	3	73800	5	29315
30052	5	73807	2	24668
30053	4	73808	2	16175
30054	3	73810	2	25794
30055	5	73812	1	29328
30056	5	73813	7	138
30057	4	73814	2	16489
30058	4	73815	1	19503
30059	5	73819	2	971
30060	5	73820	5	23688
30061	5	73821	4	29215
30062	4	73823	5	8054
30063	5	73824	4	28357
30064	1	73825	6	20313
30065	3	73832	1	6026
30066	1	73835	6	22356
30067	5	73838	2	29267
30068	4	73840	7	15535
30069	4	73842	3	29336
30070	4	73843	7	22389
30071	3	73845	2	29197
30072	4	73853	2	20210
30073	5	73855	1	8720
30074	1	73856	6	29232
30075	5	73857	2	27650
30076	4	73860	7	16744
30077	5	73861	1	2292
30078	4	73863	7	3977
30079	5	73864	6	8757
30080	3	73865	7	29178
30081	5	73866	2	29231
30082	5	73874	7	23780
30083	5	73877	3	29280
30084	4	73884	7	29222
30085	5	73889	6	3507
30086	4	73890	2	10613
30087	5	73892	3	23963
30088	3	73893	7	29219
30089	4	73894	7	29269
30090	5	73897	4	12019
30091	3	73899	5	14068
30092	4	73902	7	2691
30093	4	73903	6	7578
30094	4	73904	1	9454
30095	4	73913	2	6280
30096	5	73914	5	4110
30097	1	73915	6	29200
30098	5	73916	7	6593
30099	5	73922	4	14015
30100	4	73923	2	29292
30101	3	73924	5	29349
30102	4	73928	7	22379
30103	5	73929	6	25579
30104	5	73933	2	18707
30105	5	73934	6	8650
30106	5	73936	1	20189
30107	3	73937	7	29301
30108	5	73938	2	636
30109	5	73943	5	23226
30110	5	73944	4	15563
30111	5	73945	6	26456
30112	4	73946	3	29317
30113	5	73950	4	8961
30114	3	73954	7	24975
30115	5	73954	1	24975
30116	5	73956	4	11590
30117	5	73964	1	13687
30118	4	73966	5	29194
30119	4	73966	7	29194
30120	3	73970	5	29224
30121	5	73976	6	17025
30122	5	73979	5	11415
30123	4	73981	7	29360
30124	5	73988	4	29293
30125	5	73989	4	169
30126	5	73991	6	26739
30127	5	73997	5	28167
30128	5	73999	7	8365
30129	5	74001	2	8984
30130	4	74002	7	26556
30131	4	74004	5	27629
30132	3	74005	1	21503
30133	5	74010	4	29229
30134	5	74012	4	2631
30135	4	74015	1	2056
30136	3	74019	5	29325
30137	4	74020	7	27144
30138	4	74021	7	29262
30139	5	74023	2	2101
30140	5	74024	7	25890
30141	5	74025	7	27385
30142	3	74025	1	27385
30143	5	74035	5	29212
30144	5	74036	5	29187
30145	3	74037	1	15425
30146	5	74038	7	20099
30147	4	74039	3	29233
30148	4	74040	2	28827
30149	3	74043	2	29256
30150	5	74046	2	27583
30151	5	74048	2	21733
30152	4	74049	5	18522
30153	5	74053	6	6954
30154	3	74060	3	29331
30155	2	74063	1	29289
30156	3	74066	1	7771
30157	3	74066	3	7771
30158	5	74069	3	28361
30159	3	74070	2	1393
30160	4	74075	3	226
30161	5	74082	4	9304
30162	5	74083	1	19125
30163	3	74086	1	29218
30164	4	74090	3	29241
30165	5	74091	2	28041
30166	5	74092	5	530
30167	5	74093	6	16978
30168	3	74094	1	18307
30169	5	74095	7	29344
30170	5	74096	2	16793
30171	5	74104	7	8683
30172	5	74109	7	15930
30173	5	74110	5	29342
30174	5	74111	2	1073
30175	4	74114	7	20999
30176	5	74116	1	29242
30177	1	74118	6	23670
30178	5	74119	2	1460
30179	5	74121	7	23877
30180	5	74123	1	14002
30181	4	74124	5	19523
30182	4	74127	5	26850
30183	5	74130	3	3540
30184	5	74134	7	4511
30185	5	74135	6	29353
30186	5	74136	3	18690
30187	5	74139	4	19894
30188	5	74140	7	18840
30189	5	74142	3	29322
30190	5	74150	5	14273
30191	5	74151	6	29313
30192	2	74152	6	29180
30193	5	74153	2	29240
30194	5	74153	7	29240
30195	5	74155	7	13081
30196	4	74158	1	29207
30197	5	74158	7	29207
30198	5	74159	6	11586
30199	5	74165	6	29223
30200	5	74166	1	27054
30201	5	74166	5	27054
30202	5	74167	4	22126
30203	5	74168	7	25032
30204	5	74169	6	10111
30205	1	74171	6	18887
30206	3	74173	1	13414
30207	2	74177	1	16296
30208	4	74178	6	28650
30209	5	74178	4	28650
30210	4	74179	5	12204
30211	5	74180	2	13498
30212	5	74182	7	29245
30213	4	74183	7	29210
30214	4	74185	2	24422
30215	4	74187	7	29276
30216	3	74189	5	18940
30217	3	74191	6	27538
30218	4	74193	3	1708
30219	5	74194	2	19674
30220	4	74195	2	29252
30221	4	74198	6	29234
30222	5	74199	3	29264
30223	3	74200	3	29368
30224	4	74202	7	27602
30225	5	74203	2	24351
30226	4	74206	6	12346
30227	4	74209	7	15146
30228	3	74210	1	29296
30229	5	74213	1	12109
30230	3	74214	3	5665
30231	5	74216	7	1344
30232	3	74218	5	2025
30233	4	74225	5	29261
30234	5	74226	6	21456
30235	5	74228	1	9941
30236	5	74231	6	21779
30237	3	74232	4	29367
30238	4	74234	3	7608
30239	5	74235	6	10306
30240	2	74236	6	29297
30241	4	74236	7	29297
30242	4	74239	5	29270
30243	4	74242	7	29334
30244	4	74244	5	6989
30245	5	74247	1	29309
30246	4	74248	1	13137
30247	5	74250	3	29258
30248	3	74251	5	2564
30249	5	74252	3	9783
30250	5	74257	4	29330
30251	4	74258	2	29308
30252	5	74264	4	1582
30253	4	74265	6	6840
30254	3	74266	5	5786
30255	4	74267	5	4195
30256	5	74272	7	22795
30257	5	74273	7	21203
30258	1	74275	6	29341
30259	5	74278	6	21474
30260	4	74281	4	1588
30261	3	74283	7	11560
30262	5	74284	2	29352
30263	5	74285	4	23925
30264	5	74286	1	29254
30265	3	74287	5	18312
30266	3	74289	5	29285
30267	1	74290	6	18125
30268	5	74292	2	25071
30269	5	74294	4	27188
30270	2	74295	3	4436
30271	5	74297	7	29255
30272	4	74298	5	20157
30273	2	74299	3	4655
30274	4	74299	5	4655
30275	4	74309	2	4242
30276	3	74310	5	9626
30277	5	74311	4	29217
30278	4	74315	4	10436
30279	3	74317	4	29204
30280	5	74318	6	29188
30281	4	74319	4	25453
30282	5	74320	7	16512
30283	4	74324	5	29364
30284	5	74328	3	437
30285	5	74329	4	24359
30286	4	74331	1	29181
30287	3	74332	4	29321
30288	5	74333	5	29257
30289	5	74338	4	29546
30290	2	74341	1	2965
30291	5	74342	2	24585
30292	5	74343	2	29483
30293	4	74349	7	29430
30294	3	74351	2	26150
30295	5	74358	2	29439
30296	5	74359	1	6623
30297	5	74363	7	3755
30298	5	74370	2	8167
30299	3	74372	5	29552
30300	5	74374	4	12464
30301	4	74377	7	13940
30302	3	74378	5	7768
30303	5	74382	4	7806
30304	4	74383	2	26324
30305	5	74384	7	29444
30306	1	74390	1	11576
30307	5	74391	5	25533
30308	4	74392	5	29380
30309	5	74393	1	20216
30310	4	74397	6	29517
30311	5	74398	5	25259
30312	5	74399	1	29468
30313	4	74405	2	17672
30314	5	74406	7	7876
30315	4	74409	3	2511
30316	3	74410	1	10151
30317	1	74412	6	26588
30318	5	74413	4	20819
30319	5	74414	1	1654
30320	4	74415	5	28109
30321	5	74420	4	1156
30322	4	74423	5	29382
30323	5	74424	2	27082
30324	5	74428	6	13899
30325	5	74430	4	25086
30326	2	74431	4	7338
30327	3	74432	2	20914
30328	3	74435	5	1352
30329	4	74437	7	3189
30330	5	74438	3	29428
30331	3	74441	1	5758
30332	3	74443	5	24295
30333	3	74447	7	138
30334	5	74449	2	29537
30335	3	74452	6	21983
30336	5	74453	5	29408
30337	1	74453	6	29408
30338	5	74460	5	14103
30339	5	74462	7	29536
30340	3	74465	1	13493
30341	4	74467	3	20189
30342	5	74467	4	20189
30343	4	74474	2	5215
30344	2	74475	4	26149
30345	3	74476	5	29432
30346	5	74479	7	29437
30347	4	74480	7	29482
30348	3	74485	2	21644
30349	5	74489	2	29455
30350	5	74497	4	10283
30351	5	74498	6	24716
30352	5	74499	6	2560
30353	5	74502	2	2050
30354	3	74505	1	25841
30355	4	74506	6	13328
30356	5	74507	2	9763
30357	5	74511	5	29467
30358	3	74512	5	1541
30359	5	74519	7	16496
30360	5	74522	4	3224
30361	5	74524	6	29451
30362	3	74526	7	8864
30363	5	74527	7	8050
30364	5	74531	2	2825
30365	4	74532	3	12180
30366	5	74534	2	21570
30367	3	74535	3	29486
30368	5	74540	6	1656
30369	4	74542	6	722
30370	1	74544	5	29558
30371	5	74545	1	18617
30372	4	74549	2	25827
30373	5	74552	6	6826
30374	5	74558	2	29434
30375	5	74560	3	20026
30376	5	74561	1	25318
30377	5	74562	5	26304
30378	5	74563	3	14870
30379	5	74564	4	8876
30380	3	74565	5	1142
30381	3	74566	1	29489
30382	5	74568	5	3053
30383	2	74569	7	16813
30384	4	74572	7	25077
30385	4	74573	7	24419
30386	5	74574	1	20692
30387	4	74575	4	29463
30388	5	74577	7	23393
30389	4	74578	3	25693
30390	4	74578	2	25693
30391	5	74580	5	11044
30392	3	74581	5	17739
30393	5	74582	2	9010
30394	3	74583	5	29488
30395	5	74583	4	29488
30396	5	74584	7	11896
30397	4	74584	6	11896
30398	5	74586	2	14267
30399	5	74587	4	29466
30400	4	74590	7	18564
30401	5	74590	6	18564
30402	5	74592	6	20815
30403	5	74597	1	1709
30404	3	74601	5	6410
30405	3	74602	5	5872
30406	4	74603	5	29524
30407	4	74610	3	12361
30408	3	74611	5	15930
30409	4	74611	6	15930
30410	3	74613	5	29347
30411	5	74615	2	2054
30412	3	74620	5	27721
30413	4	74621	7	12287
30414	5	74624	6	10694
30415	5	74627	5	956
30416	5	74635	6	7446
30417	5	74637	6	6080
30418	5	74638	1	23786
30419	5	74641	1	2217
30420	4	74643	5	29562
30421	3	74644	6	29547
30422	5	74645	5	8760
30423	5	74646	6	3190
30424	5	74647	7	16512
30425	5	74650	5	5996
30426	5	74655	2	29398
30427	5	74657	6	29416
30428	5	74658	7	28363
30429	3	74659	3	20126
30430	3	74662	5	29397
30431	3	74663	6	29448
30432	5	74665	2	8795
30433	4	74666	5	1079
30434	3	74676	7	2613
30435	5	74683	6	13896
30436	5	74684	5	4779
30437	5	74686	3	12476
30438	5	74687	5	27432
30439	4	74688	5	16068
30440	4	74690	7	10679
30441	5	74692	5	23140
30442	4	74693	5	29525
30443	5	74694	6	14284
30444	4	74695	7	10211
30445	5	74698	5	29393
30446	5	74699	2	26556
30447	5	74703	2	13575
30448	4	74708	7	228
30449	5	74714	1	13379
30450	5	74716	6	29414
30451	4	74719	2	5538
30452	5	74725	5	1476
30453	5	74729	2	4072
30454	3	74730	5	10438
30455	1	74732	1	15585
30456	5	74734	6	21003
30457	5	74738	2	20931
30458	5	74740	4	29377
30459	5	74742	6	4628
30460	4	74743	1	29553
30461	2	74745	1	26952
30462	3	74749	1	2331
30463	5	74751	3	29475
30464	4	74754	7	3629
30465	3	74758	2	29493
30466	5	74759	1	27237
30467	5	74762	6	11454
30468	5	74763	6	29460
30469	5	74764	2	754
30470	5	74767	5	29491
30471	4	74771	3	20712
30472	3	74772	7	19795
30473	3	74773	4	20202
30474	3	74777	3	27469
30475	3	74783	7	18936
30476	5	74787	2	29469
30477	4	74787	5	29469
30478	5	74790	6	29521
30479	5	74795	3	28750
30480	4	74797	3	2081
30481	5	74804	6	16445
30482	4	74807	3	13054
30483	4	74810	5	16844
30484	3	74811	5	3119
30485	4	74813	5	29424
30486	5	74817	7	29387
30487	5	74819	4	26
30488	3	74820	1	29405
30489	5	74820	6	29405
30490	4	74822	6	29459
30491	5	74824	2	15242
30492	5	74828	2	29511
30493	5	74828	3	29511
30494	3	74829	6	24277
30495	3	74831	7	17795
30496	5	74832	6	29236
30497	5	74833	1	29024
30498	5	74834	6	18542
30499	5	74837	4	6997
30500	5	74838	2	20479
30501	4	74839	1	13128
30502	3	74842	4	24025
30503	5	74843	1	9576
30504	5	74845	6	6619
30505	5	74850	6	14648
30506	3	74851	2	14113
30507	5	74852	2	10122
30508	5	74856	6	29396
30509	5	74858	1	26929
30510	5	74859	7	8135
30511	5	74863	2	29522
30512	5	74864	6	16963
30513	4	74868	7	29549
30514	5	74871	7	12602
30515	5	74872	5	29538
30516	5	74873	3	29426
30517	5	74876	7	10525
30518	4	74876	3	10525
30519	5	74878	4	29441
30520	3	74881	5	18168
30521	5	74882	6	20780
30522	4	74883	7	4595
30523	3	74884	5	11964
30524	5	74886	6	29446
30525	3	74887	5	29445
30526	5	74888	7	23709
30527	5	74889	6	4309
30528	5	74896	6	5975
30529	5	74896	4	5975
30530	5	74897	6	29388
30531	5	74900	4	6276
30532	5	74902	4	203
30533	4	74903	3	24160
30534	5	74904	4	5303
30535	5	74909	4	29510
30536	5	74911	2	20360
30537	2	74912	6	29436
30538	5	74920	4	28633
30539	3	74921	3	17588
30540	5	74924	5	22273
30541	5	74930	6	10526
30542	3	74931	5	29453
30543	3	74938	1	19497
30544	5	74942	2	17541
30545	5	74945	1	171
30546	5	74946	6	11709
30547	5	74951	7	27340
30548	4	74952	2	14288
30549	3	74952	6	14288
30550	3	74954	5	14380
30551	5	74956	6	29417
30552	5	74964	7	19486
30553	2	74970	3	29556
30554	5	74971	7	29470
30555	5	74972	2	15525
30556	5	74979	2	29514
30557	5	74980	4	10412
30558	4	74981	4	6385
30559	5	74983	4	3712
30560	5	74990	3	29411
30561	3	74991	5	14593
30562	5	74992	5	6099
30563	5	74996	5	15380
30564	5	74998	2	12390
30565	5	75001	4	12819
30566	5	75002	6	29544
30567	2	75003	3	15780
30568	5	75006	4	29373
30569	4	75008	7	15026
30570	3	75013	5	17005
30571	5	75016	3	19141
30572	3	75021	1	29456
30573	5	75022	3	19971
30574	3	75022	5	19971
30575	3	75025	5	13597
30576	2	75027	2	29526
30577	5	75029	7	12910
30578	5	75029	6	12910
30579	4	75030	2	14962
30580	5	75031	6	29465
30581	3	75033	3	6987
30582	5	75034	2	29495
30583	3	75038	1	17100
30584	5	75039	6	23074
30585	5	75043	3	15965
30586	5	75045	6	18652
30587	1	75046	6	11785
30588	4	75046	5	11785
30589	5	75054	6	10868
30590	5	75054	1	10868
30591	5	75058	4	2735
30592	5	75065	4	25173
30593	5	75068	5	13373
30594	5	75069	2	643
30595	5	75071	6	28120
30596	4	75077	6	4912
30597	5	75082	2	5110
30598	4	75083	7	18190
30599	5	75084	7	24787
30600	3	75084	3	24787
30601	3	75087	5	28173
30602	5	75089	1	27725
30603	5	75092	4	16916
30604	5	75095	6	16501
30605	5	75097	7	29513
30606	5	75101	1	5181
30607	3	75102	1	8561
30608	5	75106	6	22573
30609	4	75107	7	26154
30610	4	75111	3	25685
30611	5	75114	6	22149
30612	4	75115	6	5494
30613	3	75116	5	18445
30614	5	75119	2	29698
30615	2	75120	5	14897
30616	4	75124	3	22531
30617	4	75125	7	29737
30618	5	75129	6	12401
30619	3	75132	7	29598
30620	4	75135	5	19230
30621	4	75137	4	25535
30622	4	75138	4	15916
30623	1	75149	6	15079
30624	5	75150	4	2908
30625	4	75152	1	23947
30626	5	75153	6	28255
30627	5	75157	2	20816
30628	4	75158	2	11759
30629	4	75168	7	10920
30630	5	75168	4	10920
30631	5	75170	4	24788
30632	5	75172	1	1140
30633	2	75173	3	552
30634	5	75184	3	29614
30635	2	75185	6	17874
30636	4	75189	4	19909
30637	5	75190	3	1450
30638	5	75191	1	29586
30639	5	75196	7	14498
30640	4	75199	7	29659
30641	3	75204	7	24485
30642	4	75206	3	29731
30643	4	75210	1	6256
30644	5	75211	7	16219
30645	3	75214	3	10523
30646	4	75215	5	29666
30647	5	75220	6	6773
30648	3	75223	2	29718
30649	5	75225	4	2320
30650	4	75226	2	5945
30651	5	75228	6	29708
30652	4	75229	3	4001
30653	1	75233	5	29676
30654	4	75235	6	29689
30655	5	75236	6	16765
30656	5	75240	2	29640
30657	5	75241	3	29605
30658	5	75244	2	21866
30659	5	75245	1	28181
30660	4	75246	6	28517
30661	5	75249	2	11779
30662	4	75251	6	18900
30663	1	75252	6	19444
30664	5	75254	2	22832
30665	3	75255	2	29592
30666	5	75256	7	29714
30667	4	75258	5	29650
30668	1	75261	7	29597
30669	5	75264	2	4595
30670	4	75265	7	29569
30671	5	75268	4	29618
30672	5	75270	2	3052
30673	5	75273	3	29593
30674	3	75277	4	16101
30675	5	75281	6	29677
30676	4	75283	7	20684
30677	5	75290	1	11554
30678	5	75297	6	29691
30679	3	75298	4	18793
30680	5	75300	1	16681
30681	5	75302	7	28244
30682	1	75305	6	29690
30683	5	75306	3	9224
30684	4	75311	6	16774
30685	3	75312	7	27964
30686	1	75313	6	15872
30687	5	75315	3	22638
30688	4	75318	7	21848
30689	5	75319	4	12193
30690	4	75323	7	29566
30691	5	75324	7	5150
30692	5	75326	1	29632
30693	5	75328	4	23147
30694	5	75334	4	29644
30695	3	75336	1	14970
30696	5	75337	7	3761
30697	5	75340	6	664
30698	5	75340	1	664
30699	3	75344	5	28576
30700	5	75346	3	29576
30701	5	75348	5	18612
30702	5	75349	7	22319
30703	5	75350	5	28543
30704	5	75356	2	29671
30705	5	75357	7	26694
30706	5	75360	7	24074
30707	4	75362	5	1368
30708	5	75366	2	1529
30709	5	75368	3	11146
30710	3	75371	1	10547
30711	5	75374	3	7726
30712	3	75376	2	9021
30713	5	75380	4	29725
30714	4	75380	1	29725
30715	3	75383	4	17582
30716	5	75384	7	29590
30717	5	75386	6	21601
30718	5	75387	3	1869
30719	4	75391	2	20984
30720	5	75395	3	19506
30721	5	75396	7	10739
30722	3	75397	7	27657
30723	4	75400	5	29643
30724	5	75401	6	29591
30725	5	75402	7	17864
30726	5	75405	1	811
30727	5	75406	2	20408
30728	5	75410	2	29711
30729	3	75412	4	2552
30730	2	75413	1	22431
30731	4	75416	7	2415
30732	5	75417	4	21433
30733	3	75418	1	29656
30734	4	75421	4	6496
30735	5	75423	1	13766
30736	5	75424	7	1357
30737	3	75425	7	29622
30738	5	75426	7	16970
30739	3	75429	2	16788
30740	1	75430	6	25642
30741	5	75442	6	13314
30742	5	75445	3	29762
30743	3	75446	4	13799
30744	3	75447	1	29868
30745	5	75448	1	26361
30746	5	75449	4	15578
30747	5	75451	2	21643
30748	4	75452	2	11189
30749	4	75456	4	29881
30750	5	75460	7	3125
30751	3	75463	7	27557
30752	5	75464	2	29914
30753	4	75465	7	29820
30754	5	75465	2	29820
30755	5	75467	3	29744
30756	4	75471	7	29916
30757	4	75472	4	29760
30758	5	75475	2	8171
30759	4	75476	2	21388
30760	4	75477	1	15679
30761	5	75480	5	29922
30762	3	75481	3	74
30763	5	75482	2	29873
30764	5	75483	2	19678
30765	4	75484	7	27763
30766	3	75485	5	20230
30767	4	75486	5	1934
30768	4	75489	5	29793
30769	3	75491	7	29814
30770	3	75493	3	1871
30771	5	75495	7	28634
30772	2	75496	4	15855
30773	3	75497	5	29899
30774	3	75497	2	29899
30775	4	75498	6	23656
30776	5	75500	1	29773
30777	5	75501	5	28943
30778	4	75508	7	29797
30779	4	75509	4	13081
30780	5	75509	3	13081
30781	5	75512	6	398
30782	5	75516	5	9631
30783	5	75517	2	5556
30784	5	75522	6	29860
30785	3	75523	7	19605
30786	3	75525	5	3230
30787	5	75529	3	14947
30788	5	75530	5	1348
30789	4	75530	7	1348
30790	5	75533	6	29800
30791	5	75539	7	29830
30792	4	75540	7	638
30793	3	75543	5	15084
30794	1	75544	6	7122
30795	4	75545	1	24538
30796	3	75546	1	2052
30797	3	75548	4	12712
30798	5	75551	3	29857
30799	3	75553	3	15565
30800	4	75554	7	29749
30801	5	75559	6	29836
30802	5	75563	6	29763
30803	5	75564	2	22313
30804	5	75565	2	29832
30805	5	75571	6	29890
30806	5	75574	7	27100
30807	4	75576	5	4836
30808	3	75579	4	29842
30809	5	75580	7	15219
30810	3	75582	7	29093
30811	4	75583	2	6856
30812	4	75585	7	21257
30813	4	75586	2	29782
30814	5	75587	7	19016
30815	5	75588	6	29794
30816	5	75589	4	7666
30817	3	75600	5	15120
30818	5	75602	1	4202
30819	5	75604	4	29861
30820	3	75606	5	7388
30821	4	75606	3	7388
30822	5	75612	2	29920
30823	3	75613	7	29863
30824	5	75614	5	22547
30825	5	75616	1	29871
30826	4	75619	4	12602
30827	5	75620	3	6245
30828	5	75621	7	8821
30829	1	75624	6	29816
30830	4	75625	2	11681
30831	5	75627	6	23150
30832	5	75629	4	13843
30833	5	75630	1	19817
30834	5	75637	3	10367
30835	3	75640	7	743
30836	1	75643	6	29745
30837	3	75644	2	6039
30838	5	75650	3	29906
30839	3	75651	7	15360
30840	5	75654	4	3831
30841	4	75655	4	27181
30842	5	75656	4	21454
30843	5	75659	2	24107
30844	5	75663	6	5112
30845	4	75666	2	4459
30846	5	75667	6	9614
30847	3	75668	6	1299
30848	4	75670	7	6883
30849	5	75671	6	7102
30850	3	75672	7	7751
30851	5	75673	6	29897
30852	4	75675	3	14081
30853	5	75677	6	29867
30854	5	75677	4	29867
30855	4	75689	4	12031
30856	3	75689	3	12031
30857	5	75691	1	21779
30858	5	75692	7	29756
30859	5	75693	4	2964
30860	5	75694	2	8177
30861	4	75695	7	24534
30862	3	75696	1	11223
30863	5	75697	3	628
30864	4	75701	7	28773
30865	5	75703	6	3654
30866	5	75705	7	3069
30867	1	75707	6	20739
30868	5	75708	2	29837
30869	4	75709	6	19052
30870	5	75711	2	3711
30871	5	75713	2	20205
30872	5	75713	1	20205
30873	1	75720	3	24449
30874	5	75723	1	29809
30875	5	75724	7	20423
30876	3	75727	7	29810
30877	4	75727	1	29810
30878	5	75733	3	29811
30879	3	75734	5	3883
30880	4	75735	1	13213
30881	4	75737	6	18758
30882	5	75738	7	6847
30883	5	75740	6	18194
30884	5	75741	6	29841
30885	4	75742	5	29908
30886	5	75744	1	22784
30887	5	75748	7	28293
30888	3	75752	5	29757
30889	4	75754	2	29911
30890	5	75756	5	3117
30891	5	75763	6	9347
30892	3	75769	6	12287
30893	5	75770	7	29770
30894	4	75773	7	4152
30895	1	75774	4	29904
30896	5	75775	3	15602
30897	5	75777	1	8214
30898	4	75779	7	26206
30899	5	75780	4	1040
30900	3	75783	7	8492
30901	4	75785	4	10676
30902	3	75786	5	14207
30903	4	75789	5	29889
30904	5	75799	7	16371
30905	4	75800	1	29927
30906	4	75802	2	29791
30907	5	75804	2	6655
30908	5	75805	7	22755
30909	4	75810	4	29888
30910	4	75821	1	12912
30911	5	75822	2	9383
30912	5	75823	2	29903
30913	2	75825	6	6382
30914	5	75828	6	18754
30915	3	75828	5	18754
30916	4	75831	2	11559
30917	5	75833	6	29803
30918	5	75834	5	29838
30919	5	75835	1	29785
30920	4	75844	2	21432
30921	5	75848	6	29748
30922	5	75851	4	29229
30923	5	75852	1	4772
30924	4	75852	3	4772
30925	5	75853	1	832
30926	5	75855	1	27938
30927	4	75856	4	29831
30928	4	75861	7	9182
30929	5	75864	1	6518
30930	3	75868	5	29702
30931	4	75869	2	16501
30932	5	75871	2	16678
30933	5	75872	1	3320
30934	4	75873	5	30058
30935	5	75874	1	3940
30936	5	75875	4	12064
30937	4	75877	5	30079
30938	4	75881	5	29970
30939	5	75881	2	29970
30940	5	75882	4	30118
30941	5	75883	6	30024
30942	5	75886	5	20987
30943	4	75888	7	16330
30944	5	75890	1	11183
30945	4	75892	7	29997
30946	5	75892	2	29997
30947	3	75895	7	26698
30948	5	75896	2	28283
30949	5	75897	6	29975
30950	3	75900	2	1406
30951	4	75903	7	2602
30952	4	75906	7	29966
30953	4	75909	7	30067
30954	3	75913	1	30109
30955	5	75915	5	10442
30956	5	75916	4	7211
30957	5	75917	5	17673
30958	5	75918	2	27685
30959	5	75922	7	4100
30960	5	75923	4	17700
30961	1	75924	5	30094
30962	5	75929	6	7387
30963	3	75934	5	25348
30964	5	75936	3	25189
30965	4	75937	5	7688
30966	5	75940	6	5056
30967	5	75943	1	30029
30968	4	75945	1	26945
30969	5	75946	4	6399
30970	4	75948	1	12308
30971	4	75948	7	12308
30972	3	75949	7	30018
30973	5	75957	4	21980
30974	5	75959	6	30012
30975	5	75960	4	23788
30976	3	75961	7	30115
30977	5	75964	7	16680
30978	5	75966	1	30105
30979	4	75967	4	16850
30980	5	75971	6	15735
30981	5	75976	6	30107
30982	5	75979	7	802
30983	2	75979	6	802
30984	5	75984	7	13569
30985	4	75992	7	2838
30986	4	75993	3	4356
30987	5	75994	5	24578
30988	5	75995	5	30047
30989	2	75997	6	24536
30990	3	75997	5	24536
30991	5	76001	2	30075
30992	5	76003	1	583
30993	5	76005	1	30087
30994	3	76006	5	3306
30995	5	76008	6	29939
30996	5	76010	2	24048
30997	4	76011	2	3536
30998	5	76011	6	3536
30999	4	76013	1	19423
31000	4	76016	3	11818
31001	5	76021	1	6987
31002	4	76023	2	29961
31003	5	76025	4	29965
31004	4	76032	2	30026
31005	5	76034	1	1934
31006	5	76035	2	29977
31007	3	76036	5	30085
31008	3	76037	3	30022
31009	4	76041	5	2426
31010	5	76049	2	28357
31011	4	76050	7	27639
31012	5	76053	7	678
31013	5	76053	6	678
31014	5	76055	2	5110
31015	4	76056	2	8521
31016	4	76057	4	21251
31017	2	76060	7	13725
31018	4	76061	5	14776
31019	5	76062	7	29927
31020	4	76064	4	30074
31021	4	76067	7	9657
31022	5	76070	7	28116
31023	4	76071	5	1002
31024	5	76074	1	29950
31025	3	76077	4	20754
31026	4	76078	1	24018
31027	5	76079	1	26793
31028	4	76082	6	30088
31029	5	76089	5	26613
31030	3	76090	5	15855
31031	4	76097	5	13193
31032	3	76097	1	13193
31033	5	76103	6	3478
31034	5	76106	3	13996
31035	5	76107	5	16545
31036	5	76111	5	30101
31037	5	76113	6	30095
31038	5	76114	6	5881
31039	4	76115	7	14881
31040	4	76125	6	1265
31041	4	76129	7	15532
31042	4	76131	4	2085
31043	5	76136	2	24632
31044	5	76138	3	30011
31045	4	76139	1	29980
31046	3	76141	5	3257
31047	4	76142	7	28093
31048	4	76142	3	28093
31049	5	76143	6	11466
31050	3	76145	3	30015
31051	5	76149	1	21814
31052	5	76150	6	18123
31053	5	76151	6	29936
31054	5	76152	4	30036
31055	3	76165	2	29938
31056	5	76169	1	25790
31057	4	76169	5	25790
31058	5	76172	5	28177
31059	5	76176	7	12297
31060	3	76177	3	29987
31061	5	76181	2	2753
31062	5	76183	7	23529
31063	4	76184	6	4687
31064	5	76186	4	19742
31065	3	76188	5	29377
31066	5	76189	6	9927
31067	2	76190	6	23457
31068	4	76192	5	4279
31069	3	76192	2	4279
31070	5	76193	7	18086
31071	3	76196	3	30009
31072	5	76197	7	30078
31073	5	76197	1	30078
31074	5	76198	6	29989
31075	3	76203	3	29959
31076	5	76205	2	29080
31077	3	76206	2	22894
31078	5	76207	6	29991
31079	1	76210	6	30097
31080	5	76211	6	29941
31081	4	76212	7	30063
31082	4	76214	3	30043
31083	5	76215	1	21038
31084	3	76221	5	30119
31085	5	76223	6	28607
31086	5	76225	6	30034
31087	2	76226	6	15363
31088	1	76232	4	3123
31089	5	76232	1	3123
31090	5	76238	2	3168
31091	3	76239	3	24082
31092	5	76244	2	29934
31093	5	76247	2	14046
31094	5	76250	1	29978
31095	5	76252	2	7899
31096	5	76253	1	29999
31097	3	76256	4	21552
31098	5	76259	4	30071
31099	5	76261	4	3863
31100	5	76264	7	13673
31101	5	76266	7	15595
31102	5	76267	4	30066
31103	5	76269	2	17402
31104	4	76272	3	30083
31105	4	76273	3	27720
31106	5	76274	6	28925
31107	4	76279	5	29940
31108	3	76282	4	9771
31109	3	76285	6	27886
31110	3	76288	3	30016
31111	5	76291	3	29996
31112	5	76292	3	20390
31113	3	76293	5	30093
31114	5	76294	5	20324
31115	3	76294	3	20324
31116	5	76296	7	6678
31117	5	76297	2	21606
31118	5	76298	7	6184
31119	5	76300	2	30052
31120	5	76301	7	27925
31121	5	76302	7	26040
31122	5	76307	3	13466
31123	5	76308	6	23594
31124	5	76309	2	18755
31125	3	76311	5	29954
31126	5	76314	2	23411
31127	1	76315	5	9377
31128	3	76318	7	27965
31129	5	76319	1	29988
31130	4	76320	7	30056
31131	4	76321	3	9103
31132	4	76324	5	1183
31133	5	76326	6	30048
31134	4	76329	5	8145
31135	5	76330	4	19506
31136	5	76331	7	30064
31137	4	76334	1	601
31138	5	76337	4	11067
31139	4	76338	2	30028
31140	2	76340	7	29946
31141	5	76344	7	14391
31142	5	76344	6	14391
31143	5	76346	2	29311
31144	3	76357	5	29947
31145	5	76359	2	29981
31146	4	76359	5	29981
31147	2	76360	1	820
31148	3	76361	1	30038
31149	5	76361	7	30038
31150	5	76363	7	8436
31151	5	76368	6	7586
31152	4	76370	7	30001
31153	3	76374	5	30065
31154	5	76383	6	10129
31155	5	76388	4	11756
31156	5	76390	7	18627
31157	5	76390	3	18627
31158	5	76391	6	13939
31159	2	76397	6	12952
31160	4	76404	5	22222
31161	5	76406	5	5952
31162	3	76406	3	5952
31163	5	76415	7	23466
31164	5	76418	2	4066
31165	3	76420	6	30072
31166	5	76422	4	30194
31167	5	76423	7	30122
31168	4	76426	7	16409
31169	3	76428	1	18102
31170	3	76428	5	18102
31171	5	76429	2	8597
31172	5	76430	3	20957
31173	5	76435	4	30217
31174	5	76436	6	30170
31175	5	76438	6	12667
31176	4	76440	1	9647
31177	5	76447	2	4737
31178	5	76449	3	28629
31179	4	76450	7	30297
31180	3	76452	7	30195
31181	5	76453	6	30214
31182	5	76458	6	7770
31183	5	76458	3	7770
31184	3	76462	5	30287
31185	5	76465	2	20410
31186	5	76466	7	11245
31187	4	76467	6	30256
31188	5	76469	2	16124
31189	5	76470	1	26396
31190	3	76471	6	26520
31191	3	76473	7	25313
31192	5	76475	4	25545
31193	3	76476	5	17750
31194	5	76478	2	30227
31195	4	76479	1	29849
31196	5	76481	2	12467
31197	5	76483	5	13172
31198	5	76487	7	30251
31199	4	76488	6	1517
31200	4	76489	1	13942
31201	5	76491	7	20568
31202	5	76495	5	1132
31203	5	76500	4	24303
31204	4	76501	2	14023
31205	5	76503	2	30211
31206	5	76504	6	16596
31207	4	76505	6	15329
31208	4	76507	2	30124
31209	5	76508	1	3177
31210	5	76509	1	26963
31211	3	76514	7	12261
31212	5	76520	4	26326
31213	3	76521	5	9840
31214	5	76529	2	22871
31215	1	76530	4	2631
31216	5	76531	6	1814
31217	5	76533	4	16012
31218	5	76535	5	27025
31219	5	76539	2	30285
31220	5	76540	6	29810
31221	3	76548	7	28288
31222	4	76548	4	28288
31223	5	76549	3	30274
31224	5	76550	6	30225
31225	3	76550	7	30225
31226	5	76551	1	14845
31227	5	76562	7	4020
31228	2	76565	4	7204
31229	5	76566	4	2570
31230	5	76567	1	30140
31231	5	76569	1	17794
31232	4	76572	5	10190
31233	4	76573	5	10179
31234	5	76576	4	30213
31235	5	76578	1	7139
31236	5	76581	1	17244
31237	4	76585	2	1445
31238	5	76589	3	30130
31239	5	76592	3	30242
31240	5	76593	1	2342
31241	3	76594	1	30232
31242	4	76599	4	30229
31243	5	76600	6	30164
31244	3	76607	5	22378
31245	3	76608	1	30177
31246	4	76609	1	23648
31247	3	76609	3	23648
31248	5	76610	1	20031
31249	5	76611	4	19711
31250	5	76612	7	15713
31251	5	76612	2	15713
31252	5	76613	6	16569
31253	5	76614	1	30244
31254	4	76618	2	5930
31255	5	76620	2	30269
31256	4	76621	1	30163
31257	4	76621	6	30163
31258	3	76622	5	19488
31259	4	76627	4	24041
31260	4	76629	5	27493
31261	5	76632	2	23156
31262	4	76633	6	22964
31263	4	76635	5	22261
31264	3	76635	7	22261
31265	5	76637	5	17005
31266	5	76640	7	21675
31267	5	76642	6	30196
31268	5	76653	3	30166
31269	4	76655	2	9566
31270	5	76658	7	23836
31271	5	76663	3	15386
31272	4	76668	7	24914
31273	5	76670	4	18353
31274	5	76672	6	1315
31275	5	76675	4	30146
31276	5	76676	1	395
31277	5	76677	2	23111
31278	3	76686	4	1989
31279	5	76694	6	29974
31280	5	76695	2	620
31281	5	76696	7	30150
31282	5	76699	2	30197
31283	4	76701	5	30149
31284	4	76710	7	30305
31285	3	76712	4	14826
31286	3	76713	3	2426
31287	5	76715	2	6246
31288	4	76716	3	30207
31289	5	76723	5	30144
31290	5	76725	6	21868
31291	3	76726	1	18351
31292	4	76728	6	15546
31293	5	76733	2	28971
31294	5	76734	4	27545
31295	3	76736	3	30252
31296	5	76737	7	30143
31297	5	76740	1	25827
31298	5	76744	6	17717
31299	3	76745	7	13856
31300	4	76752	5	12666
31301	3	76754	4	1632
31302	5	76760	3	7279
31303	4	76763	2	16430
31304	5	76765	6	17966
31305	4	76770	3	19965
31306	5	76773	6	23651
31307	5	76777	1	7927
31308	4	76781	1	304
31309	5	76782	2	30182
31310	5	76784	3	30141
31311	4	76789	3	30184
31312	5	76791	3	1706
31313	5	76795	1	534
31314	4	76802	3	28019
31315	5	76806	6	11043
31316	5	76807	4	30139
31317	5	76809	4	9560
31318	3	76813	7	10235
31319	5	76813	6	10235
31320	5	76815	5	2080
31321	4	76816	5	15552
31322	4	76818	5	30219
31323	5	76819	7	14929
31324	5	76821	2	30278
31325	3	76828	4	30224
31326	5	76828	2	30224
31327	5	76834	6	3471
31328	4	76836	5	27925
31329	5	76836	2	27925
31330	4	76837	7	7118
31331	4	76841	5	30261
31332	4	76842	3	9175
31333	4	76843	7	2198
31334	5	76845	5	13010
31335	5	76845	2	13010
31336	5	76848	2	5668
31337	5	76849	2	25367
31338	5	76851	1	30205
31339	5	76852	6	19906
31340	5	76853	7	11806
31341	4	76860	7	30273
31342	5	76862	6	30198
31343	5	76865	5	16989
31344	5	76872	2	30281
31345	5	76874	5	2945
31346	5	76875	2	23243
31347	3	76878	5	17583
31348	4	76880	7	24794
31349	5	76882	2	30153
31350	5	76885	6	21532
31351	4	76886	7	10258
31352	4	76887	1	4295
31353	5	76895	7	28579
31354	5	76896	6	22648
31355	5	76897	7	30135
31356	5	76898	7	18840
31357	5	76899	7	4223
31358	5	76902	6	6674
31359	5	76905	2	9001
31360	4	76906	7	7550
31361	5	76910	7	27012
31362	5	76911	2	7280
31363	5	76913	6	19000
31364	5	76915	4	4797
31365	5	76916	6	30175
31366	1	76918	4	30236
31367	5	76918	7	30236
31368	5	76921	5	30169
31369	4	76922	4	2858
31370	4	76924	6	28348
31371	3	76925	1	30307
31372	5	76925	6	30307
31373	4	76926	7	531
31374	4	76928	7	25842
31375	5	76931	6	11976
31376	3	76933	7	5140
31377	5	76934	5	30193
31378	1	76935	6	6854
31379	4	76939	7	21939
31380	5	76942	2	9575
31381	5	76944	2	20738
31382	5	76948	2	489
31383	5	76950	6	802
31384	3	76957	7	27665
31385	4	76959	5	16952
31386	5	76963	5	30370
31387	4	76964	5	30348
31388	5	76967	2	10180
31389	5	76968	6	21245
31390	5	76969	1	30468
31391	2	76970	5	28045
31392	5	76978	4	6988
31393	5	76979	6	29484
31394	5	76981	6	24719
31395	5	76983	7	30328
31396	4	76985	1	30380
31397	3	76987	3	123
31398	5	76990	5	5760
31399	1	76991	2	30489
31400	4	76995	2	23954
31401	5	76996	5	17587
31402	5	76998	3	11932
31403	5	77000	7	29647
31404	4	77001	4	30343
31405	5	77002	3	30445
31406	5	77002	2	30445
31407	5	77005	7	26232
31408	4	77007	3	2600
31409	4	77008	5	30502
31410	3	77013	2	22641
31411	4	77014	6	9000
31412	5	77017	3	30396
31413	5	77019	2	6134
31414	5	77023	2	30318
31415	4	77023	3	30318
31416	5	77024	6	1568
31417	5	77026	6	5149
31418	5	77028	1	30390
31419	5	77029	6	20094
31420	5	77034	7	9958
31421	3	77035	7	29017
31422	4	77035	5	29017
31423	4	77036	6	27889
31424	5	77037	6	30429
31425	5	77041	7	7914
31426	3	77043	7	21442
31427	5	77044	6	3227
31428	5	77046	6	30384
31429	1	77046	4	30384
31430	5	77053	4	6396
31431	3	77056	5	7849
31432	5	77059	4	30460
31433	5	77059	6	30460
31434	4	77060	3	22822
31435	5	77061	5	2413
31436	5	77062	2	30349
31437	5	77064	6	21223
31438	3	77065	5	30456
31439	5	77067	2	30423
31440	3	77070	4	21003
31441	5	77070	2	21003
31442	5	77071	1	856
31443	5	77074	6	14422
31444	5	77076	3	30434
31445	5	77077	5	21701
31446	5	77078	6	23097
31447	5	77082	7	30386
31448	5	77083	6	30377
31449	5	77084	5	30451
31450	5	77088	2	3278
31451	4	77090	2	6446
31452	4	77091	5	30354
31453	3	77094	7	19003
31454	1	77095	2	30382
31455	4	77103	1	30498
31456	4	77104	4	22572
31457	5	77110	4	4818
31458	3	77112	5	30413
31459	5	77113	3	16346
31460	5	77115	4	30479
31461	5	77121	6	7772
31462	5	77126	4	24798
31463	4	77127	5	17503
31464	5	77129	6	11435
31465	2	77130	6	30331
31466	3	77131	4	24580
31467	4	77132	3	1449
31468	3	77133	4	30325
31469	2	77136	2	28430
31470	4	77138	4	30360
31471	3	77139	5	30369
31472	5	77142	2	30332
31473	4	77144	1	30408
31474	5	77146	4	30342
31475	4	77148	6	10669
31476	5	77152	5	30447
31477	5	77153	6	30452
31478	5	77154	2	30442
31479	2	77158	3	18350
31480	4	77160	4	10183
31481	5	77163	6	30381
31482	5	77173	2	30427
31483	5	77173	5	30427
31484	5	77179	6	30448
31485	1	77183	6	18343
31486	3	77185	7	30430
31487	3	77185	6	30430
31488	5	77186	3	30439
31489	5	77193	2	14054
31490	1	77195	6	7358
31491	5	77199	2	30399
31492	3	77203	7	19665
31493	4	77205	4	7365
31494	5	77208	2	30462
31495	5	77211	4	15752
31496	5	77214	7	30473
31497	5	77214	5	30473
31498	4	77218	6	12466
31499	5	77224	3	22153
31500	5	77225	7	30412
31501	5	77225	3	30412
31502	3	77226	4	30444
31503	4	77228	4	30415
31504	4	77231	3	18833
31505	5	77233	4	24257
31506	4	77238	5	30385
31507	5	77245	6	3868
31508	5	77250	7	29702
31509	5	77251	3	28866
31510	3	77252	3	30315
31511	5	77261	5	24964
31512	4	77262	5	833
31513	4	77267	7	20852
31514	5	77269	6	22094
31515	5	77273	2	2561
31516	3	77276	5	17794
31517	2	77277	5	13081
31518	5	77279	5	30457
31519	5	77282	5	26033
31520	5	77286	3	4943
31521	4	77287	3	3211
31522	5	77289	6	13940
31523	5	77290	7	787
31524	5	77295	3	30375
31525	3	77296	7	28579
31526	5	77298	1	23434
31527	3	77303	5	30371
31528	5	77305	3	8700
31529	5	77307	7	30362
31530	5	77308	2	30334
31531	5	77310	3	23268
31532	5	77310	2	23268
31533	5	77311	5	2537
31534	3	77316	3	21862
31535	4	77320	7	18973
31536	5	77323	4	3687
31537	4	77325	2	13840
31538	5	77328	2	30345
31539	4	77331	7	30501
31540	5	77334	1	26936
31541	5	77336	6	30340
31542	1	77338	6	926
31543	4	77341	7	11436
31544	4	77342	1	9352
31545	4	77343	3	15158
31546	4	77346	1	4578
31547	5	77347	5	30378
31548	4	77352	7	25827
31549	5	77354	7	27783
31550	5	77355	3	30364
31551	4	77358	1	7246
31552	2	77359	6	30391
31553	4	77364	6	29929
31554	5	77368	1	30387
31555	4	77374	3	22564
31556	3	77376	7	15590
31557	4	77378	7	20989
31558	5	77381	4	2758
31559	3	77384	6	29723
31560	3	77384	5	29723
31561	5	77385	1	21159
31562	4	77387	4	667
31563	4	77390	3	28768
31564	5	77395	7	30503
31565	3	77397	5	30355
31566	4	77398	3	12391
31567	4	77399	5	30490
31568	3	77401	5	30496
31569	4	77402	2	11983
31570	5	77405	3	14406
31571	5	77406	2	20452
31572	5	77407	6	4832
31573	5	77410	6	6465
31574	5	77412	6	30432
31575	5	77414	1	30488
31576	5	77415	3	25410
31577	1	77416	6	5183
31578	4	77418	5	1293
31579	5	77420	7	30523
31580	5	77422	3	7151
31581	4	77423	1	14073
31582	5	77433	6	24709
31583	4	77434	5	16175
31584	3	77436	5	30602
31585	4	77438	2	20579
31586	1	77439	6	10571
31587	3	77441	5	30698
31588	5	77442	6	30686
31589	4	77447	2	5649
31590	5	77449	6	25276
31591	5	77451	2	9360
31592	5	77453	2	7606
31593	4	77454	5	7280
31594	5	77458	4	13664
31595	2	77461	6	2347
31596	4	77462	7	11172
31597	5	77463	4	6055
31598	5	77466	4	1859
31599	5	77467	7	9998
31600	5	77469	2	30545
31601	5	77470	1	30592
31602	4	77471	7	748
31603	4	77472	7	30509
31604	5	77473	6	26769
31605	3	77478	1	4242
31606	5	77479	2	26981
31607	5	77480	6	30514
31608	3	77481	3	30615
31609	4	77482	5	30706
31610	3	77482	1	30706
31611	5	77483	4	15816
31612	4	77485	4	30649
31613	3	77486	1	26405
31614	4	77487	4	29888
31615	2	77493	5	10103
31616	5	77495	2	13365
31617	5	77495	7	13365
31618	5	77496	3	21610
31619	5	77498	3	16312
31620	5	77499	7	29188
31621	3	77501	5	10433
31622	5	77503	1	30528
31623	1	77506	6	30684
31624	5	77507	3	19382
31625	3	77508	3	28670
31626	5	77509	3	21989
31627	5	77514	6	30608
31628	5	77515	1	11239
31629	5	77516	6	868
31630	4	77517	5	7227
31631	5	77518	6	19181
31632	5	77522	4	30687
31633	4	77524	2	30694
31634	3	77525	2	30617
31635	4	77525	7	30617
31636	5	77527	2	2511
31637	3	77529	7	30647
31638	5	77531	1	23082
31639	3	77533	7	15603
31640	5	77534	4	10738
31641	5	77536	6	20473
31642	3	77538	7	23729
31643	4	77543	6	30547
31644	4	77546	7	30573
31645	5	77555	3	25259
31646	5	77556	4	30705
31647	4	77560	4	27795
31648	4	77562	3	30679
31649	5	77564	7	30693
31650	5	77565	2	23561
31651	5	77567	1	30623
31652	5	77569	2	9039
31653	3	77570	4	14608
31654	3	77582	5	5891
31655	2	77583	6	13759
31656	4	77586	7	25757
31657	5	77587	6	30605
31658	4	77591	5	27861
31659	3	77593	7	24479
31660	3	77594	5	30658
31661	3	77595	1	26361
31662	5	77596	2	15995
31663	5	77598	3	30631
31664	4	77599	2	30710
31665	4	77600	3	21439
31666	5	77601	1	25751
31667	4	77606	3	16855
31668	5	77607	4	26788
31669	5	77608	6	15380
31670	5	77610	4	19836
31671	4	77612	5	10837
31672	5	77614	2	18307
31673	4	77616	4	18590
31674	3	77617	5	11477
31675	3	77622	5	17408
31676	5	77623	2	30413
31677	4	77624	1	4913
31678	4	77626	6	13518
31679	2	77629	6	6134
31680	4	77636	3	11969
31681	4	77643	7	30625
31682	4	77644	7	30613
31683	1	77648	4	838
31684	4	77652	2	30540
31685	4	77658	7	1991
31686	5	77659	3	14358
31687	5	77659	7	14358
31688	5	77660	6	26621
31689	4	77664	5	30530
31690	3	77666	2	30601
31691	5	77667	2	30672
31692	5	77670	6	5681
31693	5	77670	4	5681
31694	4	77672	3	24585
31695	5	77674	1	9324
31696	5	77677	7	17649
31697	4	77678	5	20820
31698	5	77680	4	628
31699	5	77681	1	30689
31700	5	77681	4	30689
31701	5	77682	6	6019
31702	5	77682	4	6019
31703	5	77684	5	30546
31704	5	77684	2	30546
31705	5	77685	6	14212
31706	3	77686	5	30671
31707	5	77687	2	17944
31708	5	77692	6	18757
31709	5	77694	2	30682
31710	4	77695	3	29394
31711	4	77703	4	15728
31712	5	77704	4	30518
31713	5	77705	7	19883
31714	4	77707	7	30709
31715	5	77709	7	19097
31716	5	77711	2	23623
31717	3	77715	5	14777
31718	5	77717	2	698
31719	5	77721	5	10520
31720	5	77725	1	2334
31721	5	77728	7	18145
31722	5	77731	4	4662
31723	1	77732	5	18593
31724	4	77734	6	30627
31725	3	77736	3	2543
31726	5	77737	3	30567
31727	5	77738	6	14125
31728	4	77739	4	30604
31729	5	77739	6	30604
31730	5	77740	6	3629
31731	3	77741	7	30696
31732	4	77744	6	27198
31733	3	77745	1	30571
31734	4	77747	7	13749
31735	5	77748	6	14364
31736	5	77753	6	30695
31737	4	77757	7	3260
31738	4	77758	7	3648
31739	4	77760	5	29851
31740	3	77762	7	7143
31741	3	77763	5	13444
31742	5	77765	4	30708
31743	5	77766	1	30628
31744	2	77767	7	3507
31745	4	77769	5	18667
31746	3	77772	5	30511
31747	5	77775	6	10793
31748	5	77776	2	22415
31749	4	77776	3	22415
31750	4	77777	4	20807
31751	5	77778	6	7899
31752	2	77779	6	701
31753	2	77781	1	4790
31754	5	77787	2	7727
31755	4	77789	1	13446
31756	5	77791	2	19656
31757	5	77797	7	30674
31758	5	77798	6	30566
31759	4	77800	1	30700
31760	5	77800	4	30700
31761	3	77801	5	22053
31762	4	77803	5	10298
31763	5	77804	4	15319
31764	5	77811	7	27613
31765	5	77811	6	27613
31766	1	77813	7	8193
31767	5	77816	6	20883
31768	5	77818	1	30558
31769	3	77825	1	4850
31770	5	77827	6	29164
31771	4	77828	7	21002
31772	3	77837	5	21590
31773	5	77838	4	11573
31774	2	77840	3	11181
31775	5	77840	6	11181
31776	3	77841	4	30572
31777	5	77843	3	30554
31778	4	77844	2	1536
31779	5	77845	2	27494
31780	5	77846	2	30580
31781	4	77847	3	30256
31782	4	77851	5	30568
31783	2	77854	4	2891
31784	5	77855	4	787
31785	5	77856	4	30574
31786	1	77860	6	27860
31787	4	77864	6	3825
31788	5	77865	2	30113
31789	5	77866	1	30640
31790	4	77867	1	30637
31791	5	77868	5	30611
31792	5	77868	4	30611
31793	5	77869	6	7049
31794	5	77873	1	13891
31795	5	77874	2	3170
31796	1	77880	7	28600
31797	5	77882	6	23164
31798	5	77883	6	30533
31799	5	77885	4	20392
31800	4	77887	2	30594
31801	5	77889	2	30656
31802	3	77893	7	29312
31803	5	77898	5	30565
31804	5	77915	1	2176
31805	4	77916	2	30600
31806	3	77917	4	28060
31807	3	77918	5	30711
31808	5	77919	6	30603
31809	5	77920	6	26622
31810	1	77921	6	3573
31811	5	77923	3	1792
31812	5	77927	6	28313
31813	5	77928	5	4674
31814	4	77929	4	18060
31815	5	77930	1	29900
31816	5	77931	2	8491
31817	5	77935	6	17000
31818	4	77937	1	21064
31819	4	77938	1	13535
31820	4	77939	4	6652
31821	5	77940	7	30635
31822	4	77943	3	15044
31823	5	77946	4	30655
31824	5	77948	1	30591
31825	3	77951	3	17019
31826	5	77955	7	6736
31827	4	77957	5	16858
31828	5	77958	4	30535
31829	4	77959	2	12793
31830	4	77960	7	18240
31831	4	77961	7	30633
31832	3	77963	1	6790
31833	5	77966	2	19143
31834	4	77968	7	30560
31835	2	77976	4	30653
31836	5	77981	6	26386
31837	4	77985	3	14531
31838	5	77988	7	30703
31839	3	77990	5	30646
31840	3	77993	6	10653
31841	5	77994	5	1042
31842	5	77994	2	1042
31843	3	77996	4	12078
31844	3	77999	4	17898
31845	5	78000	6	25723
31846	5	78001	4	30661
31847	4	78003	7	6640
31848	5	78004	3	30582
31849	5	78011	6	30629
31850	5	78012	7	30559
31851	4	78013	3	17015
31852	5	78015	1	30620
31853	3	78018	4	17675
31854	5	78020	6	30522
31855	1	78024	6	12906
31856	4	78026	1	9844
31857	5	78029	6	30677
31858	5	78030	1	30507
31859	5	78031	4	20898
31860	5	78032	3	27191
31861	5	78033	6	20780
31862	5	78034	5	13610
31863	5	78035	4	11756
31864	5	78037	7	30667
31865	5	78039	1	30673
31866	5	78039	6	30673
31867	3	78040	5	26607
31868	2	78042	4	9791
31869	3	78043	3	27118
31870	5	78049	4	30662
31871	3	78053	5	28380
31872	5	78056	3	12137
31873	5	78057	2	8937
31874	3	78060	5	28530
31875	5	78061	6	8707
31876	3	78067	5	30873
31877	4	78070	5	25108
31878	2	78071	7	9525
31879	5	78074	5	16071
31880	4	78078	3	9733
31881	5	78078	6	9733
31882	5	78079	6	12841
31883	5	78080	5	30720
31884	4	78082	7	27872
31885	3	78082	6	27872
31886	4	78085	7	9079
31887	5	78087	6	19112
31888	5	78089	4	19363
31889	1	78089	6	19363
31890	3	78099	5	1387
31891	4	78102	4	30856
31892	4	78103	6	664
31893	3	78110	2	9024
31894	5	78111	6	18283
31895	4	78114	4	14451
31896	4	78122	2	13827
31897	3	78124	6	11029
31898	1	78127	6	29379
31899	5	78129	7	30912
31900	5	78131	6	30828
31901	5	78132	5	6787
31902	5	78133	6	14867
31903	4	78134	5	30889
31904	4	78135	2	7058
31905	3	78139	4	30892
31906	5	78141	7	30802
31907	5	78143	2	19244
31908	5	78144	3	2130
31909	5	78145	6	30918
31910	5	78146	7	29922
31911	5	78148	4	30786
31912	3	78151	2	30781
31913	2	78152	3	3320
31914	5	78153	2	5662
31915	5	78156	1	30813
31916	5	78161	1	10101
31917	3	78165	6	23130
31918	3	78167	3	8898
31919	3	78169	5	30830
31920	5	78174	7	30869
31921	3	78176	1	13685
31922	5	78179	4	26407
31923	3	78182	6	30782
31924	5	78183	2	30833
31925	5	78188	6	19589
31926	5	78189	6	25297
31927	5	78193	5	665
31928	4	78194	4	7208
31929	4	78196	3	8338
31930	5	78197	6	30884
31931	5	78201	4	30809
31932	5	78203	2	30773
31933	5	78204	2	7211
31934	2	78210	1	30865
31935	5	78219	2	12990
31936	5	78222	5	10323
31937	3	78224	3	30745
31938	5	78225	4	2865
31939	5	78227	2	24422
31940	5	78229	1	5075
31941	4	78231	7	30862
31942	5	78233	1	119
31943	5	78234	4	4166
31944	2	78236	3	30779
31945	5	78242	1	16187
31946	5	78244	4	2854
31947	1	78247	6	19419
31948	4	78248	4	28446
31949	1	78249	4	30797
31950	5	78253	2	30925
31951	4	78254	3	27693
31952	5	78255	4	30845
31953	5	78256	4	30774
31954	4	78257	1	4703
31955	5	78258	4	22383
31956	4	78258	1	22383
31957	3	78261	2	8381
31958	4	78262	4	28748
31959	5	78267	7	30844
31960	5	78270	6	3314
31961	3	78274	3	10317
31962	3	78274	7	10317
31963	4	78275	3	810
31964	5	78276	6	16469
31965	5	78278	5	20545
31966	4	78281	6	21444
31967	3	78282	2	13808
31968	5	78291	7	30799
31969	4	78296	1	8223
31970	5	78297	7	30749
31971	5	78300	6	30811
31972	5	78301	3	30766
31973	5	78303	7	30780
31974	5	78306	2	21811
31975	4	78308	7	25510
31976	5	78312	2	11739
31977	5	78313	4	13166
31978	3	78314	3	30800
31979	5	78316	6	23464
31980	4	78318	2	4414
31981	4	78319	1	1896
31982	4	78321	7	23527
31983	5	78321	6	23527
31984	5	78322	5	30929
31985	5	78323	4	6148
31986	5	78324	5	26416
31987	5	78326	4	8311
31988	5	78328	4	889
31989	2	78338	1	30823
31990	3	78338	7	30823
31991	5	78339	2	12393
31992	4	78344	7	30854
31993	3	78345	2	30754
31994	5	78346	6	15717
31995	5	78347	6	6342
31996	4	78349	7	30755
31997	5	78356	5	6076
31998	4	78358	7	7871
31999	3	78358	4	7871
32000	5	78360	2	23241
32001	2	78361	3	18927
32002	5	78363	1	30907
32003	5	78367	6	30914
32004	4	78368	4	12336
32005	4	78369	4	20581
32006	5	78370	3	1920
32007	5	78376	7	2538
32008	5	78376	6	2538
32009	4	78377	3	30415
32010	5	78378	6	17245
32011	3	78382	4	30718
32012	5	78383	7	26035
32013	3	78384	5	6022
32014	5	78385	6	19783
32015	5	78387	2	28320
32016	5	78391	4	11380
32017	5	78392	6	30721
32018	4	78394	4	24911
32019	5	78395	2	2442
32020	5	78396	2	906
32021	5	78398	5	7704
32022	4	78399	1	22997
32023	5	78401	6	113
32024	5	78402	6	27106
32025	3	78404	6	19348
32026	3	78404	5	19348
32027	5	78406	7	15334
32028	3	78407	4	12474
32029	4	78409	5	30926
32030	3	78410	2	3480
32031	5	78411	1	12666
32032	5	78414	7	30821
32033	5	78415	6	10875
32034	4	78419	6	21562
32035	5	78422	5	23246
32036	3	78424	5	24165
32037	3	78428	7	14905
32038	5	78432	2	7140
32039	3	78433	2	30866
32040	5	78437	4	6092
32041	4	78437	7	6092
32042	1	78440	1	4020
32043	4	78442	5	1079
32044	5	78442	6	1079
32045	2	78443	6	30842
32046	1	78444	3	2933
32047	4	78447	5	9008
32048	3	78448	1	30751
32049	5	78450	6	30908
32050	5	78451	1	23665
32051	3	78452	4	5430
32052	4	78458	2	2443
32053	5	78459	5	30744
32054	5	78460	1	11841
32055	2	78463	1	615
32056	3	78469	2	30792
32057	4	78470	7	7500
32058	3	78472	7	20211
32059	5	78473	7	8548
32060	4	78474	7	19891
32061	4	78477	4	30731
32062	4	78478	2	13662
32063	3	78483	5	25141
32064	4	78484	7	19760
32065	5	78488	7	5773
32066	4	78490	1	17687
32067	4	78492	1	30835
32068	3	78502	4	5878
32069	5	78502	2	5878
32070	4	78506	2	9967
32071	5	78508	2	29962
32072	5	78509	6	29845
32073	5	78510	6	30834
32074	3	78518	3	5520
32075	5	78519	2	25735
32076	3	78522	3	17087
32077	3	78525	4	30876
32078	5	78526	1	30784
32079	3	78529	1	10589
32080	5	78531	5	17980
32081	3	78533	2	30729
32082	5	78540	7	30871
32083	5	78541	2	30878
32084	3	78542	5	30837
32085	4	78543	7	16151
32086	4	78545	6	17732
32087	4	78546	7	30750
32088	5	78547	6	16540
32089	5	78548	7	2101
32090	5	78549	2	2460
32091	5	78550	3	30841
32092	4	78551	7	30740
32093	5	78552	1	6416
32094	4	78553	6	30739
32095	5	78554	6	21731
32096	5	78555	4	30899
32097	4	78556	2	30757
32098	4	78557	3	2735
32099	3	78557	5	2735
32100	3	78559	7	30840
32101	5	78560	6	30827
32102	5	78562	7	4094
32103	3	78565	2	30832
32104	3	78566	7	8612
32105	4	78571	3	4054
32106	5	78575	5	701
32107	5	78580	6	9695
32108	5	78583	5	27913
32109	5	78584	4	10717
32110	5	78586	6	21597
32111	5	78587	7	30902
32112	5	78587	4	30902
32113	1	78589	2	18271
32114	3	78591	1	30846
32115	4	78592	1	26256
32116	5	78593	2	30748
32117	5	78594	1	24284
32118	1	78595	6	30880
32119	5	78597	5	12420
32120	5	78598	2	17768
32121	4	78599	2	23085
32122	3	78603	2	5451
32123	4	78604	5	18335
32124	5	78605	4	30898
32125	5	78606	2	7607
32126	5	78608	6	7217
32127	2	78609	4	2549
32128	5	78612	2	19886
32129	5	78613	7	30849
32130	5	78615	2	30756
32131	4	78618	2	18543
32132	5	78619	6	7702
32133	5	78620	1	19367
32134	5	78621	7	4451
32135	5	78622	1	4368
32136	5	78623	6	25887
32137	4	78625	4	881
32138	4	78626	7	30934
32139	4	78627	5	17725
32140	5	78629	5	30872
32141	5	78630	6	21387
32142	4	78636	5	10576
32143	5	78640	2	25077
32144	5	78641	6	30922
32145	3	78646	5	3255
32146	5	78647	2	10350
32147	5	78647	6	10350
32148	3	78648	5	1529
32149	5	78655	7	2280
32150	1	78661	5	5278
32151	1	78663	6	2233
32152	4	78664	7	17788
32153	4	78666	7	12694
32154	5	78667	6	30911
32155	5	78668	7	2741
32156	5	78668	1	2741
32157	4	78670	7	30906
32158	5	78672	6	14699
32159	4	78676	1	20266
32160	5	78679	3	30760
32161	5	78680	3	11420
32162	3	78682	1	30904
32163	2	78686	2	21029
32164	5	78688	4	14600
32165	5	78689	3	5215
32166	5	78689	1	5215
32167	5	78692	3	30928
32168	4	78700	4	3515
32169	5	78701	4	19686
32170	5	78703	4	30879
32171	5	78704	2	16662
32172	3	78705	3	17669
32173	4	78706	7	15735
32174	3	78707	6	29737
32175	5	78716	2	227
32176	4	78717	5	30722
32177	4	78720	6	30858
32178	3	78721	1	30798
32179	5	78722	3	6598
32180	4	78726	7	764
32181	3	78727	3	18269
32182	3	78728	7	30888
32183	3	78730	7	9005
32184	5	78732	5	14462
32185	4	78733	3	18937
32186	4	78737	7	30777
32187	5	78737	1	30777
32188	4	78738	7	30923
32189	5	78739	6	18958
32190	3	78741	7	21693
32191	4	78742	7	26998
32192	4	78746	2	3169
32193	5	78754	5	17780
32194	5	78756	5	30921
32195	4	78761	7	18491
32196	4	78763	2	2551
32197	5	78764	3	12457
32198	5	78767	4	27455
32199	5	78778	4	30796
32200	5	78780	6	15995
32201	5	78784	2	30735
32202	5	78788	7	30803
32203	4	78789	5	30855
32204	3	78791	6	22199
32205	4	78791	7	22199
32206	3	78797	5	12132
32207	5	78800	4	30789
32208	5	78808	7	21484
32209	5	78808	2	21484
32210	4	78809	7	30913
32211	5	78810	7	26236
32212	5	78813	1	30793
32213	5	78815	2	16170
32214	4	78816	7	10387
32215	4	78823	7	1106
32216	5	78826	3	1125
32217	5	78827	3	24702
32218	4	78832	7	30765
32219	3	78832	5	30765
32220	3	78833	1	30624
32221	1	78834	6	30897
32222	4	78836	7	30910
32223	2	78839	1	30737
32224	3	78840	6	30853
32225	4	78841	4	30716
32226	3	78842	7	1961
32227	5	78843	4	24872
32228	4	78846	4	3802
32229	5	78848	5	19561
32230	3	78848	1	19561
32231	5	78849	6	15188
32232	4	78852	1	16839
32233	5	78856	6	30715
32234	4	78857	5	30758
32235	3	78863	1	30954
32236	4	78865	5	22556
32237	5	78866	6	1344
32238	5	78867	2	6295
32239	5	78869	2	21671
32240	4	78871	4	15916
32241	4	78872	2	18406
32242	5	78879	6	31042
32243	3	78882	2	30995
32244	5	78884	2	1070
32245	4	78885	4	20464
32246	5	78886	4	31003
32247	4	78887	5	30952
32248	5	78888	2	30998
32249	5	78890	6	30349
32250	1	78892	4	22318
32251	3	78895	5	5989
32252	5	78896	7	12875
32253	4	78897	3	31051
32254	3	78902	1	22414
32255	4	78904	3	2421
32256	4	78905	4	20579
32257	5	78905	7	20579
32258	5	78906	6	13601
32259	5	78906	4	13601
32260	5	78908	7	25882
32261	3	78910	1	3335
32262	4	78914	7	20557
32263	5	78921	6	31039
32264	5	78922	2	18591
32265	5	78928	1	7582
32266	5	78930	7	9352
32267	4	78935	6	3819
32268	5	78937	2	9017
32269	4	78939	7	1661
32270	3	78942	2	3701
32271	5	78945	2	31098
32272	5	78946	4	25532
32273	5	78948	7	17799
32274	5	78950	4	31063
32275	5	78951	1	30963
32276	5	78952	2	31106
32277	5	78962	2	1623
32278	5	78968	6	21273
32279	5	78970	6	31110
32280	2	78971	6	30982
32281	4	78971	7	30982
32282	4	78972	5	26993
32283	4	78974	7	29127
32284	5	78979	4	11878
32285	5	78980	5	31034
32286	4	78981	5	10894
32287	5	78982	5	22606
32288	4	78989	1	31007
32289	5	78992	6	31019
32290	5	78995	3	12579
32291	5	78998	2	10829
32292	4	78999	7	6200
32293	3	79000	7	11716
32294	1	79009	7	20338
32295	4	79011	2	2185
32296	5	79014	2	31021
32297	4	79016	5	20970
32298	2	79017	5	30968
32299	1	79019	6	5970
32300	5	79019	4	5970
32301	3	79020	4	9716
32302	4	79023	7	31001
32303	3	79025	5	443
32304	3	79027	4	31099
32305	2	79030	4	18420
32306	4	79033	3	31084
32307	3	79034	6	12205
32308	4	79035	7	304
32309	5	79036	1	19822
32310	3	79037	4	26736
32311	5	79045	6	3990
32312	5	79049	2	5643
32313	4	79053	2	31035
32314	4	79054	7	26049
32315	5	79060	3	12265
32316	5	79062	3	27449
32317	4	79063	5	14138
32318	5	79064	2	31058
32319	5	79065	3	30831
32320	5	79067	3	16170
32321	5	79070	3	6809
32322	5	79073	6	23992
32323	4	79074	4	30937
32324	4	79080	7	18840
32325	5	79083	5	19661
32326	2	79087	6	27130
32327	5	79091	5	15416
32328	5	79092	4	28795
32329	3	79094	3	28315
32330	4	79095	6	20385
32331	5	79097	6	31047
32332	3	79099	7	12170
32333	5	79102	2	17634
32334	5	79103	2	31065
32335	5	79104	7	16826
32336	5	79106	7	21196
32337	5	79107	2	31000
32338	4	79107	7	31000
32339	5	79108	6	30938
32340	3	79109	1	31010
32341	5	79111	2	31005
32342	5	79115	4	10071
32343	4	79119	3	4673
32344	5	79120	6	30960
32345	5	79122	7	31018
32346	3	79122	5	31018
32347	3	79123	6	30997
32348	5	79129	7	24510
32349	5	79135	2	22288
32350	5	79137	2	23696
32351	5	79138	4	5543
32352	5	79139	6	11932
32353	5	79142	6	26222
32354	4	79143	7	30936
32355	3	79146	2	31014
32356	4	79149	1	31053
32357	3	79154	4	5014
32358	1	79155	6	30350
32359	5	79156	4	5041
32360	3	79157	2	24332
32361	3	79159	3	31062
32362	3	79160	5	4020
32363	5	79162	2	2662
32364	3	79165	5	24423
32365	3	79168	7	8597
32366	5	79169	6	30975
32367	5	79170	4	5161
32368	5	79173	6	18044
32369	4	79174	7	31059
32370	4	79175	1	19673
32371	4	79176	5	21447
32372	5	79179	5	31011
32373	5	79183	4	755
32374	3	79185	1	23988
32375	5	79190	1	17008
32376	5	79191	5	1557
32377	5	79193	6	4348
32378	5	79195	6	30179
32379	3	79196	5	28087
32380	5	79198	6	30940
32381	5	79201	7	8282
32382	3	79211	7	7931
32383	5	79212	5	21008
32384	3	79213	4	31212
32385	3	79214	1	5138
32386	4	79216	1	31202
32387	4	79218	5	13617
32388	5	79219	7	8380
32389	3	79221	4	8303
32390	5	79231	6	10234
32391	5	79232	7	13092
32392	5	79234	5	21779
32393	3	79239	5	8068
32394	4	79244	3	10928
32395	5	79247	3	31149
32396	5	79251	2	9729
32397	5	79251	7	9729
32398	4	79252	6	31244
32399	5	79261	2	27274
32400	3	79269	3	24959
32401	4	79270	3	6965
32402	3	79273	3	31239
32403	4	79277	7	24837
32404	5	79279	7	31252
32405	5	79281	6	31285
32406	3	79282	5	6037
32407	5	79289	7	12608
32408	5	79291	2	31241
32409	5	79293	2	31112
32410	3	79297	5	13081
32411	5	79301	4	31128
32412	5	79303	5	31267
32413	5	79305	6	17005
32414	5	79306	6	27247
32415	5	79310	6	7595
32416	3	79312	7	31154
32417	5	79312	6	31154
32418	3	79313	7	15026
32419	5	79317	6	11560
32420	3	79320	7	31246
32421	3	79328	4	24767
32422	5	79336	2	19741
32423	5	79337	7	18429
32424	5	79338	7	11246
32425	1	79338	6	11246
32426	4	79339	7	14867
32427	5	79343	5	11159
32428	5	79344	4	9296
32429	5	79346	2	31263
32430	3	79349	6	1992
32431	5	79350	7	31141
32432	5	79353	2	31173
32433	5	79354	7	13116
32434	5	79355	4	11466
32435	5	79356	6	27978
32436	5	79357	4	23069
32437	4	79358	6	18020
32438	3	79361	4	31184
32439	5	79362	7	31270
32440	3	79365	1	22722
32441	5	79366	3	8858
32442	5	79368	4	12819
32443	5	79374	1	12484
32444	5	79378	5	31172
32445	4	79384	6	31115
32446	5	79388	6	31188
32447	5	79390	5	8814
32448	5	79394	2	31198
32449	3	79395	5	31258
32450	1	79397	4	7247
32451	4	79399	5	1674
32452	3	79403	7	16362
32453	5	79403	3	16362
32454	4	79404	7	31125
32455	5	79411	6	31206
32456	5	79412	7	31201
32457	5	79413	5	6828
32458	1	79416	2	31276
32459	4	79421	7	13441
32460	4	79422	7	26918
32461	5	79422	2	26918
32462	4	79423	3	4887
32463	5	79427	7	31170
32464	2	79428	7	31160
32465	3	79431	7	31284
32466	5	79436	2	31261
32467	5	79439	1	13722
32468	4	79441	4	22873
32469	3	79442	2	9852
32470	3	79444	1	1155
32471	3	79445	5	31177
32472	4	79449	5	31260
32473	5	79449	1	31260
32474	4	79450	1	31162
32475	3	79451	1	15958
32476	5	79451	2	15958
32477	4	79452	4	31158
32478	5	79455	5	30783
32479	3	79459	3	7971
32480	4	79462	4	2804
32481	5	79465	5	2596
32482	4	79466	3	6783
32483	3	79467	1	2008
32484	5	79470	2	31165
32485	3	79475	5	964
32486	4	79475	7	964
32487	4	79476	4	16328
32488	4	79479	3	4228
32489	1	79481	1	381
32490	5	79484	5	21540
32491	2	79489	5	31209
32492	2	79492	1	31234
32493	5	79493	6	3579
32494	5	79495	4	6252
32495	5	79497	1	29226
32496	3	79500	5	19473
32497	5	79502	7	31279
32498	4	79505	4	26241
32499	2	79506	1	1306
32500	4	79508	6	2064
32501	5	79509	3	7086
32502	3	79512	7	31155
32503	3	79512	4	31155
32504	3	79513	7	11616
32505	5	79514	3	31123
32506	5	79515	5	31163
32507	5	79515	1	31163
32508	4	79519	7	31133
32509	4	79520	2	9562
32510	5	79521	6	13855
32511	3	79526	2	3980
32512	5	79529	2	31159
32513	5	79530	5	14854
32514	4	79531	7	31134
32515	5	79533	7	2630
32516	4	79536	7	31164
32517	4	79537	7	19957
32518	5	79538	6	15763
32519	3	79538	7	15763
32520	3	79542	3	23590
32521	5	79544	4	14259
32522	5	79549	2	31176
32523	3	79556	6	31145
32524	2	79560	6	11367
32525	5	79562	4	16570
32526	5	79567	3	20556
32527	4	79570	5	18556
32528	5	79571	1	26485
32529	5	79572	5	31273
32530	4	79573	2	16534
32531	4	79573	1	16534
32532	3	79574	3	20579
32533	4	79575	7	4583
32534	4	79579	6	25459
32535	5	79585	2	6625
32536	5	79586	6	3979
32537	5	79588	1	31271
32538	5	79591	2	28960
32539	4	79592	7	969
32540	3	79593	1	31223
32541	4	79597	1	31194
32542	5	79597	6	31194
32543	4	79599	6	7192
32544	5	79605	1	31207
32545	2	79607	1	31116
32546	5	79608	3	31118
32547	4	79609	4	4800
32548	2	79611	6	9447
32549	3	79613	2	1970
32550	4	79618	4	19464
32551	3	79621	3	3851
32552	5	79624	6	31233
32553	5	79625	6	23222
32554	5	79627	7	30102
32555	5	79630	6	28859
32556	5	79633	3	410
32557	4	79636	3	31168
32558	4	79638	3	15246
32559	4	79639	4	12169
32560	4	79647	2	14483
32561	5	79648	6	9847
32562	5	79648	7	9847
32563	5	79650	1	27779
32564	5	79651	4	10954
32565	5	79652	4	8561
32566	5	79654	1	3476
32567	5	79655	6	1309
32568	4	79657	3	2065
32569	4	79660	2	31348
32570	3	79661	5	31460
32571	4	79662	7	3420
32572	4	79665	1	13236
32573	4	79666	4	14867
32574	4	79669	6	7947
32575	4	79670	3	6753
32576	3	79672	4	18981
32577	5	79673	6	15735
32578	4	79674	2	8071
32579	4	79676	3	31335
32580	3	79678	5	31417
32581	5	79679	1	1235
32582	3	79683	5	13078
32583	5	79685	6	5950
32584	4	79687	4	8214
32585	4	79691	7	19677
32586	5	79698	6	20832
32587	4	79699	7	20288
32588	4	79701	6	3579
32589	5	79703	1	20299
32590	5	79707	5	21042
32591	5	79712	4	19565
32592	3	79714	5	20592
32593	4	79718	6	31319
32594	3	79718	4	31319
32595	4	79721	3	27499
32596	4	79723	6	7180
32597	4	79723	5	7180
32598	4	79724	1	376
32599	4	79726	3	8876
32600	4	79729	4	13634
32601	4	79731	4	1751
32602	4	79732	4	2594
32603	5	79733	7	31352
32604	3	79733	5	31352
32605	5	79735	6	12949
32606	5	79736	7	31308
32607	3	79736	3	31308
32608	4	79741	5	10166
32609	4	79744	4	31441
32610	4	79745	6	31321
32611	3	79746	3	31347
32612	3	79749	2	29560
32613	5	79750	6	31415
32614	4	79753	5	9795
32615	5	79759	5	1479
32616	5	79761	2	31313
32617	5	79762	2	21887
32618	2	79764	3	31328
32619	5	79765	6	8330
32620	5	79771	4	13054
32621	5	79772	6	6881
32622	3	79778	7	31401
32623	5	79778	2	31401
32624	3	79779	5	30841
32625	5	79783	2	12287
32626	4	79784	2	3123
32627	5	79785	1	30520
32628	4	79787	4	31406
32629	3	79790	2	1635
32630	4	79793	7	31376
32631	1	79796	6	31470
32632	5	79797	5	31471
32633	5	79798	2	16231
32634	5	79799	3	27992
32635	5	79801	7	19817
32636	3	79802	5	31333
32637	5	79808	7	2206
32638	4	79809	5	2310
32639	5	79818	4	31327
32640	4	79823	7	24275
32641	4	79825	1	20057
32642	5	79831	3	29462
32643	5	79834	4	2203
32644	4	79837	4	20780
32645	5	79839	4	7574
32646	5	79840	2	18496
32647	5	79844	4	31410
32648	5	79845	4	3390
32649	3	79849	3	10726
32650	5	79852	4	8688
32651	5	79853	3	31427
32652	3	79856	3	78
32653	5	79864	6	30818
32654	4	79865	7	20269
32655	5	79866	6	29480
32656	3	79869	5	31320
32657	5	79873	6	1259
32658	4	79874	2	23794
32659	5	79875	4	17231
32660	3	79878	5	31337
32661	4	79882	2	21266
32662	5	79883	4	25791
32663	5	79886	2	31364
32664	1	79888	6	17038
32665	3	79890	1	2559
32666	5	79891	1	482
32667	3	79892	5	232
32668	5	79895	2	31411
32669	5	79898	5	28009
32670	5	79901	3	587
32671	1	79903	1	2897
32672	2	79904	7	31425
32673	3	79905	7	23147
32674	3	79906	5	9257
32675	3	79908	7	31194
32676	4	79911	2	6131
32677	5	79913	4	17039
32678	5	79915	6	8036
32679	4	79916	6	31367
32680	5	79918	4	31435
32681	4	79919	4	16382
32682	3	79921	7	5015
32683	5	79922	7	21234
32684	4	79924	7	790
32685	5	79924	6	790
32686	5	79927	1	31464
32687	5	79930	5	31457
32688	5	79932	3	31341
32689	5	79933	4	30607
32690	4	79933	5	30607
32691	5	79934	7	6588
32692	5	79935	2	22071
32693	4	79936	7	22925
32694	4	79938	6	5192
32695	4	79941	3	31439
32696	2	79942	1	16127
32697	5	79944	3	970
32698	5	79945	5	31359
32699	1	79953	6	22992
32700	5	79954	2	23807
32701	5	79956	4	7372
32702	4	79957	7	31422
32703	5	79959	2	4836
32704	4	79959	3	4836
32705	5	79960	2	31462
32706	3	79960	3	31462
32707	4	79965	3	11046
32708	5	79966	5	31310
32709	3	79974	5	1444
32710	4	79975	7	340
32711	3	79979	3	31404
32712	4	79980	4	25941
32713	5	79986	7	31387
32714	5	79988	6	10435
32715	1	79990	6	31370
32716	5	79991	3	7719
32717	3	79993	7	29436
32718	3	79996	6	17094
32719	5	79997	4	31461
32720	3	80000	7	31400
32721	4	80006	7	27051
32722	5	80008	2	18166
32723	5	80010	6	2517
32724	5	80015	6	26919
32725	5	80015	3	26919
32726	2	80016	2	6976
32727	3	80018	4	14025
32728	5	80019	6	27010
32729	5	80022	2	31372
32730	4	80024	6	31314
32731	5	80028	7	2119
32732	3	80031	7	12712
32733	4	80038	1	23457
32734	4	80039	2	29988
32735	5	80040	5	1905
32736	4	80041	1	11565
32737	5	80042	2	31440
32738	5	80045	7	3373
32739	5	80048	2	9001
32740	5	80048	6	9001
32741	5	80051	6	31416
32742	4	80054	3	31437
32743	5	80055	5	2661
32744	5	80058	7	31383
32745	5	80061	2	24188
32746	1	80064	4	6017
32747	4	80067	1	31371
32748	5	80074	6	31306
32749	5	80075	7	31317
32750	4	80079	5	31349
32751	2	80079	1	31349
32752	5	80080	5	23218
32753	5	80081	5	1656
32754	5	80082	7	31294
32755	5	80083	1	31338
32756	5	80084	6	13001
32757	4	80085	7	31467
32758	5	80088	1	31355
32759	5	80092	4	2089
32760	2	80094	6	5306
32761	5	80095	2	25804
32762	4	80097	3	7439
32763	5	80097	7	7439
32764	5	80098	7	29414
32765	4	80104	5	29766
32766	2	80108	5	22961
32767	5	80109	2	18450
32768	4	80110	4	26630
32769	5	80113	7	26965
32770	3	80115	7	31300
32771	4	80117	3	31448
32772	4	80118	3	27703
32773	5	80119	6	31365
32774	5	80119	4	31365
32775	5	80123	5	31432
32776	4	80123	6	31432
32777	3	80124	7	11215
32778	5	80127	4	5286
32779	5	80130	2	8866
32780	5	80131	2	31361
32781	5	80133	2	13767
32782	4	80135	7	6862
32783	5	80136	2	11486
32784	5	80138	6	31296
32785	4	80139	3	2651
32786	5	80141	2	22539
32787	3	80150	4	18927
32788	5	80154	3	11594
32789	5	80157	6	31368
32790	4	80159	7	31381
32791	5	80160	6	163
32792	5	80161	5	31343
32793	4	80162	7	31340
32794	5	80164	2	25505
32795	5	80165	3	2507
32796	4	80166	5	31392
32797	3	80167	5	30879
32798	5	80171	7	28930
32799	5	80173	4	20038
32800	4	80175	6	31446
32801	2	80185	4	12433
32802	5	80187	4	209
32803	3	80190	7	29800
32804	5	80191	6	28345
32805	3	80194	5	31525
32806	5	80194	2	31525
32807	1	80195	2	4577
32808	4	80198	7	25071
32809	5	80204	6	30464
32810	2	80208	3	31543
32811	5	80210	7	31685
32812	4	80213	5	31645
32813	4	80214	7	8536
32814	5	80215	3	14590
32815	5	80217	6	26002
32816	3	80218	7	10442
32817	1	80219	6	15897
32818	3	80226	2	31056
32819	3	80227	3	31498
32820	5	80227	6	31498
32821	3	80231	2	31563
32822	5	80232	6	18033
32823	5	80234	7	7802
32824	4	80236	1	3676
32825	4	80240	2	30866
32826	4	80243	1	1183
32827	5	80247	1	31586
32828	5	80253	2	31559
32829	3	80254	7	10023
32830	5	80261	7	31585
32831	5	80267	2	31576
32832	4	80268	1	17054
32833	3	80274	7	31600
32834	5	80278	3	14747
32835	3	80280	7	31521
32836	4	80281	6	31650
32837	3	80283	7	24691
32838	5	80284	2	3221
32839	4	80286	1	12174
32840	5	80287	1	31568
32841	5	80288	3	4624
32842	5	80293	7	31604
32843	1	80294	6	31599
32844	2	80295	3	1056
32845	4	80298	1	29917
32846	4	80299	6	19583
32847	4	80301	7	31561
32848	3	80302	7	30837
32849	5	80302	1	30837
32850	3	80304	7	25872
32851	4	80311	2	31479
32852	5	80314	6	1352
32853	4	80317	3	19643
32854	5	80319	2	6496
32855	5	80324	1	23984
32856	5	80325	6	10880
32857	5	80328	5	26909
32858	5	80329	2	31663
32859	4	80331	6	14705
32860	4	80332	5	27082
32861	5	80333	2	6842
32862	4	80334	2	30064
32863	5	80336	2	31488
32864	5	80343	2	28357
32865	4	80344	7	31670
32866	3	80345	5	18917
32867	4	80351	5	7912
32868	1	80354	4	19726
32869	5	80358	6	31648
32870	4	80362	2	31642
32871	3	80363	7	17780
32872	4	80364	6	31666
32873	5	80366	4	10656
32874	4	80367	7	26840
32875	2	80373	6	10352
32876	4	80374	5	23238
32877	3	80376	5	30419
32878	5	80378	5	29566
32879	3	80378	7	29566
32880	3	80379	5	30188
32881	4	80380	2	31550
32882	1	80381	6	7829
32883	5	80382	7	3647
32884	4	80384	7	28141
32885	2	80386	4	25692
32886	5	80389	1	31665
32887	5	80390	5	13592
32888	3	80393	6	17545
32889	5	80394	4	10214
32890	4	80395	4	31509
32891	5	80396	6	15791
32892	4	80399	5	7547
32893	5	80400	1	28539
32894	5	80404	7	24902
32895	5	80413	6	10345
32896	3	80414	3	31524
32897	5	80418	4	26693
32898	5	80419	7	17429
32899	5	80420	1	14027
32900	5	80424	4	31240
32901	3	80426	1	10842
32902	5	80430	2	626
32903	5	80432	5	1001
32904	2	80434	3	31603
32905	5	80435	2	31581
32906	5	80437	7	5636
32907	5	80438	6	29419
32908	4	80439	1	8640
32909	4	80440	6	16157
32910	5	80441	1	31483
32911	3	80446	5	31667
32912	3	80447	7	20302
32913	4	80448	5	31623
32914	5	80449	3	31578
32915	5	80451	3	23603
32916	5	80452	2	3205
32917	3	80453	3	18057
32918	3	80458	7	31595
32919	4	80470	2	22609
32920	5	80471	6	9719
32921	4	80472	7	31492
32922	5	80475	6	18316
32923	4	80476	1	31542
32924	3	80481	3	30855
32925	4	80481	2	30855
32926	5	80483	6	26291
32927	4	80484	4	23241
32928	4	80486	5	25598
32929	4	80491	7	31606
32930	5	80492	1	12558
32931	5	80494	6	31673
32932	5	80502	4	31592
32933	2	80504	5	31575
32934	5	80506	6	31674
32935	3	80507	1	31544
32936	5	80511	7	20080
32937	5	80519	6	25152
32938	3	80520	5	31579
32939	4	80520	7	31579
32940	5	80521	7	31676
32941	5	80522	1	29099
32942	3	80525	1	31516
32943	4	80529	7	31540
32944	5	80530	4	15073
32945	5	80532	2	31582
32946	2	80534	3	17139
32947	4	80535	3	11772
32948	5	80536	1	2050
32949	5	80542	5	8363
32950	2	80543	3	31555
32951	5	80543	1	31555
32952	4	80545	4	26187
32953	4	80546	2	4673
32954	5	80557	5	31605
32955	5	80564	6	17778
32956	2	80567	6	11896
32957	4	80572	2	16188
32958	4	80576	1	20761
32959	5	80578	2	31587
32960	5	80579	6	22643
32961	4	80581	6	31649
32962	4	80584	1	31491
32963	5	80585	1	7685
32964	4	80587	1	27560
32965	2	80588	6	27372
32966	3	80589	7	31679
32967	5	80590	6	31593
32968	4	80591	1	24950
32969	5	80592	1	31590
32970	3	80594	2	31503
32971	5	80596	5	7486
32972	5	80599	6	9076
32973	3	80602	1	31484
32974	4	80606	3	23348
32975	5	80607	4	9191
32976	5	80609	6	24664
32977	5	80610	7	30903
32978	5	80611	2	23595
32979	5	80613	2	31552
32980	4	80614	7	31531
32981	3	80617	5	13320
32982	5	80621	5	3998
32983	5	80623	6	31506
32984	5	80627	5	31684
32985	5	80628	5	31617
32986	3	80630	7	31280
32987	5	80635	6	903
32988	5	80636	2	31610
32989	4	80638	7	7588
32990	4	80641	6	31630
32991	4	80645	6	31652
32992	5	80646	6	31487
32993	3	80649	3	115
32994	5	80650	6	31480
32995	5	80653	7	31660
32996	5	80655	2	7387
32997	5	80657	5	20396
32998	5	80658	7	31654
32999	2	80659	4	18540
33000	5	80659	6	18540
33001	5	80665	1	31481
33002	5	80667	2	31557
33003	5	80670	2	16754
33004	4	80671	2	31502
33005	3	80672	1	13987
33006	4	80673	4	4082
33007	5	80676	7	31569
33008	3	80682	1	31597
33009	5	80683	1	22243
33010	5	80684	1	11976
33011	4	80687	3	15728
33012	5	80688	5	31658
33013	5	80690	4	5125
33014	4	80693	5	13827
33015	3	80695	5	31364
33016	4	80700	1	31564
33017	1	80705	6	10798
33018	5	80708	2	10224
33019	5	80710	1	29247
33020	5	80711	1	26974
33021	5	80712	4	5310
33022	5	80714	2	4398
33023	3	80719	3	31572
33024	3	80723	5	31535
33025	4	80725	3	31616
33026	4	80726	7	31529
33027	3	80727	3	17078
33028	2	80736	6	3037
33029	4	80737	2	18492
33030	5	80738	4	8985
33031	3	80739	5	3253
33032	5	80743	1	22786
33033	1	80746	6	5473
33034	4	80747	3	17049
33035	5	80748	2	23946
33036	2	80751	6	31519
33037	5	80752	7	9339
33038	3	80753	3	31626
33039	3	80754	5	3146
33040	5	80760	2	2071
33041	3	80763	6	17137
33042	5	80763	2	17137
33043	4	80764	6	31681
33044	5	80765	2	11389
33045	5	80766	7	1541
33046	5	80768	1	31530
33047	4	80769	5	31639
33048	3	80770	5	29022
33049	5	80773	2	31539
33050	5	80777	7	13797
33051	5	80780	7	8224
33052	5	80780	2	8224
33053	5	80782	4	31768
33054	5	80787	4	14463
33055	5	80791	2	31910
33056	5	80795	6	18741
33057	4	80797	2	31738
33058	5	80799	7	17606
33059	5	80800	2	7421
33060	4	80802	6	16853
33061	1	80803	6	10100
33062	5	80808	6	28925
33063	5	80809	2	13339
33064	4	80811	4	4479
33065	3	80822	5	25737
33066	5	80826	3	31827
33067	5	80829	2	22552
33068	5	80830	6	31819
33069	3	80831	4	19237
33070	5	80838	2	7121
33071	5	80839	4	31682
33072	4	80840	5	19443
33073	4	80841	5	31749
33074	2	80843	4	31741
33075	5	80847	5	31834
33076	5	80848	2	26749
33077	4	80850	5	31689
33078	5	80855	1	31268
33079	4	80858	7	31340
33080	4	80861	1	31760
33081	3	80863	5	27965
33082	5	80864	4	461
33083	5	80865	4	30119
33084	5	80866	6	27166
33085	5	80867	7	16545
33086	4	80872	7	4607
33087	5	80874	3	31786
33088	4	80877	5	5963
33089	4	80879	6	4749
33090	5	80880	6	26126
33091	3	80882	5	26168
33092	4	80884	5	31765
33093	4	80886	5	31804
33094	5	80889	1	31755
33095	3	80890	4	31712
33096	4	80891	7	31866
33097	4	80892	2	1931
33098	4	80893	3	8100
33099	5	80895	4	31782
33100	5	80896	6	31812
33101	5	80898	4	31854
33102	4	80899	6	24318
33103	4	80900	1	7623
33104	3	80901	4	1513
33105	5	80902	4	31813
33106	5	80902	2	31813
33107	4	80908	2	31892
33108	4	80913	3	31883
33109	4	80914	7	31832
33110	4	80914	5	31832
33111	5	80917	6	1740
33112	3	80920	3	868
33113	4	80923	1	11801
33114	5	80924	3	19108
33115	5	80925	6	31707
33116	4	80929	2	5463
33117	5	80937	2	14730
33118	4	80937	5	14730
33119	5	80938	2	2806
33120	3	80940	7	31809
33121	3	80945	5	31745
33122	2	80946	7	19445
33123	5	80950	5	6476
33124	5	80952	1	9163
33125	4	80960	7	26272
33126	4	80961	3	13881
33127	2	80963	6	8737
33128	4	80964	5	13187
33129	3	80967	2	15629
33130	5	80968	6	31718
33131	5	80970	5	18551
33132	5	80976	5	31761
33133	2	80983	6	31869
33134	4	80990	5	31720
33135	5	80991	1	25582
33136	5	80992	6	25191
33137	4	80997	7	12760
33138	5	80998	7	19161
33139	4	81000	2	31872
33140	4	81003	4	22464
33141	5	81007	1	4047
33142	5	81008	1	9458
33143	5	81009	6	9440
33144	4	81017	1	586
33145	4	81019	5	3480
33146	5	81022	5	19464
33147	5	81025	2	31776
33148	4	81026	1	81
33149	5	81028	7	24625
33150	5	81029	4	31906
33151	5	81030	5	22211
33152	3	81031	3	31740
33153	5	81033	6	31696
33154	1	81035	4	19207
33155	5	81039	1	30818
33156	5	81042	1	6591
33157	5	81043	7	31792
33158	4	81047	5	31737
33159	4	81054	3	6235
33160	5	81059	7	31774
33161	5	81059	6	31774
33162	5	81062	1	31704
33163	5	81065	6	16498
33164	3	81067	7	31828
33165	5	81073	3	18658
33166	5	81074	1	1115
33167	4	81076	4	1215
33168	5	81077	3	23356
33169	5	81081	6	31698
33170	5	81083	7	31777
33171	4	81084	3	167
33172	5	81089	7	16368
33173	5	81090	2	9981
33174	5	81090	4	9981
33175	5	81092	7	18206
33176	3	81093	3	31764
33177	5	81093	5	31764
33178	3	81098	5	31856
33179	3	81101	3	28832
33180	5	81102	7	31771
33181	2	81103	2	31904
33182	5	81104	7	29608
33183	4	81106	7	12031
33184	1	81107	2	265
33185	5	81108	7	16287
33186	1	81111	6	31890
33187	5	81114	2	28818
33188	5	81117	1	24706
33189	5	81119	2	3048
33190	5	81122	7	19399
33191	5	81125	1	1227
33192	5	81126	4	31711
33193	5	81127	4	31781
33194	5	81128	4	14382
33195	3	81130	7	31729
33196	4	81131	7	20545
33197	4	81133	7	31724
33198	4	81136	2	21195
33199	4	81138	2	21901
33200	5	81140	4	20965
33201	4	81142	2	31858
33202	5	81144	3	31901
33203	5	81145	2	29493
33204	3	81147	7	8584
33205	5	81147	1	8584
33206	4	81148	1	31897
33207	4	81153	3	4793
33208	3	81157	7	7544
33209	5	81160	2	19494
33210	5	81164	2	31852
33211	4	81165	6	31821
33212	5	81167	7	2248
33213	5	81168	6	31766
33214	5	81171	5	31785
33215	3	81174	7	24643
33216	3	81187	5	31788
33217	5	81188	3	31836
33218	3	81189	3	31885
33219	3	81190	7	31722
33220	3	81192	5	16887
33221	2	81193	6	10518
33222	2	81194	7	31723
33223	5	81196	2	22315
33224	4	81199	2	31807
33225	4	81203	7	19792
33226	3	81205	7	31876
33227	3	81206	5	6869
33228	1	81207	1	31889
33229	5	81210	7	31775
33230	5	81211	4	31811
33231	5	81213	2	9808
33232	5	81218	6	31754
33233	3	81220	3	11754
33234	5	81222	6	31903
33235	4	81223	1	31721
33236	5	81224	4	20136
33237	5	81225	5	27003
33238	4	81227	5	18580
33239	5	81233	1	3851
33240	3	81236	6	31701
33241	4	81237	6	15948
33242	5	81238	4	10550
33243	5	81239	4	2599
33244	3	81240	7	4578
33245	5	81243	6	31830
33246	3	81250	4	11046
33247	4	81251	1	31895
33248	3	81254	5	9235
33249	5	81255	6	31692
33250	4	81257	1	26037
33251	5	81258	4	4829
33252	3	81259	4	27861
33253	5	81261	6	12578
33254	3	81262	1	22408
33255	3	81264	4	31744
33256	5	81270	4	10598
33257	3	81271	7	3579
33258	5	81273	4	11737
33259	5	81274	4	4190
33260	1	81278	6	31772
33261	4	81282	5	11677
33262	4	81283	2	5643
33263	4	81284	7	18476
33264	5	81287	7	31800
33265	4	81292	2	115
33266	4	81293	2	11929
33267	5	81294	7	31714
33268	5	81294	3	31714
33269	4	81295	7	13630
33270	5	81297	4	31862
33271	4	81297	3	31862
33272	3	81298	7	2855
33273	5	81302	2	14054
33274	1	81302	5	14054
33275	4	81303	7	13173
33276	4	81304	5	30679
33277	4	81310	3	31912
33278	4	81312	7	31838
33279	5	81313	7	9457
33280	4	81316	7	31706
33281	5	81317	5	31699
33282	4	81319	7	31916
33283	3	81323	7	32071
33284	5	81326	6	18566
33285	5	81328	6	19867
33286	4	81329	1	14635
33287	5	81330	7	25974
33288	4	81332	7	32013
33289	5	81334	4	29614
33290	5	81337	2	4165
33291	5	81345	4	15773
33292	5	81345	6	15773
33293	5	81346	3	31962
33294	2	81348	1	32074
33295	4	81348	3	32074
33296	4	81354	3	23989
33297	4	81358	5	23571
33298	5	81363	2	8038
33299	4	81364	7	24534
33300	5	81367	2	14349
33301	5	81367	5	14349
33302	5	81369	3	32131
33303	5	81373	6	31951
33304	4	81374	7	32070
33305	4	81376	2	32035
33306	5	81379	1	11735
33307	5	81379	2	11735
33308	5	81381	1	32001
33309	4	81385	5	32077
33310	5	81388	7	31959
33311	5	81390	7	9128
33312	5	81392	4	1803
33313	1	81398	4	25296
33314	4	81399	5	29358
33315	3	81401	1	28230
33316	5	81407	7	11640
33317	5	81408	6	32037
33318	5	81417	2	32108
33319	5	81418	7	32003
33320	5	81419	7	18865
33321	3	81422	4	32030
33322	5	81426	6	31979
33323	4	81428	6	31917
33324	5	81431	7	5907
33325	3	81432	5	15377
33326	5	81436	6	32142
33327	5	81438	6	21121
33328	5	81440	3	14844
33329	5	81440	5	14844
33330	5	81443	2	23538
33331	3	81448	6	17799
33332	4	81450	6	31939
33333	5	81451	3	31978
33334	3	81456	5	30576
33335	4	81460	3	32148
33336	5	81463	2	19123
33337	4	81465	1	31073
33338	5	81466	1	28776
33339	5	81468	1	5958
33340	5	81472	2	3052
33341	5	81481	3	32068
33342	5	81483	6	23986
33343	4	81485	3	3518
33344	4	81485	5	3518
33345	5	81487	4	22952
33346	3	81488	2	18374
33347	5	81489	6	9451
33348	5	81490	6	32128
33349	5	81491	2	29343
33350	3	81494	1	8835
33351	4	81497	1	32104
33352	3	81506	5	18699
33353	5	81506	1	18699
33354	4	81511	7	17570
33355	5	81513	2	24948
33356	5	81513	6	24948
33357	3	81514	5	2392
33358	5	81515	4	9804
33359	5	81518	6	24000
33360	1	81520	4	10474
33361	5	81521	6	13188
33362	4	81525	3	11213
33363	5	81526	4	13370
33364	3	81527	5	32126
33365	5	81531	1	28139
33366	5	81533	2	31214
33367	3	81537	5	18332
33368	3	81540	2	23680
33369	5	81542	3	32032
33370	5	81550	4	6330
33371	4	81551	7	31995
33372	5	81558	3	32083
33373	4	81561	2	29576
33374	3	81562	1	26218
33375	5	81563	2	11535
33376	1	81563	6	11535
33377	5	81564	5	9014
33378	5	81565	4	28768
33379	5	81568	6	10327
33380	5	81570	2	26355
33381	5	81572	4	31958
33382	5	81575	4	32046
33383	4	81584	4	32102
33384	5	81589	2	10342
33385	5	81593	1	32040
33386	5	81595	2	3683
33387	5	81595	6	3683
33388	5	81597	2	6232
33389	4	81598	7	24128
33390	5	81599	2	32058
33391	4	81601	4	5138
33392	3	81608	5	32137
33393	5	81609	1	18828
33394	4	81610	4	21039
33395	4	81612	5	32123
33396	3	81615	7	32145
33397	4	81617	6	32129
33398	5	81619	3	32114
33399	4	81619	4	32114
33400	5	81621	6	6049
33401	5	81624	2	30162
33402	5	81631	6	8201
33403	5	81634	4	31987
33404	5	81635	3	31931
33405	4	81638	5	27510
33406	5	81642	2	31932
33407	5	81643	1	26108
33408	5	81644	4	4052
33409	4	81645	7	32004
33410	4	81648	6	32103
33411	5	81649	2	1283
33412	4	81660	1	32099
33413	5	81660	7	32099
33414	5	81664	2	25799
33415	5	81667	6	19033
33416	5	81668	3	32000
33417	4	81669	2	28047
33418	5	81670	7	28737
33419	5	81671	2	14113
33420	5	81673	4	5970
33421	5	81675	6	32085
33422	5	81677	2	24949
33423	5	81678	6	32122
33424	3	81679	1	7211
33425	5	81680	2	1568
33426	5	81683	1	25417
33427	5	81685	6	32059
33428	3	81685	5	32059
33429	3	81687	4	32042
33430	4	81689	7	15902
33431	5	81691	7	27913
33432	5	81691	2	27913
33433	5	81695	6	10957
33434	5	81696	6	21770
33435	5	81698	6	27831
33436	5	81702	2	26095
33437	5	81706	5	32127
33438	5	81708	5	28131
33439	3	81714	7	8714
33440	5	81718	3	25853
33441	5	81719	2	11795
33442	4	81722	2	7031
33443	2	81727	3	32152
33444	5	81729	2	28252
33445	5	81731	7	32057
33446	3	81733	2	27601
33447	3	81734	7	19706
33448	3	81735	2	8317
33449	4	81738	2	8187
33450	5	81738	3	8187
33451	5	81739	5	9267
33452	3	81740	1	11228
33453	5	81741	6	2187
33454	3	81744	2	32094
33455	5	81755	6	31994
33456	5	81757	5	18672
33457	2	81760	4	32111
33458	5	81763	7	293
33459	5	81764	4	19054
33460	5	81765	6	27889
33461	1	81765	2	27889
33462	4	81766	4	11522
33463	5	81767	3	18228
33464	3	81768	6	12327
33465	3	81769	7	8484
33466	5	81770	2	3352
33467	3	81773	7	31970
33468	5	81775	6	32143
33469	4	81777	5	14476
33470	5	81778	5	7819
33471	5	81780	2	10622
33472	5	81783	5	27621
33473	4	81784	1	20579
33474	5	81785	1	32146
33475	5	81793	3	27863
33476	3	81797	1	12770
33477	5	81799	2	13854
33478	3	81800	1	4089
33479	5	81806	4	15752
33480	4	81809	4	32149
33481	4	81811	7	9390
33482	4	81812	7	25257
33483	5	81813	4	4871
33484	3	81817	5	10480
33485	2	81819	1	29763
33486	3	81820	6	31924
33487	4	81821	5	32138
33488	5	81821	4	32138
33489	5	81823	2	13507
33490	3	81829	5	32031
33491	3	81831	7	31988
33492	4	81833	4	2535
33493	5	81834	6	30107
33494	2	81835	6	32101
33495	5	81839	7	23109
33496	2	81841	1	23432
33497	5	81848	6	5190
33498	5	81859	7	10858
33499	5	81860	6	32006
33500	4	81870	4	13025
33501	5	81873	1	15139
33502	4	81874	4	3420
33503	3	81876	1	31930
33504	4	81877	3	21617
33505	4	81878	7	32016
33506	5	81879	7	32078
33507	5	81883	6	31961
33508	5	81885	6	31953
33509	5	81890	5	2507
33510	3	81891	4	27557
33511	3	81892	3	24918
33512	5	81893	3	19321
33513	3	81894	3	5215
33514	5	81899	6	32116
33515	5	81900	1	7938
33516	5	81903	1	31996
33517	5	81905	2	7370
33518	5	81905	7	7370
33519	4	81907	7	32069
33520	5	81908	6	32072
33521	5	81910	3	8716
33522	4	81914	5	31421
33523	5	81915	5	32053
33524	4	81918	7	14621
33525	3	81923	6	31964
33526	3	81930	5	3862
33527	4	81931	2	25750
33528	5	81933	2	32117
33529	5	81935	6	310
33530	5	81936	2	27010
33531	5	81937	4	32028
33532	3	81940	7	32039
33533	5	81941	4	1266
33534	5	81942	1	32115
33535	4	81947	6	14301
33536	5	81948	6	4294
33537	5	81948	4	4294
33538	5	81949	5	5291
33539	4	81952	5	31948
33540	4	81954	3	31934
33541	4	81955	7	24998
33542	5	81957	2	1167
33543	5	81958	5	16651
33544	3	81960	7	6467
33545	5	81967	3	31049
33546	5	81972	7	21676
33547	5	81974	6	25658
33548	5	81978	7	32088
33549	5	81981	3	18900
33550	5	81982	2	31980
33551	4	81986	1	32081
33552	2	81988	1	28728
33553	5	81990	2	31997
33554	5	81991	1	5311
33555	4	81994	6	32051
33556	4	81997	1	31973
33557	5	82002	4	7051
33558	3	82007	5	31943
33559	5	82007	4	31943
33560	4	82008	4	25850
33561	3	82010	7	31679
33562	4	82011	6	25134
33563	5	82025	5	26901
33564	5	82026	1	29601
33565	5	82029	2	757
33566	5	82031	4	4788
33567	4	82031	6	4788
33568	5	82032	7	12832
33569	3	82035	7	32405
33570	5	82036	4	32222
33571	4	82037	6	13468
33572	5	82038	5	20130
33573	3	82039	5	5048
33574	5	82044	1	32248
33575	3	82045	1	32300
33576	5	82048	2	5790
33577	5	82049	4	10819
33578	2	82053	7	7530
33579	5	82054	6	19464
33580	5	82055	3	20727
33581	5	82056	5	8363
33582	1	82057	4	18406
33583	4	82060	1	4332
33584	5	82061	7	13318
33585	1	82067	6	10452
33586	5	82069	6	110
33587	4	82071	7	30662
33588	5	82072	4	16613
33589	5	82077	7	32174
33590	5	82078	2	32200
33591	4	82079	7	2743
33592	5	82085	2	32328
33593	4	82087	6	14
33594	1	82088	1	16367
33595	5	82093	7	19127
33596	4	82094	2	32263
33597	5	82103	4	6527
33598	5	82103	2	6527
33599	4	82105	5	9603
33600	3	82112	7	26198
33601	5	82113	4	27113
33602	3	82115	1	32190
33603	5	82122	2	30734
33604	5	82123	7	32175
33605	5	82124	7	32309
33606	5	82125	4	8656
33607	4	82128	1	32261
33608	5	82129	7	32351
33609	3	82130	7	20565
33610	4	82132	7	15188
33611	5	82137	7	17867
33612	1	82138	6	15026
33613	3	82139	5	32194
33614	5	82144	6	27429
33615	5	82146	6	12011
33616	5	82149	7	12546
33617	4	82151	1	9053
33618	5	82153	7	96
33619	4	82154	1	31969
33620	5	82155	2	32316
33621	5	82156	6	32409
33622	5	82157	2	32271
33623	4	82158	4	12375
33624	5	82160	1	27809
33625	3	82161	5	30329
33626	5	82163	6	32199
33627	3	82164	5	32408
33628	5	82166	5	29017
33629	3	82170	1	28413
33630	4	82171	6	3059
33631	5	82176	4	32216
33632	5	82187	7	25805
33633	3	82189	4	32179
33634	4	82194	7	22050
33635	4	82195	3	13530
33636	5	82197	7	29685
33637	5	82198	6	32274
33638	5	82201	6	32327
33639	4	82203	5	19677
33640	4	82204	7	32278
33641	5	82207	5	31621
33642	1	82208	6	32363
33643	5	82209	6	32329
33644	3	82210	5	905
33645	5	82212	7	18839
33646	5	82214	3	417
33647	5	82215	6	36
33648	4	82216	5	27828
33649	4	82219	6	20270
33650	4	82220	5	32167
33651	5	82224	6	3871
33652	4	82225	5	28432
33653	4	82230	7	15390
33654	4	82233	6	11109
33655	3	82235	5	2107
33656	4	82236	1	32249
33657	5	82239	5	32255
33658	5	82242	2	13256
33659	5	82243	2	8908
33660	3	82244	5	19680
33661	5	82247	2	28183
33662	5	82248	7	9791
33663	3	82252	3	758
33664	3	82257	5	19143
33665	5	82261	2	14759
33666	3	82262	4	32304
33667	5	82263	6	32383
33668	5	82269	4	6749
33669	5	82273	6	13487
33670	3	82276	7	1582
33671	5	82278	2	6961
33672	4	82281	4	32257
33673	5	82282	6	100
33674	5	82284	2	32298
33675	3	82293	2	25382
33676	3	82293	5	25382
33677	5	82295	2	7729
33678	4	82297	7	29357
33679	4	82299	6	32286
33680	4	82299	4	32286
33681	4	82300	2	21887
33682	5	82301	6	20413
33683	5	82302	6	20749
33684	5	82303	6	32266
33685	5	82304	5	23457
33686	3	82305	1	6174
33687	4	82306	5	32367
33688	5	82307	5	24918
33689	3	82310	7	18642
33690	5	82310	2	18642
33691	5	82312	6	14786
33692	5	82313	2	9196
33693	4	82313	4	9196
33694	5	82317	2	32291
33695	5	82318	7	32322
33696	5	82323	2	32389
33697	4	82324	7	30351
33698	5	82326	6	4251
33699	4	82327	6	32391
33700	5	82330	7	32338
33701	5	82333	4	14849
33702	5	82336	2	22246
33703	3	82338	3	14862
33704	4	82341	7	32365
33705	2	82342	3	14846
33706	3	82343	4	28446
33707	5	82345	5	28477
33708	5	82350	6	20382
33709	4	82355	1	12274
33710	5	82362	4	32202
33711	4	82365	7	32229
33712	2	82366	3	32368
33713	5	82368	3	32176
33714	5	82368	7	32176
33715	5	82370	7	24990
33716	5	82371	4	1640
33717	5	82374	2	21610
33718	5	82380	4	32240
33719	5	82384	2	11237
33720	4	82385	5	32353
33721	5	82386	7	2857
33722	5	82388	6	6509
33723	3	82392	7	14183
33724	3	82393	3	19685
33725	5	82394	2	32332
33726	5	82396	6	30276
33727	5	82397	1	32165
33728	4	82399	5	5948
33729	5	82401	1	32160
33730	5	82402	4	32315
33731	5	82403	6	13855
33732	4	82404	2	2064
33733	5	82406	4	27908
33734	5	82406	1	27908
33735	5	82409	6	2567
33736	5	82411	2	5520
33737	5	82415	7	11650
33738	3	82422	4	12340
33739	4	82424	4	6474
33740	4	82427	5	28164
33741	5	82429	2	6015
33742	4	82434	6	24975
33743	2	82435	1	28633
33744	2	82439	6	11804
33745	5	82443	5	32206
33746	3	82445	1	3636
33747	1	82447	6	32213
33748	5	82450	7	3350
33749	5	82450	2	3350
33750	5	82456	7	20215
33751	5	82457	4	32341
33752	2	82461	3	31006
33753	4	82462	6	32403
33754	4	82469	5	32253
33755	4	82472	3	8098
33756	5	82477	5	25415
33757	1	82480	6	32238
33758	5	82481	1	32410
33759	5	82482	5	25134
33760	4	82483	7	11414
33761	4	82484	1	32177
33762	3	82485	5	6448
33763	5	82486	2	22485
33764	5	82487	1	4075
33765	3	82490	2	19300
33766	3	82492	3	7206
33767	5	82496	6	9021
33768	4	82497	7	29462
33769	3	82499	7	20986
33770	3	82499	4	20986
33771	4	82501	5	32381
33772	4	82502	5	15645
33773	5	82504	7	32228
33774	3	82506	7	32330
33775	4	82508	5	32417
33776	5	82510	3	19130
33777	5	82518	4	12409
33778	3	82520	4	8629
33779	5	82524	5	32366
33780	5	82534	7	6490
33781	4	82536	5	32223
33782	4	82537	2	28709
33783	5	82539	3	32380
33784	5	82541	4	32256
33785	5	82544	2	32220
33786	5	82548	6	32382
33787	5	82551	4	15535
33788	3	82552	1	28253
33789	5	82556	3	32254
33790	5	82558	2	9167
33791	5	82561	7	32350
33792	4	82562	7	32236
33793	5	82563	7	20618
33794	4	82565	5	12975
33795	3	82567	7	32292
33796	5	82568	4	24634
33797	5	82569	4	4796
33798	5	82570	6	32401
33799	5	82572	7	32191
33800	3	82577	5	29660
33801	5	82579	3	13753
33802	5	82581	1	32159
33803	5	82584	6	6009
33804	5	82594	3	31190
33805	3	82603	4	32326
33806	4	82604	7	8782
33807	4	82605	3	15910
33808	5	82606	2	32387
33809	5	82608	4	1518
33810	1	82611	4	9036
33811	5	82615	3	25118
33812	3	82618	7	29642
33813	3	82620	5	31167
33814	4	82622	2	14218
33815	5	82624	6	32361
33816	5	82624	2	32361
33817	4	82628	1	21184
33818	5	82629	3	10785
33819	5	82630	5	29655
33820	5	82631	7	14974
33821	5	82636	5	18318
33822	5	82638	4	25779
33823	5	82640	7	13585
33824	5	82641	6	25799
33825	3	82644	4	32308
33826	5	82647	4	271
33827	3	82649	5	7205
33828	4	82651	5	32373
33829	5	82654	1	2704
33830	5	82657	2	20673
33831	4	82657	4	20673
33832	5	82658	1	6976
33833	5	82659	5	1234
33834	4	82662	2	27557
33835	4	82663	6	32224
33836	2	82671	5	28210
33837	5	82672	6	3129
33838	4	82675	7	20136
33839	3	82677	5	5982
33840	5	82679	6	15441
33841	5	82684	5	32340
33842	3	82686	5	32343
33843	2	82688	2	4967
33844	5	82690	4	32193
33845	4	82692	5	16181
33846	4	82694	3	2199
33847	2	82695	5	12711
33848	4	82699	7	32237
33849	5	82701	5	32396
33850	3	82702	3	17114
33851	5	82703	3	16365
33852	5	82708	3	11554
33853	5	82709	4	32318
33854	3	82713	5	32385
33855	5	82713	4	32385
33856	5	82714	1	28743
33857	5	82715	5	4190
33858	5	82717	2	27249
33859	5	82718	2	31428
33860	4	82719	4	32210
33861	3	82722	2	31707
33862	3	82726	3	12954
33863	4	82727	5	5346
33864	5	82729	2	3089
33865	5	82730	7	32155
33866	3	82731	4	32418
33867	1	82735	6	32306
33868	3	82736	7	22722
33869	3	82738	2	30000
33870	4	82739	4	3180
33871	4	82740	7	675
33872	3	82742	4	30864
33873	5	82743	5	15292
33874	4	82748	6	32342
33875	4	82750	3	32279
33876	2	82753	6	32285
33877	4	82755	2	28606
33878	5	82756	2	20077
33879	4	82758	6	16802
33880	4	82761	7	17251
33881	4	82762	4	32158
33882	4	82764	4	11118
33883	5	82766	5	10003
33884	5	82771	2	5458
33885	4	82772	1	20833
33886	5	82773	2	9539
33887	5	82775	2	24452
33888	3	82778	4	24609
33889	5	82780	6	8649
33890	5	82781	1	5082
33891	5	82782	6	29662
33892	5	82786	6	19082
33893	5	82787	2	14825
33894	3	82788	2	32364
33895	4	82789	4	32337
33896	5	82797	6	32269
33897	5	82798	3	14229
33898	1	82804	5	32181
33899	5	82808	6	31298
33900	3	82811	5	32358
33901	5	82814	5	20811
33902	4	82816	5	23409
33903	4	82818	2	12068
33904	3	82820	5	32295
33905	5	82821	4	31129
33906	3	82825	4	32166
33907	5	82826	6	31254
33908	5	82840	1	32356
33909	5	82841	4	30455
33910	5	82850	2	29367
33911	5	82851	3	32321
33912	5	82853	3	12142
33913	5	82856	4	32244
33914	5	82859	4	16350
33915	4	82861	6	28158
33916	5	82862	6	4202
33917	5	82864	6	32205
33918	4	82865	6	32372
33919	5	82866	2	4470
33920	3	82870	5	32362
33921	5	82872	6	32225
33922	5	82874	7	29716
33923	5	82876	7	6192
33924	5	82878	6	30975
33925	3	82882	2	32370
33926	3	82883	5	30818
33927	3	82884	5	32406
33928	5	82893	6	31161
33929	5	82895	6	32493
33930	4	82898	4	30762
33931	4	82900	7	27538
33932	5	82901	4	16870
33933	5	82903	6	32491
33934	1	82905	6	4674
33935	5	82905	7	4674
33936	5	82907	6	3478
33937	1	82910	4	32464
33938	5	82913	1	4351
33939	5	82914	6	24215
33940	5	82915	7	27266
33941	4	82915	6	27266
33942	5	82916	5	32607
33943	5	82917	7	8600
33944	4	82918	6	32630
33945	5	82925	2	28803
33946	4	82926	3	25654
33947	5	82927	6	32552
33948	3	82932	5	26588
33949	5	82938	3	32531
33950	5	82939	4	18490
33951	4	82941	5	440
33952	5	82942	2	32501
33953	5	82944	4	31076
33954	5	82945	6	32425
33955	4	82945	3	32425
33956	5	82949	4	15686
33957	5	82951	5	32451
33958	5	82956	2	32537
33959	5	82958	4	6919
33960	5	82960	5	4479
33961	5	82965	5	19078
33962	4	82969	2	32449
33963	4	82970	4	25856
33964	5	82973	2	13662
33965	5	82974	6	6524
33966	5	82976	7	19733
33967	4	82977	5	24386
33968	4	82979	5	8718
33969	5	82981	6	32481
33970	3	82981	7	32481
33971	5	82983	3	20628
33972	5	82985	7	5584
33973	3	82987	7	32508
33974	5	82991	6	32554
33975	5	82995	3	32594
33976	5	82999	6	23793
33977	3	83002	2	32477
33978	5	83008	6	3888
33979	4	83010	7	32445
33980	5	83012	5	32503
33981	5	83015	6	9833
33982	5	83016	5	1796
33983	5	83018	7	15028
33984	5	83020	4	32577
33985	4	83021	5	32436
33986	2	83022	4	32533
33987	5	83023	4	19273
33988	5	83023	2	19273
33989	3	83024	4	11789
33990	5	83027	5	15812
33991	4	83029	5	27452
33992	5	83031	2	20960
33993	5	83034	5	27970
33994	5	83035	7	32513
33995	5	83036	6	32515
33996	3	83038	5	32505
33997	5	83040	2	934
33998	5	83044	4	32542
33999	5	83045	6	32602
34000	5	83046	2	12123
34001	4	83050	2	32534
34002	5	83051	2	1656
34003	5	83053	4	32591
34004	5	83054	2	7098
34005	5	83055	1	24791
34006	2	83058	3	13600
34007	3	83061	2	25834
34008	3	83062	5	25291
34009	5	83063	1	1266
34010	5	83063	2	1266
34011	5	83067	1	32583
34012	3	83068	6	30099
34013	5	83070	7	32470
34014	5	83073	4	13859
34015	5	83077	7	27660
34016	5	83077	5	27660
34017	5	83079	5	21671
34018	4	83081	5	2702
34019	5	83089	7	32424
34020	5	83090	5	971
34021	4	83092	1	23457
34022	4	83093	5	30044
34023	5	83099	3	32480
34024	2	83101	4	12882
34025	5	83103	7	3952
34026	3	83104	5	24496
34027	3	83107	4	32523
34028	5	83108	5	24190
34029	5	83110	2	15899
34030	4	83112	7	16357
34031	4	83113	3	27183
34032	3	83114	2	26292
34033	3	83122	3	22053
34034	5	83124	7	5971
34035	4	83125	5	32551
34036	4	83126	5	7540
34037	5	83133	6	21736
34038	4	83134	6	5360
34039	5	83135	4	32624
34040	5	83136	7	32626
34041	5	83141	6	9350
34042	3	83143	4	21894
34043	4	83148	7	6510
34044	4	83150	5	32570
34045	3	83153	1	32482
34046	5	83159	6	16793
34047	5	83159	2	16793
34048	5	83160	1	32567
34049	3	83161	7	24202
34050	4	83168	3	31575
34051	5	83168	7	31575
34052	5	83171	3	12218
34053	5	83174	3	32458
34054	5	83175	6	32514
34055	4	83177	7	20108
34056	5	83179	3	21877
34057	5	83183	6	32621
34058	3	83184	3	32557
34059	5	83185	7	32600
34060	3	83186	2	32478
34061	5	83188	7	32601
34062	3	83189	5	11296
34063	5	83191	4	1233
34064	5	83192	2	23488
34065	4	83194	3	24192
34066	5	83196	3	29078
34067	5	83197	6	30137
34068	5	83200	3	32434
34069	5	83200	5	32434
34070	3	83201	4	12387
34071	5	83204	1	5025
34072	5	83206	3	10292
34073	5	83210	2	6604
34074	5	83212	6	23014
34075	5	83213	4	29154
34076	5	83214	1	5141
34077	1	83215	6	24950
34078	3	83216	7	22167
34079	5	83217	1	5526
34080	5	83220	2	30945
34081	5	83221	1	1917
34082	4	83224	1	26724
34083	5	83225	2	20017
34084	3	83227	7	6361
34085	5	83230	6	15155
34086	3	83231	7	16569
34087	4	83232	3	25003
34088	5	83233	7	1263
34089	4	83235	1	21717
34090	5	83237	6	32598
34091	4	83238	3	32428
34092	5	83239	1	32613
34093	5	83241	6	32579
34094	5	83244	5	30911
34095	4	83245	3	16692
34096	5	83250	6	32580
34097	5	83257	1	32490
34098	5	83258	1	32453
34099	5	83262	6	32426
34100	3	83264	5	32512
34101	3	83264	4	32512
34102	5	83266	5	1369
34103	5	83267	3	28183
34104	5	83267	4	28183
34105	1	83268	6	20890
34106	4	83269	5	8494
34107	4	83270	4	8357
34108	5	83272	1	32690
34109	5	83274	5	32748
34110	5	83277	6	32667
34111	3	83279	6	4768
34112	5	83281	7	32779
34113	5	83283	3	13537
34114	4	83288	4	32799
34115	5	83289	6	12847
34116	5	83289	4	12847
34117	1	83294	6	27657
34118	5	83296	5	32744
34119	5	83298	6	18759
34120	4	83301	3	32735
34121	5	83303	7	8958
34122	5	83304	6	32658
34123	5	83308	1	19957
34124	3	83310	5	14768
34125	4	83311	5	22507
34126	5	83312	6	17777
34127	3	83313	4	27299
34128	5	83315	3	32125
34129	3	83316	6	11380
34130	4	83318	7	20391
34131	5	83319	1	7078
34132	5	83320	6	32756
34133	5	83321	7	4995
34134	5	83323	1	16534
34135	3	83324	7	22863
34136	3	83327	5	32668
34137	4	83329	2	32743
34138	5	83331	7	13185
34139	2	83334	1	32805
34140	5	83338	1	32737
34141	5	83340	1	32792
34142	5	83344	1	29958
34143	5	83346	6	32641
34144	5	83349	2	14566
34145	2	83352	3	32765
34146	3	83355	1	6301
34147	5	83361	3	602
34148	5	83364	2	32664
34149	5	83366	2	13994
34150	5	83366	4	13994
34151	5	83367	6	11284
34152	4	83369	5	21950
34153	4	83371	6	32758
34154	5	83373	4	19752
34155	2	83374	3	32807
34156	4	83375	3	11601
34157	5	83382	4	5232
34158	5	83387	6	32798
34159	5	83389	7	8874
34160	5	83390	6	28718
34161	5	83392	5	19278
34162	3	83393	7	32776
34163	4	83394	5	1833
34164	5	83395	1	28880
34165	5	83399	3	32180
34166	4	83400	6	26299
34167	5	83403	2	9807
34168	5	83403	3	9807
34169	3	83404	1	30891
34170	5	83410	6	32738
34171	3	83411	5	26660
34172	5	83412	7	32704
34173	5	83413	2	12648
34174	1	83414	6	32702
34175	5	83416	5	8517
34176	5	83417	4	21151
34177	5	83423	6	32811
34178	3	83426	4	30312
34179	5	83426	6	30312
34180	4	83430	6	25544
34181	5	83431	6	14095
34182	5	83435	4	7686
34183	5	83441	2	4644
34184	3	83442	1	27488
34185	3	83443	2	32782
34186	5	83444	1	32723
34187	5	83445	2	3205
34188	5	83448	1	32794
34189	3	83449	7	32684
34190	4	83455	5	32801
34191	5	83455	1	32801
34192	4	83456	2	32672
34193	5	83457	2	31988
34194	5	83459	2	32652
34195	5	83464	6	19476
34196	5	83465	6	8782
34197	5	83466	3	32772
34198	2	83466	4	32772
34199	5	83467	7	21741
34200	5	83469	2	683
34201	5	83472	2	27193
34202	5	83473	7	16538
34203	3	83475	7	22060
34204	4	83477	2	20802
34205	1	83479	6	32791
34206	5	83483	5	20774
34207	5	83485	6	4428
34208	5	83486	4	32675
34209	5	83487	6	27289
34210	5	83488	4	23986
34211	5	83493	6	17059
34212	4	83497	3	19144
34213	5	83501	4	32698
34214	3	83504	3	32696
34215	4	83504	1	32696
34216	5	83513	3	4710
34217	5	83514	6	8720
34218	3	83517	3	32673
34219	4	83518	7	3534
34220	5	83522	2	24632
34221	5	83523	5	22725
34222	5	83524	4	29612
34223	5	83524	1	29612
34224	5	83527	3	14618
34225	5	83535	6	3004
34226	4	83535	1	3004
34227	2	83536	3	11040
34228	5	83538	1	1526
34229	5	83541	7	25685
34230	5	83542	5	32555
34231	5	83544	7	32693
34232	4	83545	5	28691
34233	3	83545	4	28691
34234	5	83549	4	18149
34235	1	83558	6	32699
34236	3	83560	4	17295
34237	3	83568	5	10625
34238	5	83573	2	9289
34239	4	83573	6	9289
34240	3	83574	1	2176
34241	5	83578	4	3069
34242	5	83582	6	23190
34243	3	83583	2	32677
34244	3	83584	7	30777
34245	3	83586	5	9002
34246	3	83588	1	15030
34247	5	83592	1	32739
34248	5	83593	4	1970
34249	5	83596	3	12807
34250	4	83599	7	23292
34251	4	83601	4	32676
34252	4	83604	3	5426
34253	5	83606	5	32689
34254	5	83607	1	16860
34255	4	83608	5	10433
34256	2	83608	6	10433
34257	5	83613	4	359
34258	5	83617	7	22529
34259	3	83620	4	13746
34260	5	83623	6	32797
34261	4	83625	5	32707
34262	4	83627	5	32708
34263	4	83629	7	25287
34264	5	83631	1	32716
34265	5	83635	7	32731
34266	5	83636	6	32647
34267	5	83640	2	32674
34268	3	83643	1	32642
34269	5	83644	6	2173
34270	3	83645	2	27059
34271	5	83647	4	32649
34272	4	83648	5	2089
34273	5	83651	6	13005
34274	3	83651	5	13005
34275	5	83656	5	6487
34276	5	83658	1	32343
34277	4	83660	6	32404
34278	5	83662	1	76
34279	1	83664	4	7058
34280	4	83665	2	1025
34281	3	83670	7	32657
34282	5	83671	7	32768
34283	5	83675	7	12894
34284	5	83676	1	28814
34285	5	83677	7	32733
34286	5	83678	3	2054
34287	5	83679	6	32741
34288	5	83682	6	3996
34289	5	83684	6	32778
34290	5	83688	5	22939
34291	5	83691	4	32639
34292	5	83692	7	19098
34293	5	83697	1	32683
34294	4	83699	6	25611
34295	5	83700	5	29494
34296	4	83702	1	32700
34297	4	83704	5	18906
34298	3	83704	6	18906
34299	5	83708	4	1996
34300	5	83710	5	14453
34301	5	83710	7	14453
34302	5	83711	4	29949
34303	5	83713	7	23064
34304	4	83715	1	32645
34305	1	83716	6	22464
34306	4	83717	4	28127
34307	3	83723	5	14002
34308	5	83724	6	3297
34309	4	83727	7	32746
34310	5	83728	5	1662
34311	5	83729	4	32870
34312	5	83730	7	3749
34313	5	83733	2	32847
34314	5	83734	7	32953
34315	5	83735	6	12485
34316	4	83737	7	33012
34317	1	83744	6	32842
34318	5	83746	2	23901
34319	3	83747	1	33001
34320	4	83749	3	14160
34321	4	83752	7	32944
34322	4	83755	4	32959
34323	4	83756	3	10867
34324	5	83759	6	16806
34325	1	83761	7	29336
34326	5	83764	5	32981
34327	5	83766	2	30591
34328	5	83769	5	29381
34329	5	83777	3	32894
34330	2	83781	1	32906
34331	5	83783	7	2931
34332	5	83784	2	29164
34333	5	83788	2	6080
34334	3	83789	2	32903
34335	3	83790	3	21161
34336	5	83790	2	21161
34337	5	83792	5	27000
34338	5	83792	6	27000
34339	4	83793	7	32955
34340	5	83796	3	32909
34341	5	83798	6	32945
34342	5	83804	4	7697
34343	5	83804	6	7697
34344	1	83808	6	27970
34345	5	83810	5	17776
34346	5	83811	1	5267
34347	5	83812	5	10461
34348	4	83813	7	20706
34349	5	83818	6	9809
34350	4	83818	5	9809
34351	4	83823	7	32819
34352	5	83826	4	32931
34353	3	83827	1	5423
34354	5	83827	5	5423
34355	4	83830	2	28669
34356	5	83832	2	5930
34357	5	83833	6	32893
34358	3	83836	5	4546
34359	4	83838	6	29094
34360	3	83840	6	6640
34361	4	83841	7	7813
34362	5	83842	7	20545
34363	4	83843	2	13203
34364	4	83844	6	28631
34365	3	83846	4	1344
34366	5	83849	7	28007
34367	5	83850	2	32922
34368	5	83851	4	4817
34369	4	83851	5	4817
34370	4	83858	5	13482
34371	5	83859	4	173
34372	3	83870	5	32900
34373	3	83871	2	22966
34374	4	83878	1	15299
34375	4	83880	5	4031
34376	5	83881	2	32936
34377	4	83885	2	32590
34378	2	83890	4	7410
34379	5	83892	6	4293
34380	5	83894	5	8358
34381	3	83895	5	31523
34382	5	83898	4	32284
34383	5	83899	5	32972
34384	4	83902	5	19953
34385	4	83907	1	17363
34386	5	83908	4	12180
34387	5	83910	3	9846
34388	4	83911	5	33017
34389	5	83912	2	4652
34390	4	83913	6	32977
34391	3	83913	7	32977
34392	5	83914	5	32918
34393	1	83916	1	2497
34394	5	83918	6	6516
34395	4	83921	1	32832
34396	5	83923	7	676
34397	4	83927	4	26459
34398	4	83928	5	32837
34399	4	83932	4	32930
34400	2	83937	5	32888
34401	5	83942	2	32883
34402	4	83944	7	32863
34403	5	83949	7	3205
34404	4	83950	7	3950
34405	4	83961	1	32921
34406	5	83965	5	32886
34407	3	83968	5	16141
34408	2	83973	4	16729
34409	2	83977	3	32825
34410	5	83978	5	32881
34411	4	83979	7	32939
34412	4	83980	7	33000
34413	5	83981	5	32859
34414	3	83982	1	19537
34415	3	83983	5	32908
34416	3	83985	2	32990
34417	4	83986	6	14025
34418	4	83986	1	14025
34419	5	83987	6	7582
34420	4	83988	1	16228
34421	1	83990	2	17358
34422	5	83991	2	26520
34423	5	83992	5	32910
34424	4	83993	5	9103
34425	4	83998	6	32978
34426	5	83999	1	20747
34427	4	84000	2	33006
34428	4	84002	2	15740
34429	4	84003	5	33005
34430	4	84003	1	33005
34431	3	84004	3	32834
34432	5	84005	6	32966
34433	3	84007	1	32892
34434	4	84008	1	1092
34435	5	84009	4	2231
34436	5	84012	3	32877
34437	3	84015	7	9077
34438	5	84016	4	4356
34439	5	84017	1	32844
34440	5	84018	6	1015
34441	4	84021	3	20899
34442	4	84022	5	3467
34443	5	84024	6	32924
34444	3	84025	4	28505
34445	5	84026	2	32851
34446	5	84029	7	32868
34447	4	84032	7	32680
34448	3	84036	7	24092
34449	5	84037	5	21038
34450	5	84038	2	33021
34451	3	84040	4	32933
34452	4	84041	5	21671
34453	4	84043	5	32954
34454	5	84044	4	32941
34455	5	84047	1	20976
34456	5	84049	1	23807
34457	5	84050	5	33023
34458	5	84052	5	32876
34459	4	84059	2	32866
34460	5	84060	1	21256
34461	4	84062	3	10683
34462	5	84063	2	11779
34463	4	84066	7	6074
34464	5	84068	5	22364
34465	3	84068	7	22364
34466	5	84069	1	15973
34467	5	84077	7	16633
34468	1	84078	5	32983
34469	4	84079	7	32919
34470	5	84080	4	8899
34471	4	84090	1	26624
34472	4	84091	4	3931
34473	5	84092	5	19285
34474	4	84092	3	19285
34475	4	84094	5	13227
34476	5	84095	5	2312
34477	4	84098	1	32995
34478	5	84100	7	7857
34479	5	84101	7	20434
34480	3	84103	5	30584
34481	5	84107	4	22678
34482	5	84107	1	22678
34483	5	84110	4	4184
34484	5	84111	7	32879
34485	5	84113	6	14581
34486	3	84118	1	10515
34487	5	84119	6	32952
34488	4	84120	5	13474
34489	5	84121	7	12836
34490	4	84125	3	24914
34491	5	84130	5	32871
34492	5	84132	7	32841
34493	4	84133	4	25982
34494	5	84141	6	32864
34495	4	84142	5	11783
34496	3	84146	1	33004
34497	5	84147	7	17012
34498	5	84148	6	294
34499	5	84150	6	10853
34500	5	84151	3	22239
34501	4	84152	7	33016
34502	3	84154	5	32852
34503	5	84156	3	32641
34504	3	84162	5	13225
34505	3	84164	3	4880
34506	4	84165	6	30500
34507	5	84168	1	2823
34508	5	84174	1	32980
34509	5	84177	6	32938
34510	4	84178	1	32818
34511	4	84179	1	28952
34512	4	84180	4	21527
34513	3	84187	7	32965
34514	5	84188	6	20965
34515	3	84189	4	5770
34516	5	84193	6	22700
34517	5	84194	2	28872
34518	5	84200	3	6600
34519	3	84203	5	5811
34520	5	84205	4	32998
34521	5	84206	6	13644
34522	5	84208	2	32974
34523	3	84209	2	20928
34524	3	84209	3	20928
34525	3	84211	7	2413
34526	3	84212	5	7280
34527	3	84216	5	17951
34528	4	84217	2	32932
34529	5	84218	3	32898
34530	5	84222	4	32962
34531	5	84226	3	1106
34532	5	84228	3	7688
34533	5	84231	1	22332
34534	5	84235	7	32991
34535	1	84242	5	32869
34536	5	84249	4	32901
34537	4	84251	7	9284
34538	4	84252	1	27066
34539	5	84253	5	32957
34540	4	84255	7	32928
34541	5	84256	2	23843
34542	5	84257	5	32970
34543	3	84261	2	22478
34544	3	84266	4	31181
34545	4	84267	5	32873
34546	2	84268	6	32857
34547	4	84270	1	33013
34548	1	84272	1	20558
34549	2	84276	3	1531
34550	4	84278	7	9562
34551	5	84279	3	6406
34552	5	84281	6	581
34553	3	84281	3	581
34554	4	84284	7	32867
34555	4	84287	6	6328
34556	5	84288	1	28841
34557	5	84289	1	6546
34558	3	84291	1	27808
34559	5	84293	5	11172
34560	4	84296	5	23571
34561	1	84299	6	32988
34562	3	84302	7	32872
34563	1	84304	6	16592
34564	4	84305	3	11334
34565	5	84309	5	33115
34566	5	84310	4	33145
34567	5	84313	1	467
34568	3	84315	5	21552
34569	3	84318	4	33124
34570	3	84319	7	33034
34571	5	84320	1	23704
34572	4	84325	3	28391
34573	5	84326	4	33050
34574	4	84329	4	33062
34575	4	84333	7	16148
34576	3	84336	4	33060
34577	5	84337	3	14558
34578	5	84338	4	33111
34579	5	84340	7	12666
34580	5	84342	6	22429
34581	2	84344	3	6496
34582	4	84345	4	33090
34583	5	84348	2	25340
34584	5	84349	5	19893
34585	5	84352	6	12810
34586	5	84353	1	19642
34587	1	84356	6	33138
34588	5	84357	7	33132
34589	5	84359	4	33242
34590	5	84370	7	33185
34591	5	84372	5	22074
34592	5	84373	2	33121
34593	1	84373	6	33121
34594	5	84375	2	3711
34595	5	84377	2	25192
34596	3	84378	4	33123
34597	5	84378	7	33123
34598	4	84379	3	19046
34599	5	84383	2	2089
34600	5	84385	3	1321
34601	4	84386	2	20368
34602	5	84387	7	18722
34603	3	84388	4	22542
34604	5	84391	6	11059
34605	5	84393	6	9898
34606	3	84395	7	22425
34607	5	84397	4	26068
34608	4	84399	6	9784
34609	5	84400	7	6664
34610	5	84401	6	33126
34611	2	84405	6	33203
34612	5	84406	6	7150
34613	3	84407	5	33052
34614	3	84408	1	9496
34615	5	84409	5	33159
34616	5	84410	2	28535
34617	4	84411	3	17852
34618	5	84413	4	26392
34619	5	84416	3	33038
34620	5	84420	3	649
34621	5	84421	5	33158
34622	3	84424	4	18491
34623	5	84426	1	33057
34624	5	84430	7	33237
34625	5	84433	7	33262
34626	5	84434	2	23590
34627	5	84435	4	6941
34628	5	84436	6	23041
34629	5	84437	4	33254
34630	5	84442	6	33116
34631	4	84443	4	2929
34632	4	84450	5	33110
34633	2	84456	1	17501
34634	5	84458	1	30216
34635	5	84461	5	827
34636	5	84463	1	33094
34637	3	84464	4	33080
34638	4	84471	1	2178
34639	5	84472	1	5292
34640	3	84473	5	21333
34641	1	84474	6	15604
34642	1	84475	6	33114
34643	5	84478	3	33175
34644	5	84482	6	26467
34645	4	84483	4	33215
34646	3	84484	2	33164
34647	3	84489	7	19749
34648	5	84492	5	33137
34649	5	84493	5	20691
34650	5	84495	2	32950
34651	2	84496	6	33165
34652	5	84497	6	33097
34653	4	84500	5	25116
34654	2	84505	4	510
34655	3	84510	5	23822
34656	5	84512	2	33212
34657	5	84513	2	8983
34658	5	84515	2	27964
34659	3	84516	2	22529
34660	3	84518	7	32627
34661	4	84520	3	33039
34662	4	84521	1	6271
34663	1	84523	7	33036
34664	3	84526	6	26187
34665	5	84528	7	33063
34666	4	84531	5	12290
34667	5	84533	2	33028
34668	3	84536	7	2272
34669	2	84536	2	2272
34670	5	84540	3	13187
34671	4	84542	6	33224
34672	3	84547	7	3871
34673	5	84549	3	33140
34674	5	84553	4	33071
34675	3	84553	3	33071
34676	4	84556	1	17431
34677	4	84557	3	22898
34678	5	84561	2	30420
34679	5	84562	7	33240
34680	5	84563	1	27466
34681	5	84564	2	15816
34682	5	84565	5	33144
34683	5	84567	2	2399
34684	3	84568	1	33083
34685	5	84570	1	33031
34686	1	84570	6	33031
34687	5	84571	2	32270
34688	3	84574	1	23229
34689	4	84579	1	13122
34690	5	84584	7	29163
34691	5	84586	5	33163
34692	3	84589	5	33148
34693	4	84589	3	33148
34694	5	84590	2	15347
34695	5	84590	4	15347
34696	5	84592	4	20145
34697	3	84594	5	27927
34698	1	84597	6	19363
34699	3	84599	5	8341
34700	4	84602	2	31172
34701	4	84608	7	33192
34702	3	84616	7	33043
34703	5	84618	6	33156
34704	1	84619	7	33129
34705	5	84620	6	33267
34706	5	84620	1	33267
34707	1	84624	6	15183
34708	3	84628	4	33210
34709	5	84629	4	29922
34710	4	84633	1	33117
34711	5	84633	4	33117
34712	4	84634	5	16231
34713	3	84636	7	30251
34714	2	84637	2	33142
34715	5	84638	5	13932
34716	3	84639	3	2829
34717	3	84640	5	26919
34718	5	84641	6	24396
34719	3	84642	2	29093
34720	1	84644	1	29849
34721	4	84644	7	29849
34722	5	84645	2	17248
34723	5	84645	1	17248
34724	3	84647	5	33218
34725	5	84649	2	9321
34726	5	84649	6	9321
34727	5	84655	1	33118
34728	3	84657	3	17341
34729	5	84660	2	30154
34730	3	84664	1	8009
34731	5	84667	7	33204
34732	5	84669	2	33219
34733	5	84682	3	11732
34734	3	84684	5	30790
34735	5	84685	2	13942
34736	3	84687	7	5467
34737	4	84692	6	33045
34738	5	84696	1	33243
34739	4	84700	2	33172
34740	5	84701	5	2715
34741	5	84703	3	33032
34742	5	84705	3	32515
34743	3	84706	4	26581
34744	5	84707	1	33065
34745	3	84708	5	16290
34746	5	84712	6	30732
34747	4	84714	2	31157
34748	5	84720	2	3850
34749	4	84726	4	14290
34750	4	84727	6	33155
34751	5	84734	3	17164
34752	5	84735	6	11761
34753	5	84736	3	10632
34754	5	84738	6	1021
34755	4	84740	2	31267
34756	4	84743	4	33167
34757	5	84744	7	33245
34758	2	84745	2	25615
34759	5	84750	4	33251
34760	5	84751	1	33201
34761	5	84753	4	27623
34762	4	84755	1	28261
34763	5	84756	1	23682
34764	4	84757	3	1120
34765	3	84759	6	7390
34766	3	84760	4	7158
34767	5	84761	7	19712
34768	5	84768	4	227
34769	5	84769	3	33253
34770	4	84771	5	27944
34771	5	84772	3	27410
34772	5	84773	3	33026
34773	4	84775	6	33048
34774	4	84778	1	21896
34775	5	84784	1	11789
34776	4	84785	2	28628
34777	5	84788	2	6152
34778	4	84789	7	30126
34779	5	84791	6	7598
34780	4	84792	2	6248
34781	5	84793	1	25115
34782	5	84797	7	33150
34783	5	84798	3	33025
34784	5	84799	4	33105
34785	5	84800	4	31013
34786	4	84801	5	17085
34787	5	84804	5	33075
34788	5	84806	5	33087
34789	4	84807	6	16025
34790	4	84809	6	9701
34791	5	84811	7	33209
34792	5	84813	4	12673
34793	5	84814	5	33171
34794	5	84815	5	22649
34795	4	84815	2	22649
34796	4	84818	7	33170
34797	5	84823	6	27881
34798	5	84824	5	25577
34799	5	84828	6	9578
34800	5	84828	2	9578
34801	4	84831	1	33182
34802	5	84832	3	12205
34803	5	84838	5	33194
34804	5	84844	6	33248
34805	5	84846	1	28393
34806	5	84847	1	753
34807	5	84848	2	33072
34808	5	84861	6	33181
34809	4	84864	1	29107
34810	5	84865	1	1309
34811	1	84868	6	8448
34812	4	84869	1	8349
34813	5	84870	6	29683
34814	5	84872	5	33147
34815	5	84873	4	33227
34816	5	84881	6	33258
34817	4	84882	7	20566
34818	5	84883	4	19773
34819	5	84886	4	2442
34820	5	84887	7	33229
34821	5	84890	6	33055
34822	5	84891	5	2860
34823	5	84892	7	33049
34824	5	84893	2	16880
34825	5	84894	3	3870
34826	5	84898	7	21848
34827	5	84899	3	6277
34828	5	84900	2	32720
34829	5	84902	2	13922
34830	5	84903	3	33084
34831	5	84904	1	29226
34832	5	84907	6	15683
34833	4	84909	1	33058
34834	4	84912	2	33103
34835	5	84915	7	33247
34836	5	84916	2	33246
34837	5	84917	2	7734
34838	5	84917	1	7734
34839	3	84920	4	22035
34840	5	84923	1	33149
34841	5	84925	7	33139
34842	5	84941	2	33189
34843	3	84947	5	6113
34844	5	84947	6	6113
34845	5	84948	1	20749
34846	5	84953	7	8061
34847	5	84954	2	11413
34848	5	84955	2	33435
34849	5	84958	1	3604
34850	5	84960	1	19612
34851	5	84961	2	23093
34852	4	84967	7	33290
34853	5	84968	3	5106
34854	3	84968	4	5106
34855	1	84969	6	21799
34856	3	84970	1	3251
34857	2	84972	1	33337
34858	5	84973	1	17784
34859	5	84974	4	33449
34860	5	84975	5	33377
34861	5	84976	3	29164
34862	5	84977	6	33405
34863	5	84978	4	33465
34864	5	84981	4	7186
34865	3	84985	5	11286
34866	5	84988	5	33370
34867	5	84989	5	33328
34868	4	84990	2	33353
34869	5	84991	2	22572
34870	4	84992	3	33301
34871	3	84993	5	26227
34872	3	84994	2	29354
34873	5	84995	2	33338
34874	3	84996	5	26520
34875	3	85001	7	4655
34876	3	85003	2	15428
34877	3	85005	7	10305
34878	2	85007	1	33281
34879	5	85010	4	13554
34880	4	85015	2	27308
34881	4	85016	1	33462
34882	5	85020	4	33307
34883	5	85024	1	33414
34884	4	85025	2	33330
34885	4	85028	3	18021
34886	5	85030	5	5768
34887	5	85032	7	11180
34888	4	85033	5	33478
34889	3	85036	2	18225
34890	5	85042	2	12449
34891	5	85047	6	10311
34892	4	85048	4	16996
34893	4	85051	1	33436
34894	5	85051	3	33436
34895	5	85053	4	33471
34896	5	85055	5	27543
34897	5	85060	2	33388
34898	3	85061	4	33381
34899	4	85062	6	1258
34900	5	85064	5	11624
34901	4	85064	2	11624
34902	3	85068	5	14081
34903	5	85072	1	19841
34904	3	85076	4	11189
34905	5	85077	7	33331
34906	5	85079	2	33312
34907	2	85079	7	33312
34908	5	85081	2	33391
34909	5	85084	2	33460
34910	5	85085	1	8741
34911	4	85087	7	17206
34912	5	85088	2	18128
34913	4	85090	7	6039
34914	4	85093	2	33344
34915	4	85097	6	25859
34916	4	85100	1	2123
34917	5	85103	6	14046
34918	5	85104	6	25676
34919	5	85105	6	28631
34920	3	85106	2	16966
34921	4	85107	5	32369
34922	4	85110	5	33500
34923	5	85112	5	3350
34924	5	85113	4	33351
34925	3	85118	4	33445
34926	5	85119	7	33365
34927	5	85120	6	33297
34928	5	85123	6	33339
34929	3	85124	3	23133
34930	2	85124	6	23133
34931	5	85125	6	11510
34932	3	85127	2	22130
34933	3	85128	5	2095
34934	4	85129	7	21290
34935	4	85133	5	32086
34936	4	85136	2	11708
34937	4	85137	7	7891
34938	4	85138	4	22626
34939	5	85139	3	33371
34940	5	85141	1	1466
34941	3	85145	7	9483
34942	5	85148	3	33397
34943	4	85150	5	33274
34944	5	85152	6	4368
34945	5	85154	6	28542
34946	5	85156	7	16231
34947	5	85157	2	33276
34948	1	85160	3	13528
34949	3	85163	3	30614
34950	4	85166	7	22124
34951	4	85167	3	1636
34952	5	85168	4	23729
34953	5	85169	4	6090
34954	4	85177	2	28623
34955	5	85184	1	16510
34956	5	85186	5	32901
34957	5	85188	4	18489
34958	5	85189	2	33419
34959	5	85190	6	33322
34960	4	85192	5	33374
34961	3	85194	2	21599
34962	5	85196	6	8104
34963	4	85197	5	33484
34964	4	85198	5	28174
34965	3	85202	2	22177
34966	3	85202	7	22177
34967	5	85203	3	27804
34968	5	85204	2	9025
34969	5	85207	2	13275
34970	5	85211	6	33334
34971	4	85215	3	30909
34972	5	85221	6	4957
34973	4	85222	7	33277
34974	5	85223	2	11367
34975	4	85223	7	11367
34976	4	85224	1	28588
34977	1	85228	6	22484
34978	5	85231	7	20931
34979	5	85232	5	33275
34980	3	85233	1	15532
34981	5	85234	6	9998
34982	5	85238	6	24325
34983	5	85240	1	33407
34984	5	85243	6	14874
34985	4	85245	2	9747
34986	5	85246	4	17538
34987	4	85250	7	33504
34988	3	85252	4	20873
34989	4	85255	5	33432
34990	5	85256	2	33470
34991	5	85258	6	1093
34992	5	85259	7	33444
34993	5	85259	6	33444
34994	3	85261	5	23461
34995	5	85267	6	31865
34996	4	85268	5	25006
34997	5	85269	3	32042
34998	5	85272	6	8427
34999	5	85273	7	33486
35000	5	85274	4	6250
35001	2	85275	6	33447
35002	3	85276	1	33490
35003	5	85281	5	33380
35004	1	85282	6	33503
35005	3	85282	3	33503
35006	5	85283	7	26905
35007	5	85285	7	33278
35008	5	85287	2	33395
35009	5	85289	7	9044
35010	2	85290	4	12854
35011	5	85293	7	7766
35012	5	85295	1	7103
35013	4	85296	5	2064
35014	5	85298	4	28439
35015	5	85299	6	25760
35016	5	85309	1	17125
35017	5	85310	7	20249
35018	5	85311	6	30997
35019	4	85313	4	29856
35020	5	85314	5	24422
35021	2	85316	3	22982
35022	5	85318	6	16635
35023	1	85325	4	33319
35024	4	85326	4	21764
35025	4	85327	5	33464
35026	4	85333	3	285
35027	3	85340	3	21813
35028	4	85347	1	22713
35029	5	85349	5	18094
35030	3	85350	1	19678
35031	4	85351	1	29429
35032	4	85352	4	6444
35033	3	85353	7	33492
35034	3	85354	6	33456
35035	5	85358	4	33289
35036	5	85359	4	33483
35037	5	85360	5	12185
35038	5	85361	7	33487
35039	4	85365	1	23405
35040	3	85366	4	33453
35041	1	85374	6	18666
35042	5	85375	2	4909
35043	5	85379	7	27993
35044	5	85385	1	33300
35045	4	85387	7	9075
35046	3	85389	3	33428
35047	1	85391	6	15997
35048	4	85395	2	6934
35049	2	85395	6	6934
35050	3	85399	1	1015
35051	5	85401	3	29211
35052	5	85402	2	33366
35053	5	85408	1	2207
35054	3	85414	7	19623
35055	4	85414	4	19623
35056	5	85419	7	15334
35057	5	85421	7	33384
35058	5	85422	6	23286
35059	5	85424	3	33396
35060	3	85426	7	19955
35061	4	85427	7	8609
35062	5	85433	7	33310
35063	5	85434	7	22865
35064	5	85436	1	33417
35065	4	85438	7	27973
35066	5	85443	7	13763
35067	4	85446	2	33477
35068	1	85446	6	33477
35069	5	85447	3	12296
35070	5	85451	6	33424
35071	5	85452	1	27431
35072	4	85453	7	2196
35073	4	85454	6	5531
35074	4	85456	1	15565
35075	5	85457	5	20241
35076	5	85460	4	4764
35077	3	85461	5	33415
35078	3	85462	1	33418
35079	5	85464	5	33429
35080	3	85466	1	18870
35081	5	85467	1	10331
35082	5	85469	1	33474
35083	5	85470	6	4181
35084	4	85472	7	4834
35085	5	85475	4	15266
35086	3	85478	1	12009
35087	5	85481	6	33308
35088	3	85483	1	32911
35089	5	85484	5	20366
35090	4	85489	1	33551
35091	4	85490	5	18127
35092	5	85491	7	33583
35093	4	85493	7	33554
35094	5	85495	1	3785
35095	5	85497	2	9838
35096	4	85498	5	29408
35097	5	85501	6	16565
35098	5	85503	3	11187
35099	5	85504	2	3650
35100	5	85506	3	29824
35101	4	85507	1	24059
35102	4	85510	5	33729
35103	2	85512	2	2403
35104	5	85513	6	33651
35105	3	85515	5	33611
35106	2	85516	3	972
35107	4	85517	3	14025
35108	4	85518	3	33510
35109	2	85520	1	3413
35110	5	85521	4	7328
35111	5	85524	5	5417
35112	4	85526	2	11887
35113	5	85528	7	33563
35114	4	85531	3	33644
35115	5	85532	4	14363
35116	2	85538	7	19300
35117	5	85541	6	33620
35118	5	85541	3	33620
35119	5	85542	4	33727
35120	4	85543	5	3168
35121	5	85544	6	4578
35122	3	85552	7	33596
35123	4	85557	5	2426
35124	1	85560	6	20657
35125	3	85562	5	33613
35126	3	85563	3	8937
35127	5	85564	5	8601
35128	5	85565	4	33663
35129	5	85567	1	10764
35130	4	85570	4	24621
35131	5	85573	4	5427
35132	1	85573	6	5427
35133	5	85575	2	33598
35134	4	85576	7	20573
35135	5	85578	4	33512
35136	4	85581	6	33720
35137	5	85583	2	33619
35138	5	85586	2	7573
35139	5	85587	6	33549
35140	5	85588	7	1918
35141	3	85590	7	33716
35142	5	85599	4	33671
35143	5	85601	7	1152
35144	5	85602	5	14123
35145	5	85606	4	10994
35146	5	85606	2	10994
35147	5	85607	2	7752
35148	5	85608	4	10422
35149	5	85611	3	18919
35150	5	85614	5	13677
35151	4	85620	5	33654
35152	4	85621	4	26317
35153	5	85623	6	32315
35154	4	85625	4	4983
35155	4	85631	4	21241
35156	5	85632	6	4100
35157	4	85633	3	33546
35158	4	85636	1	18839
35159	5	85641	3	1424
35160	3	85647	5	33622
35161	3	85648	3	33675
35162	3	85652	2	10509
35163	5	85655	7	33566
35164	5	85658	2	33640
35165	5	85659	1	33
35166	5	85661	7	33542
35167	5	85664	4	33581
35168	4	85666	2	33715
35169	5	85670	4	17948
35170	5	85672	1	9779
35171	5	85675	6	20823
35172	5	85675	7	20823
35173	5	85677	6	16840
35174	5	85679	1	27343
35175	5	85684	7	33557
35176	5	85685	1	33707
35177	2	85688	1	33537
35178	4	85690	5	14711
35179	5	85690	7	14711
35180	5	85694	6	6327
35181	5	85696	2	33635
35182	3	85699	3	16411
35183	5	85700	2	26361
35184	3	85700	6	26361
35185	5	85701	1	11798
35186	4	85707	2	31104
35187	5	85710	2	13950
35188	3	85711	7	33524
35189	5	85713	1	20782
35190	5	85714	1	11334
35191	3	85719	4	5654
35192	3	85720	7	33585
35193	4	85720	6	33585
35194	5	85721	3	33623
35195	1	85722	6	33578
35196	4	85722	7	33578
35197	5	85723	2	33676
35198	5	85725	6	26461
35199	5	85726	2	33664
35200	5	85733	5	29036
35201	5	85733	3	29036
35202	4	85734	7	10502
35203	5	85735	3	33601
35204	5	85735	2	33601
35205	4	85737	7	33652
35206	4	85737	2	33652
35207	4	85738	4	27752
35208	5	85740	6	25929
35209	3	85741	5	1563
35210	5	85742	7	30106
35211	5	85744	4	33653
35212	4	85746	7	33672
35213	5	85747	7	33669
35214	4	85747	2	33669
35215	3	85750	7	33508
35216	5	85752	5	13758
35217	5	85753	1	12061
35218	3	85755	5	1729
35219	4	85757	4	15171
35220	4	85758	7	33661
35221	5	85759	1	6987
35222	4	85760	4	10125
35223	5	85762	3	33689
35224	4	85768	2	5077
35225	5	85771	4	17714
35226	4	85771	1	17714
35227	5	85776	2	12578
35228	3	85777	1	14389
35229	5	85777	6	14389
35230	4	85778	1	1093
35231	5	85781	6	20016
35232	2	85787	3	25823
35233	5	85789	3	21771
35234	4	85791	7	22468
35235	5	85793	7	24759
35236	4	85794	6	18658
35237	5	85795	6	30088
35238	4	85797	7	6277
35239	5	85800	7	18900
35240	5	85801	4	33610
35241	5	85805	6	33688
35242	5	85807	1	26621
35243	5	85810	4	33701
35244	5	85813	7	33714
35245	5	85814	1	33612
35246	5	85815	2	11806
35247	4	85822	5	32550
35248	5	85824	6	33712
35249	4	85824	2	33712
35250	5	85829	5	33587
35251	4	85837	1	28440
35252	5	85838	4	1985
35253	5	85839	4	26126
35254	5	85840	6	27066
35255	3	85841	1	29763
35256	4	85842	2	19453
35257	5	85846	2	11651
35258	3	85848	3	12081
35259	4	85852	2	431
35260	5	85856	6	2320
35261	3	85859	4	3135
35262	5	85861	1	22321
35263	3	85862	2	5024
35264	5	85864	2	25516
35265	5	85865	6	7796
35266	3	85876	3	32268
35267	3	85879	3	10721
35268	1	85883	6	33609
35269	4	85884	1	1104
35270	5	85892	1	33604
35271	5	85893	1	9873
35272	5	85894	6	33521
35273	4	85900	2	15686
35274	5	85901	6	33679
35275	3	85904	4	33658
35276	5	85905	5	27533
35277	3	85908	2	33667
35278	3	85909	5	33634
35279	4	85910	1	27329
35280	4	85911	1	4605
35281	5	85915	4	33569
35282	5	85916	6	27873
35283	4	85918	4	3327
35284	4	85919	5	33574
35285	4	85919	4	33574
35286	5	85920	4	6176
35287	5	85921	1	33702
35288	5	85923	3	11089
35289	4	85927	3	33518
35290	4	85929	4	9303
35291	5	85933	2	10828
35292	5	85936	3	2728
35293	4	85947	4	33677
35294	3	85951	3	33705
35295	4	85953	7	11039
35296	4	85957	2	19883
35297	4	85958	2	33694
35298	5	85959	6	13815
35299	3	85960	5	33602
35300	5	85961	6	33600
35301	4	85963	5	3407
35302	4	85964	2	33534
35303	5	85966	6	25043
35304	5	85969	6	1864
35305	4	85971	1	11904
35306	3	85974	3	33579
35307	5	85978	6	18831
35308	3	85979	1	11361
35309	4	85983	4	26793
35310	5	85983	7	26793
35311	4	85984	3	33544
35312	5	85984	2	33544
35313	5	85988	7	17172
35314	5	85989	3	33247
35315	5	85992	6	33657
35316	5	85994	6	24729
35317	5	85997	1	20950
35318	5	85998	3	15622
35319	4	85999	2	19603
35320	5	86003	2	17326
35321	5	86004	2	15817
35322	5	86005	1	23588
35323	3	86007	3	33597
35324	3	86009	5	6097
35325	5	86012	3	15504
35326	5	86014	7	33520
35327	4	86015	5	33608
35328	5	86019	6	33543
35329	3	86021	6	27130
35330	5	86023	2	28693
35331	3	86027	4	15907
35332	4	86029	2	13313
35333	5	86030	2	32342
35334	5	86033	7	22606
35335	3	86035	7	32956
35336	5	86036	5	30304
35337	4	86038	2	7249
35338	5	86040	2	33695
35339	3	86041	7	1346
35340	5	86043	5	4829
35341	5	86046	3	30688
35342	5	86048	4	33627
35343	5	86049	4	2373
35344	5	86050	4	33539
35345	4	86053	2	26874
35346	5	86054	6	18230
35347	5	86054	7	18230
35348	5	86055	5	13819
35349	3	86055	7	13819
35350	3	86058	7	33656
35351	3	86059	6	33637
35352	4	86061	7	6150
35353	5	86062	7	14954
35354	5	86062	6	14954
35355	5	86075	4	33723
35356	5	86077	3	32144
35357	5	86081	2	33617
35358	3	86084	5	16181
35359	5	86088	4	1555
35360	5	86105	1	8314
35361	4	86107	4	33706
35362	4	86110	7	7566
35363	5	86116	6	3647
35364	4	86117	5	33514
35365	4	86118	2	1266
35366	5	86119	6	33564
35367	5	86119	5	33564
35368	5	86120	2	21426
35369	4	86120	7	21426
35370	5	86123	4	26000
35371	5	86124	4	8118
35372	3	86125	5	33575
35373	3	86130	5	4869
35374	4	86139	4	16340
35375	5	86141	6	1541
35376	5	86143	6	584
35377	3	86144	7	14031
35378	5	86145	2	30261
35379	4	86151	7	22959
35380	5	86151	6	22959
35381	1	86155	6	7931
35382	5	86164	4	18312
35383	4	86164	7	18312
35384	5	86169	6	11076
35385	3	86171	6	1697
35386	4	86176	3	33685
35387	5	86177	5	10196
35388	4	86178	2	10330
35389	5	86179	6	11254
35390	4	86180	5	18422
35391	3	86180	3	18422
35392	4	86182	3	15200
35393	5	86186	3	33561
35394	4	86190	3	15866
35395	4	86191	7	23036
35396	5	86192	6	5236
35397	1	86194	6	20815
35398	5	86197	2	23318
35399	5	86198	2	28244
35400	4	86199	1	16339
35401	3	86203	5	24085
35402	4	86203	7	24085
35403	5	86204	2	33528
35404	5	86208	2	33724
35405	5	86209	7	14289
35406	4	86211	7	30349
35407	5	86213	4	23016
35408	5	86217	4	33519
35409	5	86217	3	33519
35410	5	86220	6	17572
35411	4	86220	3	17572
35412	4	86222	7	14068
35413	4	86225	3	14501
35414	5	86227	7	17472
35415	4	86228	6	33913
35416	5	86229	1	16165
35417	5	86231	4	5674
35418	4	86233	4	33960
35419	5	86237	7	23933
35420	4	86238	4	33789
35421	5	86239	1	3785
35422	4	86243	5	33871
35423	4	86244	1	15197
35424	2	86246	5	33952
35425	3	86247	3	17056
35426	1	86251	6	33852
35427	5	86253	6	1044
35428	5	86256	1	24590
35429	5	86258	1	456
35430	2	86258	3	456
35431	4	86260	2	20232
35432	2	86262	6	33768
35433	4	86266	7	14284
35434	4	86267	4	4436
35435	5	86271	6	27044
35436	5	86272	4	33934
35437	5	86278	6	9453
35438	5	86279	2	1155
35439	5	86281	6	17309
35440	5	86282	7	33884
35441	4	86286	4	32548
35442	5	86289	7	3314
35443	5	86293	1	10844
35444	5	86296	7	33957
35445	5	86297	6	10988
35446	5	86302	7	4652
35447	5	86305	7	33766
35448	3	86305	5	33766
35449	4	86308	6	12203
35450	4	86310	6	27651
35451	5	86311	5	20044
35452	4	86311	7	20044
35453	5	86313	2	33809
35454	4	86315	7	92
35455	5	86317	4	29939
35456	4	86319	6	33796
35457	5	86322	1	24652
35458	5	86324	3	21859
35459	4	86326	3	13951
35460	5	86327	7	13984
35461	5	86330	3	33821
35462	4	86333	7	33823
35463	5	86338	6	23504
35464	5	86341	4	33892
35465	5	86341	2	33892
35466	5	86346	5	31697
35467	5	86347	7	14734
35468	5	86348	7	980
35469	5	86349	6	6939
35470	2	86350	2	33842
35471	5	86356	6	27452
35472	5	86357	3	2384
35473	5	86360	1	30745
35474	5	86361	7	33738
35475	5	86363	4	16282
35476	4	86364	1	33744
35477	5	86366	1	31421
35478	2	86368	4	32839
35479	5	86370	2	1742
35480	4	86372	1	33769
35481	5	86376	6	868
35482	5	86380	2	10101
35483	4	86382	2	6039
35484	5	86383	3	7957
35485	5	86385	1	14698
35486	5	86388	6	32789
35487	1	86389	6	33833
35488	4	86391	7	20931
35489	4	86393	6	33888
35490	4	86399	3	11495
35491	5	86405	4	17150
35492	3	86407	7	23623
35493	5	86411	5	25574
35494	5	86412	1	33805
35495	4	86416	1	13528
35496	3	86417	5	33779
35497	4	86418	7	33761
35498	3	86418	5	33761
35499	5	86422	3	2850
35500	4	86423	6	522
35501	3	86425	7	12231
35502	5	86428	2	18445
35503	5	86432	6	17778
35504	3	86433	1	16226
35505	5	86435	3	33785
35506	5	86436	3	33915
35507	5	86443	6	29543
35508	4	86445	7	15244
35509	4	86452	2	33877
35510	5	86455	1	31125
35511	5	86457	2	33907
35512	5	86458	2	15048
35513	5	86459	7	4962
35514	4	86461	4	33927
35515	1	86463	6	11152
35516	5	86464	4	26271
35517	5	86466	1	33939
35518	5	86467	3	15750
35519	4	86471	5	24311
35520	3	86474	7	12446
35521	3	86479	2	23755
35522	5	86480	6	2699
35523	4	86482	1	32278
35524	4	86485	3	4075
35525	4	86487	4	23906
35526	5	86489	3	33765
35527	5	86490	2	26967
35528	5	86491	7	33865
35529	3	86493	1	11367
35530	3	86494	7	24755
35531	2	86495	6	33857
35532	5	86496	6	3064
35533	3	86496	7	3064
35534	5	86497	4	10508
35535	5	86498	1	20215
35536	5	86500	3	30554
35537	4	86502	7	6341
35538	5	86502	6	6341
35539	5	86503	5	18460
35540	5	86504	6	27981
35541	3	86506	3	13413
35542	4	86512	5	32014
35543	3	86516	5	1942
35544	3	86518	5	18061
35545	5	86521	6	33807
35546	3	86522	5	30077
35547	5	86524	2	16952
35548	5	86525	4	33912
35549	5	86526	2	31437
35550	5	86528	5	25459
35551	3	86529	7	33568
35552	5	86530	4	7247
35553	5	86533	6	1951
35554	4	86535	3	33801
35555	5	86536	6	11321
35556	3	86537	1	16432
35557	3	86539	1	33959
35558	5	86541	5	27072
35559	4	86542	7	33755
35560	4	86543	4	26686
35561	5	86544	1	33116
35562	4	86546	4	16779
35563	2	86550	6	19401
35564	4	86554	7	25211
35565	5	86556	3	33917
35566	4	86558	1	4161
35567	5	86564	3	27846
35568	5	86570	6	19771
35569	3	86574	7	172
35570	5	86577	6	33815
35571	5	86578	2	844
35572	5	86581	6	33843
35573	5	86582	4	33872
35574	4	86582	5	33872
35575	5	86585	2	33835
35576	4	86590	2	6393
35577	5	86592	5	18683
35578	4	86592	1	18683
35579	4	86597	1	22581
35580	3	86598	5	29004
35581	4	86600	5	12468
35582	3	86602	1	26077
35583	5	86605	4	33844
35584	5	86607	6	8994
35585	5	86613	7	14311
35586	5	86614	6	33743
35587	4	86615	7	33752
35588	3	86619	1	23832
35589	5	86622	6	17973
35590	3	86624	1	15042
35591	4	86626	1	30136
35592	5	86630	5	15728
35593	5	86632	2	33856
35594	5	86635	1	8375
35595	5	86644	5	33874
35596	4	86645	7	19303
35597	2	86645	5	19303
35598	5	86646	6	5024
35599	3	86647	3	6097
35600	4	86649	4	265
35601	4	86651	7	33893
35602	5	86651	5	33893
35603	5	86653	2	33906
35604	1	86654	5	1147
35605	5	86655	2	33876
35606	5	86657	2	33883
35607	4	86659	3	19922
35608	4	86663	7	33764
35609	5	86664	5	25992
35610	5	86665	4	11709
35611	5	86667	5	31508
35612	2	86671	3	33831
35613	4	86674	4	1539
35614	5	86678	4	11932
35615	5	86684	2	8329
35616	3	86684	7	8329
35617	5	86686	6	1053
35618	5	86687	6	33849
35619	5	86691	7	1276
35620	4	86694	2	33784
35621	5	86700	7	33933
35622	4	86701	7	33926
35623	4	86702	6	9321
35624	4	86703	1	22293
35625	5	86706	6	26899
35626	4	86707	7	33800
35627	5	86708	5	4967
35628	5	86710	3	33153
35629	5	86713	7	14252
35630	5	86715	1	21667
35631	3	86716	1	13082
35632	5	86718	7	28413
35633	3	86720	7	8783
35634	4	86723	5	16114
35635	5	86724	2	6480
35636	3	86725	7	10359
35637	5	86726	3	14788
35638	5	86730	4	24081
35639	5	86731	2	16590
35640	5	86735	1	3071
35641	5	86736	5	1988
35642	5	86739	7	33955
35643	4	86740	1	21066
35644	1	86743	6	4521
35645	5	86744	7	33901
35646	2	86748	3	6
35647	5	86749	5	33802
35648	3	86751	7	33930
35649	3	86753	5	31442
35650	5	86756	3	33847
35651	5	86757	2	28531
35652	1	86758	4	24129
35653	5	86762	4	7579
35654	1	86763	6	12994
35655	3	86766	1	16406
35656	5	86769	7	10159
35657	5	86771	6	33880
35658	3	86772	5	15791
35659	4	86774	5	7297
35660	5	86777	3	33819
35661	5	86778	3	6284
35662	5	86781	3	33791
35663	3	86782	6	7712
35664	4	86788	6	7996
35665	4	86789	7	22843
35666	5	86791	2	18438
35667	2	86794	6	1920
35668	4	86798	2	26213
35669	5	86799	3	15443
35670	3	86807	5	14987
35671	3	86815	7	18067
35672	5	86822	6	7526
35673	5	86823	2	16240
35674	5	86826	7	28856
35675	3	86829	4	3764
35676	5	86830	4	33949
35677	3	86834	3	13429
35678	5	86837	2	33737
35679	4	86837	5	33737
35680	4	86838	7	33861
35681	3	86842	3	32900
35682	2	86844	6	9423
35683	5	86845	1	25420
35684	5	86848	4	32141
35685	5	86850	7	22971
35686	5	86853	4	1293
35687	4	86858	2	15113
35688	5	86859	7	24659
35689	5	86860	4	24061
35690	5	86864	6	31181
35691	3	86869	5	33830
35692	3	86871	7	8716
35693	5	86873	2	33948
35694	5	86874	5	33858
35695	5	86875	2	17980
35696	5	86876	2	3604
35697	5	86877	7	33810
35698	5	86880	7	2585
35699	5	86882	6	8177
35700	4	86887	1	33799
35701	4	86888	5	20815
35702	5	86890	2	21387
35703	4	86891	7	13253
35704	4	86895	5	24945
35705	1	86897	6	10751
35706	3	86902	4	33804
35707	3	86904	2	33950
35708	4	86906	2	16342
35709	5	86907	6	33778
35710	3	86908	5	33905
35711	5	86908	6	33905
35712	4	86912	3	33771
35713	4	86912	5	33771
35714	5	86914	5	32631
35715	5	86918	2	15183
35716	1	86920	6	10832
35717	5	86921	1	3628
35718	5	86922	4	3277
35719	5	86925	2	33954
35720	5	86930	1	33818
35721	5	86932	7	23571
35722	4	86934	5	585
35723	5	86935	7	33825
35724	5	86936	5	33797
35725	5	86947	4	7264
35726	5	86949	2	1781
35727	4	86955	5	28736
35728	5	86956	2	33956
35729	5	86957	4	4453
35730	5	86958	4	14475
35731	4	86959	7	471
35732	4	86962	1	33899
35733	5	86965	4	7455
35734	5	86972	7	33776
35735	4	86975	4	33798
35736	5	86977	6	9324
35737	1	86978	6	4177
35738	4	86980	5	33875
35739	5	86981	6	996
35740	2	86982	1	31117
35741	5	86984	7	18932
35742	5	86987	5	2310
35743	5	86992	4	22784
35744	4	86993	6	22749
35745	5	86994	6	10812
35746	1	86996	6	29877
35747	2	86997	6	22237
35748	3	86998	6	17876
35749	3	86999	5	18893
35750	4	87005	6	22324
35751	3	87007	5	33902
35752	5	87007	6	33902
35753	5	87008	4	33836
35754	3	87009	3	8834
35755	3	87014	2	8398
35756	5	87016	6	17527
35757	5	87017	6	10744
35758	4	87019	1	14258
35759	3	87026	2	31183
35760	3	87026	4	31183
35761	5	87029	3	3780
35762	4	87030	2	32774
35763	5	87031	6	29052
35764	5	87034	7	6080
35765	4	87035	3	9737
35766	3	87036	4	29017
35767	5	87037	2	32381
35768	5	87042	1	15422
35769	5	87043	6	33910
35770	5	87043	2	33910
35771	5	87044	6	17067
35772	5	87049	7	29956
35773	3	87050	6	11051
35774	5	87052	2	33855
35775	4	87055	5	34127
35776	4	87057	1	12539
35777	3	87058	5	20289
35778	5	87061	7	33964
35779	5	87063	2	27488
35780	5	87068	5	34091
35781	5	87069	3	26810
35782	5	87071	7	33390
35783	5	87073	2	19488
35784	5	87076	1	11680
35785	4	87082	3	15225
35786	4	87083	5	34119
35787	5	87085	3	34163
35788	5	87086	2	2173
35789	4	87089	6	33970
35790	4	87093	2	22227
35791	5	87096	6	30507
35792	4	87097	4	15092
35793	5	87099	3	15488
35794	5	87104	4	33218
35795	4	87107	5	30225
35796	5	87108	2	204
35797	5	87111	5	34167
35798	5	87112	5	34131
35799	5	87113	1	34174
35800	4	87115	3	33996
35801	3	87115	5	33996
35802	2	87116	6	25757
35803	5	87117	2	6074
35804	5	87120	6	33975
35805	4	87121	7	34156
35806	5	87123	4	17072
35807	3	87125	5	33792
35808	2	87129	4	34171
35809	4	87131	1	21703
35810	3	87132	5	12772
35811	4	87133	3	4699
35812	5	87135	6	31905
35813	5	87136	2	25984
35814	4	87139	3	21701
35815	5	87143	3	27002
35816	4	87145	7	30891
35817	5	87147	6	26028
35818	5	87151	7	23285
35819	5	87153	5	34101
35820	4	87153	6	34101
35821	4	87155	7	11465
35822	4	87156	5	33987
35823	3	87157	5	10127
35824	5	87158	6	29223
35825	3	87160	1	8795
35826	5	87173	6	519
35827	5	87174	4	29258
35828	1	87174	6	29258
35829	5	87177	7	34008
35830	5	87177	2	34008
35831	5	87187	6	28640
35832	5	87189	2	27619
35833	4	87190	5	23058
35834	5	87191	4	7934
35835	3	87197	3	34032
35836	3	87199	3	21680
35837	5	87200	2	19893
35838	4	87205	5	12132
35839	5	87208	7	31927
35840	5	87209	7	34166
35841	5	87213	5	34081
35842	5	87214	4	10989
35843	4	87218	3	28482
35844	4	87222	7	34105
35845	5	87225	6	26255
35846	4	87226	3	33965
35847	5	87227	5	34029
35848	4	87229	1	4240
35849	5	87230	6	29856
35850	5	87231	2	33982
35851	5	87233	1	34021
35852	5	87236	4	34122
35853	5	87239	6	22916
35854	5	87241	1	15701
35855	5	87243	6	34074
35856	5	87246	4	29106
35857	4	87247	3	24499
35858	4	87251	1	29590
35859	3	87251	5	29590
35860	3	87252	1	11390
35861	3	87253	7	34100
35862	4	87255	2	16264
35863	5	87257	1	27649
35864	5	87260	7	20852
35865	4	87261	2	5038
35866	5	87262	1	34097
35867	5	87264	5	34048
35868	5	87266	7	34148
35869	4	87272	3	33972
35870	5	87272	1	33972
35871	3	87276	1	28431
35872	4	87283	5	15320
35873	4	87285	7	25774
35874	5	87289	3	22527
35875	4	87289	1	22527
35876	4	87290	4	17668
35877	5	87294	5	31466
35878	3	87295	7	25195
35879	5	87299	2	17253
35880	5	87300	6	41
35881	2	87302	4	11001
35882	5	87304	6	25102
35883	2	87304	7	25102
35884	5	87309	1	34007
35885	5	87312	2	34003
35886	4	87313	1	28263
35887	5	87314	6	29906
35888	5	87315	2	21021
35889	5	87317	7	10596
35890	5	87319	7	18557
35891	3	87320	4	15944
35892	5	87324	6	33969
35893	4	87325	1	71
35894	5	87329	6	23296
35895	4	87333	7	24449
35896	3	87334	4	24849
35897	5	87335	7	34014
35898	3	87336	5	20251
35899	5	87336	6	20251
35900	5	87339	6	34098
35901	1	87340	6	34056
35902	5	87341	6	14211
35903	3	87342	3	33947
35904	3	87344	1	16420
35905	4	87349	7	24638
35906	5	87353	1	26737
35907	4	87360	5	1776
35908	3	87367	1	34045
35909	5	87369	7	34026
35910	5	87370	7	3597
35911	3	87371	3	6429
35912	5	87371	5	6429
35913	5	87374	7	4912
35914	1	87375	6	4570
35915	5	87381	6	34102
35916	4	87386	4	15000
35917	5	87387	7	8666
35918	2	87388	4	34025
35919	4	87389	7	33961
35920	5	87389	2	33961
35921	2	87393	6	34020
35922	3	87394	3	29601
35923	5	87396	7	5906
35924	5	87399	2	6812
35925	3	87400	3	34064
35926	5	87403	2	7900
35927	3	87405	5	24018
35928	3	87406	5	20165
35929	4	87408	5	34000
35930	5	87412	7	34173
35931	5	87414	7	34113
35932	1	87418	6	866
35933	5	87419	3	6811
35934	5	87420	2	10226
35935	5	87429	1	627
35936	5	87432	6	34118
35937	4	87433	7	31374
35938	4	87434	5	2124
35939	5	87437	7	3343
35940	5	87440	4	30534
35941	5	87443	1	2917
35942	4	87445	5	21848
35943	4	87446	7	8048
35944	4	87449	1	111
35945	4	87452	5	22723
35946	5	87455	6	34196
35947	4	87456	7	19948
35948	5	87458	5	26826
35949	5	87460	1	15958
35950	3	87466	2	34204
35951	5	87470	1	24037
35952	5	87470	4	24037
35953	2	87473	6	29208
35954	4	87473	7	29208
35955	5	87475	4	16253
35956	5	87480	5	34219
35957	4	87483	3	9995
35958	5	87486	1	34276
35959	4	87492	6	3621
35960	5	87493	2	34315
35961	4	87494	2	34310
35962	4	87496	2	22207
35963	5	87498	4	34268
35964	5	87502	4	18692
35965	5	87503	6	10341
35966	5	87505	5	1832
35967	3	87510	5	2807
35968	5	87511	5	29306
35969	4	87513	7	34238
35970	5	87516	7	12143
35971	4	87525	5	30258
35972	3	87526	7	3651
35973	5	87527	7	14742
35974	5	87528	1	4658
35975	5	87531	2	14719
35976	5	87532	6	32406
35977	5	87533	2	34223
35978	4	87536	2	993
35979	4	87537	7	34358
35980	4	87538	6	12448
35981	3	87539	5	15488
35982	5	87540	2	21244
35983	4	87541	3	1337
35984	3	87542	3	2832
35985	5	87543	5	34239
35986	5	87544	2	14305
35987	5	87547	6	1582
35988	3	87548	5	28692
35989	5	87550	3	1899
35990	5	87553	5	7529
35991	5	87554	4	34333
35992	5	87556	7	14090
35993	5	87558	2	34365
35994	5	87559	5	34343
35995	5	87560	2	32063
35996	5	87564	2	34342
35997	5	87565	6	29214
35998	4	87567	5	27405
35999	5	87568	3	23660
36000	3	87572	5	7453
36001	5	87576	4	17809
36002	5	87579	2	30032
36003	5	87580	7	12022
36004	5	87580	6	12022
36005	5	87582	3	1306
36006	4	87583	7	29197
36007	5	87584	7	34336
36008	5	87585	6	14896
36009	5	87587	5	34363
36010	5	87588	2	19216
36011	5	87589	5	22367
36012	5	87589	3	22367
36013	3	87593	2	177
36014	5	87597	1	25215
36015	1	87598	5	16230
36016	5	87599	6	28439
36017	3	87601	1	16829
36018	5	87602	2	23835
36019	5	87604	7	18951
36020	4	87607	6	3114
36021	4	87608	7	34384
36022	5	87610	2	11768
36023	4	87610	5	11768
36024	4	87613	7	21989
36025	3	87618	1	26461
36026	5	87619	3	34359
36027	5	87624	2	28441
36028	5	87625	7	34338
36029	3	87626	1	10577
36030	5	87627	2	1780
36031	5	87629	3	23101
36032	4	87630	2	3358
36033	3	87633	5	12212
36034	5	87635	4	34308
36035	3	87636	3	24168
36036	5	87636	2	24168
36037	4	87639	6	34227
36038	4	87643	3	26742
36039	5	87644	6	34250
36040	3	87645	7	8823
36041	5	87653	5	34371
36042	5	87654	6	9227
36043	2	87655	4	31164
36044	1	87656	6	15906
36045	3	87657	5	19111
36046	5	87659	4	34235
36047	5	87660	3	5306
36048	5	87663	3	34356
36049	5	87664	5	25142
36050	5	87665	4	34185
36051	4	87666	7	34201
36052	5	87667	5	293
36053	3	87668	5	34256
36054	3	87669	6	26493
36055	5	87674	1	6898
36056	4	87677	7	16496
36057	5	87680	4	29787
36058	5	87683	5	34242
36059	4	87684	5	12191
36060	4	87688	6	27907
36061	4	87690	7	23964
36062	5	87692	2	11587
36063	5	87695	3	4063
36064	4	87696	3	11210
36065	4	87697	4	16657
36066	5	87699	2	18891
36067	1	87700	2	7206
36068	4	87702	5	34209
36069	4	87703	6	26706
36070	5	87704	7	34361
36071	4	87708	5	30124
36072	4	87712	4	8993
36073	5	87713	6	19826
36074	3	87716	5	34327
36075	5	87718	2	29064
36076	5	87720	5	24344
36077	5	87722	6	16711
36078	4	87724	3	32312
36079	3	87725	2	34331
36080	5	87725	5	34331
36081	5	87727	3	34320
36082	3	87728	2	30379
36083	5	87730	1	19366
36084	3	87732	5	34260
36085	5	87734	6	34312
36086	3	87735	2	22547
36087	5	87735	6	22547
36088	4	87737	7	34195
36089	3	87740	3	29851
36090	4	87743	5	24220
36091	3	87744	7	34194
36092	4	87745	7	34214
36093	3	87747	1	21187
36094	4	87749	3	23284
36095	5	87751	5	34231
36096	5	87752	7	34375
36097	5	87756	6	21968
36098	5	87759	6	34266
36099	5	87762	5	34230
36100	4	87763	3	34311
36101	2	87764	3	17666
36102	5	87773	4	18119
36103	3	87775	2	31148
36104	5	87776	5	23037
36105	5	87776	4	23037
36106	5	87778	6	21813
36107	5	87780	2	34213
36108	4	87786	2	27321
36109	3	87788	3	2519
36110	3	87794	1	24948
36111	5	87797	6	34307
36112	5	87798	4	2446
36113	4	87808	7	34180
36114	4	87809	5	28089
36115	4	87810	5	11239
36116	4	87811	3	21640
36117	3	87815	2	8151
36118	5	87816	6	23298
36119	3	87818	1	24135
36120	5	87822	6	1914
36121	5	87824	1	5478
36122	3	87826	6	13537
36123	5	87827	2	33909
36124	5	87830	7	34257
36125	3	87832	5	33789
36126	5	87834	7	24788
36127	5	87835	6	12793
36128	5	87840	4	34324
36129	5	87842	5	8807
36130	5	87848	4	32611
36131	3	87850	1	30189
36132	4	87851	1	29113
36133	3	87852	5	26279
36134	4	87853	7	34287
36135	5	87856	1	34379
36136	5	87861	4	19372
36137	1	87861	6	19372
36138	4	87863	7	32507
36139	5	87866	3	7638
36140	5	87870	4	34325
36141	4	87875	1	34313
36142	5	87878	2	2139
36143	4	87879	4	2048
36144	5	87881	7	856
36145	4	87882	7	15234
36146	4	87883	7	18102
36147	4	87885	5	34284
36148	4	87887	5	34253
36149	3	87889	7	12690
36150	4	87893	4	34561
36151	4	87895	6	1970
36152	4	87896	5	9531
36153	5	87898	6	18210
36154	5	87901	7	34391
36155	4	87903	4	22214
36156	5	87905	3	34498
36157	4	87906	5	34465
36158	4	87907	7	34531
36159	3	87913	4	7899
36160	4	87913	2	7899
36161	4	87915	6	11653
36162	3	87918	5	14904
36163	3	87919	5	14668
36164	5	87925	1	120
36165	4	87927	4	26417
36166	5	87927	1	26417
36167	4	87931	7	15188
36168	4	87931	4	15188
36169	5	87937	3	4592
36170	4	87941	4	5965
36171	5	87943	4	30704
36172	5	87945	6	5240
36173	5	87947	6	5540
36174	5	87947	5	5540
36175	5	87948	6	16898
36176	5	87949	3	1332
36177	3	87951	4	9311
36178	5	87952	6	34585
36179	5	87954	1	34508
36180	5	87957	5	873
36181	5	87960	7	27863
36182	4	87961	2	34394
36183	2	87963	3	15394
36184	3	87964	2	32457
36185	3	87965	4	1838
36186	3	87966	7	13636
36187	5	87967	2	34538
36188	3	87969	2	9759
36189	5	87973	4	34433
36190	5	87975	4	1093
36191	5	87976	1	26052
36192	4	87980	5	34401
36193	5	87984	5	7614
36194	4	87986	4	29929
36195	5	87986	6	29929
36196	5	87989	6	34497
36197	4	87990	3	2
36198	5	87994	7	26959
36199	4	87995	7	29951
36200	4	87998	5	12726
36201	4	88000	4	34569
36202	5	88002	2	4373
36203	5	88005	6	20203
36204	5	88006	5	25749
36205	5	88011	2	27581
36206	4	88012	6	12783
36207	5	88020	1	34421
36208	4	88023	2	10246
36209	5	88025	6	30298
36210	4	88026	4	27083
36211	5	88028	4	34578
36212	5	88029	5	9076
36213	5	88030	2	3634
36214	5	88035	3	24298
36215	5	88036	1	34443
36216	5	88039	6	34414
36217	5	88039	7	34414
36218	4	88041	6	34494
36219	5	88042	3	30557
36220	5	88044	7	8074
36221	4	88045	2	12850
36222	1	88047	6	5235
36223	5	88049	2	34418
36224	5	88052	6	34450
36225	5	88055	4	19721
36226	5	88060	6	34428
36227	4	88062	3	23084
36228	5	88064	1	34422
36229	5	88065	2	34473
36230	5	88069	2	2770
36231	4	88072	1	13622
36232	5	88073	5	34502
36233	5	88077	2	25403
36234	5	88078	5	34522
36235	5	88079	4	34588
36236	5	88080	6	22905
36237	5	88082	4	29513
36238	5	88083	6	21105
36239	5	88083	2	21105
36240	1	88087	6	9078
36241	4	88088	7	26108
36242	1	88092	4	34491
36243	4	88092	6	34491
36244	4	88094	1	26988
36245	5	88096	6	31757
36246	5	88101	7	34545
36247	4	88103	6	19566
36248	5	88107	5	32506
36249	4	88108	1	11756
36250	5	88111	7	1059
36251	5	88114	7	34573
36252	5	88115	6	5654
36253	5	88116	7	34463
36254	5	88117	2	34565
36255	5	88118	7	30371
36256	4	88119	3	18823
36257	5	88122	7	17833
36258	3	88122	4	17833
36259	4	88126	7	5768
36260	4	88131	1	34544
36261	5	88131	4	34544
36262	4	88133	4	11822
36263	5	88134	6	34486
36264	5	88138	1	22966
36265	5	88145	4	19460
36266	5	88152	1	15334
36267	5	88153	6	23102
36268	5	88154	1	1657
36269	5	88156	6	34436
36270	5	88157	2	34415
36271	1	88157	4	34415
36272	3	88158	7	11887
36273	5	88160	6	34479
36274	3	88162	3	1106
36275	4	88163	7	34429
36276	4	88165	5	19923
36277	1	88169	7	23415
36278	5	88171	3	17127
36279	5	88172	3	18390
36280	5	88173	3	5649
36281	4	88174	7	4870
36282	5	88175	6	1107
36283	5	88178	4	10287
36284	5	88182	2	1122
36285	5	88183	4	32789
36286	3	88184	3	2264
36287	5	88185	5	6516
36288	4	88186	2	18901
36289	4	88186	5	18901
36290	5	88190	2	34552
36291	5	88192	6	34459
36292	4	88194	1	20711
36293	2	88195	1	24673
36294	5	88195	6	24673
36295	5	88200	7	34488
36296	3	88201	1	34587
36297	4	88202	7	12017
36298	4	88203	4	34513
36299	4	88204	4	572
36300	5	88205	4	33001
36301	5	88208	7	28657
36302	3	88211	7	22820
36303	1	88212	6	16165
36304	2	88213	1	12275
36305	5	88217	5	26186
36306	4	88227	6	34395
36307	5	88230	4	34457
36308	5	88232	3	14671
36309	2	88234	3	11113
36310	3	88235	3	18622
36311	3	88241	1	3940
36312	5	88244	6	34586
36313	3	88245	7	34572
36314	5	88246	1	10274
36315	5	88247	6	10540
36316	4	88248	5	30302
36317	1	88250	6	21936
36318	5	88253	2	9057
36319	1	88256	6	5253
36320	5	88257	1	18356
36321	4	88257	6	18356
36322	5	88258	6	5876
36323	5	88261	2	34481
36324	5	88262	1	34437
36325	5	88264	1	34503
36326	4	88266	1	34462
36327	3	88267	3	34550
36328	5	88269	5	5570
36329	4	88271	5	34591
36330	5	88276	4	34536
36331	3	88277	5	8068
36332	4	88278	2	34413
36333	5	88279	3	34535
36334	5	88280	5	22721
36335	4	88284	1	15540
36336	1	88293	1	9081
36337	2	88294	6	25847
36338	5	88295	7	30723
36339	3	88296	5	18996
36340	4	88297	2	2041
36341	4	88298	7	34420
36342	2	88300	1	4912
36343	3	88301	7	28731
36344	5	88302	7	20869
36345	3	88305	7	5087
36346	5	88311	6	24487
36347	4	88314	1	34539
36348	3	88314	7	34539
36349	5	88315	2	12754
36350	5	88324	7	34555
36351	5	88327	6	34571
36352	5	88328	6	25965
36353	5	88331	6	34509
36354	5	88332	5	9554
36355	3	88334	7	6366
36356	4	88336	4	31983
36357	5	88338	6	23353
36358	4	88339	2	34482
36359	4	88339	4	34482
36360	3	88340	5	27770
36361	5	88341	4	8081
36362	5	88343	3	25877
36363	5	88344	1	31351
36364	5	88346	4	31679
36365	5	88348	2	11244
36366	4	88349	7	34389
36367	5	88352	2	25247
36368	4	88353	4	20905
36369	3	88354	1	28138
36370	5	88359	6	33402
36371	5	88360	6	5420
36372	4	88361	1	6155
36373	5	88365	5	16765
36374	5	88368	5	34469
36375	4	88370	2	34451
36376	5	88372	6	27920
36377	1	88373	6	27720
36378	3	88374	7	4659
36379	5	88377	1	11189
36380	5	88383	5	23172
36381	4	88384	1	34484
36382	1	88392	3	34399
36383	3	88393	5	34532
36384	4	88402	7	10558
36385	4	88403	5	2575
36386	5	88404	6	34439
36387	5	88404	3	34439
36388	5	88408	4	17385
36389	5	88412	4	2854
36390	3	88415	5	6050
36391	5	88418	5	34419
36392	5	88420	1	34447
36393	3	88423	6	18102
36394	4	88429	6	12089
36395	5	88431	2	397
36396	5	88432	2	29001
36397	3	88433	5	23339
36398	5	88434	1	980
36399	5	88437	7	27271
36400	5	88438	5	34492
36401	5	88443	5	1819
36402	5	88447	4	34438
36403	5	88448	5	25358
36404	5	88449	4	15528
36405	4	88450	7	24954
36406	5	88454	7	34396
36407	3	88456	4	7008
36408	3	88459	1	10418
36409	4	88463	1	20681
36410	3	88464	1	34504
36411	3	88466	7	34407
36412	5	88467	6	15061
36413	3	88468	3	25941
36414	5	88469	2	2302
36415	5	88470	7	19931
36416	5	88473	5	34574
36417	4	88474	2	16386
36418	3	88476	7	2651
36419	4	88479	4	5161
36420	5	88480	5	23700
36421	5	88481	3	9978
36422	5	88481	2	9978
36423	4	88488	4	34500
36424	5	88489	1	34527
36425	3	88496	7	20455
36426	5	88497	6	34411
36427	5	88501	6	32313
36428	5	88502	4	21069
36429	3	88505	4	15796
36430	3	88505	2	15796
36431	3	88506	7	13676
36432	5	88507	1	10675
36433	4	88508	1	34406
36434	3	88510	7	31032
36435	5	88511	3	31006
36436	5	88513	6	34471
36437	4	88514	2	16967
36438	4	88515	4	27777
36439	5	88520	7	18413
36440	5	88521	2	18147
36441	5	88522	3	27258
36442	3	88523	7	17994
36443	5	88524	6	34613
36444	3	88530	4	34736
36445	5	88531	2	26256
36446	1	88533	4	34601
36447	3	88537	6	13977
36448	5	88538	2	8705
36449	5	88542	4	34720
36450	5	88543	6	34640
36451	5	88544	3	34708
36452	4	88545	5	6128
36453	4	88548	6	12604
36454	3	88549	4	18603
36455	3	88552	2	25273
36456	3	88557	5	19173
36457	1	88562	7	2313
36458	3	88563	2	17603
36459	1	88568	6	12027
36460	4	88571	6	34710
36461	5	88573	6	31134
36462	5	88584	2	2401
36463	5	88585	7	27096
36464	5	88589	7	20452
36465	5	88593	6	26152
36466	5	88597	2	12761
36467	3	88600	7	34440
36468	4	88602	6	30255
36469	4	88603	7	24037
36470	5	88606	1	33602
36471	5	88607	3	34704
36472	5	88608	7	34754
36473	5	88609	2	7068
36474	5	88610	2	24942
36475	4	88614	7	17194
36476	2	88615	3	11464
36477	5	88621	7	12951
36478	4	88623	5	34752
36479	5	88625	4	34661
36480	5	88628	6	26385
36481	3	88629	1	24943
36482	5	88632	5	34711
36483	3	88633	7	16773
36484	4	88636	6	2101
36485	3	88640	2	34767
36486	5	88641	4	14508
36487	4	88644	2	3838
36488	4	88645	7	34603
36489	5	88646	2	1700
36490	5	88649	7	34660
36491	4	88650	5	9191
36492	1	88651	6	21861
36493	2	88653	3	5385
36494	5	88654	3	6664
36495	4	88657	7	7902
36496	5	88658	1	9947
36497	3	88659	3	34645
36498	2	88666	4	13613
36499	5	88666	6	13613
36500	5	88667	2	34737
36501	4	88672	5	31579
36502	3	88672	7	31579
36503	4	88676	5	3125
36504	5	88677	7	15590
36505	2	88678	6	34733
36506	3	88679	5	34728
36507	3	88680	5	34611
36508	5	88683	2	34764
36509	4	88685	5	34686
36510	5	88687	7	34713
36511	3	88688	5	27020
36512	5	88689	4	8101
36513	5	88689	2	8101
36514	5	88690	6	10575
36515	3	88691	1	22463
36516	4	88696	7	34730
36517	5	88699	2	18405
36518	5	88701	2	24916
36519	5	88703	1	10203
36520	4	88704	7	28491
36521	5	88710	4	11124
36522	2	88711	1	11301
36523	4	88712	2	23124
36524	5	88714	4	6171
36525	5	88716	6	34612
36526	4	88717	3	1555
36527	4	88721	6	22175
36528	3	88722	5	28894
36529	5	88722	4	28894
36530	4	88723	7	654
36531	4	88729	7	13410
36532	2	88730	1	34650
36533	4	88732	3	17627
36534	3	88737	3	34682
36535	5	88738	4	17626
36536	4	88743	7	19809
36537	5	88744	3	8287
36538	5	88754	4	30614
36539	4	88755	7	34721
36540	5	88756	1	34648
36541	5	88757	4	14668
36542	5	88757	2	14668
36543	4	88759	6	34646
36544	5	88761	6	13930
36545	4	88762	7	31420
36546	4	88763	1	28768
36547	3	88765	4	14175
36548	4	88767	5	34716
36549	3	88768	2	17333
36550	4	88771	4	30761
36551	5	88772	4	25369
36552	5	88775	7	2167
36553	2	88781	3	8561
36554	5	88783	4	27062
36555	4	88785	6	12615
36556	3	88786	4	26780
36557	5	88787	4	6243
36558	5	88790	7	34692
36559	4	88794	6	32344
36560	5	88795	5	26634
36561	3	88798	2	21578
36562	3	88801	1	34724
36563	5	88803	4	23285
36564	5	88811	3	11550
36565	5	88811	6	11550
36566	2	88813	4	33795
36567	5	88815	3	30173
36568	4	88825	5	32571
36569	3	88827	7	34729
36570	3	88828	3	5164
36571	5	88834	2	33492
36572	4	88835	1	21097
36573	4	88843	7	27808
36574	5	88845	7	29691
36575	4	88846	4	31595
36576	5	88847	2	28952
36577	3	88849	2	33421
36578	4	88851	1	25169
36579	5	88853	1	961
36580	4	88858	2	5093
36581	4	88859	7	34669
36582	5	88860	5	26294
36583	5	88861	3	34596
36584	5	88869	3	26528
36585	4	88872	7	27701
36586	4	88873	7	30707
36587	5	88877	1	21868
36588	4	88878	2	12546
36589	5	88879	6	34665
36590	5	88882	3	6760
36591	4	88883	7	32153
36592	5	88883	6	32153
36593	2	88885	5	34629
36594	5	88887	3	34600
36595	3	88892	4	30349
36596	5	88893	7	34698
36597	5	88893	5	34698
36598	3	88894	2	16505
36599	4	88896	3	17691
36600	4	88896	7	17691
36601	5	88903	2	9563
36602	5	88909	4	34609
36603	4	88912	5	17030
36604	5	88913	2	34615
36605	4	88917	3	10095
36606	5	88918	6	34680
36607	3	88919	7	29478
36608	3	88920	1	34740
36609	5	88921	2	8372
36610	5	88922	5	6950
36611	3	88931	1	34679
36612	5	88937	6	22963
36613	3	88939	3	18863
36614	1	88940	6	12415
36615	5	88948	3	34739
36616	5	88949	6	25621
36617	2	88951	6	29622
36618	4	88952	5	19927
36619	5	88953	2	34743
36620	4	88954	7	34667
36621	5	88956	2	11004
36622	4	88960	5	23521
36623	4	88963	2	34696
36624	4	88966	6	8939
36625	5	88968	7	6792
36626	5	88969	2	9597
36627	5	88972	7	764
36628	5	88980	2	28181
36629	5	88983	2	195
36630	4	88985	4	34772
36631	5	88986	4	2000
36632	5	88990	5	11822
36633	4	88992	5	33667
36634	3	88993	7	5271
36635	5	88993	2	5271
36636	5	88995	1	5811
36637	4	88997	5	28729
36638	3	89000	5	27053
36639	5	89004	4	6302
36640	3	89007	1	2477
36641	3	89009	3	24842
36642	5	89009	7	24842
36643	3	89010	7	477
36644	5	89012	1	23695
36645	5	89018	6	19233
36646	5	89019	3	33755
36647	5	89020	1	32300
36648	5	89021	3	34091
36649	5	89023	7	19102
36650	5	89026	7	34674
36651	3	89033	5	1245
36652	5	89035	2	30371
36653	4	89036	3	7989
36654	4	89038	1	34623
36655	5	89041	6	1669
36656	3	89042	5	30991
36657	4	89043	6	30736
36658	5	89044	6	25173
36659	4	89045	1	23380
36660	4	89046	7	34630
36661	5	89047	6	1445
36662	5	89048	7	2627
36663	2	89049	2	4363
36664	4	89050	5	34691
36665	5	89053	6	34602
36666	5	89054	2	34749
36667	3	89056	5	32675
36668	5	89056	6	32675
36669	5	89058	5	12476
36670	5	89060	5	20967
36671	4	89065	6	28564
36672	5	89067	5	13475
36673	4	89068	3	12664
36674	4	89070	4	22338
36675	5	89072	7	34605
36676	5	89073	2	7595
36677	3	89074	5	34614
36678	5	89077	6	26943
36679	3	89079	5	8852
36680	5	89084	1	15246
36681	4	89090	7	34450
36682	5	89093	6	8813
36683	5	89096	6	6277
36684	5	89097	7	5643
36685	4	89101	7	34697
36686	5	89102	4	29233
36687	5	89105	2	5359
36688	5	89106	5	34725
36689	4	89109	7	12075
36690	3	89114	7	14093
36691	5	89116	4	7211
36692	5	89126	2	9575
36693	3	89129	7	34670
36694	5	89138	2	2623
36695	5	89139	2	5474
36696	5	89142	6	34885
36697	5	89146	1	10442
36698	1	89154	6	1536
36699	4	89154	3	1536
36700	5	89161	2	34982
36701	5	89161	6	34982
36702	5	89162	6	3102
36703	4	89168	7	35004
36704	5	89169	3	18982
36705	5	89170	6	9698
36706	5	89172	4	7983
36707	4	89180	5	439
36708	5	89188	4	34871
36709	5	89189	2	21689
36710	5	89192	5	34807
36711	5	89194	6	34835
36712	5	89195	4	2416
36713	5	89199	6	34845
36714	5	89202	5	33378
36715	5	89205	4	22407
36716	4	89208	2	2928
36717	5	89210	4	21703
36718	4	89213	3	34973
36719	5	89215	7	10494
36720	4	89217	5	34892
36721	5	89219	1	20095
36722	4	89220	6	16427
36723	5	89221	6	2153
36724	3	89222	4	34927
36725	5	89224	5	29806
36726	5	89228	4	34831
36727	5	89230	5	12707
36728	4	89231	7	25172
36729	4	89232	4	91
36730	3	89233	6	34787
36731	3	89237	4	16205
36732	5	89240	2	27804
36733	5	89242	5	10031
36734	5	89243	5	34964
36735	5	89246	1	32403
36736	5	89250	7	19082
36737	5	89251	3	7000
36738	5	89253	6	31301
36739	5	89253	1	31301
36740	3	89257	4	23052
36741	4	89259	5	34895
36742	5	89260	6	21290
36743	4	89261	3	8673
36744	5	89262	6	10526
36745	5	89263	1	4820
36746	4	89265	7	34876
36747	4	89266	5	5904
36748	4	89272	2	33828
36749	5	89274	2	32960
36750	4	89276	1	34940
36751	5	89278	4	4874
36752	3	89279	1	28836
36753	3	89284	7	34827
36754	5	89285	7	34850
36755	5	89290	4	34992
36756	3	89292	5	23083
36757	5	89295	3	29809
36758	5	89299	6	34816
36759	5	89301	4	7152
36760	5	89304	2	34997
36761	5	89309	6	23518
36762	4	89313	6	15788
36763	4	89316	4	3877
36764	4	89317	6	34823
36765	5	89319	2	5110
36766	5	89320	7	32579
36767	5	89322	5	34844
36768	4	89324	3	34828
36769	3	89325	5	27202
36770	5	89326	3	15548
36771	5	89334	4	24441
36772	5	89336	4	10080
36773	3	89339	5	2781
36774	5	89340	1	34970
36775	4	89344	7	34938
36776	4	89344	5	34938
36777	2	89345	6	34920
36778	3	89348	7	33240
36779	5	89350	1	14756
36780	3	89353	3	10870
36781	4	89355	7	34949
36782	5	89356	7	11896
36783	1	89359	6	23382
36784	4	89360	5	10492
36785	1	89361	1	24552
36786	4	89362	7	5839
36787	5	89367	2	7189
36788	5	89370	5	9882
36789	2	89370	6	9882
36790	3	89372	5	18658
36791	3	89375	5	7253
36792	5	89375	1	7253
36793	5	89377	4	25612
36794	5	89382	1	34903
36795	4	89387	7	34818
36796	4	89388	7	34274
36797	5	89389	7	26911
36798	4	89390	6	32006
36799	4	89390	2	32006
36800	3	89392	5	19683
36801	1	89394	6	9989
36802	5	89396	2	34804
36803	4	89397	2	34915
36804	5	89398	6	23390
36805	4	89400	7	27931
36806	4	89401	6	2367
36807	3	89402	5	32886
36808	4	89403	6	34919
36809	5	89404	2	27997
36810	5	89406	3	4624
36811	4	89408	1	34499
36812	5	89410	4	20598
36813	4	89415	5	25602
36814	5	89417	7	2901
36815	5	89419	5	9192
36816	4	89420	3	8796
36817	2	89421	7	31661
36818	5	89425	6	4595
36819	4	89427	3	34889
36820	1	89429	6	3708
36821	2	89430	4	23512
36822	3	89432	5	34508
36823	5	89433	7	34893
36824	4	89434	1	25286
36825	5	89435	6	19498
36826	5	89436	1	31117
36827	5	89439	2	25954
36828	5	89440	7	34864
36829	3	89442	5	15605
36830	4	89442	6	15605
36831	4	89443	3	17003
36832	5	89444	2	5643
36833	5	89447	5	34880
36834	5	89452	2	9343
36835	5	89454	1	9097
36836	5	89454	3	9097
36837	4	89456	6	20823
36838	3	89458	5	27745
36839	4	89459	1	9640
36840	5	89462	7	15105
36841	5	89464	3	30841
36842	3	89465	7	14123
36843	5	89466	2	34975
36844	5	89467	2	34783
36845	5	89469	6	6515
36846	5	89471	5	34978
36847	5	89472	5	34879
36848	5	89474	5	1653
36849	4	89475	7	33346
36850	4	89477	3	34785
36851	5	89478	2	9744
36852	5	89479	5	23307
36853	5	89479	7	23307
36854	4	89480	3	30454
36855	5	89484	4	34814
36856	3	89489	5	29287
36857	4	89491	5	6586
36858	2	89494	6	11152
36859	1	89495	6	34873
36860	3	89497	7	16640
36861	5	89499	1	34976
36862	5	89501	1	11827
36863	4	89505	4	14716
36864	5	89509	7	26393
36865	4	89512	7	34900
36866	5	89519	4	34955
36867	5	89520	7	34442
36868	5	89523	5	15109
36869	5	89525	2	19313
36870	4	89526	2	34974
36871	1	89527	4	34958
36872	4	89528	6	34856
36873	5	89529	3	6729
36874	3	89530	7	34832
36875	5	89531	2	8666
36876	3	89534	2	34878
36877	5	89537	4	22272
36878	3	89539	2	29657
36879	5	89541	7	11555
36880	5	89541	1	11555
36881	4	89542	1	30279
36882	5	89543	2	8640
36883	5	89545	7	22890
36884	3	89546	4	23986
36885	3	89549	4	34993
36886	5	89551	2	765
36887	5	89552	6	27772
36888	5	89553	5	22472
36889	3	89560	3	34240
36890	4	89560	7	34240
36891	4	89561	1	34928
36892	5	89563	4	27187
36893	5	89564	6	25526
36894	5	89564	4	25526
36895	5	89566	1	2512
36896	5	89569	1	364
36897	5	89570	1	9358
36898	5	89571	2	34851
36899	5	89574	4	13399
36900	5	89580	1	8083
36901	5	89581	2	34244
36902	5	89583	5	18503
36903	5	89586	1	18112
36904	3	89590	1	26092
36905	3	89591	3	34956
36906	5	89593	6	34891
36907	2	89593	1	34891
36908	5	89594	6	19280
36909	2	89595	4	34826
36910	5	89601	6	34953
36911	1	89602	3	8054
36912	3	89604	2	34986
36913	4	89608	4	34782
36914	4	89609	4	34945
36915	5	89611	6	8609
36916	3	89611	7	8609
36917	5	89614	3	788
36918	5	89616	1	11932
36919	4	89617	2	24273
36920	5	89619	4	8968
36921	5	89620	2	2618
36922	5	89622	2	10550
36923	3	89623	6	9876
36924	2	89627	7	3224
36925	4	89630	6	30858
36926	1	89633	6	1366
36927	5	89635	2	30153
36928	5	89636	2	34862
36929	3	89637	1	19566
36930	3	89639	7	33464
36931	5	89639	2	33464
36932	5	89640	6	1843
36933	5	89641	4	16041
36934	5	89642	7	26909
36935	4	89645	3	25815
36936	3	89648	4	31186
36937	4	89657	4	25352
36938	5	89659	6	13636
36939	5	89663	7	11985
36940	3	89664	5	9684
36941	3	89666	4	31031
36942	3	89667	5	34936
36943	4	89668	4	10639
36944	5	89671	5	34809
36945	3	89673	1	15386
36946	5	89675	1	23587
36947	5	89675	7	23587
36948	5	89678	2	34917
36949	5	89679	2	33546
36950	5	89681	2	2189
36951	4	89685	7	34815
36952	5	89686	1	12274
36953	5	89688	4	34834
36954	4	89689	7	21189
36955	5	89693	1	34776
36956	4	89698	3	34872
36957	5	89700	4	34968
36958	4	89702	7	34852
36959	5	89707	7	34962
36960	5	89709	2	7119
36961	5	89712	6	4047
36962	4	89713	6	9603
36963	4	89717	7	10769
36964	5	89725	7	8492
36965	5	89727	5	23470
36966	5	89730	1	15044
36967	5	89741	2	25692
36968	5	89743	6	31888
36969	5	89745	7	20774
36970	5	89750	2	24699
36971	5	89756	1	23540
36972	4	89760	4	26765
36973	3	89763	5	35111
36974	4	89765	4	18392
36975	4	89771	2	14159
36976	5	89771	4	14159
36977	3	89772	3	31161
36978	4	89773	2	8873
36979	4	89776	3	35166
36980	3	89782	7	3949
36981	3	89783	3	13994
36982	5	89784	7	35187
36983	3	89785	3	19476
36984	5	89786	4	2238
36985	4	89789	6	15291
36986	5	89790	6	22056
36987	4	89793	5	5779
36988	3	89794	7	19729
36989	5	89797	6	33056
36990	5	89799	6	35176
36991	4	89802	7	1356
36992	5	89808	5	22350
36993	3	89809	7	27256
36994	5	89811	4	25729
36995	4	89813	7	35048
36996	3	89814	5	21375
36997	5	89818	6	35198
36998	3	89818	7	35198
36999	5	89820	2	13634
37000	3	89821	7	33311
37001	5	89822	6	35085
37002	5	89824	6	22882
37003	5	89826	3	18945
37004	4	89828	3	35175
37005	5	89833	6	203
37006	5	89835	7	20000
37007	5	89836	4	9871
37008	5	89837	2	14354
37009	1	89837	6	14354
37010	5	89839	2	5095
37011	5	89842	4	73
37012	3	89852	3	16785
37013	3	89854	3	29098
37014	5	89855	7	21543
37015	5	89859	2	656
37016	4	89860	7	31174
37017	4	89863	3	35036
37018	2	89864	5	35088
37019	4	89865	7	33746
37020	3	89866	7	3100
37021	4	89869	7	12180
37022	5	89870	2	35008
37023	5	89873	3	11011
37024	5	89874	7	35110
37025	4	89875	4	24402
37026	3	89884	3	19507
37027	5	89885	6	35095
37028	4	89887	2	16868
37029	5	89888	7	7217
37030	5	89889	1	8057
37031	3	89891	7	35201
37032	5	89896	7	16285
37033	5	89900	5	21296
37034	5	89903	6	3462
37035	3	89905	7	11798
37036	4	89907	4	3313
37037	3	89915	5	11172
37038	5	89916	1	611
37039	5	89918	3	2367
37040	3	89923	5	12053
37041	3	89926	3	35185
37042	5	89929	2	33787
37043	4	89930	7	6894
37044	5	89931	6	4836
37045	5	89932	7	16239
37046	5	89935	7	17741
37047	5	89941	3	2051
37048	4	89943	2	35102
37049	5	89944	6	35142
37050	4	89945	7	35132
37051	3	89947	7	35015
37052	5	89948	4	7764
37053	5	89948	3	7764
37054	5	89949	4	8757
37055	5	89950	4	35022
37056	4	89951	5	14332
37057	4	89952	1	35168
37058	5	89958	7	14783
37059	5	89959	6	23501
37060	5	89960	1	18292
37061	4	89963	5	2780
37062	4	89970	1	30864
37063	3	89971	1	35124
37064	5	89972	7	32012
37065	4	89975	3	17463
37066	5	89976	6	6080
37067	4	89981	7	35073
37068	3	89981	5	35073
37069	5	89983	1	8867
37070	5	89983	5	8867
37071	3	89985	5	9548
37072	5	89990	6	35047
37073	5	89991	1	35099
37074	3	89996	5	23108
37075	3	90001	3	8287
37076	3	90001	4	8287
37077	3	90002	5	34015
37078	4	90004	4	28887
37079	5	90009	1	33057
37080	5	90011	6	29159
37081	4	90016	5	30006
37082	5	90018	2	299
37083	5	90019	2	35205
37084	3	90020	1	24785
37085	4	90022	3	8094
37086	3	90023	6	35191
37087	5	90024	1	7869
37088	5	90025	7	35100
37089	5	90028	4	19600
37090	5	90033	3	35096
37091	5	90036	5	22216
37092	4	90039	5	281
37093	3	90040	2	9051
37094	4	90044	2	10870
37095	4	90046	7	33605
37096	5	90052	3	17713
37097	5	90055	1	3400
37098	4	90062	6	35038
37099	5	90066	5	27282
37100	4	90068	3	22485
37101	3	90069	7	5668
37102	4	90073	2	8244
37103	5	90073	4	8244
37104	3	90077	6	10349
37105	5	90080	4	22407
37106	4	90081	6	31576
37107	4	90082	1	35021
37108	5	90086	4	35017
37109	5	90087	7	35182
37110	4	90092	5	5433
37111	3	90092	3	5433
37112	4	90093	7	35105
37113	5	90094	4	35074
37114	2	90095	1	35026
37115	4	90096	5	2992
37116	3	90097	5	15317
37117	3	90099	2	35196
37118	2	90104	4	19768
37119	5	90106	6	24896
37120	5	90107	3	35071
37121	3	90109	7	6476
37122	5	90109	6	6476
37123	5	90115	6	29667
37124	5	90116	3	23178
37125	4	90117	6	35134
37126	5	90120	4	35161
37127	5	90123	1	1600
37128	3	90124	3	35180
37129	4	90125	7	19161
37130	4	90126	3	6958
37131	3	90128	5	18714
37132	5	90130	7	17569
37133	5	90132	6	19005
37134	5	90136	1	12178
37135	5	90136	6	12178
37136	5	90137	5	35162
37137	5	90140	6	35098
37138	5	90141	2	24284
37139	3	90144	1	2447
37140	3	90145	1	23299
37141	5	90146	4	35129
37142	3	90154	2	8487
37143	5	90157	4	19233
37144	5	90160	1	16549
37145	5	90161	5	27515
37146	5	90162	7	8764
37147	4	90164	3	28344
37148	3	90165	5	35007
37149	3	90168	5	35042
37150	3	90170	5	414
37151	5	90174	6	35023
37152	5	90178	2	35054
37153	3	90179	5	35009
37154	5	90182	5	35121
37155	5	90184	1	2897
37156	3	90184	5	2897
37157	5	90189	3	35145
37158	5	90190	4	32267
37159	5	90193	5	971
37160	4	90193	6	971
37161	3	90196	7	35034
37162	4	90201	6	12760
37163	1	90204	1	12572
37164	4	90208	3	30660
37165	4	90209	7	35150
37166	5	90214	2	28949
37167	4	90216	2	30455
37168	5	90217	1	7444
37169	1	90220	6	35144
37170	5	90222	1	2113
37171	5	90223	1	29490
37172	5	90224	6	30585
37173	4	90224	7	30585
37174	5	90225	6	35109
37175	4	90226	5	35148
37176	5	90227	7	35154
37177	4	90233	4	35031
37178	3	90235	5	35126
37179	5	90235	4	35126
37180	5	90236	1	35178
37181	5	90237	2	24659
37182	4	90239	7	157
37183	4	90243	1	12699
37184	5	90245	2	35029
37185	5	90247	3	15964
37186	3	90248	5	35163
37187	3	90250	1	5582
37188	3	90251	4	13827
37189	5	90254	3	33909
37190	4	90258	7	13042
37191	4	90259	6	35204
37192	2	90262	3	4436
37193	4	90265	7	16770
37194	3	90266	4	34631
37195	5	90268	5	35056
37196	5	90268	4	35056
37197	5	90270	2	7017
37198	5	90271	3	1531
37199	3	90273	5	16255
37200	5	90277	2	28377
37201	5	90279	4	784
37202	3	90280	5	25297
37203	4	90281	2	29917
37204	4	90284	2	5893
37205	5	90286	2	35059
37206	2	90287	6	29896
37207	5	90289	5	26270
37208	5	90290	1	33659
37209	3	90292	7	30313
37210	5	90293	7	22960
37211	5	90294	2	33843
37212	5	90295	6	23798
37213	3	90299	5	4794
37214	4	90301	7	17225
37215	3	90304	5	8506
37216	4	90308	7	30337
37217	5	90309	6	9104
37218	5	90310	1	35081
37219	4	90312	2	35072
37220	5	90314	2	4079
37221	3	90315	7	8032
37222	5	90316	4	11990
37223	4	90318	6	35164
37224	3	90319	7	29706
37225	3	90322	4	33797
37226	5	90323	6	15577
37227	3	90324	6	25856
37228	5	90328	4	15786
37229	4	90330	7	35139
37230	5	90332	4	7384
37231	4	90333	5	35024
37232	5	90336	5	26516
37233	5	90339	6	33523
37234	5	90342	5	31242
37235	3	90346	7	31409
37236	5	90350	2	35117
37237	4	90351	1	9014
37238	5	90353	3	35068
37239	5	90354	2	22952
37240	5	90360	2	4983
37241	5	90361	7	31254
37242	3	90361	2	31254
37243	3	90363	5	35158
37244	5	90366	7	8521
37245	3	90368	6	35090
37246	5	90372	4	8753
37247	1	90373	6	31680
37248	3	90375	3	34161
37249	5	90377	5	23729
37250	5	90379	7	35012
37251	3	90380	5	2951
37252	3	90381	7	11429
37253	5	90382	2	17502
37254	5	90385	7	7835
37255	4	90386	3	22049
37256	3	90386	7	22049
37257	4	90388	2	35155
37258	5	90389	2	35089
37259	5	90391	4	13495
37260	4	90392	3	35197
37261	4	90402	6	35372
37262	3	90403	7	33920
37263	3	90405	7	23105
37264	4	90406	2	14196
37265	3	90409	5	9565
37266	4	90415	6	21617
37267	1	90426	7	34034
37268	5	90427	6	35390
37269	3	90429	1	26735
37270	5	90431	6	35207
37271	3	90432	6	5448
37272	3	90435	4	35329
37273	4	90439	3	21776
37274	4	90440	4	890
37275	4	90440	6	890
37276	4	90441	6	20931
37277	3	90442	3	31429
37278	5	90445	6	11647
37279	4	90446	3	22528
37280	5	90453	4	13531
37281	5	90456	1	21836
37282	5	90459	3	2130
37283	2	90461	3	21233
37284	3	90467	4	35386
37285	5	90469	6	24392
37286	5	90470	2	25295
37287	5	90477	6	3111
37288	3	90481	5	14491
37289	5	90482	6	35327
37290	5	90487	1	4578
37291	3	90488	5	18335
37292	5	90492	4	30839
37293	4	90495	2	11943
37294	4	90499	2	35378
37295	3	90500	7	35336
37296	1	90501	6	11921
37297	5	90504	7	35346
37298	5	90506	2	30700
37299	5	90508	4	31697
37300	4	90510	1	32899
37301	5	90513	1	21028
37302	4	90519	6	26420
37303	5	90520	5	22482
37304	5	90524	2	35229
37305	2	90527	3	17790
37306	5	90530	6	35332
37307	5	90531	5	28605
37308	5	90532	2	8123
37309	3	90539	1	9716
37310	4	90540	1	10598
37311	4	90541	3	14427
37312	4	90543	6	23879
37313	5	90544	2	543
37314	5	90545	7	35268
37315	4	90548	2	11754
37316	5	90549	2	10379
37317	4	90556	2	35361
37318	5	90556	7	35361
37319	3	90557	2	35206
37320	5	90558	6	17691
37321	5	90559	6	1107
37322	5	90559	3	1107
37323	5	90561	6	19102
37324	5	90562	6	20196
37325	5	90563	6	12303
37326	4	90565	5	35319
37327	3	90568	6	6670
37328	4	90569	7	22160
37329	3	90573	7	2332
37330	5	90575	7	35355
37331	5	90580	3	7424
37332	5	90581	5	1167
37333	5	90584	1	35208
37334	5	90586	5	35359
37335	4	90588	3	25761
37336	5	90592	1	18332
37337	4	90594	2	35302
37338	2	90595	4	19845
37339	4	90600	5	18365
37340	4	90601	5	4720
37341	3	90603	1	35217
37342	5	90607	4	35393
37343	5	90608	6	35248
37344	5	90610	4	34930
37345	5	90612	6	26408
37346	4	90613	5	31869
37347	5	90614	1	4393
37348	4	90615	7	19681
37349	5	90615	4	19681
37350	5	90620	4	28268
37351	5	90621	2	4090
37352	4	90623	5	35276
37353	4	90624	3	34551
37354	5	90627	1	34788
37355	5	90629	6	30099
37356	3	90637	1	8866
37357	4	90638	3	17922
37358	3	90640	7	12546
37359	3	90641	4	31881
37360	4	90645	7	1780
37361	5	90647	7	34091
37362	5	90652	5	4116
37363	5	90654	7	18309
37364	4	90655	7	23665
37365	5	90658	6	20140
37366	4	90659	2	7002
37367	5	90662	1	13157
37368	5	90665	5	21102
37369	3	90667	3	14668
37370	5	90671	2	26240
37371	3	90675	2	19563
37372	5	90678	6	32085
37373	5	90679	2	16239
37374	4	90680	5	35246
37375	2	90685	6	12185
37376	4	90686	5	14638
37377	5	90688	2	22537
37378	4	90693	1	35279
37379	4	90694	7	22759
37380	4	90695	4	29796
37381	5	90696	2	477
37382	5	90697	7	35220
37383	3	90700	4	10703
37384	5	90701	4	23464
37385	4	90704	6	15627
37386	3	90705	5	34794
37387	5	90706	6	35340
37388	4	90707	5	35321
37389	5	90709	6	13435
37390	3	90711	6	18752
37391	5	90714	2	35288
37392	4	90718	6	35349
37393	5	90720	6	22361
37394	5	90725	2	31496
37395	5	90726	1	28174
37396	5	90730	6	3335
37397	4	90733	2	8007
37398	3	90734	2	19854
37399	3	90735	5	30629
37400	5	90737	7	25020
37401	3	90742	4	35387
37402	1	90744	6	6098
37403	4	90744	7	6098
37404	5	90745	1	3645
37405	5	90751	2	22062
37406	5	90751	3	22062
37407	3	90754	5	35218
37408	4	90762	3	2646
37409	5	90763	5	20700
37410	5	90764	1	7072
37411	5	90768	6	22973
37412	5	90769	7	22243
37413	5	90771	5	29346
37414	5	90772	1	4020
37415	5	90773	1	2641
37416	5	90775	6	29024
37417	5	90778	6	35371
37418	4	90779	1	26445
37419	4	90785	5	14759
37420	5	90786	6	12169
37421	3	90787	6	9708
37422	1	90794	7	35277
37423	5	90795	2	486
37424	5	90797	6	10886
37425	5	90798	4	35254
37426	5	90799	7	20865
37427	5	90807	1	35257
37428	3	90808	4	25171
37429	5	90809	6	32379
37430	3	90810	2	4987
37431	5	90814	6	8467
37432	4	90816	3	35369
37433	5	90817	4	26232
37434	5	90818	7	23539
37435	4	90821	5	34153
37436	3	90822	5	2311
37437	1	90824	6	26526
37438	5	90825	3	7741
37439	5	90826	3	6413
37440	5	90831	7	20169
37441	4	90831	3	20169
37442	5	90832	6	35358
37443	5	90834	6	31840
37444	5	90835	7	35401
37445	5	90838	6	22706
37446	5	90842	3	30955
37447	5	90847	5	17726
37448	3	90851	6	33077
37449	2	90853	6	13272
37450	5	90854	4	35398
37451	4	90859	7	29682
37452	5	90864	6	11144
37453	5	90864	2	11144
37454	4	90867	4	35304
37455	5	90869	3	18102
37456	5	90869	5	18102
37457	5	90870	2	17126
37458	5	90872	2	34651
37459	5	90873	4	9727
37460	5	90876	4	16858
37461	3	90878	3	16069
37462	5	90879	4	286
37463	4	90879	7	286
37464	4	90881	5	35360
37465	5	90883	6	7451
37466	4	90884	1	35259
37467	3	90886	1	31467
37468	5	90889	4	4834
37469	3	90890	7	33570
37470	5	90891	3	14812
37471	4	90892	7	23424
37472	5	90892	1	23424
37473	5	90893	5	35247
37474	3	90894	3	16719
37475	5	90894	7	16719
37476	5	90896	2	3364
37477	3	90897	7	35272
37478	3	90901	7	31716
37479	5	90903	6	34388
37480	4	90904	7	10628
37481	5	90905	4	35239
37482	5	90908	4	29042
37483	5	90914	1	21665
37484	5	90916	6	15574
37485	3	90917	4	27106
37486	5	90919	6	35376
37487	1	90921	4	28933
37488	4	90927	4	35345
37489	5	90928	1	5917
37490	5	90935	6	18924
37491	5	90937	7	35356
37492	4	90938	7	7301
37493	5	90940	2	31966
37494	4	90947	6	33484
37495	3	90948	7	385
37496	5	90951	6	28515
37497	4	90952	2	24767
37498	5	90956	5	7825
37499	5	90957	6	9977
37500	5	90961	6	35373
37501	2	90965	1	17268
37502	4	90968	3	17270
37503	4	90969	3	35317
37504	3	90970	7	35289
37505	3	90970	2	35289
37506	4	90971	7	31953
37507	5	90972	3	35324
37508	3	90973	4	35354
37509	3	90975	7	1245
37510	5	90976	4	1030
37511	5	90978	5	14859
37512	4	90979	2	35381
37513	5	90983	6	143
37514	5	90985	6	13425
37515	5	90987	4	27078
37516	5	90988	3	23036
37517	5	90990	2	14473
37518	5	90992	7	35377
37519	5	90998	7	29247
37520	5	90999	2	22900
37521	5	91008	3	35236
37522	3	91012	1	35283
37523	5	91018	6	26656
37524	3	91021	3	408
37525	5	91022	6	4988
37526	4	91024	7	2134
37527	4	91025	1	28712
37528	5	91026	2	14037
37529	5	91027	5	16729
37530	4	91028	3	16679
37531	4	91030	2	35388
37532	5	91032	1	28734
37533	4	91033	5	14249
37534	3	91033	1	14249
37535	4	91036	1	31893
37536	5	91038	6	31736
37537	5	91041	1	23758
37538	5	91043	1	7278
37539	5	91044	4	9378
37540	5	91048	2	1075
37541	5	91051	4	18793
37542	5	91053	4	18263
37543	5	91054	6	5101
37544	5	91057	2	26292
37545	5	91058	2	14010
37546	5	91060	3	14947
37547	5	91067	5	8828
37548	5	91068	4	3069
37549	5	91071	5	5678
37550	4	91072	7	1929
37551	3	91074	7	28208
37552	5	91076	5	34121
37553	5	91078	4	19488
37554	5	91081	6	29139
37555	4	91085	7	35292
37556	5	91086	7	33022
37557	4	91088	1	21092
37558	4	91092	5	35241
37559	3	91093	7	32870
37560	5	91096	7	18567
37561	5	91098	5	35365
37562	5	91103	6	27660
37563	5	91103	4	27660
37564	3	91106	5	35261
37565	5	91107	6	11802
37566	4	91108	1	28987
37567	3	91109	7	1922
37568	2	91111	6	9731
37569	3	91112	5	932
37570	5	91115	6	26721
37571	4	91117	3	35357
37572	3	91119	5	8700
37573	4	91121	2	32158
37574	5	91122	6	35222
37575	5	91123	6	2187
37576	3	91124	7	35264
37577	4	91126	6	8100
37578	3	91128	5	35258
37579	3	91130	7	5903
37580	5	91131	6	35382
37581	4	91132	5	35238
37582	5	91135	4	5099
37583	5	91138	1	31444
37584	5	91139	3	35315
37585	5	91141	1	1838
37586	4	91144	7	27511
37587	5	91146	6	19059
37588	5	91148	5	14083
37589	3	91152	7	12778
37590	5	91153	5	35374
37591	5	91155	7	30
37592	5	91156	2	2082
37593	5	91157	5	35347
37594	5	91160	3	17606
37595	5	91162	3	13416
37596	5	91163	6	35400
37597	5	91166	5	8276
37598	3	91170	4	35370
37599	4	91171	7	25789
37600	4	91174	7	5280
37601	3	91175	5	35318
37602	5	91176	6	12075
37603	4	91178	2	16359
37604	4	91180	6	17650
37605	4	91182	3	6815
37606	5	91187	6	20432
37607	4	91191	7	33243
37608	5	91193	2	35348
37609	4	91194	4	10740
37610	5	91197	1	34627
37611	5	91201	2	9140
37612	3	91202	6	13414
37613	5	91204	4	8806
37614	5	91206	5	26840
37615	1	91210	6	35510
37616	3	91211	1	35475
37617	5	91212	7	34261
37618	3	91217	7	35461
37619	5	91218	4	33019
37620	5	91231	6	23287
37621	5	91232	7	31280
37622	5	91233	1	12805
37623	5	91233	2	12805
37624	4	91234	4	12882
37625	3	91236	5	18539
37626	5	91238	5	26708
37627	3	91239	7	35489
37628	4	91240	5	20447
37629	3	91246	5	6228
37630	5	91248	4	35556
37631	5	91252	1	3052
37632	4	91259	2	35502
37633	5	91264	1	35544
37634	5	91266	2	15433
37635	5	91267	5	17564
37636	4	91270	6	21153
37637	3	91272	7	22064
37638	4	91274	7	10190
37639	4	91276	5	35571
37640	4	91277	3	35419
37641	5	91279	2	24883
37642	4	91281	7	35549
37643	5	91284	3	1645
37644	3	91285	5	35446
37645	5	91286	1	16409
37646	5	91288	6	10432
37647	3	91289	2	26015
37648	4	91291	6	6455
37649	5	91292	5	23298
37650	4	91293	1	35463
37651	3	91294	5	17941
37652	5	91297	2	25080
37653	4	91299	3	23405
37654	4	91302	7	34918
37655	5	91303	4	33520
37656	5	91304	6	35468
37657	4	91306	3	13707
37658	3	91307	1	35560
37659	3	91308	5	34565
37660	5	91310	6	35404
37661	5	91312	4	15976
37662	5	91313	6	1308
37663	4	91315	5	18810
37664	5	91320	5	18634
37665	5	91321	2	18398
37666	5	91322	2	35427
37667	5	91323	6	10009
37668	3	91324	3	6859
37669	2	91325	4	22822
37670	5	91326	5	10724
37671	5	91327	4	16000
37672	5	91331	5	2560
37673	3	91332	4	22062
37674	5	91333	4	24117
37675	4	91339	1	11988
37676	5	91343	6	735
37677	5	91344	6	13434
37678	3	91348	1	13068
37679	4	91356	5	2630
37680	5	91357	4	17527
37681	5	91361	4	13835
37682	5	91370	2	24926
37683	3	91371	1	35540
37684	4	91375	6	35407
37685	4	91375	1	35407
37686	4	91381	6	35491
37687	5	91382	5	25151
37688	4	91388	4	35522
37689	5	91389	6	20819
37690	5	91390	5	35553
37691	5	91392	5	35425
37692	3	91394	1	18283
37693	5	91398	4	31857
37694	5	91400	1	34208
37695	3	91401	7	20494
37696	4	91402	7	35474
37697	4	91403	1	31763
37698	5	91404	5	15159
37699	1	91404	6	15159
37700	5	91407	6	14016
37701	3	91408	4	12240
37702	4	91409	7	35543
37703	5	91410	1	35555
37704	5	91412	7	17579
37705	5	91413	5	19971
37706	5	91416	2	3148
37707	4	91417	5	22973
37708	4	91420	1	7770
37709	4	91421	5	8914
37710	5	91422	5	23665
37711	4	91423	5	13185
37712	5	91424	6	528
37713	3	91426	3	35497
37714	5	91428	1	17545
37715	5	91431	7	7125
37716	5	91432	5	16322
37717	5	91433	2	20521
37718	5	91434	6	13656
37719	4	91436	7	35499
37720	5	91440	3	35410
37721	1	91443	6	1062
37722	5	91444	4	35554
37723	5	91445	2	35533
37724	4	91446	7	34425
37725	5	91452	1	35521
37726	3	91454	4	8054
37727	4	91455	3	15866
37728	5	91458	1	3446
37729	5	91459	2	35464
37730	4	91460	5	20000
37731	5	91462	5	7444
37732	5	91465	7	33789
37733	5	91468	4	6807
37734	4	91473	1	35406
37735	5	91476	2	3147
37736	5	91477	1	7096
37737	5	91478	7	35456
37738	4	91479	6	14585
37739	5	91480	7	4015
37740	5	91485	2	31614
37741	3	91488	4	28023
37742	4	91491	6	35359
37743	3	91494	4	14155
37744	5	91495	6	6619
37745	3	91497	6	12298
37746	3	91498	5	15199
37747	1	91505	6	1282
37748	5	91507	5	22917
37749	4	91508	7	12302
37750	5	91508	2	12302
37751	5	91509	1	35444
37752	4	91510	4	35569
37753	5	91511	6	30877
37754	4	91512	2	14862
37755	5	91515	7	2071
37756	4	91516	5	15336
37757	5	91517	4	4635
37758	3	91522	7	22443
37759	5	91524	6	16552
37760	5	91527	6	35563
37761	3	91532	2	5743
37762	5	91533	6	35523
37763	5	91536	2	7181
37764	5	91539	7	35424
37765	5	91543	1	34270
37766	4	91544	6	7291
37767	5	91545	6	27306
37768	4	91546	4	34002
37769	5	91547	7	13968
37770	3	91548	1	1316
37771	5	91549	3	1227
37772	5	91550	7	35460
37773	5	91551	2	17413
37774	5	91552	5	35520
37775	5	91552	1	35520
37776	5	91554	2	35526
37777	5	91556	2	7451
37778	3	91557	3	3175
37779	4	91558	3	4653
37780	4	91559	6	26874
37781	4	91560	7	11163
37782	3	91561	5	35132
37783	4	91562	2	35422
37784	5	91563	6	29742
37785	3	91564	5	35546
37786	5	91565	2	19537
37787	5	91566	2	17359
37788	4	91567	7	35488
37789	4	91568	5	12524
37790	5	91572	3	996
37791	5	91576	3	25475
37792	5	91578	4	21386
37793	5	91580	2	980
37794	5	91581	5	2812
37795	3	91582	1	10787
37796	3	91584	6	35440
37797	5	91585	1	35426
37798	5	91587	1	11225
37799	4	91592	4	33625
37800	4	91593	7	5144
37801	3	91593	2	5144
37802	4	91595	7	9754
37803	4	91598	2	35445
37804	5	91603	7	35618
37805	3	91604	6	15054
37806	3	91607	5	6470
37807	3	91615	5	1183
37808	3	91616	5	10810
37809	5	91622	1	2217
37810	5	91623	2	18360
37811	1	91629	6	7066
37812	5	91632	2	17041
37813	5	91634	4	16571
37814	4	91635	5	32620
37815	5	91636	1	13799
37816	5	91638	2	11624
37817	4	91638	4	11624
37818	2	91640	6	30872
37819	5	91643	7	35673
37820	5	91645	2	35763
37821	5	91646	6	22168
37822	4	91649	7	35796
37823	3	91655	6	35578
37824	4	91657	6	26923
37825	5	91659	2	35701
37826	5	91662	6	33473
37827	3	91664	7	35597
37828	4	91664	3	35597
37829	4	91667	5	11979
37830	5	91668	4	7796
37831	1	91675	4	21757
37832	5	91676	7	22320
37833	5	91677	5	35609
37834	5	91683	2	1393
37835	4	91684	2	35716
37836	5	91687	6	28288
37837	5	91688	5	26456
37838	3	91694	1	16264
37839	5	91698	6	35726
37840	5	91698	1	35726
37841	5	91701	4	35662
37842	2	91702	5	34491
37843	4	91703	6	35774
37844	3	91704	7	33585
37845	5	91705	5	25386
37846	4	91709	7	20379
37847	5	91710	2	28030
37848	4	91714	4	12942
37849	5	91715	7	5963
37850	4	91718	3	35595
37851	5	91719	3	18900
37852	5	91720	7	23422
37853	1	91722	7	27813
37854	3	91723	5	6748
37855	3	91724	4	7731
37856	4	91727	3	35680
37857	3	91729	5	22032
37858	5	91734	4	35585
37859	3	91734	1	35585
37860	3	91735	4	28151
37861	5	91738	4	35436
37862	5	91740	7	18222
37863	5	91741	7	19166
37864	5	91745	3	3010
37865	4	91748	5	3568
37866	5	91748	6	3568
37867	5	91752	6	35785
37868	5	91753	6	35654
37869	4	91754	4	12236
37870	3	91761	1	35711
37871	5	91762	5	7623
37872	4	91763	7	35612
37873	5	91764	2	31904
37874	4	91766	1	35663
37875	3	91770	5	24616
37876	5	91771	7	35650
37877	5	91776	7	35791
37878	4	91779	6	35593
37879	4	91781	6	35630
37880	5	91782	6	35697
37881	4	91783	6	3054
37882	2	91789	4	281
37883	5	91792	5	33693
37884	5	91793	6	30417
37885	2	91794	4	5358
37886	5	91796	4	35645
37887	3	91798	5	35603
37888	5	91800	4	17471
37889	5	91802	6	32323
37890	4	91803	4	18745
37891	4	91805	7	9700
37892	2	91806	6	29345
37893	5	91808	7	3771
37894	4	91811	6	24442
37895	5	91812	6	15216
37896	5	91820	2	2651
37897	3	91824	1	21272
37898	5	91827	7	35636
37899	5	91832	7	35730
37900	5	91836	7	35707
37901	3	91837	1	11227
37902	5	91838	6	11237
37903	5	91839	1	24005
37904	5	91845	6	24918
37905	5	91846	2	35427
37906	3	91847	3	35783
37907	4	91848	2	35644
37908	1	91848	6	35644
37909	4	91849	5	19473
37910	5	91856	4	35596
37911	4	91858	2	25149
37912	5	91860	2	10616
37913	4	91861	3	35769
37914	4	91862	7	35706
37915	5	91867	4	33462
37916	4	91868	7	35749
37917	4	91874	5	28213
37918	4	91875	3	16143
37919	5	91876	4	27726
37920	4	91877	4	35784
37921	4	91878	6	16548
37922	5	91879	4	35610
37923	5	91880	3	35750
37924	5	91881	6	519
37925	3	91883	7	19050
37926	5	91884	4	1677
37927	5	91885	4	8474
37928	3	91889	4	21671
37929	5	91891	6	35727
37930	5	91894	7	27777
37931	5	91900	6	3855
37932	5	91900	4	3855
37933	4	91906	3	35731
37934	5	91909	1	35622
37935	5	91909	3	35622
37936	2	91916	6	3989
37937	5	91917	6	35786
37938	5	91920	2	21076
37939	3	91923	3	35788
37940	5	91925	4	33471
37941	5	91927	2	15028
37942	5	91928	2	8353
37943	2	91930	4	4841
37944	3	91932	7	1376
37945	3	91934	7	20772
37946	4	91940	7	35776
37947	5	91941	7	24394
37948	4	91943	2	6060
37949	5	91946	5	35767
37950	4	91948	1	15777
37951	3	91950	4	35754
37952	5	91956	1	15110
37953	5	91957	7	2339
37954	5	91959	6	30394
37955	5	91960	4	27257
37956	4	91961	2	4732
37957	5	91965	2	5183
37958	4	91966	3	5668
37959	4	91970	5	30022
37960	5	91972	6	31571
37961	3	91974	3	630
37962	4	91975	7	35605
37963	5	91976	2	18320
37964	5	91977	6	17056
37965	4	91978	4	35079
37966	5	91979	7	35799
37967	5	91985	4	20876
37968	5	91988	7	1066
37969	4	91989	5	35685
37970	5	91991	2	35737
37971	4	91991	5	35737
37972	4	91992	6	13254
37973	3	91995	1	35758
37974	5	91998	7	9445
37975	5	91999	5	14128
37976	5	92001	2	14301
37977	3	92002	6	35713
37978	5	92003	6	11348
37979	5	92004	7	35779
37980	5	92005	6	31700
37981	3	92006	2	35620
37982	4	92009	2	467
37983	5	92011	2	12808
37984	5	92012	1	12291
37985	2	92013	7	10576
37986	5	92016	4	28647
37987	1	92017	6	32025
37988	4	92018	5	32596
37989	5	92019	3	34037
37990	3	92022	5	5076
37991	4	92024	7	35591
37992	3	92025	1	8394
37993	5	92026	5	23928
37994	3	92026	4	23928
37995	1	92028	6	34125
37996	5	92029	7	20478
37997	5	92030	5	28174
37998	5	92031	4	4385
37999	2	92032	6	5437
38000	4	92033	7	35717
38001	5	92037	4	35619
38002	4	92042	3	29851
38003	1	92044	6	14968
38004	5	92045	4	28413
38005	2	92047	3	35659
38006	5	92058	5	35666
38007	5	92059	3	6187
38008	5	92060	6	35653
38009	3	92061	7	30826
38010	5	92063	6	21213
38011	3	92069	5	35919
38012	5	92072	5	21426
38013	4	92073	1	9533
38014	5	92075	3	35819
38015	4	92076	5	15151
38016	3	92079	6	35896
38017	5	92080	1	35918
38018	3	92081	1	35905
38019	5	92082	4	31266
38020	5	92084	2	22450
38021	3	92086	1	35898
38022	5	92087	4	35870
38023	4	92088	1	22865
38024	5	92089	4	23614
38025	5	92091	2	35814
38026	5	92093	1	4320
38027	3	92094	5	21649
38028	5	92095	4	35944
38029	4	92097	2	16334
38030	4	92098	5	35818
38031	5	92102	6	36010
38032	4	92109	1	34147
38033	3	92110	1	35883
38034	4	92111	6	35960
38035	5	92113	7	35813
38036	5	92114	2	18603
38037	5	92115	4	6988
38038	5	92122	2	35836
38039	1	92122	6	35836
38040	5	92124	4	35991
38041	4	92125	7	35997
38042	5	92126	2	35887
38043	4	92127	4	8397
38044	5	92129	7	2568
38045	4	92130	6	30601
38046	5	92137	4	13951
38047	5	92138	6	35809
38048	5	92139	6	3881
38049	3	92140	5	2857
38050	5	92141	5	2153
38051	4	92144	2	970
38052	1	92146	6	27556
38053	4	92147	7	25793
38054	4	92151	2	35893
38055	3	92152	4	18098
38056	3	92153	2	17951
38057	5	92154	6	20356
38058	5	92154	4	20356
38059	4	92155	5	35947
38060	4	92156	1	35914
38061	5	92156	6	35914
38062	4	92157	7	35928
38063	3	92158	1	16365
38064	4	92164	5	15945
38065	5	92167	7	11448
38066	4	92168	2	24630
38067	4	92172	5	2498
38068	5	92174	3	25781
38069	5	92175	6	34392
38070	3	92178	5	35364
38071	4	92180	7	35940
38072	5	92184	6	11214
38073	1	92192	1	19434
38074	5	92193	6	13570
38075	4	92198	7	15575
38076	5	92200	5	11829
38077	4	92200	1	11829
38078	4	92202	7	32999
38079	2	92204	1	32899
38080	5	92207	2	7204
38081	4	92211	5	35834
38082	5	92213	7	26366
38083	4	92215	2	19270
38084	3	92216	3	21261
38085	5	92217	2	24538
38086	4	92218	5	35855
38087	1	92221	6	35953
38088	4	92224	3	4255
38089	5	92226	7	15605
38090	4	92230	6	29688
38091	3	92231	5	27893
38092	3	92233	3	6104
38093	3	92234	7	35998
38094	5	92236	6	20494
38095	5	92240	2	11244
38096	3	92242	5	31939
38097	5	92243	3	24367
38098	3	92244	7	2452
38099	4	92249	4	4872
38100	5	92251	7	14831
38101	5	92253	6	11570
38102	4	92256	4	35811
38103	3	92257	5	29031
38104	4	92261	1	2799
38105	5	92262	6	1317
38106	2	92265	3	1308
38107	5	92270	6	35974
38108	3	92271	6	35907
38109	5	92272	5	4654
38110	4	92273	2	33530
38111	5	92275	4	35831
38112	5	92278	7	23200
38113	5	92281	2	35849
38114	5	92282	2	36011
38115	4	92288	5	25075
38116	5	92290	3	12460
38117	3	92293	3	29145
38118	5	92294	2	3823
38119	4	92298	5	35825
38120	5	92300	4	35992
38121	4	92302	5	13158
38122	5	92304	7	35934
38123	5	92306	6	26739
38124	3	92314	7	35833
38125	3	92315	2	33015
38126	5	92322	4	7971
38127	3	92325	6	32649
38128	5	92328	2	30704
38129	3	92329	2	35982
38130	5	92331	3	21562
38131	3	92333	2	12367
38132	3	92334	7	30045
38133	4	92335	2	35858
38134	5	92337	6	35990
38135	5	92338	7	34877
38136	5	92341	7	35879
38137	4	92342	3	35971
38138	5	92348	1	11078
38139	4	92350	7	35866
38140	4	92357	2	23433
38141	5	92362	4	35498
38142	5	92363	6	35930
38143	5	92364	1	6578
38144	3	92365	4	3934
38145	4	92369	2	24284
38146	5	92370	7	35939
38147	5	92371	6	26821
38148	3	92372	5	12482
38149	3	92375	7	35925
38150	5	92376	5	6729
38151	4	92380	2	10513
38152	4	92381	3	7220
38153	1	92385	6	18567
38154	2	92386	6	18740
38155	5	92389	2	1498
38156	5	92392	2	11423
38157	5	92393	1	7422
38158	5	92394	5	2277
38159	4	92395	4	20853
38160	4	92395	5	20853
38161	3	92399	6	35842
38162	3	92400	7	35884
38163	2	92401	3	14635
38164	3	92402	5	22705
38165	4	92404	7	22403
38166	5	92405	3	35967
38167	4	92406	3	35844
38168	4	92407	5	26797
38169	3	92407	7	26797
38170	4	92413	2	26239
38171	5	92415	1	32425
38172	5	92419	7	4343
38173	1	92420	6	6894
38174	5	92422	1	35803
38175	5	92425	4	12959
38176	4	92428	3	25738
38177	5	92430	6	34561
38178	5	92432	3	35828
38179	5	92435	4	24154
38180	5	92438	4	11868
38181	4	92439	7	21431
38182	3	92440	7	30247
38183	4	92443	5	26431
38184	5	92443	1	26431
38185	5	92444	7	35826
38186	5	92445	4	7019
38187	5	92447	1	35943
38188	5	92447	6	35943
38189	1	92448	6	6373
38190	4	92449	4	35959
38191	5	92449	2	35959
38192	3	92450	5	24246
38193	3	92456	6	20749
38194	5	92456	4	20749
38195	5	92457	6	28116
38196	5	92458	2	35817
38197	5	92459	2	1174
38198	3	92462	2	30627
38199	5	92462	5	30627
38200	5	92463	1	27973
38201	5	92464	4	35926
38202	5	92468	6	25420
38203	4	92473	3	35840
38204	5	92474	2	35980
38205	3	92477	6	23268
38206	3	92484	6	31447
38207	5	92485	2	35891
38208	4	92489	5	35983
38209	5	92490	2	35932
38210	3	92490	7	35932
38211	5	92491	4	35956
38212	5	92493	3	35882
38213	5	92494	2	28112
38214	5	92504	7	25299
38215	3	92505	3	32101
38216	3	92506	1	31379
38217	3	92509	5	24411
38218	5	92510	4	851
38219	5	92511	6	35850
38220	5	92512	4	22283
38221	5	92515	5	2519
38222	5	92518	1	486
38223	3	92519	1	28196
38224	4	92520	7	35857
38225	3	92521	3	15907
38226	4	92521	7	15907
38227	3	92523	5	31811
38228	5	92526	1	35986
38229	5	92529	3	22643
38230	4	92538	1	19221
38231	5	92538	6	19221
38232	3	92539	2	35970
38233	3	92542	5	35867
38234	5	92543	3	7202
38235	5	92543	4	7202
38236	5	92547	2	1394
38237	4	92550	7	26031
38238	5	92551	6	28041
38239	1	92552	6	7300
38240	4	92555	1	35906
38241	5	92557	1	25346
38242	4	92560	5	15829
38243	5	92561	6	35880
38244	1	92562	3	9429
38245	5	92565	1	25552
38246	2	92567	2	2244
38247	5	92567	1	2244
38248	4	92568	7	30408
38249	5	92570	2	35875
38250	5	92571	5	15350
38251	5	92572	3	35977
38252	2	92574	3	30878
38253	5	92576	7	19432
38254	3	92577	1	10106
38255	5	92579	7	35984
38256	3	92580	1	31647
38257	5	92581	4	28880
38258	5	92582	1	6787
38259	5	92583	3	1263
38260	5	92585	7	7279
38261	5	92587	2	26788
38262	5	92588	3	35845
38263	4	92589	2	2965
38264	5	92592	5	2891
38265	1	92593	6	35916
38266	5	92595	6	35897
38267	4	92597	7	7114
38268	5	92598	6	35946
38269	4	92599	1	35335
38270	3	92602	7	14406
38271	4	92603	6	8916
38272	5	92607	4	35872
38273	5	92611	2	13699
38274	2	92612	7	19602
38275	3	92613	3	23373
38276	5	92616	2	33846
38277	4	92619	7	19649
38278	4	92621	5	35902
38279	3	92624	7	7899
38280	4	92625	3	35890
38281	5	92626	7	16753
38282	5	92628	2	26359
38283	3	92633	1	27870
38284	3	92636	7	377
38285	4	92637	3	30931
38286	2	92639	7	4902
38287	5	92644	6	35924
38288	4	92646	5	5129
38289	3	92647	5	1154
38290	4	92649	2	9658
38291	3	92652	7	12809
38292	3	92653	5	35936
38293	5	92657	5	34888
38294	5	92660	1	35677
38295	3	92661	5	3612
38296	3	92663	2	31470
38297	5	92665	7	24329
38298	5	92666	3	12564
38299	4	92668	1	13185
38300	5	92670	6	9582
38301	5	92672	1	381
38302	5	92676	5	36081
38303	5	92677	3	16426
38304	3	92678	5	19556
38305	5	92679	7	28056
38306	5	92681	3	36141
38307	5	92683	7	32133
38308	5	92684	7	36216
38309	5	92686	5	35302
38310	5	92689	1	8050
38311	5	92694	3	22228
38312	5	92696	4	8785
38313	4	92697	4	24449
38314	5	92698	3	36136
38315	5	92699	6	7046
38316	5	92700	6	36117
38317	4	92701	6	13681
38318	4	92703	1	36049
38319	5	92705	2	36041
38320	5	92707	2	6901
38321	4	92708	7	22042
38322	4	92710	3	4760
38323	4	92713	1	14545
38324	2	92717	3	23688
38325	4	92729	5	36227
38326	3	92731	5	36225
38327	5	92731	6	36225
38328	4	92733	7	8669
38329	5	92735	6	36240
38330	4	92739	3	3946
38331	1	92740	6	30620
38332	3	92740	7	30620
38333	3	92741	7	28211
38334	4	92751	5	8756
38335	3	92755	5	1494
38336	5	92756	3	10349
38337	5	92756	6	10349
38338	4	92759	4	28961
38339	4	92763	4	26427
38340	4	92763	7	26427
38341	4	92767	7	29394
38342	5	92769	7	6046
38343	4	92770	5	36125
38344	5	92771	7	21173
38345	5	92775	6	34796
38346	5	92776	4	16320
38347	4	92778	2	36114
38348	5	92781	7	19445
38349	2	92784	4	20579
38350	5	92787	2	36237
38351	4	92788	5	9273
38352	5	92789	4	2783
38353	5	92792	1	25259
38354	5	92792	2	25259
38355	5	92794	2	36075
38356	5	92796	2	36132
38357	4	92798	5	36191
38358	5	92804	6	7527
38359	5	92805	4	36045
38360	4	92809	5	36032
38361	5	92811	4	36089
38362	5	92813	4	5310
38363	3	92815	4	23665
38364	4	92818	6	36196
38365	5	92821	2	5648
38366	3	92823	7	30409
38367	3	92826	5	36138
38368	5	92829	5	16914
38369	3	92830	4	32044
38370	2	92832	6	30921
38371	5	92834	2	23870
38372	4	92838	4	24171
38373	4	92838	1	24171
38374	5	92842	1	36028
38375	5	92843	2	36145
38376	5	92844	2	35691
38377	1	92847	7	23982
38378	4	92848	7	23494
38379	3	92849	3	24889
38380	5	92852	2	17154
38381	5	92855	2	30156
38382	3	92855	5	30156
38383	5	92858	1	8521
38384	5	92859	3	32344
38385	5	92860	7	2608
38386	5	92861	6	36069
38387	4	92862	7	13615
38388	2	92864	6	14781
38389	4	92868	7	9384
38390	4	92869	6	36074
38391	3	92870	1	22983
38392	1	92873	6	11225
38393	5	92875	7	26304
38394	5	92878	2	1301
38395	5	92879	5	36048
38396	2	92880	6	6426
38397	5	92883	6	36218
38398	3	92887	3	36156
38399	5	92892	7	36197
38400	5	92892	6	36197
38401	5	92893	6	24126
38402	3	92894	7	15148
38403	5	92898	1	19628
38404	5	92899	3	34812
38405	5	92901	4	36061
38406	5	92903	7	36044
38407	5	92903	2	36044
38408	5	92904	2	5506
38409	5	92907	7	36169
38410	1	92910	6	36029
38411	3	92911	5	32872
38412	5	92914	6	9915
38413	5	92916	6	15636
38414	5	92918	2	34606
38415	5	92919	7	20261
38416	4	92920	2	36143
38417	3	92924	5	36171
38418	3	92925	3	24666
38419	3	92926	5	36078
38420	4	92927	7	33844
38421	5	92928	1	36019
38422	3	92932	7	29374
38423	4	92934	2	36042
38424	3	92935	7	36082
38425	5	92937	4	26235
38426	5	92941	7	25386
38427	3	92942	7	17227
38428	5	92949	6	22272
38429	4	92950	4	14775
38430	5	92951	2	36181
38431	4	92952	1	19663
38432	5	92953	2	1386
38433	4	92954	7	3767
38434	5	92955	1	36234
38435	5	92959	7	15855
38436	5	92960	4	27538
38437	4	92962	3	12089
38438	4	92964	7	26018
38439	4	92966	6	10121
38440	4	92967	7	17555
38441	5	92968	2	7530
38442	5	92973	1	36173
38443	5	92974	6	36144
38444	5	92978	2	35980
38445	5	92979	4	13767
38446	4	92981	6	36086
38447	4	92985	7	36046
38448	3	92987	4	12686
38449	2	92989	6	22540
38450	3	92992	5	5329
38451	5	92997	4	36110
38452	1	92999	6	28779
38453	4	93000	7	17278
38454	5	93002	4	36068
38455	4	93003	1	36202
38456	5	93005	7	5527
38457	4	93011	6	26596
38458	5	93016	4	36091
38459	5	93017	4	36036
38460	5	93018	6	36123
38461	5	93019	1	36221
38462	4	93019	5	36221
38463	5	93020	6	21915
38464	5	93022	4	17654
38465	3	93023	3	23432
38466	5	93025	1	23718
38467	5	93027	6	19187
38468	4	93028	6	23900
38469	5	93029	4	36233
38470	1	93030	6	36105
38471	4	93037	7	36109
38472	5	93038	4	1168
38473	5	93040	4	4282
38474	5	93042	2	36219
38475	5	93043	1	36134
38476	4	93044	7	2616
38477	4	93045	6	15690
38478	5	93048	3	10746
38479	3	93050	2	16091
38480	3	93052	1	4209
38481	3	93052	4	4209
38482	4	93054	7	36209
38483	5	93054	1	36209
38484	5	93057	1	35993
38485	5	93062	2	15656
38486	4	93064	6	36057
38487	5	93065	2	4234
38488	3	93067	4	36152
38489	4	93068	3	2173
38490	4	93071	6	36180
38491	5	93072	5	28602
38492	3	93073	3	2153
38493	4	93076	3	2081
38494	4	93078	7	25597
38495	5	93081	2	36030
38496	4	93082	5	28247
38497	5	93083	6	32298
38498	4	93091	4	145
38499	5	93092	4	21287
38500	3	93095	5	36017
38501	5	93096	2	36179
38502	1	93097	5	7051
38503	5	93098	5	21629
38504	5	93102	1	36211
38505	4	93104	6	23559
38506	5	93113	4	6437
38507	2	93114	5	1380
38508	5	93116	5	36176
38509	5	93117	4	12355
38510	5	93117	6	12355
38511	5	93118	3	16765
38512	5	93119	3	15013
38513	5	93121	7	36084
38514	3	93123	2	12918
38515	4	93126	7	4578
38516	3	93129	5	14868
38517	4	93131	6	36107
38518	3	93132	3	36016
38519	5	93133	2	36092
38520	5	93138	6	33321
38521	5	93142	3	1421
38522	5	93144	4	36079
38523	4	93145	2	12566
38524	5	93146	7	16457
38525	5	93147	4	30471
38526	3	93152	1	36116
38527	5	93153	6	36124
38528	5	93157	1	17701
38529	5	93159	4	9011
38530	5	93161	7	36195
38531	5	93162	6	15679
38532	4	93166	2	34588
38533	5	93167	7	36035
38534	2	93168	4	27202
38535	4	93169	5	36201
38536	4	93172	3	20212
38537	5	93174	4	15166
38538	4	93177	7	1416
38539	2	93180	6	2107
38540	4	93185	7	14725
38541	5	93190	2	36050
38542	5	93190	4	36050
38543	5	93191	1	10616
38544	3	93193	7	10365
38545	4	93195	2	27792
38546	4	93197	3	13172
38547	5	93198	2	2846
38548	5	93200	4	36167
38549	4	93201	5	23575
38550	5	93202	7	36066
38551	5	93203	4	36137
38552	5	93214	5	33298
38553	5	93222	7	24767
38554	5	93226	7	32881
38555	4	93227	7	36140
38556	2	93229	3	26827
38557	4	93231	2	36127
38558	5	93232	4	36236
38559	4	93234	3	36210
38560	5	93237	6	30913
38561	4	93239	5	36162
38562	3	93240	7	30463
38563	4	93242	2	36131
38564	5	93243	2	6008
38565	5	93247	6	2062
38566	5	93248	2	3001
38567	4	93249	3	7553
38568	4	93253	7	36023
38569	4	93255	2	31751
38570	3	93256	7	12378
38571	4	93258	7	36205
38572	5	93267	6	36073
38573	5	93268	6	33568
38574	4	93269	2	33131
38575	4	93274	5	36083
38576	3	93275	1	1541
38577	5	93275	2	1541
38578	5	93278	6	25548
38579	5	93280	2	3788
38580	4	93282	4	36319
38581	4	93286	5	25576
38582	5	93287	6	19596
38583	4	93296	1	36347
38584	5	93298	5	32667
38585	5	93304	7	36273
38586	5	93306	1	36450
38587	5	93307	2	27390
38588	4	93309	6	28161
38589	4	93310	7	36248
38590	5	93313	2	34114
38591	1	93315	7	32280
38592	4	93317	4	2064
38593	5	93320	7	36464
38594	5	93322	3	36482
38595	5	93325	4	36364
38596	5	93329	2	24594
38597	3	93329	1	24594
38598	5	93334	2	9319
38599	5	93335	2	30816
38600	5	93338	7	1866
38601	5	93339	1	21551
38602	3	93342	1	36315
38603	4	93347	5	35130
38604	5	93349	2	9323
38605	5	93350	2	36458
38606	3	93351	3	36340
38607	5	93351	2	36340
38608	3	93354	4	18940
38609	4	93354	3	18940
38610	5	93355	1	19817
38611	5	93356	3	26373
38612	5	93357	2	29225
38613	5	93358	2	7501
38614	4	93359	2	28824
38615	5	93361	7	7426
38616	1	93362	4	25075
38617	3	93365	5	36502
38618	5	93368	2	36342
38619	3	93370	4	19328
38620	5	93372	1	14984
38621	4	93375	6	8987
38622	4	93375	4	8987
38623	5	93376	2	2605
38624	5	93377	6	33203
38625	5	93378	1	25123
38626	5	93379	5	36379
38627	4	93387	7	36305
38628	5	93389	7	36418
38629	5	93390	6	27718
38630	4	93392	5	31353
38631	5	93400	7	24332
38632	5	93401	5	29743
38633	5	93404	7	32686
38634	3	93405	1	10461
38635	3	93406	7	3707
38636	3	93407	1	10692
38637	5	93407	6	10692
38638	5	93409	6	14027
38639	4	93411	6	36261
38640	3	93413	3	36461
38641	3	93416	1	36296
38642	3	93421	5	36499
38643	3	93424	5	36493
38644	4	93425	5	702
38645	5	93428	5	36442
38646	5	93428	3	36442
38647	5	93438	2	19622
38648	5	93441	7	6399
38649	5	93442	1	6202
38650	4	93445	2	5527
38651	5	93450	5	36483
38652	5	93450	6	36483
38653	5	93453	2	20188
38654	5	93455	6	7802
38655	5	93463	4	184
38656	4	93464	2	14891
38657	4	93466	5	17605
38658	5	93467	1	36289
38659	5	93468	1	19822
38660	4	93469	3	1761
38661	5	93470	1	36429
38662	4	93471	7	21278
38663	5	93474	5	36353
38664	5	93475	7	36410
38665	4	93478	7	36457
38666	4	93481	7	25816
38667	5	93482	2	33149
38668	5	93483	3	14568
38669	2	93483	2	14568
38670	5	93487	6	15769
38671	5	93489	5	36376
38672	5	93490	3	14650
38673	1	93494	6	15677
38674	3	93495	3	31078
38675	3	93497	5	4036
38676	4	93498	6	27775
38677	5	93499	2	24129
38678	5	93500	7	36330
38679	5	93503	5	36298
38680	5	93505	7	4695
38681	5	93506	7	36352
38682	5	93509	3	36354
38683	4	93509	1	36354
38684	5	93513	6	36401
38685	3	93520	7	30922
38686	4	93521	1	6843
38687	4	93522	4	36384
38688	3	93525	1	36391
38689	3	93528	1	6440
38690	5	93531	2	14354
38691	5	93531	7	14354
38692	5	93534	6	36300
38693	4	93538	5	36486
38694	5	93539	2	35230
38695	5	93541	4	19987
38696	5	93541	6	19987
38697	5	93542	1	21606
38698	3	93544	5	36324
38699	4	93545	1	36451
38700	4	93547	7	36455
38701	4	93549	1	21849
38702	4	93552	4	17014
38703	5	93552	3	17014
38704	5	93553	4	2309
38705	4	93555	4	15563
38706	4	93557	7	12532
38707	4	93558	7	36247
38708	4	93561	3	3984
38709	5	93562	7	15603
38710	4	93565	5	36367
38711	5	93566	6	23178
38712	5	93567	2	27156
38713	4	93568	5	9312
38714	5	93570	6	36360
38715	5	93575	2	1296
38716	5	93576	6	3597
38717	5	93583	7	10310
38718	4	93584	6	36480
38719	4	93585	4	36497
38720	4	93586	2	32455
38721	3	93587	1	36430
38722	4	93588	5	24787
38723	5	93591	1	21107
38724	4	93595	1	24473
38725	5	93595	2	24473
38726	4	93597	7	11691
38727	5	93599	2	20457
38728	5	93600	5	30291
38729	5	93600	4	30291
38730	5	93601	1	36445
38731	4	93602	1	6883
38732	3	93603	7	26066
38733	5	93605	2	31684
38734	4	93607	3	24254
38735	3	93612	2	5131
38736	3	93614	4	2874
38737	3	93622	2	3332
38738	5	93625	7	36505
38739	5	93628	5	36267
38740	5	93633	6	33776
38741	1	93635	6	26968
38742	5	93639	3	14360
38743	4	93640	3	34779
38744	4	93640	5	34779
38745	5	93641	2	1239
38746	4	93643	7	18234
38747	3	93645	5	9215
38748	5	93647	6	36490
38749	3	93650	2	36372
38750	1	93654	6	15782
38751	3	93656	7	6421
38752	5	93661	2	36303
38753	4	93665	7	5041
38754	5	93670	1	36299
38755	3	93671	2	36358
38756	4	93672	3	36325
38757	5	93673	7	23642
38758	5	93679	6	36302
38759	5	93682	6	36246
38760	5	93686	2	34485
38761	3	93690	1	13606
38762	1	93692	6	32640
38763	5	93693	6	36271
38764	3	93694	7	22863
38765	5	93696	6	36491
38766	5	93697	2	36404
38767	5	93698	2	7896
38768	5	93711	6	23696
38769	5	93715	6	36489
38770	4	93716	4	36411
38771	3	93717	3	36326
38772	5	93719	1	21894
38773	5	93720	6	9053
38774	4	93721	2	31827
38775	5	93722	6	13045
38776	3	93724	1	36452
38777	2	93725	7	2447
38778	5	93727	7	30687
38779	4	93728	6	7858
38780	5	93732	4	36477
38781	5	93734	5	10827
38782	5	93744	6	10438
38783	5	93756	1	36428
38784	3	93757	1	13667
38785	5	93758	6	36275
38786	3	93759	4	36456
38787	5	93761	2	36310
38788	5	93762	4	36441
38789	3	93763	4	2050
38790	5	93764	3	18400
38791	4	93765	4	4170
38792	3	93766	7	10993
38793	2	93768	5	17209
38794	4	93770	5	36356
38795	5	93772	7	36333
38796	3	93773	6	4818
38797	4	93774	3	22721
38798	3	93781	7	36309
38799	4	93782	4	17038
38800	5	93783	4	25607
38801	4	93783	7	25607
38802	3	93786	5	13779
38803	4	93787	6	15530
38804	5	93788	5	35198
38805	2	93790	7	8076
38806	3	93792	7	20553
38807	5	93793	2	32294
38808	4	93795	3	36307
38809	3	93796	2	36383
38810	5	93800	4	7766
38811	5	93802	3	22373
38812	5	93803	4	15394
38813	5	93804	3	15252
38814	1	93805	6	36338
38815	4	93806	2	14958
38816	3	93807	5	4527
38817	4	93808	3	36424
38818	4	93812	4	12047
38819	5	93815	5	36485
38820	5	93818	4	36381
38821	5	93820	5	36465
38822	5	93821	1	2995
38823	4	93821	7	2995
38824	5	93822	3	36484
38825	5	93823	5	16153
38826	2	93824	1	12098
38827	5	93825	4	5822
38828	4	93830	7	36398
38829	5	93833	6	18082
38830	5	93836	7	13109
38831	4	93839	1	35669
38832	3	93840	1	35966
38833	4	93843	5	36460
38834	3	93844	1	36431
38835	3	93849	5	36397
38836	4	93850	6	36361
38837	3	93850	5	36361
38838	5	93852	5	35019
38839	5	93853	2	14989
38840	5	93854	1	36348
38841	5	93855	6	36343
38842	5	93858	7	36488
38843	3	93864	5	12660
38844	5	93872	1	16829
38845	5	93876	2	36563
38846	5	93878	1	36722
38847	4	93879	4	36734
38848	3	93879	5	36734
38849	5	93880	6	11411
38850	3	93882	4	36679
38851	5	93883	5	34670
38852	5	93884	4	19273
38853	5	93893	7	35440
38854	3	93896	7	7595
38855	5	93898	6	36671
38856	4	93899	4	14202
38857	3	93900	3	5882
38858	5	93909	2	14608
38859	4	93912	3	9925
38860	5	93915	6	35285
38861	4	93917	7	16664
38862	5	93919	2	18980
38863	5	93921	3	8390
38864	4	93924	5	36539
38865	5	93925	6	9749
38866	4	93925	1	9749
38867	3	93926	7	26504
38868	4	93928	4	21571
38869	5	93932	6	22965
38870	3	93933	3	36506
38871	5	93935	1	35568
38872	3	93937	2	4463
38873	4	93942	4	23551
38874	5	93943	6	36542
38875	4	93945	7	13400
38876	4	93947	4	36729
38877	4	93949	5	11716
38878	5	93951	6	5654
38879	5	93952	7	9560
38880	3	93953	1	28425
38881	5	93954	5	10247
38882	4	93955	7	27897
38883	5	93968	2	36593
38884	5	93972	5	30450
38885	5	93973	1	26193
38886	4	93976	6	18312
38887	5	93978	1	36604
38888	5	93981	7	36600
38889	5	93984	6	36738
38890	5	93985	7	7983
38891	4	93988	1	36545
38892	5	93990	5	27145
38893	4	93991	1	15319
38894	3	93995	1	36705
38895	5	93998	7	30001
38896	1	93999	6	24807
38897	5	94001	2	9440
38898	4	94002	1	33105
38899	2	94003	6	21907
38900	5	94004	5	11529
38901	4	94006	5	645
38902	3	94007	2	1754
38903	5	94010	6	36619
38904	5	94011	6	36647
38905	4	94014	3	36640
38906	5	94018	4	26162
38907	4	94023	7	36755
38908	4	94027	1	655
38909	3	94032	7	4242
38910	4	94033	3	36562
38911	5	94034	6	17417
38912	4	94037	7	2933
38913	4	94039	7	14002
38914	2	94042	1	36661
38915	5	94044	6	36214
38916	5	94045	6	26386
38917	5	94048	4	36537
38918	5	94053	7	22610
38919	4	94056	6	36599
38920	5	94057	3	36620
38921	5	94059	7	3629
38922	5	94060	4	25324
38923	1	94062	6	36511
38924	5	94067	4	36621
38925	5	94073	7	36612
38926	5	94074	6	1258
38927	4	94078	3	36629
38928	3	94081	7	31311
38929	4	94082	5	36521
38930	5	94083	4	36616
38931	4	94086	3	36607
38932	5	94088	6	36572
38933	3	94089	7	22664
38934	5	94090	7	36675
38935	1	94091	6	29270
38936	3	94092	5	28936
38937	3	94094	2	22630
38938	5	94098	6	36666
38939	5	94102	4	15372
38940	5	94107	7	11110
38941	4	94108	5	8038
38942	4	94110	7	17854
38943	4	94112	7	29745
38944	3	94113	7	23027
38945	5	94115	7	36703
38946	5	94117	7	36651
38947	5	94123	7	36609
38948	5	94128	4	19883
38949	4	94128	6	19883
38950	5	94130	2	2995
38951	5	94132	1	36636
38952	5	94133	6	3238
38953	2	94134	6	17979
38954	5	94141	4	3561
38955	4	94142	6	36690
38956	5	94143	6	15092
38957	3	94145	4	64
38958	5	94146	6	36711
38959	3	94146	7	36711
38960	5	94148	2	2807
38961	3	94148	5	2807
38962	5	94150	6	36623
38963	4	94156	7	36726
38964	5	94160	1	23203
38965	3	94163	6	28839
38966	3	94164	4	10668
38967	1	94168	6	36665
38968	4	94169	5	36727
38969	5	94171	2	17711
38970	5	94174	5	36633
38971	5	94175	6	36520
38972	3	94176	5	36667
38973	5	94177	6	36686
38974	5	94178	2	3115
38975	4	94181	6	19794
38976	5	94182	4	33071
38977	5	94192	5	11666
38978	5	94193	6	20329
38979	4	94196	4	13708
38980	5	94201	7	36586
38981	3	94207	5	14138
38982	3	94209	5	27958
38983	4	94217	2	36577
38984	5	94222	1	36751
38985	1	94223	4	28893
38986	5	94226	2	19935
38987	3	94229	2	7069
38988	3	94230	5	20303
38989	3	94232	5	20652
38990	3	94233	7	13379
38991	5	94234	3	36627
38992	4	94237	3	21002
38993	5	94239	3	36704
38994	5	94240	3	10590
38995	4	94244	6	4937
38996	5	94245	4	1945
38997	4	94246	4	36543
38998	5	94247	2	21198
38999	5	94250	3	7246
39000	5	94252	2	15880
39001	5	94255	6	36709
39002	3	94259	1	36747
39003	5	94260	2	4047
39004	5	94262	2	36527
39005	5	94267	5	36556
39006	5	94268	2	36589
39007	4	94268	5	36589
39008	5	94270	2	36602
39009	2	94272	6	36569
39010	4	94275	2	8750
39011	4	94276	7	31307
39012	3	94278	7	36595
39013	4	94280	7	6134
39014	5	94281	6	36582
39015	4	94282	7	31013
39016	4	94283	2	34581
39017	5	94285	2	11041
39018	4	94287	1	24200
39019	5	94288	7	32119
39020	5	94291	5	19102
39021	5	94297	4	8811
39022	3	94298	5	36742
39023	5	94299	2	441
39024	5	94300	4	36664
39025	5	94304	7	36716
39026	3	94307	5	28276
39027	5	94311	2	313
39028	4	94312	4	5701
39029	5	94315	2	6344
39030	5	94319	5	34700
39031	5	94320	4	36634
39032	4	94322	4	2082
39033	5	94323	2	36750
39034	5	94325	6	36546
39035	4	94326	6	21533
39036	4	94330	1	9943
39037	3	94331	2	17503
39038	5	94332	2	6372
39039	5	94333	3	1184
39040	1	94334	1	36692
39041	2	94335	6	36696
39042	2	94341	1	13639
39043	3	94342	6	36697
39044	4	94343	5	7775
39045	4	94344	7	11562
39046	5	94345	2	8877
39047	5	94346	3	22011
39048	5	94347	6	14540
39049	5	94348	2	36717
39050	5	94350	5	35242
39051	2	94351	6	27736
39052	4	94354	4	4644
39053	4	94357	7	22643
39054	5	94358	7	36744
39055	5	94358	4	36744
39056	5	94361	6	6439
39057	4	94366	4	36706
39058	5	94367	4	9634
39059	4	94369	2	3883
39060	5	94370	5	26461
39061	3	94371	4	12686
39062	5	94374	5	36719
39063	5	94376	6	36526
39064	5	94377	4	24899
39065	5	94380	4	25808
39066	5	94381	6	21292
39067	5	94385	6	36758
39068	5	94386	4	28532
39069	5	94387	2	27515
39070	3	94391	5	30967
39071	5	94394	6	36754
39072	4	94399	4	36588
39073	5	94401	4	36708
39074	4	94402	7	36712
39075	5	94406	5	36603
39076	5	94408	3	29010
39077	5	94410	7	23450
39078	3	94410	1	23450
39079	4	94411	7	33568
39080	4	94412	5	34578
39081	3	94414	5	9516
39082	5	94418	1	11812
39083	5	94421	5	11917
39084	4	94423	4	36529
39085	3	94432	5	11721
39086	3	94434	1	21866
39087	4	94439	6	7428
39088	5	94440	3	31501
39089	4	94441	7	3579
39090	5	94442	4	20438
39091	5	94445	7	10872
39092	3	94447	3	5033
39093	3	94449	7	36523
39094	5	94450	7	22606
39095	5	94452	5	28564
39096	2	94453	6	36654
39097	4	94454	7	5022
39098	4	94455	6	36584
39099	5	94459	6	34546
39100	3	94465	5	21601
39101	3	94468	5	26536
39102	4	94470	7	6265
39103	5	94473	5	16290
39104	5	94474	2	10851
39105	3	94481	7	25575
39106	3	94482	7	36560
39107	5	94485	5	36710
39108	4	94487	4	31823
39109	4	94488	5	11046
39110	3	94491	1	2653
39111	4	94491	5	2653
39112	4	94494	7	33357
39113	4	94497	3	531
39114	4	94498	1	15491
39115	5	94500	7	16858
39116	3	94501	5	11435
39117	5	94504	6	36723
39118	4	94508	7	27895
39119	5	94508	6	27895
39120	5	94519	3	36642
39121	5	94528	7	36553
39122	3	94532	3	36622
39123	3	94534	7	10498
39124	5	94538	4	9524
39125	5	94539	1	36632
39126	5	94541	2	34975
39127	3	94545	5	9194
39128	3	94550	2	36597
39129	2	94555	6	36575
39130	5	94557	7	35449
39131	4	94559	6	36689
39132	5	94562	2	12853
39133	1	94563	3	36566
39134	3	94563	4	36566
39135	5	94568	6	36713
39136	4	94569	7	34400
39137	5	94571	1	35102
39138	5	94572	6	36657
39139	4	94573	7	18755
39140	4	94584	2	36570
39141	5	94586	7	19307
39142	5	94590	4	15628
39143	4	94592	5	36644
39144	5	94593	2	36693
39145	5	94594	4	279
39146	4	94595	7	35812
39147	4	94596	7	7849
39148	3	94599	3	15827
39149	4	94604	4	8739
39150	5	94607	7	4642
39151	5	94613	2	8136
39152	5	94617	2	36585
39153	5	94619	5	36592
39154	2	94624	6	18947
39155	2	94625	4	36730
39156	5	94626	3	26373
39157	4	94627	3	35940
39158	4	94628	4	36538
39159	5	94632	1	8866
39160	5	94633	7	26789
39161	1	94634	6	36899
39162	4	94635	7	36937
39163	1	94635	6	36937
39164	5	94636	4	6641
39165	4	94637	4	3648
39166	5	94638	2	26242
39167	3	94640	4	6034
39168	5	94643	6	36780
39169	5	94645	6	36857
39170	5	94649	6	36968
39171	5	94650	6	14224
39172	4	94654	1	33399
39173	4	94655	2	36903
39174	4	94657	6	36932
39175	5	94660	7	3540
39176	5	94665	4	5192
39177	3	94666	7	5945
39178	5	94668	1	705
39179	5	94669	2	36959
39180	5	94670	6	19812
39181	5	94672	7	31526
39182	3	94673	3	1079
39183	4	94676	4	490
39184	5	94677	1	14985
39185	5	94678	3	36824
39186	2	94679	6	35886
39187	5	94680	6	36770
39188	5	94681	6	15189
39189	5	94682	6	1183
39190	3	94683	1	33084
39191	5	94684	4	36834
39192	4	94686	2	32222
39193	5	94687	6	30327
39194	5	94689	6	36934
39195	5	94692	5	36828
39196	5	94695	2	36859
39197	1	94703	6	4629
39198	3	94704	3	36862
39199	4	94704	7	36862
39200	3	94706	3	14915
39201	5	94707	6	36789
39202	5	94708	4	26187
39203	5	94710	7	1481
39204	5	94713	2	31706
39205	3	94720	5	7245
39206	3	94721	1	15132
39207	2	94724	3	2820
39208	3	94725	5	5972
39209	3	94728	4	36943
39210	5	94730	2	26804
39211	5	94733	7	36803
39212	5	94735	2	36809
39213	5	94740	5	20400
39214	4	94741	2	31596
39215	4	94743	4	20993
39216	4	94744	1	4635
39217	4	94753	7	20033
39218	3	94754	1	19986
39219	5	94757	5	20710
39220	4	94758	3	36918
39221	4	94759	4	9350
39222	5	94767	2	14522
39223	5	94768	4	6811
39224	3	94769	1	36868
39225	4	94774	2	6883
39226	5	94783	3	36907
39227	5	94786	4	36854
39228	5	94787	6	5117
39229	5	94792	4	23486
39230	1	94794	6	5933
39231	5	94795	5	30049
39232	3	94797	3	1366
39233	4	94799	6	14664
39234	3	94803	4	14413
39235	5	94806	2	34870
39236	5	94807	1	25313
39237	5	94810	2	9348
39238	3	94815	7	36871
39239	5	94816	7	36921
39240	5	94820	6	14758
39241	5	94821	7	31720
39242	1	94823	7	3570
39243	4	94825	3	31578
39244	5	94826	7	36777
39245	5	94829	4	36843
39246	4	94829	5	36843
39247	5	94833	5	29787
39248	5	94836	4	14447
39249	5	94838	6	35669
39250	4	94843	7	2605
39251	5	94847	6	25022
39252	5	94847	4	25022
39253	5	94851	1	13969
39254	5	94858	6	36888
39255	3	94859	7	11600
39256	5	94860	2	36772
39257	4	94860	7	36772
39258	3	94863	3	18069
39259	4	94865	7	13497
39260	5	94867	7	17558
39261	5	94870	4	13841
39262	5	94872	6	36804
39263	3	94873	4	1117
39264	5	94875	1	36924
39265	5	94876	6	10886
39266	4	94877	2	20553
39267	5	94882	7	27519
39268	4	94883	5	26961
39269	5	94885	1	22546
39270	4	94888	1	32274
39271	4	94889	7	33126
39272	5	94895	4	14873
39273	4	94897	6	25291
39274	5	94898	4	21872
39275	3	94901	5	36976
39276	5	94903	2	2301
39277	3	94909	5	18778
39278	3	94910	7	5758
39279	3	94911	4	8943
39280	5	94912	5	36966
39281	5	94915	5	22985
39282	4	94917	5	9902
39283	3	94918	2	8509
39284	5	94919	7	8742
39285	5	94922	7	36940
39286	5	94922	6	36940
39287	5	94923	2	36870
39288	5	94926	1	10608
39289	5	94926	6	10608
39290	4	94928	4	19190
39291	4	94930	7	32050
39292	4	94931	6	29542
39293	2	94932	3	27618
39294	5	94933	2	16960
39295	5	94937	7	36805
39296	4	94939	7	12769
39297	4	94941	3	10260
39298	5	94942	7	36274
39299	3	94943	5	15291
39300	5	94944	7	36811
39301	3	94946	5	36830
39302	2	94947	6	19698
39303	5	94949	6	36788
39304	5	94950	2	17245
39305	3	94951	7	26086
39306	4	94952	2	36793
39307	5	94955	1	8578
39308	2	94956	3	22017
39309	5	94959	7	36912
39310	4	94959	6	36912
39311	5	94962	2	4268
39312	4	94962	4	4268
39313	5	94965	6	10066
39314	4	94965	7	10066
39315	4	94969	3	10093
39316	5	94971	6	19830
39317	5	94972	2	14403
39318	1	94973	6	7807
39319	5	94975	3	14423
39320	5	94976	7	5440
39321	5	94977	7	21382
39322	4	94979	5	29202
39323	5	94980	5	30674
39324	4	94981	3	11268
39325	5	94982	5	31343
39326	5	94992	4	11252
39327	5	94994	6	26613
39328	4	94995	3	2424
39329	4	95001	4	23704
39330	2	95006	4	36350
39331	5	95006	7	36350
39332	5	95007	6	8695
39333	5	95009	2	10655
39334	5	95010	6	6905
39335	5	95011	7	14238
39336	4	95012	7	24651
39337	5	95016	2	3334
39338	3	95018	7	20593
39339	4	95019	3	29075
39340	4	95022	4	36950
39341	3	95024	1	34482
39342	5	95031	5	16967
39343	5	95032	6	36951
39344	3	95033	5	29990
39345	5	95035	6	10235
39346	4	95036	2	8208
39347	5	95038	7	35064
39348	4	95039	7	24308
39349	5	95042	3	13584
39350	4	95045	6	15641
39351	5	95047	6	16870
39352	4	95048	3	35812
39353	5	95049	2	3602
39354	4	95051	5	15249
39355	3	95054	1	17764
39356	3	95058	5	36904
39357	5	95058	3	36904
39358	5	95063	3	18348
39359	4	95065	6	25938
39360	5	95066	6	3852
39361	5	95067	6	7084
39362	4	95068	2	36769
39363	4	95071	5	24744
39364	5	95075	1	4351
39365	3	95078	7	36923
39366	5	95082	6	20215
39367	4	95083	7	26909
39368	4	95086	7	2124
39369	5	95087	7	22270
39370	3	95089	1	36971
39371	5	95093	4	14903
39372	4	95096	6	12530
39373	5	95097	5	21257
39374	4	95099	6	13989
39375	5	95101	7	20762
39376	5	95102	3	36926
39377	5	95104	5	10337
39378	5	95106	3	3480
39379	5	95111	7	25736
39380	5	95113	4	2150
39381	5	95119	6	17804
39382	5	95126	1	26935
39383	5	95131	7	6491
39384	5	95132	1	16330
39385	4	95134	1	36869
39386	5	95138	4	20800
39387	5	95138	2	20800
39388	4	95140	1	21256
39389	5	95142	1	36782
39390	4	95145	4	1322
39391	5	95148	2	4301
39392	5	95153	5	36949
39393	4	95154	7	29713
39394	1	95154	4	29713
39395	5	95155	4	33794
39396	5	95155	7	33794
39397	5	95159	1	30629
39398	5	95162	5	2837
39399	4	95164	3	36952
39400	5	95165	6	4673
39401	5	95166	6	8842
39402	4	95167	5	36881
39403	4	95169	3	36876
39404	5	95171	7	15377
39405	5	95172	6	28601
39406	3	95173	5	36901
39407	4	95174	6	8530
39408	5	95175	6	36954
39409	5	95177	7	36886
39410	5	95178	4	36773
39411	5	95179	6	10796
39412	3	95180	7	29017
39413	5	95181	4	20740
39414	5	95182	6	36946
39415	5	95183	4	36911
39416	4	95185	7	36761
39417	5	95187	2	36800
39418	4	95188	7	13769
39419	4	95189	2	36956
39420	3	95192	1	7946
39421	5	95197	6	13669
39422	5	95198	6	36825
39423	4	95199	4	5565
39424	4	95203	2	5640
39425	5	95204	6	11399
39426	5	95206	7	30665
39427	2	95210	3	20905
39428	3	95212	4	5506
39429	5	95214	3	3996
39430	3	95215	5	4606
39431	4	95219	7	30508
39432	5	95223	5	22268
39433	3	95224	2	32328
39434	5	95228	6	36765
39435	5	95229	2	11309
39436	5	95230	4	36852
39437	5	95231	7	36955
39438	4	95232	1	36848
39439	5	95238	2	27473
39440	4	95239	7	26392
39441	5	95240	4	24847
39442	5	95246	7	36808
39443	5	95247	6	36813
39444	4	95250	4	29470
39445	5	95254	3	7227
39446	3	95256	5	5297
39447	5	95257	2	21520
39448	5	95261	1	36897
39449	5	95264	4	17372
39450	4	95265	6	36853
39451	3	95269	7	36849
39452	3	95270	5	36909
39453	4	95271	1	21215
39454	5	95276	5	17118
39455	4	95278	1	36817
39456	2	95278	4	36817
39457	3	95279	3	30808
39458	5	95281	2	12453
39459	3	95286	5	29613
39460	5	95294	2	36847
39461	5	95296	3	36972
39462	5	95297	2	22197
39463	5	95298	7	32244
39464	5	95299	5	15585
39465	5	95300	4	33775
39466	5	95302	1	4007
39467	5	95304	5	11270
39468	5	95305	2	26272
39469	5	95308	4	8655
39470	4	95309	7	12724
39471	5	95313	4	36818
39472	5	95314	5	14909
39473	5	95318	6	856
39474	2	95319	6	22346
39475	3	95320	5	36890
39476	3	95323	5	36759
39477	1	95323	4	36759
39478	4	95324	2	18747
39479	5	95328	3	8626
39480	5	95329	2	24383
39481	3	95333	4	36821
39482	4	95335	3	20805
39483	5	95337	7	36842
39484	5	95343	4	36726
39485	4	95345	5	36962
39486	5	95347	6	16785
39487	5	95348	3	5701
39488	4	95350	4	21923
39489	3	95352	1	3631
39490	5	95354	1	4592
39491	4	95355	2	30534
39492	5	95365	1	20841
39493	5	95366	4	35023
39494	5	95367	4	36838
39495	5	95369	7	36778
39496	1	95371	1	8726
39497	3	95372	6	26292
39498	5	95373	5	10422
39499	5	95374	7	23986
39500	5	95382	6	17489
39501	5	95384	1	9054
39502	4	95385	6	30783
39503	3	95387	5	21413
39504	5	95389	1	36820
39505	5	95391	7	33683
39506	5	95392	1	36792
39507	5	95394	2	36836
39508	5	95397	6	34406
39509	5	95398	2	22564
39510	3	95403	1	30256
39511	5	95404	2	22485
39512	5	95406	3	36872
39513	3	95408	4	36953
39514	5	95410	2	32885
39515	2	95411	2	19380
39516	5	95414	5	36957
39517	4	95415	5	26116
39518	5	95416	7	10145
39519	5	95417	4	29569
39520	5	95417	3	29569
39521	3	95419	5	36802
39522	5	95420	6	3636
39523	3	95421	2	36964
39524	3	95423	7	36826
39525	4	95425	1	9893
39526	4	95427	7	28728
39527	5	95432	3	16825
39528	4	95432	4	16825
39529	4	95433	6	36059
39530	4	95437	2	22126
39531	3	95439	7	26974
39532	3	95444	6	36894
39533	3	95446	7	28362
39534	4	95448	7	21884
39535	4	95449	4	37046
39536	5	95450	3	17507
39537	5	95451	6	477
39538	5	95452	5	16831
39539	5	95453	2	37125
39540	3	95454	1	2567
39541	3	95455	5	26468
39542	5	95455	4	26468
39543	3	95456	5	9550
39544	4	95457	7	37072
39545	5	95458	4	24041
39546	3	95459	4	37115
39547	3	95463	2	6767
39548	5	95467	6	24842
39549	5	95471	6	24033
39550	5	95476	7	37065
39551	5	95478	3	5279
39552	5	95478	6	5279
39553	5	95479	6	37087
39554	3	95483	5	37048
39555	4	95484	7	37095
39556	3	95489	5	37052
39557	5	95490	6	16522
39558	4	95496	3	37130
39559	4	95501	2	8640
39560	1	95502	6	12240
39561	4	95505	2	18224
39562	5	95509	1	5180
39563	5	95510	6	37059
39564	5	95512	3	32901
39565	4	95514	7	8904
39566	3	95515	3	22515
39567	3	95517	2	23138
39568	5	95518	5	27365
39569	3	95519	2	6221
39570	3	95521	5	21264
39571	5	95522	4	28097
39572	5	95524	1	7293
39573	5	95524	3	7293
39574	3	95526	7	26523
39575	5	95527	2	6709
39576	5	95529	6	37126
39577	5	95530	1	33472
39578	4	95531	5	37092
39579	3	95532	2	37007
39580	4	95533	6	37004
39581	5	95534	3	22598
39582	1	95535	1	9793
39583	5	95537	7	37172
39584	5	95538	2	1380
39585	5	95538	4	1380
39586	5	95539	3	15452
39587	5	95540	1	3040
39588	5	95543	4	7208
39589	3	95543	2	7208
39590	5	95545	4	37023
39591	4	95545	6	37023
39592	5	95548	6	26640
39593	4	95549	3	32251
39594	4	95554	6	31065
39595	4	95557	7	11260
39596	4	95562	3	37156
39597	5	95565	2	25420
39598	5	95566	1	36449
39599	4	95566	7	36449
39600	4	95569	7	17157
39601	4	95570	1	35804
39602	4	95571	2	32249
39603	5	95576	6	33662
39604	4	95576	3	33662
39605	4	95579	5	37147
39606	5	95582	1	12309
39607	5	95583	6	37183
39608	4	95584	7	34166
39609	5	95585	2	23266
39610	2	95588	5	30131
39611	3	95592	4	10785
39612	5	95593	6	36991
39613	4	95594	5	37129
39614	4	95595	3	17732
39615	5	95596	1	32233
39616	5	95597	4	27313
39617	5	95599	2	13424
39618	5	95600	6	316
39619	2	95603	3	37030
39620	5	95605	2	31917
39621	5	95607	2	16843
39622	5	95608	6	17870
39623	3	95615	5	37053
39624	4	95616	5	37047
39625	5	95616	7	37047
39626	5	95618	1	37062
39627	3	95618	5	37062
39628	5	95619	6	26700
39629	4	95625	7	24343
39630	4	95627	7	5238
39631	4	95630	5	27524
39632	5	95634	2	35493
39633	4	95636	3	203
39634	5	95640	2	5125
39635	5	95641	6	36986
39636	2	95644	2	37056
39637	5	95645	3	32440
39638	2	95649	7	5822
39639	4	95656	4	37054
39640	3	95660	3	26983
39641	5	95662	4	24580
39642	5	95666	1	31869
39643	3	95669	5	15932
39644	5	95670	2	6941
39645	5	95671	5	37108
39646	3	95674	4	37055
39647	3	95677	5	36995
39648	4	95680	2	6047
39649	5	95681	2	4382
39650	4	95691	5	37136
39651	4	95692	7	2551
39652	5	95696	1	12105
39653	5	95699	5	37012
39654	5	95700	6	33371
39655	5	95701	6	22379
39656	5	95704	4	34557
39657	4	95706	5	26099
39658	5	95707	6	23174
39659	5	95708	3	37038
39660	3	95711	3	31240
39661	5	95712	2	863
39662	3	95715	5	3832
39663	4	95716	7	26267
39664	4	95718	5	29625
39665	5	95719	2	25254
39666	3	95720	4	30265
39667	4	95728	7	1207
39668	5	95731	7	37021
39669	5	95732	6	27146
39670	5	95733	7	37170
39671	5	95735	4	34525
39672	5	95737	4	3539
39673	5	95738	5	30010
39674	5	95739	1	37005
39675	2	95743	4	26086
39676	5	95745	6	37166
39677	5	95750	5	10870
39678	4	95751	5	14853
39679	5	95752	7	35573
39680	2	95754	3	37071
39681	4	95760	7	37081
39682	3	95763	3	25169
39683	5	95765	4	37044
39684	5	95767	1	37079
39685	4	95768	6	36361
39686	4	95769	6	6000
39687	5	95770	2	5649
39688	4	95774	3	7941
39689	4	95775	4	31447
39690	3	95778	7	37180
39691	4	95779	7	10670
39692	5	95782	2	17005
39693	4	95785	7	37100
39694	5	95786	2	16469
39695	4	95787	4	16002
39696	4	95788	2	6232
39697	5	95790	6	37153
39698	4	95792	6	37089
39699	4	95793	7	1008
39700	5	95794	6	10356
39701	4	95796	5	8961
39702	3	95797	5	32962
39703	5	95799	1	20905
39704	5	95800	4	27556
39705	5	95802	4	37098
39706	5	95806	1	37178
39707	5	95808	2	8856
39708	1	95812	6	32388
39709	5	95814	4	10478
39710	5	95818	2	2783
39711	3	95821	5	14256
39712	5	95824	2	9685
39713	4	95824	1	9685
39714	4	95827	7	37152
39715	4	95828	7	22989
39716	4	95834	2	3701
39717	5	95838	7	37133
39718	5	95840	1	13851
39719	4	95843	4	37096
39720	5	95844	7	495
39721	1	95846	1	11770
39722	5	95848	7	26630
39723	5	95849	1	11946
39724	4	95853	2	9153
39725	4	95855	7	31647
39726	5	95856	5	37306
39727	3	95857	7	7870
39728	2	95858	4	37347
39729	5	95860	6	37230
39730	3	95862	5	34503
39731	4	95865	1	3508
39732	5	95867	1	4624
39733	3	95869	7	37339
39734	3	95870	7	19456
39735	5	95871	3	13027
39736	3	95874	5	10484
39737	5	95878	1	12675
39738	3	95880	7	15139
39739	5	95881	6	37373
39740	5	95881	3	37373
39741	4	95886	4	10106
39742	5	95890	7	19320
39743	5	95892	2	7190
39744	4	95894	2	37344
39745	5	95896	6	37258
39746	5	95902	7	25049
39747	5	95906	6	27291
39748	3	95907	7	20525
39749	5	95908	6	28773
39750	5	95909	5	23134
39751	4	95910	7	37353
39752	3	95912	5	12905
39753	3	95914	7	15488
39754	4	95917	5	3328
39755	4	95919	7	24873
39756	5	95920	5	20533
39757	5	95923	2	11825
39758	5	95924	4	37218
39759	5	95926	4	25970
39760	4	95928	1	9563
39761	3	95929	1	12541
39762	4	95931	3	21521
39763	5	95933	2	37208
39764	5	95935	4	6277
39765	5	95936	7	37099
39766	4	95942	6	35720
39767	5	95943	4	9520
39768	5	95950	4	14722
39769	5	95952	6	27711
39770	4	95953	3	4478
39771	5	95957	4	12502
39772	4	95960	4	22716
39773	3	95962	3	29854
39774	4	95964	7	37185
39775	5	95965	1	15437
39776	5	95966	6	37294
39777	5	95971	2	12468
39778	5	95973	7	36798
39779	1	95974	6	730
39780	4	95975	7	37262
39781	5	95976	5	16214
39782	5	95977	4	1418
39783	5	95978	6	35063
39784	5	95980	6	37276
39785	4	95983	1	37206
39786	5	95990	1	315
39787	3	95991	5	37236
39788	5	95992	5	366
39789	5	95996	2	37334
39790	5	96000	4	37315
39791	5	96001	2	13320
39792	5	96005	6	344
39793	5	96008	2	33148
39794	3	96010	2	11266
39795	5	96011	4	30977
39796	5	96012	6	11840
39797	4	96015	1	3034
39798	4	96017	4	28319
39799	3	96018	1	7128
39800	4	96020	3	172
39801	3	96022	5	34394
39802	5	96023	5	27449
39803	5	96024	7	3924
39804	3	96025	7	6366
39805	5	96028	6	37222
39806	5	96028	2	37222
39807	5	96030	6	37366
39808	5	96034	2	21897
39809	5	96035	7	502
39810	5	96036	1	9065
39811	5	96037	4	20990
39812	3	96038	4	37301
39813	5	96041	4	37311
39814	5	96047	1	31659
39815	4	96048	7	10390
39816	5	96049	6	37203
39817	3	96051	6	34400
39818	5	96052	7	32407
39819	5	96056	5	37318
39820	3	96057	7	3728
39821	5	96057	4	3728
39822	3	96059	3	265
39823	5	96066	1	14068
39824	5	96067	2	37264
39825	5	96070	7	32671
39826	3	96071	3	21349
39827	4	96072	5	37260
39828	5	96073	4	37243
39829	3	96075	3	34311
39830	5	96076	1	32817
39831	5	96077	6	23326
39832	5	96080	5	13291
39833	5	96081	2	12267
39834	5	96081	6	12267
39835	5	96082	6	26242
39836	5	96084	2	16066
39837	4	96088	7	16045
39838	4	96088	5	16045
39839	5	96089	4	20786
39840	5	96089	6	20786
39841	5	96093	6	31160
39842	5	96101	1	27124
39843	5	96102	2	8410
39844	5	96103	3	19788
39845	4	96106	7	24013
39846	5	96108	1	3459
39847	3	96113	7	15797
39848	5	96113	2	15797
39849	5	96114	2	37192
39850	5	96115	4	37184
39851	5	96117	1	26504
39852	4	96120	5	22587
39853	5	96131	6	37340
39854	3	96134	5	33407
39855	3	96135	3	21553
39856	3	96138	2	15098
39857	4	96139	2	37191
39858	5	96140	3	37221
39859	3	96146	4	17996
39860	5	96148	1	22602
39861	4	96157	1	12281
39862	5	96160	1	37259
39863	5	96163	6	21850
39864	5	96169	2	30651
39865	4	96172	7	30073
39866	4	96173	1	36072
39867	4	96178	6	37372
39868	5	96183	5	37234
39869	4	96186	4	6228
39870	3	96187	5	390
39871	5	96188	1	33299
39872	5	96190	7	37189
39873	3	96193	4	37207
39874	4	96195	2	13987
39875	5	96198	3	29754
39876	4	96198	7	29754
39877	5	96200	4	11187
39878	4	96202	4	35016
39879	5	96203	6	7205
39880	5	96204	2	32595
39881	3	96207	4	18833
39882	5	96208	2	31653
39883	3	96218	5	11636
39884	3	96219	3	37245
39885	5	96223	5	14127
39886	3	96224	7	6975
39887	3	96226	2	15616
39888	3	96227	2	13026
39889	5	96231	7	34038
39890	4	96234	4	23867
39891	3	96235	7	17829
39892	3	96238	3	35561
39893	4	96246	3	33909
39894	5	96248	3	17014
39895	4	96251	6	13455
39896	5	96258	4	20697
39897	5	96258	1	20697
39898	5	96259	2	22971
39899	3	96262	1	37360
39900	5	96263	7	27530
39901	5	96265	5	15566
39902	5	96266	1	6650
39903	5	96271	5	37364
39904	5	96272	2	37239
39905	3	96273	7	37325
39906	5	96274	1	37242
39907	5	96276	4	10662
39908	5	96277	2	1186
39909	4	96279	5	34758
39910	3	96280	1	30668
39911	3	96281	3	37363
39912	5	96287	4	21461
39913	5	96289	7	1101
39914	5	96291	7	37313
39915	3	96291	2	37313
39916	5	96292	6	23845
39917	5	96294	2	37269
39918	5	96302	7	5300
39919	5	96305	2	7407
39920	5	96308	6	14451
39921	5	96310	6	34258
39922	5	96311	7	25353
39923	5	96312	6	37235
39924	5	96313	6	32787
39925	5	96315	2	7186
39926	4	96320	7	12392
39927	5	96321	1	37285
39928	5	96326	3	29320
39929	5	96327	5	8424
39930	4	96331	2	7234
39931	4	96334	7	9254
39932	5	96335	5	37317
39933	5	96337	6	26292
39934	5	96338	4	16567
39935	4	96340	2	15614
39936	5	96343	2	1115
39937	4	96344	6	37356
39938	3	96347	4	37316
39939	4	96348	3	24413
39940	5	96351	1	22965
39941	5	96353	2	2633
39942	5	96355	5	14025
39943	5	96355	1	14025
39944	5	96358	7	13920
39945	5	96359	3	24725
39946	3	96360	2	35782
39947	3	96361	1	19013
39948	5	96362	4	36869
39949	5	96362	1	36869
39950	3	96366	7	17857
39951	4	96368	6	17825
39952	5	96368	4	17825
39953	5	96369	5	20097
39954	5	96370	3	13994
39955	5	96371	7	11683
39956	3	96371	3	11683
39957	5	96375	4	37457
39958	5	96375	6	37457
39959	3	96376	4	10820
39960	5	96377	7	27130
39961	5	96378	2	26045
39962	5	96382	4	36041
39963	1	96385	6	20492
39964	5	96386	2	37551
39965	5	96387	6	5914
39966	3	96388	3	37495
39967	4	96402	5	17667
39968	5	96402	1	17667
39969	1	96403	5	37485
39970	5	96410	6	563
39971	5	96411	4	33949
39972	5	96412	3	34068
39973	5	96414	1	37589
39974	5	96415	4	3450
39975	5	96418	5	37537
39976	5	96420	6	37422
39977	5	96424	4	29395
39978	5	96425	2	8084
39979	4	96426	1	37510
39980	5	96428	7	14487
39981	4	96430	7	19229
39982	4	96434	2	37467
39983	3	96437	3	730
39984	5	96438	3	7704
39985	5	96439	6	37436
39986	5	96440	4	37415
39987	4	96448	7	37454
39988	5	96450	5	5782
39989	5	96453	7	12924
39990	5	96456	2	14214
39991	5	96458	2	8410
39992	3	96468	6	8846
39993	5	96469	4	19766
39994	2	96470	4	9732
39995	4	96471	4	16692
39996	5	96471	5	16692
39997	5	96474	4	31310
39998	4	96475	5	37472
39999	5	96476	6	12701
40000	4	96477	4	31255
40001	3	96478	5	37218
40002	5	96481	4	37385
40003	5	96482	6	29439
40004	5	96490	4	23352
40005	5	96494	2	34195
40006	4	96495	2	29038
40007	3	96496	1	22369
40008	5	96498	4	37451
40009	4	96500	4	3126
40010	5	96503	6	36695
40011	5	96510	5	7633
40012	5	96512	2	5329
40013	5	96514	7	18787
40014	2	96517	4	18605
40015	3	96520	3	9052
40016	5	96525	3	3323
40017	5	96526	5	37386
40018	3	96527	5	16755
40019	5	96529	6	20029
40020	5	96530	4	7871
40021	5	96531	7	37489
40022	5	96533	2	37522
40023	5	96537	6	29052
40024	5	96540	7	37483
40025	4	96541	1	2609
40026	5	96545	6	5292
40027	5	96548	6	29762
40028	4	96549	7	32447
40029	5	96550	3	29946
40030	3	96551	1	37503
40031	5	96554	5	37520
40032	4	96558	6	12398
40033	5	96564	1	5267
40034	1	96565	7	19062
40035	5	96567	6	27318
40036	4	96569	1	26268
40037	5	96572	1	12320
40038	5	96572	6	12320
40039	5	96574	3	37475
40040	5	96575	7	35622
40041	5	96577	1	14722
40042	5	96578	7	37462
40043	4	96579	5	37473
40044	4	96580	7	37440
40045	5	96581	7	37530
40046	1	96582	6	15530
40047	5	96586	5	7595
40048	5	96587	6	24033
40049	5	96588	3	13847
40050	5	96589	6	13516
40051	4	96589	1	13516
40052	5	96590	5	21771
40053	5	96591	6	37509
40054	4	96597	1	28874
40055	4	96601	4	25278
40056	5	96602	6	21000
40057	4	96608	3	32009
40058	5	96609	2	11749
40059	3	96613	7	37439
40060	5	96620	7	18630
40061	5	96620	6	18630
40062	5	96621	2	37408
40063	4	96622	3	37387
40064	5	96625	7	37476
40065	5	96631	1	2819
40066	5	96632	6	37566
40067	5	96634	6	807
40068	5	96635	2	32811
40069	5	96639	6	34509
40070	5	96641	3	37561
40071	3	96644	1	21749
40072	3	96646	7	6296
40073	5	96647	6	37399
40074	4	96650	7	35688
40075	5	96653	4	2488
40076	5	96660	7	7984
40077	4	96663	6	25003
40078	4	96666	3	37486
40079	4	96666	7	37486
40080	4	96668	1	15407
40081	4	96669	7	37529
40082	5	96671	7	37438
40083	5	96672	1	37418
40084	5	96673	3	37396
40085	5	96677	6	4166
40086	4	96679	1	37381
40087	3	96680	1	31647
40088	3	96682	5	21170
40089	4	96685	5	8865
40090	4	96686	5	29225
40091	4	96689	7	21314
40092	5	96690	4	37445
40093	5	96691	6	32025
40094	5	96693	6	27673
40095	4	96695	5	2333
40096	3	96697	5	3165
40097	5	96698	2	10956
40098	5	96703	5	26188
40099	5	96705	7	27931
40100	5	96706	1	32021
40101	5	96706	6	32021
40102	5	96707	2	20535
40103	5	96710	6	31950
40104	5	96711	4	37508
40105	3	96712	7	37429
40106	5	96713	1	10415
40107	5	96716	7	13172
40108	4	96718	2	11007
40109	4	96719	5	30385
40110	3	96720	3	37524
40111	5	96721	6	29387
40112	5	96723	6	29490
40113	3	96728	2	18539
40114	3	96732	1	30120
40115	4	96733	6	4728
40116	5	96737	5	19397
40117	3	96738	1	27821
40118	4	96740	1	37585
40119	5	96743	2	10516
40120	5	96745	4	17476
40121	5	96747	6	1176
40122	4	96749	2	37541
40123	4	96751	5	34390
40124	4	96752	4	37384
40125	5	96756	3	31251
40126	4	96758	7	37424
40127	5	96759	6	18809
40128	4	96759	4	18809
40129	3	96765	5	37568
40130	3	96767	1	20050
40131	3	96771	1	1393
40132	3	96773	2	37490
40133	5	96776	5	37480
40134	5	96780	5	37565
40135	3	96784	6	32312
40136	3	96786	1	1109
40137	5	96787	1	20309
40138	5	96787	7	20309
40139	5	96789	7	23851
40140	4	96790	5	13230
40141	5	96792	5	37570
40142	4	96794	2	37430
40143	3	96800	7	22500
40144	5	96806	6	8971
40145	5	96807	2	32936
40146	5	96808	6	37482
40147	3	96811	7	12068
40148	5	96812	7	29725
40149	5	96813	6	15117
40150	5	96814	6	14771
40151	5	96815	7	26311
40152	5	96817	2	37379
40153	5	96821	5	23461
40154	5	96823	7	8081
40155	5	96824	6	11412
40156	5	96826	7	37463
40157	5	96826	6	37463
40158	4	96827	7	21074
40159	5	96829	6	8151
40160	5	96831	6	37572
40161	5	96832	5	21559
40162	3	96833	3	37411
40163	5	96836	6	37413
40164	2	96836	3	37413
40165	5	96838	1	37558
40166	4	96839	1	21069
40167	4	96844	7	13377
40168	5	96848	4	17307
40169	5	96851	7	29108
40170	5	96853	2	37389
40171	5	96854	6	11298
40172	5	96855	3	37521
40173	3	96858	5	21576
40174	5	96862	1	16178
40175	1	96864	6	11285
40176	5	96865	6	6480
40177	3	96866	1	37581
40178	5	96868	6	37455
40179	3	96868	4	37455
40180	3	96869	5	33124
40181	5	96870	6	37559
40182	4	96879	5	16152
40183	5	96880	6	37393
40184	5	96881	3	37452
40185	3	96891	4	25596
40186	4	96892	4	32468
40187	5	96897	6	1548
40188	5	96898	6	37050
40189	4	96902	2	37550
40190	4	96907	7	37576
40191	5	96908	2	13913
40192	5	96909	4	14686
40193	5	96910	7	17657
40194	4	96911	7	32339
40195	5	96912	4	10461
40196	5	96913	6	4594
40197	4	96913	7	4594
40198	5	96914	6	37532
40199	5	96915	3	16518
40200	2	96917	4	22614
40201	5	96919	6	30937
40202	5	96920	7	18770
40203	1	96921	6	8006
40204	5	96922	6	1582
40205	5	96925	7	36226
40206	5	96926	4	37563
40207	5	96928	3	25214
40208	3	96929	1	37517
40209	5	96930	1	1934
40210	3	96930	5	1934
40211	4	96931	6	37512
40212	4	96938	1	32587
40213	5	96940	2	1010
40214	5	96941	3	37459
40215	5	96943	6	3661
40216	4	96946	2	5349
40217	5	96947	1	13665
40218	3	96952	5	9558
40219	4	96957	6	4562
40220	5	96962	5	27758
40221	4	96962	7	27758
40222	3	96965	7	35271
40223	4	96966	5	27389
40224	5	96973	3	9430
40225	5	96977	3	37513
40226	4	96978	6	36832
40227	5	96980	4	28305
40228	5	96982	2	27556
40229	5	96982	6	27556
40230	5	96985	2	37549
40231	5	96986	2	11859
40232	3	96987	5	37539
40233	5	96988	2	24289
40234	1	96988	5	24289
40235	3	96992	2	37397
40236	2	96994	6	37519
40237	2	96997	6	24624
40238	4	96998	3	32061
40239	5	97001	3	37582
40240	3	97003	5	17533
40241	5	97006	1	37763
40242	5	97009	7	37822
40243	4	97010	7	21102
40244	4	97013	1	37820
40245	5	97019	2	37742
40246	3	97021	1	11454
40247	4	97022	2	37770
40248	3	97023	3	23859
40249	5	97029	6	37800
40250	3	97031	4	18524
40251	5	97032	3	30935
40252	5	97032	7	30935
40253	4	97033	5	4881
40254	4	97036	1	37677
40255	4	97037	4	25488
40256	5	97038	6	26634
40257	4	97039	1	37651
40258	5	97041	7	31316
40259	3	97043	1	19299
40260	4	97048	1	37697
40261	4	97049	2	37600
40262	5	97050	3	4252
40263	4	97053	7	37727
40264	5	97053	2	37727
40265	5	97057	6	32557
40266	5	97065	2	15351
40267	4	97066	2	28860
40268	1	97067	4	14495
40269	4	97068	7	30697
40270	5	97069	3	25420
40271	5	97069	4	25420
40272	3	97072	5	6450
40273	2	97078	6	18392
40274	4	97079	7	3592
40275	4	97080	1	21962
40276	4	97083	4	1579
40277	4	97086	5	37793
40278	1	97088	6	37699
40279	5	97090	2	30734
40280	5	97092	1	37626
40281	4	97092	7	37626
40282	5	97093	6	7517
40283	5	97095	1	2960
40284	5	97097	3	37611
40285	5	97099	5	36555
40286	4	97101	4	37743
40287	4	97107	5	37715
40288	1	97111	6	37615
40289	5	97117	1	12676
40290	5	97121	5	4422
40291	3	97122	2	37801
40292	4	97125	7	31319
40293	5	97131	6	10719
40294	3	97135	7	37728
40295	5	97140	6	37771
40296	5	97149	3	21522
40297	4	97149	1	21522
40298	5	97152	1	37789
40299	4	97153	6	37766
40300	5	97158	2	15813
40301	2	97159	3	37750
40302	5	97160	5	27470
40303	3	97160	4	27470
40304	4	97163	5	21617
40305	2	97164	6	24332
40306	4	97165	2	22329
40307	4	97170	5	20754
40308	5	97171	7	27965
40309	5	97172	6	18388
40310	1	97173	6	1457
40311	3	97175	7	22597
40312	5	97176	6	19674
40313	4	97179	3	4478
40314	4	97180	3	2791
40315	5	97181	4	31881
40316	5	97182	2	37654
40317	5	97183	4	12001
40318	5	97185	3	24175
40319	5	97187	6	1674
40320	5	97190	2	37744
40321	1	97190	6	37744
40322	5	97194	7	15829
40323	4	97195	5	1087
40324	5	97196	3	37605
40325	2	97197	2	37645
40326	3	97201	4	8058
40327	5	97204	5	8355
40328	5	97205	4	8747
40329	5	97208	2	2507
40330	5	97210	6	37647
40331	4	97214	2	24802
40332	4	97216	3	18943
40333	5	97216	4	18943
40334	4	97217	7	4116
40335	5	97217	6	4116
40336	3	97220	5	37686
40337	5	97221	7	37703
40338	3	97229	4	23427
40339	2	97229	6	23427
40340	3	97236	5	37707
40341	4	97242	7	18666
40342	5	97248	3	342
40343	5	97250	5	37667
40344	5	97251	4	18901
40345	3	97254	2	9963
40346	5	97255	7	7591
40347	4	97256	6	37617
40348	5	97257	2	13093
40349	5	97260	2	37705
40350	4	97261	3	37740
40351	4	97264	7	37672
40352	4	97266	7	34017
40353	5	97268	6	37660
40354	5	97270	5	37767
40355	4	97273	2	37799
40356	3	97278	6	37665
40357	5	97279	7	18977
40358	4	97280	4	23693
40359	3	97281	1	37664
40360	5	97282	6	37643
40361	5	97287	1	8012
40362	5	97290	1	2052
40363	4	97293	3	6853
40364	5	97294	2	37690
40365	5	97296	6	37741
40366	5	97298	2	4632
40367	4	97299	1	23809
40368	5	97300	6	28079
40369	4	97301	6	16551
40370	5	97302	7	3835
40371	4	97308	1	20993
40372	3	97310	5	34805
40373	5	97315	2	12338
40374	5	97317	4	593
40375	5	97318	4	37795
40376	1	97320	6	37648
40377	4	97322	5	32523
40378	1	97328	6	37737
40379	5	97330	4	18583
40380	5	97331	2	30976
40381	3	97335	1	37719
40382	4	97339	5	16119
40383	5	97343	2	20487
40384	5	97346	1	20243
40385	5	97348	1	20929
40386	5	97349	1	2513
40387	4	97352	2	25076
40388	5	97353	3	7543
40389	3	97355	7	4774
40390	2	97359	4	1700
40391	4	97361	6	28232
40392	3	97363	2	37597
40393	5	97365	4	18228
40394	4	97367	5	33708
40395	5	97368	7	37621
40396	3	97369	7	28284
40397	2	97371	2	37798
40398	4	97377	2	16226
40399	1	97379	5	37747
40400	5	97380	6	19819
40401	5	97381	4	37668
40402	4	97381	7	37668
40403	4	97388	3	4409
40404	4	97390	1	12942
40405	5	97392	7	14677
40406	1	97393	5	37794
40407	5	97396	1	37607
40408	5	97397	4	28026
40409	4	97398	1	18348
40410	3	97399	2	4918
40411	3	97400	6	9758
40412	4	97404	2	2951
40413	4	97406	4	21936
40414	5	97406	3	21936
40415	5	97409	7	37700
40416	3	97413	6	8052
40417	4	97416	2	37759
40418	5	97420	1	12795
40419	5	97422	1	27426
40420	3	97423	5	27023
40421	5	97425	6	36549
40422	5	97425	5	36549
40423	5	97427	3	28456
40424	1	97429	1	37736
40425	3	97430	3	30853
40426	1	97431	6	754
40427	1	97432	6	33447
40428	5	97436	6	36687
40429	4	97436	5	36687
40430	4	97439	1	26523
40431	5	97440	3	381
40432	5	97441	1	36832
40433	4	97443	7	11750
40434	5	97446	2	1860
40435	2	97448	3	6207
40436	3	97450	5	37666
40437	5	97451	7	13730
40438	5	97455	6	37824
40439	3	97462	4	20398
40440	4	97472	4	37041
40441	5	97475	5	37732
40442	5	97477	2	13855
40443	4	97480	7	11093
40444	5	97484	2	11357
40445	5	97488	3	5536
40446	5	97490	5	34639
40447	5	97492	3	3814
40448	5	97493	2	37683
40449	5	97498	6	37280
40450	5	97500	5	1442
40451	4	97501	2	5875
40452	5	97509	2	12895
40453	3	97510	5	37594
40454	3	97518	7	37609
40455	4	97519	5	37813
40456	4	97523	3	37730
40457	5	97528	5	37708
40458	5	97529	6	37816
40459	4	97531	7	37625
40460	5	97534	7	35951
40461	5	97536	2	15594
40462	4	97538	4	27159
40463	5	97540	2	36772
40464	5	97544	7	12945
40465	4	97546	7	27918
40466	4	97547	5	24724
40467	5	97548	6	24511
40468	4	97550	5	9081
40469	4	97551	7	16632
40470	4	97553	2	20711
40471	3	97556	3	10415
40472	5	97558	6	21562
40473	5	97562	4	16893
40474	4	97564	3	19729
40475	4	97565	7	35807
40476	5	97566	6	32378
40477	5	97567	5	37640
40478	2	97569	6	37599
40479	4	97572	7	22453
40480	3	97573	1	37775
40481	3	97575	3	22283
40482	5	97578	6	13054
40483	4	97579	5	3851
40484	3	97580	2	3834
40485	5	97584	2	1031
40486	5	97587	6	37754
40487	3	97588	5	22168
40488	4	97590	7	14865
40489	4	97591	3	36255
40490	4	97594	7	13014
40491	4	97595	5	37692
40492	5	97596	1	37810
40493	5	97597	2	37624
40494	4	97602	7	3668
40495	5	97604	7	19753
40496	5	97605	4	37400
40497	5	97606	2	32063
40498	4	97607	7	35105
40499	4	97609	7	15571
40500	4	97614	4	37756
40501	4	97615	2	37641
40502	4	97616	7	22923
40503	3	97617	5	6622
40504	4	97623	4	37391
40505	5	97624	4	37591
40506	1	97624	6	37591
40507	5	97629	7	14347
40508	3	97629	1	14347
40509	5	97630	1	35595
40510	5	97631	5	34081
40511	5	97636	6	1316
40512	4	97638	1	29931
40513	1	97641	5	12650
40514	5	97642	6	16450
40515	4	97644	5	33109
40516	4	97646	2	13270
40517	5	97648	4	37805
40518	5	97650	6	5662
40519	5	97651	2	24842
40520	5	97653	5	34096
40521	5	97653	6	34096
40522	4	97656	5	31930
40523	4	97657	7	37655
40524	3	97664	5	37652
40525	5	97665	6	18897
40526	5	97667	2	19978
40527	4	97669	7	12932
40528	4	97670	2	37663
40529	3	97672	3	24165
40530	2	97676	1	29895
40531	4	97677	3	3544
40532	3	97678	7	20354
40533	5	97681	2	25067
40534	3	97683	7	14061
40535	4	97686	5	5167
40536	5	97687	5	18090
40537	5	97689	6	18927
40538	3	97690	7	31358
40539	3	97692	5	21418
40540	5	97694	2	35814
40541	4	97697	4	37990
40542	4	97700	4	38059
40543	5	97703	2	37945
40544	4	97706	2	6164
40545	3	97711	7	37919
40546	1	97712	6	28959
40547	5	97719	6	38008
40548	5	97720	6	9923
40549	5	97722	4	38072
40550	5	97724	6	25377
40551	4	97725	1	24616
40552	3	97727	7	38063
40553	5	97732	1	38010
40554	5	97734	1	37868
40555	4	97738	2	5126
40556	4	97738	5	5126
40557	5	97740	4	33346
40558	5	97741	5	38001
40559	4	97744	5	37911
40560	5	97746	4	19741
40561	3	97747	7	20384
40562	3	97753	1	37893
40563	5	97754	2	38012
40564	5	97755	5	28636
40565	5	97758	2	35315
40566	5	97762	4	14947
40567	5	97763	6	7330
40568	5	97764	7	3231
40569	5	97765	6	38104
40570	4	97765	2	38104
40571	4	97768	7	23500
40572	5	97771	4	788
40573	5	97776	4	11158
40574	3	97777	4	28808
40575	5	97778	3	477
40576	5	97780	7	37992
40577	4	97787	6	35796
40578	4	97788	7	28067
40579	4	97790	7	37956
40580	4	97793	2	32697
40581	2	97798	6	2499
40582	3	97802	7	38060
40583	5	97804	2	37935
40584	5	97806	1	36273
40585	5	97809	7	24078
40586	4	97811	5	24513
40587	1	97812	6	31717
40588	5	97812	2	31717
40589	5	97814	3	38089
40590	4	97819	5	12236
40591	5	97822	1	38056
40592	5	97826	2	38024
40593	5	97832	2	639
40594	5	97837	3	35529
40595	4	97838	7	38085
40596	5	97839	2	2080
40597	4	97845	7	36375
40598	5	97846	2	26279
40599	5	97849	2	10717
40600	4	97857	1	38103
40601	4	97858	6	37853
40602	3	97860	5	14378
40603	4	97861	1	4483
40604	5	97866	2	37855
40605	5	97867	7	2572
40606	5	97869	6	32111
40607	5	97871	7	37986
40608	5	97872	2	26392
40609	4	97873	6	34885
40610	5	97876	7	38079
40611	2	97877	4	27838
40612	1	97880	4	33547
40613	4	97882	4	33326
40614	3	97882	1	33326
40615	4	97883	3	7689
40616	3	97884	4	37886
40617	3	97885	7	36045
40618	5	97887	3	26792
40619	4	97887	7	26792
40620	5	97888	2	8180
40621	5	97889	2	36713
40622	4	97890	7	28030
40623	5	97895	1	1053
40624	5	97897	5	38051
40625	3	97898	7	21377
40626	5	97899	2	121
40627	5	97901	5	38019
40628	3	97901	2	38019
40629	4	97905	1	13768
40630	5	97910	4	23928
40631	5	97916	6	5822
40632	5	97917	1	33989
40633	5	97920	7	36502
40634	5	97920	3	36502
40635	5	97921	1	11271
40636	4	97928	2	37249
40637	5	97929	6	9106
40638	5	97931	1	27501
40639	3	97935	7	7444
40640	3	97939	4	37849
40641	5	97945	2	23552
40642	5	97946	6	22430
40643	5	97947	5	5947
40644	4	97949	7	26376
40645	5	97950	3	10567
40646	5	97952	5	31378
40647	4	97955	7	5861
40648	4	97956	2	10541
40649	4	97960	2	37981
40650	5	97963	4	37879
40651	5	97965	6	30182
40652	5	97967	4	38043
40653	4	97968	7	6055
40654	1	97969	6	34186
40655	5	97970	3	32918
40656	3	97976	4	38031
40657	5	97979	4	36075
40658	5	97980	6	37952
40659	5	97982	4	35115
40660	5	97987	7	14963
40661	1	97989	4	37918
40662	5	97990	3	34374
40663	3	97990	1	34374
40664	3	97991	7	38045
40665	4	97992	5	37861
40666	4	97993	5	861
40667	5	98004	7	21107
40668	4	98005	5	11317
40669	5	98006	6	38013
40670	4	98007	4	37906
40671	3	98010	3	7416
40672	4	98011	5	24444
40673	5	98012	5	8487
40674	5	98019	5	9230
40675	2	98020	1	18298
40676	5	98023	7	26527
40677	5	98024	2	33647
40678	5	98026	1	32687
40679	5	98027	1	4937
40680	5	98040	7	37943
40681	5	98042	5	2339
40682	4	98043	5	37268
40683	3	98047	1	15400
40684	5	98048	6	38053
40685	5	98052	5	37979
40686	5	98054	4	31906
40687	5	98058	6	38101
40688	5	98061	4	633
40689	5	98062	7	24948
40690	3	98067	7	8561
40691	4	98068	2	16010
40692	5	98069	2	10666
40693	4	98071	5	38073
40694	4	98082	3	37912
40695	5	98084	4	27574
40696	4	98088	7	678
40697	4	98090	2	31091
40698	3	98091	6	36668
40699	5	98092	2	38099
40700	5	98093	6	10814
40701	4	98095	5	37852
40702	5	98099	7	38087
40703	4	98100	1	37876
40704	5	98102	6	37936
40705	4	98103	5	31759
40706	2	98108	1	27142
40707	5	98110	5	18218
40708	4	98112	3	38068
40709	4	98114	7	14201
40710	5	98116	1	35493
40711	5	98117	6	8223
40712	2	98118	1	1143
40713	5	98119	6	24001
40714	3	98120	5	3548
40715	3	98120	1	3548
40716	4	98132	5	15909
40717	4	98132	1	15909
40718	3	98134	7	37929
40719	5	98135	2	38097
40720	5	98139	1	19868
40721	5	98140	6	3116
40722	3	98146	1	30002
40723	4	98148	1	21357
40724	3	98150	7	13596
40725	5	98151	6	37848
40726	5	98152	2	703
40727	5	98153	6	37977
40728	4	98156	7	37902
40729	4	98158	5	35930
40730	4	98159	7	24040
40731	5	98161	2	2536
40732	5	98164	4	37835
40733	4	98166	2	37962
40734	3	98167	4	5718
40735	5	98170	6	11387
40736	5	98174	4	34163
40737	4	98175	1	37896
40738	4	98176	3	37958
40739	3	98177	7	37881
40740	4	98178	3	24731
40741	4	98179	7	38030
40742	5	98179	5	38030
40743	2	98181	6	33636
40744	5	98182	7	37862
40745	4	98183	5	23356
40746	5	98184	2	8303
40747	3	98185	5	3169
40748	5	98186	6	12359
40749	5	98187	1	38095
40750	4	98190	4	10562
40751	4	98192	7	36590
40752	3	98193	2	23665
40753	5	98198	2	173
40754	5	98199	6	12151
40755	3	98200	4	37812
40756	4	98207	2	27256
40757	2	98209	1	33608
40758	5	98210	4	13885
40759	5	98212	1	9621
40760	5	98215	2	4120
40761	2	98216	6	2929
40762	5	98218	7	2065
40763	5	98219	7	37954
40764	5	98222	6	27106
40765	5	98228	6	38039
40766	4	98231	2	37904
40767	5	98234	7	19307
40768	4	98238	6	35517
40769	5	98239	2	28293
40770	4	98241	1	6007
40771	1	98242	5	31178
40772	4	98243	5	38025
40773	4	98244	3	21514
40774	3	98246	7	38086
40775	3	98247	5	4374
40776	5	98248	4	37878
40777	5	98249	6	14655
40778	4	98252	3	32819
40779	4	98253	5	3913
40780	5	98256	6	18202
40781	5	98261	2	37939
40782	3	98262	5	4595
40783	5	98264	6	37895
40784	4	98265	2	22192
40785	5	98267	5	38016
40786	5	98273	4	34969
40787	4	98274	4	25590
40788	5	98277	5	15540
40789	5	98283	6	19578
40790	3	98284	3	10479
40791	5	98290	6	8746
40792	3	98291	5	5979
40793	5	98292	1	27572
40794	5	98295	2	37882
40795	3	98296	5	38090
40796	5	98299	3	38251
40797	3	98301	1	38185
40798	5	98301	7	38185
40799	4	98303	5	4825
40800	5	98305	3	35998
40801	5	98307	6	38217
40802	4	98308	7	27447
40803	5	98312	4	38132
40804	5	98315	3	30762
40805	5	98319	4	38148
40806	5	98323	6	290
40807	4	98327	7	38167
40808	3	98328	4	10695
40809	2	98329	6	8893
40810	3	98335	7	38220
40811	5	98337	6	32785
40812	4	98338	6	22064
40813	5	98339	2	38129
40814	5	98343	6	5085
40815	3	98344	3	38174
40816	4	98347	5	34812
40817	3	98348	1	14061
40818	5	98349	6	20867
40819	3	98350	4	11237
40820	4	98352	7	38308
40821	4	98354	4	35456
40822	3	98355	4	32611
40823	5	98359	2	38136
40824	5	98362	5	13538
40825	5	98363	2	13987
40826	5	98375	6	5331
40827	5	98379	1	37625
40828	5	98382	1	38153
40829	3	98388	7	38213
40830	2	98389	3	38171
40831	5	98392	7	37012
40832	3	98395	2	17209
40833	5	98396	6	38263
40834	3	98397	7	20711
40835	5	98402	4	38261
40836	5	98405	6	38267
40837	5	98406	6	38346
40838	3	98407	6	21817
40839	3	98411	5	38197
40840	5	98416	7	17514
40841	3	98417	7	27348
40842	5	98418	2	15114
40843	2	98422	1	36361
40844	4	98422	5	36361
40845	5	98423	6	38285
40846	5	98424	2	1706
40847	5	98425	7	11089
40848	5	98426	3	28896
40849	4	98428	7	16421
40850	4	98429	5	38190
40851	5	98430	2	12367
40852	5	98431	5	38128
40853	1	98432	6	22015
40854	5	98433	2	35161
40855	4	98433	5	35161
40856	5	98434	2	38315
40857	4	98436	7	15902
40858	5	98437	4	21633
40859	5	98440	6	7476
40860	4	98443	7	4023
40861	5	98448	4	4659
40862	3	98451	7	3506
40863	5	98452	2	27551
40864	5	98453	3	38211
40865	4	98455	1	38240
40866	4	98460	5	38144
40867	5	98462	3	17003
40868	5	98463	2	32594
40869	5	98464	7	38205
40870	3	98465	7	15437
40871	1	98466	4	38223
40872	5	98467	4	24965
40873	5	98472	6	26130
40874	4	98477	7	38115
40875	3	98478	3	3403
40876	5	98483	7	38201
40877	4	98484	7	38111
40878	3	98488	5	38329
40879	5	98490	6	38112
40880	5	98494	3	19212
40881	4	98496	6	28570
40882	5	98499	6	321
40883	5	98503	6	9459
40884	5	98504	3	8050
40885	5	98509	7	14990
40886	5	98511	4	18202
40887	5	98518	2	17790
40888	5	98519	2	38237
40889	5	98520	2	38200
40890	5	98524	1	26444
40891	4	98525	7	207
40892	5	98527	6	6358
40893	3	98528	4	4960
40894	5	98529	2	3271
40895	5	98530	1	709
40896	1	98531	6	26577
40897	3	98531	5	26577
40898	4	98534	2	38137
40899	4	98536	4	5338
40900	4	98539	4	32844
40901	3	98541	7	38035
40902	4	98549	6	38126
40903	5	98549	3	38126
40904	5	98550	4	26855
40905	3	98551	6	38195
40906	5	98555	7	38305
40907	5	98557	6	38277
40908	5	98559	5	38326
40909	3	98566	1	38155
40910	3	98567	6	38340
40911	4	98570	7	38338
40912	5	98572	1	31151
40913	5	98572	6	31151
40914	5	98573	3	38202
40915	5	98576	3	38125
40916	2	98576	6	38125
40917	1	98580	4	189
40918	5	98583	7	26905
40919	4	98587	2	264
40920	5	98589	6	38282
40921	5	98592	2	22626
40922	3	98594	4	21109
40923	4	98594	2	21109
40924	5	98595	2	38278
40925	5	98596	7	602
40926	4	98597	1	37920
40927	5	98597	5	37920
40928	5	98611	2	10153
40929	5	98612	4	22357
40930	4	98613	6	2561
40931	1	98614	3	4868
40932	3	98616	5	35285
40933	3	98617	5	17174
40934	4	98618	3	3418
40935	5	98627	6	38313
40936	3	98628	3	24697
40937	3	98629	5	8215
40938	4	98633	5	36922
40939	5	98636	7	16250
40940	5	98640	2	38157
40941	3	98641	3	32581
40942	5	98642	5	1819
40943	5	98643	6	17078
40944	5	98643	2	17078
40945	5	98645	4	14838
40946	5	98652	7	24882
40947	4	98655	5	2282
40948	5	98656	4	38199
40949	4	98657	4	15190
40950	5	98658	5	7144
40951	1	98662	5	8500
40952	5	98663	6	38322
40953	3	98665	5	33230
40954	5	98666	7	25124
40955	4	98669	4	5834
40956	5	98671	7	31323
40957	5	98673	3	38348
40958	5	98675	2	38140
40959	5	98676	3	31763
40960	3	98680	7	23735
40961	3	98683	7	15105
40962	5	98684	4	223
40963	5	98686	4	38225
40964	5	98687	7	15578
40965	5	98689	1	36788
40966	4	98690	6	32603
40967	5	98692	2	38311
40968	3	98693	5	27758
40969	5	98701	5	36435
40970	5	98702	7	38276
40971	4	98708	2	35315
40972	3	98711	2	10374
40973	4	98712	7	9014
40974	5	98719	6	38169
40975	5	98721	2	19034
40976	5	98723	3	14320
40977	4	98724	5	38206
40978	4	98724	7	38206
40979	4	98728	1	20988
40980	5	98729	2	2070
40981	5	98731	4	8365
40982	3	98732	5	27183
40983	4	98734	2	35512
40984	5	98734	4	35512
40985	3	98741	5	14662
40986	5	98742	3	20199
40987	5	98744	2	38219
40988	5	98746	6	13256
40989	5	98751	2	30607
40990	5	98752	7	38135
40991	5	98753	7	38266
40992	5	98754	7	12623
40993	5	98755	6	12450
40994	5	98756	4	38194
40995	4	98757	1	38113
40996	5	98758	3	38252
40997	3	98760	4	29
40998	2	98761	3	29470
40999	5	98763	7	38152
41000	5	98764	7	9844
41001	3	98765	1	27538
41002	4	98767	6	15063
41003	3	98768	3	25212
41004	3	98775	3	38122
41005	3	98777	5	38178
41006	4	98787	6	38151
41007	5	98788	2	37759
41008	4	98790	5	38242
41009	4	98792	5	17169
41010	3	98793	4	10001
41011	4	98795	4	33530
41012	3	98802	3	15776
41013	4	98803	7	9599
41014	5	98806	3	743
41015	4	98807	2	38218
41016	3	98809	4	21386
41017	5	98810	2	4943
41018	4	98810	3	4943
41019	3	98812	3	27990
41020	5	98815	6	38161
41021	3	98821	5	38309
41022	5	98822	6	26951
41023	5	98823	6	38216
41024	4	98823	7	38216
41025	5	98824	2	5858
41026	3	98827	5	38275
41027	3	98829	1	38335
41028	3	98832	7	9088
41029	4	98836	7	17988
41030	3	98838	7	9865
41031	5	98839	7	7207
41032	5	98844	5	8358
41033	1	98847	4	19052
41034	5	98848	7	38228
41035	5	98849	1	669
41036	5	98850	6	33974
41037	4	98853	3	38210
41038	4	98854	7	37612
41039	5	98856	2	21257
41040	5	98857	4	38184
41041	5	98858	2	1937
41042	5	98859	2	21685
41043	4	98864	6	17045
41044	4	98867	7	2931
41045	4	98870	6	10661
41046	4	98871	2	7292
41047	5	98871	3	7292
41048	5	98872	6	13061
41049	5	98874	3	1988
41050	3	98876	1	20211
41051	3	98877	1	37446
41052	5	98878	1	8286
41053	3	98880	1	24100
41054	5	98882	2	18096
41055	5	98884	7	21267
41056	4	98886	1	22259
41057	1	98889	6	28053
41058	4	98890	1	33997
41059	3	98890	5	33997
41060	3	98895	6	33211
41061	3	98897	5	21461
41062	1	98898	6	23551
41063	4	98899	7	16541
41064	5	98901	6	38143
41065	5	98901	2	38143
41066	5	98905	5	38130
41067	5	98907	5	23253
41068	5	98909	7	19312
41069	3	98912	1	37761
41070	2	98913	4	23378
41071	5	98920	3	6948
41072	5	98926	4	38232
41073	4	98927	3	30609
41074	1	98928	6	38209
41075	5	98937	4	10495
41076	3	98942	7	14057
41077	4	98946	6	28320
41078	5	98951	2	5597
41079	5	98952	2	29689
41080	5	98952	6	29689
41081	5	98954	4	38231
41082	4	98958	2	38295
41083	3	98962	7	32792
41084	3	98963	2	38307
41085	5	98964	7	38323
41086	4	98966	3	2310
41087	1	98968	6	33716
41088	5	98970	2	17138
41089	4	98974	2	34003
41090	5	98974	6	34003
41091	5	98975	4	31743
41092	5	98977	4	27051
41093	4	98984	1	22476
41094	5	98985	2	35335
41095	5	98986	4	3765
41096	5	98987	6	38318
41097	4	98988	2	7764
41098	3	98990	3	5758
41099	5	98993	6	29754
41100	4	98994	6	38260
41101	3	98995	5	32268
41102	5	99002	2	20138
41103	4	99003	7	26021
41104	5	99005	3	16426
41105	5	99007	6	2432
41106	5	99009	1	27545
41107	5	99010	6	3444
41108	5	99014	5	38165
41109	4	99015	4	38191
41110	2	99016	4	15456
41111	4	99023	7	36704
41112	3	99025	2	33480
41113	4	99025	5	33480
41114	3	99028	6	38173
41115	3	99031	5	22296
41116	5	99032	4	16170
41117	4	99034	2	38300
41118	5	99035	4	38269
41119	5	99037	7	15549
41120	3	99038	4	38253
41121	5	99039	1	15899
41122	5	99041	7	38265
41123	4	99045	1	581
41124	5	99050	6	38230
41125	5	99052	2	38256
41126	5	99057	6	38314
41127	5	99059	3	37273
41128	5	99062	1	38331
41129	3	99063	5	28465
41130	4	99065	2	38139
41131	5	99070	6	24251
41132	5	99072	2	27618
41133	5	99074	5	8503
41134	5	99076	5	1081
41135	5	99077	6	38317
41136	5	99078	2	38245
41137	5	99079	1	12662
41138	4	99085	3	22830
41139	5	99085	2	22830
41140	5	99086	6	35411
41141	4	99093	3	34882
41142	5	99095	6	38357
41143	4	99099	6	22505
41144	3	99103	5	38374
41145	5	99104	4	27076
41146	5	99106	7	1406
41147	3	99109	5	38383
41148	5	99110	4	16039
41149	3	99111	5	4400
41150	4	99114	7	22935
41151	3	99116	4	575
41152	5	99117	6	30099
41153	4	99120	3	11428
41154	4	99122	1	25839
41155	4	99125	1	29254
41156	2	99127	5	38541
41157	4	99130	3	38497
41158	5	99132	1	20789
41159	5	99135	7	34544
41160	3	99137	1	30117
41161	5	99138	7	36316
41162	5	99139	6	26273
41163	3	99141	3	38459
41164	4	99144	7	38548
41165	4	99145	5	30777
41166	5	99146	1	38501
41167	4	99147	5	21979
41168	5	99148	7	1582
41169	1	99152	6	38358
41170	3	99155	2	38351
41171	5	99155	6	38351
41172	5	99156	2	36888
41173	5	99157	4	29483
41174	5	99158	2	7253
41175	5	99159	1	30935
41176	5	99162	6	24397
41177	3	99171	5	38545
41178	5	99172	3	38539
41179	5	99173	2	16627
41180	5	99174	2	9836
41181	5	99176	1	23794
41182	3	99177	6	32604
41183	4	99178	7	18826
41184	4	99180	1	33531
41185	5	99183	7	38463
41186	5	99186	6	27686
41187	4	99186	1	27686
41188	5	99188	7	33979
41189	5	99190	4	27556
41190	3	99190	6	27556
41191	4	99195	7	29983
41192	3	99197	1	11787
41193	4	99201	7	14222
41194	4	99204	6	11488
41195	3	99205	5	17579
41196	5	99206	7	18894
41197	5	99207	6	8628
41198	5	99211	2	38427
41199	5	99217	1	17850
41200	5	99217	6	17850
41201	3	99218	4	38510
41202	3	99221	5	28456
41203	5	99223	7	26921
41204	5	99225	6	38511
41205	5	99226	4	38421
41206	5	99227	3	1322
41207	5	99228	5	20968
41208	5	99229	6	27187
41209	4	99230	1	38354
41210	5	99235	3	806
41211	4	99236	7	38435
41212	5	99241	4	1168
41213	5	99243	6	7814
41214	1	99248	6	19164
41215	5	99250	4	35937
41216	4	99252	5	11572
41217	5	99256	6	38436
41218	4	99256	4	38436
41219	3	99257	7	33528
41220	5	99258	2	2874
41221	3	99260	7	38525
41222	5	99262	7	13028
41223	5	99263	3	18791
41224	3	99264	4	5350
41225	5	99267	7	32999
41226	5	99268	4	38406
41227	5	99269	6	18860
41228	5	99270	7	440
41229	5	99271	2	32828
41230	5	99272	6	1299
41231	4	99272	4	1299
41232	5	99273	2	11867
41233	4	99277	5	5699
41234	5	99281	7	16420
41235	4	99284	7	25496
41236	1	99287	6	38475
41237	5	99288	2	11676
41238	5	99292	6	38496
41239	4	99294	5	38426
41240	3	99295	4	33126
41241	4	99298	2	38439
41242	5	99299	2	38445
41243	5	99301	3	12735
41244	5	99302	6	36812
41245	5	99309	4	3636
41246	4	99310	1	37355
41247	5	99311	3	27060
41248	5	99312	1	9365
41249	5	99314	6	38544
41250	5	99315	2	38540
41251	3	99315	7	38540
41252	4	99318	6	37486
41253	5	99319	4	38405
41254	3	99320	7	34525
41255	4	99321	7	38009
41256	5	99323	2	1074
41257	3	99330	7	16750
41258	5	99331	1	12593
41259	5	99332	3	38119
41260	2	99340	2	4578
41261	5	99342	7	27246
41262	5	99343	5	23083
41263	5	99345	5	9821
41264	5	99347	6	37799
41265	5	99349	5	17161
41266	3	99356	5	20617
41267	5	99358	5	32054
41268	5	99360	6	38504
41269	3	99362	7	18490
41270	4	99367	2	16528
41271	5	99369	3	1143
41272	4	99370	6	19031
41273	5	99374	6	17721
41274	5	99377	4	14702
41275	5	99380	6	38479
41276	5	99383	2	9053
41277	5	99384	6	24336
41278	5	99388	5	5303
41279	4	99393	7	27283
41280	5	99394	5	35390
41281	5	99395	5	19718
41282	5	99402	4	38432
41283	5	99406	6	38562
41284	5	99408	7	22797
41285	5	99412	6	5201
41286	4	99414	4	1435
41287	4	99418	1	20792
41288	3	99419	5	38413
41289	4	99420	7	32184
41290	4	99427	7	26416
41291	5	99428	6	18234
41292	4	99428	5	18234
41293	5	99430	1	7244
41294	5	99439	7	38355
41295	5	99441	7	37456
41296	3	99443	4	11262
41297	4	99445	4	16758
41298	1	99446	2	22952
41299	5	99448	2	34019
41300	4	99449	4	16228
41301	5	99451	2	10530
41302	5	99452	2	38454
41303	5	99455	1	32455
41304	5	99457	4	3702
41305	4	99459	6	16152
41306	5	99462	5	38377
41307	5	99463	6	32002
41308	3	99468	1	17916
41309	5	99472	6	14735
41310	4	99473	5	35061
41311	5	99474	6	38499
41312	4	99475	4	38547
41313	5	99476	4	36089
41314	4	99481	5	28357
41315	3	99482	2	13497
41316	5	99483	3	18840
41317	3	99486	7	14480
41318	3	99489	5	38462
41319	4	99490	7	32894
41320	5	99492	7	24882
41321	5	99494	6	34551
41322	5	99496	1	14239
41323	4	99498	3	38556
41324	5	99499	2	27730
41325	5	99501	4	27808
41326	4	99502	2	12857
41327	5	99505	5	1645
41328	4	99508	6	13930
41329	4	99509	7	38529
41330	4	99512	3	13182
41331	4	99514	7	38272
41332	3	99517	5	27575
41333	5	99523	3	38455
41334	3	99525	5	38400
41335	3	99527	5	14795
41336	5	99527	7	14795
41337	3	99530	5	15208
41338	5	99535	4	23931
41339	3	99537	7	7431
41340	3	99539	7	32317
41341	5	99541	7	38508
41342	4	99544	7	38415
41343	5	99546	2	38481
41344	4	99547	1	32178
41345	5	99549	3	997
41346	5	99550	4	34918
41347	5	99551	2	38554
41348	5	99553	6	4828
41349	5	99554	1	20845
41350	2	99556	1	38428
41351	4	99557	3	30695
41352	5	99561	7	19767
41353	5	99563	7	27785
41354	5	99563	1	27785
41355	3	99565	7	30477
41356	3	99565	5	30477
41357	5	99566	4	35131
41358	5	99571	6	38408
41359	4	99573	2	27925
41360	4	99577	7	38285
41361	3	99579	4	38389
41362	5	99580	6	786
41363	1	99582	4	38407
41364	5	99585	4	8713
41365	5	99586	7	38546
41366	5	99589	1	7232
41367	5	99593	2	10950
41368	3	99598	1	38451
41369	5	99599	5	38430
41370	5	99601	4	13642
41371	5	99604	7	8546
41372	5	99608	2	18180
41373	5	99609	6	15671
41374	4	99610	5	26140
41375	5	99611	5	20781
41376	5	99612	7	38396
41377	4	99614	5	38393
41378	5	99616	6	38471
41379	5	99618	4	38495
41380	4	99619	1	10038
41381	5	99621	5	2615
41382	3	99623	5	26594
41383	2	99624	4	38493
41384	5	99628	2	33495
41385	1	99629	6	26614
41386	5	99630	4	1809
41387	5	99631	4	28377
41388	5	99633	5	10692
41389	5	99634	1	37801
41390	4	99635	1	38561
41391	4	99639	3	38472
41392	3	99642	7	19228
41393	4	99646	7	38381
41394	5	99650	6	23350
41395	3	99651	4	16426
41396	4	99655	7	38390
41397	5	99656	3	33949
41398	5	99657	4	16091
41399	5	99660	1	38414
41400	4	99663	7	6651
41401	1	99668	2	38456
41402	4	99671	2	11455
41403	2	99673	4	10667
41404	5	99674	5	38512
41405	5	99674	3	38512
41406	3	99675	2	36344
41407	2	99676	1	5047
41408	2	99677	4	36682
41409	5	99678	4	38523
41410	4	99678	7	38523
41411	4	99681	7	29263
41412	3	99682	6	38470
41413	5	99684	4	19356
41414	4	99685	7	29856
41415	5	99687	3	12338
41416	4	99688	6	18746
41417	4	99689	2	15035
41418	4	99692	5	16197
41419	4	99694	1	38419
41420	5	99697	7	38552
41421	5	99698	4	21021
41422	5	99700	3	9088
41423	3	99702	7	3002
41424	4	99705	2	19729
41425	4	99708	7	27908
41426	5	99714	6	13187
41427	5	99716	6	20836
41428	4	99724	5	5075
41429	5	99726	6	38550
41430	3	99727	2	7841
41431	5	99729	7	38425
41432	5	99730	6	10255
41433	5	99731	4	2651
41434	2	99736	2	27769
41435	3	99738	3	22511
41436	4	99739	7	7277
41437	5	99740	3	17056
41438	5	99741	5	38542
41439	5	99741	1	38542
41440	5	99743	2	28644
41441	5	99743	6	28644
41442	5	99745	1	31937
41443	4	99748	7	32450
41444	3	99749	3	38367
41445	4	99752	5	38549
41446	5	99758	3	30407
41447	4	99759	5	27803
41448	3	99764	1	36801
41449	3	99766	5	38531
41450	5	99768	6	38447
41451	5	99769	7	281
41452	3	99779	7	38507
41453	3	99780	4	29226
41454	4	99781	4	4498
41455	4	99784	6	38528
41456	5	99785	2	38543
41457	5	99789	2	11046
41458	5	99789	7	11046
41459	5	99791	4	38488
41460	3	99794	1	4652
41461	5	99806	3	4223
41462	4	99807	5	35474
41463	4	99813	7	8337
41464	3	99823	6	352
41465	4	99824	7	21310
41466	5	99828	6	38460
41467	4	99832	3	3173
41468	4	99833	2	38535
41469	5	99834	6	5763
41470	5	99837	3	11764
41471	5	99838	6	38446
41472	5	99841	5	16217
41473	5	99842	5	7007
41474	5	99843	5	20114
41475	5	99845	1	31836
41476	5	99852	7	19971
41477	3	99853	7	38371
41478	5	99854	2	7731
41479	4	99855	6	38388
41480	2	99857	6	29421
41481	5	99861	6	15815
41482	5	99869	4	10580
41483	5	99871	6	18174
41484	5	99871	2	18174
41485	5	99872	1	17245
41486	5	99874	2	4445
41487	5	99875	4	38434
41488	4	99876	1	12437
41489	1	99877	6	14121
41490	5	99880	2	38474
41491	4	99881	7	32488
41492	5	99882	6	21690
41493	1	99883	6	23709
41494	3	99885	7	30284
41495	5	99888	3	17528
41496	2	99889	3	3540
41497	5	99891	6	15614
41498	5	99892	3	4465
41499	5	99893	6	16984
41500	5	99896	6	38553
41501	3	99898	2	7064
41502	5	99901	7	12452
41503	5	99902	2	38441
41504	5	99906	4	38384
41505	5	99907	7	35870
41506	5	99910	2	3883
41507	2	99911	5	38353
41508	5	99912	5	5975
41509	5	99918	6	38516
41510	5	99919	2	2946
41511	5	99922	5	28006
41512	5	99923	1	38385
41513	3	99925	7	38350
41514	5	99928	1	22688
41515	5	99929	1	38480
41516	5	99932	2	1722
41517	4	99937	5	29394
41518	5	99942	2	38365
41519	3	99943	2	32144
41520	5	99944	7	15360
41521	5	99946	3	38443
41522	5	99947	6	28879
41523	3	99951	6	32119
41524	5	99957	2	25064
41525	5	99959	4	10293
41526	5	99962	4	38113
41527	5	99963	6	38387
41528	5	99964	5	38424
41529	5	99967	4	25780
41530	5	99971	1	38453
41531	3	99972	6	344
41532	4	99977	4	2110
41533	5	99980	6	18494
41534	3	99982	6	16434
41535	5	99985	2	13082
41536	5	99986	1	38667
41537	3	99987	7	17378
41538	5	99989	1	2946
41539	3	99991	7	38725
41540	4	99992	5	35812
41541	3	99994	5	38653
41542	5	99995	1	964
41543	5	100002	5	28098
41544	5	100003	7	38251
41545	5	100004	4	28978
41546	5	100005	2	27936
41547	5	100010	2	38738
41548	1	100011	7	18902
41549	3	100016	1	21216
41550	5	100017	6	38690
41551	3	100018	7	38724
41552	5	100023	7	5648
41553	4	100024	7	38691
41554	1	100026	6	14081
41555	5	100028	4	38620
41556	5	100029	2	37761
41557	4	100033	5	38707
41558	5	100034	2	38637
41559	1	100035	6	14756
41560	4	100037	7	28137
41561	5	100047	1	31760
41562	5	100048	6	24130
41563	4	100051	3	14770
41564	5	100051	7	14770
41565	4	100053	7	38747
41566	5	100054	3	38567
41567	3	100055	7	21825
41568	5	100058	3	38663
41569	4	100059	2	36465
41570	5	100060	3	8877
41571	5	100061	6	31015
41572	5	100063	6	38698
41573	5	100065	6	27124
41574	5	100067	7	37851
41575	5	100068	1	15892
41576	5	100071	4	12425
41577	5	100072	6	2648
41578	5	100075	3	38742
41579	4	100079	7	10692
41580	5	100082	5	38670
41581	5	100083	5	16943
41582	5	100084	4	17362
41583	5	100087	4	6023
41584	3	100088	1	38706
41585	5	100091	2	7968
41586	3	100094	5	16225
41587	5	100095	4	2735
41588	5	100101	1	38717
41589	1	100106	6	38635
41590	5	100108	2	12508
41591	5	100110	5	16450
41592	4	100111	5	22564
41593	4	100111	1	22564
41594	3	100112	7	7098
41595	5	100116	7	38576
41596	5	100117	7	29154
41597	5	100119	4	16228
41598	1	100121	7	23761
41599	5	100125	2	9640
41600	5	100126	6	16121
41601	4	100128	5	22167
41602	4	100131	2	38674
41603	1	100133	6	7760
41604	3	100137	5	38723
41605	3	100137	7	38723
41606	4	100138	2	33560
41607	3	100140	7	38630
41608	5	100142	3	25606
41609	4	100144	4	31995
41610	4	100145	2	30163
41611	4	100147	6	35105
41612	5	100148	2	38728
41613	5	100149	4	8141
41614	5	100153	7	26994
41615	4	100155	3	38577
41616	4	100158	4	38568
41617	3	100158	7	38568
41618	4	100160	6	33421
41619	5	100162	2	4260
41620	5	100167	7	38598
41621	3	100171	5	38592
41622	5	100176	4	27306
41623	5	100177	7	23257
41624	3	100179	2	4794
41625	4	100180	3	568
41626	4	100183	7	3426
41627	5	100185	6	38648
41628	5	100188	2	10480
41629	4	100192	6	12865
41630	5	100197	4	38727
41631	4	100200	6	38696
41632	4	100205	5	38748
41633	5	100205	6	38748
41634	2	100206	1	1918
41635	3	100207	1	38609
41636	5	100210	3	34812
41637	4	100214	4	3839
41638	5	100215	4	4935
41639	5	100219	6	38655
41640	3	100220	5	21064
41641	4	100223	7	36025
41642	5	100228	6	15508
41643	4	100228	1	15508
41644	5	100231	2	38654
41645	4	100232	2	1269
41646	5	100233	5	21493
41647	4	100235	7	21765
41648	1	100236	4	38578
41649	3	100236	5	38578
41650	1	100239	6	5248
41651	5	100240	7	5513
41652	3	100241	5	38589
41653	4	100242	1	38602
41654	5	100245	2	38292
41655	5	100245	7	38292
41656	3	100248	6	17674
41657	5	100249	1	21121
41658	4	100252	6	31477
41659	3	100252	3	31477
41660	5	100257	4	38649
41661	5	100259	7	22568
41662	4	100261	6	38664
41663	5	100262	6	37539
41664	3	100264	5	30334
41665	5	100266	3	11580
41666	5	100267	6	14779
41667	5	100268	2	38628
41668	5	100271	6	11138
41669	5	100271	3	11138
41670	3	100277	7	38585
41671	5	100278	7	4912
41672	5	100280	2	38736
41673	4	100282	4	38750
41674	5	100288	6	18137
41675	4	100294	7	38622
41676	5	100299	4	34596
41677	3	100300	3	38621
41678	5	100300	2	38621
41679	3	100301	5	13000
41680	4	100302	3	2269
41681	4	100306	2	38732
41682	4	100309	6	38682
41683	4	100311	1	38694
41684	3	100312	1	5629
41685	2	100313	3	38702
41686	4	100313	5	38702
41687	5	100314	6	31347
41688	4	100316	7	23946
41689	4	100317	4	38103
41690	5	100320	5	30229
41691	3	100321	3	1799
41692	5	100323	6	13767
41693	5	100325	2	38619
41694	2	100326	4	1383
41695	4	100327	6	33353
41696	3	100330	5	3212
41697	5	100335	6	21295
41698	5	100338	2	38705
41699	5	100339	5	27344
41700	5	100340	6	32767
41701	4	100342	4	8283
41702	5	100347	3	16792
41703	4	100350	1	5238
41704	4	100351	3	32900
41705	5	100352	6	28472
41706	4	100353	6	38737
41707	2	100354	3	38597
41708	5	100360	6	24069
41709	5	100361	2	33813
41710	5	100364	3	38657
41711	5	100365	2	38581
41712	5	100366	3	13982
41713	4	100371	5	38639
41714	4	100372	7	38633
41715	5	100374	2	30227
41716	4	100374	7	30227
41717	4	100375	4	12020
41718	4	100376	2	38638
41719	3	100381	4	38729
41720	5	100382	6	19020
41721	5	100383	2	38716
41722	3	100384	6	9132
41723	3	100388	5	5135
41724	5	100389	2	17505
41725	5	100391	6	35135
41726	3	100396	2	38968
41727	1	100397	2	24630
41728	5	100398	3	2710
41729	5	100404	2	4060
41730	3	100406	5	5093
41731	4	100409	6	38845
41732	5	100412	4	14667
41733	5	100412	2	14667
41734	5	100413	1	38964
41735	3	100416	4	29663
41736	5	100417	4	11671
41737	4	100419	7	38801
41738	2	100419	6	38801
41739	4	100420	2	37555
41740	4	100421	7	37055
41741	5	100423	7	4975
41742	4	100425	7	38822
41743	5	100436	7	6811
41744	3	100440	7	92
41745	5	100441	7	22337
41746	3	100442	7	23785
41747	3	100443	6	13248
41748	3	100444	5	28173
41749	4	100445	4	38755
41750	4	100448	3	20338
41751	5	100449	4	2880
41752	5	100450	5	38989
41753	3	100453	5	26827
41754	5	100454	1	25506
41755	3	100457	4	38885
41756	3	100458	7	16767
41757	5	100461	4	5183
41758	4	100464	6	38912
41759	5	100466	4	12188
41760	5	100467	4	23863
41761	5	100469	1	38776
41762	5	100472	7	28375
41763	4	100477	5	38842
41764	5	100478	6	33593
41765	3	100479	4	35806
41766	2	100480	3	3314
41767	3	100482	1	38780
41768	3	100483	6	25952
41769	3	100485	5	38916
41770	5	100487	2	32256
41771	4	100492	2	38757
41772	3	100496	2	38858
41773	5	100497	4	8750
41774	5	100500	1	7459
41775	3	100501	7	38907
41776	3	100502	7	37641
41777	5	100502	1	37641
41778	5	100503	1	6591
41779	5	100511	6	18923
41780	1	100513	6	38866
41781	3	100517	4	38873
41782	1	100518	6	38965
41783	4	100519	1	22212
41784	5	100522	6	3109
41785	2	100524	1	10281
41786	4	100528	7	30472
41787	5	100530	6	3106
41788	4	100530	2	3106
41789	3	100534	6	20553
41790	4	100535	2	4655
41791	5	100537	6	26473
41792	4	100537	7	26473
41793	5	100540	7	38949
41794	5	100542	2	9379
41795	3	100543	5	33900
41796	4	100546	1	38788
41797	5	100547	1	2443
41798	5	100548	3	38879
41799	5	100550	3	38802
41800	5	100554	6	932
41801	5	100555	1	5410
41802	5	100562	6	21024
41803	3	100564	5	38850
41804	5	100564	3	38850
41805	5	100565	5	36819
41806	4	100566	6	36458
41807	3	100569	7	10458
41808	5	100570	4	28652
41809	3	100572	1	38936
41810	3	100575	3	38785
41811	5	100575	4	38785
41812	5	100578	5	32506
41813	5	100579	4	7110
41814	5	100581	7	38895
41815	5	100582	2	29754
41816	5	100583	2	38778
41817	5	100587	2	38974
41818	3	100588	7	25876
41819	4	100591	5	3115
41820	5	100592	6	13444
41821	5	100593	7	38869
41822	5	100597	2	38763
41823	5	100597	6	38763
41824	4	100602	5	14606
41825	5	100603	3	36097
41826	5	100608	1	10630
41827	5	100609	5	38898
41828	5	100609	4	38898
41829	3	100614	2	38939
41830	5	100615	1	1564
41831	5	100618	3	5257
41832	5	100622	2	38948
41833	2	100626	6	38794
41834	5	100630	6	14710
41835	5	100634	6	38899
41836	3	100635	7	13507
41837	4	100636	7	30484
41838	5	100641	7	38976
41839	5	100642	4	38646
41840	5	100643	2	31165
41841	4	100645	3	33119
41842	5	100647	6	3250
41843	4	100648	5	38887
41844	4	100653	7	38819
41845	3	100655	3	38810
41846	4	100658	5	2549
41847	5	100662	2	225
41848	3	100663	6	6880
41849	5	100667	1	18922
41850	5	100671	3	19798
41851	5	100672	7	32204
41852	5	100674	6	36045
41853	4	100674	3	36045
41854	4	100677	3	38813
41855	5	100678	1	8900
41856	5	100679	6	38941
41857	5	100682	6	26112
41858	5	100686	5	33813
41859	4	100688	2	38827
41860	5	100689	2	35581
41861	1	100690	6	30722
41862	5	100697	3	15127
41863	5	100698	4	8397
41864	4	100702	6	38792
41865	4	100703	2	13471
41866	5	100704	1	24694
41867	5	100709	4	10558
41868	5	100713	6	30753
41869	3	100714	5	7261
41870	5	100715	2	38851
41871	5	100718	5	33100
41872	5	100720	2	506
41873	1	100723	6	38891
41874	4	100725	6	7299
41875	4	100728	7	38892
41876	5	100729	6	25658
41877	5	100730	5	38839
41878	4	100733	5	38761
41879	5	100734	4	26767
41880	3	100734	5	26767
41881	2	100735	4	36990
41882	5	100738	4	17196
41883	5	100739	4	38790
41884	5	100740	3	26087
41885	5	100745	5	38860
41886	5	100746	7	38781
41887	5	100748	2	38913
41888	5	100752	6	30169
41889	5	100755	2	23777
41890	5	100756	5	9319
41891	5	100759	5	11006
41892	4	100761	6	38874
41893	3	100764	7	16337
41894	5	100772	6	11995
41895	4	100774	1	10806
41896	4	100776	4	6429
41897	5	100781	2	38820
41898	4	100782	6	24141
41899	5	100782	7	24141
41900	5	100787	7	38774
41901	5	100788	3	38764
41902	5	100789	4	15684
41903	4	100791	4	38972
41904	4	100791	2	38972
41905	3	100794	5	16462
41906	5	100796	7	38856
41907	3	100800	7	260
41908	5	100801	2	12938
41909	4	100802	3	11470
41910	5	100806	6	18687
41911	5	100807	6	9089
41912	5	100810	5	9464
41913	5	100812	6	13313
41914	3	100821	3	38878
41915	2	100822	6	4592
41916	5	100823	6	5596
41917	1	100824	4	38846
41918	5	100825	2	7958
41919	3	100827	7	20225
41920	5	100828	4	30790
41921	4	100830	1	38903
41922	3	100831	7	14954
41923	5	100832	1	609
41924	3	100838	1	15326
41925	3	100840	5	38992
41926	5	100842	4	31159
41927	4	100846	7	38779
41928	4	100848	3	19698
41929	1	100851	4	34670
41930	5	100853	4	38817
41931	5	100854	2	18085
41932	5	100856	4	38848
41933	4	100860	2	35265
41934	5	100861	7	15614
41935	5	100862	2	14531
41936	5	100864	3	38966
41937	5	100867	2	38830
41938	3	100871	1	38829
41939	4	100874	4	38777
41940	5	100879	3	34431
41941	5	100887	1	38815
41942	5	100888	7	38098
41943	3	100891	4	38880
41944	5	100895	1	31899
41945	3	100896	3	38905
41946	5	100897	3	38884
41947	4	100898	2	38811
41948	4	100901	7	36455
41949	4	100902	2	11515
41950	3	100903	2	16738
41951	5	100905	2	37387
41952	4	100908	5	10666
41953	5	100917	6	9011
41954	5	100919	6	8586
41955	5	100920	4	1148
41956	5	100924	5	28288
41957	4	100927	5	38943
41958	5	100929	6	26613
41959	4	100932	3	31857
41960	5	100933	4	25513
41961	5	100938	3	6600
41962	2	100940	6	23665
41963	5	100942	4	39160
41964	5	100943	7	39167
41965	5	100944	6	31359
41966	4	100945	4	39086
41967	3	100948	4	36471
41968	4	100949	2	39214
41969	5	100950	4	39081
41970	4	100952	6	24767
41971	5	100954	3	27999
41972	4	100963	3	19011
41973	5	100964	6	39146
41974	5	100966	1	27565
41975	4	100969	4	39026
41976	5	100971	6	39035
41977	3	100972	5	9139
41978	5	100973	6	9319
41979	4	100974	2	24422
41980	5	100976	6	16620
41981	5	100977	7	39052
41982	5	100978	7	39051
41983	4	100983	7	14808
41984	4	100985	7	3711
41985	2	100986	4	39107
41986	3	100987	4	35489
41987	4	100989	1	35740
41988	4	100991	2	11435
41989	5	100992	4	39237
41990	5	100994	7	39006
41991	5	100995	5	36839
41992	4	100996	7	39147
41993	2	100998	2	16831
41994	5	101001	5	39217
41995	5	101002	4	39009
41996	5	101005	5	8584
41997	5	101007	3	39013
41998	5	101008	6	7772
41999	5	101012	3	2885
42000	3	101013	3	26966
42001	3	101014	5	1889
42002	5	101017	4	24166
42003	5	101018	2	39200
42004	4	101020	3	39075
42005	3	101023	2	34760
42006	3	101024	1	39157
42007	1	101030	6	39203
42008	1	101031	5	39038
42009	4	101032	1	15456
42010	5	101034	4	6810
42011	5	101037	2	11411
42012	4	101038	7	1498
42013	5	101039	2	39097
42014	4	101040	6	39165
42015	5	101042	6	39123
42016	5	101056	5	35106
42017	4	101057	4	35872
42018	5	101058	3	371
42019	5	101061	1	22711
42020	4	101063	7	39069
42021	4	101066	1	39067
42022	5	101068	1	27615
42023	5	101071	6	39083
42024	5	101072	4	5180
42025	5	101079	2	34140
42026	4	101081	4	20792
42027	5	101092	6	4622
42028	3	101096	5	3754
42029	5	101097	4	15864
42030	5	101098	6	33225
42031	5	101100	1	5262
42032	5	101101	4	29001
42033	3	101102	4	32487
42034	3	101104	2	20869
42035	5	101106	4	39062
42036	5	101108	5	15082
42037	4	101110	3	39179
42038	5	101112	2	39103
42039	4	101114	7	34106
42040	3	101117	3	39104
42041	2	101119	5	19342
42042	5	101120	5	3420
42043	5	101122	2	39054
42044	5	101123	6	39151
42045	4	101124	7	17610
42046	4	101124	2	17610
42047	5	101125	3	39093
42048	5	101133	5	31172
42049	4	101133	3	31172
42050	3	101135	7	2809
42051	5	101145	2	3537
42052	5	101146	7	27808
42053	4	101149	4	39207
42054	5	101157	2	34357
42055	4	101159	1	39056
42056	5	101161	5	5071
42057	3	101161	6	5071
42058	5	101163	2	27651
42059	4	101164	7	31821
42060	3	101165	4	35850
42061	1	101167	6	39048
42062	5	101168	4	16186
42063	4	101172	5	14149
42064	5	101176	5	11710
42065	3	101180	5	39095
42066	5	101181	4	39222
42067	1	101182	4	39084
42068	4	101183	4	6188
42069	5	101184	7	4956
42070	4	101187	1	28081
42071	3	101190	2	35058
42072	3	101191	1	39235
42073	4	101197	2	17500
42074	1	101199	6	10340
42075	5	101200	3	7678
42076	3	101202	5	28775
42077	5	101206	4	10914
42078	4	101210	1	38297
42079	4	101211	7	39079
42080	3	101212	5	28658
42081	5	101213	4	1255
42082	5	101216	7	30162
42083	4	101218	5	10633
42084	4	101218	3	10633
42085	4	101219	5	16922
42086	3	101220	4	16226
42087	5	101227	6	11342
42088	5	101228	2	15120
42089	5	101230	2	39064
42090	5	101232	2	2227
42091	5	101233	2	24274
42092	1	101235	6	10043
42093	5	101238	7	2283
42094	2	101238	2	2283
42095	5	101243	4	8104
42096	5	101244	3	34812
42097	5	101245	4	39094
42098	3	101247	7	39150
42099	3	101251	2	35331
42100	5	101252	2	39059
42101	4	101255	3	1256
42102	5	101255	1	1256
42103	5	101256	6	9238
42104	3	101257	5	36944
42105	5	101259	6	7821
42106	3	101260	2	7741
42107	5	101262	4	35332
42108	5	101269	7	25941
42109	5	101270	7	7086
42110	5	101277	5	17318
42111	2	101278	7	39122
42112	5	101281	3	38617
42113	5	101282	7	39137
42114	4	101283	7	10670
42115	5	101285	6	32548
42116	5	101288	6	34304
42117	4	101292	7	39140
42118	5	101294	6	39118
42119	3	101295	5	24671
42120	5	101296	6	39000
42121	1	101297	2	39072
42122	5	101298	7	28965
42123	4	101303	5	39244
42124	5	101305	2	15018
42125	4	101308	2	39077
42126	5	101308	4	39077
42127	3	101309	6	30504
42128	5	101311	6	21038
42129	5	101313	4	39112
42130	5	101316	2	1322
42131	5	101317	1	39070
42132	5	101319	7	38476
42133	5	101320	7	39177
42134	3	101321	3	39098
42135	5	101323	6	21628
42136	5	101325	6	39037
42137	5	101333	2	32947
42138	5	101334	2	17790
42139	5	101347	6	39109
42140	5	101348	3	25444
42141	5	101349	2	28851
42142	1	101350	6	13651
42143	5	101355	2	16871
42144	5	101356	4	2232
42145	3	101358	5	24356
42146	4	101359	7	39050
42147	5	101362	2	2443
42148	3	101366	7	38457
42149	5	101370	4	39190
42150	3	101372	5	39034
42151	4	101376	4	39126
42152	5	101378	3	26684
42153	5	101379	5	11240
42154	5	101381	6	39223
42155	5	101382	4	27
42156	5	101384	7	13713
42157	4	101388	7	33795
42158	4	101391	1	23717
42159	5	101391	6	23717
42160	5	101398	7	39197
42161	4	101399	5	1934
42162	5	101399	2	1934
42163	4	101403	2	39218
42164	5	101410	3	39119
42165	4	101413	6	988
42166	3	101414	4	33916
42167	3	101426	7	27161
42168	5	101427	3	3567
42169	4	101430	6	12934
42170	5	101431	4	31509
42171	5	101433	2	3871
42172	5	101434	2	39102
42173	4	101435	7	7069
42174	4	101436	5	39139
42175	5	101438	4	39227
42176	5	101440	4	30335
42177	3	101441	5	23334
42178	4	101446	2	38450
42179	5	101448	3	39241
42180	5	101452	3	39042
42181	5	101453	6	39168
42182	3	101454	5	184
42183	5	101455	1	18916
42184	3	101458	3	39238
42185	5	101463	7	13226
42186	5	101467	6	39186
42187	4	101468	5	36823
42188	4	101469	6	31610
42189	3	101472	1	39206
42190	3	101478	2	10005
42191	5	101480	7	22334
42192	5	101481	1	39176
42193	4	101481	7	39176
42194	5	101482	6	39043
42195	3	101484	5	38196
42196	4	101485	7	19717
42197	5	101490	6	4192
42198	5	101491	7	39213
42199	4	101492	1	1000
42200	4	101495	3	6637
42201	5	101496	6	39120
42202	5	101497	6	39194
42203	3	101498	3	6173
42204	5	101500	5	39057
42205	4	101505	2	5344
42206	3	101506	7	39205
42207	4	101507	7	39236
42208	5	101509	1	39208
42209	5	101509	4	39208
42210	5	101510	6	38576
42211	5	101511	7	21290
42212	2	101512	6	39185
42213	5	101513	4	26165
42214	5	101515	6	39101
42215	3	101517	1	1847
42216	5	101518	7	25530
42217	3	101519	7	39163
42218	5	101520	7	29905
42219	5	101522	6	16068
42220	1	101524	6	39047
42221	5	101528	6	33022
42222	1	101529	6	36053
42223	5	101530	4	2599
42224	5	101531	7	39121
42225	4	101533	1	3385
42226	5	101535	4	39074
42227	5	101535	2	39074
42228	3	101536	7	12912
42229	5	101538	5	39180
42230	2	101542	3	39158
42231	2	101543	6	5526
42232	4	101544	6	14763
42233	4	101545	3	7020
42234	4	101547	2	2850
42235	2	101549	6	39187
42236	5	101550	2	22464
42237	4	101553	5	25852
42238	5	101553	2	25852
42239	3	101554	2	35249
42240	5	101555	6	7792
42241	5	101558	2	39117
42242	5	101561	4	39018
42243	5	101562	2	6776
42244	5	101564	2	16706
42245	4	101567	5	2131
42246	3	101568	7	39274
42247	4	101571	7	39373
42248	5	101572	6	39414
42249	5	101574	6	31432
42250	5	101576	2	20191
42251	3	101582	4	4562
42252	4	101585	7	39312
42253	5	101588	2	14864
42254	4	101589	2	10670
42255	5	101589	3	10670
42256	3	101590	7	31448
42257	3	101592	7	38787
42258	5	101593	4	38219
42259	5	101597	4	24201
42260	4	101599	4	30911
42261	5	101604	6	39411
42262	5	101607	5	27544
42263	5	101608	1	8149
42264	4	101608	6	8149
42265	5	101610	3	9148
42266	5	101611	1	28688
42267	5	101613	4	21793
42268	5	101616	3	18069
42269	5	101618	4	27484
42270	5	101620	2	21271
42271	4	101623	3	1038
42272	5	101625	4	3755
42273	5	101627	6	37956
42274	5	101629	6	39375
42275	5	101633	2	29722
42276	4	101638	7	39417
42277	4	101640	4	39324
42278	5	101642	5	39379
42279	3	101643	4	21825
42280	5	101644	5	30356
42281	4	101644	7	30356
42282	4	101645	3	13495
42283	5	101646	6	9021
42284	3	101653	7	32173
42285	4	101653	4	32173
42286	5	101656	7	15320
42287	4	101659	4	30737
42288	5	101661	5	30894
42289	3	101662	5	5426
42290	3	101663	6	39436
42291	5	101664	5	9801
42292	1	101665	2	17595
42293	5	101666	3	39356
42294	5	101667	5	22146
42295	5	101668	1	1526
42296	3	101677	1	39111
42297	3	101684	5	19906
42298	4	101686	2	20835
42299	5	101688	1	39315
42300	5	101691	4	27835
42301	5	101693	7	11590
42302	4	101696	4	2392
42303	5	101698	6	11219
42304	5	101701	6	3509
42305	5	101703	1	38860
42306	5	101705	3	39288
42307	5	101708	6	39259
42308	5	101710	6	24666
42309	5	101719	1	8540
42310	3	101720	3	39385
42311	4	101721	7	33019
42312	4	101723	6	36576
42313	5	101724	2	39376
42314	5	101728	7	6200
42315	5	101730	6	39392
42316	5	101735	1	12070
42317	5	101736	6	39452
42318	5	101739	7	39431
42319	3	101743	1	39371
42320	4	101744	3	38461
42321	3	101745	5	33517
42322	5	101746	6	1072
42323	5	101747	1	28091
42324	4	101750	4	13891
42325	4	101751	7	39403
42326	3	101752	5	9920
42327	4	101765	2	39317
42328	5	101766	6	39454
42329	5	101768	3	16982
42330	3	101769	5	39293
42331	5	101772	6	39415
42332	5	101776	7	25477
42333	5	101779	6	39421
42334	1	101783	2	37983
42335	5	101790	2	39335
42336	5	101791	3	3771
42337	2	101792	5	19731
42338	5	101795	1	7020
42339	2	101796	3	39394
42340	5	101799	4	23662
42341	4	101801	2	2351
42342	5	101802	6	39364
42343	5	101806	4	5736
42344	5	101809	5	6453
42345	5	101815	2	33919
42346	5	101816	6	2706
42347	5	101816	4	2706
42348	4	101817	6	7953
42349	4	101825	5	36179
42350	5	101826	7	39369
42351	5	101830	4	39407
42352	5	101833	5	39386
42353	4	101833	7	39386
42354	5	101837	3	9684
42355	4	101838	6	37726
42356	3	101840	4	2667
42357	5	101846	5	39352
42358	5	101850	6	24041
42359	1	101856	6	30952
42360	5	101857	5	19725
42361	5	101858	1	39340
42362	5	101859	5	39438
42363	4	101860	7	39378
42364	3	101861	6	39400
42365	4	101862	1	9387
42366	5	101864	3	8900
42367	4	101868	1	12677
42368	5	101869	2	770
42369	5	101870	6	34663
42370	5	101874	7	39276
42371	5	101875	2	39262
42372	4	101877	5	7937
42373	3	101878	5	16346
42374	4	101882	1	39328
42375	3	101884	5	20088
42376	5	101885	2	33849
42377	5	101886	4	12278
42378	2	101891	1	39451
42379	4	101892	2	4624
42380	4	101896	3	27161
42381	5	101899	2	39449
42382	5	101900	7	20723
42383	3	101901	2	24668
42384	5	101906	2	7345
42385	5	101908	4	20997
42386	5	101908	6	20997
42387	5	101913	5	39441
42388	5	101914	4	19157
42389	5	101917	1	22448
42390	5	101920	5	28756
42391	5	101923	3	16498
42392	4	101927	6	28902
42393	5	101929	4	3129
42394	5	101933	1	27571
42395	4	101934	3	36830
42396	4	101935	7	8274
42397	5	101936	4	15929
42398	5	101938	7	19979
42399	5	101939	2	4065
42400	5	101942	1	24057
42401	5	101948	3	31805
42402	4	101949	7	7208
42403	5	101950	4	35350
42404	5	101952	7	27556
42405	5	101956	2	14354
42406	4	101957	1	32542
42407	4	101958	2	19054
42408	4	101959	7	39299
42409	2	101962	6	39363
42410	5	101964	4	20754
42411	5	101965	2	26630
42412	5	101967	4	1862
42413	3	101968	1	13451
42414	2	101972	6	8380
42415	5	101972	7	8380
42416	4	101980	4	3332
42417	5	101989	2	34688
42418	5	101991	1	29145
42419	4	101995	5	39382
42420	5	102000	1	1918
42421	3	102002	2	37163
42422	1	102008	6	32903
42423	5	102009	6	29780
42424	3	102011	7	39445
42425	4	102012	7	1436
42426	5	102017	3	39443
42427	5	102019	2	10142
42428	5	102019	1	10142
42429	3	102020	7	9535
42430	5	102022	4	5730
42431	2	102024	5	39433
42432	5	102031	3	18422
42433	5	102033	5	39316
42434	3	102035	5	39042
42435	4	102037	1	27625
42436	3	102041	5	37131
42437	3	102042	7	16897
42438	5	102044	6	39337
42439	5	102045	2	36944
42440	4	102049	5	39412
42441	4	102051	7	35424
42442	3	102053	7	10038
42443	5	102055	7	11317
42444	4	102056	3	39389
42445	5	102061	7	15616
42446	5	102061	6	15616
42447	5	102063	3	20183
42448	5	102064	4	5602
42449	5	102065	3	35080
42450	3	102068	7	26098
42451	5	102074	5	29263
42452	5	102075	6	39448
42453	5	102079	3	32294
42454	5	102081	6	15641
42455	4	102083	6	39307
42456	5	102085	6	28323
42457	4	102086	2	39347
42458	5	102087	3	8355
42459	5	102089	2	39334
42460	5	102090	7	39360
42461	5	102092	1	39285
42462	5	102092	6	39285
42463	4	102093	3	4420
42464	4	102095	1	25998
42465	5	102096	5	39396
42466	5	102107	6	5549
42467	4	102108	6	32358
42468	5	102111	2	33551
42469	4	102112	7	4137
42470	5	102113	6	39428
42471	4	102113	2	39428
42472	5	102114	2	39286
42473	2	102116	7	20119
42474	4	102118	2	3155
42475	5	102122	2	3380
42476	5	102130	6	39322
42477	5	102131	6	9962
42478	4	102138	7	39261
42479	3	102140	3	24284
42480	4	102141	2	39318
42481	5	102142	6	26690
42482	4	102143	3	449
42483	3	102144	1	39432
42484	5	102145	3	3517
42485	5	102146	4	39368
42486	2	102151	3	22075
42487	5	102156	3	9618
42488	3	102159	5	39338
42489	5	102160	6	39365
42490	4	102163	3	10065
42491	4	102165	7	39302
42492	4	102167	6	13639
42493	3	102171	5	39427
42494	5	102172	2	1318
42495	4	102173	6	19386
42496	5	102177	1	33909
42497	5	102179	4	39384
42498	4	102181	7	21617
42499	4	102184	1	25658
42500	5	102188	2	9533
42501	5	102194	1	7746
42502	4	102195	1	39080
42503	5	102199	2	2153
42504	5	102201	7	37992
42505	4	102203	6	39434
42506	3	102205	3	39251
42507	5	102207	6	37480
42508	4	102209	3	39423
42509	4	102209	7	39423
42510	4	102216	5	4685
42511	5	102217	6	39372
42512	5	102218	4	19711
42513	5	102223	5	39674
42514	3	102224	2	3570
42515	5	102226	3	25550
42516	5	102229	2	18981
42517	5	102230	5	38380
42518	4	102232	7	39683
42519	5	102239	1	39642
42520	1	102242	6	12180
42521	3	102244	3	35885
42522	5	102244	5	35885
42523	4	102245	7	29353
42524	4	102247	5	39489
42525	5	102249	3	11529
42526	5	102252	2	10491
42527	3	102254	3	5762
42528	4	102255	6	39670
42529	4	102258	5	9637
42530	5	102266	2	39644
42531	3	102267	5	12900
42532	5	102268	4	39471
42533	5	102270	5	39617
42534	5	102273	6	30679
42535	3	102274	7	29358
42536	3	102277	4	29146
42537	5	102279	4	31329
42538	5	102283	3	39552
42539	3	102287	6	27196
42540	4	102290	4	39548
42541	3	102292	4	6147
42542	5	102294	3	16345
42543	5	102297	7	13236
42544	5	102301	6	39535
42545	4	102302	1	39536
42546	4	102303	2	39710
42547	5	102306	5	13621
42548	5	102307	2	39510
42549	5	102308	2	22819
42550	5	102308	7	22819
42551	4	102309	5	11096
42552	5	102310	4	18393
42553	4	102311	7	39566
42554	4	102313	1	30867
42555	3	102314	5	6732
42556	5	102316	7	39720
42557	3	102317	4	37758
42558	5	102320	5	39505
42559	5	102322	4	34612
42560	5	102323	7	39684
42561	4	102325	6	39482
42562	5	102327	5	8553
42563	5	102329	7	37586
42564	3	102330	1	31890
42565	3	102331	7	39492
42566	4	102332	2	39696
42567	4	102334	1	38480
42568	3	102342	1	30777
42569	4	102343	5	39667
42570	3	102344	5	3900
42571	5	102345	4	39657
42572	3	102346	6	39508
42573	3	102346	1	39508
42574	5	102347	1	17430
42575	3	102352	1	11784
42576	5	102353	7	34551
42577	5	102356	7	39550
42578	5	102362	1	39712
42579	3	102363	4	7383
42580	5	102368	3	758
42581	3	102368	7	758
42582	5	102371	6	39623
42583	4	102372	6	3198
42584	4	102374	7	27775
42585	4	102377	7	39576
42586	5	102379	7	28177
42587	3	102381	2	34990
42588	4	102386	1	39512
42589	5	102389	1	37454
42590	2	102390	3	24273
42591	3	102391	6	2541
42592	5	102392	6	6148
42593	5	102394	2	21176
42594	5	102397	5	30486
42595	5	102399	2	12567
42596	4	102401	5	29417
42597	5	102406	3	29349
42598	5	102408	2	28756
42599	4	102410	1	547
42600	3	102412	6	32116
42601	3	102413	6	3949
42602	4	102416	5	643
42603	5	102418	4	33220
42604	5	102420	2	17443
42605	5	102421	4	27874
42606	5	102422	4	20942
42607	5	102424	5	35455
42608	5	102425	6	34267
42609	5	102428	6	39490
42610	5	102429	4	8781
42611	3	102430	3	29743
42612	5	102433	6	8729
42613	3	102434	1	35894
42614	5	102435	1	39555
42615	1	102436	5	39654
42616	3	102438	3	28441
42617	3	102439	7	24920
42618	5	102440	6	13343
42619	5	102441	2	8496
42620	4	102444	7	18929
42621	3	102450	5	39687
42622	5	102451	7	2310
42623	1	102452	6	39518
42624	5	102456	6	21612
42625	5	102462	4	13606
42626	5	102467	4	31969
42627	5	102468	6	20265
42628	4	102469	6	21794
42629	3	102470	7	11534
42630	4	102472	5	12148
42631	1	102473	6	39554
42632	5	102474	3	25861
42633	5	102475	7	13713
42634	3	102479	4	8438
42635	4	102479	7	8438
42636	3	102480	5	39464
42637	4	102485	1	39709
42638	5	102486	1	27757
42639	5	102487	6	15680
42640	3	102492	1	10267
42641	5	102492	3	10267
42642	4	102505	7	774
42643	5	102506	3	27130
42644	4	102507	6	39467
42645	5	102509	6	39559
42646	5	102512	7	14546
42647	5	102513	4	39542
42648	3	102515	4	39589
42649	2	102519	7	39569
42650	5	102521	1	10589
42651	3	102522	6	39700
42652	5	102524	2	18533
42653	5	102525	5	6192
42654	5	102528	6	39568
42655	5	102529	2	39622
42656	5	102532	4	36111
42657	5	102533	2	38497
42658	5	102534	7	2372
42659	4	102537	1	20820
42660	5	102538	4	1581
42661	3	102539	7	17113
42662	3	102545	4	11415
42663	2	102547	2	25857
42664	3	102549	7	4522
42665	5	102550	4	3012
42666	5	102552	7	39718
42667	5	102555	6	39479
42668	5	102556	5	8586
42669	5	102560	3	27620
42670	5	102562	4	34999
42671	5	102563	2	35374
42672	4	102565	4	26116
42673	5	102573	4	39658
42674	5	102573	5	39658
42675	5	102575	5	19542
42676	5	102580	1	35961
42677	5	102583	5	39455
42678	3	102585	7	36744
42679	5	102587	1	32936
42680	5	102588	3	39579
42681	5	102591	6	39647
42682	5	102592	1	33544
42683	4	102592	4	33544
42684	4	102595	2	23902
42685	4	102597	6	39491
42686	4	102599	2	20172
42687	3	102599	5	20172
42688	3	102600	4	4170
42689	3	102605	6	39661
42690	4	102606	3	8358
42691	3	102610	1	26837
42692	5	102617	2	12599
42693	1	102621	2	39469
42694	5	102624	2	4943
42695	3	102625	3	23720
42696	4	102627	2	39567
42697	1	102628	6	39676
42698	3	102629	5	39656
42699	5	102630	7	31351
42700	4	102631	3	27082
42701	5	102632	7	11795
42702	5	102633	6	39533
42703	5	102634	1	26446
42704	5	102636	4	39527
42705	5	102637	1	23023
42706	3	102638	5	35031
42707	4	102639	2	11764
42708	4	102640	6	21779
42709	5	102641	6	3869
42710	5	102645	6	39461
42711	5	102651	2	21716
42712	4	102653	5	13106
42713	5	102653	7	13106
42714	5	102655	6	30762
42715	4	102656	7	39523
42716	5	102658	6	9953
42717	3	102665	5	39702
42718	4	102667	7	24625
42719	5	102669	5	31523
42720	5	102670	4	6887
42721	3	102676	4	32846
42722	5	102678	2	30391
42723	2	102683	1	39590
42724	5	102688	4	16156
42725	4	102688	5	16156
42726	5	102689	5	27639
42727	4	102692	2	4983
42728	1	102693	6	21377
42729	5	102694	1	759
42730	5	102697	7	39142
42731	5	102698	6	39693
42732	5	102699	6	39689
42733	4	102700	1	27269
42734	5	102701	1	35366
42735	5	102702	7	32805
42736	1	102704	6	39481
42737	4	102707	1	33196
42738	5	102708	7	8546
42739	5	102711	5	18343
42740	4	102712	5	11686
42741	5	102716	4	36863
42742	5	102717	1	39581
42743	5	102720	5	39465
42744	5	102721	7	39561
42745	5	102722	2	39517
42746	5	102724	5	18472
42747	4	102725	7	17381
42748	4	102727	6	39486
42749	4	102729	6	39651
42750	4	102734	5	39563
42751	4	102736	7	16287
42752	5	102746	6	17481
42753	4	102749	5	39538
42754	5	102750	5	39583
42755	4	102753	2	6320
42756	5	102754	2	30921
42757	5	102755	7	37279
42758	5	102758	2	4062
42759	1	102759	2	39462
42760	3	102760	4	39603
42761	5	102766	5	37209
42762	4	102770	4	4959
42763	5	102771	4	11938
42764	5	102773	7	39514
42765	5	102774	2	39626
42766	3	102775	5	4308
42767	5	102778	2	29429
42768	4	102783	5	36690
42769	5	102784	4	39457
42770	5	102785	2	21236
42771	5	102786	6	24964
42772	4	102788	5	22590
42773	5	102794	3	39610
42774	4	102797	6	38630
42775	5	102802	7	30469
42776	4	102804	2	37201
42777	5	102806	1	39593
42778	3	102807	7	15290
42779	5	102808	5	39628
42780	3	102809	1	39675
42781	5	102810	4	18309
42782	4	102814	3	7253
42783	5	102818	6	39606
42784	5	102819	4	33849
42785	5	102821	3	10495
42786	4	102826	7	23986
42787	5	102830	6	30781
42788	4	102831	7	1931
42789	5	102835	1	38942
42790	4	102838	1	19753
42791	5	102839	5	3077
42792	3	102843	5	5819
42793	3	102844	5	3858
42794	5	102849	6	6826
42795	5	102850	5	13537
42796	5	102853	4	39639
42797	3	102855	3	4108
42798	5	102856	7	27040
42799	3	102856	2	27040
42800	5	102859	2	34979
42801	5	102863	6	6876
42802	3	102869	5	18836
42803	5	102874	5	8052
42804	4	102875	3	30474
42805	5	102877	6	38746
42806	3	102880	4	31328
42807	4	102881	1	38593
42808	3	102882	7	26984
42809	4	102888	6	437
42810	3	102891	5	39671
42811	4	102892	3	39495
42812	5	102893	2	17352
42813	5	102898	7	28739
42814	4	102900	5	39699
42815	5	102906	2	28402
42816	4	102913	7	5098
42817	5	102914	3	33439
42818	5	102917	1	17181
42819	3	102921	5	39750
42820	5	102926	1	2252
42821	3	102928	7	30887
42822	4	102929	7	782
42823	5	102931	2	24171
42824	5	102934	6	17912
42825	5	102936	5	36458
42826	5	102937	6	8866
42827	5	102940	6	39789
42828	4	102941	4	18428
42829	2	102942	6	28908
42830	5	102944	5	31074
42831	5	102945	1	39785
42832	5	102947	4	701
42833	5	102951	4	21898
42834	3	102952	1	39843
42835	5	102956	6	39741
42836	4	102959	2	39746
42837	5	102966	2	39910
42838	4	102967	2	2054
42839	5	102968	3	15456
42840	4	102969	1	10719
42841	5	102970	6	39895
42842	5	102972	6	31832
42843	5	102974	7	39823
42844	4	102975	7	39360
42845	5	102980	3	39358
42846	4	102983	2	11811
42847	5	102984	2	37201
42848	5	102985	1	33670
42849	5	102987	4	2783
42850	4	102989	2	39901
42851	5	102993	6	34115
42852	4	102993	3	34115
42853	4	102997	1	27727
42854	4	103001	7	32484
42855	5	103006	2	4798
42856	5	103006	4	4798
42857	4	103007	2	30618
42858	4	103009	7	8882
42859	5	103012	1	35585
42860	4	103015	5	1068
42861	5	103022	1	20711
42862	3	103022	7	20711
42863	5	103024	6	12065
42864	5	103026	3	39806
42865	5	103028	6	12983
42866	5	103030	4	31181
42867	4	103037	5	15237
42868	4	103039	6	39742
42869	3	103042	5	26860
42870	5	103043	6	23871
42871	5	103044	2	4182
42872	5	103047	4	35118
42873	2	103047	6	35118
42874	1	103052	6	1722
42875	4	103053	3	34106
42876	5	103057	4	32090
42877	5	103059	4	39682
42878	5	103060	2	39849
42879	5	103061	2	17372
42880	5	103063	2	14391
42881	4	103064	3	1393
42882	1	103066	1	37907
42883	5	103070	3	39784
42884	4	103072	3	39900
42885	3	103073	1	12049
42886	5	103075	4	22014
42887	4	103077	7	17367
42888	3	103079	2	33456
42889	5	103083	3	39865
42890	5	103084	2	35943
42891	5	103085	2	24315
42892	5	103087	1	20473
42893	5	103091	3	14127
42894	3	103092	7	39903
42895	5	103098	2	38470
42896	3	103102	5	32503
42897	5	103103	7	7261
42898	5	103104	6	16490
42899	5	103109	7	24922
42900	5	103111	3	18436
42901	5	103112	2	39892
42902	3	103113	7	34644
42903	3	103116	3	23435
42904	4	103123	7	25430
42905	5	103131	1	14488
42906	3	103132	7	39793
42907	5	103133	4	39743
42908	5	103134	6	1701
42909	5	103135	7	39828
42910	3	103136	7	8043
42911	5	103138	3	22214
42912	5	103140	6	39771
42913	4	103141	2	12012
42914	5	103142	4	511
42915	4	103143	1	39735
42916	4	103149	4	5951
42917	5	103151	6	27632
42918	5	103154	3	36481
42919	4	103156	5	10395
42920	3	103160	3	14532
42921	5	103165	3	3048
42922	5	103167	4	15959
42923	5	103168	6	3077
42924	5	103171	2	30367
42925	5	103171	5	30367
42926	5	103172	5	39852
42927	5	103174	1	361
42928	5	103176	7	16071
42929	4	103178	4	6608
42930	4	103179	4	39745
42931	4	103180	6	39827
42932	4	103185	7	39866
42933	4	103188	5	10662
42934	5	103192	2	24605
42935	4	103194	2	20079
42936	5	103194	6	20079
42937	3	103195	1	18067
42938	5	103197	6	6900
42939	4	103197	4	6900
42940	4	103198	4	39883
42941	5	103199	7	36946
42942	5	103201	6	8852
42943	4	103202	7	30230
42944	5	103207	2	23130
42945	4	103210	3	10237
42946	5	103215	4	39891
42947	4	103216	2	21386
42948	3	103220	7	34163
42949	4	103221	5	33271
42950	5	103222	1	39740
42951	5	103225	2	17247
42952	5	103229	6	23997
42953	5	103230	6	28094
42954	4	103234	6	39896
42955	5	103235	7	39850
42956	3	103237	5	19581
42957	3	103238	5	39807
42958	5	103239	6	39837
42959	5	103242	6	29069
42960	5	103247	2	18027
42961	3	103248	4	39747
42962	5	103248	2	39747
42963	5	103250	2	39800
42964	5	103250	6	39800
42965	5	103251	2	38940
42966	5	103252	3	17835
42967	5	103254	4	39798
42968	4	103259	5	39821
42969	4	103265	3	19511
42970	5	103266	3	25141
42971	5	103267	5	11921
42972	1	103268	5	39748
42973	5	103270	6	39818
42974	5	103271	6	39844
42975	5	103272	2	39879
42976	5	103273	7	18221
42977	5	103276	6	30238
42978	5	103277	2	2799
42979	5	103280	6	6593
42980	3	103282	3	30667
42981	4	103286	7	33946
42982	5	103294	6	21
42983	3	103296	2	39854
42984	5	103297	2	8071
42985	5	103299	7	39869
42986	5	103300	3	9483
42987	5	103301	1	2623
42988	5	103302	6	39906
42989	5	103303	7	36842
42990	5	103303	6	36842
42991	1	103304	5	20601
42992	5	103306	7	39809
42993	3	103312	4	29509
42994	5	103314	5	14425
42995	3	103315	7	39912
42996	5	103317	1	26195
42997	5	103319	7	37830
42998	5	103321	2	39867
42999	4	103322	2	21299
43000	5	103324	5	39840
43001	5	103329	2	39863
43002	4	103330	1	15629
43003	5	103331	2	39772
43004	5	103332	6	18752
43005	4	103333	7	11362
43006	3	103334	1	14206
43007	5	103336	4	16571
43008	5	103341	1	23779
43009	5	103342	7	39860
43010	5	103345	2	16996
43011	2	103350	6	34288
43012	3	103351	4	39890
43013	5	103358	4	39815
43014	4	103358	3	39815
43015	5	103359	4	24395
43016	4	103360	3	8283
43017	5	103365	6	35853
43018	5	103373	5	23155
43019	5	103376	6	4099
43020	5	103379	1	444
43021	5	103380	1	1101
43022	3	103381	5	18711
43023	5	103389	6	31313
43024	3	103391	3	39822
43025	4	103392	1	24668
43026	5	103392	4	24668
43027	4	103396	6	39876
43028	5	103398	4	16303
43029	5	103400	2	17623
43030	5	103403	2	28815
43031	3	103407	7	305
43032	5	103411	2	35375
43033	5	103413	5	29841
43034	1	103414	7	25301
43035	5	103417	2	18730
43036	3	103421	4	5155
43037	5	103424	6	20182
43038	1	103426	6	39838
43039	5	103427	6	11288
43040	5	103429	6	5371
43041	5	103430	4	13294
43042	5	103434	2	24950
43043	4	103438	7	7969
43044	3	103442	5	15872
43045	5	103444	2	19172
43046	5	103445	1	22750
43047	4	103448	4	22987
43048	3	103453	7	39887
43049	3	103455	5	27726
43050	5	103457	2	16444
43051	4	103458	5	886
43052	3	103461	1	17350
43053	5	103462	7	662
43054	2	103463	6	1180
43055	3	103470	6	11063
43056	2	103471	7	28538
43057	4	103473	3	11317
43058	4	103474	2	16059
43059	3	103474	7	16059
43060	2	103479	7	29532
43061	3	103481	3	32477
43062	2	103482	3	660
43063	3	103483	5	39792
43064	4	103485	3	22714
43065	5	103486	5	4986
43066	4	103491	7	29529
43067	4	103492	4	25764
43068	5	103496	1	18233
43069	3	103496	7	18233
43070	5	103497	2	39767
43071	1	103498	2	39832
43072	3	103501	7	38809
43073	5	103502	6	39831
43074	3	103503	3	39873
43075	3	103507	3	34431
43076	5	103510	6	26343
43077	3	103510	7	26343
43078	3	103516	7	31260
43079	5	103520	7	12532
43080	4	103522	7	24839
43081	3	103526	5	38667
43082	5	103528	3	23831
43083	4	103531	4	38035
43084	5	103534	3	11464
43085	4	103535	4	5886
43086	2	103540	6	38680
43087	5	103541	6	37253
43088	5	103544	4	39857
43089	5	103544	5	39857
43090	5	103547	2	21152
43091	5	103550	3	36310
43092	5	103555	4	13012
43093	5	103557	2	37512
43094	4	103557	5	37512
43095	4	103563	7	35087
43096	5	103565	4	16883
43097	5	103567	1	17513
43098	5	103570	6	15449
43099	4	103571	1	39914
43100	4	103572	7	7924
43101	4	103576	3	39791
43102	5	103577	2	16845
43103	5	103584	2	39911
43104	5	103586	7	39769
43105	4	103587	7	16177
43106	5	103588	3	14475
43107	5	103590	1	14373
43108	5	103592	6	39841
43109	5	103594	6	39187
43110	5	103597	7	21134
43111	4	103599	3	1373
43112	5	103599	6	1373
43113	5	103605	6	32603
43114	4	103608	3	1003
43115	5	103612	4	39877
43116	5	103615	5	39765
43117	5	103616	4	2398
43118	5	103617	1	6396
43119	3	103621	3	27838
43120	5	103623	6	13858
43121	5	103626	4	39864
43122	5	103629	2	8726
43123	5	103630	2	23797
43124	5	103631	4	10706
43125	4	103635	3	9312
43126	4	103637	1	39909
43127	4	103641	5	6174
43128	4	103642	1	9672
43129	5	103642	2	9672
43130	4	103643	1	40124
43131	5	103651	4	40167
43132	3	103652	3	8612
43133	5	103655	5	8059
43134	4	103656	7	14207
43135	4	103657	7	39982
43136	5	103658	1	17091
43137	3	103660	7	20957
43138	4	103661	6	13697
43139	4	103662	6	1239
43140	4	103663	3	28486
43141	5	103666	3	23562
43142	3	103667	5	3870
43143	4	103668	2	40205
43144	3	103669	5	40063
43145	5	103672	2	31971
43146	3	103674	6	39961
43147	3	103678	7	40158
43148	5	103678	2	40158
43149	5	103679	6	15040
43150	4	103682	7	7571
43151	4	103683	3	39926
43152	5	103683	6	39926
43153	5	103685	6	35877
43154	2	103686	3	3031
43155	5	103687	6	34492
43156	3	103689	5	4882
43157	5	103690	6	22530
43158	4	103691	5	16632
43159	4	103694	5	31628
43160	3	103697	5	31013
43161	5	103698	6	40152
43162	3	103700	7	40019
43163	5	103700	2	40019
43164	4	103704	5	40087
43165	4	103708	6	19617
43166	4	103712	7	14008
43167	4	103715	7	11402
43168	5	103717	4	40172
43169	4	103719	7	16779
43170	5	103723	3	6342
43171	5	103724	1	11897
43172	5	103725	5	3347
43173	4	103726	4	538
43174	5	103727	5	5584
43175	5	103728	6	27461
43176	5	103729	4	39922
43177	3	103731	1	40073
43178	4	103733	5	40138
43179	4	103735	7	28112
43180	5	103736	7	19300
43181	3	103737	3	39740
43182	5	103740	3	39966
43183	5	103743	7	26127
43184	4	103744	2	7912
43185	5	103745	3	9053
43186	5	103746	2	37688
43187	4	103748	6	40093
43188	4	103749	4	40085
43189	4	103750	7	31581
43190	5	103752	6	40108
43191	1	103756	7	40135
43192	3	103759	5	40127
43193	4	103765	5	10802
43194	5	103766	4	27988
43195	3	103766	1	27988
43196	5	103767	5	39800
43197	5	103767	4	39800
43198	5	103768	1	40125
43199	5	103769	5	15750
43200	5	103771	5	4287
43201	5	103772	2	1924
43202	4	103772	5	1924
43203	5	103774	2	36302
43204	5	103776	6	40195
43205	5	103779	5	3284
43206	4	103782	7	3381
43207	5	103784	2	37288
43208	4	103784	6	37288
43209	4	103787	7	40077
43210	3	103794	5	33683
43211	5	103795	7	40170
43212	4	103796	3	31824
43213	4	103798	3	3211
43214	3	103798	5	3211
43215	5	103799	2	32899
43216	5	103800	6	30256
43217	3	103802	7	34676
43218	3	103806	4	33333
43219	3	103810	3	11859
43220	5	103811	6	39986
43221	5	103812	6	40080
43222	4	103812	1	40080
43223	5	103815	6	31454
43224	4	103818	7	9515
43225	3	103819	2	39952
43226	3	103828	1	39931
43227	4	103833	1	35581
43228	4	103837	7	14025
43229	5	103844	7	40154
43230	5	103845	3	35365
43231	5	103848	7	24510
43232	5	103849	6	40090
43233	5	103852	3	31738
43234	5	103852	1	31738
43235	5	103853	4	31115
43236	5	103859	6	18947
43237	3	103864	7	11023
43238	4	103867	5	40199
43239	4	103867	7	40199
43240	4	103871	5	13491
43241	5	103872	5	35343
43242	5	103878	2	40032
43243	5	103879	4	16920
43244	5	103884	4	19726
43245	5	103885	4	32133
43246	4	103887	5	40010
43247	5	103891	2	12611
43248	5	103895	2	39997
43249	2	103896	4	1258
43250	5	103897	4	40067
43251	3	103898	3	40153
43252	4	103899	3	2713
43253	5	103900	2	2855
43254	1	103901	7	35199
43255	3	103902	5	24037
43256	5	103903	2	32584
43257	4	103906	2	31095
43258	5	103908	7	2227
43259	4	103909	1	39927
43260	4	103910	7	40103
43261	5	103914	5	7964
43262	4	103916	7	1780
43263	4	103919	6	20383
43264	1	103920	6	8956
43265	4	103920	1	8956
43266	5	103922	1	40042
43267	1	103922	6	40042
43268	5	103926	4	30022
43269	5	103930	6	203
43270	5	103931	4	14683
43271	5	103932	2	37834
43272	5	103937	4	21071
43273	5	103938	6	26459
43274	4	103939	7	32863
43275	4	103940	1	3032
43276	5	103941	5	22558
43277	5	103945	2	40122
43278	1	103947	7	39984
43279	5	103948	1	9171
43280	4	103954	7	28495
43281	3	103959	5	39975
43282	4	103960	1	6366
43283	4	103966	4	4595
43284	4	103967	1	40182
43285	5	103969	7	17582
43286	5	103973	6	40121
43287	3	103974	6	2637
43288	4	103975	7	4754
43289	3	103981	5	27300
43290	4	103982	7	6435
43291	2	103983	6	40071
43292	5	103985	4	40007
43293	1	103994	3	40115
43294	5	103997	2	17850
43295	3	104000	3	27496
43296	4	104002	6	7924
43297	5	104004	4	11887
43298	4	104008	2	21239
43299	5	104010	4	27875
43300	4	104012	7	318
43301	3	104013	7	38556
43302	3	104015	1	40183
43303	5	104021	5	32823
43304	4	104023	3	37948
43305	5	104025	2	39994
43306	5	104027	4	1379
43307	4	104034	2	6769
43308	5	104035	7	10170
43309	4	104036	7	24171
43310	5	104040	4	40209
43311	5	104042	4	36480
43312	5	104043	5	30679
43313	4	104045	7	28630
43314	3	104048	5	39946
43315	3	104053	7	15485
43316	5	104054	6	23075
43317	5	104065	7	25971
43318	4	104067	5	25922
43319	5	104076	7	40119
43320	5	104077	2	40024
43321	5	104081	3	40192
43322	4	104082	5	5729
43323	5	104090	5	40086
43324	5	104098	4	33730
43325	4	104099	6	16090
43326	4	104100	5	20729
43327	5	104103	4	40059
43328	3	104104	4	12078
43329	5	104105	6	40011
43330	5	104108	6	24042
43331	4	104108	7	24042
43332	5	104110	2	24538
43333	5	104111	1	40078
43334	3	104112	7	38743
43335	4	104115	5	39985
43336	5	104118	3	1663
43337	5	104119	2	33981
43338	2	104122	6	22600
43339	4	104122	1	22600
43340	5	104123	7	31259
43341	4	104124	3	40068
43342	5	104126	6	25728
43343	5	104130	6	29320
43344	5	104132	6	38120
43345	5	104133	7	38646
43346	5	104134	2	37743
43347	5	104135	7	28080
43348	4	104139	5	26271
43349	5	104144	4	20805
43350	2	104145	7	26140
43351	1	104146	6	23859
43352	4	104147	7	19397
43353	5	104148	2	13275
43354	5	104149	3	40105
43355	5	104150	3	24865
43356	5	104150	6	24865
43357	3	104153	5	4155
43358	4	104156	4	40178
43359	3	104157	5	22628
43360	5	104165	7	40064
43361	5	104169	1	15626
43362	5	104170	4	33959
43363	3	104172	5	25865
43364	4	104173	6	39943
43365	2	104174	6	2415
43366	4	104175	3	40159
43367	4	104176	6	40165
43368	5	104178	7	23424
43369	5	104180	6	34003
43370	4	104182	2	40156
43371	2	104184	6	15256
43372	5	104190	7	65
43373	5	104191	7	40022
43374	3	104194	2	15110
43375	4	104197	2	676
43376	2	104198	7	40053
43377	3	104199	7	40174
43378	5	104199	2	40174
43379	5	104202	6	40142
43380	4	104204	3	1944
43381	5	104206	6	25811
43382	4	104208	4	19399
43383	5	104208	1	19399
43384	5	104210	6	26065
43385	5	104211	1	334
43386	3	104211	7	334
43387	5	104215	4	30306
43388	5	104217	1	36310
43389	3	104219	4	18094
43390	3	104220	7	40201
43391	2	104223	6	5886
43392	5	104224	2	13547
43393	3	104226	7	20573
43394	5	104226	3	20573
43395	5	104229	2	40177
43396	5	104235	6	19946
43397	1	104235	4	19946
43398	1	104238	6	25882
43399	5	104240	6	40140
43400	5	104241	5	6387
43401	5	104248	4	10653
43402	3	104250	7	7364
43403	3	104256	6	10287
43404	4	104259	6	40193
43405	4	104263	7	40095
43406	5	104267	6	40043
43407	4	104268	5	9934
43408	5	104270	2	39987
43409	5	104272	3	39928
43410	5	104277	1	10758
43411	5	104277	7	10758
43412	4	104279	7	34899
43413	3	104280	1	36952
43414	3	104284	7	14756
43415	5	104285	3	3540
43416	5	104287	6	40146
43417	5	104290	2	15103
43418	5	104295	4	32647
43419	5	104295	6	32647
43420	5	104298	3	1885
43421	5	104299	6	40002
43422	3	104302	5	1836
43423	5	104303	4	20379
43424	5	104304	2	40004
43425	5	104307	4	14673
43426	4	104308	6	25420
43427	5	104309	2	35806
43428	5	104311	2	28451
43429	5	104314	6	18831
43430	1	104315	6	19678
43431	5	104319	3	40184
43432	1	104323	4	36250
43433	4	104327	1	39995
43434	5	104329	4	30356
43435	5	104330	4	39942
43436	5	104330	3	39942
43437	3	104333	1	31847
43438	4	104334	1	40056
43439	3	104341	7	15350
43440	5	104341	2	15350
43441	3	104343	7	40081
43442	3	104344	4	40148
43443	5	104345	2	37261
43444	5	104346	4	453
43445	5	104348	6	38441
43446	5	104350	2	7189
43447	5	104351	6	14984
43448	5	104355	1	28074
43449	5	104356	2	3444
43450	5	104357	1	24306
43451	3	104360	2	10537
43452	4	104363	5	40151
43453	4	104365	2	40008
43454	4	104365	3	40008
43455	3	104366	3	18475
43456	3	104368	4	20555
43457	5	104370	3	13
43458	3	104372	5	39919
43459	5	104377	6	40104
43460	4	104380	5	173
43461	5	104382	6	25879
43462	1	104382	4	25879
43463	4	104383	6	18597
43464	4	104384	4	39957
43465	4	104386	3	22850
43466	5	104387	4	29560
43467	5	104388	2	22788
43468	5	104390	5	3399
43469	5	104393	1	22081
43470	4	104395	6	40035
43471	5	104396	2	7718
43472	5	104401	4	40066
43473	5	104402	4	40112
43474	4	104404	7	13296
43475	3	104406	5	10180
43476	5	104408	1	40013
43477	4	104409	7	35184
43478	5	104410	7	40001
43479	5	104411	3	3307
43480	5	104413	6	23084
43481	3	104415	5	39973
43482	2	104418	6	10717
43483	5	104429	3	14092
43484	5	104430	3	6247
43485	3	104431	6	15031
43486	4	104432	1	9322
43487	5	104434	4	32379
43488	5	104435	2	11751
43489	4	104438	2	811
43490	3	104440	4	12894
43491	5	104441	5	40060
43492	3	104448	2	15889
43493	5	104449	7	6400
43494	5	104456	6	40161
43495	5	104459	2	39968
43496	5	104463	2	10339
43497	5	104464	2	13272
43498	5	104466	4	23080
43499	1	104468	6	38468
43500	4	104469	5	18123
43501	4	104471	3	7206
43502	5	104472	2	24034
43503	5	104474	4	2924
43504	3	104477	7	35726
43505	5	104478	2	5707
43506	5	104481	6	27703
43507	5	104483	7	74
43508	4	104489	5	13875
43509	3	104490	6	31185
43510	5	104491	1	3677
43511	5	104493	4	13287
43512	5	104499	3	39924
43513	5	104503	5	39949
43514	3	104507	7	31363
43515	3	104510	4	17469
43516	3	104511	5	23897
43517	4	104511	3	23897
43518	5	104512	6	39969
43519	4	104516	6	9728
43520	5	104521	7	39962
43521	5	104526	2	10281
43522	5	104528	6	22257
43523	4	104533	2	20595
43524	5	104535	7	25580
43525	5	104536	4	17875
43526	5	104537	6	9125
43527	5	104540	6	11961
43528	3	104547	1	22373
43529	3	104547	7	22373
43530	5	104551	6	31900
43531	5	104554	6	40110
43532	5	104556	6	25202
43533	5	104558	6	33619
43534	3	104563	5	35595
43535	3	104564	4	21612
43536	5	104569	3	2874
43537	5	104570	4	31210
43538	3	104573	7	39974
43539	4	104574	7	11417
43540	5	104582	1	40051
43541	4	104585	1	40069
43542	5	104586	7	20193
43543	5	104587	6	6882
43544	5	104588	6	39936
43545	2	104590	5	19371
43546	1	104597	2	30582
43547	2	104598	3	27388
43548	5	104600	2	17691
43549	5	104601	1	40025
43550	5	104602	7	16924
43551	5	104603	2	12231
43552	5	104604	5	11130
43553	5	104606	7	13529
43554	3	104609	5	14868
43555	5	104613	1	40113
43556	5	104614	2	16967
43557	5	104618	7	24211
43558	5	104621	6	27236
43559	4	104624	2	40029
43560	5	104626	7	9198
43561	5	104628	2	2546
43562	3	104632	6	32945
43563	3	104635	5	10876
43564	5	104637	1	32941
43565	5	104638	2	8730
43566	5	104641	2	39970
43567	3	104644	2	20196
43568	5	104645	2	39996
43569	5	104647	1	16181
43570	4	104655	6	25038
43571	5	104656	2	39929
43572	4	104657	7	12403
43573	5	104659	2	40047
43574	5	104660	3	40168
43575	5	104665	2	40150
43576	3	104665	7	40150
43577	4	104666	1	11239
43578	5	104669	6	40169
43579	5	104669	7	40169
43580	2	104673	1	37917
43581	3	104675	1	40179
43582	4	104676	7	32082
43583	5	104678	6	35831
43584	3	104683	7	37713
43585	5	104689	7	21728
43586	5	104689	4	21728
43587	5	104691	5	22185
43588	5	104694	1	10187
43589	5	104696	2	24611
43590	4	104701	6	9312
43591	5	104705	7	22062
43592	5	104709	7	40301
43593	4	104712	7	28712
43594	3	104714	5	40344
43595	5	104716	7	4190
43596	5	104718	6	35643
43597	5	104719	2	35720
43598	3	104720	7	10854
43599	1	104727	6	40250
43600	5	104732	1	19953
43601	4	104738	7	3645
43602	4	104739	5	40273
43603	4	104739	2	40273
43604	4	104742	7	31876
43605	4	104743	2	32936
43606	4	104744	4	36385
43607	5	104748	6	40426
43608	5	104755	6	40304
43609	3	104756	5	40251
43610	3	104759	5	40323
43611	5	104760	4	40404
43612	3	104765	4	19383
43613	4	104768	5	8204
43614	5	104768	2	8204
43615	5	104771	6	32539
43616	5	104772	4	9475
43617	5	104776	5	40366
43618	5	104780	7	35722
43619	3	104782	5	35807
43620	3	104790	7	6282
43621	3	104792	3	23118
43622	5	104795	6	34162
43623	5	104796	6	33607
43624	5	104797	6	2237
43625	2	104799	3	10596
43626	2	104800	1	14984
43627	1	104806	4	19391
43628	4	104812	1	4060
43629	5	104812	4	4060
43630	2	104819	6	23469
43631	5	104822	7	40306
43632	5	104823	3	26819
43633	4	104826	7	33195
43634	4	104828	2	40405
43635	5	104830	5	32739
43636	1	104834	6	40456
43637	5	104835	5	40350
43638	4	104836	5	40238
43639	5	104836	3	40238
43640	5	104837	7	40354
43641	3	104838	3	40239
43642	4	104839	6	40375
43643	5	104840	4	30855
43644	1	104841	7	14104
43645	5	104844	2	10420
43646	4	104845	5	5966
43647	5	104848	2	8234
43648	5	104854	7	40217
43649	5	104856	1	30005
43650	4	104860	6	32914
43651	3	104861	5	40310
43652	3	104863	3	28044
43653	5	104864	5	29398
43654	4	104865	5	40467
43655	4	104866	7	34700
43656	5	104867	2	34890
43657	5	104869	7	7211
43658	5	104870	5	40438
43659	2	104873	4	40326
43660	3	104874	5	40434
43661	5	104875	2	22629
43662	5	104876	5	23065
43663	5	104878	6	2552
43664	5	104879	7	11560
43665	5	104880	6	23999
43666	5	104882	1	2283
43667	4	104882	5	2283
43668	3	104885	1	33331
43669	5	104888	6	40275
43670	3	104895	1	10152
43671	4	104896	1	24250
43672	4	104901	7	10993
43673	5	104904	7	40309
43674	5	104904	4	40309
43675	5	104905	6	40433
43676	5	104906	1	40446
43677	5	104908	3	11057
43678	5	104909	1	18782
43679	5	104910	7	10425
43680	5	104911	6	40342
43681	5	104912	7	40397
43682	5	104920	4	6688
43683	5	104921	4	16313
43684	5	104924	2	21671
43685	3	104925	3	11342
43686	4	104931	5	16438
43687	5	104934	5	4150
43688	5	104937	3	14545
43689	4	104937	1	14545
43690	5	104940	4	18983
43691	5	104941	7	40222
43692	5	104943	2	3997
43693	4	104945	2	19428
43694	4	104948	6	14294
43695	5	104949	6	40420
43696	5	104951	7	40312
43697	3	104953	1	40325
43698	5	104953	5	40325
43699	5	104954	2	40411
43700	4	104956	5	8181
43701	3	104957	7	5192
43702	5	104958	6	38615
43703	5	104962	7	40329
43704	5	104963	1	40283
43705	3	104968	5	40357
43706	4	104970	7	29302
43707	4	104971	7	40227
43708	1	104972	6	10045
43709	3	104974	3	27938
43710	5	104977	2	31117
43711	4	104978	5	16607
43712	5	104983	6	40346
43713	4	104984	4	4107
43714	4	104987	6	8622
43715	5	104989	3	32551
43716	5	104995	3	40359
43717	5	104996	6	40424
43718	3	104997	7	40351
43719	5	104999	6	40368
43720	5	105004	1	40352
43721	3	105014	7	32328
43722	3	105014	5	32328
43723	5	105016	6	17793
43724	5	105018	7	18297
43725	4	105019	7	22622
43726	3	105020	5	27567
43727	5	105023	7	15156
43728	5	105026	1	932
43729	3	105030	7	3874
43730	5	105033	4	19113
43731	3	105035	4	35439
43732	5	105039	4	40233
43733	4	105044	7	32115
43734	5	105052	6	6499
43735	5	105053	6	40409
43736	3	105055	2	23988
43737	3	105061	5	14279
43738	5	105062	7	40448
43739	5	105068	4	40465
43740	5	105070	7	17797
43741	3	105078	7	6156
43742	5	105080	7	5109
43743	5	105081	3	31549
43744	3	105084	5	8180
43745	4	105088	2	14254
43746	5	105090	1	28663
43747	5	105091	7	40394
43748	4	105094	7	32729
43749	5	105095	1	25444
43750	5	105095	2	25444
43751	5	105098	1	23758
43752	4	105100	7	40396
43753	5	105103	7	29283
43754	5	105106	6	13621
43755	5	105114	4	40260
43756	3	105117	7	40294
43757	5	105118	4	2616
43758	3	105122	1	22125
43759	3	105123	4	40330
43760	5	105126	6	30070
43761	5	105128	6	39925
43762	5	105130	1	40249
43763	3	105134	7	14169
43764	5	105135	5	40271
43765	5	105136	6	11530
43766	3	105143	7	12012
43767	5	105144	4	23276
43768	3	105148	2	6644
43769	3	105150	7	40401
43770	4	105155	3	29265
43771	4	105158	6	38584
43772	5	105160	7	9804
43773	3	105160	6	9804
43774	3	105162	7	27410
43775	5	105164	4	23602
43776	4	105173	6	40640
43777	5	105174	5	17351
43778	5	105179	2	40490
43779	5	105181	2	24260
43780	4	105182	3	16550
43781	5	105183	2	12099
43782	5	105184	4	20571
43783	3	105187	5	34688
43784	3	105187	4	34688
43785	3	105192	3	40499
43786	4	105194	6	39973
43787	5	105197	2	32130
43788	5	105201	7	32945
43789	5	105205	2	25594
43790	5	105207	2	1445
43791	5	105208	3	26033
43792	5	105209	6	28982
43793	4	105210	3	40479
43794	4	105211	5	40538
43795	5	105212	2	40721
43796	5	105215	6	26643
43797	5	105218	6	40482
43798	4	105218	7	40482
43799	5	105219	2	33129
43800	5	105220	6	17154
43801	5	105221	1	28174
43802	5	105225	2	1944
43803	1	105228	6	17353
43804	5	105233	1	30074
43805	5	105236	2	3629
43806	5	105238	6	11505
43807	5	105238	4	11505
43808	4	105239	7	40598
43809	5	105240	6	40582
43810	3	105243	2	593
43811	4	105246	5	40619
43812	3	105248	2	40651
43813	5	105249	1	11494
43814	4	105250	7	40496
43815	5	105252	6	19759
43816	5	105259	1	40488
43817	5	105260	3	40637
43818	5	105263	2	22071
43819	5	105265	1	12001
43820	5	105271	6	40559
43821	4	105272	5	24807
43822	5	105274	3	39327
43823	3	105275	3	35374
43824	4	105282	7	24609
43825	5	105285	6	14851
43826	4	105287	7	38996
43827	5	105289	4	33467
43828	5	105291	4	19706
43829	4	105293	1	8212
43830	5	105297	3	40545
43831	2	105298	6	36213
43832	4	105305	6	40568
43833	5	105307	1	40639
43834	5	105308	4	40641
43835	5	105309	4	40522
43836	5	105310	1	40590
43837	5	105313	6	40694
43838	5	105315	6	40567
43839	4	105316	4	3806
43840	1	105317	6	18898
43841	2	105318	6	27095
43842	5	105320	6	40684
43843	3	105324	2	37451
43844	3	105326	5	32212
43845	5	105327	4	40623
43846	4	105329	2	40622
43847	4	105330	5	40655
43848	3	105331	4	40589
43849	3	105334	3	9071
43850	4	105335	1	17412
43851	5	105339	6	18090
43852	5	105340	3	450
43853	4	105341	6	40495
43854	5	105342	6	22298
43855	1	105343	6	40602
43856	5	105345	4	40700
43857	5	105346	5	36081
43858	5	105348	6	14081
43859	5	105349	2	13518
43860	5	105349	1	13518
43861	5	105352	7	28720
43862	4	105353	4	26677
43863	5	105354	6	38738
43864	5	105355	7	40505
43865	3	105357	5	40683
43866	5	105359	7	18355
43867	5	105365	1	24975
43868	5	105367	2	15654
43869	4	105368	7	40618
43870	4	105372	6	40519
43871	3	105374	1	34237
43872	3	105376	5	40477
43873	5	105379	3	17685
43874	5	105382	7	40701
43875	3	105383	3	40530
43876	5	105385	7	28367
43877	3	105386	5	36504
43878	3	105389	1	40599
43879	4	105391	3	40540
43880	5	105393	2	34247
43881	3	105395	5	29695
43882	4	105399	1	40692
43883	3	105400	5	7763
43884	5	105401	1	3312
43885	5	105401	7	3312
43886	5	105402	3	40656
43887	3	105404	5	35574
43888	5	105406	7	40557
43889	5	105407	3	34767
43890	5	105408	6	40145
43891	3	105416	5	6953
43892	5	105417	5	40611
43893	5	105420	3	14710
43894	5	105427	5	28607
43895	3	105430	7	40542
43896	5	105434	5	40529
43897	5	105437	6	40716
43898	5	105441	6	10554
43899	4	105445	1	40508
43900	5	105446	5	21747
43901	4	105451	5	32475
43902	5	105456	6	2616
43903	5	105457	4	12976
43904	5	105458	5	14984
43905	4	105459	2	40578
43906	4	105463	1	40665
43907	5	105465	2	4143
43908	3	105465	4	4143
43909	5	105466	4	40708
43910	5	105468	6	32306
43911	5	105469	4	21009
43912	4	105475	1	32
43913	1	105477	6	40472
43914	5	105479	6	36737
43915	5	105480	7	36449
43916	4	105483	2	21893
43917	5	105485	6	40714
43918	5	105487	2	40502
43919	4	105490	1	27483
43920	3	105491	4	40709
43921	5	105493	2	31611
43922	1	105494	7	16867
43923	3	105495	5	40579
43924	4	105498	5	40552
43925	4	105501	7	23614
43926	4	105503	4	40531
43927	5	105505	6	40570
43928	5	105506	2	9298
43929	4	105515	3	37532
43930	3	105516	5	20705
43931	1	105517	6	27700
43932	5	105518	2	33758
43933	3	105519	5	32419
43934	4	105520	6	5442
43935	5	105523	6	40474
43936	5	105524	6	40537
43937	3	105525	2	18260
43938	5	105526	3	15577
43939	3	105527	3	40712
43940	4	105530	5	32692
43941	5	105531	6	15699
43942	5	105531	4	15699
43943	5	105533	6	4030
43944	5	105536	6	33100
43945	2	105538	6	18746
43946	5	105542	4	32447
43947	5	105544	5	13075
43948	5	105545	7	40563
43949	5	105546	3	26634
43950	5	105551	5	40662
43951	3	105565	7	15550
43952	5	105568	1	40724
43953	5	105570	4	26459
43954	4	105572	5	22947
43955	4	105573	7	40533
43956	5	105574	1	40682
43957	3	105575	7	11927
43958	5	105577	5	12269
43959	4	105578	1	1562
43960	3	105579	6	40669
43961	3	105580	7	7750
43962	1	105583	7	40503
43963	5	105584	6	40549
43964	4	105585	5	40690
43965	5	105588	1	5963
43966	3	105593	3	8692
43967	3	105597	5	536
43968	3	105598	5	29795
43969	4	105602	7	40704
43970	5	105604	4	38601
43971	5	105606	4	26659
43972	5	105607	2	40512
43973	5	105609	5	23914
43974	5	105610	4	6342
43975	5	105612	3	19776
43976	5	105621	6	40322
43977	4	105623	3	25031
43978	5	105628	6	11487
43979	5	105629	2	40476
43980	4	105631	2	18822
43981	4	105633	2	37327
43982	4	105636	7	13722
43983	4	105642	3	1896
43984	3	105644	1	9899
43985	5	105646	3	30629
43986	5	105647	6	10453
43987	5	105648	6	40539
43988	1	105649	4	29489
43989	5	105650	2	25668
43990	5	105652	6	40663
43991	5	105656	4	40974
43992	5	105659	1	40936
43993	5	105662	7	38625
43994	5	105663	2	15776
43995	5	105664	6	29460
43996	4	105668	4	113
43997	5	105669	2	40754
43998	4	105671	5	40742
43999	4	105673	6	40883
44000	5	105676	4	40856
44001	5	105678	6	2801
44002	4	105679	6	34911
44003	5	105681	2	27712
44004	4	105682	2	3363
44005	3	105683	2	40934
44006	4	105684	7	36550
44007	4	105685	4	40771
44008	5	105686	7	40908
44009	4	105687	2	4342
44010	4	105691	7	40902
44011	5	105698	3	40782
44012	5	105701	1	31716
44013	5	105704	3	352
44014	3	105705	6	40790
44015	5	105706	4	21538
44016	2	105709	6	26989
44017	5	105710	4	11555
44018	4	105713	6	26911
44019	5	105721	2	40927
44020	3	105722	2	17518
44021	4	105729	4	12640
44022	5	105730	4	40730
44023	5	105734	7	18959
44024	4	105735	1	39872
44025	1	105736	6	40885
44026	5	105739	1	38986
44027	4	105740	5	3185
44028	1	105741	6	38612
44029	5	105743	3	28737
44030	5	105744	2	40911
44031	4	105745	7	24455
44032	5	105746	7	20667
44033	5	105747	7	21786
44034	3	105747	3	21786
44035	3	105748	5	40937
44036	5	105749	6	7623
44037	5	105750	2	4116
44038	1	105751	1	41012
44039	5	105752	6	41000
44040	4	105754	2	40942
44041	5	105757	1	40819
44042	5	105758	1	8180
44043	3	105759	4	32785
44044	4	105761	7	36161
44045	5	105762	6	14414
44046	2	105763	1	40791
44047	4	105765	1	6858
44048	4	105767	4	2491
44049	5	105772	6	15684
44050	5	105776	4	40877
44051	5	105777	2	23048
44052	5	105778	1	40975
44053	4	105780	1	11093
44054	5	105781	1	1447
44055	5	105785	4	40765
44056	5	105786	6	13606
44057	5	105787	6	40980
44058	5	105787	7	40980
44059	1	105789	6	24440
44060	5	105790	6	40740
44061	5	105791	7	40958
44062	2	105793	1	40735
44063	4	105793	7	40735
44064	5	105794	5	7007
44065	3	105797	7	21461
44066	4	105799	3	3361
44067	5	105800	1	40862
44068	5	105801	7	12227
44069	4	105803	4	36029
44070	5	105805	4	30535
44071	5	105806	2	23096
44072	5	105807	6	40746
44073	4	105809	7	27501
44074	3	105811	5	40751
44075	4	105815	2	16580
44076	3	105816	2	39717
44077	5	105823	3	6544
44078	5	105825	1	30747
44079	3	105828	2	31789
44080	1	105828	6	31789
44081	3	105830	5	40978
44082	4	105831	5	26767
44083	3	105832	3	32524
44084	3	105833	5	17465
44085	5	105835	7	40844
44086	5	105840	6	2185
44087	3	105841	4	23294
44088	4	105843	4	15856
44089	4	105846	2	17695
44090	4	105850	3	4004
44091	5	105851	5	40785
44092	5	105851	1	40785
44093	5	105853	3	35440
44094	2	105854	4	35343
44095	3	105856	5	17747
44096	5	105857	7	40879
44097	4	105858	4	6589
44098	5	105862	2	4274
44099	5	105863	7	34245
44100	4	105866	4	15716
44101	1	105867	6	40816
44102	3	105869	7	25799
44103	5	105870	5	32946
44104	3	105871	1	1885
44105	5	105872	2	126
44106	5	105875	7	6260
44107	5	105879	5	33506
44108	5	105881	6	33010
44109	5	105882	1	7338
44110	5	105884	6	32385
44111	5	105889	2	21502
44112	5	105890	6	21612
44113	4	105891	6	18687
44114	1	105892	7	40965
44115	5	105894	1	40931
44116	3	105895	3	6830
44117	5	105901	7	16615
44118	5	105903	7	40867
44119	3	105903	5	40867
44120	3	105904	7	34124
44121	5	105905	2	40994
44122	4	105906	7	35485
44123	3	105907	4	12397
44124	4	105908	4	14638
44125	5	105910	4	28876
44126	5	105912	5	35218
44127	5	105913	6	29071
44128	4	105919	1	701
44129	4	105922	7	38218
44130	4	105930	7	13375
44131	3	105933	6	41004
44132	5	105934	6	14462
44133	5	105935	5	40808
44134	5	105938	5	40895
44135	3	105940	3	40766
44136	5	105942	4	40770
44137	5	105945	1	40829
44138	5	105948	5	21801
44139	5	105948	6	21801
44140	3	105949	7	41008
44141	3	105952	2	10284
44142	5	105954	6	9925
44143	5	105955	2	8847
44144	5	105956	1	40775
44145	5	105957	6	26472
44146	4	105960	3	40812
44147	5	105965	4	19527
44148	4	105967	4	40798
44149	5	105971	5	14578
44150	5	105972	1	37911
44151	4	105978	3	40825
44152	5	105980	6	8195
44153	4	105981	2	32215
44154	5	105982	5	13996
44155	5	105983	5	40905
44156	5	105984	6	40930
44157	4	105986	3	40858
44158	5	105987	2	36682
44159	4	105988	3	12327
44160	5	105989	6	33094
44161	5	105990	4	743
44162	5	105996	4	23600
44163	5	105997	7	40739
44164	5	105998	7	2863
44165	3	106011	7	25911
44166	5	106012	6	40780
44167	2	106015	6	40768
44168	3	106019	7	33949
44169	5	106020	2	972
44170	4	106025	5	16239
44171	5	106027	2	11495
44172	1	106028	6	40894
44173	5	106032	7	40859
44174	4	106034	1	12717
44175	5	106035	7	10234
44176	3	106036	5	15805
44177	3	106037	5	40769
44178	5	106038	7	40744
44179	4	106039	7	8246
44180	3	106045	4	10651
44181	5	106046	4	18858
44182	5	106046	5	18858
44183	5	106047	7	40779
44184	5	106048	2	6566
44185	5	106051	4	9147
44186	4	106053	6	19914
44187	5	106057	3	4793
44188	5	106058	7	3470
44189	5	106062	2	40764
44190	3	106064	5	40967
44191	4	106068	2	30991
44192	4	106070	5	40820
44193	5	106074	7	40847
44194	5	106077	5	16320
44195	3	106078	5	33258
44196	4	106083	7	40830
44197	4	106086	7	14343
44198	5	106086	3	14343
44199	5	106087	3	40976
44200	4	106090	7	14199
44201	4	106092	4	40971
44202	5	106093	5	37369
44203	5	106094	2	40949
44204	4	106095	4	40795
44205	5	106096	2	6232
44206	4	106098	5	40966
44207	4	106101	2	40745
44208	3	106106	4	40794
44209	3	106109	5	40866
44210	2	106111	7	39674
44211	5	106118	2	40763
44212	5	106120	4	40956
44213	4	106121	4	40756
44214	5	106122	7	9420
44215	5	106123	2	40815
44216	4	106125	7	10621
44217	4	106126	3	40997
44218	4	106129	5	40741
44219	5	106131	5	20876
44220	5	106135	7	14325
44221	3	106136	1	13928
44222	5	106137	3	40960
44223	5	106139	4	4921
44224	5	106141	5	2320
44225	1	106143	5	40981
44226	5	106150	6	40957
44227	3	106152	4	18001
44228	5	106153	2	40837
44229	5	106156	2	2651
44230	4	106160	1	3812
44231	5	106161	6	5829
44232	4	106162	4	30056
44233	5	106165	3	20579
44234	5	106166	1	40996
44235	5	106167	1	31092
44236	5	106168	6	5741
44237	3	106172	1	40989
44238	1	106175	6	14699
44239	5	106179	2	40728
44240	4	106180	3	33698
44241	3	106182	2	41011
44242	3	106184	3	40925
44243	3	106185	7	32285
44244	2	106186	3	40688
44245	5	106189	4	17094
44246	5	106191	3	6615
44247	5	106198	2	33344
44248	5	106201	2	11991
44249	5	106204	3	40823
44250	4	106205	3	40909
44251	4	106207	2	32144
44252	4	106208	1	40906
44253	3	106209	2	30275
44254	4	106211	6	13994
44255	5	106212	6	40961
44256	1	106216	6	8604
44257	5	106220	7	31927
44258	5	106222	2	36142
44259	4	106223	7	40870
44260	3	106225	1	40787
44261	3	106227	6	15093
44262	5	106228	5	40872
44263	5	106230	6	6443
44264	4	106231	4	40991
44265	3	106232	4	13946
44266	5	106235	6	19854
44267	5	106238	7	41003
44268	5	106241	1	11566
44269	3	106245	4	40990
44270	4	106247	6	22500
44271	5	106254	6	26066
44272	4	106259	4	3674
44273	4	106260	2	2422
44274	4	106260	7	2422
44275	2	106262	4	1151
44276	3	106265	1	15769
44277	5	106266	6	7855
44278	4	106267	5	31612
44279	5	106269	4	40924
44280	5	106271	4	39928
44281	5	106275	5	27060
44282	5	106276	7	40784
44283	5	106277	2	40802
44284	5	106281	7	40993
44285	5	106284	6	28617
44286	3	106285	7	41001
44287	3	106286	1	40977
44288	4	106287	6	28090
44289	5	106288	4	35397
44290	4	106289	4	40929
44291	4	106289	2	40929
44292	3	106291	7	41007
44293	5	106296	2	22123
44294	4	106300	7	40951
44295	4	106301	7	26643
44296	3	106304	4	40986
44297	5	106308	7	40855
44298	5	106309	7	32505
44299	5	106312	6	40919
44300	2	106313	4	22515
44301	3	106316	1	12188
44302	4	106320	3	19946
44303	4	106321	5	21074
44304	3	106325	4	35684
44305	5	106326	7	40962
44306	5	106330	2	20288
44307	5	106333	3	24194
44308	3	106335	5	13012
44309	5	106337	2	40750
44310	4	106337	4	40750
44311	4	106339	3	3436
44312	4	106341	7	40851
44313	4	106343	1	27287
44314	5	106344	4	8528
44315	5	106345	6	40857
44316	3	106347	4	35758
44317	5	106350	1	15400
44318	5	106351	2	40761
44319	4	106352	7	40743
44320	5	106353	6	40945
44321	5	106354	2	7710
44322	3	106357	4	13053
44323	5	106358	6	21698
44324	5	106364	5	2390
44325	4	106367	7	20459
44326	4	106369	5	9171
44327	4	106370	7	26028
44328	3	106374	5	40932
44329	5	106376	5	41013
44330	2	106378	6	39630
44331	4	106380	5	15209
44332	4	106383	7	40729
44333	4	106384	3	40727
44334	4	106385	6	40814
44335	5	106386	2	9996
44336	3	106389	3	40758
44337	4	106390	4	13555
44338	5	106390	6	13555
44339	3	106391	4	40888
44340	2	106392	3	13086
44341	5	106394	7	34419
44342	5	106396	7	26345
44343	5	106398	6	40900
44344	5	106399	5	6015
44345	4	106402	5	40821
44346	5	106404	3	35062
44347	5	106407	2	735
44348	4	106407	1	735
44349	5	106408	2	40755
44350	5	106409	7	18684
44351	4	106410	7	28739
44352	4	106412	2	40901
44353	3	106413	7	40914
44354	3	106416	1	29399
44355	5	106417	2	2932
44356	5	106419	7	9374
44357	4	106422	6	1427
44358	5	106426	5	5192
44359	1	106427	6	41076
44360	5	106428	4	2367
44361	5	106429	6	30528
44362	5	106430	7	41190
44363	5	106435	1	17085
44364	4	106439	7	31567
44365	3	106439	2	31567
44366	5	106440	6	28543
44367	4	106441	1	41111
44368	5	106442	4	41181
44369	3	106443	5	29394
44370	3	106447	7	41165
44371	5	106449	2	14902
44372	5	106450	6	41233
44373	3	106452	5	6897
44374	5	106454	4	41187
44375	3	106455	4	103
44376	3	106460	5	1212
44377	5	106461	1	41080
44378	5	106467	6	15271
44379	3	106467	5	15271
44380	4	106468	7	41144
44381	4	106469	1	31743
44382	5	106470	4	41162
44383	4	106471	1	41108
44384	5	106471	7	41108
44385	3	106475	5	41180
44386	5	106477	7	41029
44387	5	106479	6	41075
44388	5	106481	6	34706
44389	4	106482	7	41223
44390	5	106483	3	41176
44391	5	106484	7	41196
44392	4	106485	7	41136
44393	3	106486	5	6276
44394	5	106488	7	720
44395	5	106489	2	39587
44396	5	106495	4	28060
44397	5	106495	6	28060
44398	4	106497	2	41156
44399	5	106499	7	41129
44400	2	106500	6	41183
44401	5	106501	4	2269
44402	1	106502	5	19889
44403	5	106505	4	41033
44404	4	106507	7	41256
44405	4	106507	2	41256
44406	4	106510	5	41175
44407	5	106511	3	27452
44408	5	106514	4	22610
44409	5	106515	6	24452
44410	4	106516	1	38990
44411	5	106517	2	25279
44412	5	106518	6	41267
44413	3	106519	2	16019
44414	3	106519	4	16019
44415	4	106520	3	4393
44416	5	106525	4	16850
44417	3	106525	5	16850
44418	5	106526	5	38955
44419	4	106531	2	29231
44420	4	106532	7	15491
44421	4	106533	5	27102
44422	5	106534	2	1523
44423	3	106535	5	41209
44424	4	106539	5	14378
44425	3	106542	3	29065
44426	5	106543	7	39663
44427	5	106543	3	39663
44428	4	106545	3	5044
44429	5	106548	6	11933
44430	5	106549	2	41137
44431	5	106551	1	14364
44432	5	106554	1	21562
44433	5	106556	7	41221
44434	3	106565	1	26473
44435	5	106570	4	41131
44436	5	106572	6	37303
44437	3	106574	3	1334
44438	4	106576	6	41159
44439	4	106578	4	19729
44440	4	106579	6	41124
44441	5	106580	4	21973
44442	5	106582	6	36366
44443	5	106584	6	41198
44444	5	106585	7	19031
44445	4	106587	7	24101
44446	4	106592	6	18864
44447	5	106596	4	41232
44448	5	106597	4	3619
44449	5	106598	3	9021
44450	3	106601	7	36113
44451	5	106604	3	36161
44452	5	106608	4	9163
44453	5	106611	4	41055
44454	2	106614	4	24031
44455	5	106616	7	17064
44456	5	106618	5	31370
44457	5	106619	6	41226
44458	3	106620	6	3692
44459	5	106621	5	20457
44460	4	106623	7	41154
44461	3	106624	1	27082
44462	3	106629	7	22441
44463	4	106631	7	21003
44464	4	106631	1	21003
44465	5	106632	2	41078
44466	5	106636	4	15549
44467	3	106640	7	21007
44468	4	106646	1	28574
44469	5	106648	6	36615
44470	5	106649	1	2591
44471	5	106650	2	14608
44472	5	106652	6	41248
44473	5	106652	3	41248
44474	5	106653	6	41041
44475	4	106653	5	41041
44476	4	106656	6	9494
44477	4	106657	6	41058
44478	3	106658	5	40431
44479	5	106659	6	40192
44480	5	106660	6	3900
44481	5	106661	5	41030
44482	5	106662	5	27970
44483	5	106663	3	29233
44484	5	106668	2	41064
44485	5	106670	1	38486
44486	4	106671	6	41054
44487	5	106672	3	40710
44488	2	106677	1	41206
44489	5	106678	5	26256
44490	5	106679	7	41169
44491	5	106681	2	26768
44492	3	106681	1	26768
44493	5	106682	7	38804
44494	5	106684	4	41110
44495	5	106685	4	41166
44496	5	106686	6	2552
44497	3	106687	3	41177
44498	5	106688	6	41062
44499	5	106689	5	18203
44500	5	106691	5	28799
44501	4	106692	2	41105
44502	5	106693	7	13878
44503	5	106694	4	41239
44504	5	106697	6	13888
44505	5	106698	2	6298
44506	5	106704	3	5039
44507	5	106705	3	30385
44508	3	106705	4	30385
44509	1	106706	6	29585
44510	1	106709	6	30399
44511	3	106711	7	15511
44512	5	106714	7	39654
44513	4	106722	5	24493
44514	3	106729	4	39841
44515	3	106735	2	41257
44516	4	106738	3	124
44517	5	106742	1	41191
44518	4	106743	3	34704
44519	3	106747	3	21912
44520	4	106748	6	19229
44521	5	106749	2	12305
44522	4	106751	7	41059
44523	5	106751	2	41059
44524	5	106758	2	41016
44525	4	106761	3	35098
44526	5	106763	6	41128
44527	3	106766	7	41040
44528	5	106770	2	41229
44529	3	106770	6	41229
44530	4	106771	4	12790
44531	4	106777	7	6656
44532	5	106778	6	41061
44533	4	106779	5	41182
44534	5	106780	6	41044
44535	4	106783	5	41094
44536	5	106785	4	31480
44537	4	106787	4	30408
44538	5	106788	5	16048
44539	5	106791	3	2426
44540	3	106794	4	4636
44541	5	106801	7	41113
44542	4	106806	7	7293
44543	5	106807	6	11748
44544	5	106808	4	28911
44545	4	106811	5	41095
44546	3	106814	5	41032
44547	4	106814	3	41032
44548	5	106815	6	26186
44549	5	106817	6	12430
44550	4	106822	7	27558
44551	5	106823	1	15199
44552	5	106824	2	41107
44553	4	106825	7	35563
44554	5	106826	4	21805
44555	2	106831	2	3015
44556	5	106832	2	23345
44557	3	106833	2	41106
44558	5	106837	6	6235
44559	5	106840	6	29837
44560	5	106842	1	41070
44561	5	106845	2	37356
44562	5	106848	5	35655
44563	5	106851	1	40232
44564	4	106852	2	7476
44565	5	106856	7	41249
44566	3	106862	3	25292
44567	5	106864	3	10144
44568	4	106867	5	41104
44569	5	106868	6	6381
44570	5	106871	6	41236
44571	4	106872	5	17352
44572	5	106875	5	18283
44573	5	106882	6	37916
44574	5	106882	4	37916
44575	5	106883	5	41261
44576	5	106890	6	41250
44577	3	106892	7	41053
44578	4	106894	6	10123
44579	3	106896	5	41096
44580	2	106897	6	41242
44581	5	106898	7	25227
44582	5	106900	1	41026
44583	5	106905	4	12132
44584	5	106908	5	2631
44585	5	106909	1	2731
44586	4	106911	7	19467
44587	3	106913	1	1660
44588	5	106914	1	32117
44589	3	106914	5	32117
44590	5	106916	4	41203
44591	5	106918	6	17862
44592	5	106920	2	13761
44593	5	106920	6	13761
44594	3	106921	7	8355
44595	4	106923	3	748
44596	3	106925	1	18740
44597	2	106930	3	41074
44598	5	106931	2	2752
44599	3	106933	5	40131
44600	4	106934	2	16456
44601	4	106936	4	41197
44602	4	106939	6	36334
44603	4	106944	1	41150
44604	5	106950	2	16275
44605	3	106953	1	29747
44606	5	106954	6	41167
44607	5	106956	2	5156
44608	4	106959	3	22471
44609	4	106960	2	23806
44610	5	106962	5	9152
44611	5	106965	2	764
44612	4	106966	5	26135
44613	5	106969	4	23692
44614	3	106970	1	41127
44615	3	106973	5	9717
44616	3	106978	7	1452
44617	4	106979	1	29351
44618	3	106984	5	14435
44619	4	106985	7	41067
44620	5	106990	3	41072
44621	3	106991	2	23411
44622	4	106992	3	28932
44623	5	106993	7	6221
44624	5	106994	5	41015
44625	1	106996	6	17421
44626	4	106998	3	4170
44627	3	106999	7	41245
44628	4	107000	7	4186
44629	1	107000	6	4186
44630	5	107001	4	23268
44631	3	107003	6	41068
44632	3	107003	4	41068
44633	5	107004	2	41093
44634	5	107006	6	16440
44635	5	107007	2	31059
44636	4	107008	6	7156
44637	3	107009	7	41082
44638	5	107017	4	40142
44639	5	107020	4	38707
44640	3	107021	5	41151
44641	3	107022	7	21829
44642	3	107028	5	11124
44643	5	107033	5	41195
44644	5	107034	1	35064
44645	4	107036	3	32887
44646	5	107037	1	19248
44647	3	107038	7	41089
44648	4	107039	7	41138
44649	5	107041	6	41234
44650	5	107041	1	41234
44651	5	107043	7	352
44652	4	107048	3	31055
44653	5	107054	6	38368
44654	3	107061	7	35357
44655	5	107061	6	35357
44656	5	107063	5	18870
44657	4	107066	7	12894
44658	3	107068	7	41235
44659	5	107069	6	41189
44660	4	107071	5	33521
44661	3	107075	7	37228
44662	4	107075	3	37228
44663	4	107077	2	41266
44664	3	107079	7	1293
44665	5	107081	6	41132
44666	4	107087	5	20573
44667	3	107090	5	21731
44668	5	107091	5	30763
44669	5	107092	7	41178
44670	5	107094	7	41028
44671	5	107097	6	41219
44672	1	107098	6	41048
44673	5	107099	4	30015
44674	4	107102	7	41446
44675	3	107107	6	28499
44676	5	107109	6	28844
44677	4	107111	7	7437
44678	5	107114	7	13715
44679	5	107116	7	41498
44680	5	107117	5	41470
44681	5	107120	6	35231
44682	4	107123	2	41489
44683	3	107125	2	24541
44684	5	107125	6	24541
44685	3	107132	5	27208
44686	5	107133	5	41282
44687	3	107135	1	41269
44688	4	107136	4	41376
44689	5	107137	5	24184
44690	4	107138	6	21959
44691	5	107139	1	25649
44692	4	107140	6	41389
44693	5	107142	4	17894
44694	3	107146	3	41429
44695	2	107151	3	23298
44696	5	107152	6	28491
44697	5	107154	6	13982
44698	5	107156	7	8092
44699	1	107158	6	41451
44700	4	107161	7	41287
44701	4	107161	5	41287
44702	5	107164	7	41467
44703	4	107165	2	36710
44704	4	107170	7	24877
44705	5	107176	5	19970
44706	5	107177	1	35885
44707	3	107182	1	31943
44708	5	107185	2	21901
44709	5	107188	2	30607
44710	4	107189	7	41403
44711	5	107190	3	10336
44712	4	107194	7	41453
44713	5	107200	7	41295
44714	1	107205	5	41359
44715	3	107207	5	28488
44716	3	107210	4	10689
44717	5	107213	2	33203
44718	5	107218	4	41399
44719	4	107221	4	41485
44720	5	107222	7	4983
44721	4	107224	4	17797
44722	5	107225	4	27021
44723	3	107226	1	748
44724	5	107227	6	2166
44725	2	107228	3	41283
44726	5	107230	6	8770
44727	5	107232	2	33775
44728	5	107234	3	41503
44729	4	107235	5	41334
44730	5	107238	1	18085
44731	4	107241	7	19199
44732	4	107242	5	41501
44733	5	107250	1	41378
44734	5	107250	6	41378
44735	5	107252	6	11006
44736	4	107253	4	39006
44737	5	107254	5	23810
44738	5	107255	2	27291
44739	2	107255	3	27291
44740	4	107261	2	3431
44741	3	107263	7	41408
44742	4	107264	5	11992
44743	5	107265	7	38871
44744	3	107268	5	21937
44745	5	107268	2	21937
44746	5	107273	7	41411
44747	5	107277	2	24935
44748	5	107279	6	41342
44749	5	107281	4	29929
44750	5	107283	6	24987
44751	3	107287	5	3942
44752	5	107288	6	6442
44753	5	107291	4	41365
44754	5	107292	6	39556
44755	5	107293	3	14759
44756	5	107294	1	41277
44757	5	107295	1	41356
44758	5	107297	2	37142
44759	5	107298	4	41419
44760	5	107299	3	27306
44761	4	107305	7	41430
44762	5	107310	2	6751
44763	4	107313	4	23714
44764	5	107313	7	23714
44765	3	107315	1	13045
44766	5	107317	7	41381
44767	5	107320	4	41452
44768	5	107324	4	41372
44769	5	107331	1	33185
44770	5	107334	1	23554
44771	3	107336	7	562
44772	3	107339	4	493
44773	1	107340	6	22262
44774	4	107342	7	10896
44775	4	107343	4	26359
44776	5	107344	5	27057
44777	3	107348	7	40116
44778	5	107349	5	41497
44779	5	107350	4	41387
44780	4	107353	1	16655
44781	4	107357	1	9688
44782	4	107357	6	9688
44783	3	107363	2	41487
44784	3	107366	5	14775
44785	4	107367	7	41315
44786	5	107370	4	22363
44787	4	107373	2	12103
44788	5	107374	4	27319
44789	4	107376	5	41353
44790	4	107377	6	24263
44791	5	107378	6	41274
44792	5	107379	1	4805
44793	5	107381	7	16910
44794	4	107382	5	23113
44795	5	107384	5	41448
44796	5	107385	6	41410
44797	5	107385	1	41410
44798	4	107387	2	39944
44799	4	107389	4	25877
44800	5	107390	2	32444
44801	4	107391	3	2285
44802	3	107392	1	41338
44803	5	107396	6	31581
44804	5	107397	1	22691
44805	5	107399	4	3858
44806	5	107400	7	27908
44807	5	107403	6	13881
44808	2	107404	3	41395
44809	4	107407	7	31510
44810	3	107413	1	41416
44811	5	107416	1	41374
44812	5	107417	4	35682
44813	3	107420	5	28305
44814	5	107421	3	41329
44815	5	107422	4	27085
44816	4	107423	7	12771
44817	4	107423	2	12771
44818	3	107424	5	41500
44819	3	107425	5	33943
44820	5	107429	2	35660
44821	4	107429	4	35660
44822	5	107430	4	41293
44823	4	107432	4	24980
44824	4	107446	1	11676
44825	5	107447	5	38091
44826	4	107448	6	20229
44827	3	107451	2	41393
44828	5	107453	4	31695
44829	4	107454	3	28618
44830	3	107454	7	28618
44831	5	107455	6	39902
44832	5	107457	6	38866
44833	1	107458	7	36271
44834	5	107459	2	11766
44835	2	107461	1	19707
44836	5	107462	5	25997
44837	5	107463	5	41447
44838	5	107465	2	8506
44839	5	107466	2	24639
44840	5	107468	3	9682
44841	5	107469	5	41441
44842	4	107470	4	41400
44843	5	107471	2	41343
44844	2	107473	3	41124
44845	5	107479	2	6596
44846	4	107490	7	33916
44847	4	107491	1	40065
44848	5	107495	6	24967
44849	5	107497	6	41499
44850	3	107498	5	20792
44851	4	107504	5	41461
44852	4	107505	4	9976
44853	5	107508	4	21352
44854	5	107509	2	2451
44855	5	107510	1	3680
44856	4	107511	4	5483
44857	5	107514	2	41333
44858	3	107519	7	41459
44859	5	107522	6	36375
44860	5	107529	6	41360
44861	5	107532	5	18035
44862	5	107536	7	15244
44863	5	107538	3	30647
44864	5	107540	6	12017
44865	4	107548	6	41426
44866	4	107549	7	16239
44867	3	107550	1	41435
44868	5	107551	1	8212
44869	4	107554	7	31724
44870	4	107555	4	22496
44871	4	107556	6	41278
44872	4	107560	5	17545
44873	5	107561	2	15386
44874	4	107563	4	34745
44875	5	107566	2	41388
44876	5	107571	4	36405
44877	5	107584	6	2590
44878	5	107585	7	6173
44879	3	107586	1	4183
44880	5	107586	5	4183
44881	5	107591	7	41332
44882	4	107592	7	39737
44883	3	107594	5	29527
44884	5	107597	6	41436
44885	5	107598	5	41270
44886	5	107599	3	39344
44887	4	107600	5	41442
44888	4	107600	2	41442
44889	5	107601	2	41339
44890	5	107602	5	20158
44891	4	107604	5	41462
44892	5	107605	3	6758
44893	3	107606	5	7231
44894	5	107608	6	22056
44895	2	107611	1	20338
44896	2	107612	7	5808
44897	5	107613	7	11409
44898	5	107621	2	30167
44899	4	107624	6	39418
44900	4	107632	3	19750
44901	1	107633	6	11046
44902	5	107636	5	41380
44903	4	107636	6	41380
44904	5	107638	5	9711
44905	5	107639	5	15626
44906	5	107640	2	27777
44907	4	107642	7	34309
44908	5	107644	5	41418
44909	1	107650	1	34707
44910	5	107651	4	22341
44911	5	107654	6	31365
44912	3	107654	5	31365
44913	5	107655	6	29328
44914	5	107656	6	2552
44915	4	107658	7	41478
44916	5	107659	6	41479
44917	5	107662	2	5508
44918	3	107663	7	25125
44919	5	107666	3	24996
44920	5	107668	6	24210
44921	5	107669	7	41486
44922	4	107671	5	28537
44923	4	107672	5	39946
44924	5	107676	2	12578
44925	5	107678	4	35492
44926	5	107679	2	24343
44927	5	107680	5	41493
44928	5	107680	6	41493
44929	5	107683	2	41272
44930	5	107685	1	11407
44931	5	107687	6	41341
44932	4	107688	4	41318
44933	5	107689	6	41299
44934	4	107692	6	27492
44935	1	107692	1	27492
44936	5	107696	3	41300
44937	5	107699	4	13637
44938	5	107701	6	28249
44939	3	107704	3	14473
44940	1	107705	4	27332
44941	5	107706	3	41326
44942	5	107710	7	23579
44943	3	107713	7	32332
44944	3	107718	1	41323
44945	5	107719	4	13874
44946	5	107723	4	13790
44947	5	107724	1	30476
44948	3	107725	1	28912
44949	5	107728	5	18090
44950	5	107730	4	10435
44951	3	107731	1	614
44952	3	107731	7	614
44953	5	107732	4	4943
44954	3	107738	7	19358
44955	5	107739	2	33750
44956	4	107745	5	41667
44957	2	107748	3	31117
44958	5	107749	6	5447
44959	5	107750	4	41672
44960	5	107751	6	41508
44961	3	107754	5	8065
44962	4	107756	3	6308
44963	3	107757	1	17934
44964	3	107759	3	39006
44965	4	107760	5	31981
44966	5	107762	7	41568
44967	5	107765	1	24082
44968	5	107772	2	7122
44969	5	107777	6	35581
44970	5	107778	4	17620
44971	5	107780	3	26383
44972	3	107784	7	26163
44973	5	107787	7	36632
44974	5	107791	7	17308
44975	5	107792	2	5515
44976	5	107794	6	33261
44977	4	107795	5	2668
44978	4	107796	1	28411
44979	4	107797	2	41557
44980	5	107798	4	11202
44981	5	107798	7	11202
44982	5	107799	6	2780
44983	3	107801	5	41704
44984	5	107801	4	41704
44985	5	107804	7	20377
44986	5	107806	4	41616
44987	4	107807	2	19637
44988	5	107808	4	27938
44989	3	107813	2	25190
44990	2	107817	3	13968
44991	3	107818	7	1549
44992	5	107823	2	39024
44993	5	107823	4	39024
44994	5	107824	6	38469
44995	5	107825	1	25788
44996	4	107826	5	37013
44997	5	107829	7	20330
44998	4	107830	6	7338
44999	5	107831	7	18390
45000	5	107833	7	18386
45001	5	107835	2	11438
45002	4	107836	1	32288
45003	4	107838	5	41559
45004	3	107839	1	39095
45005	5	107840	5	34682
45006	5	107844	6	41574
45007	3	107846	3	41585
45008	3	107847	5	18530
45009	5	107848	4	37097
45010	3	107853	4	21600
45011	4	107854	6	1517
45012	4	107858	7	41514
45013	5	107859	2	39825
45014	4	107861	7	5512
45015	3	107864	6	20646
45016	5	107867	6	6173
45017	5	107869	2	9295
45018	4	107870	5	31172
45019	5	107872	6	24594
45020	5	107874	4	39357
45021	1	107876	6	24395
45022	3	107877	6	38673
45023	4	107880	7	41532
45024	5	107886	7	29777
45025	1	107890	2	3052
45026	3	107893	7	41668
45027	5	107895	6	32144
45028	4	107896	1	41556
45029	3	107897	4	21507
45030	5	107902	4	8729
45031	2	107902	7	8729
45032	5	107905	4	41621
45033	5	107910	7	10527
45034	4	107915	3	1591
45035	5	107921	6	41620
45036	4	107922	2	4992
45037	5	107923	3	41601
45038	5	107924	7	41680
45039	4	107925	4	29844
45040	4	107931	2	3949
45041	5	107934	2	8229
45042	5	107937	4	41662
45043	4	107940	4	8860
45044	5	107945	6	38897
45045	5	107954	5	31056
45046	5	107956	1	41594
45047	5	107960	6	11961
45048	5	107961	3	4142
45049	5	107963	3	41523
45050	5	107966	2	13928
45051	4	107972	7	35806
45052	4	107978	7	39891
45053	4	107981	5	21760
45054	1	107983	6	22364
45055	3	107985	1	25722
45056	3	107987	1	41685
45057	5	107991	4	6007
45058	4	107992	4	7809
45059	5	107995	4	39527
45060	4	107999	7	37213
45061	5	108001	2	41665
45062	5	108003	7	41581
45063	4	108009	2	18491
45064	3	108010	5	1814
45065	5	108014	1	41626
45066	3	108015	5	41526
45067	5	108016	2	17502
45068	5	108019	2	15653
45069	5	108027	7	28074
45070	5	108029	2	32912
45071	5	108031	5	13141
45072	5	108035	2	17329
45073	5	108037	4	32060
45074	5	108041	5	14237
45075	5	108042	3	5889
45076	5	108043	4	12397
45077	5	108046	6	30384
45078	5	108050	2	41696
45079	4	108057	5	21855
45080	3	108059	1	27544
45081	5	108062	4	17808
45082	3	108063	1	270
45083	5	108066	1	28553
45084	5	108068	2	32067
45085	3	108070	6	23698
45086	5	108075	4	41619
45087	5	108076	6	11998
45088	4	108077	2	8365
45089	4	108079	4	41549
45090	5	108082	7	34507
45091	1	108083	7	7387
45092	4	108086	5	9003
45093	5	108088	4	41565
45094	5	108091	1	16810
45095	5	108092	2	41625
45096	3	108097	5	41598
45097	5	108100	7	41518
45098	5	108102	6	41588
45099	5	108103	6	19803
45100	5	108104	1	38777
45101	5	108106	2	7886
45102	4	108110	7	13179
45103	5	108112	7	41675
45104	5	108113	5	31975
45105	4	108116	1	5309
45106	3	108123	7	2052
45107	3	108124	5	24573
45108	5	108126	4	17929
45109	5	108127	4	41529
45110	5	108130	1	25532
45111	5	108132	6	41699
45112	5	108132	5	41699
45113	4	108134	2	41632
45114	1	108137	6	29099
45115	5	108142	4	41659
45116	5	108149	2	41547
45117	5	108150	5	41713
45118	3	108152	5	23467
45119	5	108154	6	36421
45120	5	108156	7	701
45121	5	108157	2	15890
45122	4	108158	1	38387
45123	5	108163	6	16367
45124	3	108164	2	41628
45125	5	108164	4	41628
45126	5	108165	3	27567
45127	3	108166	7	32571
45128	5	108169	6	41693
45129	4	108170	7	28584
45130	3	108176	2	41522
45131	5	108178	6	31212
45132	3	108181	1	32687
45133	5	108186	6	32520
45134	1	108189	6	21008
45135	4	108190	7	41573
45136	5	108194	4	3012
45137	3	108196	1	11840
45138	5	108197	4	8035
45139	5	108198	4	41650
45140	5	108200	3	41645
45141	5	108201	5	41587
45142	5	108202	2	12018
45143	5	108203	7	34423
45144	5	108203	2	34423
45145	5	108216	5	35910
45146	5	108218	7	22197
45147	4	108221	7	29695
45148	4	108225	7	6895
45149	4	108228	5	10679
45150	4	108235	5	41524
45151	5	108236	1	15182
45152	5	108238	4	41519
45153	5	108239	2	27680
45154	3	108240	5	41553
45155	4	108241	3	33076
45156	5	108242	6	32802
45157	5	108243	6	13005
45158	4	108244	6	14357
45159	3	108245	4	4822
45160	3	108251	5	41569
45161	3	108254	3	25181
45162	4	108258	7	12031
45163	5	108262	5	41715
45164	4	108265	6	30074
45165	5	108271	3	9107
45166	5	108281	2	6630
45167	3	108285	2	13760
45168	4	108288	2	26839
45169	3	108305	7	5205
45170	5	108308	4	16834
45171	5	108308	6	16834
45172	5	108309	6	26281
45173	5	108310	2	28396
45174	3	108311	7	33683
45175	5	108313	2	15767
45176	5	108317	6	41686
45177	5	108319	6	5919
45178	5	108320	7	29504
45179	5	108323	2	10456
45180	5	108323	1	10456
45181	3	108324	5	15679
45182	5	108325	6	30498
45183	3	108327	6	16222
45184	4	108328	7	15405
45185	5	108329	2	41521
45186	5	108330	5	41544
45187	5	108331	7	41669
45188	5	108332	2	1801
45189	5	108334	7	12181
45190	1	108334	6	12181
45191	3	108336	1	40499
45192	4	108337	7	36708
45193	4	108338	5	11263
45194	5	108341	5	40039
45195	2	108344	1	1085
45196	3	108345	7	41593
45197	5	108349	7	8848
45198	3	108354	3	31835
45199	5	108354	5	31835
45200	4	108356	7	41507
45201	5	108357	1	41515
45202	4	108359	7	41599
45203	3	108363	1	41708
45204	3	108364	3	41694
45205	4	108366	1	3119
45206	3	108367	3	41618
45207	5	108371	7	41614
45208	5	108372	4	8620
45209	4	108374	5	41558
45210	4	108376	4	13300
45211	4	108376	2	13300
45212	5	108377	7	41542
45213	2	108381	7	14331
45214	4	108382	7	21081
45215	5	108382	6	21081
45216	3	108390	6	41530
45217	5	108391	1	41638
45218	5	108391	7	41638
45219	5	108392	6	19506
45220	5	108394	6	20631
45221	1	108395	6	8010
45222	5	108398	2	35254
45223	5	108403	7	7202
45224	5	108408	4	41710
45225	3	108409	3	25454
45226	4	108410	1	41590
45227	5	108411	6	18101
45228	4	108412	7	25942
45229	3	108417	1	35084
45230	3	108418	4	41655
45231	5	108421	5	38451
45232	5	108422	1	30841
45233	5	108423	2	34517
45234	5	108425	6	41554
45235	4	108426	2	41697
45236	3	108427	2	41627
45237	5	108428	1	7591
45238	5	108431	7	26062
45239	4	108434	5	19399
45240	3	108435	1	12068
45241	5	108437	6	21705
45242	5	108438	7	7595
45243	5	108439	3	41509
45244	2	108440	5	22511
45245	3	108441	7	22131
45246	5	108442	1	14243
45247	4	108443	2	26808
45248	5	108444	2	7951
45249	4	108446	7	948
45250	5	108449	1	13580
45251	3	108451	5	36854
45252	5	108452	6	41705
45253	4	108455	4	17996
45254	5	108465	6	36794
45255	4	108467	7	9682
45256	5	108469	6	23184
45257	5	108470	3	6749
45258	4	108471	6	27026
45259	5	108472	2	1657
45260	5	108472	1	1657
45261	5	108475	2	17121
45262	3	108476	3	41560
45263	3	108478	5	4644
45264	4	108479	7	41646
45265	5	108483	3	27239
45266	3	108485	1	41624
45267	5	108486	1	20524
45268	2	108489	3	90
45269	4	108490	5	41548
45270	5	108492	6	34631
45271	4	108496	7	10305
45272	4	108505	4	17268
45273	4	108507	2	41608
45274	5	108508	7	11933
45275	5	108509	6	41240
45276	3	108510	7	6037
45277	5	108512	3	6480
45278	1	108515	1	41540
45279	3	108516	4	23835
45280	5	108517	6	41615
45281	3	108520	6	41651
45282	5	108521	5	20534
45283	5	108524	4	41939
45284	2	108530	7	41875
45285	3	108533	6	40583
45286	5	108534	7	18245
45287	5	108535	5	17341
45288	5	108536	2	20440
45289	3	108537	7	40611
45290	3	108539	2	19603
45291	4	108540	3	40066
45292	5	108541	5	41794
45293	5	108543	6	28151
45294	4	108545	7	41974
45295	5	108547	2	41764
45296	5	108549	6	25044
45297	1	108550	6	1362
45298	5	108552	7	29189
45299	3	108557	7	19303
45300	1	108558	3	729
45301	5	108559	2	4347
45302	4	108560	5	34034
45303	3	108562	7	38569
45304	4	108563	5	41726
45305	5	108564	2	31002
45306	4	108568	4	41956
45307	3	108571	6	38157
45308	5	108576	6	15930
45309	4	108580	1	36330
45310	5	108583	7	4147
45311	3	108585	3	18468
45312	4	108588	4	3823
45313	5	108599	7	29345
45314	5	108601	3	27147
45315	3	108602	1	15481
45316	3	108602	7	15481
45317	3	108603	5	5746
45318	4	108608	2	12282
45319	3	108609	2	41815
45320	3	108610	1	6410
45321	3	108614	5	17460
45322	5	108618	5	8644
45323	5	108620	4	41964
45324	5	108623	6	32824
45325	5	108634	4	15323
45326	4	108635	3	8045
45327	5	108639	1	41940
45328	5	108639	6	41940
45329	5	108640	1	41863
45330	5	108645	6	30917
45331	5	108647	3	13279
45332	5	108650	6	16749
45333	5	108650	2	16749
45334	1	108652	6	41749
45335	5	108656	3	18311
45336	4	108658	7	41897
45337	5	108660	2	41755
45338	3	108664	3	41843
45339	5	108671	6	19572
45340	4	108673	1	17005
45341	4	108675	6	41720
45342	5	108676	2	33533
45343	4	108681	3	16194
45344	5	108681	1	16194
45345	3	108682	7	39464
45346	1	108683	6	41775
45347	5	108684	7	29004
45348	4	108686	3	29339
45349	3	108688	5	19892
45350	4	108691	6	41778
45351	5	108693	6	22595
45352	4	108696	5	41976
45353	4	108697	5	9065
45354	5	108701	7	1269
45355	5	108707	6	13370
45356	3	108710	5	41791
45357	5	108713	7	41829
45358	5	108715	1	41891
45359	3	108717	5	40517
45360	5	108721	7	41910
45361	2	108722	3	38062
45362	5	108723	7	28362
45363	5	108724	6	35158
45364	5	108724	2	35158
45365	5	108727	7	41942
45366	1	108728	6	15873
45367	5	108730	7	33891
45368	5	108731	6	41874
45369	3	108733	7	41902
45370	5	108735	5	36182
45371	4	108735	4	36182
45372	3	108737	4	999
45373	5	108739	2	41922
45374	5	108744	5	41975
45375	3	108746	5	20218
45376	4	108748	6	40476
45377	1	108751	6	16709
45378	4	108754	2	41860
45379	3	108756	5	23506
45380	4	108756	7	23506
45381	5	108758	4	41727
45382	3	108758	5	41727
45383	5	108759	5	13656
45384	5	108760	7	41928
45385	5	108763	2	40139
45386	5	108764	2	26065
45387	5	108765	6	41811
45388	5	108767	2	820
45389	5	108771	3	33324
45390	5	108773	7	34232
45391	5	108775	6	15954
45392	4	108777	6	8792
45393	5	108779	7	14475
45394	4	108780	7	4892
45395	4	108782	5	34208
45396	5	108783	7	17434
45397	4	108785	3	6182
45398	5	108786	6	41973
45399	5	108787	6	22238
45400	3	108788	5	41917
45401	5	108789	2	41780
45402	4	108793	3	456
45403	5	108795	3	21130
45404	5	108801	7	41721
45405	3	108803	6	33547
45406	5	108804	2	25299
45407	5	108805	6	29851
45408	5	108808	6	18400
45409	5	108809	5	41856
45410	3	108810	4	41723
45411	3	108813	4	17809
45412	3	108814	2	25255
45413	5	108816	3	25799
45414	2	108821	6	41739
45415	5	108822	6	30864
45416	5	108825	1	7151
45417	5	108831	6	41894
45418	5	108832	6	658
45419	4	108833	4	41734
45420	4	108833	1	41734
45421	5	108835	2	41921
45422	5	108841	6	41802
45423	1	108844	2	41757
45424	3	108846	3	30534
45425	5	108850	1	41908
45426	5	108852	4	15639
45427	5	108853	2	5685
45428	5	108856	5	13084
45429	5	108858	4	40511
45430	3	108858	1	40511
45431	1	108859	6	41979
45432	3	108862	7	30155
45433	5	108863	5	41306
45434	5	108864	7	41933
45435	5	108867	7	41924
45436	5	108868	3	2089
45437	5	108873	7	31882
45438	4	108874	3	1243
45439	5	108876	7	5311
45440	5	108881	3	1101
45441	5	108885	2	41865
45442	5	108887	1	25053
45443	5	108891	6	1383
45444	4	108892	5	41816
45445	1	108896	6	36805
45446	5	108897	5	41869
45447	5	108898	5	16193
45448	3	108900	3	19940
45449	1	108901	2	10283
45450	5	108906	6	26596
45451	4	108908	7	27283
45452	5	108909	6	41937
45453	5	108909	2	41937
45454	4	108912	7	1676
45455	5	108913	2	5729
45456	4	108914	6	41793
45457	5	108917	2	3976
45458	3	108918	7	41899
45459	5	108921	6	35663
45460	5	108921	7	35663
45461	5	108922	4	8307
45462	3	108923	1	18878
45463	4	108924	5	41907
45464	3	108925	5	41886
45465	2	108927	6	41941
45466	3	108938	1	13651
45467	4	108940	7	6065
45468	4	108944	1	29134
45469	5	108947	3	41888
45470	5	108948	7	18209
45471	5	108949	2	24684
45472	5	108952	6	13319
45473	4	108954	2	41977
45474	4	108954	6	41977
45475	4	108966	5	41712
45476	1	108967	4	41827
45477	5	108968	6	34463
45478	3	108971	7	41732
45479	4	108973	7	4205
45480	5	108974	6	11709
45481	4	108977	5	2274
45482	5	108977	2	2274
45483	4	108979	4	1462
45484	5	108983	3	23427
45485	5	108984	2	24047
45486	3	108985	5	29881
45487	5	108987	1	14495
45488	5	108991	7	41763
45489	5	108991	6	41763
45490	3	108992	1	41857
45491	5	108995	1	18007
45492	5	108995	6	18007
45493	5	108999	2	18682
45494	4	109008	2	41855
45495	3	109009	1	5141
45496	4	109011	4	19313
45497	5	109012	3	41743
45498	5	109014	3	26382
45499	5	109014	4	26382
45500	5	109015	6	4223
45501	5	109017	5	31631
45502	3	109018	3	1255
45503	5	109019	7	2056
45504	4	109020	3	1700
45505	5	109022	4	28446
45506	4	109024	4	37142
45507	5	109025	2	29693
45508	5	109029	1	41736
45509	5	109031	6	41929
45510	4	109032	6	14984
45511	4	109038	5	13000
45512	4	109040	7	6028
45513	3	109041	2	684
45514	5	109050	6	29697
45515	5	109051	6	41733
45516	3	109051	3	41733
45517	5	109053	4	11206
45518	5	109055	6	8146
45519	5	109057	6	11613
45520	5	109059	4	41934
45521	5	109061	3	30597
45522	5	109062	5	41760
45523	5	109064	4	12517
45524	3	109065	1	41820
45525	3	109069	5	28405
45526	4	109070	2	41735
45527	5	109074	6	13320
45528	5	109076	1	29231
45529	5	109078	3	19968
45530	3	109078	4	19968
45531	3	109082	5	19827
45532	4	109083	4	41776
45533	4	109085	5	41796
45534	4	109086	7	22210
45535	5	109087	5	15188
45536	5	109088	2	27124
45537	4	109092	5	41792
45538	3	109093	4	7451
45539	5	109096	6	27539
45540	5	109097	2	3048
45541	5	109100	6	41909
45542	5	109100	4	41909
45543	4	109103	2	1355
45544	4	109107	7	21623
45545	4	109110	5	9166
45546	3	109115	1	17038
45547	4	109116	3	41744
45548	4	109117	1	41968
45549	4	109118	2	3160
45550	4	109122	2	36612
45551	4	109125	1	37041
45552	4	109131	3	33938
45553	5	109132	7	41980
45554	5	109133	2	2627
45555	5	109134	5	41847
45556	3	109135	1	33452
45557	5	109140	6	24676
45558	3	109143	2	41889
45559	3	109145	3	41761
45560	5	109148	5	34252
45561	4	109149	7	10016
45562	4	109149	6	10016
45563	3	109152	7	41771
45564	3	109153	1	41810
45565	4	109155	7	41965
45566	5	109156	5	26090
45567	5	109157	4	6201
45568	3	109159	5	1879
45569	5	109162	3	30659
45570	3	109163	5	5097
45571	5	109165	1	39118
45572	5	109167	1	8651
45573	4	109168	4	41967
45574	5	109169	5	21031
45575	5	109170	2	20080
45576	3	109171	2	9011
45577	5	109173	3	41900
45578	4	109175	7	18716
45579	3	109176	4	25502
45580	5	109178	3	7415
45581	3	109179	5	25202
45582	4	109181	4	41930
45583	5	109181	7	41930
45584	5	109190	4	34075
45585	4	109192	3	19720
45586	5	109197	2	41717
45587	5	109197	1	41717
45588	3	109199	7	41905
45589	5	109200	2	3102
45590	4	109201	3	7098
45591	5	109205	1	37597
45592	5	109205	2	37597
45593	5	109206	1	1335
45594	4	109208	2	2928
45595	4	109210	2	13040
45596	4	109211	2	6708
45597	3	109212	5	13660
45598	4	109213	3	31037
45599	5	109218	2	1952
45600	4	109219	7	17226
45601	3	109220	7	1293
45602	5	109221	2	28225
45603	5	109222	2	41978
45604	3	109224	3	38872
45605	5	109228	4	25079
45606	5	109237	2	29678
45607	5	109238	7	39323
45608	5	109239	1	7582
45609	3	109240	7	41919
45610	5	109245	2	29898
45611	5	109252	6	3434
45612	4	109255	5	35763
45613	4	109258	2	37473
45614	5	109261	2	3148
45615	4	109263	1	18643
45616	4	109263	3	18643
45617	5	109264	1	26163
45618	3	109265	3	41754
45619	4	109268	6	16870
45620	5	109269	6	28442
45621	4	109272	3	26393
45622	3	109273	7	41728
45623	5	109278	7	10489
45624	5	109280	7	41840
45625	5	109282	2	23362
45626	4	109285	7	1774
45627	5	109287	7	41751
45628	1	109290	6	41730
45629	5	109290	5	41730
45630	4	109291	3	35910
45631	3	109293	2	41146
45632	5	109295	7	41740
45633	5	109297	4	41808
45634	3	109299	7	16957
45635	5	109300	4	24575
45636	5	109301	4	27960
45637	5	109306	7	437
45638	5	109309	4	27589
45639	4	109310	7	8410
45640	5	109314	7	41848
45641	2	109316	4	22311
45642	5	109317	2	36949
45643	5	109320	6	6015
45644	5	109322	4	18129
45645	5	109324	7	41773
45646	5	109325	5	18838
45647	4	109326	5	10850
45648	3	109327	6	41203
45649	3	109328	7	23193
45650	1	109329	6	15777
45651	5	109331	7	7431
45652	4	109337	5	31661
45653	3	109342	7	37014
45654	3	109343	5	41963
45655	5	109346	1	18322
45656	5	109353	6	38950
45657	3	109357	3	41960
45658	4	109358	7	39432
45659	3	109362	5	41885
45660	4	109365	5	21377
45661	1	109367	7	34253
45662	3	109370	1	30311
45663	4	109377	7	23378
45664	5	109377	1	23378
45665	4	109378	4	9297
45666	3	109383	4	41981
45667	4	109384	1	11096
45668	4	109386	6	32734
45669	5	109387	6	7833
45670	5	109388	7	26901
45671	3	109393	7	41959
45672	3	109394	5	41750
45673	4	109395	7	29856
45674	3	109396	1	6009
45675	5	109399	4	14427
45676	5	109401	2	29618
45677	5	109402	2	9995
45678	4	109406	5	16791
45679	5	109407	7	41783
45680	4	109410	1	232
45681	5	109413	6	41867
45682	3	109414	1	22973
45683	5	109416	5	21501
45684	3	109417	1	41880
45685	5	109419	3	22813
45686	5	109423	4	41966
45687	4	109424	7	22487
45688	5	109424	6	22487
45689	5	109425	2	25430
45690	3	109428	2	41879
45691	4	109429	5	41724
45692	3	109435	3	32455
45693	3	109437	7	14937
45694	4	109440	2	27082
45695	5	109445	6	16755
45696	2	109446	6	5485
45697	4	109447	3	12905
45698	4	109453	6	38421
45699	5	109461	2	31856
45700	1	109462	4	42108
45701	1	109463	6	42216
45702	1	109465	1	42051
45703	5	109471	3	42102
45704	3	109473	1	2855
45705	5	109476	7	42187
45706	4	109477	7	42011
45707	5	109477	6	42011
45708	5	109479	2	27783
45709	5	109481	5	5707
45710	4	109483	6	20957
45711	3	109485	5	42207
45712	4	109491	1	24221
45713	5	109494	1	26343
45714	3	109496	7	14982
45715	4	109502	4	28780
45716	4	109502	6	28780
45717	4	109506	4	42117
45718	5	109509	6	42221
45719	3	109510	4	5994
45720	5	109511	7	23668
45721	5	109512	7	42179
45722	3	109514	1	42162
45723	5	109517	4	41992
45724	5	109519	2	38771
45725	3	109526	5	32820
45726	4	109527	5	42000
45727	3	109528	4	2778
45728	1	109529	6	19498
45729	3	109530	6	34640
45730	5	109531	2	7304
45731	5	109532	6	42192
45732	4	109535	5	41997
45733	4	109536	5	35055
45734	4	109537	3	30769
45735	2	109540	6	31243
45736	5	109550	3	37323
45737	4	109552	5	42172
45738	5	109553	6	13881
45739	5	109565	3	9907
45740	3	109572	5	42118
45741	5	109575	7	18133
45742	3	109576	7	14138
45743	3	109578	6	10892
45744	5	109579	2	2387
45745	4	109581	3	35511
45746	5	109582	2	37244
45747	4	109584	5	42223
45748	3	109587	4	709
45749	5	109588	7	34368
45750	4	109591	1	8112
45751	5	109592	4	13272
45752	5	109594	1	24766
45753	4	109595	3	17211
45754	5	109596	6	42141
45755	5	109600	6	15407
45756	3	109601	4	42021
45757	3	109607	5	23350
45758	2	109609	2	25840
45759	5	109611	3	42159
45760	3	109612	1	42231
45761	5	109613	2	42176
45762	5	109617	5	3799
45763	4	109621	5	26247
45764	3	109623	6	12650
45765	5	109623	2	12650
45766	5	109626	7	42138
45767	2	109628	6	42065
45768	3	109631	6	11254
45769	4	109632	7	4042
45770	3	109633	1	8410
45771	3	109633	5	8410
45772	5	109635	4	15017
45773	5	109638	7	18283
45774	5	109640	6	42142
45775	4	109642	4	6730
45776	2	109646	3	24853
45777	1	109648	6	15302
45778	5	109649	1	12540
45779	5	109653	4	42104
45780	5	109659	3	40617
45781	5	109666	6	42131
45782	4	109674	7	37954
45783	5	109676	6	42147
45784	3	109677	5	26307
45785	4	109679	5	16901
45786	5	109681	6	31480
45787	3	109684	7	5983
45788	2	109685	4	33683
45789	3	109689	2	31940
45790	4	109692	6	5976
45791	5	109693	7	28316
45792	5	109694	6	21671
45793	3	109695	3	4207
45794	5	109698	1	8651
45795	4	109699	2	42180
45796	5	109701	2	39103
45797	5	109702	4	25239
45798	5	109703	7	41294
45799	5	109706	2	17327
45800	4	109707	3	17872
45801	5	109708	1	42073
45802	4	109709	3	4100
45803	3	109711	1	42064
45804	5	109713	7	19939
45805	4	109715	3	33900
45806	5	109718	2	30416
45807	5	109721	7	21282
45808	5	109726	7	42067
45809	5	109727	5	37485
45810	5	109727	4	37485
45811	5	109733	4	41022
45812	5	109734	4	12211
45813	5	109735	1	22858
45814	5	109736	6	42212
45815	5	109738	1	42043
45816	5	109740	2	42106
45817	3	109741	5	41993
45818	5	109742	2	30413
45819	5	109743	7	35167
45820	5	109748	4	42184
45821	5	109751	7	16908
45822	3	109752	7	4589
45823	5	109753	1	31719
45824	5	109754	6	33339
45825	1	109755	1	2819
45826	5	109757	6	11225
45827	4	109760	1	42199
45828	5	109768	1	18901
45829	3	109770	5	40204
45830	5	109771	7	30512
45831	4	109775	4	25107
45832	3	109776	5	6678
45833	5	109777	2	42056
45834	5	109777	7	42056
45835	3	109779	5	4039
45836	3	109781	3	8019
45837	4	109782	6	42200
45838	4	109783	6	16850
45839	3	109786	5	21770
45840	5	109788	2	17594
45841	5	109791	6	16568
45842	5	109796	6	6547
45843	5	109803	7	20128
45844	4	109804	7	30891
45845	5	109805	5	39377
45846	5	109807	5	12151
45847	5	109813	1	26750
45848	3	109814	7	41991
45849	5	109815	6	42204
45850	5	109816	2	3509
45851	5	109817	3	33021
45852	5	109821	6	42155
45853	3	109822	4	3997
45854	4	109825	6	13066
45855	2	109827	6	37819
45856	5	109829	7	42029
45857	5	109831	2	19159
45858	4	109834	4	7211
45859	5	109835	1	29581
45860	5	109836	3	22210
45861	5	109836	5	22210
45862	5	109838	2	27432
45863	3	109839	1	42089
45864	3	109841	4	37179
45865	4	109844	5	42144
45866	4	109847	4	41995
45867	4	109848	6	42085
45868	3	109849	1	33673
45869	5	109851	5	42006
45870	5	109852	5	42020
45871	5	109858	7	42083
45872	4	109861	4	39495
45873	5	109862	4	74
45874	3	109870	5	34678
45875	5	109874	1	42058
45876	5	109876	6	23947
45877	4	109882	5	19684
45878	5	109883	1	8500
45879	4	109888	7	33556
45880	5	109891	7	18019
45881	5	109894	6	4807
45882	5	109895	4	20780
45883	5	109896	7	16518
45884	3	109898	1	950
45885	5	109899	5	12951
45886	3	109900	1	37364
45887	5	109901	3	28892
45888	3	109904	1	17435
45889	4	109905	4	42063
45890	4	109908	5	42186
45891	5	109914	3	38993
45892	1	109918	6	8298
45893	4	109920	7	19995
45894	5	109924	2	42178
45895	3	109928	1	42069
45896	5	109932	2	39570
45897	5	109937	6	15265
45898	5	109939	6	10518
45899	4	109940	5	4451
45900	5	109942	6	16539
45901	5	109943	6	41996
45902	5	109944	2	19464
45903	5	109948	2	13767
45904	4	109949	4	42228
45905	3	109950	6	42055
45906	5	109952	3	42042
45907	4	109953	2	42023
45908	2	109955	6	15187
45909	3	109956	4	15119
45910	5	109958	7	25315
45911	3	109961	5	42443
45912	5	109962	7	23614
45913	3	109965	1	18901
45914	5	109972	2	19602
45915	4	109976	1	29854
45916	5	109976	6	29854
45917	5	109978	5	32146
45918	5	109979	4	22796
45919	5	109980	6	18427
45920	5	109980	1	18427
45921	5	109989	5	25108
45922	5	109997	7	42340
45923	4	110005	7	37177
45924	5	110008	3	42358
45925	5	110011	2	37531
45926	4	110012	7	12174
45927	3	110013	2	30596
45928	5	110020	6	36922
45929	4	110023	5	42377
45930	4	110025	7	42309
45931	5	110027	7	29340
45932	4	110033	5	42355
45933	4	110035	3	19825
45934	3	110036	1	5743
45935	5	110037	6	22264
45936	5	110038	1	14709
45937	5	110043	5	27790
45938	5	110044	4	143
45939	5	110046	6	11586
45940	4	110050	4	42302
45941	5	110051	7	32378
45942	5	110058	2	4733
45943	4	110064	7	18797
45944	4	110064	1	18797
45945	4	110065	3	42379
45946	3	110066	7	40236
45947	4	110067	3	42363
45948	5	110072	3	42297
45949	4	110074	5	3343
45950	5	110077	4	41926
45951	5	110078	3	42356
45952	5	110084	5	11454
45953	5	110092	2	42421
45954	5	110095	6	412
45955	3	110098	3	9542
45956	5	110099	2	7825
45957	5	110100	3	42269
45958	3	110101	5	21930
45959	3	110102	3	24524
45960	5	110106	2	17667
45961	4	110107	3	9298
45962	5	110110	5	15820
45963	5	110111	6	19036
45964	5	110116	4	42263
45965	4	110118	7	25658
45966	5	110120	2	32360
45967	5	110123	3	3877
45968	4	110126	3	42400
45969	4	110133	5	38045
45970	5	110134	2	42376
45971	4	110135	5	12231
45972	5	110136	2	42411
45973	5	110139	2	7338
45974	3	110141	7	28651
45975	3	110142	4	26071
45976	3	110143	1	42370
45977	2	110145	2	13634
45978	1	110146	6	42280
45979	5	110148	1	11380
45980	3	110150	5	14399
45981	4	110151	1	31835
45982	4	110151	4	31835
45983	5	110154	5	42414
45984	4	110155	2	5082
45985	4	110156	2	14263
45986	3	110160	4	7378
45987	5	110165	7	9627
45988	4	110167	5	15858
45989	5	110173	2	42374
45990	4	110175	5	42248
45991	5	110176	4	42413
45992	5	110178	4	15686
45993	3	110184	5	41451
45994	5	110191	3	8090
45995	5	110192	6	39512
45996	3	110194	2	27590
45997	4	110198	7	42339
45998	5	110199	3	822
45999	5	110200	6	38175
46000	5	110203	3	17151
46001	5	110204	1	17390
46002	5	110205	1	42266
46003	5	110206	7	42247
46004	2	110207	6	32300
46005	5	110209	2	5079
46006	3	110215	3	38495
46007	4	110216	5	42261
46008	4	110217	5	20633
46009	5	110219	3	42293
46010	5	110220	2	25656
46011	5	110223	7	42435
46012	3	110228	7	42334
46013	5	110230	2	29042
46014	4	110231	4	42436
46015	4	110235	4	42283
46016	4	110237	2	26402
46017	5	110238	5	17223
46018	3	110240	7	42320
46019	5	110241	5	41053
46020	5	110242	2	9150
46021	5	110247	5	8381
46022	1	110249	6	38907
46023	5	110251	3	42274
46024	3	110254	2	3002
46025	5	110255	1	14328
46026	5	110256	6	9043
46027	5	110257	4	32285
46028	3	110258	7	42257
46029	5	110259	2	42422
46030	3	110260	7	32078
46031	5	110261	4	42409
46032	3	110263	6	14657
46033	3	110267	5	26468
46034	5	110269	1	20955
46035	5	110270	7	6369
46036	5	110271	6	4514
46037	3	110271	7	4514
46038	4	110277	3	20970
46039	5	110278	5	17094
46040	5	110279	4	12132
46041	5	110279	2	12132
46042	5	110283	7	38582
46043	3	110284	1	41772
46044	5	110285	6	42412
46045	5	110287	4	1715
46046	3	110290	3	18935
46047	5	110292	2	31117
46048	5	110293	4	10767
46049	5	110295	4	33667
46050	1	110297	6	42324
46051	5	110304	2	42373
46052	5	110305	7	612
46053	5	110306	1	40062
46054	5	110309	6	15821
46055	5	110311	5	42444
46056	5	110320	3	41880
46057	4	110322	7	16172
46058	5	110322	6	16172
46059	3	110325	4	42442
46060	4	110327	5	20136
46061	4	110336	7	591
46062	5	110337	3	14344
46063	4	110339	2	13101
46064	4	110340	7	40193
46065	5	110345	6	42250
46066	4	110346	7	37817
46067	4	110349	6	42327
46068	5	110350	6	31951
46069	4	110351	5	4344
46070	5	110353	6	42417
46071	5	110356	3	27241
46072	4	110359	5	11148
46073	5	110360	4	42271
46074	5	110362	4	42281
46075	5	110364	5	13907
46076	4	110366	2	1406
46077	5	110366	3	1406
46078	5	110368	6	42321
46079	3	110372	6	42255
46080	3	110375	2	6168
46081	4	110376	7	23462
46082	4	110376	5	23462
46083	4	110377	2	3160
46084	4	110384	7	4628
46085	3	110387	4	42389
46086	5	110393	3	5527
46087	3	110394	7	15617
46088	4	110396	2	42256
46089	3	110397	2	9867
46090	5	110398	6	36458
46091	4	110400	5	28932
46092	5	110405	4	42378
46093	5	110407	2	42259
46094	3	110409	2	21283
46095	4	110413	2	19004
46096	5	110414	3	5354
46097	5	110415	2	42265
46098	5	110416	6	41376
46099	3	110422	7	28456
46100	5	110422	6	28456
46101	5	110428	7	18227
46102	4	110433	3	6846
46103	5	110434	7	38433
46104	5	110440	6	22848
46105	5	110441	5	20243
46106	5	110444	1	21725
46107	1	110448	6	6608
46108	5	110451	4	8628
46109	5	110453	6	42347
46110	3	110454	3	754
46111	1	110455	7	42270
46112	3	110455	1	42270
46113	5	110456	6	6233
46114	5	110457	1	42338
46115	5	110458	5	42310
46116	5	110459	5	42246
46117	1	110462	6	42254
46118	3	110465	5	42367
46119	3	110468	1	42384
46120	5	110470	4	16246
46121	3	110472	1	17881
46122	4	110482	6	11039
46123	5	110484	6	20998
46124	5	110486	2	42430
46125	3	110492	2	26492
46126	4	110495	5	42425
46127	3	110497	2	42287
46128	5	110497	4	42287
46129	4	110498	3	37873
46130	5	110500	6	11221
46131	5	110508	3	42312
46132	5	110509	1	2615
46133	2	110511	3	14290
46134	5	110512	4	20511
46135	5	110513	6	42092
46136	5	110515	2	26940
46137	5	110517	7	6831
46138	4	110518	4	42371
46139	4	110520	3	313
46140	5	110522	3	16829
46141	5	110529	4	29509
46142	4	110532	1	24434
46143	4	110541	6	34667
46144	5	110547	4	991
46145	4	110551	5	5325
46146	1	110552	1	12195
46147	5	110554	4	42502
46148	5	110558	4	42487
46149	5	110559	2	299
46150	4	110560	7	25069
46151	5	110561	7	6195
46152	5	110566	6	42464
46153	5	110568	4	19380
46154	5	110570	3	22639
46155	5	110573	6	6671
46156	4	110574	1	33020
46157	5	110575	3	6987
46158	5	110577	6	5817
46159	3	110578	5	31208
46160	5	110582	6	42673
46161	4	110583	7	19323
46162	5	110584	6	29422
46163	5	110587	6	24803
46164	3	110588	7	42458
46165	3	110593	5	42645
46166	3	110593	7	42645
46167	4	110594	5	12274
46168	5	110598	1	40333
46169	4	110598	6	40333
46170	5	110601	7	3863
46171	1	110605	6	36347
46172	5	110607	2	13327
46173	5	110613	6	42612
46174	3	110613	1	42612
46175	5	110615	4	13791
46176	3	110617	1	42321
46177	5	110618	1	21786
46178	5	110624	6	42657
46179	3	110632	7	27018
46180	5	110635	6	1715
46181	3	110638	3	22778
46182	3	110639	2	34992
46183	5	110639	7	34992
46184	5	110640	5	42521
46185	3	110642	1	13987
46186	5	110643	2	42465
46187	4	110643	5	42465
46188	3	110645	4	42525
46189	5	110647	4	34641
46190	3	110649	3	33183
46191	3	110650	7	10434
46192	4	110652	2	32010
46193	3	110656	5	28225
46194	4	110657	5	11658
46195	3	110658	7	30534
46196	5	110659	1	14867
46197	4	110662	2	42675
46198	5	110664	3	8029
46199	5	110665	3	972
46200	5	110669	2	298
46201	3	110670	2	3534
46202	1	110671	6	42589
46203	4	110677	1	31091
46204	5	110684	5	7861
46205	3	110686	7	26290
46206	2	110691	4	4227
46207	5	110694	3	42457
46208	5	110698	6	12676
46209	5	110699	3	3652
46210	4	110701	2	23217
46211	4	110706	2	27764
46212	2	110707	6	18567
46213	5	110713	5	10392
46214	4	110717	4	31140
46215	3	110718	3	42481
46216	5	110721	3	16983
46217	4	110728	7	21922
46218	5	110732	2	42536
46219	5	110736	6	37162
46220	3	110741	5	2729
46221	4	110741	6	2729
46222	5	110742	6	42633
46223	5	110750	4	42518
46224	5	110751	2	38339
46225	5	110753	6	21390
46226	4	110753	2	21390
46227	5	110754	5	42669
46228	5	110755	6	5658
46229	4	110759	6	27993
46230	5	110760	4	7699
46231	5	110768	2	42604
46232	5	110771	2	10755
46233	5	110772	2	42506
46234	5	110775	5	42459
46235	5	110777	6	42642
46236	5	110778	5	12019
46237	4	110781	7	42488
46238	5	110789	2	6596
46239	5	110790	1	13371
46240	5	110794	6	42629
46241	4	110801	5	39624
46242	4	110802	7	34426
46243	5	110802	2	34426
46244	4	110810	7	948
46245	5	110812	6	20729
46246	5	110814	5	42528
46247	5	110816	3	18479
46248	5	110817	5	26350
46249	5	110819	2	19955
46250	5	110825	7	42592
46251	4	110836	2	42573
46252	5	110838	2	42535
46253	3	110840	5	42586
46254	5	110841	6	42480
46255	5	110842	2	6499
46256	2	110844	3	24508
46257	5	110845	7	42655
46258	5	110846	2	2282
46259	4	110851	7	42570
46260	2	110853	6	9907
46261	3	110854	6	42564
46262	5	110855	6	42552
46263	5	110862	1	42654
46264	5	110864	7	42540
46265	5	110864	2	42540
46266	4	110867	5	10296
46267	5	110869	3	20907
46268	5	110875	2	31997
46269	3	110879	4	34175
46270	4	110880	6	655
46271	3	110881	1	27122
46272	5	110883	2	42509
46273	5	110886	4	10679
46274	5	110887	4	1080
46275	5	110888	6	16346
46276	4	110892	6	12935
46277	5	110893	6	13380
46278	4	110894	7	19845
46279	3	110897	4	4596
46280	3	110898	5	5158
46281	5	110900	6	6326
46282	5	110904	2	14641
46283	1	110905	4	42519
46284	5	110906	7	35685
46285	3	110909	7	23829
46286	4	110910	7	15516
46287	5	110914	5	5492
46288	5	110915	4	6514
46289	5	110919	7	42526
46290	4	110920	7	23673
46291	5	110922	4	12573
46292	5	110923	2	12796
46293	3	110924	7	18153
46294	5	110925	4	13531
46295	5	110928	1	11932
46296	3	110931	3	35869
46297	5	110933	6	28749
46298	4	110934	5	42493
46299	3	110937	1	30617
46300	5	110937	2	30617
46301	4	110940	5	42625
46302	5	110943	1	8647
46303	3	110944	5	32341
46304	5	110945	2	17
46305	3	110946	5	13115
46306	3	110951	2	42597
46307	5	110953	7	12286
46308	5	110959	2	1963
46309	4	110962	7	20877
46310	1	110966	4	19583
46311	5	110969	4	40341
46312	3	110970	2	8946
46313	5	110971	7	42492
46314	5	110976	2	466
46315	5	110977	2	42585
46316	4	110979	2	33604
46317	4	110980	6	20329
46318	5	110981	2	35759
46319	5	110986	2	20723
46320	5	110987	7	42495
46321	5	110987	2	42495
46322	5	110988	4	28808
46323	5	110989	6	15159
46324	5	110992	1	42559
46325	5	110998	2	10796
46326	4	110999	4	29664
46327	5	111001	1	222
46328	3	111005	4	42562
46329	5	111006	6	2843
46330	5	111007	4	6322
46331	5	111009	1	13697
46332	5	111014	7	42505
46333	5	111015	6	7623
46334	5	111017	7	42574
46335	5	111018	5	3332
46336	5	111019	7	18417
46337	4	111021	3	41561
46338	4	111025	3	42627
46339	4	111026	6	19217
46340	5	111027	2	42595
46341	4	111028	4	11815
46342	5	111029	2	18526
46343	4	111030	4	14731
46344	5	111031	2	4885
46345	4	111033	3	42551
46346	4	111035	6	35627
46347	4	111036	6	42641
46348	3	111039	5	42476
46349	3	111041	5	203
46350	5	111043	5	42611
46351	5	111044	3	8149
46352	3	111049	5	26943
46353	5	111050	2	41176
46354	4	111051	7	42599
46355	5	111052	2	36714
46356	3	111053	3	9793
46357	3	111054	4	3968
46358	5	111056	3	42569
46359	4	111058	7	42485
46360	5	111058	2	42485
46361	4	111060	7	42662
46362	5	111060	2	42662
46363	4	111061	6	42511
46364	5	111064	4	36077
46365	5	111064	1	36077
46366	5	111068	5	9337
46367	3	111069	5	42596
46368	4	111073	3	42489
46369	1	111073	4	42489
46370	3	111074	2	15614
46371	5	111077	6	36832
46372	3	111080	6	27080
46373	5	111081	6	6664
46374	3	111081	7	6664
46375	3	111083	6	40591
46376	3	111087	5	40509
46377	5	111089	1	39397
46378	2	111092	6	15539
46379	4	111094	2	30330
46380	3	111096	1	20876
46381	5	111097	1	25577
46382	4	111102	3	22338
46383	5	111105	6	6894
46384	5	111110	7	1166
46385	5	111111	1	42520
46386	3	111113	2	2538
46387	2	111116	6	17861
46388	4	111117	4	29856
46389	5	111122	6	9470
46390	5	111123	5	31044
46391	5	111125	7	37627
46392	5	111132	2	21434
46393	4	111134	3	2585
46394	5	111137	5	29065
46395	5	111139	6	1488
46396	3	111141	5	10935
46397	3	111142	2	30279
46398	5	111145	7	5768
46399	5	111148	2	20185
46400	5	111157	6	39976
46401	5	111158	2	23110
46402	5	111160	6	42558
46403	5	111162	2	22863
46404	5	111167	2	42527
46405	5	111168	3	39271
46406	4	111168	2	39271
46407	3	111169	3	1293
46408	5	111171	6	19911
46409	5	111172	4	30697
46410	3	111173	1	6055
46411	4	111178	7	42651
46412	5	111181	5	8175
46413	5	111183	2	996
46414	5	111184	6	34039
46415	2	111185	4	37673
46416	4	111186	6	970
46417	5	111188	6	2089
46418	5	111189	5	42475
46419	5	111193	1	31726
46420	3	111193	2	31726
46421	4	111199	7	42607
46422	4	111200	2	18914
46423	5	111203	6	7425
46424	4	111204	6	754
46425	5	111206	5	8990
46426	5	111209	5	42638
46427	5	111213	5	7604
46428	4	111215	7	4212
46429	3	111216	6	42582
46430	5	111217	4	30460
46431	4	111219	5	40401
46432	4	111220	4	36729
46433	4	111222	5	42566
46434	5	111223	4	26520
46435	3	111223	5	26520
46436	3	111224	4	4904
46437	5	111226	6	17051
46438	5	111229	2	1093
46439	4	111232	3	42529
46440	5	111236	6	10244
46441	3	111239	3	10442
46442	4	111242	1	31300
46443	3	111244	7	13801
46444	4	111245	7	38822
46445	5	111246	5	36148
46446	5	111247	3	2656
46447	5	111248	6	36010
46448	3	111249	1	42530
46449	4	111253	2	10205
46450	5	111254	2	40170
46451	5	111257	4	32175
46452	3	111258	1	11960
46453	3	111264	2	19432
46454	5	111265	7	16304
46455	4	111266	5	24570
46456	5	111271	2	29527
46457	3	111272	1	7779
46458	3	111273	7	42807
46459	3	111276	1	39654
46460	3	111277	4	25051
46461	4	111277	3	25051
46462	4	111278	4	18432
46463	3	111288	7	42772
46464	5	111290	3	5808
46465	5	111291	1	23271
46466	5	111292	2	7629
46467	5	111294	2	9303
46468	5	111295	4	42775
46469	4	111299	7	3565
46470	4	111302	3	14267
46471	5	111304	2	5483
46472	4	111310	7	33269
46473	4	111311	2	37123
46474	5	111312	3	25355
46475	5	111314	4	8900
46476	5	111320	6	32766
46477	5	111322	2	42687
46478	5	111323	6	42750
46479	5	111324	3	26341
46480	3	111328	5	37320
46481	5	111329	1	32298
46482	4	111330	4	36754
46483	5	111331	7	42697
46484	5	111333	4	38895
46485	5	111340	5	42899
46486	5	111340	2	42899
46487	5	111345	2	2857
46488	5	111347	7	42889
46489	5	111347	1	42889
46490	5	111350	3	15284
46491	4	111352	3	38336
46492	5	111353	7	41722
46493	5	111354	3	42840
46494	5	111359	4	3350
46495	5	111360	5	637
46496	4	111363	5	16578
46497	5	111368	4	42883
46498	5	111372	4	5914
46499	4	111376	5	34507
46500	5	111379	1	6331
46501	5	111380	6	1557
46502	5	111384	1	42776
46503	4	111385	6	26464
46504	5	111386	6	3500
46505	3	111391	5	42824
46506	5	111394	1	42891
46507	3	111396	7	8126
46508	5	111396	1	8126
46509	2	111398	4	32939
46510	5	111399	7	22219
46511	5	111403	4	24780
46512	5	111404	7	7034
46513	4	111408	7	12172
46514	5	111409	6	17518
46515	5	111410	6	42852
46516	4	111411	4	21684
46517	5	111413	2	16231
46518	5	111415	6	39411
46519	4	111416	7	26927
46520	3	111417	5	42886
46521	4	111418	7	42916
46522	5	111420	2	42896
46523	5	111424	1	36734
46524	5	111425	4	28320
46525	3	111425	3	28320
46526	5	111426	1	40046
46527	4	111430	5	39621
46528	4	111431	7	14362
46529	5	111432	6	5780
46530	5	111433	6	30219
46531	5	111434	1	4262
46532	5	111435	2	9147
46533	4	111437	7	42777
46534	5	111439	4	26747
46535	5	111442	6	42866
46536	3	111442	2	42866
46537	5	111444	3	37694
46538	4	111447	7	31592
46539	5	111449	7	30302
46540	5	111450	7	29903
46541	5	111451	6	42680
46542	5	111452	4	42696
46543	5	111453	1	25846
46544	2	111454	6	18911
46545	3	111454	2	18911
46546	5	111455	2	19246
46547	4	111455	5	19246
46548	5	111457	6	26967
46549	5	111460	6	31062
46550	5	111461	7	34859
46551	3	111464	5	26894
46552	4	111465	7	28039
46553	3	111467	3	3679
46554	4	111470	4	3072
46555	5	111472	1	42822
46556	3	111479	4	15645
46557	5	111485	4	17268
46558	3	111488	3	42138
46559	5	111488	5	42138
46560	5	111489	4	15535
46561	5	111493	6	42717
46562	5	111494	6	37258
46563	3	111502	7	24980
46564	3	111503	7	7330
46565	5	111504	5	40148
46566	5	111505	2	40906
46567	3	111506	7	9175
46568	5	111512	3	33304
46569	3	111518	7	42709
46570	5	111524	1	38475
46571	3	111524	7	38475
46572	5	111530	7	42849
46573	4	111531	7	42841
46574	4	111532	5	42684
46575	3	111534	7	37886
46576	4	111534	3	37886
46577	5	111535	1	42771
46578	3	111541	2	16834
46579	4	111543	4	42799
46580	4	111548	2	24176
46581	5	111548	6	24176
46582	5	111551	7	12702
46583	5	111552	4	42826
46584	5	111553	2	21875
46585	3	111555	5	3173
46586	5	111556	2	8294
46587	5	111560	2	42842
46588	4	111560	7	42842
46589	3	111564	4	34867
46590	5	111565	4	42909
46591	4	111568	7	42808
46592	5	111571	4	42911
46593	5	111571	6	42911
46594	2	111572	2	35867
46595	4	111574	5	42722
46596	5	111578	7	2556
46597	5	111582	5	688
46598	3	111583	7	11715
46599	5	111591	1	22383
46600	4	111594	1	7636
46601	3	111596	5	42902
46602	4	111597	2	42843
46603	4	111599	1	42705
46604	5	111607	2	42672
46605	5	111608	2	19637
46606	3	111609	1	31716
46607	5	111611	3	12578
46608	4	111613	6	16542
46609	3	111614	7	42701
46610	5	111615	6	42745
46611	5	111621	2	42892
46612	3	111623	3	35106
46613	1	111624	6	33942
46614	5	111627	4	42832
46615	4	111627	7	42832
46616	5	111630	3	33015
46617	4	111633	3	31014
46618	4	111634	5	1865
46619	5	111636	2	662
46620	3	111638	7	42814
46621	5	111644	6	33717
46622	4	111646	6	2287
46623	5	111647	3	31098
46624	3	111649	2	3931
46625	5	111651	1	29960
46626	5	111657	5	42810
46627	5	111657	4	42810
46628	5	111658	2	39930
46629	3	111659	1	8574
46630	5	111660	1	35733
46631	5	111665	4	42710
46632	3	111667	4	23767
46633	5	111674	1	12676
46634	5	111675	7	24062
46635	4	111676	7	42811
46636	5	111677	6	1314
46637	3	111679	3	33701
46638	5	111680	7	2408
46639	4	111681	1	42838
46640	5	111684	6	28058
46641	5	111686	5	42871
46642	5	111687	4	626
46643	3	111690	1	4719
46644	5	111691	4	23573
46645	3	111694	7	28827
46646	5	111695	6	2771
46647	4	111699	7	10740
46648	5	111700	7	42738
46649	5	111701	1	13939
46650	5	111703	5	28632
46651	5	111704	6	13520
46652	5	111707	3	16170
46653	3	111708	3	13913
46654	5	111710	5	37181
46655	2	111711	3	16032
46656	5	111712	1	42836
46657	5	111716	2	2902
46658	5	111719	3	32716
46659	5	111724	2	42835
46660	5	111725	2	6197
46661	3	111726	1	24667
46662	5	111727	4	14292
46663	5	111731	3	42686
46664	5	111732	6	10645
46665	5	111733	3	42876
46666	4	111734	2	42780
46667	4	111738	5	42704
46668	5	111739	6	18495
46669	3	111745	3	16915
46670	5	111747	4	15401
46671	3	111748	1	42744
46672	5	111750	6	15510
46673	3	111752	3	28204
46674	5	111755	4	42784
46675	5	111756	2	42905
46676	3	111757	7	28600
46677	5	111761	4	42872
46678	3	111762	6	13613
46679	4	111763	7	19408
46680	3	111764	7	42865
46681	3	111766	1	22871
46682	4	111771	6	17171
46683	3	111774	5	38176
46684	5	111775	4	33025
46685	5	111778	3	4162
46686	5	111780	3	7211
46687	4	111781	5	16027
46688	4	111785	3	41749
46689	5	111788	6	42787
46690	3	111793	1	22881
46691	4	111794	1	25499
46692	4	111797	5	14727
46693	4	111798	2	32839
46694	5	111800	7	37215
46695	5	111801	2	26316
46696	5	111801	4	26316
46697	5	111802	2	22363
46698	5	111806	1	11283
46699	5	111807	2	13758
46700	4	111808	2	20392
46701	3	111809	7	18075
46702	1	111810	6	37325
46703	3	111811	6	38383
46704	5	111813	4	38898
46705	5	111816	2	8288
46706	3	111825	5	17687
46707	4	111828	5	42890
46708	4	111829	4	23424
46709	5	111832	6	42695
46710	3	111833	7	3238
46711	4	111836	4	41268
46712	4	111840	3	13068
46713	5	111841	6	42759
46714	5	111848	2	26336
46715	5	111850	6	40359
46716	3	111853	7	42921
46717	5	111854	6	2980
46718	5	111855	2	42910
46719	4	111865	5	42693
46720	4	111868	2	15386
46721	5	111873	6	5781
46722	4	111874	1	2288
46723	5	111875	6	3431
46724	5	111879	2	42733
46725	5	111881	7	28485
46726	5	111882	4	42850
46727	4	111882	2	42850
46728	2	111884	6	29716
46729	5	111885	4	42739
46730	4	111886	3	42702
46731	5	111889	4	42699
46732	1	111890	6	18519
46733	5	111892	2	36012
46734	3	111893	1	8147
46735	3	111898	1	42834
46736	4	111899	6	42912
46737	4	111902	2	8198
46738	3	111903	7	42812
46739	3	111904	5	20136
46740	5	111905	4	19582
46741	3	111906	1	42741
46742	3	111908	5	42796
46743	4	111913	4	42906
46744	5	111914	7	16996
46745	1	111915	4	3006
46746	5	111916	4	11210
46747	4	111917	6	12273
46748	5	111918	1	33298
46749	5	111920	6	29042
46750	5	111926	3	35122
46751	4	111928	1	42846
46752	5	111929	2	37196
46753	4	111930	5	16244
46754	5	111932	1	23025
46755	4	111941	3	42755
46756	5	111942	6	19711
46757	5	111943	6	11150
46758	4	111947	7	39741
46759	3	111948	4	30741
46760	5	111949	1	42688
46761	1	111951	6	28653
46762	4	111953	2	42761
46763	5	111953	6	42761
46764	5	111954	6	6144
46765	4	111956	3	14307
46766	5	111956	4	14307
46767	5	111961	6	42864
46768	5	111963	2	42894
46769	5	111964	3	10451
46770	3	111973	4	28579
46771	4	111974	1	16813
46772	5	111976	6	43135
46773	4	111980	4	42959
46774	4	111981	7	17799
46775	4	111982	2	42254
46776	3	111986	7	42928
46777	5	111994	5	23233
46778	4	111998	1	43119
46779	3	112001	1	42979
46780	5	112002	2	6686
46781	5	112011	1	42963
46782	5	112015	2	13567
46783	4	112018	7	43145
46784	5	112019	3	38089
46785	5	112022	7	41072
46786	5	112025	2	35017
46787	4	112025	7	35017
46788	3	112030	1	7428
46789	5	112031	1	23931
46790	3	112032	5	12515
46791	5	112033	2	15117
46792	5	112035	7	43173
46793	5	112036	7	2185
46794	4	112037	4	11287
46795	5	112041	1	43005
46796	3	112044	5	22252
46797	5	112046	1	24621
46798	5	112050	3	42950
46799	5	112055	6	477
46800	4	112058	2	38250
46801	3	112060	3	14106
46802	5	112061	4	209
46803	3	112063	5	30961
46804	4	112064	7	10568
46805	5	112064	5	10568
46806	5	112065	2	43064
46807	3	112068	5	43030
46808	5	112069	4	17969
46809	5	112072	1	467
46810	4	112074	6	40945
46811	5	112086	6	8781
46812	5	112089	5	43152
46813	5	112093	6	10276
46814	5	112097	3	10708
46815	3	112098	5	21451
46816	1	112103	6	22977
46817	5	112106	5	195
46818	5	112107	2	34052
46819	3	112109	2	14781
46820	3	112110	5	43036
46821	5	112111	6	43132
46822	5	112112	4	993
46823	5	112114	5	26997
46824	5	112116	5	42961
46825	5	112117	4	17127
46826	5	112119	6	10177
46827	4	112120	7	36113
46828	5	112123	2	43170
46829	5	112124	1	27783
46830	3	112126	5	20650
46831	5	112126	2	20650
46832	3	112132	5	16603
46833	3	112133	3	1044
46834	5	112138	6	43008
46835	5	112140	6	42986
46836	1	112143	6	26486
46837	5	112144	6	6765
46838	5	112149	3	42936
46839	3	112151	3	19758
46840	3	112159	7	806
46841	5	112160	7	42883
46842	5	112167	5	16128
46843	4	112168	4	43051
46844	5	112170	4	16538
46845	3	112172	2	43164
46846	5	112177	5	19624
46847	4	112178	2	29111
46848	4	112178	7	29111
46849	3	112180	5	7151
46850	1	112180	6	7151
46851	3	112181	4	42940
46852	3	112182	5	24018
46853	4	112183	7	42957
46854	5	112186	5	25015
46855	5	112193	1	673
46856	3	112196	2	32044
46857	4	112199	5	43058
46858	4	112200	2	18271
46859	3	112203	7	41749
46860	1	112203	2	41749
46861	5	112207	1	822
46862	3	112209	5	43154
46863	4	112210	6	43122
46864	5	112216	4	29866
46865	4	112217	2	9600
46866	1	112218	6	4451
46867	5	112218	4	4451
46868	3	112219	3	43026
46869	5	112220	7	28574
46870	3	112223	6	22007
46871	5	112224	2	34551
46872	4	112225	2	30391
46873	5	112228	7	43039
46874	3	112229	4	20136
46875	1	112231	4	29097
46876	5	112231	5	29097
46877	5	112233	4	43162
46878	3	112234	2	42985
46879	4	112236	4	43168
46880	4	112238	2	43150
46881	4	112241	6	41443
46882	4	112242	7	20970
46883	5	112245	1	7510
46884	4	112249	2	4582
46885	5	112252	1	22179
46886	5	112255	7	4395
46887	2	112256	4	825
46888	4	112260	6	20126
46889	4	112266	5	40956
46890	4	112267	1	37747
46891	3	112274	2	43172
46892	2	112280	3	13228
46893	5	112282	7	42943
46894	3	112283	7	23213
46895	4	112286	4	3040
46896	5	112287	2	39214
46897	5	112289	2	1857
46898	5	112291	6	31288
46899	5	112294	2	42815
46900	4	112297	7	43157
46901	5	112298	3	43126
46902	5	112302	6	39805
46903	5	112305	6	4662
46904	4	112306	7	41284
46905	5	112309	6	42948
46906	5	112310	1	42960
46907	3	112311	4	26841
46908	5	112312	6	43024
46909	2	112313	7	13109
46910	5	112315	5	3006
46911	3	112315	6	3006
46912	4	112316	3	20429
46913	5	112316	7	20429
46914	3	112317	5	43042
46915	5	112318	2	1402
46916	3	112321	2	43090
46917	5	112322	7	1457
46918	5	112326	5	36586
46919	5	112327	7	43134
46920	5	112328	6	40869
46921	2	112329	1	40627
46922	5	112334	7	31065
46923	5	112338	6	43144
46924	4	112340	6	27284
46925	5	112342	1	37099
46926	5	112346	6	18777
46927	5	112347	3	11735
46928	5	112348	7	42968
46929	5	112358	5	33546
46930	4	112359	5	11623
46931	5	112360	3	42931
46932	5	112360	5	42931
46933	4	112363	2	39026
46934	3	112370	6	43116
46935	4	112373	1	43153
46936	3	112374	7	5428
46937	5	112377	7	26043
46938	4	112381	2	14519
46939	5	112382	7	13445
46940	5	112383	5	27287
46941	5	112385	5	7273
46942	5	112387	4	12952
46943	2	112389	6	43038
46944	5	112392	3	41196
46945	5	112393	6	10741
46946	5	112396	2	12577
46947	3	112405	4	14050
46948	1	112408	4	4369
46949	5	112409	6	42935
46950	1	112413	6	18557
46951	5	112418	1	17928
46952	5	112419	7	43118
46953	5	112423	3	33003
46954	3	112424	2	43096
46955	5	112427	6	43179
46956	4	112431	7	43085
46957	4	112432	4	42937
46958	4	112434	2	43177
46959	5	112435	6	43061
46960	3	112436	5	7221
46961	5	112439	2	32640
46962	5	112445	5	37080
46963	3	112448	5	43069
46964	5	112450	2	15569
46965	5	112451	5	34791
46966	5	112452	7	12367
46967	5	112453	2	42999
46968	4	112455	1	7963
46969	3	112459	1	43029
46970	5	112460	1	16925
46971	4	112464	1	2110
46972	5	112468	6	43044
46973	5	112471	4	531
46974	4	112473	7	43031
46975	5	112475	1	42923
46976	5	112476	5	43110
46977	5	112478	5	43067
46978	2	112480	4	8090
46979	5	112484	4	43065
46980	5	112485	7	13973
46981	4	112487	4	30179
46982	5	112492	3	13819
46983	5	112498	4	28922
46984	5	112499	6	43010
46985	3	112499	3	43010
46986	4	112501	5	38396
46987	5	112503	6	42994
46988	5	112504	4	6614
46989	5	112507	7	42954
46990	5	112510	5	28053
46991	3	112514	1	32533
46992	5	112514	3	32533
46993	5	112516	6	43006
46994	1	112517	6	43040
46995	5	112519	7	43066
46996	4	112520	6	42944
46997	3	112525	5	938
46998	5	112531	4	22056
46999	1	112532	6	17739
47000	5	112533	3	36470
47001	1	112534	4	42213
47002	3	112539	1	42949
47003	4	112540	3	42581
47004	5	112543	4	2657
47005	5	112543	6	2657
47006	5	112544	1	37933
47007	4	112546	2	30783
47008	1	112550	4	43161
47009	4	112551	3	42987
47010	5	112554	2	35174
47011	3	112557	1	43143
47012	5	112558	3	25775
47013	5	112563	6	13568
47014	5	112565	6	19668
47015	3	112566	5	29542
47016	4	112572	4	32178
47017	1	112573	6	9112
47018	4	112579	7	3271
47019	5	112582	7	9798
47020	5	112583	7	11124
47021	4	112586	4	24241
47022	3	112589	7	43020
47023	5	112590	4	11260
47024	2	112602	6	43130
47025	4	112606	5	10336
47026	4	112608	5	42945
47027	4	112609	4	12292
47028	3	112614	5	42978
47029	5	112615	6	43046
47030	5	112616	6	41198
47031	5	112617	1	12763
47032	5	112618	4	26557
47033	3	112622	6	39590
47034	4	112624	7	43108
47035	5	112624	1	43108
47036	4	112625	5	9440
47037	4	112627	2	39712
47038	5	112628	2	29065
47039	5	112631	5	38755
47040	3	112633	1	43071
47041	5	112637	5	42991
47042	5	112640	3	43034
47043	5	112641	2	42984
47044	5	112644	2	36531
47045	5	112645	6	10624
47046	5	112646	6	23716
47047	5	112647	1	42970
47048	5	112648	5	6787
47049	4	112649	7	5155
47050	5	112650	5	40016
47051	3	112651	3	36639
47052	5	112652	5	8852
47053	5	112653	1	34790
47054	3	112655	6	43149
47055	5	112656	6	43009
47056	3	112657	5	42997
47057	3	112659	4	36942
47058	5	112660	5	40954
47059	5	112662	1	16003
47060	5	112663	4	32417
47061	5	112665	6	43415
47062	4	112666	5	12570
47063	5	112671	7	43291
47064	5	112672	2	19109
47065	5	112675	6	23585
47066	4	112676	6	26697
47067	5	112677	7	35298
47068	4	112679	1	5345
47069	5	112680	3	18509
47070	5	112688	4	7714
47071	5	112691	3	43244
47072	3	112692	6	27389
47073	5	112700	2	14354
47074	5	112701	1	9617
47075	4	112701	7	9617
47076	5	112702	6	29170
47077	4	112704	6	29193
47078	5	112713	1	26683
47079	5	112715	7	4982
47080	3	112717	4	43391
47081	4	112719	6	32058
47082	5	112721	7	43284
47083	5	112722	6	17094
47084	3	112723	2	17599
47085	5	112725	2	13156
47086	5	112726	6	37253
47087	5	112729	1	7991
47088	4	112732	5	23010
47089	4	112736	6	43373
47090	5	112740	2	2052
47091	5	112741	4	7331
47092	4	112744	7	24593
47093	4	112745	1	19869
47094	3	112746	5	43407
47095	5	112747	6	38323
47096	5	112748	5	9192
47097	2	112750	5	5571
47098	3	112752	5	43300
47099	3	112753	5	16361
47100	5	112754	2	23671
47101	3	112755	5	43363
47102	5	112758	5	39627
47103	3	112765	1	34850
47104	5	112765	3	34850
47105	5	112766	2	28775
47106	2	112768	6	35213
47107	4	112769	7	33716
47108	5	112780	7	43350
47109	3	112781	5	43351
47110	4	112782	4	30230
47111	5	112783	7	43406
47112	5	112784	4	7217
47113	4	112790	3	8733
47114	5	112795	6	37272
47115	4	112796	4	19363
47116	4	112803	2	6559
47117	4	112806	4	43416
47118	5	112807	7	24718
47119	5	112810	4	38190
47120	5	112811	2	26628
47121	1	112812	6	43362
47122	5	112815	3	43320
47123	4	112817	2	30269
47124	4	112819	5	43346
47125	5	112820	6	11175
47126	5	112822	4	43261
47127	5	112823	2	28484
47128	5	112830	6	43418
47129	3	112832	4	1507
47130	3	112835	5	32120
47131	4	112836	5	43254
47132	4	112840	2	30929
47133	4	112842	7	12820
47134	3	112843	6	3773
47135	5	112844	2	43262
47136	5	112846	2	541
47137	4	112847	4	43285
47138	4	112850	1	1813
47139	3	112854	7	38447
47140	1	112857	6	43290
47141	5	112857	3	43290
47142	5	112858	2	18612
47143	4	112859	6	25941
47144	5	112860	2	20072
47145	4	112860	1	20072
47146	5	112861	2	43329
47147	4	112863	7	43396
47148	5	112865	4	8583
47149	5	112869	3	22752
47150	5	112873	7	27158
47151	5	112876	1	43278
47152	4	112878	7	43395
47153	5	112880	2	43209
47154	5	112881	1	25749
47155	5	112882	3	19300
47156	5	112883	2	30273
47157	5	112884	6	30238
47158	5	112885	7	43310
47159	4	112889	6	43413
47160	5	112890	7	25802
47161	3	112892	4	20126
47162	5	112895	4	29664
47163	5	112896	1	9319
47164	5	112899	3	11491
47165	5	112900	1	40267
47166	5	112903	6	10538
47167	5	112904	6	40872
47168	5	112907	5	43194
47169	4	112913	5	38107
47170	4	112915	2	21095
47171	5	112916	7	26122
47172	5	112920	5	43348
47173	5	112923	7	33900
47174	5	112924	6	43269
47175	5	112924	7	43269
47176	4	112927	2	8654
47177	5	112928	2	16881
47178	5	112931	5	43243
47179	5	112933	6	37456
47180	4	112936	7	906
47181	4	112938	7	35452
47182	4	112938	2	35452
47183	5	112943	1	14814
47184	3	112946	5	37832
47185	5	112946	2	37832
47186	5	112947	2	43292
47187	5	112948	2	11702
47188	4	112951	4	43302
47189	5	112951	1	43302
47190	4	112955	5	40885
47191	5	112964	2	15264
47192	5	112966	5	34896
47193	5	112969	5	43216
47194	3	112973	5	43215
47195	3	112974	7	43249
47196	5	112975	6	25137
47197	3	112975	3	25137
47198	5	112978	7	4818
47199	4	112982	4	37559
47200	2	112985	1	32438
47201	4	112986	5	40738
47202	5	112987	6	43383
47203	5	112988	4	23987
47204	5	112990	4	43321
47205	5	112991	7	43314
47206	4	112992	5	43247
47207	5	112998	7	10573
47208	4	113000	2	43317
47209	5	113000	7	43317
47210	5	113002	6	25179
47211	4	113002	5	25179
47212	5	113003	3	43423
47213	4	113003	1	43423
47214	3	113004	5	31137
47215	4	113007	6	43221
47216	5	113013	7	2519
47217	5	113018	5	43255
47218	4	113019	5	43324
47219	5	113020	2	33000
47220	5	113022	2	3898
47221	3	113024	5	37084
47222	5	113025	7	3470
47223	3	113029	4	43429
47224	5	113031	6	43375
47225	5	113032	2	2457
47226	5	113033	6	14494
47227	5	113036	6	42571
47228	3	113042	7	33698
47229	5	113044	7	33197
47230	3	113047	5	2517
47231	3	113050	2	964
47232	5	113053	6	40397
47233	3	113054	6	32754
47234	5	113055	7	43274
47235	4	113057	2	5483
47236	5	113060	2	22459
47237	5	113062	2	3835
47238	5	113063	1	43424
47239	4	113064	5	42550
47240	4	113066	1	43277
47241	5	113069	3	43353
47242	1	113070	4	10068
47243	5	113070	5	10068
47244	5	113071	4	43427
47245	5	113074	6	14207
47246	4	113083	2	43198
47247	5	113084	5	43419
47248	4	113089	5	43225
47249	1	113090	6	18271
47250	3	113091	1	43272
47251	5	113096	6	30611
47252	5	113096	7	30611
47253	2	113097	4	6489
47254	5	113101	6	43385
47255	5	113102	1	43325
47256	5	113104	5	43202
47257	4	113105	4	16042
47258	5	113109	2	43260
47259	4	113110	5	22533
47260	5	113116	4	27557
47261	4	113119	1	25925
47262	3	113123	4	43295
47263	5	113126	2	18762
47264	4	113126	6	18762
47265	5	113127	4	43405
47266	4	113127	5	43405
47267	4	113128	3	43372
47268	5	113129	5	16550
47269	5	113130	2	11531
47270	4	113133	7	31837
47271	3	113136	1	43229
47272	4	113137	5	915
47273	3	113138	7	43226
47274	5	113139	1	43410
47275	5	113140	5	10872
47276	3	113145	7	9563
47277	5	113145	1	9563
47278	3	113146	7	40948
47279	5	113147	6	43219
47280	5	113148	6	22369
47281	5	113149	3	40262
47282	5	113149	1	40262
47283	4	113152	2	43404
47284	5	113154	3	34547
47285	5	113157	2	12699
47286	5	113158	3	40800
47287	3	113161	6	43303
47288	5	113163	6	43355
47289	4	113164	4	43374
47290	5	113164	1	43374
47291	5	113166	6	13383
47292	5	113167	6	40483
47293	1	113169	6	24045
47294	3	113170	6	26927
47295	3	113170	3	26927
47296	5	113171	6	24853
47297	4	113173	1	43326
47298	3	113176	7	31804
47299	5	113178	7	41300
47300	3	113179	7	39654
47301	2	113180	1	20852
47302	2	113185	3	42964
47303	4	113188	2	43354
47304	5	113190	2	30353
47305	4	113194	4	1645
47306	5	113197	1	4054
47307	3	113198	5	43187
47308	5	113199	4	22854
47309	5	113201	2	3015
47310	5	113202	6	43245
47311	4	113203	6	26601
47312	5	113206	2	13528
47313	5	113207	1	43218
47314	5	113209	6	19771
47315	5	113210	1	43403
47316	5	113213	4	8054
47317	3	113216	2	18496
47318	5	113221	6	709
47319	1	113224	6	11893
47320	5	113226	3	43343
47321	4	113227	5	43304
47322	4	113231	7	17084
47323	5	113235	2	33224
47324	5	113236	2	11081
47325	2	113237	7	16140
47326	3	113241	5	43352
47327	2	113245	3	43193
47328	5	113247	6	20868
47329	5	113248	2	38926
47330	4	113250	7	10618
47331	3	113253	5	37735
47332	4	113255	7	43412
47333	5	113256	2	11543
47334	5	113256	3	11543
47335	5	113257	1	8139
47336	4	113259	3	8550
47337	4	113266	5	43238
47338	5	113266	6	43238
47339	5	113270	5	17044
47340	4	113273	6	7022
47341	5	113276	2	37062
47342	5	113277	6	43426
47343	5	113282	6	10964
47344	5	113283	7	3111
47345	5	113286	5	10950
47346	5	113288	6	43263
47347	5	113290	3	38052
47348	5	113294	6	43420
47349	4	113295	5	26659
47350	4	113299	2	21002
47351	5	113301	1	35265
47352	4	113302	3	23358
47353	5	113309	6	8651
47354	3	113314	4	28950
47355	4	113316	5	26443
47356	4	113317	2	11963
47357	5	113318	1	43289
47358	5	113319	4	43257
47359	5	113320	7	43378
47360	5	113322	1	40854
47361	3	113322	5	40854
47362	5	113323	7	20629
47363	5	113326	6	33819
47364	5	113329	4	43357
47365	5	113334	2	33585
47366	5	113338	7	38399
47367	5	113339	2	43309
47368	3	113340	2	43307
47369	2	113342	6	15201
47370	3	113343	5	43370
47371	5	113345	2	43311
47372	3	113347	5	43189
47373	5	113348	5	4069
47374	5	113350	4	15744
47375	5	113351	7	7403
47376	5	113355	2	624
47377	5	113357	4	43299
47378	5	113359	4	23735
47379	5	113361	2	6860
47380	3	113363	1	24768
47381	5	113364	6	43228
47382	5	113365	3	22176
47383	4	113366	2	43241
47384	2	113368	5	43337
47385	3	113369	3	9260
47386	5	113372	2	37154
47387	5	113374	2	43200
47388	4	113375	3	43217
47389	3	113376	5	22872
47390	3	113377	3	43294
47391	5	113383	4	10679
47392	4	113384	7	14133
47393	5	113388	2	16878
47394	5	113389	5	15172
47395	5	113391	3	43203
47396	5	113393	2	37824
47397	5	113393	3	37824
47398	4	113397	5	14455
47399	5	113399	6	39827
47400	5	113401	6	36871
47401	5	113402	5	13189
47402	4	113403	7	36007
47403	4	113404	1	364
47404	5	113408	6	43237
47405	3	113410	1	16883
47406	5	113414	6	23615
47407	5	113420	2	43253
47408	1	113424	6	19702
47409	5	113425	2	1002
47410	4	113427	6	8358
47411	5	113427	3	8358
47412	5	113432	2	20219
47413	5	113432	5	20219
47414	5	113433	7	43333
47415	5	113435	7	43425
47416	5	113443	1	43271
47417	5	113448	2	3747
47418	5	113450	1	43400
47419	5	113451	6	14867
47420	4	113454	7	43236
47421	5	113455	6	37952
47422	5	113457	5	43399
47423	5	113460	1	43339
47424	4	113460	5	43339
47425	4	113461	4	10461
47426	4	113463	5	34917
47427	3	113465	3	7623
47428	5	113467	1	43174
47429	4	113468	7	39461
47430	3	113473	1	43259
47431	2	113476	3	43252
47432	5	113480	4	13767
47433	4	113481	7	33765
47434	3	113483	7	41674
47435	5	113485	6	43266
47436	5	113490	4	43382
47437	5	113492	2	32141
47438	5	113495	2	1451
47439	4	113497	6	12132
47440	5	113499	5	26361
47441	5	113502	6	25490
47442	3	113510	2	43604
47443	3	113510	6	43604
47444	5	113511	6	609
47445	5	113512	4	34822
47446	5	113517	1	30309
47447	5	113519	4	17188
47448	3	113525	5	43577
47449	5	113531	2	8253
47450	5	113536	2	1334
47451	5	113539	4	43580
47452	5	113540	5	8597
47453	5	113541	2	43442
47454	3	113542	6	13962
47455	3	113547	5	9923
47456	4	113550	3	43554
47457	3	113554	3	40743
47458	5	113555	5	43601
47459	3	113557	4	13051
47460	5	113559	2	12484
47461	5	113560	6	43617
47462	4	113562	4	43540
47463	5	113563	2	29754
47464	5	113564	7	26255
47465	3	113565	6	37257
47466	3	113567	1	16621
47467	3	113568	7	32097
47468	4	113569	7	43667
47469	2	113570	3	43595
47470	5	113572	2	40608
47471	4	113575	2	35534
47472	2	113578	3	43317
47473	5	113585	6	30262
47474	5	113590	4	43559
47475	4	113592	7	43549
47476	5	113595	7	43681
47477	4	113600	7	2605
47478	5	113602	7	43603
47479	3	113603	5	23633
47480	5	113608	3	43500
47481	5	113609	1	43646
47482	4	113610	2	17594
47483	1	113611	1	14320
47484	5	113613	6	43592
47485	3	113617	3	33251
47486	5	113618	6	2076
47487	5	113620	2	13285
47488	5	113621	5	1933
47489	5	113622	3	43616
47490	3	113629	2	28244
47491	4	113631	7	43478
47492	5	113633	1	34272
47493	5	113638	4	23828
47494	4	113641	2	43568
47495	5	113644	6	3802
47496	1	113655	6	43644
47497	4	113662	2	35141
47498	4	113665	5	5306
47499	5	113666	6	18337
47500	4	113669	7	36451
47501	5	113673	6	12474
47502	5	113674	7	37342
47503	4	113675	4	43584
47504	5	113676	4	2351
47505	5	113680	6	34375
47506	4	113682	3	22708
47507	5	113685	2	43506
47508	5	113685	5	43506
47509	3	113689	1	17534
47510	5	113691	7	41727
47511	5	113692	4	38379
47512	4	113693	5	32009
47513	5	113693	1	32009
47514	3	113712	7	15996
47515	5	113713	6	36858
47516	5	113720	2	14302
47517	3	113729	5	15820
47518	4	113730	4	7623
47519	3	113740	5	32727
47520	5	113743	2	27623
47521	4	113745	3	40314
47522	2	113746	4	26966
47523	3	113747	4	330
47524	4	113751	5	813
47525	4	113751	1	813
47526	3	113755	5	36159
47527	4	113759	6	40936
47528	5	113762	3	43621
47529	5	113762	1	43621
47530	5	113765	3	43086
47531	1	113766	6	27514
47532	4	113771	7	138
47533	5	113774	2	27941
47534	3	113775	7	43602
47535	5	113780	6	28295
47536	4	113784	3	14433
47537	4	113786	6	20250
47538	4	113787	5	18332
47539	5	113788	3	3684
47540	4	113796	7	24863
47541	5	113797	6	39042
47542	4	113800	7	36113
47543	3	113801	5	21253
47544	5	113804	6	12935
47545	5	113810	6	11833
47546	5	113811	6	33677
47547	5	113814	1	27137
47548	5	113817	3	63
47549	4	113818	3	43507
47550	4	113820	5	23789
47551	5	113821	7	8757
47552	4	113825	1	42715
47553	4	113829	6	43455
47554	5	113830	7	21289
47555	5	113830	6	21289
47556	3	113831	5	43532
47557	4	113833	2	22601
47558	4	113838	5	1987
47559	5	113839	5	31497
47560	4	113841	5	36989
47561	2	113844	6	39893
47562	5	113845	2	27513
47563	3	113848	7	33128
47564	5	113849	6	30947
47565	4	113850	2	43437
47566	5	113856	2	2401
47567	4	113857	1	19254
47568	3	113859	5	431
47569	5	113864	2	37834
47570	5	113866	7	26840
47571	5	113873	7	22274
47572	5	113874	3	29320
47573	5	113878	2	43557
47574	3	113881	1	43440
47575	3	113885	2	749
47576	3	113888	4	24807
47577	4	113889	7	42038
47578	5	113890	7	38414
47579	5	113891	4	43583
47580	3	113892	3	43618
47581	5	113894	6	25608
47582	3	113897	3	14247
47583	3	113899	5	13326
47584	4	113900	3	8445
47585	3	113902	4	43649
47586	5	113905	4	14642
47587	4	113911	5	20000
47588	3	113913	4	10127
47589	5	113922	2	765
47590	3	113939	7	38046
47591	4	113941	5	36940
47592	5	113942	7	16018
47593	4	113943	4	43574
47594	4	113946	3	2665
47595	5	113948	4	43598
47596	5	113950	6	10199
47597	3	113953	5	28669
47598	5	113955	1	43597
47599	4	113957	7	43565
47600	5	113959	6	39441
47601	5	113962	6	946
47602	4	113963	6	35619
47603	5	113965	5	31646
47604	5	113968	4	38541
47605	5	113974	6	27356
47606	3	113980	7	43541
47607	5	113981	6	43629
47608	3	113982	1	21386
47609	4	113984	6	39471
47610	5	113989	6	37259
47611	5	113991	6	28239
47612	3	113992	5	16346
47613	4	113995	5	43454
47614	3	113997	1	2172
47615	5	113999	6	26681
47616	5	114001	7	32697
47617	5	114001	4	32697
47618	5	114002	6	26897
47619	5	114007	4	43576
47620	3	114008	1	7851
47621	3	114009	5	43573
47622	1	114013	6	43619
47623	4	114021	3	42951
47624	5	114023	3	26624
47625	3	114024	5	43572
47626	4	114027	6	20178
47627	3	114029	1	9884
47628	3	114030	5	1309
47629	3	114031	3	20817
47630	4	114032	7	42919
47631	5	114032	5	42919
47632	5	114037	1	35038
47633	5	114041	2	36992
47634	5	114045	5	9733
47635	5	114051	7	43641
47636	5	114052	6	18645
47637	3	114054	4	43544
47638	5	114055	6	13105
47639	3	114059	7	39279
47640	3	114066	6	38787
47641	5	114067	4	43569
47642	2	114070	1	43486
47643	3	114077	5	5730
47644	4	114081	7	5718
47645	5	114084	6	43600
47646	4	114087	4	43636
47647	5	114088	6	39095
47648	4	114092	6	43672
47649	4	114093	2	36639
47650	4	114094	7	22426
47651	4	114095	2	43663
47652	4	114096	7	31825
47653	3	114098	5	43481
47654	4	114099	7	43567
47655	3	114102	5	43513
47656	4	114104	4	6937
47657	4	114109	4	40611
47658	3	114111	7	7387
47659	5	114114	2	39904
47660	5	114120	4	11239
47661	5	114124	6	6276
47662	3	114126	5	17410
47663	5	114127	5	29943
47664	4	114129	4	25836
47665	3	114130	7	35274
47666	5	114131	4	43482
47667	5	114133	6	2442
47668	4	114134	7	29810
47669	4	114135	4	43593
47670	2	114139	2	4652
47671	4	114141	6	27071
47672	4	114142	4	6206
47673	4	114143	1	36202
47674	5	114144	7	43659
47675	5	114148	4	43509
47676	3	114148	7	43509
47677	3	114149	2	5520
47678	4	114152	6	43505
47679	5	114153	3	27401
47680	3	114154	7	43472
47681	3	114156	7	21732
47682	5	114157	7	9813
47683	5	114161	2	5158
47684	5	114162	4	25295
47685	5	114163	3	19750
47686	4	114164	2	24717
47687	5	114165	3	29805
47688	5	114167	7	32772
47689	5	114170	2	24294
47690	1	114172	6	16702
47691	5	114173	1	19566
47692	3	114174	7	6169
47693	4	114175	5	18872
47694	4	114179	7	2850
47695	5	114181	1	4072
47696	3	114182	4	22369
47697	5	114183	5	30396
47698	5	114185	4	5201
47699	3	114187	3	43697
47700	5	114189	4	40614
47701	5	114196	2	27014
47702	5	114197	3	20623
47703	5	114202	7	43533
47704	4	114203	4	43435
47705	5	114205	6	20711
47706	5	114206	7	40658
47707	3	114213	7	43448
47708	5	114217	6	43693
47709	5	114219	1	36853
47710	5	114221	6	43522
47711	5	114226	2	34330
47712	4	114226	5	34330
47713	3	114230	4	43579
47714	5	114232	7	43590
47715	4	114235	7	36790
47716	5	114237	5	7772
47717	5	114242	4	43504
47718	4	114243	5	36931
47719	5	114245	6	43492
47720	5	114246	6	15105
47721	5	114248	3	43518
47722	5	114251	2	43698
47723	3	114255	7	43531
47724	4	114259	5	43445
47725	3	114261	3	43553
47726	5	114262	1	7982
47727	2	114263	4	43467
47728	1	114263	3	43467
47729	1	114266	6	6150
47730	5	114273	6	36406
47731	4	114277	3	542
47732	5	114278	2	43529
47733	3	114279	7	36316
47734	5	114281	4	36288
47735	5	114284	7	20545
47736	4	114285	7	13111
47737	5	114285	3	13111
47738	4	114286	3	13800
47739	3	114290	6	35505
47740	5	114291	3	43596
47741	5	114292	2	33647
47742	5	114292	7	33647
47743	5	114295	5	42840
47744	5	114296	6	519
47745	4	114297	3	13844
47746	3	114299	5	5138
47747	3	114301	5	18840
47748	4	114303	7	26542
47749	5	114305	4	5336
47750	5	114306	6	43499
47751	5	114307	6	43610
47752	3	114310	5	24604
47753	5	114311	2	19163
47754	2	114312	1	43686
47755	5	114312	7	43686
47756	2	114313	6	37950
47757	5	114315	2	21450
47758	5	114321	5	14491
47759	1	114323	6	28612
47760	3	114325	4	37925
47761	5	114326	4	20877
47762	1	114333	6	34462
47763	5	114339	2	35454
47764	3	114340	7	2979
47765	5	114341	3	5857
47766	5	114345	6	43607
47767	4	114348	4	43623
47768	5	114350	7	15279
47769	4	114353	5	38206
47770	4	114354	2	43434
47771	4	114358	6	43441
47772	2	114361	3	2445
47773	4	114362	3	1258
47774	5	114369	6	17527
47775	5	114370	3	43642
47776	4	114371	7	34581
47777	4	114376	5	24073
47778	5	114378	3	41131
47779	5	114382	2	28288
47780	4	114386	3	43526
47781	4	114386	7	43526
47782	4	114387	1	43465
47783	3	114388	1	612
47784	5	114389	7	33918
47785	5	114389	2	33918
47786	2	114393	3	9621
47787	5	114394	1	43632
47788	5	114400	6	16544
47789	5	114404	7	35060
47790	5	114406	6	31546
47791	3	114408	5	40458
47792	4	114408	3	40458
47793	5	114409	2	11167
47794	4	114410	7	36515
47795	5	114411	2	27488
47796	3	114415	7	43645
47797	5	114416	1	10997
47798	5	114418	2	12862
47799	5	114421	5	31557
47800	3	114423	3	18085
47801	5	114428	3	35732
47802	4	114434	4	20288
47803	3	114437	7	26588
47804	4	114438	7	5183
47805	3	114439	7	43650
47806	5	114444	4	43556
47807	5	114445	4	31018
47808	4	114446	7	30478
47809	5	114448	2	29678
47810	5	114449	2	27907
47811	5	114451	6	43692
47812	5	114452	4	5799
47813	2	114454	4	10702
47814	5	114457	3	337
47815	3	114463	7	27547
47816	5	114465	2	35951
47817	5	114466	2	30107
47818	4	114468	3	6156
47819	3	114469	1	25590
47820	5	114476	7	22611
47821	5	114484	4	9633
47822	3	114489	7	43763
47823	5	114490	2	34252
47824	5	114494	3	19382
47825	1	114498	1	27273
47826	3	114501	5	13740
47827	5	114503	2	43952
47828	5	114507	7	15086
47829	5	114508	3	43913
47830	3	114509	7	43941
47831	4	114510	7	18218
47832	5	114511	6	1548
47833	4	114515	7	31671
47834	5	114516	2	29231
47835	5	114516	4	29231
47836	5	114519	2	43886
47837	5	114520	1	41294
47838	4	114522	7	11156
47839	5	114525	5	5468
47840	4	114526	3	27895
47841	5	114527	2	43937
47842	3	114528	5	43794
47843	3	114529	7	29728
47844	4	114531	5	28302
47845	5	114533	7	43867
47846	4	114534	3	43872
47847	3	114548	3	24708
47848	5	114551	7	17181
47849	5	114552	4	5871
47850	5	114553	1	21390
47851	3	114555	6	37966
47852	4	114561	7	43945
47853	4	114562	5	43748
47854	5	114563	4	18974
47855	4	114572	6	15186
47856	5	114573	1	35160
47857	5	114577	1	21847
47858	5	114578	2	21783
47859	5	114580	6	38818
47860	5	114581	2	5613
47861	4	114582	4	5106
47862	5	114586	1	10203
47863	5	114589	5	43953
47864	4	114592	7	43827
47865	5	114595	2	43848
47866	5	114596	7	28229
47867	1	114597	6	29939
47868	3	114599	4	18468
47869	5	114601	3	15326
47870	4	114610	6	20329
47871	4	114612	1	14354
47872	5	114613	6	43766
47873	5	114616	3	19883
47874	4	114616	6	19883
47875	5	114617	3	17700
47876	5	114620	7	43828
47877	4	114622	1	2021
47878	5	114624	1	35898
47879	5	114625	6	43775
47880	5	114627	7	9970
47881	4	114638	5	17629
47882	5	114639	6	43730
47883	5	114639	3	43730
47884	5	114640	3	13155
47885	5	114643	5	11413
47886	5	114644	4	43768
47887	5	114647	4	43194
47888	5	114649	2	20219
47889	5	114651	3	22987
47890	5	114653	6	43760
47891	5	114654	1	3924
47892	4	114658	7	39666
47893	5	114659	4	43858
47894	3	114660	5	34991
47895	5	114662	7	43732
47896	4	114664	3	30011
47897	3	114666	5	43839
47898	4	114668	5	4798
47899	5	114670	6	43815
47900	3	114671	2	9465
47901	5	114673	6	43950
47902	5	114674	5	43706
47903	3	114675	1	23621
47904	3	114676	4	34059
47905	4	114677	3	9350
47906	3	114680	7	43851
47907	5	114681	6	268
47908	4	114682	2	43756
47909	5	114683	6	15110
47910	4	114686	4	2572
47911	5	114687	1	43415
47912	5	114690	7	29726
47913	4	114694	6	43961
47914	4	114695	5	7373
47915	4	114696	4	11907
47916	3	114698	7	43752
47917	5	114698	6	43752
47918	3	114700	5	41209
47919	3	114704	7	43923
47920	5	114707	2	43747
47921	5	114708	1	43881
47922	4	114710	5	997
47923	4	114713	5	3634
47924	5	114718	5	41240
47925	5	114720	3	9348
47926	3	114725	6	8303
47927	4	114730	4	33251
47928	4	114732	1	43724
47929	3	114732	2	43724
47930	4	114736	6	43738
47931	4	114737	7	43805
47932	5	114742	4	10221
47933	5	114743	4	4867
47934	5	114745	3	43734
47935	5	114747	2	27076
47936	3	114748	6	43924
47937	5	114752	6	43915
47938	5	114753	3	12040
47939	4	114757	5	24703
47940	5	114758	6	6773
47941	5	114759	2	8300
47942	1	114760	4	38839
47943	5	114761	7	12506
47944	3	114762	5	43939
47945	5	114764	4	41555
47946	5	114765	1	6769
47947	4	114766	6	26336
47948	4	114767	3	21606
47949	5	114768	3	43720
47950	5	114776	3	6589
47951	5	114777	7	26288
47952	3	114782	3	33937
47953	4	114783	5	43885
47954	4	114784	2	43948
47955	5	114785	6	34221
47956	5	114790	4	26466
47957	1	114791	6	28315
47958	4	114792	4	8375
47959	3	114797	2	8600
47960	3	114798	7	7709
47961	5	114799	3	34482
47962	5	114801	2	43932
47963	5	114805	6	16813
47964	4	114806	5	36794
47965	5	114807	6	43859
47966	5	114808	4	33435
47967	3	114809	7	42772
47968	3	114812	5	43882
47969	3	114814	3	25544
47970	5	114816	3	20333
47971	4	114820	5	43826
47972	3	114822	1	43856
47973	5	114822	6	43856
47974	5	114823	1	41069
47975	5	114828	6	27256
47976	5	114830	7	10880
47977	3	114831	7	36088
47978	4	114836	7	29831
47979	3	114839	5	22242
47980	4	114848	2	3823
47981	5	114849	1	2018
47982	5	114850	6	25904
47983	5	114853	2	15270
47984	5	114856	6	7992
47985	5	114864	6	43835
47986	3	114868	6	43888
47987	5	114869	4	41507
47988	5	114872	3	43884
47989	4	114878	3	40769
47990	5	114880	6	32208
47991	4	114882	6	19011
47992	5	114884	7	18842
47993	5	114886	4	43917
47994	3	114887	4	43906
47995	4	114889	4	3253
47996	5	114890	7	23334
47997	5	114893	5	25430
47998	5	114895	6	43757
47999	3	114896	5	11863
48000	3	114898	2	2004
48001	4	114902	6	43842
48002	5	114904	2	6080
48003	4	114910	2	21664
48004	1	114914	6	43928
48005	5	114915	4	18715
48006	5	114916	6	39163
48007	4	114918	4	2470
48008	4	114923	5	3393
48009	5	114924	1	43857
48010	5	114926	6	43714
48011	5	114927	6	27362
48012	4	114929	4	43868
48013	4	114930	3	33438
48014	4	114936	7	21574
48015	5	114936	4	21574
48016	4	114938	5	31129
48017	5	114939	7	969
48018	4	114940	7	33607
48019	5	114941	4	28630
48020	5	114942	2	18390
48021	4	114945	5	12516
48022	4	114949	5	35654
48023	5	114956	6	28293
48024	5	114958	1	43971
48025	4	114964	4	42436
48026	5	114967	3	14677
48027	3	114972	5	43976
48028	4	114973	5	15623
48029	4	114974	2	4192
48030	3	114976	1	10802
48031	5	114978	4	44104
48032	5	114979	6	32207
48033	2	114981	6	22126
48034	4	114983	5	44136
48035	4	114985	1	27405
48036	3	114988	7	44038
48037	4	114990	6	28039
48038	5	114994	7	43237
48039	4	114997	5	44164
48040	5	114999	6	8735
48041	4	115000	5	4426
48042	5	115002	1	33230
48043	5	115003	2	11543
48044	5	115005	2	5461
48045	3	115009	5	11073
48046	5	115012	6	44133
48047	4	115013	6	44098
48048	5	115015	7	44053
48049	4	115018	5	32003
48050	4	115018	2	32003
48051	5	115019	4	44117
48052	4	115023	1	42799
48053	4	115024	7	39465
48054	3	115025	3	44139
48055	4	115029	6	6101
48056	3	115031	3	14990
48057	3	115033	1	32839
48058	5	115035	1	10235
48059	4	115038	4	6235
48060	5	115041	6	6066
48061	4	115043	5	17803
48062	5	115045	3	33147
48063	4	115046	7	40939
48064	4	115049	4	6848
48065	5	115050	2	5297
48066	5	115051	6	32611
48067	3	115051	7	32611
48068	4	115052	7	22407
48069	4	115054	1	40931
48070	5	115057	5	40189
48071	1	115060	6	21807
48072	4	115061	7	9283
48073	5	115062	6	44160
48074	5	115063	6	44043
48075	5	115063	3	44043
48076	5	115066	1	7706
48077	5	115068	4	27152
48078	5	115072	6	15016
48079	5	115076	6	44084
48080	3	115078	7	36411
48081	5	115078	6	36411
48082	4	115082	5	27715
48083	5	115082	2	27715
48084	4	115083	5	35974
48085	3	115084	5	44077
48086	5	115085	7	9777
48087	5	115086	2	43823
48088	2	115087	6	25295
48089	1	115088	6	11955
48090	5	115095	2	36992
48091	4	115097	1	40699
48092	5	115101	2	20017
48093	4	115102	6	14858
48094	3	115105	7	22965
48095	4	115108	6	11486
48096	3	115110	5	24513
48097	3	115111	7	27332
48098	4	115113	1	43986
48099	4	115117	4	27212
48100	5	115119	1	41962
48101	5	115127	2	44090
48102	5	115127	3	44090
48103	4	115129	6	40131
48104	5	115131	6	34624
48105	5	115132	6	29692
48106	3	115134	3	42481
48107	4	115135	6	28320
48108	3	115140	5	20995
48109	5	115141	7	32649
48110	5	115144	6	43965
48111	4	115148	7	15155
48112	4	115151	7	29568
48113	5	115154	6	15907
48114	5	115163	1	15022
48115	4	115166	6	44064
48116	5	115167	1	10781
48117	3	115170	5	44006
48118	5	115173	7	44097
48119	4	115174	5	21900
48120	5	115179	6	43992
48121	3	115182	6	33787
48122	5	115183	1	3870
48123	4	115184	5	44078
48124	3	115185	3	38447
48125	5	115188	3	13100
48126	5	115191	7	4465
48127	4	115196	7	5443
48128	5	115198	4	44049
48129	5	115198	2	44049
48130	1	115199	6	37068
48131	4	115200	7	24223
48132	5	115202	6	43094
48133	5	115207	7	32484
48134	4	115214	7	44162
48135	4	115217	7	44140
48136	5	115222	6	7582
48137	5	115223	6	14678
48138	5	115227	1	31374
48139	5	115229	4	44021
48140	5	115231	3	265
48141	3	115233	7	44138
48142	5	115235	4	44167
48143	5	115236	2	13498
48144	4	115238	3	8285
48145	5	115240	3	44107
48146	3	115241	7	23298
48147	5	115243	7	38926
48148	5	115246	7	23427
48149	5	115247	7	42864
48150	5	115249	7	44121
48151	4	115251	5	18637
48152	5	115253	2	18166
48153	4	115255	1	44057
48154	4	115256	2	44066
48155	1	115258	6	44032
48156	5	115259	2	14263
48157	5	115260	3	12568
48158	4	115261	2	44148
48159	5	115262	2	33212
48160	5	115263	6	43998
48161	5	115263	5	43998
48162	5	115264	6	27559
48163	5	115267	7	44026
48164	4	115268	7	44001
48165	4	115270	3	37439
48166	5	115272	2	33053
48167	5	115275	1	22924
48168	5	115275	5	22924
48169	4	115276	1	24900
48170	5	115279	6	12178
48171	5	115282	6	44130
48172	3	115285	3	30690
48173	3	115286	2	6983
48174	5	115287	2	44178
48175	3	115288	5	43982
48176	5	115289	4	6378
48177	5	115290	4	44155
48178	4	115291	1	29769
48179	5	115291	2	29769
48180	5	115293	2	24725
48181	3	115294	7	44028
48182	4	115295	5	19783
48183	5	115298	3	12907
48184	5	115299	2	37870
48185	5	115300	1	44070
48186	4	115301	6	27658
48187	5	115302	3	21324
48188	5	115303	6	40679
48189	5	115306	2	17710
48190	5	115308	4	2187
48191	5	115309	5	44060
48192	4	115310	2	14578
48193	4	115311	4	44181
48194	4	115313	7	2244
48195	3	115316	5	39891
48196	5	115318	2	21785
48197	5	115323	3	10076
48198	5	115325	6	44173
48199	5	115326	1	8050
48200	5	115326	4	8050
48201	1	115329	7	9193
48202	5	115332	3	2712
48203	1	115335	6	28647
48204	5	115338	7	638
48205	5	115340	2	722
48206	5	115344	2	4045
48207	4	115348	7	34311
48208	3	115354	5	43969
48209	4	115354	1	43969
48210	5	115356	6	35079
48211	3	115357	6	17794
48212	4	115358	5	33022
48213	4	115360	7	44071
48214	4	115361	2	7588
48215	4	115363	5	44056
48216	5	115365	6	44016
48217	2	115365	1	44016
48218	5	115371	4	41810
48219	5	115376	2	44174
48220	4	115380	4	44145
48221	3	115384	7	44128
48222	5	115385	6	41757
48223	3	115387	1	6769
48224	5	115394	3	32633
48225	5	115399	2	281
48226	4	115400	3	38219
48227	4	115412	7	43966
48228	4	115415	5	44076
48229	4	115417	6	37634
48230	3	115418	6	10258
48231	5	115420	4	10013
48232	4	115426	7	12662
48233	5	115427	4	5925
48234	4	115430	7	3168
48235	5	115433	1	44020
48236	5	115435	4	41107
48237	5	115440	6	41586
48238	5	115445	4	30140
48239	5	115447	2	44088
48240	5	115447	7	44088
48241	5	115448	1	38500
48242	4	115450	7	3127
48243	5	115454	1	44102
48244	1	115454	6	44102
48245	5	115455	1	44131
48246	5	115457	3	9308
48247	4	115459	3	22220
48248	3	115460	4	44094
48249	5	115461	4	44184
48250	5	115464	7	27191
48251	4	115465	6	44161
48252	5	115466	6	44036
48253	5	115479	2	12479
48254	5	115481	2	44099
48255	3	115482	2	44034
48256	3	115484	5	24872
48257	3	115485	1	16406
48258	3	115490	5	43973
48259	3	115491	5	44187
48260	3	115492	1	44132
48261	5	115495	1	35367
48262	5	115497	1	44059
48263	3	115499	5	39478
48264	4	115502	1	14199
48265	1	115503	6	39163
48266	3	115504	3	865
48267	4	115508	5	44017
48268	5	115509	6	43594
48269	3	115510	5	44009
48270	5	115515	7	44154
48271	5	115518	4	5786
48272	4	115521	4	34751
48273	5	115523	5	12478
48274	3	115528	3	17381
48275	5	115533	5	44141
48276	5	115536	2	38939
48277	5	115537	5	14875
48278	3	115539	2	14897
48279	4	115540	7	19591
48280	5	115543	7	37456
48281	5	115544	5	44423
48282	4	115545	7	44232
48283	3	115546	5	44270
48284	5	115550	6	24215
48285	4	115551	7	20329
48286	5	115554	4	40680
48287	3	115557	2	44303
48288	4	115558	2	26321
48289	4	115561	2	44324
48290	5	115566	1	12790
48291	4	115577	5	22363
48292	5	115579	5	37019
48293	4	115580	5	23735
48294	5	115582	3	36887
48295	5	115589	2	44291
48296	5	115591	7	21544
48297	4	115592	7	44257
48298	3	115594	5	41829
48299	4	115595	5	30440
48300	1	115596	1	36537
48301	5	115598	6	28816
48302	5	115603	1	9565
48303	5	115606	5	44341
48304	5	115611	2	44248
48305	4	115614	7	43135
48306	2	115615	1	5194
48307	5	115616	2	44200
48308	5	115616	7	44200
48309	5	115617	6	39627
48310	2	115619	3	44421
48311	3	115619	5	44421
48312	4	115625	7	32324
48313	5	115626	7	44386
48314	5	115627	2	39294
48315	5	115628	4	2272
48316	5	115631	2	39021
48317	2	115634	3	18409
48318	5	115636	3	44393
48319	5	115638	4	44402
48320	3	115638	5	44402
48321	4	115640	2	44244
48322	3	115642	3	44214
48323	3	115643	7	2418
48324	4	115644	5	9040
48325	4	115648	6	44290
48326	5	115652	2	25337
48327	4	115653	6	44309
48328	4	115659	4	36542
48329	5	115660	6	44220
48330	5	115661	6	19035
48331	5	115662	1	21134
48332	4	115663	5	39581
48333	3	115664	1	18316
48334	5	115668	7	3659
48335	4	115669	2	43331
48336	4	115673	5	44213
48337	5	115677	2	7227
48338	4	115679	5	44435
48339	5	115682	4	17053
48340	5	115683	2	15572
48341	5	115684	4	44196
48342	5	115685	6	24614
48343	3	115686	5	17342
48344	3	115687	5	44338
48345	3	115688	7	6591
48346	2	115691	2	12305
48347	5	115692	2	5549
48348	5	115693	4	44197
48349	5	115696	6	44280
48350	5	115698	2	34155
48351	5	115701	1	35234
48352	4	115701	3	35234
48353	3	115702	2	40131
48354	5	115708	3	11688
48355	5	115713	7	11177
48356	3	115715	7	43957
48357	5	115717	6	44249
48358	4	115719	4	26690
48359	3	115720	7	8161
48360	4	115722	7	11769
48361	5	115723	3	44394
48362	4	115724	7	16813
48363	4	115725	4	19889
48364	5	115731	5	13486
48365	4	115731	3	13486
48366	3	115732	4	44219
48367	4	115733	4	44360
48368	5	115734	5	27140
48369	5	115735	4	38574
48370	4	115745	4	44390
48371	5	115747	2	33231
48372	4	115751	2	2443
48373	4	115755	7	44315
48374	4	115758	2	44336
48375	5	115759	5	7591
48376	5	115763	1	36029
48377	5	115764	7	44434
48378	5	115765	1	44372
48379	1	115766	4	44247
48380	3	115769	2	3451
48381	5	115770	1	638
48382	5	115771	6	12290
48383	2	115776	7	27517
48384	3	115778	1	25731
48385	5	115778	4	25731
48386	3	115786	3	23727
48387	3	115787	5	3024
48388	4	115788	2	16127
48389	5	115791	3	2184
48390	4	115792	4	33851
48391	1	115793	6	26955
48392	4	115800	1	9330
48393	5	115801	1	44413
48394	5	115803	1	14862
48395	4	115806	5	35373
48396	3	115812	7	40713
48397	5	115813	5	15118
48398	5	115814	7	25275
48399	5	115818	2	32901
48400	5	115820	3	44340
48401	2	115821	7	35838
48402	1	115822	6	6644
48403	5	115825	1	21493
48404	5	115826	2	12185
48405	5	115826	3	12185
48406	5	115827	6	44259
48407	5	115829	6	36375
48408	5	115833	5	44304
48409	3	115835	5	7509
48410	3	115837	3	33648
48411	5	115838	7	44288
48412	3	115839	6	4735
48413	5	115842	2	26341
48414	5	115844	2	9180
48415	3	115845	4	44320
48416	4	115845	3	44320
48417	5	115852	5	44245
48418	5	115854	1	1846
48419	3	115856	7	787
48420	4	115859	7	8918
48421	3	115863	4	9833
48422	5	115867	7	491
48423	4	115869	3	33632
48424	5	115869	5	33632
48425	4	115871	7	44269
48426	3	115876	2	41216
48427	5	115886	6	44365
48428	5	115887	4	172
48429	4	115890	7	29164
48430	4	115891	7	44292
48431	5	115892	5	3530
48432	5	115895	2	12016
48433	3	115896	6	40833
48434	5	115898	6	30230
48435	5	115904	6	44419
48436	4	115906	7	44193
48437	4	115910	1	44203
48438	4	115914	3	44431
48439	5	115916	2	14103
48440	5	115917	2	44359
48441	3	115918	1	6694
48442	4	115919	4	44430
48443	5	115923	5	24678
48444	4	115924	7	18364
48445	4	115926	5	44218
48446	5	115929	6	22556
48447	3	115930	5	44216
48448	2	115935	3	39777
48449	3	115940	5	24235
48450	4	115942	4	31015
48451	5	115943	7	44319
48452	5	115944	4	44286
48453	5	115948	5	34551
48454	4	115951	6	20711
48455	5	115952	5	43678
48456	4	115954	6	44387
48457	2	115956	1	27661
48458	2	115957	2	40611
48459	5	115961	3	44230
48460	1	115963	6	3122
48461	4	115967	2	5238
48462	5	115969	6	24186
48463	5	115973	2	44302
48464	3	115974	5	27426
48465	4	115979	7	7772
48466	5	115981	2	44329
48467	3	115982	3	44301
48468	5	115989	7	27488
48469	5	115992	7	44345
48470	4	115994	7	44289
48471	5	115996	4	44298
48472	5	115996	6	44298
48473	5	115997	2	25880
48474	4	115998	2	11557
48475	4	116001	7	18488
48476	5	116004	5	15679
48477	3	116005	7	44371
48478	5	116008	4	28970
48479	5	116015	5	39454
48480	4	116017	6	21171
48481	5	116019	2	29632
48482	5	116025	3	22283
48483	2	116028	6	26210
48484	3	116029	5	13950
48485	5	116032	2	13128
48486	3	116037	5	36830
48487	4	116039	6	44381
48488	5	116044	4	25206
48489	4	116046	2	20140
48490	4	116049	1	5972
48491	4	116050	2	44346
48492	5	116051	5	22380
48493	5	116052	6	4436
48494	4	116057	5	44368
48495	5	116058	7	19777
48496	4	116060	1	23430
48497	3	116062	3	21392
48498	3	116062	7	21392
48499	5	116063	5	13473
48500	5	116064	7	748
48501	3	116066	3	22542
48502	1	116067	6	44271
48503	5	116068	4	4621
48504	5	116069	2	24283
48505	3	116070	5	14186
48506	3	116071	2	44407
48507	5	116072	7	44433
48508	5	116072	5	44433
48509	5	116073	4	905
48510	5	116075	4	43070
48511	5	116076	4	44337
48512	5	116077	7	39992
48513	5	116078	4	27644
48514	3	116079	1	31324
48515	5	116080	2	44235
48516	5	116082	1	2993
48517	5	116086	5	18271
48518	5	116088	2	5109
48519	4	116092	2	17806
48520	5	116094	5	44436
48521	4	116096	3	14280
48522	1	116100	6	44274
48523	4	116108	7	27206
48524	4	116112	1	1839
48525	5	116120	6	44242
48526	4	116121	1	1061
48527	5	116122	6	44426
48528	4	116123	2	14845
48529	5	116124	6	44205
48530	3	116125	5	34448
48531	5	116134	4	15361
48532	5	116135	7	44378
48533	4	116137	5	18476
48534	3	116140	5	26271
48535	5	116141	5	44322
48536	5	116142	7	44403
48537	5	116143	2	44415
48538	3	116144	4	9483
48539	5	116146	6	3991
48540	5	116150	4	44283
48541	3	116151	4	6470
48542	4	116153	7	44318
48543	4	116156	1	20970
48544	5	116158	2	44349
48545	5	116161	6	44424
48546	3	116166	5	44411
48547	4	116169	7	35131
48548	3	116170	5	6296
48549	4	116174	5	44277
48550	4	116176	2	35573
48551	5	116177	2	2329
48552	4	116177	3	2329
48553	4	116179	6	44209
48554	5	116179	7	44209
48555	3	116181	7	13424
48556	5	116182	4	37950
48557	5	116186	3	44375
48558	5	116188	3	20255
48559	3	116189	3	13371
48560	5	116189	4	13371
48561	5	116190	2	23656
48562	5	116192	5	26904
48563	5	116194	5	9105
48564	3	116196	4	37398
48565	4	116198	5	26456
48566	5	116198	2	26456
48567	4	116204	2	35190
48568	4	116205	5	8737
48569	5	116207	1	23323
48570	3	116207	7	23323
48571	5	116208	7	9007
48572	5	116209	6	34200
48573	3	116213	5	10899
48574	5	116219	6	14424
48575	5	116220	7	36791
48576	5	116223	2	9563
48577	3	116224	3	10848
48578	5	116225	1	42137
48579	4	116226	5	44409
48580	3	116227	5	24348
48581	5	116237	6	43223
48582	5	116238	6	9190
48583	2	116239	4	44344
48584	5	116239	6	44344
48585	5	116243	6	32567
48586	5	116244	5	44414
48587	3	116246	3	44282
48588	3	116248	7	13577
48589	5	116251	2	44411
48590	5	116252	1	44647
48591	5	116253	3	28530
48592	3	116255	4	19839
48593	5	116259	6	4199
48594	5	116263	6	29284
48595	4	116265	6	22420
48596	5	116267	2	28528
48597	5	116268	4	31114
48598	5	116270	3	7610
48599	5	116271	7	44555
48600	4	116271	5	44555
48601	5	116275	2	2750
48602	3	116280	3	21334
48603	5	116283	1	44683
48604	5	116284	7	44667
48605	5	116285	5	5704
48606	3	116287	7	44531
48607	2	116290	6	13938
48608	3	116292	4	42939
48609	5	116293	6	14982
48610	4	116294	2	40062
48611	5	116297	4	44574
48612	4	116299	7	12931
48613	5	116304	2	26963
48614	5	116305	2	44700
48615	5	116306	1	30709
48616	4	116308	5	12345
48617	1	116315	6	44452
48618	5	116318	1	15303
48619	5	116320	6	6668
48620	5	116321	6	35810
48621	3	116326	5	44634
48622	3	116327	2	28964
48623	1	116328	6	807
48624	5	116330	6	42516
48625	4	116331	4	39284
48626	5	116332	2	44614
48627	4	116334	7	24080
48628	4	116334	1	24080
48629	3	116335	5	44334
48630	3	116335	1	44334
48631	5	116338	4	24050
48632	5	116338	7	24050
48633	4	116339	3	3767
48634	4	116339	7	3767
48635	5	116340	6	39763
48636	5	116341	5	44544
48637	5	116342	6	7293
48638	5	116346	2	14531
48639	4	116347	5	1409
48640	5	116348	7	44550
48641	4	116349	7	44517
48642	5	116351	1	13662
48643	4	116352	6	31634
48644	5	116352	1	31634
48645	5	116356	1	44538
48646	3	116358	4	44641
48647	5	116359	1	44610
48648	4	116360	7	29582
48649	4	116363	5	5391
48650	5	116365	7	26685
48651	4	116370	6	44480
48652	4	116373	5	41851
48653	4	116374	3	44520
48654	5	116377	1	23432
48655	4	116379	7	29619
48656	2	116380	1	44487
48657	4	116382	3	22308
48658	4	116383	3	44669
48659	2	116384	5	32597
48660	4	116389	1	44560
48661	3	116390	4	3848
48662	4	116392	2	44592
48663	5	116394	7	44600
48664	5	116396	6	44661
48665	4	116396	1	44661
48666	2	116399	4	34739
48667	5	116400	6	44017
48668	4	116401	5	39297
48669	5	116405	4	13577
48670	5	116406	6	29450
48671	5	116408	5	44645
48672	3	116409	1	7726
48673	2	116410	5	15693
48674	5	116410	6	15693
48675	4	116414	7	44499
48676	5	116415	6	31818
48677	5	116419	4	21295
48678	4	116420	3	38219
48679	5	116421	6	15385
48680	5	116422	4	44576
48681	5	116426	6	688
48682	5	116429	7	44524
48683	3	116430	5	30153
48684	4	116434	5	35179
48685	4	116438	7	44687
48686	3	116447	1	34032
48687	4	116450	3	31076
48688	5	116454	2	35276
48689	5	116454	1	35276
48690	5	116455	2	28945
48691	5	116457	7	38701
48692	5	116459	6	44451
48693	4	116460	3	20150
48694	5	116461	2	25658
48695	3	116464	5	18283
48696	5	116466	1	11262
48697	3	116468	5	30422
48698	5	116469	2	39982
48699	5	116470	6	44627
48700	2	116471	6	42313
48701	3	116472	2	19523
48702	3	116474	7	5053
48703	3	116475	7	44607
48704	5	116476	6	13371
48705	5	116477	7	5264
48706	4	116483	2	25018
48707	5	116484	6	44485
48708	4	116487	7	456
48709	3	116490	4	39277
48710	5	116491	4	25884
48711	5	116492	7	44468
48712	5	116493	5	28305
48713	4	116495	6	33714
48714	5	116496	6	12320
48715	5	116498	6	1329
48716	5	116501	1	43995
48717	5	116502	4	44649
48718	3	116503	1	44672
48719	1	116506	6	28987
48720	5	116507	4	44622
48721	4	116509	2	25751
48722	5	116510	7	42536
48723	3	116514	7	17818
48724	2	116515	4	11877
48725	5	116517	7	44628
48726	4	116517	1	44628
48727	3	116518	1	44589
48728	3	116520	7	3786
48729	3	116521	3	35933
48730	4	116524	6	12700
48731	3	116525	5	3119
48732	5	116526	7	44608
48733	3	116527	7	17941
48734	5	116529	7	20520
48735	1	116532	6	9998
48736	5	116537	4	44563
48737	5	116538	2	8013
48738	4	116539	3	44529
48739	4	116544	5	7899
48740	3	116545	5	44479
48741	5	116546	5	44605
48742	5	116551	3	44540
48743	5	116555	6	25423
48744	4	116557	5	44558
48745	5	116558	4	1968
48746	1	116558	6	1968
48747	5	116560	5	35018
48748	5	116563	4	44707
48749	5	116564	6	11039
48750	4	116567	1	28588
48751	5	116573	6	35685
48752	4	116575	2	1780
48753	5	116577	6	19132
48754	4	116579	5	29610
48755	5	116581	3	44637
48756	5	116584	1	1813
48757	3	116585	5	44490
48758	5	116590	6	24490
48759	5	116591	6	44585
48760	5	116593	6	17067
48761	5	116594	4	44492
48762	4	116595	5	41802
48763	5	116597	4	44444
48764	5	116607	7	14562
48765	4	116608	7	31280
48766	3	116614	4	13600
48767	5	116615	7	44620
48768	5	116616	6	29691
48769	5	116617	1	10689
48770	4	116621	5	44594
48771	5	116622	2	16623
48772	3	116623	5	18223
48773	5	116624	2	19735
48774	5	116625	6	15532
48775	5	116627	6	44542
48776	1	116628	5	44515
48777	5	116629	6	20686
48778	5	116633	5	44632
48779	1	116635	6	44488
48780	5	116635	7	44488
48781	4	116636	7	13097
48782	5	116640	2	11504
48783	4	116648	5	30841
48784	2	116656	4	43134
48785	1	116658	6	44459
48786	4	116659	1	19613
48787	4	116660	7	6632
48788	5	116661	7	44481
48789	4	116662	7	2054
48790	5	116663	2	26116
48791	5	116663	6	26116
48792	3	116664	7	44664
48793	5	116666	7	44534
48794	5	116667	2	44551
48795	3	116671	5	44511
48796	4	116671	2	44511
48797	5	116676	2	44537
48798	5	116677	2	33202
48799	5	116678	1	15022
48800	4	116679	5	27975
48801	5	116683	7	39554
48802	3	116685	5	44553
48803	5	116686	6	44463
48804	4	116688	4	18922
48805	5	116694	2	25071
48806	5	116696	1	8931
48807	3	116697	1	44695
48808	2	116699	6	13621
48809	4	116700	5	29436
48810	3	116703	4	44654
48811	4	116704	5	10935
48812	5	116705	5	41499
48813	4	116706	2	44504
48814	4	116708	2	44638
48815	5	116709	4	44557
48816	4	116716	7	21525
48817	3	116718	6	16890
48818	4	116720	1	16170
48819	5	116721	6	44596
48820	5	116724	2	44705
48821	5	116730	6	44439
48822	5	116733	6	32913
48823	4	116735	2	44666
48824	5	116736	5	31129
48825	5	116739	2	31418
48826	5	116740	4	25190
48827	4	116741	7	44593
48828	2	116745	3	38162
48829	4	116747	2	27862
48830	5	116748	5	8154
48831	4	116750	7	44643
48832	5	116752	3	11578
48833	4	116753	7	10354
48834	5	116754	2	44686
48835	3	116756	7	3705
48836	5	116757	1	33658
48837	5	116759	7	26974
48838	5	116761	2	36383
48839	5	116763	4	44484
48840	3	116767	4	44566
48841	5	116768	5	44521
48842	5	116770	4	4749
48843	5	116772	7	20687
48844	3	116774	5	44579
48845	5	116777	7	37598
48846	4	116781	6	44693
48847	4	116784	5	40509
48848	5	116786	2	44629
48849	4	116788	4	44456
48850	4	116790	3	44467
48851	4	116793	7	23557
48852	5	116797	6	44626
48853	5	116798	4	44497
48854	5	116802	5	38002
48855	3	116803	1	3425
48856	4	116806	2	44625
48857	5	116808	2	44619
48858	5	116808	6	44619
48859	5	116812	7	44461
48860	3	116813	1	42317
48861	5	116816	1	6979
48862	4	116818	7	34394
48863	4	116819	3	34301
48864	5	116822	7	44554
48865	1	116823	6	41932
48866	4	116825	6	26600
48867	5	116826	5	44503
48868	5	116829	5	44587
48869	3	116830	3	44471
48870	5	116832	4	44532
48871	5	116834	6	14174
48872	3	116835	1	19751
48873	5	116837	6	17938
48874	5	116839	4	2951
48875	5	116841	5	19657
48876	5	116842	5	10699
48877	5	116849	6	38996
48878	3	116850	5	44677
48879	5	116851	3	28514
48880	5	116854	2	1376
48881	5	116857	5	44630
48882	5	116859	4	44706
48883	5	116860	6	25394
48884	4	116862	7	16432
48885	3	116863	7	28254
48886	5	116865	2	27625
48887	3	116866	1	23457
48888	5	116866	2	23457
48889	5	116872	2	43394
48890	4	116874	5	44694
48891	5	116875	3	25718
48892	4	116877	5	44528
48893	5	116878	2	44549
48894	4	116880	4	18839
48895	5	116881	2	36638
48896	5	116882	1	14269
48897	5	116884	1	73
48898	4	116889	2	12054
48899	3	116891	4	33949
48900	5	116892	6	23599
48901	3	116895	3	44635
48902	5	116896	6	2373
48903	3	116898	5	2190
48904	3	116901	7	42063
48905	3	116902	7	3997
48906	5	116905	5	44501
48907	4	116906	4	16242
48908	5	116908	6	6695
48909	3	116909	5	35827
48910	5	116914	5	44704
48911	5	116914	2	44704
48912	5	116915	6	44519
48913	4	116915	4	44519
48914	5	116917	2	44455
48915	5	116924	5	20902
48916	5	116926	5	3600
48917	4	116932	3	31980
48918	5	116933	7	17524
48919	4	116937	7	44443
48920	5	116940	3	44559
48921	4	116941	2	44680
48922	4	116943	5	8852
48923	5	116944	5	44568
48924	5	116946	4	44606
48925	3	116947	7	44453
48926	5	116952	1	193
48927	4	116953	3	44685
48928	5	116954	2	44502
48929	5	116957	2	2089
48930	5	116959	5	44571
48931	5	116961	1	15847
48932	5	116964	6	15891
48933	5	116965	2	41143
48934	5	116966	4	44507
48935	5	116969	7	44673
48936	3	116970	7	2275
48937	3	116977	4	36636
48938	5	116979	6	44696
48939	3	116981	5	44448
48940	5	116983	7	11440
48941	5	116984	4	299
48942	3	116988	1	4581
48943	5	116989	1	2333
48944	5	116991	5	35914
48945	5	116994	7	44495
48946	2	116995	3	44652
48947	5	116998	6	44474
48948	5	116999	7	42919
48949	5	117000	6	36957
48950	3	117001	1	44573
48951	5	117008	6	15678
48952	5	117015	7	9835
48953	3	117016	5	44659
48954	4	117017	1	19300
48955	5	117018	6	36658
48956	5	117022	2	39648
48957	5	117023	2	22425
48958	5	117025	3	42368
48959	5	117026	6	23195
48960	5	117027	6	38228
48961	4	117027	5	38228
48962	4	117028	7	10799
48963	5	117030	7	6468
48964	3	117031	4	40704
48965	5	117033	7	44866
48966	5	117038	1	26742
48967	5	117039	1	36917
48968	5	117043	1	2821
48969	5	117045	7	44940
48970	4	117051	2	20606
48971	4	117055	5	44933
48972	5	117062	1	37304
48973	1	117063	2	10497
48974	3	117068	7	29608
48975	5	117069	6	26425
48976	4	117070	5	37644
48977	4	117072	7	13856
48978	4	117073	7	34490
48979	5	117077	6	6116
48980	4	117080	5	11550
48981	5	117085	4	17114
48982	5	117086	1	44848
48983	5	117088	5	31101
48984	5	117092	4	13371
48985	4	117093	6	7215
48986	4	117094	7	44833
48987	5	117097	1	23252
48988	5	117099	3	44897
48989	5	117100	1	6425
48990	5	117101	6	7304
48991	3	117102	5	17351
48992	1	117104	6	44807
48993	5	117107	1	44826
48994	3	117108	5	44814
48995	5	117111	6	3348
48996	3	117112	4	28058
48997	3	117116	7	43830
48998	4	117118	3	36284
48999	3	117119	7	13760
49000	3	117121	4	1369
49001	5	117122	2	31318
49002	3	117123	1	44734
49003	1	117123	6	44734
49004	4	117124	4	26349
49005	4	117126	6	40366
49006	5	117127	5	236
49007	5	117129	4	8181
49008	4	117132	5	44843
49009	5	117136	6	26781
49010	3	117139	5	44888
49011	5	117141	1	12778
49012	3	117144	7	9554
49013	5	117145	5	37037
49014	3	117146	4	35599
49015	4	117151	2	44777
49016	5	117153	1	44762
49017	3	117154	7	32158
49018	3	117157	5	34239
49019	5	117159	5	10163
49020	5	117163	6	32487
49021	5	117165	6	39657
49022	4	117166	7	25027
49023	5	117168	5	3665
49024	5	117174	7	33477
49025	5	117175	6	23787
49026	4	117175	7	23787
49027	4	117176	5	6528
49028	4	117177	6	32288
49029	5	117180	6	11655
49030	1	117186	1	38860
49031	4	117190	7	26187
49032	5	117192	1	31950
49033	5	117196	7	43869
49034	5	117196	2	43869
49035	5	117200	7	44816
49036	5	117204	7	18874
49037	3	117204	1	18874
49038	3	117205	6	14965
49039	4	117209	5	23797
49040	4	117213	7	5822
49041	4	117215	7	44749
49042	5	117218	7	14779
49043	4	117219	6	6107
49044	5	117219	1	6107
49045	4	117220	5	10444
49046	4	117222	5	39797
49047	4	117223	2	44737
49048	5	117224	2	44917
49049	2	117225	4	16459
49050	5	117229	7	24074
49051	4	117231	1	44845
49052	5	117232	7	34157
49053	5	117233	3	34259
49054	2	117236	6	21370
49055	5	117237	7	44943
49056	3	117238	6	42171
49057	4	117241	3	40274
49058	3	117245	4	6499
49059	5	117246	4	44889
49060	3	117247	4	681
49061	4	117251	4	44841
49062	2	117253	6	44946
49063	5	117264	6	37055
49064	4	117265	6	29350
49065	5	117268	3	15961
49066	3	117271	7	38316
49067	4	117273	2	12578
49068	3	117274	1	2897
49069	5	117288	7	44836
49070	5	117289	7	4117
49071	5	117291	3	44798
49072	5	117294	1	15560
49073	5	117295	2	37900
49074	4	117301	2	9304
49075	4	117303	7	30953
49076	3	117303	5	30953
49077	5	117305	4	44842
49078	3	117307	4	12204
49079	5	117308	2	38505
49080	3	117316	7	41412
49081	5	117321	6	6729
49082	3	117325	4	44876
49083	4	117329	5	7964
49084	4	117330	6	44773
49085	4	117330	3	44773
49086	4	117332	7	41749
49087	4	117334	7	2352
49088	3	117334	3	2352
49089	4	117336	3	26739
49090	5	117337	6	44907
49091	5	117338	7	42288
49092	4	117339	4	44877
49093	5	117341	6	28906
49094	3	117344	5	37949
49095	5	117353	6	44930
49096	4	117356	6	42060
49097	5	117358	6	23789
49098	5	117359	5	30821
49099	5	117362	4	44891
49100	3	117364	7	34355
49101	2	117365	6	18851
49102	5	117367	6	6232
49103	4	117368	5	8229
49104	5	117369	6	44851
49105	4	117370	6	8940
49106	5	117373	6	37689
49107	3	117375	3	44914
49108	1	117376	6	44849
49109	4	117377	6	11004
49110	4	117383	1	14277
49111	5	117384	6	26556
49112	4	117385	6	29674
49113	4	117388	4	44901
49114	1	117389	6	17861
49115	4	117392	7	20438
49116	5	117392	6	20438
49117	5	117393	5	17939
49118	5	117397	4	30253
49119	5	117399	1	44879
49120	3	117401	4	44728
49121	4	117404	4	44793
49122	5	117406	6	19654
49123	4	117408	4	33144
49124	5	117409	2	29120
49125	4	117410	4	25351
49126	4	117412	6	12371
49127	5	117415	3	44950
49128	4	117415	1	44950
49129	3	117416	7	41404
49130	4	117417	5	34382
49131	3	117419	7	12732
49132	5	117420	5	44750
49133	5	117423	5	27596
49134	1	117428	4	41643
49135	1	117431	1	16450
49136	5	117440	7	1814
49137	5	117443	4	44872
49138	3	117444	5	16413
49139	5	117445	4	44713
49140	5	117445	3	44713
49141	4	117446	4	44720
49142	4	117448	5	44764
49143	5	117450	1	1007
49144	4	117452	5	44709
49145	5	117462	3	44884
49146	3	117467	4	10989
49147	3	117471	5	17995
49148	3	117473	5	17237
49149	5	117477	6	29134
49150	5	117478	1	16470
49151	5	117481	3	44945
49152	4	117482	7	37014
49153	4	117483	6	42436
49154	5	117484	7	44708
49155	5	117485	6	17265
49156	3	117487	4	44857
49157	5	117494	2	44910
49158	5	117496	3	39705
49159	3	117497	5	44941
49160	5	117499	1	44758
49161	3	117501	5	25206
49162	5	117504	6	29171
49163	5	117505	7	44957
49164	5	117507	6	44722
49165	5	117508	7	43333
49166	4	117513	6	30283
49167	5	117515	6	44949
49168	5	117517	1	17699
49169	5	117518	5	34669
49170	5	117519	2	44840
49171	4	117523	4	14440
49172	5	117524	4	43025
49173	2	117525	3	20184
49174	5	117527	2	42860
49175	4	117530	4	26905
49176	5	117533	2	44759
49177	4	117536	3	44856
49178	5	117537	1	43784
49179	5	117539	6	44915
49180	5	117544	2	16929
49181	5	117551	6	32760
49182	5	117552	6	27602
49183	5	117563	2	44800
49184	4	117564	5	30826
49185	5	117565	5	35485
49186	4	117566	6	44371
49187	5	117575	1	3237
49188	4	117582	2	44887
49189	5	117584	6	44740
49190	5	117585	6	42485
49191	4	117589	6	8755
49192	5	117592	5	8474
49193	5	117592	2	8474
49194	4	117593	5	21193
49195	5	117594	3	44937
49196	3	117595	7	44785
49197	5	117595	2	44785
49198	5	117597	7	44844
49199	3	117598	4	41348
49200	3	117600	2	8740
49201	4	117606	3	2841
49202	5	117609	7	36275
49203	4	117610	3	44792
49204	4	117612	7	22755
49205	5	117614	4	28222
49206	3	117616	7	44753
49207	4	117618	1	42667
49208	4	117623	7	32298
49209	5	117624	2	41145
49210	4	117625	4	1714
49211	5	117626	7	6733
49212	5	117628	5	37173
49213	4	117629	2	42900
49214	5	117631	4	44756
49215	5	117635	7	15092
49216	5	117636	6	20907
49217	3	117638	5	31823
49218	4	117643	3	45188
49219	4	117644	5	41615
49220	5	117645	2	2699
49221	3	117647	4	19321
49222	5	117650	7	45066
49223	4	117653	2	40899
49224	3	117656	1	23074
49225	3	117660	2	42231
49226	5	117662	4	34163
49227	3	117665	1	44967
49228	4	117666	5	34417
49229	2	117669	4	45022
49230	4	117670	7	34644
49231	5	117671	1	13054
49232	3	117671	5	13054
49233	4	117672	5	14540
49234	4	117673	2	42809
49235	5	117679	6	45060
49236	4	117680	5	17492
49237	4	117680	4	17492
49238	3	117685	7	13797
49239	4	117686	4	24392
49240	5	117687	7	45041
49241	3	117690	7	45172
49242	5	117693	2	45158
49243	5	117694	3	45194
49244	5	117697	6	22811
49245	5	117698	6	45127
49246	3	117699	2	35671
49247	4	117704	4	42401
49248	4	117708	5	12167
49249	4	117711	7	45016
49250	3	117719	4	314
49251	3	117721	3	40148
49252	5	117722	1	29230
49253	4	117722	7	29230
49254	5	117724	4	38688
49255	5	117725	2	45167
49256	5	117729	7	560
49257	4	117730	2	45166
49258	5	117733	7	18738
49259	3	117739	6	20467
49260	4	117740	4	38986
49261	3	117743	5	1219
49262	5	117747	3	39579
49263	4	117749	1	34747
49264	5	117751	6	23362
49265	5	117754	4	43961
49266	3	117754	5	43961
49267	3	117756	7	17214
49268	5	117757	3	30171
49269	5	117760	1	11586
49270	5	117761	2	44984
49271	4	117761	5	44984
49272	5	117764	6	7449
49273	4	117770	6	24572
49274	3	117771	5	22631
49275	5	117776	2	38663
49276	5	117779	5	14153
49277	5	117780	6	19729
49278	5	117795	2	23291
49279	5	117800	1	25263
49280	3	117803	1	6850
49281	3	117809	6	29929
49282	5	117815	6	29608
49283	4	117817	6	44994
49284	5	117817	7	44994
49285	3	117821	4	44970
49286	3	117825	7	36759
49287	4	117826	7	10807
49288	3	117827	7	44976
49289	1	117827	6	44976
49290	3	117829	4	925
49291	5	117831	6	8514
49292	3	117833	7	39626
49293	5	117835	6	44978
49294	5	117838	4	14263
49295	5	117840	5	45184
49296	4	117841	6	45035
49297	3	117843	7	37486
49298	4	117843	4	37486
49299	5	117847	1	10676
49300	5	117849	5	45074
49301	4	117855	7	35291
49302	5	117858	7	33927
49303	5	117864	5	45055
49304	4	117872	6	42566
49305	4	117873	3	45214
49306	5	117876	7	9891
49307	5	117880	7	35812
49308	5	117883	1	35265
49309	3	117884	3	15961
49310	4	117887	3	44962
49311	5	117890	2	33431
49312	3	117892	7	45137
49313	5	117898	4	16734
49314	4	117900	4	45155
49315	5	117901	4	45207
49316	4	117902	5	20471
49317	5	117903	1	30967
49318	4	117908	3	7476
49319	5	117908	1	7476
49320	5	117910	7	45054
49321	4	117912	6	45023
49322	5	117915	6	45077
49323	3	117917	1	11104
49324	4	117919	1	45088
49325	5	117930	7	31035
49326	5	117933	7	12232
49327	4	117933	3	12232
49328	5	117935	2	37644
49329	5	117936	6	34932
49330	5	117938	6	32387
49331	5	117940	7	41933
49332	5	117941	4	27056
49333	4	117945	2	10786
49334	4	117948	1	29912
49335	3	117949	5	35101
49336	3	117954	7	2760
49337	5	117955	2	10549
49338	3	117959	7	28056
49339	5	117962	6	28722
49340	3	117972	7	25541
49341	4	117973	7	29172
49342	5	117973	3	29172
49343	5	117977	2	42515
49344	5	117978	2	17183
49345	5	117980	2	30308
49346	5	117985	6	13101
49347	5	117986	6	45179
49348	4	117987	7	5797
49349	5	117988	2	25759
49350	4	117989	5	17703
49351	3	117990	7	42481
49352	5	117991	1	45131
49353	5	117994	4	14239
49354	5	117996	7	11559
49355	5	117997	6	5830
49356	4	118000	7	7311
49357	5	118004	6	45129
49358	4	118007	3	10209
49359	5	118008	3	45191
49360	4	118011	6	13306
49361	4	118012	3	1885
49362	5	118016	2	884
49363	3	118017	4	33322
49364	3	118019	3	45036
49365	4	118022	6	19139
49366	5	118027	2	35806
49367	5	118028	1	1228
49368	5	118030	2	11544
49369	4	118031	5	23341
49370	5	118033	7	33492
49371	4	118035	3	27037
49372	4	118039	3	136
49373	5	118040	6	34688
49374	5	118042	5	45008
49375	3	118043	7	45138
49376	1	118046	6	44971
49377	5	118048	1	30999
49378	4	118049	7	45000
49379	4	118050	3	45058
49380	5	118050	4	45058
49381	5	118052	6	35873
49382	5	118053	2	30153
49383	3	118056	1	23700
49384	3	118057	4	45071
49385	5	118058	1	23285
49386	5	118061	4	7023
49387	5	118068	6	12936
49388	3	118069	5	45193
49389	4	118070	1	45203
49390	5	118071	2	1963
49391	3	118074	7	10461
49392	4	118078	4	19316
49393	5	118079	2	42424
49394	5	118080	3	45053
49395	4	118086	3	4911
49396	5	118091	2	35804
49397	4	118093	5	26920
49398	4	118098	7	45065
49399	4	118099	6	24841
49400	5	118099	1	24841
49401	5	118100	3	4768
49402	5	118101	4	30812
49403	3	118103	5	29543
49404	1	118106	1	45153
49405	5	118112	4	17323
49406	1	118114	2	18025
49407	4	118117	1	45101
49408	5	118118	7	14726
49409	5	118122	5	44975
49410	4	118123	4	41772
49411	3	118124	2	5730
49412	5	118127	3	19056
49413	5	118128	6	3940
49414	5	118129	7	25416
49415	5	118132	5	4937
49416	4	118133	2	45043
49417	3	118137	5	24802
49418	5	118138	2	3989
49419	1	118140	4	45148
49420	5	118144	6	29118
49421	4	118145	6	34394
49422	5	118149	2	45198
49423	4	118151	6	45092
49424	4	118155	6	6283
49425	3	118156	5	43656
49426	5	118159	7	45164
49427	5	118160	2	19715
49428	5	118162	1	45037
49429	4	118163	2	44992
49430	5	118163	1	44992
49431	4	118164	2	2919
49432	5	118166	4	19011
49433	5	118171	6	11051
49434	5	118172	6	7617
49435	5	118173	6	30623
49436	4	118175	1	20784
49437	3	118176	7	14374
49438	3	118179	3	14501
49439	5	118180	6	43650
49440	4	118181	5	36264
49441	3	118183	2	17689
49442	4	118187	1	45091
49443	4	118195	5	13744
49444	3	118198	5	2228
49445	5	118203	4	45089
49446	5	118210	4	24900
49447	4	118210	1	24900
49448	4	118215	2	45100
49449	4	118216	3	184
49450	4	118218	7	2669
49451	5	118225	4	45197
49452	3	118229	7	1460
49453	4	118231	4	33821
49454	5	118232	4	45142
49455	5	118234	5	35366
49456	5	118237	7	2391
49457	4	118243	5	45050
49458	4	118250	4	21934
49459	3	118252	4	4846
49460	3	118253	7	24755
49461	3	118254	5	13636
49462	4	118258	6	3685
49463	5	118260	6	44819
49464	5	118263	6	45204
49465	5	118264	2	34021
49466	5	118265	2	15404
49467	5	118266	6	39745
49468	5	118269	7	20169
49469	4	118270	6	11578
49470	5	118276	1	45002
49471	3	118277	4	44966
49472	5	118280	2	45192
49473	5	118281	4	37465
49474	4	118282	2	19506
49475	4	118284	7	45044
49476	5	118285	1	45109
49477	5	118290	4	44693
49478	5	118292	1	45102
49479	4	118296	7	44961
49480	5	118298	1	23373
49481	5	118304	7	16227
49482	5	118306	2	24813
49483	3	118308	4	45216
49484	5	118309	5	12439
49485	5	118310	6	30529
49486	5	118316	1	45114
49487	4	118319	6	45190
49488	3	118320	7	27741
49489	4	118329	7	40476
49490	4	118330	5	26788
49491	4	118332	2	9273
49492	5	118333	7	19580
49493	5	118334	5	28155
49494	3	118338	3	6276
49495	5	118339	4	3508
49496	4	118342	5	45042
49497	2	118345	6	45165
49498	5	118347	7	28579
49499	4	118349	7	6156
49500	5	118349	3	6156
49501	5	118352	5	40618
49502	3	118356	7	44982
49503	5	118358	6	31997
49504	5	118359	2	6009
49505	5	118361	4	6594
49506	3	118371	1	34645
49507	5	118377	6	3406
49508	4	118379	6	26271
49509	5	118380	5	44977
49510	4	118383	7	45105
49511	5	118383	6	45105
49512	4	118385	7	45168
49513	4	118386	7	45107
49514	5	118388	1	34463
49515	5	118390	2	5661
49516	3	118391	5	44974
49517	5	118392	3	45093
49518	5	118392	7	45093
49519	5	118393	1	2874
49520	4	118397	2	24715
49521	4	118398	1	13436
49522	4	118399	7	35527
49523	5	118400	4	22913
49524	4	118401	4	32296
49525	3	118404	5	39148
49526	2	118406	1	37983
49527	4	118407	5	16613
49528	5	118408	3	22804
49529	5	118409	6	3222
49530	5	118410	5	20816
49531	5	118413	2	122
49532	5	118414	2	43119
49533	5	118418	2	13236
49534	4	118419	5	27227
49535	2	118420	5	38940
49536	5	118421	7	44979
49537	5	118423	7	16521
49538	3	118424	7	4592
49539	5	118430	6	45080
49540	5	118435	4	17392
49541	5	118436	6	8949
49542	5	118444	7	9001
49543	5	118446	7	24282
49544	5	118447	6	39123
49545	3	118448	4	42721
49546	5	118449	2	45110
49547	5	118450	2	45005
49548	5	118454	4	12582
49549	3	118458	5	10401
49550	5	118459	2	45209
49551	3	118461	7	41223
49552	5	118462	7	12067
49553	4	118467	5	45215
49554	5	118468	3	42987
49555	5	118468	1	42987
49556	5	118471	6	45118
49557	5	118473	3	7162
49558	5	118474	3	9565
49559	3	118479	5	38771
49560	5	118480	6	45003
49561	5	118485	6	31975
49562	4	118488	7	45085
49563	1	118490	2	29127
49564	3	118493	2	11596
49565	5	118495	6	45201
49566	5	118496	6	25790
49567	5	118497	6	42271
49568	5	118500	6	33789
49569	4	118502	4	43245
49570	4	118504	7	14885
49571	4	118504	5	14885
49572	2	118506	3	45032
49573	5	118509	6	45115
49574	5	118510	7	45084
49575	5	118516	6	18061
49576	5	118517	4	11039
49577	5	118518	5	18307
49578	5	118519	4	45001
49579	4	118520	1	42680
49580	5	118525	7	31405
49581	5	118526	4	44987
49582	5	118528	3	8034
49583	5	118531	5	24284
49584	5	118533	2	45094
49585	5	118534	5	5180
49586	4	118534	7	5180
49587	5	118537	6	41946
49588	5	118538	4	45430
49589	3	118539	7	5496
49590	5	118540	3	30697
49591	4	118542	6	45322
49592	4	118547	3	6399
49593	5	118548	6	39952
49594	4	118553	2	20972
49595	5	118555	1	32810
49596	5	118559	4	33672
49597	3	118559	3	33672
49598	5	118563	2	3106
49599	4	118567	7	37612
49600	4	118568	7	33971
49601	5	118569	7	45343
49602	4	118570	1	74
49603	5	118576	6	15872
49604	1	118583	6	42000
49605	3	118584	2	45291
49606	3	118585	5	19481
49607	5	118587	4	45464
49608	5	118590	4	10094
49609	5	118590	7	10094
49610	5	118591	1	15188
49611	5	118591	6	15188
49612	5	118596	1	1460
49613	5	118597	6	7395
49614	4	118599	5	45082
49615	3	118602	7	45447
49616	4	118609	5	40476
49617	4	118613	7	41610
49618	3	118614	6	45359
49619	5	118615	3	5612
49620	4	118619	5	4113
49621	5	118622	7	45488
49622	5	118625	6	45324
49623	5	118625	2	45324
49624	4	118627	4	45244
49625	3	118628	1	17338
49626	4	118629	7	19300
49627	5	118630	2	36891
49628	5	118632	4	16839
49629	5	118636	3	45252
49630	5	118636	2	45252
49631	5	118640	6	28833
49632	5	118641	6	13506
49633	5	118641	4	13506
49634	1	118646	6	32881
49635	4	118648	1	8849
49636	1	118651	4	45497
49637	4	118653	7	10359
49638	5	118654	1	33946
49639	4	118662	7	33501
49640	3	118663	5	25811
49641	5	118667	2	5016
49642	5	118668	5	22699
49643	4	118670	2	287
49644	4	118672	5	45377
49645	5	118673	7	1244
49646	5	118677	2	16465
49647	4	118679	2	1044
49648	5	118680	2	9466
49649	5	118681	1	45454
49650	1	118682	6	3374
49651	2	118682	4	3374
49652	4	118688	4	45371
49653	4	118690	3	17268
49654	3	118691	5	19093
49655	5	118693	1	9804
49656	3	118694	2	5180
49657	5	118698	6	45415
49658	5	118699	7	19428
49659	5	118700	2	20241
49660	5	118703	3	10008
49661	5	118706	6	17049
49662	3	118709	4	2968
49663	5	118710	6	45367
49664	4	118716	7	2293
49665	5	118717	3	41216
49666	5	118718	4	28928
49667	5	118719	4	18576
49668	5	118720	6	1890
49669	3	118722	1	592
49670	4	118727	3	41010
49671	5	118733	6	45268
49672	4	118735	7	17036
49673	4	118738	5	45325
49674	5	118740	7	35807
49675	4	118742	4	17594
49676	4	118745	5	39408
49677	4	118747	1	21
49678	3	118750	2	45408
49679	5	118755	3	8071
49680	5	118756	1	45421
49681	4	118758	2	35195
49682	4	118759	5	9312
49683	1	118764	1	45234
49684	5	118766	6	21210
49685	5	118768	3	18174
49686	3	118769	4	8564
49687	5	118770	4	26004
49688	3	118774	4	45336
49689	3	118777	2	22850
49690	3	118778	4	45309
49691	5	118788	3	45352
49692	5	118794	6	13980
49693	5	118795	1	13291
49694	3	118796	3	21345
49695	4	118800	4	36606
49696	1	118802	6	45477
49697	5	118804	2	37043
49698	3	118806	7	45256
49699	3	118809	3	9627
49700	4	118813	3	45339
49701	4	118814	3	12306
49702	5	118815	4	13029
49703	5	118817	4	12338
49704	3	118819	1	45455
49705	3	118820	4	42241
49706	4	118822	5	31997
49707	5	118825	5	19479
49708	3	118827	7	27660
49709	1	118830	4	5201
49710	4	118832	7	44984
49711	3	118834	7	16562
49712	5	118835	6	45370
49713	1	118836	6	10254
49714	5	118837	6	4205
49715	3	118838	5	21020
49716	5	118839	3	43353
49717	4	118840	2	31137
49718	4	118841	7	42117
49719	5	118842	2	26292
49720	5	118845	7	42919
49721	5	118846	3	10333
49722	2	118847	6	14433
49723	5	118848	4	7156
49724	5	118849	6	45326
49725	4	118849	3	45326
49726	4	118856	5	45390
49727	3	118866	4	1948
49728	4	118867	4	20380
49729	5	118870	5	24089
49730	3	118871	7	4831
49731	4	118874	4	11610
49732	5	118875	2	29329
49733	5	118876	6	24676
49734	5	118880	3	772
49735	4	118883	2	45272
49736	5	118885	4	10993
49737	5	118891	1	2959
49738	5	118892	5	16481
49739	4	118896	7	43407
49740	3	118897	7	26407
49741	4	118898	6	45418
49742	3	118901	2	14921
49743	5	118901	5	14921
49744	5	118902	1	45364
49745	5	118904	6	7670
49746	3	118905	7	7917
49747	5	118909	4	13918
49748	3	118914	6	31620
49749	5	118916	6	2809
49750	4	118916	4	2809
49751	5	118918	6	31346
49752	5	118921	3	19753
49753	2	118922	3	3247
49754	3	118927	2	19135
49755	5	118931	5	42292
49756	3	118932	7	39537
49757	4	118933	5	44731
49758	3	118934	7	31183
49759	5	118938	2	45496
49760	5	118940	5	17086
49761	5	118941	1	45221
49762	4	118947	4	735
49763	1	118949	6	993
49764	5	118950	6	36161
49765	4	118951	2	26783
49766	3	118953	5	41560
49767	3	118957	7	28819
49768	3	118965	7	7898
49769	3	118966	1	40443
49770	3	118971	5	29204
49771	5	118972	7	16720
49772	3	118974	7	45276
49773	3	118977	5	25313
49774	5	118979	1	45264
49775	5	118980	6	32767
49776	5	118981	4	40960
49777	5	118984	5	24922
49778	4	118986	2	37326
49779	4	118987	6	5644
49780	5	118988	4	21322
49781	4	118996	7	45247
49782	4	118996	5	45247
49783	4	118998	5	45348
49784	4	119003	5	44711
49785	3	119004	1	45481
49786	3	119004	5	45481
49787	4	119005	7	35438
49788	4	119008	2	6489
49789	4	119009	4	37941
49790	5	119012	4	22688
49791	4	119015	4	16626
49792	4	119019	5	6916
49793	3	119021	2	45397
49794	5	119025	4	45333
49795	3	119027	1	45320
49796	3	119028	4	754
49797	4	119029	3	45422
49798	4	119030	5	45323
49799	5	119038	6	14465
49800	3	119039	2	45420
49801	5	119040	5	45434
49802	4	119043	5	19760
49803	5	119046	3	45392
49804	2	119047	6	45303
49805	4	119054	7	45398
49806	5	119055	4	38860
49807	3	119055	7	38860
49808	3	119058	7	38055
49809	4	119059	7	817
49810	4	119067	5	4434
49811	5	119069	7	10404
49812	3	119073	5	4380
49813	4	119074	7	45425
49814	5	119075	5	16680
49815	2	119076	1	40727
49816	5	119077	2	29339
49817	5	119079	6	40265
49818	4	119081	2	6396
49819	4	119082	7	43798
49820	5	119090	7	45374
49821	5	119093	2	39421
49822	5	119094	4	5478
49823	5	119095	2	45360
49824	5	119098	5	43702
49825	5	119108	7	38219
49826	5	119110	7	36476
49827	4	119111	4	3456
49828	4	119113	4	45282
49829	5	119118	6	7673
49830	4	119122	7	29151
49831	5	119122	3	29151
49832	5	119123	2	45459
49833	4	119124	5	482
49834	4	119129	6	32723
49835	5	119130	7	21973
49836	5	119132	4	4737
49837	4	119133	7	17212
49838	1	119135	6	39557
49839	3	119139	7	31940
49840	5	119140	4	39861
49841	4	119143	7	701
49842	5	119147	2	45306
49843	4	119148	1	638
49844	5	119150	6	37673
49845	5	119151	6	8323
49846	5	119153	6	32099
49847	5	119159	1	45223
49848	5	119161	2	45432
49849	4	119162	2	4490
49850	5	119163	6	10618
49851	5	119164	5	20364
49852	3	119165	5	45229
49853	3	119168	7	45412
49854	4	119170	7	45493
49855	5	119172	6	38797
49856	5	119173	2	9061
49857	5	119178	7	45298
49858	5	119179	7	36547
49859	5	119182	2	19144
49860	5	119184	6	45332
49861	3	119187	5	28147
49862	3	119188	5	31133
49863	4	119190	5	45232
49864	5	119194	7	30281
49865	5	119200	5	24510
49866	4	119201	7	12546
49867	5	119203	7	13743
49868	3	119203	5	13743
49869	3	119204	7	40238
49870	4	119206	6	45393
49871	5	119208	6	27763
49872	3	119209	7	32475
49873	2	119210	6	20803
49874	3	119211	7	45328
49875	3	119212	2	7690
49876	5	119214	1	39778
49877	3	119216	7	43096
49878	4	119217	6	17644
49879	4	119220	2	23719
49880	5	119221	5	45225
49881	3	119229	2	45391
49882	1	119233	6	25505
49883	5	119235	2	8064
49884	5	119238	6	45290
49885	4	119242	7	39454
49886	5	119247	6	18179
49887	5	119251	4	44489
49888	1	119255	6	28781
49889	5	119256	1	45400
49890	4	119257	3	36245
49891	5	119260	3	33191
49892	5	119260	4	33191
49893	2	119261	4	34402
49894	4	119263	7	16902
49895	5	119266	5	34368
49896	5	119268	2	45498
49897	5	119271	4	10076
49898	5	119271	3	10076
49899	4	119277	7	24485
49900	5	119277	3	24485
49901	2	119278	6	45489
49902	4	119281	6	29576
49903	5	119283	2	45437
49904	5	119287	7	31586
49905	3	119289	7	33789
49906	5	119290	4	36478
49907	4	119291	7	45274
49908	4	119293	6	44534
49909	3	119294	5	15109
49910	5	119295	1	31160
49911	4	119296	7	6553
49912	5	119298	2	38664
49913	5	119301	2	41229
49914	4	119303	3	19443
49915	4	119303	7	19443
49916	5	119304	2	11686
49917	5	119305	2	37927
49918	5	119308	1	45299
49919	3	119309	5	38563
49920	4	119316	7	4275
49921	1	119317	2	1079
49922	3	119318	1	45463
49923	5	119323	2	37427
49924	3	119325	2	44717
49925	4	119327	5	30262
49926	5	119329	7	8586
49927	5	119330	6	40672
49928	5	119332	5	45321
49929	5	119333	6	30028
49930	5	119334	4	34458
49931	2	119336	3	7222
49932	4	119336	1	7222
49933	5	119339	6	708
49934	5	119340	2	45485
49935	5	119341	5	21368
49936	5	119342	4	26225
49937	5	119343	4	45345
49938	5	119344	7	45243
49939	5	119345	6	41154
49940	5	119346	4	45318
49941	4	119347	4	31853
49942	5	119350	2	28574
49943	4	119353	5	38523
49944	5	119354	7	33997
49945	3	119357	6	45492
49946	5	119359	6	28774
49947	1	119361	6	34512
49948	3	119366	5	45279
49949	5	119366	4	45279
49950	2	119369	3	17685
49951	5	119370	4	43094
49952	5	119371	7	16883
49953	3	119372	5	39982
49954	5	119376	2	36392
49955	5	119377	3	45448
49956	2	119378	5	38675
49957	5	119379	1	39484
49958	4	119380	6	1922
49959	3	119381	7	45228
49960	3	119385	7	34016
49961	5	119391	4	3155
49962	5	119394	3	17350
49963	3	119396	1	5571
49964	5	119397	5	45480
49965	3	119397	7	45480
49966	5	119398	4	29871
49967	3	119407	7	26624
49968	5	119409	6	15968
49969	4	119410	7	15671
49970	3	119413	7	39931
49971	5	119415	3	9107
49972	2	119416	7	3430
49973	5	119418	4	37834
49974	5	119421	2	2491
49975	2	119422	6	9313
49976	4	119423	7	32598
49977	4	119425	3	44012
49978	4	119427	7	2882
49979	3	119429	5	126
49980	4	119430	6	45439
49981	3	119432	2	45373
49982	5	119435	5	23159
49983	4	119435	3	23159
49984	3	119436	7	37873
49985	5	119437	3	41354
49986	4	119440	4	36277
49987	4	119440	5	36277
49988	3	119441	4	25430
49989	3	119443	5	24803
49990	5	119444	2	656
49991	5	119445	1	45307
49992	4	119446	7	43535
49993	3	119451	4	45424
49994	4	119452	5	4125
49995	5	119456	3	41889
49996	4	119462	5	23166
49997	4	119463	6	26994
49998	2	119464	4	27698
49999	4	119466	4	45446
50000	5	119467	2	9750
50001	5	119468	7	30709
50002	3	119469	1	33802
50003	5	119474	4	30683
50004	5	119475	4	11792
50005	3	119479	4	14972
50006	5	119481	6	27164
50007	5	119488	3	4479
50008	5	119489	2	45269
50009	3	119491	7	45494
50010	5	119494	6	45315
50011	4	119495	4	4459
50012	5	119498	7	45403
50013	4	119499	1	9021
50014	3	119500	3	44809
50015	5	119501	6	6243
50016	5	119503	6	45217
50017	5	119508	2	31641
50018	3	119511	4	30246
50019	4	119514	1	45389
50020	3	119515	5	16755
50021	5	119515	4	16755
50022	5	119516	6	23751
50023	5	119517	2	27783
50024	4	119518	3	45353
50025	3	119520	4	45335
50026	5	119526	1	45241
50027	5	119527	6	45116
50028	5	119536	6	45349
50029	4	119537	1	22319
50030	5	119539	6	45236
50031	5	119544	6	20438
50032	5	119552	6	1031
50033	3	119552	2	1031
50034	4	119555	1	33889
50035	4	119562	4	44522
50036	5	119565	2	45230
50037	4	119565	7	45230
50038	3	119567	5	4735
50039	4	119570	5	16557
50040	5	119572	1	45363
50041	4	119573	5	44853
50042	3	119575	5	30139
50043	5	119576	4	45281
50044	5	119577	4	45361
50045	4	119581	4	20018
50046	4	119582	5	7438
50047	5	119585	1	5004
50048	5	119588	4	3012
50049	5	119590	5	9846
50050	4	119591	4	25248
50051	3	119594	2	7498
50052	5	119595	6	45487
50053	3	119596	4	45394
50054	4	119603	2	24006
50055	5	119605	7	45460
50056	4	119606	7	33313
50057	3	119608	4	3863
50058	5	119609	6	45293
50059	3	119613	6	45624
50060	5	119614	4	38225
50061	5	119616	6	45728
50062	5	119619	2	23636
50063	5	119621	5	26377
50064	5	119622	2	22771
50065	1	119624	6	45504
50066	2	119625	1	24858
50067	3	119632	5	45735
50068	3	119633	4	13753
50069	1	119634	2	40754
50070	5	119635	5	9352
50071	5	119636	7	12774
50072	5	119637	5	37889
50073	4	119638	1	27577
50074	5	119641	2	45639
50075	5	119642	1	17304
50076	5	119643	6	32334
50077	5	119645	7	45715
50078	5	119646	2	13097
50079	4	119647	1	3783
50080	5	119653	6	45563
50081	4	119659	7	11150
50082	5	119661	6	25360
50083	4	119666	1	45646
50084	1	119667	6	45505
50085	5	119670	6	45514
50086	5	119670	4	45514
50087	5	119671	7	23576
50088	4	119671	2	23576
50089	5	119672	1	45599
50090	4	119676	4	5087
50091	3	119677	2	7835
50092	5	119679	5	14446
50093	4	119680	3	26622
50094	5	119681	2	38638
50095	5	119687	2	45640
50096	5	119688	4	1860
50097	5	119689	6	1262
50098	4	119690	6	45041
50099	5	119692	3	43520
50100	5	119694	7	16191
50101	3	119696	7	39026
50102	4	119697	1	20787
50103	5	119698	7	45672
50104	4	119701	7	45750
50105	3	119702	5	12652
50106	5	119703	6	45668
50107	5	119706	4	45513
50108	3	119708	5	29225
50109	3	119710	7	8311
50110	3	119713	7	26667
50111	4	119714	7	2098
50112	5	119715	7	45002
50113	5	119719	1	41691
50114	4	119725	4	15828
50115	3	119727	5	41926
50116	5	119728	2	32797
50117	4	119729	4	2526
50118	2	119730	5	26089
50119	4	119731	6	10344
50120	5	119731	1	10344
50121	5	119732	6	28712
50122	4	119733	5	45650
50123	5	119738	3	12772
50124	5	119745	7	27575
50125	5	119746	2	45586
50126	4	119747	7	45531
50127	5	119749	6	38909
50128	3	119751	3	45785
50129	4	119751	4	45785
50130	5	119753	6	45552
50131	5	119753	7	45552
50132	3	119756	7	45591
50133	5	119756	4	45591
50134	4	119759	5	45532
50135	5	119760	7	28401
50136	5	119761	5	7782
50137	4	119763	4	18203
50138	5	119764	7	32110
50139	5	119766	7	39596
50140	5	119768	1	33503
50141	5	119768	7	33503
50142	5	119770	4	45612
50143	5	119773	4	20460
50144	4	119774	1	45724
50145	5	119776	3	45510
50146	5	119782	2	42420
50147	4	119785	1	13508
50148	5	119787	7	45620
50149	4	119790	3	27674
50150	4	119792	5	10479
50151	4	119793	2	45556
50152	5	119794	7	23215
50153	5	119796	3	45615
50154	3	119797	2	45697
50155	5	119798	6	31601
50156	5	119800	6	25834
50157	4	119803	5	33101
50158	5	119804	6	16755
50159	5	119805	7	45601
50160	5	119806	2	1044
50161	5	119808	1	42277
50162	4	119811	5	33070
50163	3	119812	2	45501
50164	1	119818	6	28157
50165	5	119820	7	45706
50166	5	119822	6	45659
50167	5	119823	7	45637
50168	5	119824	7	45754
50169	4	119828	4	31371
50170	5	119830	6	31184
50171	5	119832	3	20209
50172	4	119833	7	2059
50173	5	119835	6	33946
50174	5	119837	2	39979
50175	5	119838	2	24274
50176	5	119839	4	37868
50177	5	119843	5	38394
50178	5	119847	2	19817
50179	3	119847	1	19817
50180	5	119849	1	35287
50181	1	119851	6	25537
50182	3	119854	2	39332
50183	5	119856	7	45655
50184	4	119857	7	20705
50185	4	119858	5	23379
50186	5	119859	1	38689
50187	4	119861	7	9934
50188	3	119862	7	1645
50189	5	119865	7	17142
50190	5	119867	6	45583
50191	3	119868	5	13332
50192	5	119871	3	14979
50193	4	119873	1	207
50194	5	119875	3	32926
50195	4	119876	5	45680
50196	5	119876	7	45680
50197	2	119882	4	39350
50198	3	119883	7	45664
50199	4	119884	7	26019
50200	5	119885	7	23267
50201	5	119887	2	45626
50202	5	119889	6	33203
50203	4	119891	1	25125
50204	5	119892	1	40633
50205	5	119894	4	45665
50206	5	119895	1	14306
50207	3	119895	2	14306
50208	5	119897	7	45521
50209	3	119898	3	12670
50210	5	119899	6	8292
50211	4	119900	3	45780
50212	3	119901	5	29361
50213	4	119902	3	41242
50214	4	119902	5	41242
50215	3	119903	2	22375
50216	5	119905	6	30882
50217	3	119907	2	28613
50218	5	119911	5	31405
50219	1	119913	6	24470
50220	5	119915	1	17268
50221	5	119917	4	45574
50222	5	119918	4	45527
50223	5	119920	6	45622
50224	4	119926	5	25410
50225	5	119931	6	23355
50226	5	119933	6	1344
50227	5	119941	1	11384
50228	5	119943	2	3444
50229	5	119947	6	28544
50230	5	119949	7	20800
50231	3	119949	1	20800
50232	5	119950	6	39579
50233	5	119954	2	45703
50234	4	119957	6	36290
50235	4	119959	1	36839
50236	4	119960	7	45760
50237	3	119962	2	45547
50238	4	119963	4	2571
50239	5	119966	1	32465
50240	5	119967	7	32968
50241	5	119974	7	32599
50242	5	119974	3	32599
50243	5	119980	2	10188
50244	3	119981	2	18494
50245	4	119987	2	3132
50246	4	119988	1	45790
50247	2	119988	6	45790
50248	5	119989	7	13371
50249	5	119990	7	29236
50250	4	119992	5	45598
50251	5	119994	5	39526
50252	5	120001	6	8946
50253	1	120002	6	45569
50254	4	120003	3	27804
50255	5	120012	2	16455
50256	5	120014	2	41506
50257	5	120016	5	18840
50258	4	120017	5	45641
50259	5	120018	6	45588
50260	4	120020	5	45770
50261	2	120023	6	27376
50262	5	120025	3	12225
50263	5	120026	1	4124
50264	5	120027	7	38739
50265	2	120029	6	38339
50266	5	120031	7	964
50267	4	120033	4	45683
50268	5	120036	2	1844
50269	4	120037	6	9273
50270	3	120040	2	45798
50271	5	120041	5	39493
50272	5	120048	6	10308
50273	5	120050	4	4031
50274	4	120053	7	29301
50275	5	120054	4	5420
50276	4	120055	2	39500
50277	3	120060	7	13729
50278	5	120064	2	931
50279	5	120068	1	45690
50280	3	120068	7	45690
50281	5	120079	2	45667
50282	4	120081	7	29477
50283	5	120085	2	22332
50284	4	120086	7	14896
50285	5	120091	7	1306
50286	5	120092	2	45506
50287	2	120093	6	45648
50288	5	120097	2	43211
50289	5	120099	2	33388
50290	4	120100	7	44158
50291	5	120104	3	45736
50292	4	120105	1	45734
50293	3	120107	7	38466
50294	4	120115	5	27199
50295	5	120116	4	45613
50296	5	120119	2	8489
50297	5	120121	2	44867
50298	5	120128	5	15594
50299	5	120129	1	45669
50300	5	120132	4	1985
50301	3	120138	2	45884
50302	4	120142	6	45838
50303	4	120143	1	13497
50304	5	120148	6	34257
50305	5	120151	2	46018
50306	5	120151	6	46018
50307	1	120152	6	17862
50308	3	120159	7	24718
50309	4	120162	5	11300
50310	4	120164	7	45859
50311	5	120166	6	13326
50312	3	120167	5	8098
50313	1	120170	2	2526
50314	3	120171	2	29757
50315	5	120176	6	45854
50316	4	120179	2	46037
50317	2	120180	3	13855
50318	3	120182	3	34266
50319	5	120184	2	45897
50320	2	120185	3	45976
50321	4	120187	7	13951
50322	3	120189	4	8676
50323	3	120195	5	46011
50324	5	120196	5	45873
50325	5	120197	2	45978
50326	3	120200	2	29847
50327	5	120204	2	45899
50328	5	120205	6	31206
50329	4	120207	7	39280
50330	3	120208	1	9175
50331	5	120210	5	44549
50332	5	120211	6	45856
50333	5	120211	1	45856
50334	4	120212	5	18729
50335	3	120213	4	2130
50336	5	120214	6	45938
50337	5	120215	6	45862
50338	4	120217	7	45949
50339	5	120221	6	45866
50340	4	120223	3	7063
50341	5	120224	4	13460
50342	4	120227	2	8390
50343	5	120227	7	8390
50344	3	120229	5	30259
50345	5	120232	4	14356
50346	4	120237	7	24733
50347	4	120237	1	24733
50348	4	120238	3	39925
50349	4	120239	7	46024
50350	5	120241	4	16044
50351	1	120243	6	42640
50352	3	120244	4	45917
50353	4	120246	7	41832
50354	5	120247	6	45918
50355	4	120252	7	3546
50356	5	120254	7	36569
50357	5	120256	2	45987
50358	5	120258	4	17337
50359	4	120260	1	46021
50360	5	120265	1	46017
50361	5	120267	6	40831
50362	4	120268	4	45839
50363	5	120269	1	18852
50364	5	120271	4	38138
50365	5	120274	6	45993
50366	4	120275	2	26739
50367	4	120277	5	33899
50368	5	120279	6	45869
50369	4	120280	7	44223
50370	5	120281	4	15101
50371	5	120284	6	21430
50372	4	120287	5	15313
50373	3	120287	1	15313
50374	5	120288	2	7604
50375	5	120289	7	25274
50376	3	120292	5	45941
50377	3	120295	3	45891
50378	3	120296	4	25190
50379	4	120297	3	33037
50380	4	120299	5	32403
50381	5	120300	1	45965
50382	5	120300	4	45965
50383	5	120302	6	45977
50384	5	120305	7	8240
50385	4	120309	6	19511
50386	4	120309	1	19511
50387	5	120310	7	14539
50388	5	120312	2	45163
50389	3	120314	1	33476
50390	5	120318	7	45940
50391	5	120319	5	45912
50392	4	120321	6	31441
50393	5	120323	6	13422
50394	5	120327	3	568
50395	5	120327	6	568
50396	5	120328	7	24618
50397	4	120329	5	9236
50398	4	120333	1	45807
50399	5	120333	2	45807
50400	5	120335	6	45973
50401	5	120336	1	37505
50402	4	120337	6	22893
50403	5	120340	6	36200
50404	5	120340	2	36200
50405	5	120342	3	33148
50406	5	120344	1	27937
50407	5	120345	6	14556
50408	5	120347	7	27046
50409	5	120349	7	18402
50410	5	120349	4	18402
50411	4	120350	6	45964
50412	5	120351	1	43829
50413	4	120351	7	43829
50414	5	120357	2	15434
50415	5	120358	4	45998
50416	5	120361	2	21031
50417	5	120365	6	39464
50418	5	120367	2	22516
50419	4	120369	4	6602
50420	5	120374	6	46019
50421	5	120374	2	46019
50422	4	120376	7	37015
50423	4	120376	4	37015
50424	5	120377	6	10205
50425	4	120378	7	23551
50426	3	120380	5	45910
50427	3	120381	3	45966
50428	5	120384	7	6015
50429	4	120388	7	35239
50430	5	120389	5	45920
50431	5	120389	7	45920
50432	5	120390	7	25499
50433	5	120392	4	5272
50434	3	120394	6	8234
50435	5	120399	6	45882
50436	4	120400	7	12089
50437	5	120401	3	46008
50438	5	120402	7	42315
50439	1	120403	4	20198
50440	4	120405	7	37381
50441	5	120409	6	5227
50442	5	120413	2	29570
50443	5	120414	2	44208
50444	4	120415	6	11288
50445	5	120418	6	45930
50446	3	120420	5	41660
50447	5	120423	3	466
50448	4	120425	2	34535
50449	5	120426	6	37071
50450	2	120433	7	45928
50451	5	120435	4	8966
50452	3	120436	5	20542
50453	5	120441	7	37366
50454	5	120442	2	45836
50455	5	120443	6	46016
50456	5	120445	7	45885
50457	5	120446	1	25827
50458	5	120448	3	3835
50459	5	120449	6	45970
50460	4	120450	4	154
50461	5	120452	3	12003
50462	5	120457	3	19729
50463	5	120458	6	46029
50464	4	120460	5	1809
50465	4	120462	5	45914
50466	5	120471	1	12912
50467	1	120472	6	45957
50468	5	120473	7	1582
50469	4	120478	6	24778
50470	5	120481	6	33303
50471	5	120483	2	35763
50472	3	120483	5	35763
50473	3	120484	4	45948
50474	5	120485	6	45967
50475	4	120487	1	12275
50476	5	120491	6	46032
50477	3	120492	7	42702
50478	5	120493	6	44425
50479	5	120496	1	45860
50480	5	120500	4	45904
50481	4	120502	7	45935
50482	4	120503	6	40640
50483	5	120505	1	8981
50484	4	120508	7	13251
50485	4	120509	3	2995
50486	3	120511	4	45936
50487	3	120513	5	12808
50488	3	120514	7	29504
50489	5	120516	3	33472
50490	5	120517	7	25910
50491	5	120520	1	43248
50492	5	120524	3	45979
50493	3	120528	5	13881
50494	5	120531	4	28087
50495	5	120534	5	7969
50496	5	120539	2	44684
50497	5	120540	2	6983
50498	5	120541	4	25010
50499	5	120544	3	3760
50500	5	120546	4	19583
50501	5	120552	4	12841
50502	3	120553	5	12814
50503	5	120554	4	44688
50504	4	120555	6	12954
50505	3	120557	3	44853
50506	4	120559	5	32128
50507	5	120561	6	45922
50508	3	120565	5	35660
50509	4	120567	7	46038
50510	5	120568	4	34820
50511	2	120569	2	18942
50512	5	120569	4	18942
50513	5	120570	4	18979
50514	3	120573	5	13555
50515	5	120574	2	13088
50516	5	120575	6	14001
50517	4	120579	4	28431
50518	5	120580	5	41810
50519	5	120585	6	45950
50520	4	120587	6	46012
50521	4	120590	2	43587
50522	3	120591	3	36449
50523	5	120593	1	31364
50524	5	120596	1	10019
50525	5	120598	7	45817
50526	3	120599	5	14516
50527	3	120601	1	38296
50528	3	120602	3	92
50529	5	120603	7	18936
50530	3	120604	5	12239
50531	1	120607	5	37839
50532	4	120610	3	12355
50533	5	120613	2	30693
50534	5	120615	2	7854
50535	3	120617	3	5064
50536	3	120618	1	32450
50537	3	120620	5	68
50538	4	120628	7	29979
50539	3	120628	1	29979
50540	3	120631	1	1101
50541	5	120633	4	45847
50542	5	120634	7	39537
50543	4	120635	7	11150
50544	4	120635	5	11150
50545	5	120637	7	46004
50546	3	120641	2	35541
50547	5	120644	6	38731
50548	4	120645	4	24698
50549	5	120646	2	4166
50550	4	120650	2	19056
50551	5	120653	7	45926
50552	5	120655	6	45801
50553	3	120658	7	45810
50554	5	120659	6	11093
50555	2	120660	2	45881
50556	4	120661	6	7284
50557	4	120667	1	17788
50558	5	120670	4	10915
50559	5	120671	6	8880
50560	5	120674	4	45895
50561	5	120674	3	45895
50562	3	120675	7	45984
50563	4	120676	1	45992
50564	4	120682	3	39793
50565	5	120684	2	2082
50566	5	120685	2	9747
50567	5	120687	3	37169
50568	5	120689	2	21702
50569	2	120690	2	38952
50570	5	120691	6	27575
50571	5	120693	5	45830
50572	5	120694	6	3507
50573	4	120695	3	5154
50574	5	120697	7	20091
50575	5	120698	1	13148
50576	4	120700	5	45968
50577	4	120701	7	20402
50578	2	120702	4	19691
50579	5	120715	7	35529
50580	3	120717	2	20636
50581	5	120719	2	4731
50582	5	120721	6	20911
50583	5	120723	6	46054
50584	5	120723	3	46054
50585	5	120725	4	34787
50586	5	120727	6	12675
50587	5	120728	7	17580
50588	3	120729	3	35766
50589	5	120730	4	46227
50590	5	120731	1	17855
50591	4	120733	1	41548
50592	3	120734	4	46095
50593	1	120736	6	35472
50594	4	120745	5	39723
50595	5	120746	2	22242
50596	5	120748	6	9319
50597	5	120749	3	2788
50598	5	120750	5	46096
50599	5	120755	6	13308
50600	4	120758	1	13765
50601	5	120761	5	46187
50602	4	120763	6	20803
50603	3	120764	7	43961
50604	5	120770	6	4822
50605	5	120770	1	4822
50606	5	120772	1	46058
50607	4	120772	2	46058
50608	4	120773	3	46170
50609	5	120774	7	23863
50610	3	120775	5	18192
50611	3	120777	4	28002
50612	1	120778	4	28132
50613	5	120780	2	45647
50614	5	120783	6	36380
50615	3	120785	5	24579
50616	2	120786	4	12671
50617	4	120788	2	5650
50618	2	120792	6	46281
50619	2	120796	6	27989
50620	5	120800	5	33945
50621	5	120801	2	19986
50622	4	120803	3	27208
50623	4	120806	3	21417
50624	5	120809	3	1115
50625	4	120812	4	37991
50626	5	120813	1	46085
50627	3	120814	3	16456
50628	5	120815	7	32571
50629	5	120817	6	45863
50630	5	120826	2	11534
50631	3	120827	4	46114
50632	3	120828	5	46146
50633	5	120829	6	46047
50634	4	120836	2	41093
50635	5	120838	4	6213
50636	4	120843	4	46072
50637	4	120844	6	34456
50638	5	120844	4	34456
50639	5	120846	6	3909
50640	3	120847	5	39710
50641	5	120848	7	6276
50642	4	120852	1	36624
50643	5	120856	2	41324
50644	5	120860	3	29795
50645	5	120864	2	46186
50646	1	120868	2	634
50647	5	120869	4	8663
50648	5	120870	6	46282
50649	5	120873	6	46136
50650	5	120879	4	46242
50651	5	120881	4	46140
50652	3	120885	3	38768
50653	3	120887	1	46208
50654	1	120891	6	17427
50655	5	120894	2	16139
50656	5	120895	5	25847
50657	5	120897	2	26275
50658	3	120903	3	36472
50659	5	120904	7	34463
50660	5	120906	1	11864
50661	5	120908	4	46147
50662	5	120910	6	46130
50663	5	120911	7	3864
50664	5	120913	1	46218
50665	5	120914	2	12578
50666	4	120915	6	46270
50667	5	120916	2	4425
50668	3	120930	7	8569
50669	5	120933	2	46149
50670	5	120935	4	46107
50671	5	120940	5	40410
50672	4	120942	7	46042
50673	3	120944	6	16344
50674	5	120948	5	36970
50675	4	120949	3	46078
50676	5	120950	1	12123
50677	5	120951	3	46221
50678	5	120952	4	40794
50679	5	120953	6	41851
50680	4	120955	2	35693
50681	5	120960	3	28851
50682	4	120965	1	46117
50683	5	120967	4	30933
50684	5	120968	6	46041
50685	4	120969	7	1656
50686	5	120970	2	3926
50687	5	120971	2	26721
50688	5	120972	1	1477
50689	5	120973	4	46277
50690	3	120974	5	46193
50691	5	120976	7	26407
50692	5	120978	5	46293
50693	2	120982	4	37098
50694	5	120983	6	11582
50695	4	120984	2	46135
50696	5	120988	6	38417
50697	5	120989	2	26596
50698	5	120990	6	38962
50699	5	120991	1	46229
50700	4	120996	7	29639
50701	5	120998	2	46171
50702	3	120999	1	36992
50703	1	121001	3	13955
50704	5	121002	6	46155
50705	4	121005	7	46091
50706	5	121007	7	3224
50707	5	121016	1	15965
50708	5	121017	6	16181
50709	4	121020	7	37622
50710	5	121021	5	27896
50711	3	121023	2	27020
50712	4	121026	3	46202
50713	3	121030	1	34009
50714	4	121033	5	25598
50715	4	121038	7	171
50716	4	121040	6	46162
50717	4	121045	3	35010
50718	1	121047	1	46076
50719	5	121051	2	23583
50720	4	121056	4	20852
50721	3	121057	5	46141
50722	5	121059	3	46210
50723	4	121061	4	46240
50724	4	121062	7	46189
50725	5	121064	4	10101
50726	5	121065	2	46157
50727	5	121069	7	46284
50728	5	121071	6	39272
50729	4	121074	6	45734
50730	4	121075	5	22124
50731	5	121077	4	46260
50732	5	121081	2	46252
50733	5	121082	2	11873
50734	4	121090	5	13752
50735	5	121091	6	46244
50736	5	121096	2	37456
50737	5	121097	4	33560
50738	3	121098	7	46043
50739	1	121100	4	46087
50740	5	121104	6	46080
50741	3	121109	7	2094
50742	5	121117	1	388
50743	4	121118	1	46127
50744	5	121119	4	20792
50745	5	121120	7	46245
50746	4	121122	2	26411
50747	5	121123	6	17003
50748	3	121125	5	46102
50749	3	121129	2	30841
50750	4	121131	3	25550
50751	4	121132	7	6097
50752	3	121133	5	46182
50753	5	121137	4	27620
50754	3	121139	7	46083
50755	5	121140	3	13188
50756	4	121143	3	17920
50757	5	121145	1	37577
50758	5	121145	6	37577
50759	2	121149	6	46175
50760	5	121152	7	29797
50761	5	121159	4	14025
50762	5	121160	4	40115
50763	3	121161	3	30154
50764	1	121161	6	30154
50765	5	121166	1	46217
50766	4	121167	7	21515
50767	5	121169	2	45998
50768	5	121171	4	46126
50769	5	121172	2	38815
50770	5	121173	6	39044
50771	5	121173	5	39044
50772	5	121176	4	6990
50773	2	121177	3	31822
50774	4	121178	7	46181
50775	4	121178	1	46181
50776	3	121184	7	33282
50777	3	121188	5	46198
50778	5	121189	2	39103
50779	5	121190	4	691
50780	3	121194	2	544
50781	5	121195	2	46150
50782	1	121195	4	46150
50783	5	121196	7	4411
50784	3	121200	4	43826
50785	5	121202	4	40862
50786	4	121204	5	45324
50787	4	121207	3	32067
50788	5	121208	5	12606
50789	3	121209	5	16004
50790	3	121212	7	27231
50791	4	121218	3	24355
50792	5	121219	3	25441
50793	4	121222	7	25157
50794	5	121223	5	46203
50795	5	121227	5	37437
50796	5	121227	6	37437
50797	5	121231	4	10723
50798	3	121236	7	482
50799	5	121238	1	12612
50800	5	121239	1	28959
50801	5	121240	2	46119
50802	5	121242	2	12145
50803	5	121246	4	46108
50804	5	121249	4	46053
50805	5	121252	4	9847
50806	4	121254	5	16718
50807	5	121255	4	27950
50808	3	121256	7	20742
50809	3	121260	5	45014
50810	4	121261	3	32344
50811	5	121264	6	46154
50812	5	121267	2	25580
50813	5	121268	5	20811
50814	5	121268	2	20811
50815	3	121270	4	46098
50816	5	121271	1	46167
50817	3	121272	5	46110
50818	5	121273	2	41906
50819	5	121277	2	46156
50820	4	121280	3	46161
50821	3	121284	5	46273
50822	5	121290	3	5421
50823	5	121292	3	46230
50824	4	121294	3	46268
50825	5	121298	2	46046
50826	5	121300	4	27694
50827	4	121302	3	46070
50828	5	121316	3	36207
50829	5	121327	6	3604
50830	5	121328	6	46166
50831	4	121331	6	46239
50832	4	121332	4	16137
50833	5	121338	3	25180
50834	2	121339	1	46191
50835	4	121341	5	36541
50836	5	121342	7	13466
50837	3	121343	5	32283
50838	5	121344	5	45873
50839	5	121345	1	46291
50840	4	121348	5	46220
50841	2	121351	6	274
50842	5	121354	5	12196
50843	4	121355	7	5570
50844	5	121356	5	16031
50845	5	121356	4	16031
50846	5	121357	7	11150
50847	3	121359	5	6959
50848	5	121364	1	38169
50849	4	121365	7	36451
50850	5	121365	1	36451
50851	5	121367	2	3324
50852	5	121370	6	46144
50853	5	121371	7	26867
50854	4	121372	1	43252
50855	5	121373	3	14105
50856	5	121374	1	44743
50857	5	121377	5	9517
50858	4	121378	6	46056
50859	3	121379	3	31880
50860	5	121379	2	31880
50861	5	121382	1	10518
50862	5	121384	7	46231
50863	5	121385	7	46082
50864	5	121386	2	40358
50865	5	121390	1	3820
50866	5	121392	7	19628
50867	5	121398	7	29222
50868	5	121399	3	32750
50869	3	121401	7	44739
50870	5	121404	2	44640
50871	3	121404	6	44640
50872	3	121406	6	21536
50873	5	121407	3	46142
50874	5	121408	2	18659
50875	1	121410	6	44146
50876	5	121411	5	41460
50877	4	121414	6	42101
50878	4	121418	4	38942
50879	5	121423	2	32808
50880	4	121424	7	9023
50881	5	121426	5	46090
50882	5	121426	7	46090
50883	5	121428	7	32263
50884	5	121429	3	12835
50885	5	121430	4	2552
50886	3	121432	7	33980
50887	5	121434	5	46236
50888	5	121435	2	46120
50889	4	121440	1	10276
50890	5	121442	7	37209
50891	4	121443	4	46153
50892	3	121445	3	40867
50893	1	121447	6	32316
50894	4	121448	2	8560
50895	5	121450	7	40731
50896	4	121452	1	46192
50897	5	121459	7	14881
50898	5	121466	3	25097
50899	1	121469	4	34098
50900	5	121473	4	19282
50901	5	121473	6	19282
50902	5	121474	5	46180
50903	5	121475	3	8622
50904	5	121476	6	24883
50905	5	121476	5	24883
50906	4	121478	5	34026
50907	3	121483	2	33514
50908	4	121483	7	33514
50909	5	121486	3	32295
50910	4	121489	6	46531
50911	5	121492	6	46404
50912	5	121493	6	46498
50913	5	121494	4	46386
50914	4	121495	7	27840
50915	5	121496	7	46457
50916	5	121500	7	46528
50917	5	121506	2	41400
50918	5	121506	5	41400
50919	4	121507	3	44489
50920	5	121509	3	13939
50921	4	121512	3	15042
50922	3	121515	7	28070
50923	5	121517	7	46373
50924	3	121520	4	27519
50925	5	121527	4	12952
50926	5	121528	6	46433
50927	5	121529	7	46524
50928	5	121531	4	44236
50929	3	121532	7	46324
50930	5	121536	6	46536
50931	4	121537	7	37791
50932	5	121540	3	43698
50933	4	121545	2	32810
50934	5	121549	7	46427
50935	5	121551	2	11555
50936	4	121555	1	46430
50937	3	121556	6	46468
50938	5	121557	1	24547
50939	2	121560	3	46438
50940	5	121560	7	46438
50941	3	121561	5	18512
50942	5	121562	5	38810
50943	5	121566	4	17342
50944	5	121568	6	33680
50945	5	121577	7	46441
50946	5	121579	6	17669
50947	3	121579	3	17669
50948	4	121582	7	19616
50949	3	121584	7	46455
50950	4	121584	2	46455
50951	5	121586	4	46405
50952	4	121587	3	45385
50953	4	121588	7	46499
50954	3	121589	3	1048
50955	4	121595	7	40881
50956	4	121596	7	9370
50957	5	121597	1	45711
50958	5	121598	6	16822
50959	5	121601	5	46320
50960	5	121602	7	16152
50961	5	121603	7	42289
50962	1	121606	5	32784
50963	5	121608	7	46501
50964	5	121611	6	31571
50965	5	121615	6	46338
50966	5	121616	6	46217
50967	5	121618	6	4277
50968	5	121619	6	46343
50969	5	121620	1	29874
50970	5	121623	3	1468
50971	1	121624	2	46464
50972	5	121626	2	34812
50973	5	121627	2	18170
50974	3	121628	4	12476
50975	5	121629	2	46491
50976	5	121632	3	16967
50977	5	121634	2	45267
50978	5	121634	6	45267
50979	5	121635	6	11081
50980	5	121636	2	1880
50981	5	121637	2	37331
50982	5	121639	4	4164
50983	3	121648	2	46318
50984	5	121651	2	6221
50985	5	121655	6	20308
50986	4	121661	2	26349
50987	5	121664	1	378
50988	5	121667	1	30777
50989	4	121674	5	46353
50990	4	121677	4	46406
50991	1	121678	7	31536
50992	5	121684	6	33610
50993	3	121686	4	46463
50994	4	121686	1	46463
50995	1	121690	6	24792
50996	3	121695	5	38736
50997	4	121697	5	23264
50998	5	121697	4	23264
50999	2	121707	1	9836
51000	4	121708	1	29067
51001	5	121709	1	46439
51002	3	121713	5	7557
51003	4	121716	4	15236
51004	5	121716	2	15236
51005	5	121719	6	15544
51006	5	121723	6	10006
51007	4	121726	7	3618
51008	5	121727	2	35456
51009	5	121728	1	39322
51010	5	121731	5	23017
51011	5	121732	2	19434
51012	5	121737	5	46372
51013	3	121738	4	46549
51014	2	121741	7	34052
51015	5	121742	6	46494
51016	4	121743	7	46402
51017	5	121745	7	31318
51018	4	121746	3	46377
51019	5	121751	7	13948
51020	5	121756	4	39981
51021	5	121757	7	46507
51022	5	121759	6	46534
51023	5	121760	6	46384
51024	3	121761	2	37278
51025	3	121767	6	4295
51026	5	121773	6	9404
51027	3	121774	5	46541
51028	5	121776	2	46369
51029	5	121778	4	46520
51030	5	121788	7	28831
51031	4	121791	2	39492
51032	4	121794	7	15437
51033	5	121796	7	5497
51034	5	121797	7	38759
51035	5	121798	3	22529
51036	5	121799	2	40945
51037	4	121800	5	28315
51038	5	121805	7	25470
51039	3	121806	6	25473
51040	3	121807	4	18870
51041	5	121808	5	46416
51042	5	121811	6	22201
51043	4	121812	7	45308
51044	5	121813	4	20912
51045	5	121814	6	31183
51046	1	121816	1	28629
51047	3	121821	4	22445
51048	5	121822	5	46302
51049	5	121825	4	837
51050	2	121827	3	16344
51051	5	121828	2	46347
51052	3	121830	5	27736
51053	5	121831	3	46504
51054	5	121832	6	25320
51055	5	121833	3	19321
51056	3	121834	5	22942
51057	4	121837	2	46316
51058	5	121840	4	46307
51059	3	121841	3	15214
51060	3	121846	5	3300
51061	5	121847	3	33805
51062	4	121850	4	41607
51063	5	121853	1	37149
51064	5	121861	4	46459
51065	4	121862	6	28091
51066	5	121867	2	389
51067	3	121868	1	9993
51068	5	121871	3	46306
51069	2	121873	4	46517
51070	4	121876	5	46429
51071	5	121877	2	36549
51072	4	121877	6	36549
51073	5	121880	6	1630
51074	5	121882	4	9933
51075	5	121883	6	46544
51076	5	121886	6	46551
51077	2	121889	1	46303
51078	5	121890	4	46400
51079	3	121890	5	46400
51080	3	121892	4	25991
51081	5	121895	6	28813
51082	4	121896	5	39598
51083	5	121900	4	46521
51084	5	121901	6	46548
51085	1	121903	1	46346
51086	5	121912	7	26392
51087	4	121915	4	40377
51088	3	121918	5	46401
51089	4	121920	7	25458
51090	5	121926	6	46398
51091	2	121927	6	4363
51092	5	121928	2	46407
51093	5	121931	6	22351
51094	5	121936	4	46435
51095	5	121938	2	46383
51096	5	121939	4	5399
51097	3	121942	7	10707
51098	5	121943	2	22259
51099	3	121944	7	11393
51100	5	121949	6	36536
51101	5	121952	3	24021
51102	4	121953	2	46443
51103	3	121954	7	39578
51104	2	121955	1	46335
51105	4	121956	3	21614
51106	5	121961	1	46465
51107	3	121961	5	46465
51108	4	121968	6	46444
51109	3	121969	5	6326
51110	5	121971	4	1536
51111	5	121972	1	29358
51112	3	121972	5	29358
51113	4	121978	5	26387
51114	5	121981	2	46294
51115	3	121988	1	46518
51116	3	121988	7	46518
51117	3	121989	7	6695
51118	4	121990	2	43113
51119	4	121991	7	16181
51120	5	121991	2	16181
51121	4	121994	5	18312
51122	3	121995	5	15406
51123	4	122001	5	22260
51124	4	122002	3	46389
51125	3	122004	5	46490
51126	5	122007	7	44321
51127	5	122008	5	46364
51128	5	122012	3	46308
51129	4	122014	7	24789
51130	4	122015	1	42703
51131	5	122016	7	41923
51132	5	122016	6	41923
51133	5	122017	2	23805
51134	5	122019	2	4970
51135	2	122020	4	46341
51136	3	122022	5	9543
51137	5	122028	7	20512
51138	5	122040	4	44490
51139	4	122041	3	46327
51140	5	122042	6	7822
51141	5	122044	4	46312
51142	5	122044	6	46312
51143	4	122045	2	721
51144	5	122049	4	32598
51145	3	122050	3	19668
51146	3	122053	3	43288
51147	4	122061	5	46297
51148	5	122062	5	46456
51149	5	122067	6	36887
51150	5	122068	1	46314
51151	4	122069	4	32557
51152	4	122070	5	46484
51153	5	122072	1	46390
51154	4	122074	5	37163
51155	5	122076	6	27541
51156	3	122079	1	46376
51157	4	122087	2	1296
51158	5	122089	4	45099
51159	4	122090	5	46475
51160	5	122091	7	1963
51161	4	122093	5	46330
51162	4	122095	1	42381
51163	4	122095	3	42381
51164	5	122098	5	29127
51165	5	122101	4	37399
51166	5	122102	4	883
51167	5	122104	4	46409
51168	5	122108	1	5962
51169	5	122112	5	32680
51170	4	122116	3	46423
51171	4	122117	6	46412
51172	5	122124	4	14491
51173	5	122128	1	32468
51174	5	122129	6	21467
51175	4	122133	4	17456
51176	5	122138	1	7143
51177	5	122141	3	37004
51178	1	122142	6	46450
51179	5	122144	1	44508
51180	3	122144	4	44508
51181	5	122145	4	45007
51182	1	122145	6	45007
51183	5	122148	1	29429
51184	5	122152	5	12867
51185	4	122153	7	11681
51186	4	122159	1	46360
51187	4	122160	7	121
51188	5	122160	1	121
51189	3	122162	2	30910
51190	5	122163	5	7814
51191	5	122165	7	19811
51192	5	122176	7	31822
51193	5	122178	6	2527
51194	3	122180	6	22643
51195	5	122184	6	44051
51196	5	122192	6	46351
51197	5	122196	5	46315
51198	2	122197	7	18940
51199	5	122198	4	5473
51200	1	122200	4	46460
51201	5	122200	6	46460
51202	5	122202	6	11038
51203	5	122203	3	39657
51204	5	122209	7	46305
51205	1	122213	6	39813
51206	3	122214	2	43571
51207	4	122216	5	46431
51208	3	122218	5	46469
51209	4	122220	7	24989
51210	5	122224	4	2935
51211	5	122226	4	46458
51212	5	122230	7	13602
51213	5	122234	2	9406
51214	1	122237	6	8560
51215	5	122239	3	18275
51216	5	122242	5	7098
51217	5	122244	2	46500
51218	3	122249	5	46479
51219	5	122250	2	365
51220	5	122252	7	5383
51221	5	122253	6	22704
51222	5	122254	2	16231
51223	4	122255	2	46523
51224	4	122258	6	32759
51225	4	122259	7	44740
51226	4	122260	7	46432
51227	5	122261	6	36516
51228	4	122262	7	8796
51229	4	122263	7	17063
51230	5	122265	3	6642
51231	5	122267	4	21606
51232	2	122269	6	14110
51233	4	122271	4	12315
51234	5	122271	7	12315
51235	5	122273	3	44870
51236	5	122274	6	22443
51237	5	122275	3	41765
51238	5	122277	2	17789
51239	4	122278	5	46558
51240	5	122282	4	46716
51241	5	122283	5	43796
51242	4	122283	7	43796
51243	3	122287	7	4794
51244	5	122288	5	12100
51245	5	122292	7	46579
51246	5	122295	6	24590
51247	5	122301	7	46571
51248	5	122302	6	37514
51249	5	122303	4	1306
51250	5	122308	4	29852
51251	4	122309	2	36899
51252	4	122309	4	36899
51253	4	122310	4	46660
51254	1	122311	6	14824
51255	3	122313	5	46622
51256	4	122313	7	46622
51257	4	122314	7	46578
51258	5	122318	5	17508
51259	3	122321	4	38585
51260	5	122324	7	45442
51261	5	122325	1	46688
51262	4	122326	7	12623
51263	3	122329	7	22342
51264	4	122333	5	2538
51265	3	122334	1	19341
51266	5	122335	4	37579
51267	5	122338	4	10802
51268	5	122341	7	28772
51269	4	122342	1	21339
51270	5	122344	2	32665
51271	4	122345	5	12331
51272	5	122347	1	18451
51273	4	122350	7	46725
51274	5	122353	6	46733
51275	5	122356	7	19432
51276	4	122357	4	802
51277	5	122358	7	24380
51278	5	122359	1	46667
51279	5	122363	3	4370
51280	5	122366	6	46661
51281	5	122368	6	46665
51282	4	122369	1	25571
51283	3	122375	5	39546
51284	5	122376	7	28857
51285	4	122379	4	9377
51286	5	122382	2	46687
51287	3	122387	7	25332
51288	5	122390	1	31398
51289	5	122392	7	46751
51290	4	122395	4	46710
51291	5	122397	1	7750
51292	4	122398	1	46668
51293	5	122403	1	46603
51294	4	122405	7	46629
51295	5	122407	2	46782
51296	5	122408	6	41746
51297	4	122412	1	46664
51298	4	122413	6	7749
51299	5	122414	4	27775
51300	4	122416	7	46781
51301	5	122419	2	42121
51302	5	122421	5	46650
51303	5	122422	2	19913
51304	3	122424	7	8217
51305	3	122428	4	46707
51306	4	122435	3	46799
51307	5	122437	6	4430
51308	3	122439	6	29600
51309	3	122441	3	46624
51310	5	122446	6	1900
51311	5	122448	4	15216
51312	3	122453	1	16248
51313	4	122455	6	24975
51314	5	122458	6	6480
51315	3	122459	2	46600
51316	5	122460	2	26096
51317	5	122461	7	43705
51318	3	122464	1	46654
51319	5	122468	7	33501
51320	5	122470	4	41952
51321	2	122472	3	3997
51322	5	122479	5	46682
51323	5	122482	4	46738
51324	4	122484	6	43915
51325	5	122490	7	5430
51326	5	122491	7	26386
51327	3	122494	7	30019
51328	5	122499	1	20907
51329	1	122502	4	46700
51330	4	122504	4	8382
51331	3	122509	1	46755
51332	5	122513	5	32068
51333	4	122515	3	46750
51334	5	122523	1	46694
51335	3	122524	7	27283
51336	4	122525	3	46623
51337	4	122526	6	15728
51338	3	122530	5	36958
51339	5	122532	5	43818
51340	5	122533	6	34295
51341	3	122534	2	28441
51342	1	122535	6	45041
51343	5	122538	6	45876
51344	5	122543	2	46737
51345	5	122545	6	24359
51346	3	122546	5	32674
51347	5	122548	6	31548
51348	3	122549	7	4287
51349	5	122552	2	30855
51350	3	122554	7	10015
51351	5	122555	2	46615
51352	3	122560	6	31454
51353	5	122563	7	40924
51354	5	122567	7	13303
51355	5	122570	2	37071
51356	5	122573	1	10589
51357	5	122574	4	30760
51358	5	122576	1	46663
51359	4	122580	7	46708
51360	3	122581	5	46610
51361	5	122586	7	40436
51362	5	122587	5	1762
51363	5	122594	2	800
51364	5	122596	3	46389
51365	5	122597	5	5358
51366	3	122598	4	21553
51367	3	122601	7	9816
51368	5	122603	1	5308
51369	4	122605	5	46778
51370	5	122606	6	45283
51371	5	122613	3	44574
51372	5	122614	6	46570
51373	4	122615	5	46605
51374	5	122616	1	46640
51375	4	122618	6	35700
51376	5	122619	4	33520
51377	5	122620	2	20720
51378	5	122621	4	16321
51379	5	122622	2	39790
51380	3	122627	1	6038
51381	4	122629	4	46612
51382	5	122631	1	21884
51383	3	122638	5	46784
51384	1	122640	6	46636
51385	5	122644	6	8574
51386	5	122646	4	46770
51387	5	122650	3	2447
51388	4	122651	6	15957
51389	4	122655	7	33717
51390	5	122656	6	41105
51391	5	122657	4	44130
51392	5	122660	3	17492
51393	4	122661	6	20845
51394	4	122663	5	46747
51395	4	122665	4	46602
51396	5	122666	2	30099
51397	4	122670	1	43449
51398	5	122675	7	39728
51399	5	122680	4	29773
51400	5	122681	4	46659
51401	4	122682	5	46563
51402	5	122683	1	5945
51403	3	122685	7	4825
51404	4	122689	4	46717
51405	4	122689	5	46717
51406	5	122690	3	33798
51407	5	122692	7	46586
51408	5	122696	3	36954
51409	5	122699	3	5350
51410	5	122700	5	41696
51411	5	122701	2	677
51412	5	122704	4	46626
51413	5	122707	6	2540
51414	5	122711	3	46562
51415	5	122712	4	46625
51416	5	122715	6	26186
51417	2	122718	3	46559
51418	4	122719	6	14003
51419	4	122724	7	29401
51420	2	122726	3	18459
51421	5	122727	2	31374
51422	5	122731	7	45738
51423	1	122735	4	42584
51424	5	122736	7	19464
51425	5	122737	6	19418
51426	5	122738	5	43362
51427	4	122742	3	5425
51428	5	122743	5	19033
51429	4	122745	6	46635
51430	4	122747	6	37725
51431	3	122748	1	46768
51432	5	122749	6	709
51433	5	122750	1	46648
51434	4	122753	2	21322
51435	5	122758	6	46769
51436	5	122760	6	43085
51437	5	122761	7	46646
51438	5	122761	2	46646
51439	5	122762	7	36273
51440	5	122763	1	38016
51441	5	122764	6	35023
51442	5	122767	2	3065
51443	5	122770	2	15028
51444	5	122771	2	13817
51445	5	122775	5	32799
51446	5	122778	6	40722
51447	3	122782	1	38809
51448	1	122785	2	8746
51449	3	122791	2	24744
51450	5	122791	4	24744
51451	1	122792	6	18070
51452	4	122795	3	45284
51453	5	122795	7	45284
51454	4	122796	6	5666
51455	1	122797	6	33670
51456	5	122798	3	24994
51457	5	122799	1	40272
51458	5	122799	4	40272
51459	5	122800	6	30038
51460	5	122801	3	45886
51461	4	122802	5	9582
51462	3	122805	1	19143
51463	3	122806	1	27550
51464	5	122807	3	16720
51465	5	122807	7	16720
51466	5	122808	6	30127
51467	4	122811	6	46712
51468	5	122814	6	44257
51469	5	122815	6	46613
51470	3	122816	5	37607
51471	2	122820	7	39596
51472	4	122821	6	17168
51473	5	122824	4	21038
51474	5	122825	7	1155
51475	3	122826	3	46584
51476	5	122829	2	31333
51477	5	122834	3	46727
51478	4	122836	6	1733
51479	5	122837	4	46713
51480	4	122839	5	45720
51481	3	122840	5	29896
51482	4	122843	2	16746
51483	4	122848	4	46673
51484	3	122849	6	44348
51485	5	122853	6	21071
51486	5	122856	7	39775
51487	5	122859	2	40917
51488	5	122860	5	38712
51489	4	122862	4	46676
51490	3	122866	2	26024
51491	5	122873	7	5131
51492	5	122875	6	17753
51493	5	122877	4	40933
51494	2	122879	7	17988
51495	5	122881	2	1400
51496	5	122882	6	37953
51497	3	122884	4	1507
51498	2	122885	6	46704
51499	5	122887	7	31574
51500	4	122890	4	20957
51501	4	122891	5	18522
51502	5	122893	7	46754
51503	5	122895	3	3172
51504	5	122898	7	982
51505	4	122899	4	18227
51506	5	122901	5	46761
51507	3	122902	3	46734
51508	4	122903	7	17511
51509	5	122907	5	23322
51510	3	122911	5	13614
51511	4	122913	6	46745
51512	4	122914	7	46773
51513	5	122918	4	21212
51514	5	122919	6	18095
51515	3	122921	7	46742
51516	5	122922	3	4166
51517	3	122924	4	45266
51518	1	122925	6	37201
51519	5	122927	2	46674
51520	5	122927	6	46674
51521	5	122928	7	169
51522	5	122929	2	14796
51523	5	122930	7	15909
51524	5	122931	7	46730
51525	5	122933	4	31125
51526	1	122935	5	4974
51527	3	122936	4	7094
51528	5	122937	5	46718
51529	4	122940	2	10850
51530	4	122942	4	44853
51531	5	122943	6	15186
51532	3	122947	3	46630
51533	5	122948	6	11543
51534	3	122957	4	14410
51535	1	122959	4	3784
51536	5	122960	6	8841
51537	5	122962	6	20794
51538	5	122967	2	11240
51539	3	122968	3	41949
51540	4	122969	4	47015
51541	5	122971	6	25275
51542	5	122974	6	18880
51543	4	122977	5	32313
51544	5	122979	5	30073
51545	5	122980	1	23090
51546	4	122982	3	46703
51547	5	122983	7	46862
51548	5	122988	6	1451
51549	4	122991	6	3792
51550	4	122994	5	13652
51551	5	122995	2	40614
51552	5	122996	6	46916
51553	5	122996	4	46916
51554	3	122997	3	36099
51555	5	122998	4	27444
51556	5	123000	2	46621
51557	3	123002	4	30229
51558	3	123009	1	46818
51559	5	123010	3	46940
51560	4	123015	1	37882
51561	5	123025	3	21109
51562	4	123028	5	14499
51563	4	123030	3	44183
51564	2	123037	4	46944
51565	5	123038	4	40556
51566	5	123039	6	46948
51567	5	123042	5	39703
51568	5	123044	6	17534
51569	5	123044	2	17534
51570	5	123045	7	46943
51571	5	123047	3	36967
51572	5	123049	2	46858
51573	4	123053	1	15054
51574	5	123054	5	3439
51575	5	123055	5	46860
51576	5	123061	5	3580
51577	1	123062	6	46947
51578	4	123063	5	46887
51579	5	123069	2	46826
51580	3	123071	1	22910
51581	5	123073	6	40917
51582	5	123077	7	47032
51583	4	123077	5	47032
51584	5	123079	4	7050
51585	5	123080	6	46980
51586	5	123082	1	25641
51587	5	123085	5	40585
51588	3	123086	3	46933
51589	3	123090	7	37821
51590	5	123091	7	9643
51591	2	123093	4	33234
51592	4	123094	7	10716
51593	4	123097	1	13613
51594	4	123098	5	44897
51595	3	123103	7	8866
51596	5	123103	1	8866
51597	3	123105	7	36606
51598	5	123107	1	41870
51599	4	123115	2	40586
51600	5	123116	4	2965
51601	4	123125	4	46978
51602	4	123125	7	46978
51603	5	123127	7	46554
51604	5	123131	5	46804
51605	5	123134	2	2492
51606	5	123135	1	46923
51607	5	123135	4	46923
51608	3	123139	5	8067
51609	5	123139	2	8067
51610	4	123141	6	46981
51611	5	123145	6	32765
51612	5	123146	6	22784
51613	5	123148	4	47057
51614	5	123149	2	1115
51615	4	123150	3	41225
51616	3	123151	5	15133
51617	5	123153	2	33376
51618	4	123154	4	16816
51619	5	123155	3	1106
51620	3	123158	4	46987
51621	3	123160	5	7058
51622	2	123164	4	43995
51623	5	123164	3	43995
51624	4	123167	4	43704
51625	1	123169	6	42216
51626	3	123173	7	15393
51627	5	123175	6	47001
51628	4	123176	7	28317
51629	4	123179	3	36969
51630	4	123182	7	19847
51631	3	123183	7	46838
51632	1	123184	5	37865
51633	5	123195	2	46836
51634	5	123197	7	46845
51635	5	123199	7	47000
51636	5	123201	5	4762
51637	4	123202	5	14703
51638	5	123204	5	30752
51639	3	123209	3	32973
51640	5	123212	6	5640
51641	4	123217	3	3629
51642	4	123223	5	32936
51643	5	123224	6	34458
51644	5	123225	4	7633
51645	3	123231	7	46945
51646	5	123235	7	8474
51647	3	123237	4	18940
51648	5	123237	5	18940
51649	3	123238	2	46975
51650	3	123242	3	3512
51651	4	123246	6	33896
51652	5	123249	2	46827
51653	5	123251	4	40708
51654	3	123256	7	47029
51655	4	123261	4	31384
51656	3	123262	7	18936
51657	3	123265	6	9833
51658	1	123269	6	15018
51659	5	123271	3	28987
51660	4	123274	7	16676
51661	5	123275	7	37077
51662	5	123283	2	17664
51663	5	123286	2	754
51664	5	123287	5	23114
51665	5	123289	1	46898
51666	3	123291	1	21414
51667	5	123296	4	35096
51668	5	123297	3	46952
51669	4	123298	7	46922
51670	4	123300	2	20478
51671	4	123305	6	5169
51672	5	123305	2	5169
51673	4	123309	6	12106
51674	4	123310	7	46880
51675	5	123315	6	889
51676	4	123319	5	17021
51677	4	123321	1	23414
51678	4	123322	7	25631
51679	3	123323	7	18597
51680	4	123324	4	24752
51681	5	123326	4	22099
51682	3	123326	5	22099
51683	5	123329	4	18878
51684	5	123330	4	47011
51685	4	123333	5	46819
51686	3	123334	5	16475
51687	5	123335	3	46928
51688	5	123341	4	35776
51689	3	123342	1	29104
51690	5	123344	4	47034
51691	5	123345	2	46849
51692	3	123349	7	46991
51693	4	123349	6	46991
51694	5	123351	6	7301
51695	5	123356	1	46854
51696	3	123360	3	22071
51697	5	123361	6	47009
51698	5	123362	2	2253
51699	5	123363	7	29137
51700	2	123374	6	27076
51701	4	123375	5	47033
51702	3	123380	3	1914
51703	5	123383	2	12709
51704	3	123385	1	28478
51705	5	123392	2	10046
51706	3	123393	7	308
51707	3	123394	5	47023
51708	1	123397	2	7796
51709	5	123399	5	11770
51710	4	123401	5	14223
51711	3	123401	1	14223
51712	5	123403	5	43604
51713	5	123404	6	43642
51714	4	123415	2	31176
51715	5	123416	2	46807
51716	4	123417	2	35530
51717	3	123420	4	46974
51718	5	123422	5	13400
51719	5	123423	6	15400
51720	5	123424	5	15143
51721	4	123425	1	40488
51722	5	123433	6	38819
51723	1	123434	6	25255
51724	3	123436	1	16556
51725	3	123437	5	17936
51726	4	123439	7	2878
51727	4	123443	2	46955
51728	1	123444	6	47048
51729	5	123445	2	22683
51730	3	123446	4	25944
51731	4	123449	5	25200
51732	5	123450	4	46949
51733	4	123452	5	19530
51734	5	123454	7	46969
51735	5	123456	2	46905
51736	3	123457	1	46869
51737	4	123461	4	46982
51738	3	123466	3	44639
51739	4	123468	6	46971
51740	3	123471	5	46910
51741	4	123473	3	28038
51742	5	123474	4	46895
51743	3	123484	5	46889
51744	4	123488	3	47013
51745	5	123489	6	44155
51746	5	123490	7	15484
51747	4	123491	7	6437
51748	4	123492	7	33280
51749	3	123492	5	33280
51750	4	123494	6	46900
51751	5	123496	2	46820
51752	4	123499	3	6135
51753	5	123499	6	6135
51754	2	123500	4	21485
51755	3	123502	5	37031
51756	5	123502	1	37031
51757	4	123507	5	46999
51758	5	123510	6	43915
51759	5	123510	4	43915
51760	5	123511	6	16167
51761	5	123514	5	46871
51762	3	123516	2	26819
51763	4	123517	4	46902
51764	4	123518	7	11969
51765	5	123523	2	46927
51766	5	123524	5	47014
51767	5	123525	1	45951
51768	5	123526	7	24010
51769	4	123528	5	46976
51770	5	123531	1	5485
51771	5	123534	7	47010
51772	4	123538	5	46884
51773	5	123539	6	20196
51774	3	123540	6	5236
51775	5	123542	7	23559
51776	3	123548	7	33315
51777	4	123554	7	26952
51778	3	123555	3	28209
51779	5	123555	2	28209
51780	4	123556	2	46805
51781	5	123557	6	45308
51782	3	123560	5	11840
51783	4	123561	4	12844
51784	5	123564	2	42818
51785	4	123565	5	46988
51786	5	123568	7	13172
51787	5	123569	2	36597
51788	5	123571	6	44840
51789	5	123577	7	39946
51790	4	123578	2	46841
51791	5	123579	6	31480
51792	5	123580	7	2056
51793	4	123582	5	15093
51794	5	123584	6	32
51795	4	123585	2	1924
51796	4	123589	7	46872
51797	2	123591	6	46831
51798	4	123592	4	5308
51799	4	123594	7	15042
51800	5	123595	7	17577
51801	4	123598	4	2185
51802	5	123599	1	7297
51803	5	123599	6	7297
51804	5	123600	2	11876
51805	5	123602	4	46867
51806	4	123603	2	47030
51807	5	123604	3	8180
51808	5	123606	5	46840
51809	1	123607	3	5451
51810	3	123609	3	8950
51811	5	123611	7	23859
51812	5	123613	4	46883
51813	4	123617	7	39414
51814	1	123618	6	45654
51815	4	123620	2	38875
51816	4	123620	5	38875
51817	5	123621	1	44383
51818	5	123622	5	46929
51819	5	123631	5	6362
51820	5	123634	7	46817
51821	3	123636	5	46907
51822	4	123640	7	46941
51823	5	123641	4	38948
51824	5	123642	2	13950
51825	3	123648	1	29033
51826	4	123654	5	21430
51827	5	123655	2	39678
51828	3	123657	5	21887
51829	5	123661	2	46803
51830	5	123664	6	26361
51831	4	123664	4	26361
51832	5	123665	5	19628
51833	5	123666	4	40152
51834	3	123669	7	33990
51835	5	123671	6	47005
51836	5	123674	2	20669
51837	5	123675	4	46832
51838	3	123678	4	46914
51839	3	123679	5	20451
51840	5	123681	3	45559
51841	4	123682	4	40611
51842	4	123683	1	39168
51843	5	123684	6	46994
51844	5	123686	6	46875
51845	5	123687	7	46921
51846	5	123688	6	45770
51847	5	123689	2	27744
51848	5	123694	2	46951
51849	5	123697	5	36091
51850	5	123699	2	11105
51851	5	123699	5	11105
51852	5	123701	6	24833
51853	1	123703	1	46958
51854	5	123704	2	15110
51855	3	123705	5	24734
51856	4	123707	2	46973
51857	4	123709	3	46896
51858	3	123709	7	46896
51859	5	123714	6	1212
51860	3	123717	5	46857
51861	5	123718	6	41218
51862	4	123721	6	657
51863	5	123722	3	6501
51864	4	123723	5	25246
51865	5	123724	2	41906
51866	5	123726	7	47041
51867	3	123726	3	47041
51868	3	123728	1	2528
51869	5	123729	7	38185
51870	5	123738	4	46847
51871	3	123741	6	10519
51872	3	123742	7	46935
51873	3	123743	4	46997
51874	5	123745	2	46926
51875	5	123747	5	27907
51876	5	123749	6	3341
51877	4	123753	5	10986
51878	5	123754	3	28515
51879	3	123755	1	29121
51880	5	123761	1	42330
51881	3	123762	3	46835
51882	4	123764	1	28999
51883	5	123766	5	28692
51884	5	123773	1	42247
51885	5	123776	3	11666
51886	5	123777	5	33946
51887	3	123779	1	47046
51888	5	123780	6	22740
51889	5	123782	6	10279
51890	2	123791	1	46853
51891	4	123802	6	820
51892	5	123803	6	9893
51893	4	123804	3	24789
51894	4	123805	5	17545
51895	5	123806	4	9610
51896	3	123807	1	46825
51897	3	123809	1	33645
51898	5	123810	2	27646
51899	4	123811	3	19816
51900	2	123814	6	47026
51901	5	123818	1	40936
51902	5	123820	1	46810
51903	4	123821	7	22479
51904	5	123823	6	46851
51905	3	123824	5	25741
51906	5	123825	5	2440
51907	1	123826	6	25830
51908	5	123828	7	4482
51909	5	123829	3	173
51910	3	123830	4	42051
51911	2	123831	2	1406
51912	4	123840	5	15961
51913	5	123841	7	30516
51914	5	123842	7	46986
51915	4	123843	4	46115
51916	5	123844	2	17710
51917	5	123845	1	37730
51918	3	123846	7	26332
51919	4	123849	1	40267
51920	1	123852	6	3638
51921	5	123852	1	3638
51922	4	123853	6	26507
51923	4	123856	7	14947
51924	5	123857	3	2201
51925	5	123859	1	6871
51926	5	123861	2	42414
51927	5	123863	2	19903
51928	4	123865	4	47100
51929	5	123866	7	12460
51930	5	123868	4	21457
51931	5	123870	5	47090
51932	5	123872	3	47059
51933	5	123875	4	43668
51934	5	123877	6	11296
51935	5	123878	4	13507
51936	4	123880	7	3885
51937	4	123880	3	3885
51938	3	123884	3	16010
51939	4	123885	2	10378
51940	5	123889	7	47120
51941	5	123895	6	47096
51942	4	123896	7	16749
51943	1	123898	6	47145
51944	4	123899	1	3198
51945	5	123903	1	47184
51946	4	123904	1	47234
51947	5	123905	6	10753
51948	5	123906	5	47116
51949	3	123908	1	45097
51950	1	123909	6	29086
51951	4	123910	2	47233
51952	3	123914	5	47178
51953	3	123915	3	47106
51954	5	123917	6	8898
51955	5	123923	6	41299
51956	5	123924	1	30839
51957	4	123926	5	4846
51958	5	123929	6	41926
51959	1	123930	6	47249
51960	4	123931	7	14109
51961	5	123933	6	47259
51962	5	123934	7	34869
51963	4	123938	7	29068
51964	5	123938	6	29068
51965	5	123939	1	47114
51966	5	123945	7	47080
51967	5	123948	6	37496
51968	4	123949	2	45559
51969	4	123950	7	25235
51970	2	123951	6	13710
51971	5	123951	3	13710
51972	5	123952	6	47058
51973	5	123953	2	28731
51974	3	123954	6	4814
51975	4	123956	3	41471
51976	5	123956	6	41471
51977	4	123958	7	16192
51978	3	123959	3	8543
51979	4	123969	5	15636
51980	5	123972	2	47285
51981	4	123978	1	47093
51982	5	123983	1	41030
51983	5	123983	6	41030
51984	2	123988	1	47088
51985	5	123991	4	10102
51986	5	123992	2	4010
51987	5	123994	2	7223
51988	4	123996	7	47287
51989	4	123996	6	47287
51990	4	123997	1	8585
51991	3	123999	7	42911
51992	4	124001	6	47153
51993	5	124003	5	47142
51994	5	124004	2	39108
51995	4	124005	6	47165
51996	3	124005	7	47165
51997	4	124006	2	21155
51998	4	124008	5	6747
51999	5	124009	3	41967
52000	4	124011	6	47295
52001	3	124014	5	226
52002	4	124015	2	19183
52003	3	124016	5	47167
52004	2	124017	3	47161
52005	3	124018	3	6182
52006	4	124022	3	23200
52007	3	124025	5	8355
52008	4	124026	7	23988
52009	3	124027	5	2197
52010	4	124028	3	43323
52011	4	124032	7	11783
52012	4	124035	7	743
52013	5	124037	2	25294
52014	5	124042	7	5737
52015	5	124043	3	47242
52016	4	124044	3	28183
52017	4	124046	5	47221
52018	5	124049	4	12158
52019	4	124050	5	5478
52020	5	124056	3	10936
52021	5	124056	5	10936
52022	5	124060	4	1693
52023	4	124066	5	13051
52024	5	124067	3	47239
52025	3	124068	5	15790
52026	3	124074	5	11148
52027	5	124075	2	9799
52028	4	124082	7	47246
52029	3	124082	5	47246
52030	4	124084	4	24510
52031	5	124084	1	24510
52032	4	124085	2	37461
52033	5	124086	5	47240
52034	5	124087	2	39340
52035	5	124091	6	47275
52036	4	124092	2	46932
52037	4	124093	5	2519
52038	5	124098	4	33477
52039	5	124099	7	47082
52040	5	124100	6	74
52041	3	124100	3	74
52042	4	124104	7	30814
52043	5	124105	6	6015
52044	5	124109	4	33226
52045	5	124110	2	47104
52046	4	124111	7	23976
52047	4	124113	7	35010
52048	5	124114	6	47215
52049	5	124115	7	24416
52050	5	124116	6	5511
52051	5	124117	7	25590
52052	3	124124	5	29080
52053	4	124129	6	233
52054	4	124129	1	233
52055	5	124130	7	39660
52056	5	124131	6	44279
52057	4	124132	6	35807
52058	5	124133	7	31282
52059	3	124135	5	45745
52060	5	124137	2	40321
52061	4	124138	6	4319
52062	5	124139	5	27808
52063	5	124140	1	47149
52064	5	124142	5	35188
52065	3	124142	7	35188
52066	5	124146	6	47182
52067	4	124150	7	35937
52068	4	124151	7	3796
52069	4	124152	1	40564
52070	5	124152	6	40564
52071	4	124153	2	9688
52072	4	124156	4	47209
52073	4	124157	7	23129
52074	3	124159	7	47229
52075	4	124160	2	47181
52076	5	124162	2	47192
52077	5	124163	7	31528
52078	5	124168	6	40259
52079	5	124171	2	18304
52080	5	124172	3	15714
52081	5	124173	4	20156
52082	5	124177	5	47070
52083	5	124177	7	47070
52084	4	124182	7	43943
52085	3	124183	5	33629
52086	1	124186	1	17011
52087	4	124190	3	45498
52088	3	124191	7	9071
52089	5	124192	4	35425
52090	2	124194	2	39857
52091	4	124197	1	31112
52092	3	124200	5	47294
52093	4	124202	5	19965
52094	5	124202	7	19965
52095	5	124204	3	16165
52096	5	124213	4	35337
52097	4	124216	6	47193
52098	5	124217	6	14831
52099	5	124218	4	47141
52100	4	124223	6	38357
52101	5	124227	4	27084
52102	5	124230	1	20520
52103	4	124231	1	215
52104	5	124233	6	47103
52105	4	124237	5	47194
52106	3	124238	7	25444
52107	3	124239	3	47199
52108	5	124241	4	6885
52109	4	124242	1	46078
52110	5	124243	6	47143
52111	1	124244	6	36272
52112	4	124245	5	37523
52113	5	124246	6	47230
52114	4	124248	4	3688
52115	5	124252	7	47274
52116	5	124253	1	23288
52117	3	124254	6	33844
52118	5	124255	3	47117
52119	5	124256	2	28041
52120	3	124257	5	8362
52121	5	124258	4	31227
52122	4	124258	7	31227
52123	3	124259	5	19243
52124	5	124260	6	41151
52125	5	124263	2	34806
52126	4	124263	6	34806
52127	4	124264	6	47152
52128	5	124266	1	41753
52129	5	124267	2	21967
52130	5	124269	1	15731
52131	5	124270	2	40652
52132	5	124275	1	6267
52133	4	124278	7	22311
52134	5	124279	6	47297
52135	4	124279	4	47297
52136	5	124280	4	4775
52137	5	124282	3	22411
52138	5	124285	6	24300
52139	4	124287	6	47302
52140	1	124289	4	26773
52141	5	124290	2	15042
52142	5	124290	6	15042
52143	5	124291	4	47247
52144	5	124293	2	32335
52145	5	124295	3	42048
52146	5	124296	2	5817
52147	5	124297	1	42667
52148	5	124299	3	13327
52149	5	124299	6	13327
52150	5	124300	2	314
52151	5	124306	7	9171
52152	3	124307	2	8538
52153	5	124313	6	24535
52154	5	124314	3	47139
52155	4	124317	1	698
52156	5	124318	2	36310
52157	2	124319	6	47168
52158	5	124320	2	47126
52159	5	124321	5	33607
52160	5	124322	2	9925
52161	5	124323	5	38086
52162	5	124323	3	38086
52163	4	124326	4	7717
52164	5	124327	3	39447
52165	4	124330	4	7514
52166	5	124331	6	47198
52167	4	124333	1	2443
52168	5	124334	7	46173
52169	3	124336	2	46389
52170	5	124337	3	43519
52171	4	124339	6	34299
52172	5	124343	7	2187
52173	5	124344	7	47160
52174	5	124346	2	47248
52175	5	124349	4	47211
52176	5	124350	5	47266
52177	3	124351	7	15005
52178	4	124352	5	47112
52179	5	124355	3	31573
52180	3	124356	7	3351
52181	3	124357	5	22689
52182	4	124362	3	29017
52183	3	124364	7	11882
52184	3	124369	3	31939
52185	4	124370	6	41626
52186	5	124371	6	47133
52187	3	124376	4	30376
52188	4	124378	2	12841
52189	1	124379	3	30382
52190	3	124382	2	4354
52191	4	124383	7	25572
52192	4	124384	2	17867
52193	3	124388	5	13313
52194	4	124389	5	13344
52195	4	124390	5	24271
52196	5	124392	4	41170
52197	5	124403	1	38731
52198	4	124405	2	44038
52199	5	124405	6	44038
52200	1	124411	4	38431
52201	4	124412	4	47254
52202	5	124414	3	10706
52203	5	124415	4	7527
52204	5	124424	1	30496
52205	5	124427	6	14826
52206	5	124428	2	1064
52207	5	124429	7	5692
52208	5	124433	4	47138
52209	5	124433	7	47138
52210	5	124435	4	21068
52211	5	124436	6	27380
52212	5	124437	5	3403
52213	5	124438	6	22363
52214	4	124445	6	47127
52215	3	124446	1	5240
52216	5	124449	2	20294
52217	5	124454	2	30197
52218	4	124457	4	12386
52219	4	124459	4	47309
52220	5	124460	6	47241
52221	5	124461	7	19052
52222	3	124462	7	36908
52223	5	124468	7	12434
52224	4	124471	5	13156
52225	5	124472	1	36002
52226	3	124473	2	46522
52227	4	124474	5	47282
52228	5	124478	6	47099
52229	5	124481	2	47190
52230	4	124482	2	19907
52231	5	124483	6	40630
52232	2	124489	3	34041
52233	5	124490	6	46185
52234	5	124492	4	47084
52235	3	124493	3	23956
52236	4	124494	5	9621
52237	3	124496	5	38169
52238	4	124497	5	34297
52239	5	124498	3	21003
52240	4	124499	5	24556
52241	5	124503	6	16136
52242	4	124504	2	40731
52243	5	124505	2	22752
52244	5	124506	6	47293
52245	5	124507	7	26241
52246	3	124510	4	7026
52247	5	124516	4	24033
52248	3	124518	7	3238
52249	1	124520	7	44618
52250	5	124522	2	32970
52251	4	124524	4	37824
52252	5	124529	6	4870
52253	3	124533	3	12776
52254	3	124535	5	38370
52255	5	124536	3	3817
52256	3	124537	5	15350
52257	4	124539	6	29839
52258	3	124541	3	22259
52259	5	124542	7	39636
52260	5	124543	7	33662
52261	4	124544	7	39257
52262	5	124550	1	33682
52263	5	124554	2	30089
52264	3	124556	7	21659
52265	5	124559	7	14161
52266	5	124561	6	8748
52267	5	124562	1	18353
52268	3	124563	2	47187
52269	3	124564	5	3260
52270	3	124566	5	248
52271	5	124568	2	31850
52272	5	124576	4	62
52273	5	124577	2	15501
52274	4	124578	1	47219
52275	4	124581	6	33801
52276	5	124584	5	12707
52277	5	124589	5	8680
52278	4	124591	5	47147
52279	5	124593	2	9569
52280	4	124594	3	47250
52281	5	124595	3	15827
52282	3	124597	7	47156
52283	3	124599	7	33998
52284	5	124599	6	33998
52285	3	124601	3	1489
52286	5	124604	7	47213
52287	1	124605	2	22790
52288	5	124606	3	19720
52289	5	124606	5	19720
52290	5	124607	7	47169
52291	4	124609	6	42751
52292	4	124614	3	24974
52293	4	124618	6	47086
52294	5	124620	3	47267
52295	2	124621	4	15065
52296	5	124621	1	15065
52297	5	124622	6	3883
52298	4	124629	7	47270
52299	3	124634	1	32571
52300	3	124639	4	7691
52301	2	124642	6	30275
52302	5	124646	4	8433
52303	5	124646	3	8433
52304	3	124647	5	47081
52305	5	124648	7	10787
52306	5	124654	7	20931
52307	5	124657	1	19957
52308	4	124658	4	45543
52309	4	124661	7	42179
52310	5	124663	3	37631
52311	3	124665	5	24144
52312	3	124666	7	27524
52313	5	124671	1	47176
52314	3	124672	7	16025
52315	4	124673	7	42098
52316	5	124674	1	47208
52317	5	124675	2	14358
52318	5	124677	5	13484
52319	4	124681	4	13813
52320	5	124682	1	46771
52321	3	124683	5	1244
52322	1	124684	6	3221
52323	1	124686	4	1639
52324	4	124687	5	35549
52325	2	124688	6	46632
52326	5	124689	6	14131
52327	5	124694	2	47310
52328	5	124695	1	43446
52329	4	124697	7	6046
52330	3	124699	3	25749
52331	5	124700	1	47130
52332	5	124701	1	30167
52333	4	124704	2	7472
52334	5	124705	3	47272
52335	5	124707	1	27256
52336	5	124709	7	38419
52337	4	124710	2	24728
52338	2	124713	7	4066
52339	5	124715	2	42598
52340	3	124724	1	15419
52341	4	124726	7	43666
52342	5	124727	5	19056
52343	2	124729	6	47196
52344	4	124729	5	47196
52345	5	124730	7	47071
52346	3	124731	5	21574
52347	3	124738	3	45308
52348	3	124740	1	2264
52349	5	124742	7	47257
52350	5	124743	1	45939
52351	5	124754	3	19277
52352	4	124757	1	44634
52353	4	124761	5	19279
52354	5	124762	5	21561
52355	5	124763	5	19085
52356	5	124767	6	47073
52357	5	124769	2	15563
52358	5	124770	5	2995
52359	5	124774	1	8716
52360	5	124780	3	47179
52361	5	124781	5	47077
52362	3	124785	6	47313
52363	3	124787	5	5962
52364	5	124789	2	30917
52365	5	124792	4	47218
52366	4	124797	5	47261
52367	5	124801	4	1148
52368	3	124801	1	1148
52369	4	124802	6	35771
52370	5	124808	2	37090
52371	4	124810	2	47269
52372	3	124815	4	47180
52373	5	124816	2	45554
52374	1	124818	6	36826
52375	4	124823	2	31008
52376	4	124825	6	17809
52377	5	124828	5	11766
52378	3	124830	1	8620
52379	5	124831	4	37802
52380	5	124832	7	24221
52381	5	124836	4	21205
52382	5	124843	5	47227
52383	5	124844	4	32991
52384	3	124845	5	18306
52385	5	124846	1	8347
52386	5	124847	7	47111
52387	4	124848	1	47252
52388	5	124849	3	18734
52389	5	124851	7	15578
52390	5	124854	2	23680
52391	5	124857	6	47319
52392	1	124859	6	47223
52393	5	124861	6	16134
52394	5	124869	2	37392
52395	5	124870	4	6296
52396	3	124872	5	359
52397	4	124873	4	36495
52398	4	124878	2	23276
52399	5	124881	1	37439
52400	5	124882	6	42746
52401	3	124887	7	14020
52402	1	124888	6	40697
52403	4	124890	3	13953
52404	5	124891	2	36382
52405	4	124893	7	47195
52406	5	124898	7	47146
52407	4	124899	1	47312
52408	4	124900	7	32129
52409	4	124901	6	46846
52410	5	124903	6	10807
52411	2	124903	2	10807
52412	4	124905	1	47300
52413	5	124906	7	47296
52414	5	124907	3	27299
52415	5	124908	4	3173
52416	5	124911	2	18708
52417	4	124913	5	47109
52418	5	124920	7	44164
52419	3	124921	5	30263
52420	4	124924	1	38651
52421	3	124926	5	30251
52422	5	124927	1	35545
52423	1	124928	4	19560
52424	4	124930	7	47158
52425	5	124931	3	47097
52426	2	124940	1	46492
52427	4	124941	3	47083
52428	4	124943	7	47064
52429	5	124947	1	47258
52430	5	124953	3	31006
52431	5	124956	1	45738
52432	5	124960	4	47191
52433	5	124963	2	5416
52434	3	124966	7	13042
52435	5	124967	6	27917
52436	5	124973	4	5574
52437	4	124976	1	24024
52438	4	124978	1	8057
52439	3	124981	7	31479
52440	3	124983	7	14490
52441	4	124984	2	46464
52442	5	124986	5	46797
52443	1	124987	6	26186
52444	5	124988	6	47424
52445	5	124989	5	47332
52446	4	124991	6	47466
52447	4	124992	7	47414
52448	5	124993	6	47464
52449	4	124994	5	33897
52450	5	124997	2	47439
52451	5	124999	1	47504
52452	4	125002	2	4995
52453	4	125003	7	11869
52454	4	125004	7	9136
52455	5	125005	3	9506
52456	5	125006	1	38141
52457	5	125007	7	4636
52458	5	125012	3	36581
52459	4	125014	7	30167
52460	4	125019	2	3945
52461	5	125022	7	47369
52462	5	125026	5	12327
52463	5	125029	5	14641
52464	5	125031	2	38813
52465	5	125033	2	42882
52466	3	125034	7	9235
52467	5	125036	1	47459
52468	4	125037	3	47403
52469	4	125038	5	47351
52470	5	125042	2	26874
52471	5	125047	7	47387
52472	3	125047	1	47387
52473	5	125048	6	40265
52474	4	125053	7	31021
52475	3	125054	3	47443
52476	5	125057	7	47442
52477	3	125059	5	11604
52478	3	125060	7	33164
52479	5	125069	5	1473
52480	2	125070	6	47340
52481	5	125070	5	47340
52482	5	125071	4	47492
52483	5	125073	6	30252
52484	5	125080	2	18781
52485	3	125081	7	47480
52486	4	125089	7	37167
52487	5	125092	7	19913
52488	4	125093	4	34301
52489	5	125095	2	25905
52490	4	125098	5	27961
52491	5	125100	2	20414
52492	5	125103	2	4208
52493	5	125110	5	5109
52494	5	125114	3	47441
52495	5	125115	5	10150
52496	2	125117	4	47381
52497	5	125118	4	2067
52498	3	125121	7	21662
52499	3	125123	4	47456
52500	5	125123	3	47456
52501	5	125124	3	47503
52502	5	125125	4	8252
52503	5	125127	6	33581
52504	4	125129	7	25231
52505	3	125130	7	906
52506	5	125131	4	2618
52507	4	125132	3	47333
52508	4	125134	1	47475
52509	3	125138	5	6161
52510	3	125144	5	32663
52511	5	125145	3	47445
52512	1	125149	6	3705
52513	5	125153	1	47341
52514	5	125163	2	7899
52515	4	125169	6	40856
52516	3	125172	6	41152
52517	5	125177	1	32571
52518	4	125179	7	47498
52519	5	125182	5	27313
52520	3	125186	5	33829
52521	5	125187	4	14488
52522	5	125189	3	4395
52523	3	125190	1	21552
52524	5	125193	4	41829
52525	5	125194	3	47447
52526	5	125195	2	15875
52527	3	125200	4	47352
52528	5	125201	5	47425
52529	5	125202	2	10674
52530	5	125204	6	28949
52531	5	125208	1	43128
52532	3	125209	3	17866
52533	4	125210	5	28670
52534	4	125211	7	35132
52535	5	125212	5	13713
52536	5	125217	5	47382
52537	5	125219	6	47438
52538	5	125220	2	21
52539	5	125223	3	43948
52540	5	125224	2	10412
52541	3	125230	1	14585
52542	4	125232	6	45362
52543	1	125233	4	37458
52544	3	125234	3	7253
52545	5	125235	6	4794
52546	4	125241	1	45936
52547	4	125243	7	39244
52548	3	125244	6	41654
52549	5	125246	5	47454
52550	2	125246	6	47454
52551	5	125248	1	23933
52552	3	125254	1	5945
52553	1	125254	6	5945
52554	5	125257	1	28078
52555	5	125261	1	47390
52556	5	125262	3	6923
52557	5	125263	2	40711
52558	5	125264	7	35209
52559	5	125267	6	18475
52560	5	125269	2	36993
52561	4	125273	2	40658
52562	5	125274	6	47463
52563	4	125280	3	37855
52564	5	125281	4	18612
52565	4	125282	2	640
52566	5	125284	2	43587
52567	5	125288	4	34456
52568	3	125288	6	34456
52569	5	125289	5	19295
52570	5	125291	5	18646
52571	4	125292	5	47497
52572	5	125293	4	5975
52573	4	125293	7	5975
52574	4	125298	2	7726
52575	5	125299	6	47370
52576	5	125301	4	46734
52577	3	125303	1	23975
52578	5	125304	7	36480
52579	5	125305	6	27264
52580	3	125307	5	43008
52581	5	125310	4	46380
52582	5	125316	1	18604
52583	3	125318	5	42722
52584	4	125320	4	33263
52585	3	125322	7	8779
52586	5	125323	7	44149
52587	4	125328	5	33010
52588	5	125329	5	25950
52589	1	125330	6	47460
52590	4	125334	7	43350
52591	5	125339	1	1267
52592	5	125346	4	17564
52593	4	125346	7	17564
52594	4	125349	5	43165
52595	3	125350	4	39665
52596	4	125352	4	33414
52597	5	125353	2	2300
52598	5	125358	3	1562
52599	5	125360	6	14710
52600	3	125365	7	24741
52601	3	125369	2	4863
52602	1	125372	6	44872
52603	4	125373	4	31779
52604	5	125378	5	44835
52605	5	125380	5	47363
52606	5	125382	6	28090
52607	5	125383	1	47461
52608	5	125386	4	8279
52609	5	125386	1	8279
52610	4	125389	7	37742
52611	5	125393	2	47321
52612	4	125394	4	45245
52613	2	125398	1	41055
52614	5	125404	6	47491
52615	4	125407	5	39850
52616	2	125408	1	17685
52617	1	125409	6	13099
52618	5	125411	5	47334
52619	5	125413	1	14342
52620	5	125413	6	14342
52621	5	125414	4	12183
52622	5	125416	1	47402
52623	5	125423	1	26232
52624	5	125425	6	47485
52625	5	125426	7	3153
52626	5	125427	4	47354
52627	3	125429	7	38909
52628	4	125431	7	37231
52629	5	125431	4	37231
52630	2	125435	4	33584
52631	4	125438	3	47484
52632	3	125438	5	47484
52633	5	125440	7	42283
52634	5	125441	7	47376
52635	4	125443	7	14130
52636	5	125445	4	2761
52637	5	125450	2	19143
52638	3	125452	7	40288
52639	4	125455	4	10670
52640	4	125458	5	23589
52641	4	125461	6	46815
52642	3	125463	6	25130
52643	5	125467	1	16520
52644	5	125469	7	8651
52645	3	125470	1	20899
52646	5	125471	6	35337
52647	5	125473	7	47476
52648	5	125474	1	27589
52649	5	125476	5	3629
52650	5	125477	6	47465
52651	5	125481	7	13535
52652	5	125484	2	22064
52653	4	125485	7	5792
52654	5	125486	4	17876
52655	4	125487	7	13262
52656	4	125491	7	6113
52657	5	125495	5	34216
52658	1	125496	6	47669
52659	4	125499	1	47590
52660	5	125504	6	47711
52661	5	125510	5	31151
52662	5	125511	6	35838
52663	2	125512	2	43323
52664	4	125513	2	9996
52665	4	125520	7	20044
52666	4	125521	7	826
52667	5	125526	6	32312
52668	1	125527	3	47631
52669	5	125529	5	44833
52670	3	125530	1	28993
52671	4	125531	7	23147
52672	3	125534	3	7330
52673	4	125535	2	21324
52674	4	125538	6	12552
52675	4	125542	5	12411
52676	5	125544	5	10851
52677	4	125546	7	16158
52678	5	125549	2	8731
52679	5	125550	2	7119
52680	3	125551	7	19721
52681	5	125552	4	47626
52682	1	125553	6	46299
52683	5	125554	2	3286
52684	1	125557	6	25332
52685	5	125558	1	37678
52686	5	125560	3	23780
52687	3	125561	1	10676
52688	5	125562	6	47529
52689	5	125564	6	9196
52690	5	125566	1	47672
52691	5	125568	3	11394
52692	5	125569	6	47709
52693	4	125570	5	47612
52694	5	125576	2	20867
52695	3	125578	2	22404
52696	5	125578	6	22404
52697	4	125580	5	45578
52698	4	125582	7	47688
52699	4	125583	6	12022
52700	5	125585	4	3507
52701	5	125586	2	477
52702	5	125591	4	1229
52703	3	125594	7	27545
52704	2	125597	3	34957
52705	1	125604	4	13062
52706	4	125605	1	19657
52707	5	125606	6	43945
52708	5	125611	1	19387
52709	1	125620	6	47664
52710	2	125625	4	36849
52711	5	125625	2	36849
52712	5	125628	2	5875
52713	5	125633	2	44695
52714	5	125636	6	29754
52715	5	125645	6	47634
52716	4	125647	1	6410
52717	5	125649	2	26628
52718	5	125650	5	41774
52719	5	125652	3	6364
52720	5	125653	5	45209
52721	5	125656	6	47625
52722	5	125657	4	18928
52723	5	125658	6	37744
52724	4	125660	6	47582
52725	5	125660	2	47582
52726	5	125663	2	27609
52727	3	125665	1	26187
52728	4	125667	7	1726
52729	5	125670	5	7685
52730	4	125671	1	22208
52731	4	125672	4	4760
52732	3	125673	3	11005
52733	4	125675	2	47712
52734	5	125677	6	36882
52735	5	125681	1	38117
52736	3	125683	5	27584
52737	4	125686	2	47524
52738	5	125687	7	7013
52739	5	125687	6	7013
52740	5	125688	3	15768
52741	4	125693	5	39308
52742	4	125693	7	39308
52743	4	125695	7	15603
52744	5	125697	6	46539
52745	5	125700	6	1802
52746	3	125702	5	13845
52747	4	125703	7	39275
52748	4	125704	2	36888
52749	3	125705	4	47624
52750	5	125708	1	20581
52751	5	125709	6	14852
52752	4	125711	2	2250
52753	5	125714	3	47698
52754	3	125716	3	26283
52755	4	125719	5	47666
52756	5	125720	5	41159
52757	4	125723	1	42192
52758	3	125724	4	8347
52759	5	125726	6	47595
52760	5	125727	7	47575
52761	5	125736	4	19626
52762	5	125737	6	34581
52763	3	125739	4	47644
52764	4	125742	5	38895
52765	5	125745	2	35223
52766	5	125746	7	13767
52767	5	125747	6	47545
52768	5	125748	6	47617
52769	5	125750	4	47695
52770	5	125753	7	4486
52771	5	125756	4	7084
52772	4	125757	7	47726
52773	2	125761	4	7058
52774	5	125763	7	34854
52775	3	125766	7	47661
52776	5	125768	4	16470
52777	4	125769	7	43037
52778	4	125772	5	47682
52779	3	125773	4	47650
52780	4	125777	6	9743
52781	5	125778	6	45802
52782	5	125780	1	13406
52783	5	125781	3	638
52784	5	125785	4	1713
52785	5	125786	4	3965
52786	1	125790	6	39202
52787	5	125794	6	47635
52788	5	125795	6	27618
52789	5	125799	2	8295
52790	5	125800	2	30065
52791	3	125800	3	30065
52792	4	125803	7	42485
52793	5	125804	4	34698
52794	5	125805	1	47662
52795	5	125810	6	8942
52796	5	125812	4	47729
52797	5	125815	5	13948
52798	4	125817	6	21010
52799	3	125819	1	40387
52800	5	125822	3	35487
52801	4	125823	5	11669
52802	4	125825	7	4982
52803	3	125829	3	10009
52804	5	125831	6	47633
52805	5	125832	6	20804
52806	4	125834	7	19169
52807	5	125837	3	42289
52808	5	125840	4	28225
52809	5	125841	2	1698
52810	5	125842	1	29821
52811	5	125843	6	36385
52812	4	125844	7	13316
52813	5	125844	2	13316
52814	4	125845	2	38229
52815	5	125845	6	38229
52816	5	125846	2	3564
52817	3	125847	4	27154
52818	5	125848	5	1402
52819	4	125851	7	8626
52820	5	125852	5	28320
52821	4	125854	7	17019
52822	3	125855	7	47654
52823	5	125855	2	47654
52824	5	125858	2	26099
52825	5	125860	7	13634
52826	5	125861	2	33196
52827	4	125863	2	1760
52828	3	125867	7	47555
52829	5	125869	4	46754
52830	4	125870	7	17341
52831	5	125871	4	47533
52832	4	125873	4	9776
52833	5	125874	6	24071
52834	4	125875	4	23169
52835	4	125876	5	37791
52836	3	125878	4	43788
52837	5	125881	4	991
52838	4	125882	6	41578
52839	3	125884	7	22930
52840	5	125893	5	6053
52841	5	125894	6	28719
52842	5	125898	5	36870
52843	4	125899	5	12541
52844	5	125902	3	36752
52845	5	125903	2	36290
52846	5	125905	5	3949
52847	5	125906	5	41242
52848	5	125907	7	3363
52849	5	125908	4	47616
52850	5	125910	4	37638
52851	5	125911	7	36993
52852	5	125913	4	47723
52853	3	125915	1	8421
52854	5	125918	7	6129
52855	5	125922	6	47653
52856	5	125924	5	47639
52857	5	125925	7	43272
52858	5	125931	1	47657
52859	5	125931	4	47657
52860	3	125933	5	22002
52861	4	125938	5	4945
52862	5	125939	2	47733
52863	4	125941	2	46658
52864	3	125944	5	47537
52865	5	125948	5	34846
52866	4	125949	7	34305
52867	5	125950	2	31146
52868	4	125959	7	31032
52869	5	125963	3	47614
52870	2	125964	6	2630
52871	1	125965	6	47660
52872	4	125971	3	47541
52873	3	125973	2	20483
52874	3	125975	3	19913
52875	4	125978	5	45190
52876	3	125980	7	14165
52877	3	125981	1	1269
52878	4	125984	6	47534
52879	5	125989	4	47632
52880	3	125991	5	47671
52881	2	125992	3	43745
52882	5	125993	4	31045
52883	4	125995	5	14982
52884	5	125996	3	47684
52885	4	125998	5	31482
52886	5	125999	1	43811
52887	5	126000	1	37734
52888	4	126009	5	9903
52889	5	126013	2	47645
52890	5	126015	6	47731
52891	4	126016	7	10697
52892	5	126018	3	20329
52893	5	126020	2	14921
52894	5	126025	6	7566
52895	4	126027	1	17478
52896	5	126027	3	17478
52897	3	126029	1	33908
52898	5	126031	6	47601
52899	5	126036	4	19857
52900	4	126039	1	47521
52901	5	126040	2	47383
52902	4	126042	5	996
52903	5	126042	7	996
52904	4	126044	3	42750
52905	4	126046	7	16929
52906	5	126049	3	11869
52907	5	126051	2	38459
52908	5	126052	6	47581
52909	5	126053	1	47611
52910	5	126058	2	47610
52911	5	126059	5	22707
52912	5	126061	7	47549
52913	3	126062	5	16911
52914	4	126063	3	47618
52915	3	126064	5	8873
52916	5	126068	1	47721
52917	3	126071	4	27242
52918	5	126073	6	40429
52919	3	126077	5	19759
52920	5	126077	2	19759
52921	5	126079	3	7704
52922	5	126082	2	31936
52923	5	126083	7	25181
52924	4	126089	5	47699
52925	4	126090	3	45974
52926	5	126094	5	38246
52927	5	126094	2	38246
52928	5	126096	7	1693
52929	3	126097	2	47961
52930	4	126098	7	32765
52931	4	126103	5	15791
52932	5	126104	1	24241
52933	5	126106	2	13185
52934	5	126107	2	11886
52935	5	126107	7	11886
52936	5	126108	1	1679
52937	3	126111	1	23439
52938	5	126115	7	31171
52939	5	126120	2	148
52940	5	126121	2	7835
52941	5	126124	6	47842
52942	5	126125	6	43027
52943	3	126127	5	47780
52944	5	126128	5	22969
52945	4	126129	7	47788
52946	3	126133	7	40510
52947	5	126135	2	39551
52948	4	126141	1	41647
52949	5	126141	6	41647
52950	5	126142	4	21233
52951	2	126143	4	44136
52952	4	126144	6	32627
52953	5	126146	6	47761
52954	5	126151	2	7797
52955	4	126152	7	47953
52956	5	126153	6	14522
52957	5	126157	4	27161
52958	5	126159	1	4798
52959	1	126164	6	47896
52960	5	126167	2	24585
52961	3	126170	4	9171
52962	4	126171	7	12231
52963	5	126177	1	14692
52964	5	126177	4	14692
52965	5	126179	7	13848
52966	4	126181	7	47892
52967	5	126183	7	25254
52968	4	126183	5	25254
52969	5	126188	4	41222
52970	5	126189	7	3048
52971	5	126192	7	47814
52972	5	126194	6	39735
52973	5	126205	5	5157
52974	5	126207	2	44504
52975	3	126208	5	21874
52976	2	126210	1	27487
52977	3	126217	4	47902
52978	5	126217	3	47902
52979	5	126222	1	17470
52980	3	126225	5	40765
52981	4	126226	5	41779
52982	4	126229	7	20896
52983	2	126230	6	35571
52984	4	126233	5	19657
52985	5	126236	6	4075
52986	1	126237	6	28377
52987	5	126239	3	14029
52988	5	126239	2	14029
52989	3	126241	7	47787
52990	5	126245	5	37202
52991	3	126250	3	47829
52992	4	126252	5	23553
52993	5	126253	2	47756
52994	3	126254	5	164
52995	4	126254	7	164
52996	5	126259	2	44944
52997	4	126260	1	13674
52998	4	126266	6	13089
52999	5	126268	1	47947
53000	1	126276	1	41403
53001	5	126281	4	30951
53002	3	126283	7	47750
53003	5	126286	6	32287
53004	4	126290	5	32002
53005	5	126291	4	28952
53006	4	126295	5	5575
53007	4	126296	4	38342
53008	4	126300	2	28269
53009	1	126301	6	47890
53010	5	126302	2	47781
53011	3	126303	7	4783
53012	5	126305	1	10362
53013	5	126308	6	7200
53014	3	126310	6	47847
53015	5	126312	6	14244
53016	5	126313	4	28827
53017	5	126314	5	35937
53018	5	126318	4	7053
53019	5	126320	7	24246
53020	4	126322	4	26631
53021	5	126323	5	38614
53022	5	126325	7	47884
53023	5	126327	2	39819
53024	5	126328	2	47850
53025	3	126329	2	47870
53026	5	126330	2	31480
53027	5	126335	2	3592
53028	5	126337	2	12122
53029	4	126338	7	40998
53030	4	126339	4	39043
53031	5	126339	2	39043
53032	3	126341	4	21690
53033	5	126342	2	6721
53034	1	126346	6	47796
53035	5	126347	6	1071
53036	3	126348	5	27058
53037	5	126349	2	359
53038	3	126351	7	12452
53039	5	126352	5	24030
53040	5	126353	2	5298
53041	4	126354	1	47834
53042	5	126356	4	23862
53043	5	126358	7	39280
53044	3	126359	7	17344
53045	3	126364	4	38135
53046	3	126367	5	27567
53047	5	126372	6	24274
53048	5	126373	3	47933
53049	5	126375	1	27481
53050	3	126376	1	10438
53051	5	126379	5	47905
53052	5	126380	4	47938
53053	4	126383	3	24616
53054	4	126391	1	43782
53055	5	126393	2	17210
53056	4	126394	7	1972
53057	4	126395	2	18927
53058	5	126396	7	21763
53059	5	126397	4	37834
53060	4	126397	6	37834
53061	4	126399	2	18232
53062	5	126403	4	35004
53063	5	126409	3	5792
53064	5	126411	5	25670
53065	3	126411	7	25670
53066	5	126412	6	31769
53067	5	126414	2	47843
53068	3	126414	4	47843
53069	5	126416	7	28056
53070	5	126417	5	20993
53071	4	126422	1	47908
53072	5	126423	6	3227
53073	5	126426	6	15027
53074	5	126430	4	30548
53075	4	126434	5	11723
53076	5	126435	6	41518
53077	5	126438	4	44489
53078	5	126439	3	47816
53079	5	126440	6	8135
53080	4	126440	7	8135
53081	3	126447	2	19583
53082	2	126449	1	18271
53083	5	126451	6	9710
53084	2	126452	2	3843
53085	5	126455	4	33961
53086	4	126461	1	437
53087	2	126465	1	43119
53088	3	126466	5	39424
53089	5	126468	5	47747
53090	5	126469	5	47818
53091	4	126470	2	12614
53092	5	126471	1	43010
53093	3	126472	5	25637
53094	2	126473	5	20060
53095	5	126474	2	47919
53096	5	126475	1	47746
53097	5	126475	6	47746
53098	5	126477	2	27339
53099	5	126479	7	19239
53100	5	126480	2	44789
53101	4	126481	7	880
53102	3	126481	4	880
53103	5	126482	6	28126
53104	4	126485	6	36125
53105	5	126486	7	24042
53106	4	126488	5	46054
53107	1	126488	6	46054
53108	5	126491	6	25685
53109	4	126491	4	25685
53110	3	126495	1	23542
53111	3	126496	7	8118
53112	5	126497	2	47951
53113	4	126497	5	47951
53114	4	126501	1	47831
53115	5	126503	4	47805
53116	4	126504	3	47752
53117	5	126505	5	47766
53118	5	126509	6	31736
53119	3	126510	7	40496
53120	3	126511	5	36918
53121	5	126515	2	11592
53122	5	126517	2	47745
53123	5	126518	5	27995
53124	4	126521	7	17008
53125	5	126522	7	36639
53126	4	126522	4	36639
53127	3	126526	7	1429
53128	4	126529	2	8852
53129	5	126532	6	27435
53130	4	126537	7	47948
53131	3	126540	1	20965
53132	5	126541	6	39705
53133	4	126547	7	47383
53134	3	126547	6	47383
53135	3	126548	1	38625
53136	5	126550	5	35566
53137	5	126554	2	47811
53138	4	126556	3	27488
53139	5	126557	2	22382
53140	5	126557	6	22382
53141	1	126558	4	43437
53142	4	126559	2	42050
53143	5	126560	3	42025
53144	4	126562	5	47800
53145	3	126563	4	19760
53146	3	126563	6	19760
53147	5	126565	4	26083
53148	3	126577	7	6193
53149	5	126578	4	47201
53150	5	126580	2	39520
53151	5	126581	3	5110
53152	2	126582	7	13686
53153	5	126583	2	24902
53154	4	126586	5	25560
53155	5	126587	1	12058
53156	5	126587	6	12058
53157	5	126590	6	36077
53158	5	126596	6	1119
53159	4	126599	3	13846
53160	3	126601	1	18576
53161	2	126604	1	36295
53162	3	126605	1	40619
53163	5	126611	4	47744
53164	3	126617	6	47768
53165	5	126618	1	2169
53166	5	126623	1	47794
53167	5	126626	4	24635
53168	4	126628	7	47839
53169	5	126633	4	30238
53170	4	126637	2	12155
53171	5	126638	6	39406
53172	5	126639	6	21443
53173	3	126642	7	47925
53174	5	126646	3	24309
53175	3	126648	1	9554
53176	5	126649	7	2770
53177	4	126653	7	5914
53178	4	126654	2	20929
53179	4	126657	3	3932
53180	4	126657	4	3932
53181	5	126658	4	37018
53182	5	126661	4	47959
53183	4	126664	2	47878
53184	3	126666	5	44383
53185	5	126667	2	47833
53186	5	126672	7	47852
53187	2	126673	7	35852
53188	4	126673	2	35852
53189	3	126674	7	13714
53190	3	126680	4	47759
53191	3	126683	5	15807
53192	5	126686	4	5878
53193	5	126689	1	47932
53194	5	126693	1	45275
53195	4	126698	4	21139
53196	4	126699	4	47822
53197	5	126700	5	32677
53198	4	126702	1	14737
53199	5	126703	3	34147
53200	5	126703	6	34147
53201	1	126704	6	47928
53202	5	126708	7	45109
53203	4	126709	7	3917
53204	4	126710	2	3444
53205	4	126712	5	34663
53206	5	126717	5	41939
53207	5	126721	7	27835
53208	5	126730	5	39848
53209	3	126731	7	47921
53210	4	126732	2	47782
53211	5	126737	2	25710
53212	4	126742	5	18891
53213	5	126742	2	18891
53214	5	126745	6	47855
53215	5	126746	6	47801
53216	5	126748	4	47879
53217	5	126753	6	14525
53218	4	126756	5	43367
53219	5	126759	5	47795
53220	5	126760	1	47880
53221	5	126761	1	47773
53222	5	126761	4	47773
53223	5	126763	6	11169
53224	4	126766	1	28512
53225	4	126768	5	44430
53226	5	126769	1	37781
53227	5	126770	7	20103
53228	3	126770	2	20103
53229	5	126772	4	47955
53230	4	126774	2	3647
53231	5	126775	4	27825
53232	4	126776	1	47764
53233	5	126777	4	25881
53234	5	126777	2	25881
53235	5	126778	6	15343
53236	3	126779	7	47806
53237	5	126782	4	25781
53238	4	126785	3	47769
53239	4	126786	4	29632
53240	5	126788	7	22595
53241	3	126792	7	11541
53242	3	126798	2	38787
53243	5	126800	6	13320
53244	5	126805	4	47749
53245	3	126807	5	26577
53246	3	126813	7	47856
53247	3	126814	2	15275
53248	5	126815	7	28362
53249	3	126816	7	47952
53250	4	126817	7	7360
53251	5	126824	2	9567
53252	5	126828	4	47901
53253	5	126828	2	47901
53254	3	126829	2	2228
53255	5	126832	2	766
53256	3	126835	1	26610
53257	3	126836	5	47869
53258	4	126837	1	30458
53259	5	126838	1	46132
53260	3	126839	5	38278
53261	5	126845	1	29413
53262	3	126846	5	39056
53263	5	126847	5	8558
53264	4	126847	3	8558
53265	5	126850	2	40299
53266	5	126851	7	32269
53267	4	126855	7	25021
53268	5	126856	5	1582
53269	5	126857	3	26173
53270	5	126860	6	46406
53271	3	126861	5	27885
53272	5	126861	2	27885
53273	5	126862	7	34125
53274	4	126866	6	37102
53275	3	126868	1	48064
53276	5	126875	1	48168
53277	5	126876	5	48137
53278	5	126878	4	308
53279	3	126880	1	9833
53280	5	126880	7	9833
53281	3	126882	2	2846
53282	5	126887	3	37673
53283	5	126889	1	11172
53284	3	126890	5	48087
53285	3	126891	4	47989
53286	3	126892	3	4428
53287	5	126893	4	31957
53288	2	126896	4	47976
53289	3	126897	5	32200
53290	5	126898	2	48042
53291	3	126903	7	44248
53292	4	126907	3	48122
53293	1	126909	6	47974
53294	5	126910	1	5032
53295	4	126914	3	19711
53296	3	126921	2	47977
53297	4	126922	7	28394
53298	3	126924	3	14859
53299	5	126931	7	27066
53300	4	126934	7	7460
53301	5	126939	3	143
53302	5	126939	4	143
53303	4	126940	3	5701
53304	5	126941	6	9014
53305	5	126948	2	13948
53306	5	126949	1	13377
53307	5	126951	2	17944
53308	4	126952	4	9366
53309	5	126953	1	7653
53310	5	126956	6	8258
53311	3	126956	1	8258
53312	5	126958	2	12053
53313	3	126961	5	47990
53314	3	126965	2	6166
53315	3	126966	3	48081
53316	5	126967	3	3936
53317	4	126970	7	31296
53318	5	126971	5	11789
53319	5	126972	7	31628
53320	3	126975	5	15110
53321	5	126976	6	33125
53322	5	126977	1	48173
53323	4	126978	1	47964
53324	5	126979	6	48041
53325	3	126983	5	21628
53326	3	126984	6	20033
53327	5	126986	5	17444
53328	5	126987	1	48124
53329	4	126988	6	34406
53330	5	126992	5	48037
53331	5	126993	7	48104
53332	5	126994	2	2473
53333	5	126996	7	13635
53334	3	126997	3	6142
53335	3	126999	7	48147
53336	3	126999	3	48147
53337	5	127000	1	48044
53338	4	127001	1	19422
53339	2	127005	3	3534
53340	3	127006	5	48120
53341	5	127008	2	7803
53342	5	127011	4	44498
53343	3	127013	7	16372
53344	3	127014	7	48141
53345	2	127015	1	3364
53346	3	127017	2	17988
53347	5	127018	6	47973
53348	3	127019	1	32410
53349	5	127021	6	5735
53350	5	127022	6	6567
53351	5	127028	5	42352
53352	4	127029	7	38956
53353	5	127030	2	18057
53354	4	127031	5	30758
53355	4	127031	7	30758
53356	4	127032	6	20992
53357	5	127034	1	48040
53358	4	127036	7	48171
53359	3	127041	6	45269
53360	5	127043	2	3982
53361	1	127044	4	48108
53362	5	127045	7	31307
53363	5	127047	4	26189
53364	4	127048	2	11973
53365	5	127052	2	46722
53366	5	127053	7	48053
53367	3	127054	5	12523
53368	3	127055	5	14929
53369	5	127060	2	43155
53370	5	127061	3	13429
53371	5	127062	1	48063
53372	3	127063	7	5850
53373	5	127063	6	5850
53374	5	127069	6	1649
53375	5	127070	6	18983
53376	5	127072	4	1910
53377	5	127073	6	26187
53378	5	127078	3	34250
53379	4	127079	7	13561
53380	4	127082	2	48073
53381	3	127083	6	18668
53382	4	127084	7	43866
53383	3	127087	7	32629
53384	4	127088	3	15971
53385	4	127092	2	26965
53386	5	127093	1	43630
53387	5	127097	6	26963
53388	5	127097	3	26963
53389	5	127098	2	36347
53390	5	127099	7	43425
53391	5	127100	6	45146
53392	5	127106	2	45809
53393	5	127108	4	48046
53394	5	127114	4	16505
53395	5	127115	6	24583
53396	4	127120	7	47971
53397	5	127121	2	42841
53398	3	127122	5	48151
53399	5	127123	2	47962
53400	5	127133	6	43770
53401	5	127142	6	10622
53402	5	127142	4	10622
53403	5	127143	5	48112
53404	3	127143	3	48112
53405	1	127144	6	40667
53406	5	127145	1	28532
53407	4	127147	2	25015
53408	5	127148	7	34369
53409	5	127153	4	11317
53410	4	127155	7	48170
53411	5	127160	1	47840
53412	4	127161	5	7217
53413	5	127162	4	20573
53414	5	127163	1	43673
53415	4	127166	5	33128
53416	5	127175	6	4586
53417	3	127176	1	31509
53418	5	127179	1	44183
53419	5	127181	4	48178
53420	2	127184	6	48159
53421	3	127187	7	48032
53422	5	127189	1	3245
53423	5	127194	1	6974
53424	5	127196	1	9737
53425	3	127198	5	48153
53426	4	127201	3	48050
53427	5	127202	3	7188
53428	5	127203	4	48092
53429	4	127206	4	32280
53430	5	127208	4	48070
53431	5	127216	2	36672
53432	5	127216	7	36672
53433	5	127217	6	36888
53434	4	127220	3	42755
53435	5	127221	2	44832
53436	5	127225	2	33769
53437	4	127226	3	34803
53438	3	127227	5	30480
53439	5	127228	2	24587
53440	5	127229	5	48177
53441	5	127230	3	9644
53442	4	127232	6	48075
53443	4	127236	7	24903
53444	4	127237	4	48157
53445	5	127238	6	47975
53446	4	127241	5	31759
53447	5	127242	5	10311
53448	5	127243	7	47991
53449	4	127244	4	48111
53450	3	127246	7	8225
53451	3	127249	6	33175
53452	4	127253	7	22521
53453	4	127253	3	22521
53454	5	127257	7	4714
53455	4	127258	7	6977
53456	2	127263	4	8448
53457	4	127266	7	45931
53458	5	127267	7	15116
53459	3	127267	5	15116
53460	5	127268	6	48097
53461	5	127272	2	48061
53462	4	127273	7	4666
53463	5	127287	7	18797
53464	5	127299	4	12236
53465	5	127303	5	44503
53466	3	127304	6	26461
53467	5	127305	6	749
53468	4	127306	4	46611
53469	5	127307	3	21671
53470	5	127309	2	11624
53471	3	127311	3	44895
53472	5	127312	1	34368
53473	4	127317	5	2878
53474	5	127319	7	48018
53475	4	127320	7	48180
53476	5	127321	7	48010
53477	5	127323	4	48085
53478	5	127325	6	38970
53479	5	127326	7	47604
53480	3	127327	5	6228
53481	5	127331	4	26868
53482	4	127332	2	866
53483	5	127333	6	48062
53484	5	127336	5	6366
53485	3	127339	2	48058
53486	5	127340	4	15385
53487	5	127341	6	26428
53488	3	127344	7	48007
53489	2	127345	6	7743
53490	5	127347	7	45853
53491	3	127349	6	10525
53492	5	127350	7	11666
53493	3	127350	3	11666
53494	3	127352	1	19776
53495	5	127356	2	38074
53496	4	127358	7	48072
53497	3	127358	2	48072
53498	3	127359	1	2702
53499	4	127362	6	48011
53500	5	127364	4	7896
53501	5	127365	2	33596
53502	3	127370	1	48016
53503	4	127371	7	15236
53504	4	127380	3	26659
53505	5	127381	7	40611
53506	1	127385	6	1445
53507	5	127389	4	48049
53508	5	127394	2	48034
53509	4	127395	2	16834
53510	5	127396	4	3181
53511	3	127398	4	48110
53512	5	127399	7	36021
53513	4	127401	3	8543
53514	3	127403	5	6439
53515	4	127406	7	48132
53516	5	127407	2	4459
53517	5	127410	5	26477
53518	5	127412	2	43655
53519	5	127413	4	26909
53520	3	127415	1	48091
53521	4	127417	5	48057
53522	4	127418	3	27625
53523	5	127419	6	48086
53524	4	127427	7	28880
53525	4	127429	3	47697
53526	3	127432	1	43768
53527	4	127436	2	26065
53528	5	127437	7	11402
53529	4	127437	5	11402
53530	3	127440	2	41274
53531	5	127441	4	17825
53532	2	127443	4	6591
53533	4	127444	6	830
53534	4	127446	4	1433
53535	4	127449	3	68
53536	4	127451	6	43971
53537	3	127458	2	21
53538	5	127459	4	32097
53539	5	127462	5	11550
53540	3	127463	1	42089
53541	2	127464	4	18676
53542	4	127466	5	4197
53543	5	127467	7	41898
53544	4	127469	1	23128
53545	5	127472	6	8631
53546	4	127473	3	25214
53547	5	127475	2	48035
53548	3	127478	3	39579
53549	4	127482	4	29814
53550	5	127483	6	21511
53551	3	127489	3	48022
53552	4	127491	7	28930
53553	3	127493	4	29423
53554	4	127494	4	24409
53555	3	127496	5	48156
53556	5	127497	1	25688
53557	5	127497	6	25688
53558	5	127498	5	25509
53559	4	127501	1	45012
53560	5	127502	6	3711
53561	5	127504	7	5094
53562	4	127505	4	48056
53563	5	127506	6	4607
53564	5	127508	3	46088
53565	4	127509	7	9550
53566	4	127513	7	757
53567	5	127514	5	8487
53568	5	127515	5	48126
53569	5	127516	6	42167
53570	4	127517	7	35510
53571	5	127519	6	43081
53572	5	127521	4	48047
53573	5	127523	6	48109
53574	4	127524	5	9757
53575	3	127534	7	23493
53576	5	127535	1	48146
53577	2	127536	6	45651
53578	5	127538	6	48055
53579	3	127539	7	47963
53580	5	127547	2	37754
53581	1	127552	6	48106
53582	5	127553	6	15653
53583	5	127555	1	44261
53584	4	127556	2	48155
53585	5	127560	4	26580
53586	4	127562	7	29919
53587	5	127562	3	29919
53588	5	127563	2	15067
53589	5	127565	6	41206
53590	4	127567	4	47475
53591	5	127569	1	28503
53592	3	127570	6	46459
53593	5	127572	4	48002
53594	4	127579	7	47984
53595	5	127580	6	32620
53596	4	127582	7	32622
53597	5	127587	5	32897
53598	5	127590	6	17788
53599	5	127593	7	47972
53600	5	127594	3	11334
53601	5	127595	4	48131
53602	3	127596	2	48084
53603	3	127597	1	32300
53604	3	127598	1	11759
53605	5	127599	6	33789
53606	5	127604	5	44798
53607	5	127605	4	30903
53608	5	127606	4	21121
53609	4	127607	1	32128
53610	5	127610	6	35350
53611	5	127613	3	15834
53612	4	127615	1	48285
53613	5	127616	5	22738
53614	5	127618	6	43245
53615	2	127622	1	48383
53616	5	127625	7	48189
53617	3	127626	5	7412
53618	3	127628	2	47812
53619	4	127630	1	48342
53620	5	127634	2	22395
53621	5	127647	5	8788
53622	5	127649	2	23386
53623	5	127653	3	17055
53624	3	127655	2	48276
53625	5	127658	3	48385
53626	2	127660	6	43725
53627	4	127664	4	48191
53628	5	127667	4	13469
53629	5	127668	5	44094
53630	5	127669	3	1176
53631	4	127671	7	46545
53632	5	127674	7	47497
53633	5	127677	4	48438
53634	3	127680	7	11438
53635	4	127684	7	17652
53636	3	127693	7	48198
53637	3	127694	1	16796
53638	5	127695	4	8285
53639	3	127698	5	48439
53640	4	127699	5	23313
53641	5	127701	6	48254
53642	5	127705	6	10147
53643	5	127707	4	5387
53644	4	127710	2	10765
53645	5	127711	4	36922
53646	4	127712	5	2560
53647	5	127713	5	48384
53648	5	127716	2	1896
53649	3	127722	7	40576
53650	3	127723	7	16468
53651	4	127725	2	48340
53652	5	127725	1	48340
53653	1	127734	6	34473
53654	5	127740	4	27596
53655	5	127742	6	12855
53656	4	127746	2	31624
53657	3	127747	2	38977
53658	5	127748	4	37167
53659	5	127753	2	48394
53660	4	127754	7	48344
53661	5	127755	2	38157
53662	5	127759	6	13740
53663	5	127760	6	31186
53664	4	127760	5	31186
53665	5	127764	5	48401
53666	4	127765	4	5183
53667	3	127767	5	48324
53668	5	127768	6	212
53669	5	127771	3	7456
53670	5	127775	6	48414
53671	5	127776	4	2116
53672	5	127777	7	45124
53673	5	127779	3	28952
53674	4	127784	5	8352
53675	5	127785	3	48319
53676	5	127787	6	21257
53677	5	127788	2	25002
53678	3	127790	1	19088
53679	5	127793	3	4967
53680	5	127794	4	17398
53681	5	127794	7	17398
53682	4	127795	7	8313
53683	3	127796	2	36380
53684	5	127798	5	12185
53685	4	127803	4	38578
53686	5	127804	7	47509
53687	5	127805	6	5550
53688	3	127806	7	23785
53689	5	127808	3	16033
53690	5	127810	3	30168
53691	5	127811	1	48311
53692	4	127815	1	48205
53693	4	127817	1	7609
53694	5	127819	6	48431
53695	4	127820	2	25608
53696	3	127823	1	48360
53697	3	127823	3	48360
53698	5	127824	7	38231
53699	5	127825	7	14094
53700	4	127830	7	38397
53701	4	127836	1	33096
53702	5	127839	5	33873
53703	5	127841	5	45191
53704	5	127842	6	24588
53705	5	127844	4	36385
53706	3	127845	7	25015
53707	5	127846	3	48288
53708	3	127847	5	48243
53709	3	127849	1	20991
53710	5	127850	6	14304
53711	5	127852	1	36980
53712	5	127853	5	27833
53713	5	127855	7	48244
53714	5	127857	4	9814
53715	3	127861	2	33686
53716	4	127861	4	33686
53717	5	127866	5	2837
53718	4	127869	6	23518
53719	4	127872	4	48395
53720	3	127874	4	13073
53721	5	127876	3	23658
53722	5	127876	4	23658
53723	5	127877	2	20077
53724	4	127878	3	47170
53725	5	127880	6	48253
53726	5	127883	6	23555
53727	4	127883	3	23555
53728	4	127887	1	15284
53729	5	127888	6	43331
53730	5	127891	2	6617
53731	5	127893	2	5215
53732	5	127894	2	38050
53733	5	127895	1	47581
53734	4	127895	7	47581
53735	4	127898	7	43553
53736	4	127898	6	43553
53737	3	127899	5	48411
53738	1	127902	6	22949
53739	4	127903	4	45637
53740	5	127905	6	33480
53741	3	127906	5	33168
53742	2	127909	6	48327
53743	4	127910	3	12849
53744	4	127912	7	39711
53745	5	127915	4	33401
53746	2	127919	4	15913
53747	5	127921	7	11154
53748	5	127922	4	48330
53749	5	127924	5	17552
53750	5	127925	5	10758
53751	2	127927	6	10602
53752	5	127928	4	40958
53753	5	127932	2	14039
53754	5	127938	4	44293
53755	5	127944	7	19022
53756	4	127947	5	48202
53757	1	127953	2	48305
53758	5	127958	1	45457
53759	5	127958	5	45457
53760	5	127959	3	22822
53761	5	127959	7	22822
53762	3	127960	7	31789
53763	5	127963	3	8229
53764	1	127964	6	25159
53765	5	127965	5	11721
53766	4	127966	7	48368
53767	4	127966	5	48368
53768	3	127969	5	36866
53769	5	127970	6	48273
53770	5	127973	2	48295
53771	5	127975	3	10466
53772	5	127976	2	48421
53773	4	127976	5	48421
53774	3	127977	7	48211
53775	3	127983	5	6113
53776	2	127984	6	48219
53777	5	127985	5	48353
53778	5	127986	4	39753
53779	5	127987	7	48238
53780	3	127991	4	48226
53781	4	127992	5	40319
53782	4	127994	7	34627
53783	5	127996	7	45473
53784	2	128000	6	48192
53785	1	128001	6	47023
53786	4	128002	1	48415
53787	5	128005	4	13437
53788	4	128008	1	48429
53789	5	128010	1	43669
53790	5	128011	4	48303
53791	5	128013	6	48435
53792	5	128015	1	26270
53793	4	128020	4	48221
53794	5	128020	6	48221
53795	4	128021	7	45452
53796	5	128022	6	32365
53797	1	128027	3	10340
53798	4	128028	7	37341
53799	5	128029	1	24865
53800	5	128030	4	17546
53801	5	128032	6	28453
53802	5	128033	2	48373
53803	4	128035	1	24276
53804	5	128038	6	20158
53805	4	128038	7	20158
53806	3	128040	2	48255
53807	5	128042	6	36359
53808	4	128043	6	40408
53809	5	128044	6	140
53810	4	128047	6	30122
53811	3	128047	3	30122
53812	5	128049	6	31139
53813	4	128050	4	48338
53814	5	128051	4	10850
53815	5	128054	6	45983
53816	1	128060	7	48216
53817	3	128061	6	48201
53818	5	128065	7	48247
53819	4	128066	7	48423
53820	5	128067	4	11932
53821	5	128071	7	5117
53822	5	128072	7	4894
53823	5	128077	2	249
53824	5	128080	7	20320
53825	3	128083	4	48365
53826	4	128084	2	34581
53827	4	128084	3	34581
53828	5	128085	1	43035
53829	5	128086	7	48313
53830	3	128089	5	48234
53831	5	128090	1	17809
53832	5	128095	2	19212
53833	3	128095	7	19212
53834	4	128096	6	19445
53835	4	128097	5	16343
53836	4	128098	7	18065
53837	5	128099	7	48372
53838	2	128101	6	48188
53839	5	128103	5	48318
53840	5	128106	5	10718
53841	5	128108	7	48337
53842	5	128109	7	38630
53843	4	128110	3	48380
53844	5	128115	4	48232
53845	5	128117	5	38229
53846	3	128119	3	48425
53847	5	128120	4	45666
53848	5	128123	5	48326
53849	5	128124	7	9682
53850	4	128124	6	9682
53851	3	128125	5	48256
53852	5	128126	2	15845
53853	1	128127	3	43856
53854	5	128132	4	48217
53855	4	128133	3	21121
53856	3	128135	4	226
53857	5	128139	1	47923
53858	5	128140	4	1569
53859	3	128141	1	48190
53860	3	128145	7	8862
53861	5	128150	6	22995
53862	5	128151	7	4874
53863	3	128152	4	48283
53864	4	128154	4	20439
53865	5	128160	7	12491
53866	4	128164	2	24422
53867	5	128171	4	18541
53868	1	128173	6	48246
53869	2	128174	3	47977
53870	5	128174	4	47977
53871	5	128176	5	21464
53872	3	128178	6	16080
53873	5	128179	6	11239
53874	3	128183	5	42493
53875	3	128184	1	847
53876	3	128186	2	18928
53877	5	128191	3	34163
53878	4	128192	1	48320
53879	2	128194	1	30862
53880	5	128197	7	36447
53881	5	128198	3	45018
53882	4	128199	5	48403
53883	5	128200	7	16342
53884	4	128201	4	12121
53885	4	128204	7	11046
53886	5	128206	4	6962
53887	4	128208	7	16389
53888	5	128210	6	5425
53889	5	128213	7	26615
53890	4	128214	6	26742
53891	5	128214	7	26742
53892	5	128215	4	46049
53893	5	128216	2	44197
53894	5	128217	6	3522
53895	5	128219	1	47047
53896	2	128221	5	48397
53897	3	128222	1	47803
53898	3	128223	4	25279
53899	5	128234	3	270
53900	3	128236	7	23788
53901	5	128238	1	39982
53902	5	128240	2	5104
53903	5	128248	4	1932
53904	5	128249	6	593
53905	5	128250	7	28441
53906	2	128252	4	48274
53907	4	128253	7	29003
53908	5	128255	1	23263
53909	5	128258	6	17837
53910	5	128259	7	38507
53911	5	128260	1	24984
53912	5	128260	7	24984
53913	5	128263	6	48412
53914	5	128263	3	48412
53915	3	128266	4	23939
53916	3	128268	1	34524
53917	5	128269	5	21142
53918	5	128270	2	14057
53919	5	128271	4	7626
53920	5	128274	7	47944
53921	5	128275	7	48197
53922	5	128279	6	48323
53923	5	128280	7	48286
53924	5	128284	4	19566
53925	3	128288	5	32020
53926	5	128290	6	46358
53927	4	128291	5	41818
53928	5	128295	5	48250
53929	5	128298	4	1215
53930	5	128302	1	20136
53931	4	128311	1	21910
53932	4	128312	2	48218
53933	3	128313	5	39891
53934	5	128317	1	11013
53935	5	128320	2	20408
53936	4	128323	7	48293
53937	5	128325	2	34485
53938	2	128329	3	29394
53939	5	128332	6	27313
53940	4	128333	7	24899
53941	4	128337	7	27011
53942	3	128339	5	17532
53943	5	128340	3	7025
53944	4	128341	4	23349
53945	5	128343	1	24688
53946	5	128348	3	16820
53947	5	128350	2	15048
53948	4	128351	1	18125
53949	5	128353	3	21612
53950	3	128360	1	37272
53951	4	128364	1	48731
53952	2	128365	6	16404
53953	4	128374	2	39536
53954	2	128375	5	1324
53955	5	128382	6	8435
53956	5	128383	6	48736
53957	4	128385	7	37515
53958	5	128386	1	48650
53959	5	128387	2	5473
53960	3	128390	5	25696
53961	5	128392	4	48703
53962	5	128394	6	32620
53963	5	128396	6	37217
53964	4	128397	7	31583
53965	5	128399	2	48522
53966	3	128399	7	48522
53967	4	128400	3	21907
53968	5	128403	6	48485
53969	4	128405	5	48511
53970	5	128407	5	35836
53971	4	128412	2	38241
53972	4	128413	5	36853
53973	3	128414	6	24869
53974	3	128415	5	48653
53975	4	128416	6	19851
53976	5	128419	5	46326
53977	4	128420	3	8726
53978	5	128422	2	47989
53979	5	128424	7	25061
53980	5	128428	6	32116
53981	5	128429	6	2820
53982	5	128430	7	48694
53983	4	128433	4	25125
53984	4	128441	5	17075
53985	5	128443	2	36980
53986	4	128445	2	13403
53987	5	128446	2	46837
53988	3	128448	7	45589
53989	5	128449	7	48443
53990	4	128450	3	48698
53991	4	128452	5	8027
53992	4	128453	7	36922
53993	5	128454	7	48745
53994	5	128455	4	48619
53995	5	128457	6	48461
53996	5	128460	2	48521
53997	3	128462	3	46640
53998	3	128463	3	39061
53999	5	128464	2	1207
54000	5	128466	4	2780
54001	5	128468	6	47544
54002	5	128469	7	33227
54003	3	128469	4	33227
54004	1	128471	2	24870
54005	5	128472	3	48509
54006	4	128472	6	48509
54007	5	128477	7	48714
54008	4	128486	7	48595
54009	5	128487	1	48730
54010	4	128488	5	7254
54011	4	128489	5	30609
54012	3	128489	4	30609
54013	3	128490	2	40564
54014	5	128491	2	28893
54015	4	128492	7	39810
54016	5	128492	6	39810
54017	5	128493	5	5839
54018	5	128494	1	44456
54019	5	128496	1	13467
54020	5	128499	3	48295
54021	5	128499	7	48295
54022	4	128502	7	48587
54023	3	128502	4	48587
54024	5	128503	4	48710
54025	5	128504	5	38457
54026	5	128505	2	48598
54027	5	128506	3	15442
54028	5	128510	5	46433
54029	3	128518	2	42798
54030	4	128519	7	8852
54031	5	128521	7	27506
54032	5	128522	6	29974
54033	5	128526	6	35284
54034	5	128529	2	20816
54035	4	128530	1	48727
54036	5	128537	2	24729
54037	5	128541	6	48452
54038	3	128542	5	16498
54039	5	128543	2	24690
54040	5	128544	2	48475
54041	5	128546	2	48535
54042	4	128547	4	3701
54043	5	128549	2	19619
54044	5	128550	6	36925
54045	5	128551	2	38732
54046	1	128557	6	48457
54047	3	128558	5	48638
54048	5	128559	6	14927
54049	5	128565	4	39642
54050	5	128566	4	45152
54051	5	128567	2	18828
54052	3	128569	3	12053
54053	5	128570	2	30976
54054	5	128571	6	23384
54055	4	128571	5	23384
54056	3	128575	4	28456
54057	5	128578	6	48704
54058	5	128578	3	48704
54059	2	128582	6	44354
54060	3	128585	7	5671
54061	5	128587	1	48459
54062	5	128588	7	4047
54063	5	128590	3	33334
54064	3	128592	5	9114
54065	3	128594	2	24959
54066	2	128599	4	14593
54067	5	128600	6	48526
54068	5	128601	6	32886
54069	5	128603	3	5097
54070	3	128607	3	9870
54071	4	128609	7	48618
54072	3	128609	1	48618
54073	5	128611	7	33962
54074	5	128614	7	6439
54075	5	128620	2	762
54076	4	128622	2	48625
54077	5	128623	2	29666
54078	5	128625	2	48680
54079	4	128628	7	37870
54080	3	128631	4	37419
54081	5	128633	3	48621
54082	3	128638	5	11455
54083	4	128641	5	48445
54084	1	128641	6	48445
54085	4	128643	7	48611
54086	5	128644	2	3774
54087	4	128644	5	3774
54088	5	128646	4	41772
54089	4	128651	4	33667
54090	3	128657	1	39666
54091	5	128660	2	45411
54092	5	128662	2	40971
54093	5	128663	6	48645
54094	5	128665	2	19931
54095	5	128666	3	44258
54096	5	128667	2	21263
54097	5	128667	1	21263
54098	5	128677	6	44327
54099	5	128678	2	40462
54100	5	128679	6	48686
54101	5	128680	6	43245
54102	5	128682	5	32133
54103	1	128684	6	44828
54104	3	128686	3	6127
54105	2	128690	4	48523
54106	3	128693	4	48442
54107	5	128695	5	48613
54108	5	128697	2	11979
54109	3	128699	5	48606
54110	3	128700	3	19049
54111	3	128700	7	19049
54112	4	128702	5	27583
54113	3	128703	1	44985
54114	5	128704	6	38350
54115	4	128706	6	10388
54116	2	128707	6	48458
54117	1	128710	6	28808
54118	4	128713	7	48516
54119	4	128715	5	48529
54120	5	128716	4	9391
54121	3	128717	5	40885
54122	3	128718	3	44361
54123	5	128724	6	44881
54124	5	128724	5	44881
54125	4	128727	2	16549
54126	5	128729	1	48639
54127	5	128735	6	48725
54128	5	128736	4	30698
54129	5	128737	7	48631
54130	3	128739	5	6737
54131	5	128740	2	48492
54132	4	128741	1	802
54133	5	128743	3	14284
54134	4	128744	6	48560
54135	4	128744	2	48560
54136	5	128747	3	44084
54137	5	128748	4	868
54138	3	128749	5	48450
54139	5	128754	6	48720
54140	1	128756	6	48498
54141	3	128763	3	26728
54142	5	128765	4	48489
54143	2	128768	2	32120
54144	5	128772	6	32054
54145	5	128774	4	48693
54146	3	128774	5	48693
54147	5	128779	2	43436
54148	5	128783	6	23288
54149	4	128784	3	26899
54150	4	128785	1	48657
54151	5	128786	2	26003
54152	5	128789	6	48713
54153	5	128790	6	519
54154	5	128792	6	23581
54155	4	128794	5	5930
54156	5	128795	6	31172
54157	5	128796	6	48558
54158	4	128797	3	17680
54159	2	128798	7	22360
54160	5	128801	6	8755
54161	4	128802	5	25717
54162	5	128803	2	46078
54163	2	128804	4	48557
54164	3	128806	1	33250
54165	5	128809	3	2962
54166	5	128810	7	41696
54167	5	128812	4	1415
54168	3	128814	5	17901
54169	3	128817	5	48708
54170	5	128818	6	24880
54171	4	128820	2	29637
54172	5	128823	4	12394
54173	1	128826	6	36349
54174	4	128828	4	45772
54175	5	128829	7	17391
54176	3	128832	3	48612
54177	3	128833	7	4287
54178	5	128837	7	48476
54179	5	128838	6	48688
54180	5	128841	1	42883
54181	5	128842	5	23473
54182	4	128847	2	48467
54183	5	128849	2	34681
54184	1	128851	6	22570
54185	3	128852	6	47693
54186	5	128854	6	48566
54187	5	128858	7	24389
54188	4	128860	3	36966
54189	4	128861	5	48608
54190	3	128862	4	38999
54191	3	128862	3	38999
54192	5	128864	4	44376
54193	5	128873	2	7945
54194	4	128874	4	29052
54195	5	128875	7	34995
54196	5	128876	1	48531
54197	5	128879	2	10495
54198	1	128881	2	25299
54199	4	128881	3	25299
54200	5	128885	2	33654
54201	5	128887	3	45821
54202	5	128889	6	23676
54203	4	128890	1	17502
54204	5	128893	4	16501
54205	4	128894	1	48466
54206	5	128895	6	48460
54207	5	128901	6	6341
54208	5	128903	4	48679
54209	5	128906	7	48534
54210	4	128907	5	48690
54211	3	128908	5	44522
54212	5	128909	4	44223
54213	4	128911	2	48663
54214	4	128913	5	38023
54215	4	128916	7	48494
54216	1	128917	6	25770
54217	5	128918	1	42031
54218	2	128919	6	7907
54219	4	128922	4	48470
54220	5	128923	4	2553
54221	5	128924	5	27202
54222	5	128925	6	10604
54223	3	128927	4	17747
54224	3	128929	5	17304
54225	3	128929	7	17304
54226	4	128931	5	14553
54227	4	128936	6	15057
54228	4	128938	6	42342
54229	5	128942	7	655
54230	3	128944	7	12102
54231	4	128945	7	32259
54232	5	128947	6	24379
54233	2	128949	4	48647
54234	5	128950	4	48505
54235	3	128955	1	48575
54236	5	128957	4	48524
54237	3	128958	7	782
54238	1	128969	6	17551
54239	4	128970	1	48702
54240	4	128972	6	48740
54241	4	128974	5	8977
54242	5	128975	2	4824
54243	5	128976	7	48520
54244	1	128979	6	40016
54245	5	128983	4	43909
54246	5	128984	2	41909
54247	5	128986	5	30577
54248	4	128991	2	48547
54249	5	128991	3	48547
54250	4	128992	5	10256
54251	5	128993	7	23706
54252	4	128994	7	48552
54253	5	128994	5	48552
54254	3	129000	7	10310
54255	5	129001	7	48642
54256	5	129004	1	4714
54257	5	129005	4	40393
54258	4	129006	2	26542
54259	5	129009	5	8635
54260	3	129012	7	8121
54261	5	129015	2	48700
54262	5	129019	7	48681
54263	5	129020	4	48564
54264	5	129024	6	8064
54265	5	129025	4	14432
54266	4	129026	7	27790
54267	3	129027	7	42452
54268	5	129028	7	39690
54269	3	129030	2	28715
54270	5	129035	4	13708
54271	5	129037	5	48669
54272	4	129042	7	44573
54273	5	129045	1	48739
54274	4	129047	1	48517
54275	4	129053	7	14928
54276	4	129058	6	48493
54277	5	129060	6	19949
54278	5	129061	7	48503
54279	5	129063	4	48536
54280	5	129064	4	46033
54281	4	129066	6	32802
54282	5	129068	6	40614
54283	5	129070	1	48709
54284	5	129072	6	30271
54285	4	129075	7	48729
54286	5	129076	6	42117
54287	4	129076	1	42117
54288	5	129081	3	48448
54289	4	129081	7	48448
54290	5	129083	6	6104
54291	5	129087	3	4062
54292	5	129091	6	48197
54293	5	129094	1	5338
54294	1	129096	6	48696
54295	5	129097	5	41992
54296	3	129102	1	31737
54297	5	129103	7	6616
54298	5	129104	2	48540
54299	5	129105	6	6054
54300	5	129114	7	38922
54301	5	129114	1	38922
54302	5	129115	6	11192
54303	5	129119	5	41493
54304	5	129122	7	48691
54305	5	129124	6	32713
54306	4	129125	3	48506
54307	5	129126	4	48692
54308	3	129128	7	11542
54309	5	129131	7	48737
54310	3	129135	7	22308
54311	5	129137	5	5891
54312	5	129138	7	48583
54313	3	129139	4	48487
54314	4	129142	5	19607
54315	5	129144	7	6979
54316	4	129146	5	48733
54317	5	129147	3	13068
54318	5	129149	4	5817
54319	5	129153	6	26600
54320	5	129154	2	48601
54321	3	129155	4	23663
54322	5	129156	6	48512
54323	4	129160	3	7212
54324	5	129160	1	7212
54325	3	129164	7	19183
54326	3	129167	2	48507
54327	5	129168	2	42958
54328	4	129170	6	42952
54329	5	129171	4	38324
54330	3	129173	1	48617
54331	5	129174	6	19398
54332	4	129177	4	26428
54333	3	129179	2	16839
54334	5	129180	5	27426
54335	5	129181	6	5000
54336	5	129187	4	3399
54337	5	129196	7	48504
54338	5	129197	6	8044
54339	5	129203	4	48571
54340	5	129205	3	48643
54341	4	129208	5	14845
54342	5	129217	2	26740
54343	5	129218	3	23128
54344	4	129219	3	48747
54345	5	129227	6	19313
54346	4	129230	7	48472
54347	5	129231	7	41150
54348	4	129233	6	40789
54349	5	129238	4	40794
54350	5	129240	1	35154
54351	5	129241	7	48541
54352	5	129243	5	21601
54353	1	129247	6	19279
54354	5	129250	2	48490
54355	4	129251	4	48591
54356	4	129252	1	48589
54357	4	129256	3	48510
54358	3	129261	5	48497
54359	4	129262	6	29382
54360	5	129264	6	37398
54361	5	129265	2	26521
54362	1	129268	6	48674
54363	5	129271	6	14610
54364	4	129272	1	48543
54365	4	129274	4	48616
54366	5	129275	2	48495
54367	5	129277	6	8600
54368	5	129278	6	48630
54369	5	129280	1	22941
54370	5	129281	4	11586
54371	5	129283	4	25926
54372	3	129284	2	40157
54373	5	129289	4	8167
54374	4	129290	1	30162
54375	5	129290	2	30162
54376	5	129292	4	44012
54377	5	129294	4	18461
54378	4	129295	6	48579
54379	3	129296	3	19300
54380	5	129297	6	16087
54381	5	129303	6	47580
54382	3	129303	7	47580
54383	4	129304	7	18106
54384	1	129311	6	28333
54385	3	129312	2	45720
54386	5	129316	7	12231
54387	5	129320	2	32325
54388	3	129321	1	3318
54389	5	129323	4	48806
54390	4	129328	2	48797
54391	2	129331	6	48781
54392	5	129333	6	48926
54393	4	129334	5	49036
54394	3	129335	4	26006
54395	5	129343	5	49025
54396	5	129345	2	5730
54397	5	129347	2	48835
54398	5	129349	3	23478
54399	5	129349	7	23478
54400	3	129350	7	23164
54401	5	129353	5	29880
54402	1	129359	6	46326
54403	5	129360	2	48878
54404	3	129361	5	15449
54405	5	129364	3	48757
54406	4	129368	6	41553
54407	5	129369	4	48790
54408	3	129372	6	7070
54409	5	129376	4	9045
54410	5	129385	4	32399
54411	4	129386	1	40146
54412	5	129392	2	22900
54413	2	129399	3	40089
54414	3	129400	4	25649
54415	5	129402	4	28616
54416	5	129407	2	41614
54417	4	129408	1	38456
54418	5	129408	5	38456
54419	4	129416	5	49035
54420	4	129418	4	3719
54421	5	129423	3	46993
54422	4	129424	7	33845
54423	1	129427	6	43266
54424	4	129428	7	3682
54425	5	129435	7	23241
54426	5	129436	4	43129
54427	3	129437	7	11603
54428	5	129442	7	48928
54429	5	129444	4	5580
54430	5	129445	2	48801
54431	4	129445	3	48801
54432	4	129446	6	31456
54433	5	129451	6	43636
54434	2	129452	6	6015
54435	4	129455	5	37358
54436	3	129459	2	26642
54437	5	129461	2	15594
54438	5	129462	2	7803
54439	4	129463	5	48933
54440	5	129464	7	27979
54441	3	129465	5	42154
54442	4	129466	6	18546
54443	5	129469	1	28230
54444	5	129470	2	25474
54445	5	129472	2	24040
54446	5	129473	4	725
54447	5	129476	5	14362
54448	3	129477	3	48767
54449	3	129478	7	35729
54450	5	129479	2	26709
54451	5	129481	6	27152
54452	4	129483	5	48942
54453	5	129484	5	16136
54454	1	129486	6	6591
54455	4	129487	4	45806
54456	4	129491	2	27721
54457	2	129492	3	23625
54458	1	129496	4	43447
54459	5	129498	7	48997
54460	5	129500	3	24590
54461	4	129508	5	48970
54462	4	129508	6	48970
54463	4	129509	1	8355
54464	4	129509	5	8355
54465	1	129510	1	1415
54466	4	129512	1	48890
54467	4	129514	2	48773
54468	5	129515	3	5654
54469	5	129517	2	48315
54470	5	129518	7	34388
54471	5	129521	5	2651
54472	2	129524	3	48872
54473	5	129526	1	20284
54474	5	129528	4	49013
54475	4	129529	6	21866
54476	1	129533	6	48916
54477	3	129535	5	48391
54478	5	129536	3	48755
54479	5	129538	4	23600
54480	5	129540	2	19771
54481	3	129540	7	19771
54482	5	129541	7	49023
54483	4	129542	5	48936
54484	5	129544	7	32434
54485	3	129545	4	1656
54486	5	129546	4	48803
54487	3	129546	5	48803
54488	5	129547	4	49007
54489	3	129549	7	49000
54490	4	129552	5	11849
54491	5	129553	6	13564
54492	4	129555	5	49003
54493	3	129555	7	49003
54494	5	129558	3	48884
54495	3	129559	1	45739
54496	4	129562	1	48888
54497	4	129563	7	48857
54498	5	129565	2	45659
54499	3	129567	5	46096
54500	3	129568	5	48829
54501	3	129569	7	31077
54502	3	129570	3	44719
54503	5	129571	7	48979
54504	5	129573	1	13413
54505	5	129574	2	48830
54506	3	129575	5	36324
54507	5	129579	7	47167
54508	5	129580	6	48877
54509	5	129581	1	49004
54510	5	129582	6	1183
54511	5	129582	7	1183
54512	5	129583	1	8152
54513	5	129584	7	48785
54514	5	129587	4	256
54515	3	129588	2	32805
54516	5	129589	5	24971
54517	4	129590	1	15798
54518	5	129591	1	48941
54519	3	129592	7	8473
54520	4	129594	7	49010
54521	5	129595	1	907
54522	5	129596	4	46754
54523	5	129600	6	17952
54524	5	129607	2	8391
54525	4	129608	6	17654
54526	5	129610	1	44626
54527	4	129612	2	5426
54528	3	129613	1	48811
54529	5	129615	2	43823
54530	4	129616	4	48999
54531	3	129617	5	39229
54532	3	129622	7	48759
54533	4	129623	5	48985
54534	5	129624	2	41108
54535	3	129629	5	48964
54536	4	129631	3	40285
54537	5	129633	3	47924
54538	5	129638	5	18272
54539	3	129639	5	48965
54540	4	129643	7	42485
54541	5	129645	2	48930
54542	5	129648	7	27592
54543	5	129651	6	42091
54544	4	129652	4	29929
54545	4	129652	2	29929
54546	4	129656	4	48778
54547	5	129659	6	48753
54548	5	129660	4	1431
54549	5	129665	1	8583
54550	5	129667	6	14698
54551	5	129668	1	2848
54552	3	129669	2	43202
54553	4	129672	2	48845
54554	5	129673	6	4455
54555	5	129675	6	48956
54556	5	129676	7	23153
54557	5	129677	3	8632
54558	3	129678	2	3280
54559	3	129680	5	48784
54560	5	129682	6	14782
54561	5	129687	7	25246
54562	5	129689	3	49026
54563	4	129690	4	49018
54564	3	129694	3	25648
54565	3	129696	7	48796
54566	5	129698	2	19396
54567	5	129701	2	8877
54568	5	129705	5	27769
54569	4	129707	3	15334
54570	4	129707	7	15334
54571	5	129708	5	25108
54572	3	129711	5	48840
54573	4	129712	2	34238
54574	4	129713	7	10008
54575	5	129713	2	10008
54576	4	129714	7	1380
54577	2	129717	4	5047
54578	5	129718	4	48880
54579	4	129720	1	20556
54580	4	129721	7	39745
54581	4	129725	3	48853
54582	5	129730	6	26849
54583	4	129730	3	26849
54584	5	129731	1	44097
54585	5	129732	7	11559
54586	3	129733	7	25850
54587	4	129736	7	42899
54588	4	129738	4	25075
54589	5	129739	3	133
54590	4	129740	5	48886
54591	4	129742	1	832
54592	5	129744	4	30298
54593	4	129745	5	14633
54594	4	129746	3	27329
54595	5	129748	6	12022
54596	3	129750	5	36517
54597	4	129752	4	26884
54598	3	129753	4	11395
54599	5	129755	1	48266
54600	5	129757	6	15982
54601	3	129768	4	39410
54602	3	129769	5	17671
54603	4	129773	5	48868
54604	5	129774	6	14668
54605	3	129778	7	48762
54606	4	129784	6	48780
54607	3	129785	7	48906
54608	3	129787	7	7227
54609	5	129788	7	27701
54610	1	129789	6	26766
54611	3	129791	7	11029
54612	5	129796	6	5668
54613	3	129798	7	48852
54614	4	129798	3	48852
54615	3	129803	7	44537
54616	2	129804	1	19916
54617	5	129812	2	12369
54618	4	129816	1	48924
54619	5	129817	6	8211
54620	5	129818	7	14656
54621	4	129821	7	48994
54622	5	129821	2	48994
54623	3	129823	7	19862
54624	4	129824	5	9214
54625	3	129825	6	48871
54626	4	129826	7	38961
54627	4	129828	4	30567
54628	5	129830	4	10142
54629	5	129837	1	34077
54630	4	129838	5	16001
54631	5	129840	5	48920
54632	5	129845	6	17226
54633	5	129846	7	33629
54634	5	129847	2	48792
54635	4	129850	1	16549
54636	5	129853	6	2307
54637	5	129855	3	17702
54638	3	129861	5	14481
54639	5	129868	7	1424
54640	4	129869	3	48820
54641	5	129871	6	2735
54642	5	129872	7	24364
54643	3	129872	5	24364
54644	5	129875	3	48810
54645	5	129876	7	49022
54646	4	129882	3	48769
54647	5	129884	6	49021
54648	5	129885	7	715
54649	4	129889	4	18587
54650	4	129890	1	1713
54651	4	129893	3	47661
54652	3	129896	1	8247
54653	5	129898	4	778
54654	4	129901	5	29932
54655	5	129905	5	42666
54656	4	129910	7	16152
54657	5	129912	6	12532
54658	3	129920	2	9630
54659	4	129921	5	48892
54660	5	129922	4	9271
54661	4	129927	2	13772
54662	3	129928	7	7931
54663	5	129928	3	7931
54664	5	129931	5	28755
54665	4	129933	4	36846
54666	5	129934	4	48843
54667	5	129941	2	45736
54668	5	129941	5	45736
54669	3	129942	6	48921
54670	3	129945	3	48816
54671	5	129948	1	12905
54672	4	129950	5	48943
54673	4	129952	2	25310
54674	3	129955	1	48869
54675	2	129959	5	2311
54676	3	129961	3	26489
54677	1	129964	2	14660
54678	5	129967	2	31309
54679	5	129969	7	5669
54680	3	129971	1	30382
54681	4	129973	1	20215
54682	2	129974	4	16387
54683	3	129978	3	30108
54684	3	129993	3	8230
54685	5	129995	6	43195
54686	2	129997	6	4193
54687	5	130000	2	36812
54688	3	130005	7	48800
54689	3	130008	5	18871
54690	5	130009	1	48821
54691	3	130013	6	49001
54692	5	130018	7	43717
54693	4	130020	7	48914
54694	4	130022	4	15696
54695	5	130031	2	30104
54696	5	130032	2	41926
54697	5	130035	3	33994
54698	5	130035	6	33994
54699	3	130038	2	14913
54700	4	130043	7	13277
54701	5	130045	5	48946
54702	5	130047	5	48858
54703	5	130049	4	17641
54704	5	130053	1	16613
54705	5	130055	2	44685
54706	3	130059	1	38094
54707	4	130060	3	35291
54708	5	130065	7	43320
54709	5	130066	4	282
54710	5	130067	7	4196
54711	3	130068	7	49017
54712	5	130070	7	46315
54713	5	130071	7	2665
54714	5	130074	6	23350
54715	5	130075	2	42500
54716	5	130076	7	23925
54717	5	130076	2	23925
54718	5	130079	6	25928
54719	4	130086	6	28283
54720	5	130087	5	25519
54721	4	130090	5	48865
54722	5	130092	6	12224
54723	5	130095	2	32152
54724	5	130103	2	822
54725	5	130105	7	46576
54726	3	130107	5	34229
54727	3	130109	5	17926
54728	3	130112	7	4079
54729	5	130113	3	48952
54730	5	130116	7	48754
54731	4	130119	6	292
54732	5	130121	6	32097
54733	4	130123	1	48923
54734	5	130129	6	49020
54735	5	130135	5	35403
54736	1	130136	5	48940
54737	5	130137	2	30771
54738	5	130143	2	19711
54739	4	130145	2	48978
54740	5	130149	1	49005
54741	3	130153	7	44750
54742	2	130157	4	36320
54743	4	130158	5	40047
54744	4	130159	7	47837
54745	5	130164	4	48948
54746	4	130166	4	10446
54747	5	130169	4	21515
54748	4	130171	6	35079
54749	4	130173	4	14775
54750	4	130174	4	13149
54751	5	130175	7	3352
54752	5	130179	1	19296
54753	5	130180	1	23365
54754	2	130182	2	48774
54755	4	130184	2	29588
54756	5	130186	1	23270
54757	5	130188	4	48841
54758	3	130190	5	39870
54759	4	130191	1	21561
54760	5	130192	6	48863
54761	5	130192	7	48863
54762	4	130195	7	12169
54763	5	130196	3	4809
54764	5	130197	6	15622
54765	3	130198	7	26127
54766	5	130199	6	17365
54767	3	130201	2	18549
54768	5	130205	2	48955
54769	5	130206	3	39481
54770	3	130207	4	48951
54771	3	130214	4	37718
54772	5	130215	6	626
54773	3	130225	4	2821
54774	4	130226	5	23908
54775	5	130228	6	48919
54776	4	130231	1	8441
54777	5	130232	6	9367
54778	5	130235	6	48982
54779	5	130242	2	5183
54780	5	130244	7	25493
54781	3	130245	1	48934
54782	4	130250	6	7027
54783	5	130251	4	2151
54784	4	130252	6	32777
54785	5	130253	2	48980
54786	4	130255	5	11006
54787	5	130256	7	48731
54788	5	130258	6	39925
54789	5	130261	3	41219
54790	4	130261	1	41219
54791	5	130262	6	8866
54792	4	130264	4	48889
54793	1	130267	6	7526
54794	5	130269	6	45083
54795	5	130271	6	48756
54796	5	130273	2	48779
54797	3	130273	7	48779
54798	5	130275	6	19691
54799	4	130280	3	23280
54800	3	130284	5	48974
54801	4	130285	1	48968
54802	2	130290	6	48861
54803	3	130297	4	48961
54804	5	130301	1	48931
54805	1	130303	2	41386
54806	3	130308	5	18612
54807	4	130313	5	48983
54808	5	130317	1	38401
54809	5	130319	3	32101
54810	3	130320	4	48909
54811	4	130324	1	25571
54812	5	130325	4	49033
54813	1	130326	6	48932
54814	4	130327	7	48786
54815	4	130329	5	5992
54816	4	130331	4	48962
54817	5	130333	2	39108
54818	5	130335	6	48922
54819	5	130337	6	46464
54820	4	130339	5	41604
54821	4	130340	5	9784
54822	5	130341	6	49037
54823	5	130344	1	30090
54824	4	130345	4	30616
54825	5	130346	7	47252
54826	4	130348	4	24165
54827	4	130348	7	24165
54828	5	130350	1	2623
54829	4	130351	2	5979
54830	5	130356	2	3260
54831	5	130358	2	49038
54832	4	130359	6	41290
54833	5	130362	3	2659
54834	5	130364	6	48771
54835	5	130369	2	12488
54836	4	130369	5	12488
54837	3	130371	5	48794
54838	5	130373	2	27861
54839	2	130377	6	23466
54840	4	130378	7	7958
54841	5	130379	3	21142
54842	5	130383	4	32623
54843	4	130385	2	15575
54844	5	130388	7	48850
54845	5	130393	2	48777
54846	5	130395	7	48879
54847	3	130396	6	48866
54848	4	130398	7	15863
54849	2	130399	1	49011
54850	5	130400	2	15337
54851	1	130401	6	30389
54852	5	130411	2	37548
54853	3	130417	2	48751
54854	5	130419	6	37082
54855	3	130420	3	48789
54856	5	130424	7	8444
54857	3	130425	5	38372
54858	5	130430	2	32974
54859	4	130431	7	31197
54860	5	130435	1	34367
54861	5	130439	4	10135
54862	3	130440	2	48834
54863	5	130441	2	8451
54864	4	130442	5	19042
54865	4	130444	7	821
54866	4	130445	5	48867
54867	5	130449	6	30702
54868	5	130450	5	49128
54869	5	130452	7	49263
54870	4	130453	7	49031
54871	3	130456	7	49131
54872	5	130457	5	24089
54873	5	130460	6	24301
54874	5	130462	5	44028
54875	5	130468	7	33326
54876	5	130471	2	25776
54877	4	130472	1	2571
54878	5	130473	6	12089
54879	5	130474	4	49216
54880	5	130474	1	49216
54881	4	130475	3	12276
54882	5	130475	6	12276
54883	5	130476	2	12943
54884	4	130479	3	26024
54885	4	130482	3	7069
54886	5	130487	4	41542
54887	5	130491	5	49077
54888	5	130496	6	18676
54889	5	130497	6	49165
54890	5	130498	4	49188
54891	3	130502	7	2369
54892	4	130507	7	18702
54893	4	130511	5	15192
54894	4	130515	3	18445
54895	4	130521	1	49225
54896	4	130521	5	49225
54897	4	130522	7	43664
54898	4	130523	6	10869
54899	5	130524	6	49059
54900	5	130534	6	6578
54901	5	130535	2	39735
54902	4	130542	4	47684
54903	5	130546	4	47480
54904	5	130548	6	14845
54905	5	130552	6	49215
54906	3	130553	1	49249
54907	5	130556	7	22511
54908	5	130558	4	44025
54909	4	130560	7	49155
54910	5	130562	7	48263
54911	4	130564	4	41405
54912	5	130565	4	14097
54913	5	130566	2	39315
54914	3	130567	5	30745
54915	3	130569	5	49199
54916	5	130570	6	49242
54917	3	130571	5	49112
54918	5	130574	4	49147
54919	5	130577	3	36216
54920	5	130589	6	28020
54921	3	130589	5	28020
54922	5	130592	7	1379
54923	4	130593	7	13522
54924	5	130596	3	49168
54925	3	130597	7	3613
54926	2	130601	1	36306
54927	5	130602	2	30977
54928	5	130603	5	27330
54929	4	130604	2	3568
54930	3	130606	5	49135
54931	4	130607	7	13994
54932	1	130608	6	28413
54933	4	130610	5	49222
54934	5	130611	2	49146
54935	5	130613	2	22921
54936	3	130614	5	39604
54937	5	130617	6	3585
54938	5	130619	1	49175
54939	4	130621	6	38625
54940	5	130621	4	38625
54941	5	130622	2	9449
54942	5	130623	3	49124
54943	5	130627	6	5319
54944	4	130630	6	7439
54945	3	130633	5	34413
54946	5	130636	3	7606
54947	2	130644	6	33219
54948	4	130649	6	37676
54949	3	130651	7	48819
54950	4	130654	7	22450
54951	5	130655	2	45028
54952	5	130660	1	49154
54953	4	130663	6	49167
54954	3	130666	5	11907
54955	1	130668	1	49122
54956	5	130671	6	39960
54957	4	130674	2	24753
54958	5	130679	6	17794
54959	4	130683	3	18293
54960	5	130683	4	18293
54961	5	130685	1	16283
54962	5	130686	3	49143
54963	5	130687	3	49244
54964	5	130688	2	35325
54965	5	130695	6	34032
54966	5	130696	1	49119
54967	5	130697	2	7195
54968	5	130700	6	31981
54969	5	130701	2	49227
54970	4	130703	6	13297
54971	3	130705	1	49081
54972	4	130705	4	49081
54973	5	130706	1	26373
54974	3	130709	7	15394
54975	3	130713	2	34330
54976	3	130714	6	49200
54977	3	130715	5	49205
54978	4	130718	5	22126
54979	3	130722	4	1718
54980	3	130722	3	1718
54981	5	130723	7	18687
54982	5	130724	6	49239
54983	1	130725	2	49250
54984	4	130730	4	47661
54985	5	130735	7	35347
54986	5	130736	2	49284
54987	4	130737	3	42974
54988	2	130738	3	49078
54989	5	130740	4	9886
54990	3	130742	4	49090
54991	5	130745	7	2065
54992	5	130749	6	5004
54993	2	130752	3	20681
54994	4	130753	3	49044
54995	5	130755	6	23673
54996	5	130755	4	23673
54997	5	130756	5	35871
54998	5	130759	3	47980
54999	5	130763	4	49055
55000	5	130765	3	23165
55001	3	130768	5	49272
55002	4	130769	1	49151
55003	5	130769	4	49151
55004	3	130772	4	44532
55005	5	130774	2	23604
55006	5	130777	4	49092
55007	4	130778	7	29571
55008	5	130780	2	49073
55009	5	130781	2	22698
55010	4	130784	1	16003
55011	3	130785	3	12479
55012	3	130787	6	24264
55013	3	130790	2	1656
55014	5	130791	7	33282
55015	4	130802	1	49262
55016	4	130803	4	11767
55017	5	130804	2	49184
55018	5	130808	5	49129
55019	5	130810	7	49185
55020	5	130814	6	5202
55021	4	130815	5	34746
55022	4	130823	5	34497
55023	5	130831	3	39536
55024	4	130832	5	35961
55025	2	130837	1	32967
55026	5	130840	2	40686
55027	5	130842	5	38866
55028	4	130846	5	28549
55029	5	130848	5	7531
55030	3	130849	5	31856
55031	4	130850	2	37424
55032	4	130851	4	12185
55033	3	130852	7	49195
55034	4	130854	5	49061
55035	5	130857	7	17736
55036	5	130858	2	4695
55037	5	130859	5	49243
55038	5	130860	4	26120
55039	5	130863	2	7924
55040	4	130866	6	42599
55041	2	130869	6	40238
55042	3	130870	7	684
55043	3	130872	3	49149
55044	5	130875	7	7371
55045	4	130879	5	39223
55046	2	130881	1	49233
55047	5	130883	5	33767
55048	4	130886	2	17534
55049	4	130887	1	49097
55050	3	130892	2	12454
55051	2	130898	5	36946
55052	5	130902	4	6221
55053	4	130904	7	38224
55054	3	130907	7	49177
55055	3	130908	7	43925
55056	5	130910	6	288
55057	5	130912	3	17932
55058	5	130915	5	49106
55059	5	130919	2	24174
55060	5	130927	6	42194
55061	5	130928	6	281
55062	5	130929	3	23835
55063	3	130930	5	11258
55064	5	130932	7	42381
55065	3	130935	5	49093
55066	5	130936	3	30624
55067	5	130941	6	49158
55068	5	130943	2	47853
55069	5	130943	7	47853
55070	5	130944	5	33492
55071	4	130952	4	19566
55072	4	130954	1	38812
55073	3	130956	4	44546
55074	4	130961	1	46430
55075	4	130962	5	11527
55076	4	130963	7	49586
55077	5	130965	2	22418
55078	3	130966	7	49367
55079	5	130971	6	8438
55080	3	130975	5	43915
55081	5	130977	5	49364
55082	3	130978	5	36693
55083	1	130979	6	6504
55084	5	130981	2	36251
55085	5	130983	5	49298
55086	5	130984	6	49496
55087	5	130985	7	37186
55088	4	130992	1	7566
55089	5	130996	1	49532
55090	5	130999	2	17695
55091	5	131000	5	7119
55092	5	131001	2	49306
55093	4	131003	7	44991
55094	3	131004	6	3996
55095	5	131005	4	49296
55096	5	131006	6	49593
55097	1	131008	5	49592
55098	5	131011	6	37176
55099	4	131014	1	5329
55100	2	131015	7	41616
55101	5	131020	4	49434
55102	5	131021	3	10641
55103	4	131028	7	19174
55104	3	131029	2	8341
55105	3	131033	1	33742
55106	4	131035	5	30777
55107	5	131036	3	27023
55108	3	131038	1	11109
55109	3	131041	3	49432
55110	3	131044	2	49546
55111	1	131048	4	6442
55112	5	131050	4	4818
55113	3	131051	5	33772
55114	1	131052	6	31430
55115	5	131053	2	49371
55116	4	131055	1	49494
55117	5	131057	4	31927
55118	5	131058	7	49407
55119	4	131065	2	32738
55120	5	131065	5	32738
55121	3	131066	7	38102
55122	5	131067	7	1429
55123	5	131069	6	49418
55124	5	131070	7	49048
55125	5	131071	5	15599
55126	5	131072	4	49564
55127	5	131076	6	49446
55128	4	131077	5	49612
55129	5	131080	5	8029
55130	5	131080	7	8029
55131	3	131081	5	46833
55132	5	131082	5	30909
55133	3	131083	4	9995
55134	4	131085	7	16536
55135	5	131086	1	44854
55136	3	131087	2	49467
55137	4	131089	6	49430
55138	3	131092	7	10755
55139	5	131093	1	5180
55140	5	131096	1	2843
55141	5	131096	7	2843
55142	2	131099	6	49339
55143	5	131104	4	49610
55144	5	131111	1	41621
55145	4	131112	5	13838
55146	5	131117	6	49299
55147	2	131118	6	49603
55148	3	131121	5	42929
55149	5	131125	2	3755
55150	5	131126	1	6429
55151	4	131127	5	49417
55152	5	131128	5	49347
55153	5	131131	7	22472
55154	4	131132	6	49349
55155	3	131135	1	10826
55156	2	131138	6	49503
55157	5	131139	6	19687
55158	5	131140	4	49550
55159	4	131143	4	7780
55160	3	131145	1	26653
55161	5	131151	5	43124
55162	4	131152	6	15222
55163	3	131154	1	49581
55164	4	131161	2	49594
55165	2	131163	3	12019
55166	5	131164	1	11525
55167	4	131166	6	31764
55168	5	131172	2	49305
55169	4	131173	4	5933
55170	4	131174	2	49493
55171	5	131177	7	49591
55172	5	131179	7	14021
55173	5	131181	7	49429
55174	5	131187	2	49300
55175	4	131192	1	40468
55176	4	131195	5	49551
55177	3	131196	7	49310
55178	5	131197	7	4534
55179	5	131197	6	4534
55180	5	131199	7	49308
55181	5	131202	7	49622
55182	4	131203	7	626
55183	4	131204	3	575
55184	5	131205	6	10771
55185	5	131207	3	7364
55186	4	131211	5	11415
55187	5	131221	6	9292
55188	5	131221	1	9292
55189	4	131223	6	49392
55190	5	131227	3	25885
55191	5	131229	2	49535
55192	5	131232	5	49522
55193	4	131232	7	49522
55194	4	131233	7	17036
55195	5	131234	7	44954
55196	4	131236	4	1638
55197	5	131238	7	12598
55198	5	131240	3	49376
55199	5	131244	7	980
55200	5	131245	6	46057
55201	4	131248	4	30357
55202	4	131255	7	7953
55203	5	131256	6	49514
55204	5	131257	7	16961
55205	4	131265	3	49501
55206	3	131268	5	21041
55207	5	131271	5	49482
55208	4	131273	7	32542
55209	5	131274	3	4445
55210	5	131275	6	18621
55211	3	131278	5	23883
55212	4	131279	7	6230
55213	5	131282	7	31814
55214	5	131283	2	7058
55215	4	131285	7	13948
55216	5	131287	7	49316
55217	4	131290	5	41652
55218	5	131294	5	45308
55219	5	131295	4	20338
55220	5	131297	7	49469
55221	1	131303	6	9164
55222	3	131307	2	25461
55223	5	131309	7	29856
55224	3	131310	5	49479
55225	5	131314	7	6646
55226	5	131315	5	46486
55227	3	131316	5	5679
55228	5	131317	5	30680
55229	3	131317	1	30680
55230	5	131325	7	9806
55231	5	131326	1	20970
55232	5	131331	4	15941
55233	5	131335	7	46389
55234	5	131338	5	37948
55235	5	131342	4	49608
55236	4	131347	5	12664
55237	5	131349	4	9308
55238	4	131353	2	7032
55239	5	131355	4	1303
55240	5	131357	6	49372
55241	5	131358	7	4655
55242	3	131360	7	46444
55243	4	131361	2	47215
55244	5	131362	7	13859
55245	5	131364	3	20074
55246	5	131369	6	49565
55247	5	131375	6	37134
55248	3	131377	1	49486
55249	4	131378	7	24510
55250	5	131380	6	11635
55251	5	131383	6	11646
55252	5	131386	2	40235
55253	5	131387	4	6715
55254	4	131389	7	39424
55255	5	131391	6	29445
55256	5	131396	1	4104
55257	4	131401	7	3903
55258	5	131402	5	9008
55259	4	131406	4	4411
55260	5	131410	3	49541
55261	3	131411	2	24950
55262	5	131414	2	46777
55263	5	131415	6	49485
55264	5	131417	2	18228
55265	5	131418	4	49381
55266	5	131419	2	27733
55267	4	131420	6	1232
55268	4	131422	4	20060
55269	5	131424	3	49459
55270	3	131426	5	49444
55271	5	131427	7	8461
55272	5	131428	4	21006
55273	3	131430	2	19664
55274	5	131431	6	9311
55275	5	131436	6	49471
55276	5	131440	6	49615
55277	5	131441	5	49387
55278	4	131442	1	16186
55279	5	131444	7	49621
55280	5	131445	1	49315
55281	4	131446	7	49585
55282	5	131450	7	49354
55283	5	131451	1	21205
55284	3	131454	2	49312
55285	5	131455	7	49337
55286	5	131459	4	19637
55287	1	131461	5	48518
55288	4	131465	5	43468
55289	4	131465	2	43468
55290	5	131469	2	3335
55291	5	131471	3	49627
55292	3	131472	5	31383
55293	5	131473	5	15076
55294	4	131474	7	44563
55295	4	131474	5	44563
55296	3	131475	7	4678
55297	3	131476	5	31391
55298	5	131478	2	11394
55299	4	131482	6	30915
55300	5	131483	2	27195
55301	5	131487	2	49590
55302	4	131488	5	49570
55303	4	131491	2	49587
55304	5	131491	6	49587
55305	3	131492	4	11052
55306	3	131495	7	31581
55307	5	131497	3	9575
55308	4	131499	7	22886
55309	2	131501	5	15350
55310	5	131503	1	49577
55311	5	131504	3	2769
55312	4	131506	4	24407
55313	4	131507	7	5603
55314	4	131509	5	2994
55315	4	131510	5	49609
55316	3	131511	1	49464
55317	3	131512	3	49344
55318	5	131512	7	49344
55319	5	131513	6	49326
55320	5	131516	4	49400
55321	5	131518	4	48067
55322	4	131521	7	49321
55323	5	131526	7	49531
55324	5	131527	5	49393
55325	5	131528	2	40659
55326	4	131534	7	9014
55327	5	131535	7	49476
55328	3	131536	6	36567
55329	4	131537	6	35104
55330	5	131538	5	37528
55331	5	131540	4	47177
55332	4	131542	1	12823
55333	5	131547	4	49428
55334	5	131551	7	12390
55335	3	131553	5	9467
55336	3	131557	2	49484
55337	5	131559	5	29397
55338	5	131559	1	29397
55339	5	131565	7	36559
55340	5	131566	6	34792
55341	5	131568	4	49560
55342	5	131569	5	18296
55343	5	131570	7	49554
55344	5	131571	4	36762
55345	5	131573	2	27449
55346	4	131575	2	49342
55347	5	131577	3	11926
55348	5	131580	7	49384
55349	2	131583	4	3616
55350	5	131584	5	49495
55351	3	131585	5	25252
55352	4	131586	7	36273
55353	5	131587	3	28390
55354	5	131589	7	49625
55355	5	131594	2	38124
55356	5	131595	4	32998
55357	4	131596	4	49449
55358	4	131597	5	49442
55359	5	131601	7	19876
55360	5	131602	6	8675
55361	4	131603	2	42317
55362	5	131604	6	31787
55363	5	131607	1	49561
55364	4	131610	3	31989
55365	3	131613	3	49574
55366	3	131614	4	33808
55367	5	131615	6	22790
55368	3	131616	7	49414
55369	4	131634	5	49490
55370	5	131639	2	22841
\.


--
-- Data for Name: users; Type: TABLE DATA; Schema: public; Owner: -
--

COPY public.users (id_user, created_at, created_date, name, email, city, state, credit_card_number, credit_card_hash, credit_card_provider, lat, lon) FROM stdin;
1	2019-01-01 00:29:02	2019-01-01	Tim Abraham	tim@timabe.me	Berkeley	California	4540725990517699	c7850bef067282d30a326b50fa4eb1c6	Discover	37.857445772227976	-122.266271272474555
2	2019-01-01 00:41:03	2019-01-01	Dr. Orvil Conn III	dr.orvil.conn.iii@geemail.com	San Francisco	California	676326018456710	c553c904162c4973251b14d97839138d	Maestro	37.7636297974646737	-122.417320353748082
3	2019-01-01 01:45:39	2019-01-01	Gerrit Stokes	gerrit.stokes@warmmail.com	San Francisco	California	869964940961151131	7d4f7b9dda9ebe83afd6b70ef8e8fd20	Maestro	37.7623727700518117	-122.427050350241899
4	2019-01-01 02:02:41	2019-01-01	Kamilah Kihn	kamilah.kihn@geemail.com	Oakland	California	3020321294245246	546059382559fcbfa02c45427dee8c57	Maestro	37.804175500765794	-122.278868355412143
5	2019-01-01 02:03:25	2019-01-01	Miss Marianna Brown PhD	miss.marianna.brown.phd@geemail.com	San Francisco	California	3337144469722598145	41816b064b72044b2bcb46cc8f86d1bf	Maestro	37.7726167056236477	-122.440969089214065
6	2019-01-01 02:04:42	2019-01-01	Kaylie McCullough PhD	kaylie.mccullough.phd@warmmail.com	Oakland	California	4626311774674266	0cdb4e6de276c97c7a0cdec15538b191	Mastercard	37.8215498501115235	-122.269163107550028
7	2019-01-01 02:24:38	2019-01-01	Odelia Bahringer	odelia.bahringer@geemail.com	Oakland	California	869961128449207591	354158185cde63569126bec58a117a0f	VISA 16 digit	37.8363987765727927	-122.293005611967672
8	2019-01-01 02:58:54	2019-01-01	Jace Sipes	jace.sipes@woohoo.com	San Francisco	California	4774616925333194	854a637f5fe9549a638044cc336d59ff	Voyager	37.7651642326677148	-122.434461246021527
9	2019-01-01 03:07:30	2019-01-01	Azul Kassulke	azul.kassulke@geemail.com	Oakland	California	3088280204782538242	8205d8d0b41f88d2a41d76f3d55ac8f2	JCB 16 digit	37.8004951889001077	-122.28919686043001
10	2019-01-01 03:19:01	2019-01-01	Devyn Schaefer V	devyn.schaefer.v@geemail.com	San Francisco	California	4843443143105	1bc1b94fbf6d97f5923ad88dbc80589f	JCB 15 digit	37.7859341760224012	-122.419381836244654
11	2019-01-01 03:20:21	2019-01-01	Ms. Racquel Armstrong	ms.racquel.armstrong@geemail.com	San Francisco	California	3112517170039060311	a36e85fbcc53bbd4bb6ef88186740e89	JCB 16 digit	37.7945604034192684	-122.437840066462869
12	2019-01-01 03:24:31	2019-01-01	Brendan Beer	brendan.beer@geemail.com	San Francisco	California	3445551107710427	7645538126202b196b90a0de62f5ae2c	VISA 16 digit	37.7814734489329993	-122.427441773179766
13	2019-01-01 04:01:42	2019-01-01	Mr. Amon Stokes	mr.amon.stokes@geemail.com	San Francisco	California	180004082241194590	fb6359cbf7c72273793039d3611cc1a8	Mastercard	37.780008799487689	-122.433129082754334
14	2019-01-01 04:31:42	2019-01-01	Miss Mathilde Hudson	miss.mathilde.hudson@woohoo.com	New York	New York	869997801847311037	ff0fefbfb9b98a9f4f52b89cd2d8a5e0	VISA 16 digit	40.6561775601226856	-73.9474332587223415
15	2019-01-01 04:43:45	2019-01-01	Vira Stanton-Green	vira.stanton.green@geemail.com	San Francisco	California	3752127414021061	0997bdbf943da21f220864a09ebbfc0c	Diners Club / Carte Blanche	37.7884604222532872	-122.442371158848601
16	2019-01-01 05:02:10	2019-01-01	Sherree Beahan	sherree.beahan@geemail.com	San Francisco	California	4459275495458410	a370e88bdb2467a3870dd9ea04c8cf3d	Maestro	37.7712865456048803	-122.459947884685917
17	2019-01-01 06:08:54	2019-01-01	Kristofer Turner	kristofer.turner@woohoo.com	San Francisco	California	4862857698262003	de0ac4231ad13f30f39911d7bb48a4ac	VISA 16 digit	37.7744344783516297	-122.441198037749828
18	2019-01-01 06:18:39	2019-01-01	Lillian Auer	lillian.auer@geemail.com	San Francisco	California	180021376023001570	f4e40a19b6b38789a1c6a2efc0a07cf4	VISA 16 digit	37.7337914929745182	-122.436520091012056
19	2019-01-01 06:34:48	2019-01-01	Nakita Jacobs	nakita.jacobs@geemail.com	San Francisco	California	6011063197048060220	c91dc946889a81dec2e14abc357a659b	Mastercard	37.7646257131570167	-122.43738193870854
20	2019-01-01 07:04:08	2019-01-01	Deonte Mayer MD	deonte.mayer.md@warmmail.com	San Francisco	California	210096056595314771	3e5836bcceed93c0c6851aaa6f16450b	Mastercard	37.7461793838093982	-122.419457579767567
21	2019-01-01 07:04:14	2019-01-01	Dr. Elease Weissnat DVM	dr.elease.weissnat.dvm@woohoo.com	San Francisco	California	6011780747561803323	4a6be3b04e74e27f75f3018e31e6dd5f	Diners Club / Carte Blanche	37.7417584743117231	-122.428012829878313
22	2019-01-01 07:42:39	2019-01-01	Brant Kreiger	brant.kreiger@geemail.com	San Francisco	California	503801893291409	475e0556bd905c11bde70109c95132a0	American Express	37.7948193542309809	-122.448989651432441
23	2019-01-01 07:57:29	2019-01-01	Romie Shields	romie.shields@geemail.com	San Francisco	California	180088321453090982	899313e461743641e50063b8efc7bc37	Discover	37.7891398314584634	-122.439223087481238
24	2019-01-01 08:05:59	2019-01-01	Dr. Pryor Flatley IV	dr.pryor.flatley.iv@geemail.com	Oakland	California	3112710572489903996	5c65cf523029f4bc0d8145647dad68d7	VISA 13 digit	37.7849773984237132	-122.27887531773689
25	2019-01-01 08:13:21	2019-01-01	Linwood Goyette I	linwood.goyette.i@woohoo.com	San Francisco	California	4978346129155	3d5ca2c2d46f7c3d627db12712926154	Mastercard	37.8020626161571229	-122.425469438227978
26	2019-01-01 08:24:42	2019-01-01	Jami Eichmann	jami.eichmann@geemail.com	San Francisco	California	060418725936134	bd77ef7a31846675f2e61fe5690b3ca8	JCB 15 digit	37.7635903685325545	-122.407492434603213
27	2019-01-01 08:30:44	2019-01-01	Rubin Hackett	rubin.hackett@geemail.com	San Francisco	California	3337707227677142387	b408e82ccaf5ccf9d8f0d7955744fa4c	Diners Club / Carte Blanche	37.7629163134817318	-122.438982407047448
28	2019-01-01 09:02:44	2019-01-01	Carolynn Lemke-Mayert	carolynn.lemke.mayert@warmmail.com	San Francisco	California	6011225481886614990	633285cbfadce28ea3f0f9a2d264e9e8	Mastercard	37.7320271207847568	-122.444649707805553
29	2019-01-01 09:09:50	2019-01-01	Urijah Okuneva MD	urijah.okuneva.md@geemail.com	Oakland	California	54950437037520420	26546d7caf894ffe6bb3e2d60f16bb4d	Maestro	37.7843580358221871	-122.281582043133938
30	2019-01-01 09:16:07	2019-01-01	Almira Cole	almira.cole@woohoo.com	San Francisco	California	3479263010112472	cd4d490fe9b92b986123ab14e755ccf0	JCB 15 digit	37.7574743682625069	-122.417001549242116
31	2019-01-01 09:37:14	2019-01-01	Dr. Creed Jones I	dr.creed.jones.i@geemail.com	San Francisco	California	3025646120846295	d9bd80b357b9478160602346fead8d29	Discover	37.782225565948508	-122.40845057928415
32	2019-01-01 10:07:49	2019-01-01	Dr. Una Dickens	dr.una.dickens@geemail.com	San Francisco	California	6011841479954000666	940e6e2c875a6ed80c28785eff92a5a1	JCB 15 digit	37.7713261728373553	-122.422773666231706
33	2019-01-01 10:33:48	2019-01-01	Mrs. Sherri Reichert MD	mrs.sherri.reichert.md@geemail.com	San Francisco	California	51749419491627020	2524155e8231e913ef08ba094972f0b8	American Express	37.7934487204735277	-122.44579994287497
34	2019-01-01 10:39:48	2019-01-01	Jaslyn Halvorson PhD	jaslyn.halvorson.phd@geemail.com	San Francisco	California	3158984936799916593	7e371e92f61e50ac1aeaffdbb26fddf8	JCB 15 digit	37.8027082549285112	-122.388312170784033
35	2019-01-01 11:10:58	2019-01-01	Lisette Kub	lisette.kub@geemail.com	Oakland	California	6011262172951082296	dba073054925611b67a72c45e9fd7450	JCB 15 digit	37.8002468154783315	-122.244632120516258
36	2019-01-01 11:19:35	2019-01-01	Regina Bode	regina.bode@woohoo.com	San Francisco	California	3088625408108288804	2d1569f63f306fe3a079a2f6f29e853a	VISA 13 digit	37.7930876472414496	-122.400351804289514
37	2019-01-01 11:26:15	2019-01-01	Debra Kshlerin	debra.kshlerin@warmmail.com	San Francisco	California	55947506084289752	d04659db54a49594f2c8d587cc1a1dbe	American Express	37.8220652236209389	-122.442767051165404
38	2019-01-01 11:41:53	2019-01-01	Robin Konopelski	robin.konopelski@warmmail.com	Oakland	California	3096481237001428735	0a8f12b7abec8f670bb81ae633bfb8ce	Voyager	37.7926074265727721	-122.266952376524543
39	2019-01-01 11:48:30	2019-01-01	Alonso Hegmann	alonso.hegmann@geemail.com	San Francisco	California	180003494727106223	819b7063dbe6ea8c619591ac37bdc6c0	VISA 16 digit	37.7515623752808409	-122.430120654686078
40	2019-01-01 11:59:05	2019-01-01	Baldwin Windler	baldwin.windler@geemail.com	Oakland	California	3035652455692759	b6a067dbca7ae1a3f5adf751c2f4f1be	JCB 16 digit	37.7853681122287668	-122.316743991951185
41	2019-01-01 12:35:52	2019-01-01	Yahaira Flatley	yahaira.flatley@geemail.com	San Francisco	California	869922176292626696	c5a1cae95fe8c21945212fa0b29f6981	JCB 15 digit	37.7662808687010596	-122.443261165328465
42	2019-01-01 13:25:32	2019-01-01	Dashawn Hoeger	dashawn.hoeger@geemail.com	Berkeley	California	4637831005666135	d0a7b9038d2fff71609105fae931b25e	Voyager	37.8754173147191366	-122.262189180861114
43	2019-01-01 13:34:07	2019-01-01	Permelia Hayes	permelia.hayes@geemail.com	Berkeley	California	502018985330952	734c57c4c82f3b6140a433c080bcb49a	Mastercard	37.8342450177935063	-122.310653421029642
44	2019-01-01 13:53:26	2019-01-01	Jerrilyn Carter PhD	jerrilyn.carter.phd@geemail.com	San Francisco	California	4552021818110593	9084f8b819f26b88d21bd4330b18b88d	JCB 16 digit	37.770793871088884	-122.433225815848715
45	2019-01-01 13:59:57	2019-01-01	Ms. Dionne Kirlin	ms.dionne.kirlin@geemail.com	San Francisco	California	210060416983961330	2b8a8497b6ca0d40eb6ed6ef8183bafd	JCB 16 digit	37.7506324897594325	-122.431734337995962
46	2019-01-01 14:18:38	2019-01-01	Erby Welch	erby.welch@woohoo.com	San Francisco	California	869986712408982558	019e6215ce3083c97ea9b520cfa667b6	VISA 13 digit	37.7854957715689821	-122.461363195918338
47	2019-01-01 14:39:16	2019-01-01	Oddie Breitenberg IV	oddie.breitenberg.iv@geemail.com	San Francisco	California	869955762459770532	22a6c3eb3823cc6f0cc5d3f3f636264e	JCB 15 digit	37.8129205622790749	-122.471469245081067
48	2019-01-01 14:50:28	2019-01-01	Robby McLaughlin-Hoppe	robby.mclaughlin.hoppe@geemail.com	San Francisco	California	6011754809316357401	41b79b8033f37c3e9d8c73310d303abe	VISA 16 digit	37.7738417251426739	-122.477585322616179
49	2019-01-01 15:00:59	2019-01-01	Izabella Kunde	izabella.kunde@geemail.com	San Francisco	California	4625777386087918	f476041f87870e39188cd1e54e827f23	VISA 16 digit	37.7879261588307855	-122.456811917108553
50	2019-01-01 15:03:52	2019-01-01	Micky Lockman PhD	micky.lockman.phd@geemail.com	Oakland	California	4668632796201	e1b83e0ae3ffd7746768ea7c519830c5	VISA 16 digit	37.7924509018709855	-122.233061672186324
51	2019-01-01 15:32:06	2019-01-01	Tammie Thiel	tammie.thiel@warmmail.com	San Francisco	California	3450550105974581	f00d1110463a22e1d5521af978a0545e	VISA 16 digit	37.7457078292281665	-122.397758066318261
52	2019-01-01 15:35:24	2019-01-01	Gray Kreiger	gray.kreiger@geemail.com	Berkeley	California	52357467328731757	62c9275b822f69ba735d94c948cd8cc0	VISA 16 digit	37.8626432991452972	-122.266955097911563
53	2019-01-01 16:29:51	2019-01-01	Tawana Toy	tawana.toy@warmmail.com	San Francisco	California	3720960593394167	7f3a0f9b789c2c08c568bd5e7f6308c1	JCB 16 digit	37.7612505867145032	-122.432381024329047
54	2019-01-01 16:33:33	2019-01-01	Mrs. Shanna Goldner	mrs.shanna.goldner@geemail.com	San Francisco	California	4162002577973936	a33773b107235554c73dc50e5813dd4a	American Express	37.7740477447422336	-122.437001026644211
55	2019-01-01 16:57:09	2019-01-01	Shaneka Kunze	shaneka.kunze@geemail.com	San Francisco	California	6011013070178971279	4664a562cb2e4ffc23dfadaafc4679ed	American Express	37.7813926104819942	-122.413898151247551
56	2019-01-01 17:01:41	2019-01-01	Romie Hoeger	romie.hoeger@geemail.com	San Francisco	California	3337103986679653440	dddb8e9d1025b6be5cd63c619e1ba860	Maestro	37.7661433562192457	-122.44472511859459
57	2019-01-01 17:21:16	2019-01-01	Mr. Archibald Kuhlman DVM	mr.archibald.kuhlman.dvm@woohoo.com	San Francisco	California	561256977510546	2fa3261f22c94a7221105652e07b09e8	VISA 16 digit	37.7980924087717511	-122.469459923615361
58	2019-01-01 17:37:18	2019-01-01	Lorri Doyle	lorri.doyle@geemail.com	San Francisco	California	3733422544920108	3593cc3af4bb21f030293fdc9f0b500e	VISA 13 digit	37.7894918970803815	-122.413652696315651
59	2019-01-01 17:51:44	2019-01-01	Perley Considine	perley.considine@geemail.com	San Francisco	California	210056456416799382	107d1de6076f04e39f2f3cb2bbb582bf	VISA 16 digit	37.7695149224231272	-122.416365635846333
60	2019-01-01 17:51:58	2019-01-01	Boris Aufderhar V	boris.aufderhar.v@geemail.com	San Francisco	California	4071935387794663	05697479330d47025ca1ab39f2b5ec90	Discover	37.7677884525608434	-122.435064046768304
61	2019-01-01 17:53:07	2019-01-01	Jaiden Wolf	jaiden.wolf@geemail.com	San Francisco	California	6011799914658631137	a9ef1730bc1f6858ad7e98451325ef59	Discover	37.8026485583222964	-122.448872718916718
62	2019-01-01 18:04:12	2019-01-01	Aurora Friesen	aurora.friesen@geemail.com	Oakland	California	6011263287431997001	446c3ed259ace81821698eaeb29e1df2	Mastercard	37.8017062759968141	-122.297807616737657
63	2019-01-01 18:08:33	2019-01-01	Ellamae Durgan	ellamae.durgan@geemail.com	Oakland	California	4099407176975	5e7ef6b3c8790103eff980bb89769e0a	Voyager	37.8125551877258772	-122.253914111028749
64	2019-01-01 18:09:31	2019-01-01	Rupert Larson	rupert.larson@geemail.com	Berkeley	California	4101919723157102	b9bbf61460129a1f5812740d0056031b	Diners Club / Carte Blanche	37.8832163807389009	-122.244341309169101
65	2019-01-01 18:10:10	2019-01-01	Errol Herzog	errol.herzog@geemail.com	Berkeley	California	4063555071597147	a0fc3502b75f11961bac74186b06e43b	VISA 16 digit	37.891444924821208	-122.263302489333142
66	2019-01-01 18:24:03	2019-01-01	Todd Ritchie II	todd.ritchie.ii@geemail.com	Oakland	California	869949040777635409	9c3108367a3d508227fd950be2fda8b6	JCB 16 digit	37.8131569441395712	-122.245960629095705
67	2019-01-01 19:49:49	2019-01-01	Chasity Howe	chasity.howe@warmmail.com	San Francisco	California	6011213570369947945	9c74960307b30bcb41c473d07f26ee28	JCB 16 digit	37.753496535956792	-122.428823670756572
68	2019-01-01 19:51:06	2019-01-01	Mr. Amasa Schaden III	mr.amasa.schaden.iii@geemail.com	San Francisco	California	503831716667881	f1a3e93a321e65785eed6f4a90a02240	Maestro	37.7676774239117705	-122.43395109932348
69	2019-01-01 20:48:54	2019-01-01	Denice Lemke	denice.lemke@geemail.com	San Francisco	California	55540136672847836	a9d76c58154d482832b779d0e73258b2	JCB 16 digit	37.7565875014486352	-122.429247258707505
70	2019-01-01 20:51:38	2019-01-01	Dr. Brantley Hackett DVM	dr.brantley.hackett.dvm@geemail.com	Oakland	California	3008250809581484	86ec2faad94b72f4ebe89a255c08fa8c	Mastercard	37.8082429462385292	-122.256680633257105
71	2019-01-01 21:13:51	2019-01-01	Dr. Danae Okuneva	dr.danae.okuneva@geemail.com	San Francisco	California	4636633158440412	e532bcea1039fbe23885b5a1a98c133d	Discover	37.7951919480060283	-122.42461380887616
72	2019-01-01 21:51:27	2019-01-01	Nikolai Crona	nikolai.crona@geemail.com	Denver	Colorado	3461192788503986	718a70e865fee28d74ea12213e2764e0	Maestro	39.7994216590240555	-104.952183957515658
73	2019-01-01 22:45:30	2019-01-01	Dr. Lavenia Cole DDS	dr.lavenia.cole.dds@geemail.com	San Francisco	California	3337772649647817253	49f755c9a290764117e9a77931d23c55	Maestro	37.7924068515886091	-122.457858929353463
74	2019-01-01 22:51:44	2019-01-01	Lillian Champlin	lillian.champlin@geemail.com	San Francisco	California	4235544516396748	094c18ea738a8949158bd7a5ae5140fc	Mastercard	37.7915039657323319	-122.423795951319448
75	2019-01-01 23:03:57	2019-01-01	Sydni Bins-Feest	sydni.bins.feest@geemail.com	San Francisco	California	4334174750696304	813c8a59aa31dc05ba78e2b808a0fe8f	JCB 16 digit	37.7451509352942765	-122.432078608525416
76	2019-01-01 23:40:01	2019-01-01	Dr. Ceasar Grady IV	dr.ceasar.grady.iv@woohoo.com	San Francisco	California	3088534029613818966	bd6918f8dc3d69439b8a877528556ee4	Voyager	37.7766715193077403	-122.439840286903291
77	2019-01-01 23:51:31	2019-01-01	Louetta Greenholt	louetta.greenholt@geemail.com	San Francisco	California	4336867044985114	1c5ddba9629de1fdf7f24ee5363dc184	VISA 16 digit	37.7644940080047462	-122.466001274107256
78	2019-01-01 23:55:13	2019-01-01	Dr. Webb Ferry	dr.webb.ferry@geemail.com	San Francisco	California	3088757649826131764	90a937eac987e39328ce366f3915471d	JCB 16 digit	37.7817661893899484	-122.418255879905388
79	2019-01-02 01:05:42	2019-01-02	Dr. Heber Zemlak V	dr.heber.zemlak.v@warmmail.com	San Francisco	California	3096697731572608337	6686c23d7370f695dab96961eb94a160	JCB 16 digit	37.7796559170730291	-122.390684894125286
80	2019-01-02 01:22:36	2019-01-02	Red Schinner	red.schinner@woohoo.com	San Francisco	California	3158642925578021349	5d01d77f93eca9f9d7fa132b3de2a310	Discover	37.7868140754308968	-122.398090580546182
81	2019-01-02 01:32:18	2019-01-02	Cornie Streich	cornie.streich@geemail.com	San Francisco	California	3454186912013911	5f594874d4cafdb85428f8194aef579d	Diners Club / Carte Blanche	37.7628258665744596	-122.421072165862256
82	2019-01-02 01:59:45	2019-01-02	Durrell Medhurst	durrell.medhurst@geemail.com	Berkeley	California	4489153631309	4e65d0df8f78bd80f51ed78497aa58ba	VISA 16 digit	37.8736729165304382	-122.245045767490765
83	2019-01-02 03:16:26	2019-01-02	Brendan Stracke	brendan.stracke@geemail.com	San Francisco	California	4063269250187	2ef3f88414351338070f7bc780fd53e0	American Express	37.7426638291342869	-122.462219646778735
84	2019-01-02 03:25:18	2019-01-02	Clare Prosacco-Deckow	clare.prosacco.deckow@geemail.com	Oakland	California	3158697633466251796	fd6c0bc3372874afdfe70404945b61d3	JCB 16 digit	37.7860659613835921	-122.300500658748845
85	2019-01-02 03:43:16	2019-01-02	Sue Hudson	sue.hudson@woohoo.com	San Francisco	California	676129943265115	6e85729d7d783f399c0b08344473d48d	American Express	37.7726815013933432	-122.45843299230404
86	2019-01-02 04:34:24	2019-01-02	Miss Kelcie Kutch	miss.kelcie.kutch@geemail.com	San Francisco	California	53580216520567686	bc1b91f66973846eb26b1b1f27fd20c4	Maestro	37.7469056043717615	-122.435010864449424
87	2019-01-02 05:23:58	2019-01-02	Savion Dibbert IV	savion.dibbert.iv@geemail.com	New York	New York	3037215133994761	9d0bd57065e60f1ba717cab2ffee5fa3	VISA 13 digit	40.5776180515289298	-74.0221250709041954
88	2019-01-02 05:54:42	2019-01-02	Dalvin Hayes	dalvin.hayes@woohoo.com	San Francisco	California	3747328853868198	7c83f11c5bb9d46d6f8639973fb44cd3	Voyager	37.7627051556122524	-122.450870666817892
89	2019-01-02 06:04:31	2019-01-02	Littleton Nader	littleton.nader@warmmail.com	San Francisco	California	4793657910944592	8f4403ef658df3766856055b2e786a7e	Mastercard	37.7455405786761347	-122.447233476655583
90	2019-01-02 06:15:02	2019-01-02	Kassie Glover	kassie.glover@geemail.com	San Francisco	California	4168444202185870	20f36cd7ef68b30df087ed04155fb728	VISA 13 digit	37.7450094862381178	-122.431774029039943
91	2019-01-02 06:16:09	2019-01-02	Trudy Pollich	trudy.pollich@geemail.com	San Francisco	California	3112923514481416117	c416eeeb874b8db9736718ebe3161801	JCB 15 digit	37.8016412862017788	-122.413333280013191
92	2019-01-02 06:22:54	2019-01-02	Mrs. Jaiden Hessel	mrs.jaiden.hessel@warmmail.com	San Francisco	California	6011218037718558000	bddabe45140c3e604fc45ee7399bb346	JCB 15 digit	37.7656843709132133	-122.411532502355513
93	2019-01-02 07:12:33	2019-01-02	Toshiko Cremin DVM	toshiko.cremin.dvm@woohoo.com	San Francisco	California	3088142188350770279	7a5ab81844e96bfecc5c73926d7ac4a7	VISA 16 digit	37.7760995050110324	-122.418692901049482
94	2019-01-02 07:41:59	2019-01-02	Miss Georgie Kuphal MD	miss.georgie.kuphal.md@geemail.com	Chicago	Illinois	3054275357262553	5f1ce6717f9d3c3ebf477b45235bb6aa	VISA 16 digit	41.8105062126018154	-87.6807137000404282
95	2019-01-02 07:51:47	2019-01-02	Kloe Herman	kloe.herman@geemail.com	San Francisco	California	3088324969411653897	de4e0408d49ed139317103d7852ebac6	American Express	37.7315405113693458	-122.430024213124469
96	2019-01-02 07:51:49	2019-01-02	Elwood Kertzmann	elwood.kertzmann@woohoo.com	San Francisco	California	3412032701621921	2bdb37f284597b82d3a7a582c35bd657	JCB 16 digit	37.7502005007527686	-122.411626975796267
97	2019-01-02 08:11:41	2019-01-02	Nakisha Hyatt	nakisha.hyatt@geemail.com	San Francisco	California	639054516526222	073830376219e0c9c098f61fd1e5cfee	Mastercard	37.7679306945959894	-122.43999627083538
98	2019-01-02 08:14:22	2019-01-02	Dr. Ether Von	dr.ether.von@warmmail.com	San Francisco	California	869903916858188158	7919eec51d0c820ff1ae7c6ada47fafc	JCB 16 digit	37.7621572714353064	-122.445688752140853
99	2019-01-02 08:28:42	2019-01-02	Mr. Jaimie Zemlak	mr.jaimie.zemlak@warmmail.com	San Francisco	California	3112074665540310944	bb210ff2d2a5889aff5d186dc7d66ec3	American Express	37.7650050398590551	-122.426676035747164
100	2019-01-02 08:51:05	2019-01-02	Destin Ortiz	destin.ortiz@geemail.com	San Francisco	California	4128544833337	c87aae5414a6253c129957210df03a05	Mastercard	37.7676671230853458	-122.410705785538553
101	2019-01-02 09:28:05	2019-01-02	Chelsey Oberbrunner	chelsey.oberbrunner@woohoo.com	San Francisco	California	3430870466551975	b887ee559b5c039fa6d2efae5275f4b6	VISA 16 digit	37.7753982897607159	-122.376828553467618
102	2019-01-02 09:46:54	2019-01-02	Brent Hoppe-Green	brent.hoppe.green@geemail.com	San Francisco	California	3337875873555878463	4cd6370929e6df07b381cfe476999860	Maestro	37.7401735791759805	-122.408588186433363
103	2019-01-02 09:50:05	2019-01-02	Kennedi Dooley	kennedi.dooley@geemail.com	San Francisco	California	3337301587095165504	72b9daf3b4203af3c8d55c97e57610da	Diners Club / Carte Blanche	37.7373383785246901	-122.415178742728003
104	2019-01-02 09:57:12	2019-01-02	Lyman Auer	lyman.auer@geemail.com	San Francisco	California	210020289587538021	ba33d8068f2a8bc6b6bc8535d36ac208	VISA 13 digit	37.7417433585912931	-122.405562046895568
105	2019-01-02 10:08:15	2019-01-02	Khalil Fritsch III	khalil.fritsch.iii@woohoo.com	San Francisco	California	3096078072491754251	dd790e5d6e42a30e912642a237fa276b	Voyager	37.7629203201430741	-122.457363661752794
106	2019-01-02 11:14:26	2019-01-02	Lisette Feeney	lisette.feeney@warmmail.com	San Francisco	California	4454305243452	b8985c5bf1dba7dd6ca77e081caaf9f7	Discover	37.7673477112452218	-122.475309816841914
107	2019-01-02 11:23:32	2019-01-02	Ethie Rowe	ethie.rowe@geemail.com	San Francisco	California	3735139052107914	da79cba18cac5b6b199068e3816e305c	American Express	37.7721211428894463	-122.410766724103155
108	2019-01-02 11:46:30	2019-01-02	Lockie Zieme	lockie.zieme@geemail.com	Oakland	California	210068602766749859	4b5e3cca884d1de40614b5dfae27225a	JCB 16 digit	37.835801693240164	-122.277941595124418
109	2019-01-02 12:04:53	2019-01-02	Elinore Doyle	elinore.doyle@geemail.com	Oakland	California	4700175931034	db891c59efc0e9e5a20d520c433f3d8a	JCB 16 digit	37.8351741695942749	-122.289518480286802
110	2019-01-02 12:10:06	2019-01-02	Less Haley	less.haley@woohoo.com	San Francisco	California	53683967480626088	f53af2c9d6a8e8f8502a4636c2c48d59	VISA 13 digit	37.771477894949669	-122.444137433611459
111	2019-01-02 13:19:41	2019-01-02	Mr. Jordy DuBuque	mr.jordy.dubuque@warmmail.com	San Francisco	California	4716263438721192	0fed64abde4bd44c9edd926c71a9a799	VISA 16 digit	37.7957109546497989	-122.422027761426847
112	2019-01-02 13:36:34	2019-01-02	Elden Thiel-Gottlieb	elden.thiel.gottlieb@geemail.com	San Francisco	California	3088446829817561644	87eada5be4aef4f62e7b05f8d63d45c3	VISA 13 digit	37.7524818605239574	-122.464693449878368
113	2019-01-02 13:50:35	2019-01-02	Dr. Maxx Parker DDS	dr.maxx.parker.dds@geemail.com	San Francisco	California	3096788063116828985	c0d19ff12e21e306f8934c725c3828a1	Maestro	37.7840746862308663	-122.425944313208802
114	2019-01-02 15:30:16	2019-01-02	Giada Bailey	giada.bailey@geemail.com	Oakland	California	3718665226362309	9f5e30e338d816c7a6999c086cd1a931	Voyager	37.7997747153270325	-122.294408557383832
115	2019-01-02 16:19:52	2019-01-02	Evelyn Gleason	evelyn.gleason@geemail.com	San Francisco	California	3454704766525069	6433314571c97dfc6ab9bb9c42d9e52d	VISA 16 digit	37.7777085506574863	-122.475558204504125
116	2019-01-02 16:23:44	2019-01-02	Keaton Roberts	keaton.roberts@warmmail.com	San Francisco	California	210019554999018307	aecacc4f3f9a18be568bc7b3056c8c01	Voyager	37.7785934270181016	-122.41759277320574
117	2019-01-02 16:25:04	2019-01-02	Ximena Lindgren	ximena.lindgren@geemail.com	San Francisco	California	3158243552769451847	30cbf266c7e08e60da7303ba4d7104ad	Mastercard	37.7358553082706365	-122.459095419990092
118	2019-01-02 16:55:14	2019-01-02	Mr. Scotty Turcotte Sr.	mr.scotty.turcotte.sr.@geemail.com	San Francisco	California	3704230247115586	c39d9773e49ec8c6238b98d86a8f57ec	JCB 15 digit	37.7687325200479904	-122.414130919000115
119	2019-01-02 17:59:47	2019-01-02	Bret Bednar	bret.bednar@woohoo.com	San Francisco	California	6011557839999496985	3edbeae5d49d6e459cc7fc57d17ca15f	Discover	37.7697899955579217	-122.447517990013623
120	2019-01-02 18:00:32	2019-01-02	Eliga Vandervort	eliga.vandervort@geemail.com	Berkeley	California	869932236506922360	ee03fd7d151fb3d0df663814f3928391	Voyager	37.8821606776505462	-122.243018871511183
121	2019-01-02 18:54:46	2019-01-02	Trinity Smitham	trinity.smitham@geemail.com	Berkeley	California	676228133873662	f3abebdec94171cc93059a5b76a7312e	JCB 16 digit	37.8791149250580403	-122.289829654723334
122	2019-01-02 19:33:34	2019-01-02	Dr. Anders Dickinson PhD	dr.anders.dickinson.phd@geemail.com	San Francisco	California	3096152274085325337	2774488a20a47929298d8c7a16b6b9bb	VISA 16 digit	37.7803838280510789	-122.428331765900637
123	2019-01-02 20:08:25	2019-01-02	Cleda Becker	cleda.becker@geemail.com	Oakland	California	4412926876670	b440057b4a8721c9e518e8f11182f3dd	Mastercard	37.8031373374931547	-122.228600651781406
124	2019-01-02 20:19:29	2019-01-02	Starla Oberbrunner	starla.oberbrunner@geemail.com	Berkeley	California	3088384821046265752	328279b85d2bbe8193a99d3d7c1f3096	VISA 16 digit	37.872945385320989	-122.288960674132781
125	2019-01-02 21:23:02	2019-01-02	Ovid Larkin	ovid.larkin@woohoo.com	San Francisco	California	210014511778878058	26f450cde0b78757ee3c5f0a67ed1839	Voyager	37.8243586466790234	-122.404978135874387
126	2019-01-02 21:25:37	2019-01-02	Dr. Reva Casper	dr.reva.casper@woohoo.com	San Francisco	California	3477174269543626	433940efd22bcdcd719999ff3e9fcbb1	JCB 16 digit	37.764321907861131	-122.423567302228761
127	2019-01-02 21:38:47	2019-01-02	Boris Murray	boris.murray@geemail.com	San Francisco	California	3096353170262920170	5b445cebee828803aa35c54dfc6b027c	VISA 16 digit	37.7905622904825762	-122.40555975211764
128	2019-01-02 23:30:35	2019-01-02	Mr. Hideo Fahey Jr.	mr.hideo.fahey.jr.@geemail.com	San Francisco	California	3096128062063540246	63b0317e46a29067fcb45343cf118ec1	Maestro	37.7514128192693192	-122.457826882665202
129	2019-01-03 00:58:44	2019-01-03	Edward Beatty PhD	edward.beatty.phd@warmmail.com	San Antonio	Texas	869971992819252406	10a43c47f1355430ea92ebaeb166dffd	JCB 16 digit	29.4325781897712488	-98.4970208889175183
130	2019-01-03 00:58:47	2019-01-03	Tab Rice	tab.rice@geemail.com	Chicago	Illinois	53040618564745405	daf67cbee075c1a8718fb4f085daeee9	JCB 16 digit	41.8365833541214514	-87.613139346943413
131	2019-01-03 00:59:16	2019-01-03	Vicente Wiza	vicente.wiza@geemail.com	San Francisco	California	3096869477619483589	354713b2ec2e51b9cb7e32ed5da99f70	JCB 16 digit	37.7624648649856312	-122.448500658384347
132	2019-01-03 01:23:03	2019-01-03	Haylie Koelpin	haylie.koelpin@geemail.com	Berkeley	California	4285309598636307	be97518b2010cd8439cf0affbf382ff1	VISA 13 digit	37.8772879753266167	-122.288462964649938
133	2019-01-03 02:32:34	2019-01-03	Shayna Dibbert-Parisian	shayna.dibbert.parisian@woohoo.com	San Francisco	California	4305936939809460	f5b7767c72aecfad7649b5626e018642	Mastercard	37.7538689205785474	-122.402001752733838
134	2019-01-03 03:03:12	2019-01-03	Vincent Hermann	vincent.hermann@geemail.com	San Francisco	California	4702722251326518	5dc06adbd650a5efe7429ece7a21c915	Maestro	37.7668489547372417	-122.443800782825591
135	2019-01-03 04:34:22	2019-01-03	Britta Welch DVM	britta.welch.dvm@woohoo.com	Berkeley	California	4158543616367	e7db9edabb22d7cfb4a07a118cc48b6a	Mastercard	37.8540174560800935	-122.302520466582124
136	2019-01-03 04:55:20	2019-01-03	Luka Armstrong	luka.armstrong@woohoo.com	San Francisco	California	210036317606682546	b666a5c75757cd70038b55991fdaa104	VISA 16 digit	37.7480083678484633	-122.421594037225333
137	2019-01-03 05:10:47	2019-01-03	Brain Lowe	brain.lowe@geemail.com	San Francisco	California	3781900661860372	2be0ab0da54b009075178302a2840781	American Express	37.7722050427019767	-122.426731086339359
138	2019-01-03 06:07:07	2019-01-03	Mikeal Dare	mikeal.dare@warmmail.com	San Francisco	California	53432303450452228	e85253ca21e951fa91bfc0b31508ef80	VISA 13 digit	37.7853919305418131	-122.430095699394371
139	2019-01-03 06:07:41	2019-01-03	Milagros Lemke	milagros.lemke@woohoo.com	San Francisco	California	3096224518398855818	028f2a556a40416ae8835fca4038a3cf	JCB 16 digit	37.7696339685468416	-122.434648106494876
140	2019-01-03 06:12:27	2019-01-03	Mrs. Daniella Pacocha DVM	mrs.daniella.pacocha.dvm@geemail.com	San Francisco	California	3088856454764021097	c9b26ce6293dc9f8764a57e425fa421a	VISA 13 digit	37.7895121901380335	-122.392422072830044
141	2019-01-03 06:39:03	2019-01-03	Diego Bechtelar	diego.bechtelar@woohoo.com	San Francisco	California	4869620593341	e9bde842fbf2b649ee353c98561e1605	VISA 16 digit	37.7835836598735142	-122.400626896454838
142	2019-01-03 06:45:50	2019-01-03	Carol Auer	carol.auer@geemail.com	San Francisco	California	3784470448454359	8050b24ae49104b040a1de542e08dd6e	VISA 16 digit	37.784914271067656	-122.442229238125009
143	2019-01-03 07:00:20	2019-01-03	Clemon Schamberger	clemon.schamberger@woohoo.com	San Francisco	California	869990435658505291	6594beba8c8942f293f46c198eded46c	Voyager	37.811688583994524	-122.404639293373279
144	2019-01-03 09:04:44	2019-01-03	Angeline Homenick	angeline.homenick@geemail.com	San Francisco	California	210031697518895954	24015275afd876978d93a2b17105e2a5	Voyager	37.7428197655804496	-122.4203461805416
145	2019-01-03 10:54:04	2019-01-03	Brianne Walter	brianne.walter@geemail.com	San Francisco	California	869968621474726785	16a4fa12a2090d3bd408324450cd825a	JCB 16 digit	37.727482530961602	-122.442922492284353
146	2019-01-03 12:09:45	2019-01-03	Bennie Beier DVM	bennie.beier.dvm@geemail.com	San Francisco	California	3088382115092138852	78c4a937a58097a352a25796fd62ba04	JCB 16 digit	37.7848367818438575	-122.439432089504592
147	2019-01-03 14:24:10	2019-01-03	Miss Gwenda Bins PhD	miss.gwenda.bins.phd@geemail.com	Berkeley	California	639012676280949	a7ba5ca61e12cd286ac42e889a0561bd	Diners Club / Carte Blanche	37.8563849446043577	-122.302867740102442
148	2019-01-03 15:14:39	2019-01-03	Delmas Zieme	delmas.zieme@geemail.com	Berkeley	California	3704357810441691	afa47f1a4c3d2cfe7711c1b0d3279365	American Express	37.869293420647935	-122.260978875151949
149	2019-01-03 15:18:30	2019-01-03	Ayden Mayer	ayden.mayer@geemail.com	San Francisco	California	503877546458025	8392a64d8d7f79c9e047e729d8e2e317	VISA 16 digit	37.7905415457622951	-122.428656062023862
150	2019-01-03 17:13:20	2019-01-03	Gussie Bergnaum DVM	gussie.bergnaum.dvm@geemail.com	San Francisco	California	4929148719347	3dad24c7715dbf2025f09133813d71df	VISA 13 digit	37.7693347998723183	-122.399853562642363
151	2019-01-03 17:16:00	2019-01-03	Payton Wyman	payton.wyman@geemail.com	Oakland	California	3446646932499565	e2f63b4c9bb0cb69805d3a7722b24885	Voyager	37.8099314587293662	-122.233518935797377
152	2019-01-03 19:04:12	2019-01-03	Diane Schaefer	diane.schaefer@geemail.com	San Francisco	California	630448741282973	0d5e53fed4f32254c50ed474c78c36e2	JCB 16 digit	37.7614475567880632	-122.446683306041692
153	2019-01-03 21:33:08	2019-01-03	Finley Dare	finley.dare@warmmail.com	San Francisco	California	4978342145063164	61669b7e8db8f06c0f652890b53ad2cd	JCB 16 digit	37.78419107597459	-122.448790400672976
154	2019-01-03 21:52:18	2019-01-03	Ms. Adel Frami	ms.adel.frami@warmmail.com	San Francisco	California	3417581141387738	da42ea8ad91113d4b313a3d2e4f36c6e	VISA 16 digit	37.809892267957288	-122.441144980986763
155	2019-01-03 22:49:28	2019-01-03	Ms. Sina Berge	ms.sina.berge@geemail.com	San Francisco	California	4070939971688811	69c4898a44ef72f9f3840bd05e189365	Voyager	37.7892278143007019	-122.460815545776313
156	2019-01-03 22:55:02	2019-01-03	Vena Okuneva	vena.okuneva@warmmail.com	Oakland	California	4449405546176	42a20f0552fb39798c631f197b8384d9	VISA 16 digit	37.7778097472335261	-122.260305521624034
157	2019-01-03 23:09:55	2019-01-03	Dr. Sean Watsica	dr.sean.watsica@geemail.com	San Francisco	California	3096207979936281068	c07c0b16f877cc4221b3354c19b47b09	Diners Club / Carte Blanche	37.782096874396494	-122.424057491934093
158	2019-01-03 23:41:32	2019-01-03	Belia Hodkiewicz	belia.hodkiewicz@woohoo.com	San Francisco	California	3437607045504684	6c79c932704adde6686d236e5e98411c	Voyager	37.7450204014641315	-122.43440517181412
159	2019-01-03 23:54:22	2019-01-03	Alfredo Kuhlman	alfredo.kuhlman@geemail.com	San Francisco	California	4937167554096987	cbcc4493189c4daee8d1a1a3df2a9b0a	JCB 16 digit	37.7848937505067397	-122.443667787045442
160	2019-01-04 00:35:29	2019-01-04	Roselyn Fay	roselyn.fay@geemail.com	San Francisco	California	869965606242885503	46e60478e5a473b2b2d92539a4dc3ff9	Maestro	37.7134194301195649	-122.468194887530103
161	2019-01-04 00:46:44	2019-01-04	Jermey Johnson	jermey.johnson@geemail.com	San Francisco	California	3112158608717182489	0b3aae7719e5d4cb6eba955fc590aaad	Voyager	37.7724714180290135	-122.417735813388489
162	2019-01-04 01:17:54	2019-01-04	Arman Lebsack	arman.lebsack@geemail.com	San Francisco	California	4949978205738793	1c94546846871206ced1a3d7e1460a97	JCB 16 digit	37.7489793678898877	-122.447459569127048
163	2019-01-04 03:16:13	2019-01-04	Dr. Sheridan Considine Jr.	dr.sheridan.considine.jr.@geemail.com	San Francisco	California	210030222648149007	aef052805b211576912420fb1024338d	Maestro	37.7627721764018389	-122.424928559711631
164	2019-01-04 03:29:25	2019-01-04	Antonia Hoppe	antonia.hoppe@geemail.com	San Francisco	California	55941825402546214	e4d648ac88ff523ecb7782ecc7a4348a	American Express	37.7892751027333702	-122.419759866380318
165	2019-01-04 04:09:59	2019-01-04	Jaslene Batz	jaslene.batz@geemail.com	Jacksonville	Florida	52786613391259520	6651b139a7f4c3098696d01a48d29760	JCB 16 digit	30.41212970987484	-81.624064074837051
166	2019-01-04 08:11:48	2019-01-04	Natalya Langworth	natalya.langworth@geemail.com	San Francisco	California	3088908394792701799	f991ce981112ca07e0cdc3fc23836a4e	Discover	37.7732598575502294	-122.432317306990285
167	2019-01-04 08:33:12	2019-01-04	Darryle Gibson	darryle.gibson@woohoo.com	San Francisco	California	3088837864610371393	941b6185166d77acdb2518eb46b58a6e	JCB 15 digit	37.777160401032873	-122.455216729014111
168	2019-01-04 08:58:21	2019-01-04	Neppie Gutmann DDS	neppie.gutmann.dds@warmmail.com	San Francisco	California	4119032180539	565eb4fb05550ed4fbe44ba1d2710d65	Discover	37.773386732241228	-122.411636525189692
169	2019-01-04 08:59:41	2019-01-04	Tia Rolfson	tia.rolfson@geemail.com	Oakland	California	210063840469876125	61acdd2655c459b6bcfc6d10eee6eea6	Discover	37.8195561492033647	-122.240601340531228
170	2019-01-04 09:35:17	2019-01-04	Norah Kuhn	norah.kuhn@geemail.com	San Francisco	California	3112330930034105923	0dfd2e9e543da8d6da36cf48fc32e630	Discover	37.7368651836927711	-122.420881328100478
171	2019-01-04 09:58:56	2019-01-04	Lukas Considine IV	lukas.considine.iv@geemail.com	San Francisco	California	6011261736852955171	e0b94e051ddea505135f192924fc3f60	JCB 16 digit	37.7828610402997782	-122.451733326322454
172	2019-01-04 10:49:49	2019-01-04	Daron Jerde	daron.jerde@geemail.com	Oakland	California	869930547505169312	5ae2460b0cee85eef1aad3546bc72e01	American Express	37.8256333213354026	-122.252989870470387
173	2019-01-04 11:58:33	2019-01-04	Nakia Conroy MD	nakia.conroy.md@geemail.com	Oakland	California	676247149803661	587de0c9d769785e98f509fbcb12da43	American Express	37.8481686539891058	-122.272639155515549
174	2019-01-04 13:32:44	2019-01-04	Wayne Bruen	wayne.bruen@geemail.com	Austin	Texas	6011693697782173889	a1f5742300f6b37da2499dad5dda66c9	VISA 16 digit	30.2941501971926535	-97.7039371128432492
175	2019-01-04 13:32:52	2019-01-04	Jefferey Bradtke	jefferey.bradtke@geemail.com	Berkeley	California	3528862149046882389	916db962a278a0daeb19a65f71977c34	Voyager	37.8748002595433064	-122.295056211024729
176	2019-01-04 17:07:56	2019-01-04	Mr. Jonathan McLaughlin DVM	mr.jonathan.mclaughlin.dvm@warmmail.com	Oakland	California	53535380243678711	2b16f68b58dfd551e5e05d086fdfdba9	Maestro	37.8160180962316019	-122.254217559918203
177	2019-01-04 17:36:23	2019-01-04	Lillia Auer	lillia.auer@geemail.com	San Francisco	California	51837030468617614	edc513f228caa7cf6120d5c5f798e36f	Discover	37.768388113833268	-122.420316943648842
178	2019-01-04 18:22:40	2019-01-04	Dr. Albert Senger	dr.albert.senger@woohoo.com	Berkeley	California	3337212219716355854	12e0fc440f18774c676a7d6fcb45252e	VISA 16 digit	37.8597507802621607	-122.229988103278217
179	2019-01-04 19:11:05	2019-01-04	Roma Nicolas	roma.nicolas@geemail.com	Oakland	California	52271071565330308	033fe386784fb905bcb310998635d3e5	Diners Club / Carte Blanche	37.8445907041829699	-122.251767434962673
180	2019-01-04 19:40:50	2019-01-04	Fallon Koepp	fallon.koepp@warmmail.com	San Francisco	California	3700152918917104	fbdc97b98745ea485978be5d907294da	JCB 15 digit	37.7643089259228262	-122.432575852934136
181	2019-01-04 19:41:49	2019-01-04	Dink Batz	dink.batz@warmmail.com	San Francisco	California	3528855221890930801	8bf055df4f1dd97ddb9c6907670488c8	JCB 16 digit	37.7936993192040092	-122.427637284102019
182	2019-01-04 21:35:15	2019-01-04	Shannon Kihn	shannon.kihn@woohoo.com	San Francisco	California	3158214660736176259	6fb2351e0e3ca24f8add1d56841dc181	JCB 16 digit	37.7860167428646747	-122.441452801192526
183	2019-01-04 21:51:50	2019-01-04	Miss Blanchie Kerluke	miss.blanchie.kerluke@geemail.com	San Francisco	California	53697593436934709	8acaba90cafe46cbce8fb8d1fd3b00db	Maestro	37.7457909420056552	-122.434149464463573
184	2019-01-04 21:55:26	2019-01-04	Mr. Osborne Runolfsson	mr.osborne.runolfsson@warmmail.com	San Francisco	California	3528161093179039417	170cc007e02497a26447ab057ad905ae	Voyager	37.7679621206891554	-122.433065950141028
185	2019-01-04 22:20:44	2019-01-04	Nereida Langworth PhD	nereida.langworth.phd@geemail.com	San Francisco	California	55512619489170918	4bc80fa23f5f03e19638b3ae5b9c58ed	JCB 16 digit	37.7704187786677608	-122.416348742804701
186	2019-01-04 22:39:30	2019-01-04	Wilfrid Ernser	wilfrid.ernser@geemail.com	Oakland	California	869983131414047301	d1d6174628f697b50e2da9f7b8373dd0	Diners Club / Carte Blanche	37.7934693054625583	-122.24259122551878
187	2019-01-04 22:42:30	2019-01-04	Mr. Arno Johns	mr.arno.johns@woohoo.com	San Francisco	California	4574584438778	bc2bab8719229aef77aeac76e893b37e	American Express	37.7707462715722357	-122.436036409520355
188	2019-01-04 22:43:52	2019-01-04	Mr. Knute Crona	mr.knute.crona@geemail.com	San Francisco	California	4745544969564191	dd642604bf55562530689331b70f12f1	JCB 15 digit	37.7387574834862889	-122.428348708928823
189	2019-01-04 23:04:02	2019-01-04	Alivia Hilll	alivia.hilll@warmmail.com	San Francisco	California	869985047438468984	3e3366178f3f00f81a19337f783ef38b	VISA 13 digit	37.7659736751761912	-122.405798882574217
190	2019-01-04 23:35:28	2019-01-04	Jaret Ullrich II	jaret.ullrich.ii@warmmail.com	San Francisco	California	4489719851031075	5518432042f9fe107d380b9c9b4ec488	Maestro	37.75713603192672	-122.427202349928862
191	2019-01-05 01:43:06	2019-01-05	Lavelle Gleichner-Cormier	lavelle.gleichner.cormier@geemail.com	San Francisco	California	210006643839795847	88a8c662e5358ee0b66606fe6577c155	JCB 16 digit	37.7175810135270382	-122.428092234225119
192	2019-01-05 02:36:39	2019-01-05	Magnolia Thiel	magnolia.thiel@geemail.com	San Francisco	California	3158540404789960953	5bb10259ec690634039ef6e1c0a50ccd	Voyager	37.7631005889817786	-122.452430933109355
193	2019-01-05 02:39:53	2019-01-05	Hortencia Zulauf	hortencia.zulauf@geemail.com	Berkeley	California	3705554915953617	4dda738cd3b36a98c51497a8f8e170b8	JCB 16 digit	37.8716618043233524	-122.287517276100161
194	2019-01-05 04:24:03	2019-01-05	Arlyn Boyle	arlyn.boyle@geemail.com	San Francisco	California	3054080877161040	37b4d8dd2d3f6fa9b5a96b109128edb6	Voyager	37.7709106261167804	-122.402336255196616
195	2019-01-05 04:37:16	2019-01-05	Cordia Koelpin MD	cordia.koelpin.md@geemail.com	San Francisco	California	6011586949409249554	285097b198bf49d89155d97b878a1390	JCB 16 digit	37.7547072742846979	-122.422555708519511
196	2019-01-05 05:53:29	2019-01-05	Mr. Claus Prohaska DDS	mr.claus.prohaska.dds@geemail.com	Berkeley	California	3039135620507355	bcb2be6de68804a12611a825d5e1b71d	Mastercard	37.8867392197898383	-122.25919265931114
197	2019-01-05 06:23:41	2019-01-05	Roma Maggio	roma.maggio@woohoo.com	Oakland	California	3037719447990753	b234642337d98d9c8168900705b055f8	Diners Club / Carte Blanche	37.7922728483722068	-122.286867179605167
198	2019-01-05 07:14:00	2019-01-05	Hali Abshire	hali.abshire@geemail.com	San Francisco	California	869961273429415101	c27de32ab3ca4e93f954f7ce008bc882	JCB 16 digit	37.7776139265229389	-122.414257254784445
199	2019-01-05 09:09:45	2019-01-05	Mace Lynch	mace.lynch@geemail.com	Oakland	California	869965693297832119	2b25ad8dca38e9b828d625415dc1c0c0	VISA 16 digit	37.7886409846151636	-122.27460320392079
200	2019-01-05 09:32:01	2019-01-05	Jeanetta Haag PhD	jeanetta.haag.phd@geemail.com	Oakland	California	3036915707034578	4b233bbafc7a10d63bd593f3e2735256	JCB 15 digit	37.801645661753895	-122.295437177369266
201	2019-01-05 10:33:06	2019-01-05	Tammi Hayes	tammi.hayes@warmmail.com	San Francisco	California	180048828234267142	c556412410074ffb428dbfa0618115b3	Discover	37.7873645056632981	-122.42584841409824
202	2019-01-05 11:10:19	2019-01-05	Bailee Deckow PhD	bailee.deckow.phd@geemail.com	San Francisco	California	3088579174709914588	b5bd1037be0108f0feaa8e052eab3f7b	Diners Club / Carte Blanche	37.8260175854405531	-122.441800544677591
203	2019-01-05 11:23:02	2019-01-05	Stephanie Douglas	stephanie.douglas@geemail.com	San Francisco	California	4442390415654111	2e09ca6c7986c5bd961dba852b7558f9	JCB 16 digit	37.8120509582693458	-122.42344765640847
204	2019-01-05 11:28:56	2019-01-05	Mimi Casper	mimi.casper@geemail.com	San Francisco	California	675949204492646	8ac026fdd80f68f207e32570cad1e71b	American Express	37.7724750873860557	-122.421663935039945
205	2019-01-05 11:46:05	2019-01-05	Urban Kemmer DDS	urban.kemmer.dds@woohoo.com	San Francisco	California	4150977575527319	7e648e590c2b42e5e306c8fda127bd0a	JCB 16 digit	37.7762711957380262	-122.417431154031945
206	2019-01-05 11:58:41	2019-01-05	Chelsie Rogahn	chelsie.rogahn@geemail.com	Jersey City	New Jersey	3337626483747193979	5b2ffe21099c36b31f6ae34dc701187d	Discover	40.6262927815724169	-74.1623801694207003
207	2019-01-05 12:33:15	2019-01-05	Geoffrey Gaylord DVM	geoffrey.gaylord.dvm@geemail.com	Oakland	California	210073873887281089	b6ebbc5b139fe8b0601a3fbc13ff7ddf	Discover	37.8292384420374361	-122.269363754955947
208	2019-01-05 13:53:01	2019-01-05	Heriberto Bashirian	heriberto.bashirian@geemail.com	San Francisco	California	3096465131922681920	f79f068aa0c49a4d27dc32f33616793b	Discover	37.756098100469174	-122.422347405672795
209	2019-01-05 15:12:57	2019-01-05	Mr. Harrell Doyle	mr.harrell.doyle@geemail.com	San Francisco	California	4150682461742457	2512d2549177ddaed4a09fa91b85f9a1	American Express	37.7488690288039805	-122.437972284543747
210	2019-01-05 16:45:53	2019-01-05	Jonathan Corwin-Collins	jonathan.corwin.collins@geemail.com	San Francisco	California	3015782989797269	a170598bd1a99074f487cc2e8b6a3061	JCB 15 digit	37.7768428124275744	-122.462149425834255
211	2019-01-05 17:27:12	2019-01-05	Weaver Raynor	weaver.raynor@geemail.com	San Francisco	California	3112972663327845532	fc0e36dee167b86429344cbf0cc49c35	JCB 15 digit	37.800815176479361	-122.460201491634564
212	2019-01-05 21:32:31	2019-01-05	Tavaris D'Amore	tavaris.d'amore@geemail.com	Waco	Texas	3791589036658559	99d2ab68c6f25bd829057a0115ab2ffb	Mastercard	31.6010171578474335	-97.142905946088959
213	2019-01-05 21:49:10	2019-01-05	Emmitt Boehm	emmitt.boehm@geemail.com	San Francisco	California	4093471136784692	6d9bd52f3efaf7f5219cd90340ebd204	Maestro	37.7548650338123508	-122.436889323627042
214	2019-01-05 22:33:39	2019-01-05	Ibrahim Moore	ibrahim.moore@woohoo.com	San Francisco	California	4901062103355566	83794a9c862e1e7010141763fecde338	JCB 15 digit	37.7451171680115678	-122.462775193253549
215	2019-01-05 23:42:22	2019-01-05	Chace Terry-Boehm	chace.terry.boehm@geemail.com	Berkeley	California	3720489370872005	092f85ca9f200aab2ef4717b80e50aac	Maestro	37.8883539460864185	-122.22248056161213
216	2019-01-05 23:51:44	2019-01-05	Fenton McClure	fenton.mcclure@geemail.com	Oakland	California	4552904929411	82ad007db6cdd11c981e040d7f7c1c69	VISA 16 digit	37.7986515507461647	-122.283684844812797
217	2019-01-06 03:53:32	2019-01-06	Dr. Talon Schneider	dr.talon.schneider@geemail.com	Berkeley	California	3158160530278779915	09a045bd1634d626ca3d04557b24933a	Mastercard	37.8436241388368373	-122.296519207360802
218	2019-01-06 04:40:53	2019-01-06	Devon McKenzie	devon.mckenzie@geemail.com	San Francisco	California	51094832438601885	59a499e70f18727b5e887ed49fc12ca5	JCB 16 digit	37.7432304016862261	-122.416342292751764
219	2019-01-06 06:45:36	2019-01-06	Britany Stracke	britany.stracke@geemail.com	Berkeley	California	180059179010571604	726ebdc88231c694c5aaed066a661465	VISA 16 digit	37.8477455530792	-122.262684805908933
220	2019-01-06 08:53:22	2019-01-06	Mr. Pershing Kuhlman Sr.	mr.pershing.kuhlman.sr.@geemail.com	Berkeley	California	3112217719602071924	e864a3e26ac696cdff1a8249d5788869	JCB 15 digit	37.8698400140736169	-122.261311837824238
221	2019-01-06 09:12:19	2019-01-06	Patience McKenzie	patience.mckenzie@geemail.com	San Francisco	California	3437919173543693	0c86ca7f74c730dc904c3cfd9bfd0eec	VISA 13 digit	37.7722796804145204	-122.471845621282299
222	2019-01-06 10:55:54	2019-01-06	Delos Hauck	delos.hauck@warmmail.com	Berkeley	California	6011309858301795901	552023d49d6f74a82156d84331b81bf2	Voyager	37.8427665527903301	-122.264010838907865
223	2019-01-06 11:14:12	2019-01-06	Dr. Saul Dooley PhD	dr.saul.dooley.phd@geemail.com	San Francisco	California	54413380020120710	3efa9712126ce6084674575cc985a64b	Diners Club / Carte Blanche	37.7697504095686583	-122.439675101789447
224	2019-01-06 11:54:53	2019-01-06	Bascom Cassin	bascom.cassin@geemail.com	Berkeley	California	3096638524213197030	73ea74ee1372837dc8d03eab226ba67d	JCB 16 digit	37.8680398269984337	-122.260084195678033
225	2019-01-06 12:09:30	2019-01-06	Kendall Schulist-Ziemann	kendall.schulist.ziemann@geemail.com	San Francisco	California	6011966967828838773	26b6add62e87cd08331768b311bdc450	JCB 16 digit	37.7898982152872378	-122.452799593262341
226	2019-01-06 15:05:47	2019-01-06	Stefan Wiza	stefan.wiza@warmmail.com	San Francisco	California	6011188053531661257	6b7255e7c16b561800845a53114731ad	VISA 16 digit	37.8038755518257261	-122.422699488560099
227	2019-01-06 17:06:55	2019-01-06	Sloane Rempel	sloane.rempel@warmmail.com	Oakland	California	060448754432242	358efa65b45925acb948f2d9d7cb970a	VISA 13 digit	37.8086382265773366	-122.278858059206428
228	2019-01-06 17:19:18	2019-01-06	Mr. Albertus Lind Sr.	mr.albertus.lind.sr.@warmmail.com	San Francisco	California	54719810048419018	c7b315dd4ae54a084f65f4f4a553dc22	JCB 15 digit	37.7869705983398489	-122.426659283507931
229	2019-01-06 17:41:42	2019-01-06	Marlon Schiller	marlon.schiller@geemail.com	San Francisco	California	3112914763135407136	b55df2a143931f6d20a112bdee28b624	American Express	37.7980648188039723	-122.445136692796808
230	2019-01-06 18:33:43	2019-01-06	Trula Wuckert-Cartwright	trula.wuckert.cartwright@geemail.com	Chicago	Illinois	4792203521409336	b8adbc4094e09550bb84a3d835bf73a5	JCB 15 digit	41.8367151764523229	-87.6396504535835135
231	2019-01-06 20:12:51	2019-01-06	Johney Stokes-Nader	johney.stokes.nader@geemail.com	Atlanta	Georgia	3047461307658994	fdbd0ecc010a354a00a8489898949aaa	JCB 15 digit	33.6969005630161647	-84.3453594612933699
232	2019-01-06 21:18:22	2019-01-06	Gillie Yundt	gillie.yundt@geemail.com	San Francisco	California	3158719054846053550	5945ed739319b6bc66c4515b44181918	JCB 16 digit	37.7545047309132187	-122.401083670631266
233	2019-01-06 21:25:35	2019-01-06	Dr. Stone Schowalter MD	dr.stone.schowalter.md@geemail.com	San Francisco	California	6011883453919600802	ff67acf98de76922f284262d0dac0051	American Express	37.760348308226007	-122.405817414100341
234	2019-01-06 21:53:48	2019-01-06	Brook Marvin	brook.marvin@warmmail.com	San Francisco	California	869996994820340619	5abaad4643d13d9a224d3f67f8b11f2e	Voyager	37.7582375503187464	-122.443707701287664
235	2019-01-06 22:18:51	2019-01-06	Dr. Evelyn Klocko	dr.evelyn.klocko@geemail.com	San Francisco	California	4438353479669249	89d1e6f2dc1bcf5749ff59f06d16ef7b	Maestro	37.7754872278328904	-122.414558621450311
236	2019-01-06 23:59:29	2019-01-06	Samara Orn-Stroman	samara.orn.stroman@woohoo.com	San Francisco	California	6011369847869221753	002a883ce7e2a3b3c69ec96e1c48999e	JCB 16 digit	37.7701591603226277	-122.444226232485732
237	2019-01-07 01:21:47	2019-01-07	Jazmyn O'Hara	jazmyn.o'hara@woohoo.com	San Francisco	California	51776180517695534	9912aa970eb43fa33c0362870ee9a8b4	JCB 16 digit	37.7540526943506052	-122.411295730670929
238	2019-01-07 09:18:45	2019-01-07	Keanu Ziemann	keanu.ziemann@geemail.com	Berkeley	California	3736155414989335	ace3a7f1f9f366adbf5aafa22db8f834	Maestro	37.9057359104724796	-122.25912979229372
239	2019-01-07 10:12:10	2019-01-07	Albert Funk PhD	albert.funk.phd@geemail.com	San Francisco	California	4995959900904	185e53343ffb807392dadc384bee9ca8	Diners Club / Carte Blanche	37.7635958468945745	-122.411107530536071
240	2019-01-07 11:02:32	2019-01-07	Joesph Moore	joesph.moore@warmmail.com	Berkeley	California	4561097318884548	05f006d40538e71703cb13081da3ae99	Voyager	37.8297826718052406	-122.260461934423745
241	2019-01-07 11:51:28	2019-01-07	Miss Mae Bednar MD	miss.mae.bednar.md@warmmail.com	Oakland	California	630469964843952	ddbc876bdcfc6c4329c4c4629d3b21ce	American Express	37.7770744221776695	-122.280435293313104
242	2019-01-07 13:47:50	2019-01-07	Ruffin Kunze	ruffin.kunze@geemail.com	Berkeley	California	3112841474384361044	9565cdd89ed3be76a8a4ea6c78ae8381	JCB 15 digit	37.8691292448314343	-122.274539186998538
243	2019-01-07 13:52:19	2019-01-07	Lue Will-Rogahn	lue.will.rogahn@geemail.com	New York	New York	4281794862835	56d6f5af784b3d3601d4e76c233fd8e2	Maestro	40.636460212454196	-73.8396200807195129
244	2019-01-07 15:13:08	2019-01-07	Lashunda Murray	lashunda.murray@warmmail.com	Gilbert	Arizona	561296485877201	c4df26b824b737b943538bf069ce6b0f	VISA 13 digit	33.3483226970650222	-111.727257593315471
245	2019-01-07 18:07:21	2019-01-07	Leonel Bednar	leonel.bednar@geemail.com	Berkeley	California	630465360140217	b6e730d5762ea0b67b961f236e06554d	JCB 16 digit	37.8660326272350147	-122.27186941777704
246	2019-01-07 19:21:09	2019-01-07	Mr. Jaimie Dietrich V	mr.jaimie.dietrich.v@warmmail.com	San Francisco	California	4906059991131930	46bf0615108bb86972863fb155bd7134	Diners Club / Carte Blanche	37.7711953131197475	-122.434733774494944
247	2019-01-07 19:30:06	2019-01-07	Mrs. Lauren Corwin	mrs.lauren.corwin@geemail.com	San Francisco	California	3417652341307394	5243b1400be41e42a7cef5230453b007	JCB 16 digit	37.8163060369462087	-122.423859808773173
248	2019-01-07 19:34:41	2019-01-07	Dr. Jaden Gibson III	dr.jaden.gibson.iii@woohoo.com	San Francisco	California	3054892153701871	db1c30a1bc84898cea638d96ea18af54	JCB 15 digit	37.7617728682936047	-122.454727777725225
249	2019-01-07 20:04:22	2019-01-07	Octavius Johnston	octavius.johnston@geemail.com	Berkeley	California	4403666003930	f675c0038dc023f1486b9da2094fed90	Diners Club / Carte Blanche	37.8914560109996543	-122.251240543005082
250	2019-01-07 20:26:30	2019-01-07	Dr. Wallace Graham	dr.wallace.graham@geemail.com	San Francisco	California	869920110709512993	8abac6b5479daac2655f4ab0cbaef771	Voyager	37.7639505448461108	-122.430840159000539
251	2019-01-07 20:39:09	2019-01-07	Miss Clella Donnelly MD	miss.clella.donnelly.md@geemail.com	San Francisco	California	4149139000140085	229f786872c9f088ad13e97df8926cad	VISA 16 digit	37.7644118961767461	-122.406544533478339
252	2019-01-07 21:53:57	2019-01-07	Makayla Daniel DDS	makayla.daniel.dds@geemail.com	Oakland	California	4078196879448010	fc0d10042ea4824ba0331d28c7dc0325	Diners Club / Carte Blanche	37.7749105263533664	-122.265000858781889
253	2019-01-07 21:56:34	2019-01-07	Jahiem Shanahan	jahiem.shanahan@geemail.com	San Francisco	California	54102695847015694	2d59b124ac338a212e39a443eb5b1bf9	Voyager	37.7518010170914309	-122.450822482957875
254	2019-01-08 02:06:34	2019-01-08	Remy Considine	remy.considine@geemail.com	Oakland	California	6011761235924801229	0dfdd404581275eedbd16a7c284710e8	JCB 16 digit	37.7925229553191002	-122.241826185774926
255	2019-01-08 06:02:46	2019-01-08	Haiden Collier	haiden.collier@woohoo.com	San Francisco	California	210083723721511340	3a92955b59c4db5d5042e72af2761e64	VISA 13 digit	37.7783193972240809	-122.412731161609273
256	2019-01-08 06:04:51	2019-01-08	Ms. Yulisa Weissnat DDS	ms.yulisa.weissnat.dds@warmmail.com	Oakland	California	4097573871585	a139828efeb89c29e65e88b637da5df3	JCB 15 digit	37.7737859270392917	-122.270534692139989
257	2019-01-08 12:58:30	2019-01-08	Cleveland White	cleveland.white@woohoo.com	San Francisco	California	3037439478511259	35a7a3e8c225bd59fc18cac6fe036073	JCB 15 digit	37.7967806473544954	-122.425419024160561
258	2019-01-08 13:15:08	2019-01-08	Leyla Pouros-Steuber	leyla.pouros.steuber@geemail.com	New York	New York	3337611325121797452	000fbbad7ec2c72e4fe47aff243e7fef	VISA 16 digit	40.7229613599590934	-73.9002094631444635
259	2019-01-08 14:49:46	2019-01-08	Cliff Marquardt	cliff.marquardt@woohoo.com	San Francisco	California	4337971719212	43d12325e71980be901023e8b9de98d5	Diners Club / Carte Blanche	37.7731511146003527	-122.441836421215172
260	2019-01-08 14:56:38	2019-01-08	Christopher Larkin	christopher.larkin@geemail.com	Berkeley	California	210029030598098790	e43f49e4f7e6a15c181bfbdcb9154523	VISA 16 digit	37.8794936921036935	-122.260838754067876
261	2019-01-08 15:57:56	2019-01-08	Takisha Hackett	takisha.hackett@geemail.com	Berkeley	California	589326476108795	1ad5b83def2470448a0d55b2b20c8a2c	American Express	37.8533827140047592	-122.295177900596229
262	2019-01-08 16:15:35	2019-01-08	Karma Rodriguez-Barrows	karma.rodriguez.barrows@geemail.com	San Francisco	California	3013814746620153	9aaf2d84d69c04f6cc86ec8c3806f4c1	Diners Club / Carte Blanche	37.795201460773157	-122.390292157276647
263	2019-01-08 17:06:36	2019-01-08	Delvin Beahan-Breitenberg	delvin.beahan.breitenberg@geemail.com	Peoria	Arizona	51437040263927948	63524694e399a4fb1de3938be644633e	Diners Club / Carte Blanche	33.8279211387306447	-112.315935848692433
264	2019-01-08 17:10:17	2019-01-08	Amerigo Bartoletti	amerigo.bartoletti@warmmail.com	San Francisco	California	3337374824688334862	48a5ecca601ea8476a616ec6709a81e9	Diners Club / Carte Blanche	37.8027179048644442	-122.444347223396051
265	2019-01-08 18:16:03	2019-01-08	Miss Nia Block MD	miss.nia.block.md@woohoo.com	San Francisco	California	54262608174382203	5f888eb58e22bf671cb6bb51ed319a89	VISA 16 digit	37.762930544521268	-122.447739936202254
266	2019-01-08 18:18:50	2019-01-08	Mr. Hilario Yost IV	mr.hilario.yost.iv@geemail.com	San Francisco	California	4321968024293029	7a53f696fbbb565d58b18e72c2b1c2cc	Voyager	37.7710627566668435	-122.456578256630152
267	2019-01-08 18:28:58	2019-01-08	Jones Waters	jones.waters@geemail.com	San Francisco	California	3337979296935212242	dcbe7733035f5959c005cf29e00cf80c	JCB 15 digit	37.7736738027624455	-122.373034557117307
268	2019-01-08 22:19:54	2019-01-08	Lily Swaniawski PhD	lily.swaniawski.phd@woohoo.com	San Francisco	California	180000574513787287	feaeacf4c8cfbe9d6635e6e526769268	VISA 13 digit	37.7855619866174166	-122.446524813442579
269	2019-01-08 22:41:02	2019-01-08	Alondra Jacobi	alondra.jacobi@geemail.com	San Francisco	California	180099688249077078	81e42c3a31f25c78d1f1c1c9af54d237	Maestro	37.7369752948855393	-122.448512452915836
270	2019-01-08 23:50:23	2019-01-08	Carmen Luettgen	carmen.luettgen@geemail.com	San Francisco	California	4765737298255	0f412b7f9a3c1744cc28502eabea72a8	JCB 16 digit	37.7636249758831042	-122.425947886034095
271	2019-01-09 01:14:16	2019-01-09	Willie McDermott	willie.mcdermott@warmmail.com	San Francisco	California	6011722536713296440	65e780d76f6223e1bef09087007804ff	Discover	37.7997054671262873	-122.417762284588449
272	2019-01-09 04:33:05	2019-01-09	Miss Antonina Gorczany	miss.antonina.gorczany@geemail.com	Tampa	Florida	51514289353311937	9dec305fc66c7168d0895f5f82c90612	Voyager	28.0346491560921045	-82.4426586526192722
273	2019-01-09 04:48:10	2019-01-09	Dr. Cicely Nitzsche	dr.cicely.nitzsche@woohoo.com	San Francisco	California	210052988262356952	6f3bb73d5b9a7c41cd4fd1d10e7a6456	Discover	37.7872272337412483	-122.463114870612856
274	2019-01-09 09:28:05	2019-01-09	Milagros Hermann	milagros.hermann@warmmail.com	Berkeley	California	51663998914388064	928112e24f211c564a3a45b113ceff0f	VISA 13 digit	37.8420364353171621	-122.302095533101934
275	2019-01-09 12:38:33	2019-01-09	Salena Parker DVM	salena.parker.dvm@geemail.com	San Francisco	California	675925876913663	86cfc8ad053a5247975c8fe02658e74c	JCB 16 digit	37.7406528270263379	-122.419360316190804
276	2019-01-09 12:41:00	2019-01-09	Madlyn Friesen	madlyn.friesen@geemail.com	San Francisco	California	3528313361994615555	e29bdce3a09fca065003213dbe6ad944	VISA 16 digit	37.7658137102984455	-122.43321385262071
277	2019-01-09 13:07:26	2019-01-09	Kinley Hagenes	kinley.hagenes@geemail.com	Wichita	Kansas	51005777624197883	f1cc170d83ac57651a554ec56d2f5b75	JCB 16 digit	37.7778218804270054	-97.34948304493129
278	2019-01-09 14:07:43	2019-01-09	Ms. Tomeka Prosacco DDS	ms.tomeka.prosacco.dds@warmmail.com	San Francisco	California	3096073405368897974	e10cb5f9a1c940fc944f91d0dd26ac74	Discover	37.7389204516137085	-122.399837559369161
279	2019-01-09 16:43:05	2019-01-09	Colette Stark-Kuhn	colette.stark.kuhn@warmmail.com	San Francisco	California	3038063819524562	37f13f58b84880834965ba077ac10240	Voyager	37.7388896234050222	-122.444417276496722
280	2019-01-09 20:28:11	2019-01-09	Shelley Kertzmann-Stroman	shelley.kertzmann.stroman@geemail.com	San Francisco	California	630473704069720	70184aa670e394cd7750c8dbb3195e56	Mastercard	37.7739635482697054	-122.409660865880895
281	2019-01-09 21:09:56	2019-01-09	Rutha Turcotte-Rodriguez	rutha.turcotte.rodriguez@geemail.com	San Francisco	California	210042870758027748	1c92f9b2d036070cbcc4a3837e5a7caa	VISA 13 digit	37.7595122664430463	-122.4613566807881
282	2019-01-09 21:55:44	2019-01-09	Mrs. Pinkie Heller	mrs.pinkie.heller@geemail.com	San Francisco	California	501858057834259	e90cfb8b8f45e365b53f88a148c6e4a3	VISA 16 digit	37.7775378350679816	-122.426593143805448
283	2019-01-09 23:21:09	2019-01-09	Mr. Eric Nikolaus	mr.eric.nikolaus@geemail.com	San Francisco	California	869949565201946527	065feb0b7c313dbd7236b333c105f507	JCB 15 digit	37.7698914048552083	-122.431254446363354
284	2019-01-10 00:53:30	2019-01-10	Arlyn Hauck DVM	arlyn.hauck.dvm@geemail.com	Fort Worth	Texas	3758544143793311	b13bc8e62948d0ea104dc2060cd4f55e	VISA 16 digit	32.7079676203019929	-97.3891484328366772
285	2019-01-10 05:07:24	2019-01-10	Izayah Cummings	izayah.cummings@geemail.com	San Francisco	California	869976482018066315	53854bc7e8b2cc11a130b45d403ef34f	VISA 16 digit	37.766745970377265	-122.421195508191403
286	2019-01-10 05:31:59	2019-01-10	Hali Glover	hali.glover@geemail.com	San Francisco	California	4627113143762	49d6c37d83ca354575484f3e918f51cf	JCB 16 digit	37.7443467374183399	-122.434442258983907
287	2019-01-10 05:41:25	2019-01-10	Miss Ula Turcotte DVM	miss.ula.turcotte.dvm@geemail.com	San Francisco	California	4977328004885731	a8d579a7761e5f52a07b3a9892c38ec5	Maestro	37.7528853957179891	-122.427804714390817
288	2019-01-10 07:55:53	2019-01-10	Brett Schulist	brett.schulist@woohoo.com	San Francisco	California	4663352066950703	5953b43db1fb6988402a52f52a0eaa31	Diners Club / Carte Blanche	37.7394958688790183	-122.433763863591167
289	2019-01-10 08:35:16	2019-01-10	Trena Keeling	trena.keeling@geemail.com	San Francisco	California	4649603214865519	d7eb0aa285e7dc4d171bfd6b89d3abab	VISA 13 digit	37.7717087609630511	-122.434294468807622
290	2019-01-10 08:56:26	2019-01-10	Ms. Madyson Mosciski DVM	ms.madyson.mosciski.dvm@geemail.com	San Francisco	California	3112767836709060008	21a4efbd804a6d723b5947b24354059c	JCB 16 digit	37.7407259325415652	-122.427745421672171
291	2019-01-10 09:45:15	2019-01-10	Miss Parker Little MD	miss.parker.little.md@geemail.com	Berkeley	California	3445061493523061	2a568ff95598c9a7552dd9775deac8a7	Maestro	37.8797131176496293	-122.276243670161165
292	2019-01-10 10:28:18	2019-01-10	Dr. Coletta Ankunding DVM	dr.coletta.ankunding.dvm@geemail.com	Los Angeles	California	4369921174838740	ce9fcfff091d2c4beb828344370db305	Mastercard	33.9801034638524015	-118.47769294199459
293	2019-01-10 11:28:18	2019-01-10	Caprice Beahan	caprice.beahan@warmmail.com	San Francisco	California	3015675810141998	5315d30097d0f18384b99da97f4187b2	Maestro	37.7654698065615051	-122.403198527412485
294	2019-01-10 12:01:03	2019-01-10	Ms. Clemence Wolf MD	ms.clemence.wolf.md@warmmail.com	San Francisco	California	4001957306639196	b01190157074858a86716365677868fd	American Express	37.7553997764857172	-122.447295173029147
295	2019-01-10 15:29:16	2019-01-10	Corliss Schowalter	corliss.schowalter@warmmail.com	San Francisco	California	3096112627546744488	b08002a397c807992db0f2486cd4c0ae	Discover	37.7935197401648324	-122.441973420969163
296	2019-01-10 16:47:03	2019-01-10	Shelia Jast	shelia.jast@geemail.com	San Francisco	California	676290684740005	9a3fb1f8894c285ea65348748cf4b793	JCB 15 digit	37.8006826252992809	-122.417589364111123
297	2019-01-10 18:22:54	2019-01-10	Dionicio Mayer	dionicio.mayer@woohoo.com	San Francisco	California	6011037429913984025	d65b4e38efcaca0d8f8e9a53bd16a9c2	JCB 16 digit	37.7775876787384348	-122.427604258779112
298	2019-01-11 00:23:52	2019-01-11	Bruno Oberbrunner-Howe	bruno.oberbrunner.howe@geemail.com	San Francisco	California	3465181406441493	7919a393c0222df55175585b2df76519	Voyager	37.7896179183027741	-122.395213272717626
299	2019-01-11 02:34:48	2019-01-11	Nadine O'Reilly	nadine.o'reilly@warmmail.com	San Francisco	California	4135687603907835	5b136336487c874de4db06a9a027d932	Maestro	37.7451659010128679	-122.419109926715066
300	2019-01-11 08:53:45	2019-01-11	Malcolm Rippin-Runte	malcolm.rippin.runte@geemail.com	Dallas	Texas	4035682893468763	9ee5060fadd8a308398143ec8cd8c149	VISA 16 digit	32.8315864902727341	-96.7781567254532007
301	2019-01-11 12:26:28	2019-01-11	Marsha Lowe	marsha.lowe@geemail.com	Oakland	California	52340196122735843	da365fb30d9b02cfa9cbf8a13e671fd8	Discover	37.7759982243592134	-122.248932861248278
302	2019-01-11 12:50:08	2019-01-11	Randolf Hayes I	randolf.hayes.i@geemail.com	San Francisco	California	869902435419152356	352a3648fec35deeef49202d3043fc5e	VISA 13 digit	37.766878999477882	-122.379679343752827
303	2019-01-11 16:18:00	2019-01-11	Grayson Hoeger-Ankunding	grayson.hoeger.ankunding@geemail.com	Berkeley	California	4718825652115	b72e82d238b6ac386b1e0fd0ae43a97b	JCB 16 digit	37.8531818484611406	-122.310117883377146
304	2019-01-11 17:16:01	2019-01-11	Lilliana Rippin	lilliana.rippin@geemail.com	San Francisco	California	869989058973787494	5d5569530a3d4bc036f19b53514e4e80	Mastercard	37.7898167004978234	-122.422153525932302
305	2019-01-11 17:18:09	2019-01-11	Dr. Esley Medhurst IV	dr.esley.medhurst.iv@geemail.com	San Francisco	California	3088767225458148836	274a83159e69f532b8434c00e800721a	JCB 15 digit	37.7599629042815508	-122.437810280283827
306	2019-01-11 20:00:12	2019-01-11	Jordan Zboncak	jordan.zboncak@geemail.com	Washington	District of Columbia	3112271916739381316	2cd51079ee73debe9333108a75f6a0be	Discover	38.9828972018122641	-77.091571633492407
307	2019-01-11 21:21:02	2019-01-11	Fleta O'Keefe MD	fleta.o'keefe.md@geemail.com	San Francisco	California	4599943473448	5db00e6d7e1071d4d310bec0f7a5bd0a	VISA 16 digit	37.7630929414969998	-122.42939732093653
308	2019-01-11 21:52:15	2019-01-11	Miss Sarrah Emmerich MD	miss.sarrah.emmerich.md@geemail.com	San Francisco	California	4813476074428	60b3811d88e886e47de431d2dc524069	JCB 15 digit	37.7567610319690985	-122.43104988910541
309	2019-01-11 22:34:46	2019-01-11	Philip Rosenbaum	philip.rosenbaum@geemail.com	San Francisco	California	3337505150949581345	30d46bbc2d073ee42e50783b207fa4c3	VISA 16 digit	37.7850153792377199	-122.420063969598189
310	2019-01-12 01:28:14	2019-01-12	Camille Beatty	camille.beatty@warmmail.com	San Francisco	California	4925576847212843	414001a27692de5f238bf0f93016fe65	Voyager	37.7224671920942427	-122.467363946193331
311	2019-01-12 03:17:38	2019-01-12	Mrs. Frida Morissette PhD	mrs.frida.morissette.phd@geemail.com	San Francisco	California	869913100353467577	f145f42c51d5828b9cfd1a9e80e57e5a	Maestro	37.7503968321874694	-122.423449064552855
312	2019-01-12 05:22:01	2019-01-12	Dr. Jaslene Rosenbaum	dr.jaslene.rosenbaum@geemail.com	Oakland	California	3053343491301389	680cdcba0b7595cd5b3dff6ebff6ff7b	JCB 16 digit	37.7804660136871959	-122.276581722992105
313	2019-01-12 08:33:42	2019-01-12	Ozzie Russel	ozzie.russel@geemail.com	San Francisco	California	869974286042622452	daeb6b9b76ef1a9e271d8b54ffb06b67	VISA 16 digit	37.8368149045210487	-122.421172718994214
314	2019-01-12 08:42:03	2019-01-12	Dr. Gage Purdy V	dr.gage.purdy.v@geemail.com	San Francisco	California	3528418353027655603	7f08b1691e30a7469a59ca7ad04e0acb	VISA 13 digit	37.734738110642013	-122.436424462875749
315	2019-01-12 10:33:45	2019-01-12	Jaquan DuBuque	jaquan.dubuque@warmmail.com	San Francisco	California	3761260493666305	16ca483dfc0902ef2ad35b86b6d3b2d8	Voyager	37.7620082558685723	-122.421232592168295
316	2019-01-12 14:03:32	2019-01-12	Trevion Rempel	trevion.rempel@warmmail.com	Atlanta	Georgia	4986358069450567	ac1aacb354a3892bcfec466c03af5c89	Diners Club / Carte Blanche	33.7237283622656037	-84.5205310088161497
317	2019-01-12 14:06:27	2019-01-12	Kennith Wisozk III	kennith.wisozk.iii@geemail.com	San Francisco	California	3017798625489473	69348ebad05d6a00b4b0a46bb6475342	Mastercard	37.7841330474082469	-122.468363042101089
318	2019-01-12 15:18:49	2019-01-12	Mr. Jarett Kuphal Sr.	mr.jarett.kuphal.sr.@warmmail.com	Oklahoma City	Oklahoma	4657347595396	c1bde1bd8051d190a4372b46776acd83	Diners Club / Carte Blanche	35.5411007353015265	-97.4169557677011966
319	2019-01-12 19:22:52	2019-01-12	Shaunna Howe	shaunna.howe@geemail.com	San Francisco	California	4501542171054187	dc0f6e4b73aaf2238813ea522f6803e7	American Express	37.787984173042716	-122.420311751239211
320	2019-01-12 19:59:58	2019-01-12	Shelvie Mills	shelvie.mills@woohoo.com	San Francisco	California	501800976962266	ffac15fdc75d8ccdba33f94e13d51876	Discover	37.7696953940546649	-122.428143667119912
321	2019-01-12 22:35:35	2019-01-12	Adriane Wolf	adriane.wolf@woohoo.com	San Francisco	California	6011368764507867494	25d49c369e5689e647c4aa1add467a83	Maestro	37.7436785842153029	-122.401646552394951
322	2019-01-12 23:57:56	2019-01-12	Ms. Lori Bauch MD	ms.lori.bauch.md@woohoo.com	San Francisco	California	3528904957497926293	f57a5ac3381408adb54a541cb11fdfb0	JCB 15 digit	37.7553658805590686	-122.416959059930917
323	2019-01-13 07:06:40	2019-01-13	Miriah Schmeler	miriah.schmeler@warmmail.com	San Francisco	California	639084074980370	312545956883c3048eca76d6373ca881	VISA 16 digit	37.7714353552748037	-122.413521288403388
324	2019-01-13 07:35:54	2019-01-13	Mr. Kurtis Dicki	mr.kurtis.dicki@warmmail.com	San Francisco	California	060420937981395	bb042ed73b6e6b2e9f28f2d243fe2184	JCB 15 digit	37.7754273065159083	-122.423516709566314
325	2019-01-13 07:47:58	2019-01-13	Dr. Jep Cormier	dr.jep.cormier@geemail.com	San Francisco	California	869923404895851993	af5a8ece3770d96d5c94f238793b687e	JCB 16 digit	37.770370884630303	-122.436648152812978
326	2019-01-13 08:18:48	2019-01-13	Hermann McGlynn	hermann.mcglynn@geemail.com	San Francisco	California	3467743586894680	3890f2bb3c167556378b18b55933c18e	Voyager	37.7963369178982163	-122.444996560726494
327	2019-01-13 09:08:08	2019-01-13	Vivian Towne	vivian.towne@geemail.com	San Francisco	California	180058669522034431	7ecfbdb8e7f4ac3a60d56ee9e56a5359	VISA 16 digit	37.7344479776729145	-122.435732085116641
328	2019-01-13 12:17:04	2019-01-13	Rebeca Senger	rebeca.senger@geemail.com	Macon	Georgia	869984539759093996	6432ee93ea1821c08d3639dd498b73b9	VISA 13 digit	32.8151899134285756	-83.6730693928159752
329	2019-01-13 18:45:23	2019-01-13	Dr. Edw Sanford	dr.edw.sanford@geemail.com	Oakland	California	3407189119184285	52ff27f9dd5a0438d6bbf16252d5ea2b	Mastercard	37.8234975657358703	-122.26476657207175
330	2019-01-13 20:40:54	2019-01-13	Torry Douglas-Metz	torry.douglas.metz@geemail.com	Berkeley	California	3447649194566567	2a53499a56b6e03727418ffa0b240aee	VISA 16 digit	37.891533267908116	-122.299858131270909
331	2019-01-13 21:01:49	2019-01-13	Cathleen Zulauf	cathleen.zulauf@geemail.com	New York	New York	3528805317249577359	9a73ef64dcbeb517efecb085f1ea4c8a	VISA 16 digit	40.6030919897593563	-73.8621725191723471
332	2019-01-13 21:39:18	2019-01-13	Rogers King	rogers.king@geemail.com	Berkeley	California	3400890059183347	2e8894e948a5b1a959fc9854cc5ece3d	JCB 15 digit	37.8591471535559094	-122.274171340838407
333	2019-01-13 23:38:04	2019-01-13	Anna Smitham	anna.smitham@geemail.com	San Francisco	California	6011109456082227640	b58303ea3a6d9c7caf4a401755f4db02	Diners Club / Carte Blanche	37.7639990689500706	-122.425531013255366
334	2019-01-14 00:40:26	2019-01-14	Signa Hilpert	signa.hilpert@geemail.com	Tucson	Arizona	502023678345275	50926c20ee455c25bccd15d1c7a7c4fa	VISA 16 digit	32.2175110907334883	-110.884496868005385
335	2019-01-14 00:54:33	2019-01-14	Kim O'Hara	kim.o'hara@geemail.com	San Francisco	California	3096697746562555520	4046e8bebecb99296661fbb48d92bef1	JCB 15 digit	37.7738502917677579	-122.461963352003323
336	2019-01-14 02:49:08	2019-01-14	Rhett Grimes IV	rhett.grimes.iv@geemail.com	Columbus	Ohio	3039641892979867	342ef7a92e59292b4e6239abfa2a19ab	JCB 16 digit	40.0450697572946552	-82.954506796994437
337	2019-01-14 05:02:49	2019-01-14	Daja Volkman	daja.volkman@warmmail.com	Berkeley	California	53058087083650943	9f368719d1a7cb3e4c1a195071a74646	JCB 16 digit	37.8719932732847866	-122.279647729875791
338	2019-01-14 09:05:41	2019-01-14	Maria Ledner PhD	maria.ledner.phd@geemail.com	Oakland	California	869947552166595772	4b3ddbfc976449fa9df793a19faac5c7	Discover	37.7888714630614189	-122.261395383337785
339	2019-01-14 09:29:58	2019-01-14	Erick Hammes Jr.	erick.hammes.jr.@warmmail.com	San Francisco	California	4130191006040398	31a47f63d35e3d49c916cdb936efa544	JCB 15 digit	37.792695817868136	-122.444151325313598
340	2019-01-14 16:36:45	2019-01-14	Dessie Greenholt	dessie.greenholt@geemail.com	Oakland	California	4970520642069523	188e657a54e5242b6adbdfb5e6718670	JCB 15 digit	37.8205436771764738	-122.271108268404106
341	2019-01-14 23:54:55	2019-01-14	Etter Metz	etter.metz@geemail.com	San Francisco	California	3158929911526268145	19f6a6bec67fca41ded4ccea76e06b7a	Mastercard	37.7556521492846002	-122.424984166010034
342	2019-01-15 04:47:30	2019-01-15	Judah Farrell	judah.farrell@geemail.com	Chicago	Illinois	3096697358098870926	a7f50290bc174354c28bbe0c3155dd28	JCB 16 digit	41.8706157385673379	-87.6373162766482636
343	2019-01-15 06:10:56	2019-01-15	Siobhan Beatty DVM	siobhan.beatty.dvm@geemail.com	Berkeley	California	3003291024520795	a56cfea42aec1396d2b9929739cb818e	JCB 15 digit	37.8950118131406413	-122.271143151699789
344	2019-01-15 06:16:40	2019-01-15	Dr. Claudie Romaguera	dr.claudie.romaguera@woohoo.com	San Francisco	California	3047318634256852	59a02a48cd40f9efd30e73d26ff2cf1a	JCB 16 digit	37.8067358148009518	-122.423856176164236
345	2019-01-15 06:27:08	2019-01-15	Hartley Corkery	hartley.corkery@warmmail.com	Oakland	California	4747705506208	3d69ea37cb12b577c003d52cf05f60f0	Discover	37.7915721725259743	-122.259856644823685
346	2019-01-15 07:33:38	2019-01-15	Retta Thompson	retta.thompson@warmmail.com	San Francisco	California	53121142190091730	4b85f3403d5dfab3d4d6cefbf6486d6d	VISA 16 digit	37.7914113831031173	-122.454458856047921
347	2019-01-15 12:38:29	2019-01-15	Jarett Lakin-Lind	jarett.lakin.lind@geemail.com	New York	New York	3417659630590077	0745b727fe2bf2047de49a5d3e23efb0	Diners Club / Carte Blanche	40.5820822854749821	-73.8733650536637754
348	2019-01-15 14:01:49	2019-01-15	Laverne Welch	laverne.welch@geemail.com	Oakland	California	210040021245887102	eaed25b3f849a073563778ce418b9955	JCB 15 digit	37.8392273646688793	-122.241019559265141
349	2019-01-15 16:34:48	2019-01-15	Yancy Gibson	yancy.gibson@geemail.com	Oakland	California	4195437618810260	b9c886c498d626bc8829cb5e2ae897d1	Mastercard	37.8105129459432234	-122.281298013277478
350	2019-01-15 17:52:48	2019-01-15	Bonnie Dickinson	bonnie.dickinson@warmmail.com	Oakland	California	4639956573096	a92ebab120aea40c6588049e354a21e7	Diners Club / Carte Blanche	37.8290566767477756	-122.280048440219701
351	2019-01-16 00:53:17	2019-01-16	Monroe Price	monroe.price@geemail.com	San Francisco	California	589393930985838	ad1f0b2e25fe27a3142c88ceeb1106e2	American Express	37.7893035179316499	-122.404804710794011
352	2019-01-16 05:27:29	2019-01-16	Tia Pollich	tia.pollich@warmmail.com	San Francisco	California	3009626563388043	a2c4fea477af301cdceb11a426303076	Discover	37.798721165364789	-122.423210096351241
353	2019-01-16 06:01:22	2019-01-16	Dr. Huston Graham DDS	dr.huston.graham.dds@warmmail.com	Anaheim	California	6011750326264180390	53c27c6c22609d16056cdec28f62c0b0	Diners Club / Carte Blanche	33.8543896832335705	-117.780278309734911
354	2019-01-16 07:16:23	2019-01-16	Racheal Willms	racheal.willms@geemail.com	Oakland	California	869929397759118224	9af1f74a669df3ab4a36797c5d400dbd	JCB 15 digit	37.7853003414437509	-122.235691707236199
355	2019-01-16 07:34:38	2019-01-16	Jaden Labadie	jaden.labadie@geemail.com	San Francisco	California	180045272040049480	8ef026d80eb56ab45f25818ecfa8d764	JCB 15 digit	37.7974269904569198	-122.43643564452411
356	2019-01-16 11:43:29	2019-01-16	Hadley Quigley V	hadley.quigley.v@woohoo.com	San Francisco	California	3096862351325971152	8f04c3dbcdac4732d271c350bdba3828	JCB 16 digit	37.7503200298137429	-122.40662844216439
357	2019-01-16 15:23:26	2019-01-16	Dr. Tillman McLaughlin	dr.tillman.mclaughlin@warmmail.com	McKinney	Texas	6011493792429850189	a52f0c5adeb053ff2dc7fd43acf2aece	JCB 16 digit	33.165879313241696	-96.6535453683994774
358	2019-01-16 19:22:03	2019-01-16	Dr. Ansel Kris	dr.ansel.kris@warmmail.com	San Francisco	California	869960013119508844	418b11d447e6a3f3d8ef3ae42f463805	Maestro	37.7628450695559366	-122.418660091502829
359	2019-01-17 01:36:23	2019-01-17	Misael Jacobs	misael.jacobs@geemail.com	Oakland	California	3012268039764189	183ba4e165303a082486c8109b33e6da	JCB 15 digit	37.8100508099190975	-122.282482298698724
360	2019-01-17 06:06:28	2019-01-17	Chauncey Dooley	chauncey.dooley@warmmail.com	Oakland	California	869999315177678251	701fcdbede69fcf4c8f529c62150e7dd	Mastercard	37.8288621074301616	-122.282052419498697
361	2019-01-17 08:01:00	2019-01-17	Rondal Mitchell	rondal.mitchell@geemail.com	Berkeley	California	3528080739381919006	92be7b7e5a27358d260ed65624eeaa77	JCB 15 digit	37.8489868299033105	-122.261670288459172
362	2019-01-17 15:46:25	2019-01-17	Annika Konopelski	annika.konopelski@geemail.com	Dallas	Texas	3438627838577761	296823896a746263f4046c29d3c23472	Voyager	32.8363818753782652	-96.8009185505527938
363	2019-01-17 16:20:04	2019-01-17	Cherie Torphy-Purdy	cherie.torphy.purdy@woohoo.com	Oakland	California	6011739728967391263	773bc86957c6f2ae59d4a020c8c88d26	VISA 13 digit	37.7913894285984355	-122.225030514213415
364	2019-01-17 19:57:40	2019-01-17	Mr. Hollie Friesen III	mr.hollie.friesen.iii@geemail.com	San Francisco	California	3006640845657649	507f8e7124f567029a23b8dcfea2c529	VISA 16 digit	37.7491418317788288	-122.424423628662268
365	2019-01-17 23:05:37	2019-01-17	Melvina Rutherford	melvina.rutherford@geemail.com	Kansas City	Missouri	3009508667818804	53c413ce0a62375ef7b0ae1091f1eebb	American Express	39.0595099307898437	-94.6489300066828747
366	2019-01-18 01:57:21	2019-01-18	Dr. Terry Nader Sr.	dr.terry.nader.sr.@geemail.com	Provo	Utah	4713959295926294	186285b27a12d543417c59a21a9d7196	JCB 16 digit	40.163330839925635	-111.62516185945384
367	2019-01-18 12:27:14	2019-01-18	Clarnce Willms	clarnce.willms@geemail.com	San Diego	California	4173911085026002	793b632e7f5563037382901aa0efe463	JCB 15 digit	32.752877639939264	-117.13804445303046
368	2019-01-18 14:06:56	2019-01-18	Rowan Howell	rowan.howell@woohoo.com	San Francisco	California	869961800012226832	73eaf436c45ed81469c1cdacbe707c59	Discover	37.8002244789332593	-122.441260473483112
369	2019-01-18 14:09:27	2019-01-18	Dr. Semaj Adams PhD	dr.semaj.adams.phd@geemail.com	San Francisco	California	589329837455491	d0123c0d7e6e5f0f6f923266ce4e0bb3	JCB 16 digit	37.7806492579835904	-122.416651029869229
370	2019-01-18 15:40:03	2019-01-18	Eller Lemke	eller.lemke@geemail.com	Berkeley	California	51772830648720478	b188fcadcd521df82625ac2438a5f3b5	Maestro	37.8999158346339726	-122.256694090287624
371	2019-01-18 17:34:16	2019-01-18	Mr. Thomas Lang	mr.thomas.lang@geemail.com	San Francisco	California	4170195291302364	ad4f9b006d41c5de66d56562b8914479	VISA 13 digit	37.7507797402575775	-122.409481850020541
372	2019-01-18 22:37:17	2019-01-18	Frazier Bergstrom	frazier.bergstrom@warmmail.com	San Francisco	California	3000500112557433	32752924a42144a3ba31ad4388fb116a	Mastercard	37.7963668328635904	-122.463130162291506
373	2019-01-18 23:16:22	2019-01-18	Darold Cummerata	darold.cummerata@warmmail.com	San Francisco	California	4251643021024	a25c4449d5e81bc3f40af8abd5c4627b	Maestro	37.7321318125889107	-122.421115825297179
374	2019-01-19 00:52:12	2019-01-19	Phillip Rodriguez	phillip.rodriguez@geemail.com	Berkeley	California	3528205135862955983	aff2eba039e6b6e446f5c6461c7f62ba	Discover	37.8222563579550695	-122.278782390717339
375	2019-01-19 11:23:45	2019-01-19	Mr. Hubbard Mosciski Sr.	mr.hubbard.mosciski.sr.@geemail.com	Murfreesboro	Tennessee	4771546412084781	570f5839540ff54af3720b1d3f50d1f6	VISA 16 digit	35.7839186439875547	-86.3530243534911364
376	2019-01-19 16:21:50	2019-01-19	Dr. Colt Bogisich	dr.colt.bogisich@geemail.com	San Francisco	California	3003561130999491	3c32fc8e55c6a4bc36e7dae583a22d0b	American Express	37.7716152428194363	-122.392486256056188
377	2019-01-19 18:45:28	2019-01-19	Trisha Lueilwitz	trisha.lueilwitz@woohoo.com	Oakland	California	53398614919519494	a825ab4bffbe56d0e0e5cd138a14f5f5	JCB 15 digit	37.8181885076283919	-122.260569386696204
378	2019-01-19 18:58:20	2019-01-19	Odile Roob	odile.roob@geemail.com	San Francisco	California	4388335465865212	de49724acdd09ccda0d02a895cd59c10	VISA 16 digit	37.7939838271445723	-122.438446633806805
379	2019-01-19 19:02:02	2019-01-19	Valentino Effertz-Gutmann	valentino.effertz.gutmann@woohoo.com	San Francisco	California	869954696814179842	c202e89ce57e4a7f95998bf41c1caf82	Maestro	37.7595462807505839	-122.448449725570967
380	2019-01-19 19:49:47	2019-01-19	Ivette Davis	ivette.davis@geemail.com	Oceanside	California	639010234103876	10fca85e3726bec300d2fd55801379a9	Mastercard	33.208393500920387	-117.211635881391175
381	2019-01-19 20:43:24	2019-01-19	Laverne Satterfield	laverne.satterfield@geemail.com	San Francisco	California	060430388049782	1c2ce926a8d2d99838e38327f9703a9c	American Express	37.7787297247592377	-122.425295597913788
382	2019-01-20 02:05:06	2019-01-20	Justine Connelly	justine.connelly@warmmail.com	San Francisco	California	3785306254965717	29cc6ef6b94ed7a26a6b84efdb329030	Diners Club / Carte Blanche	37.7635100840361204	-122.40817041940825
383	2019-01-20 05:19:29	2019-01-20	Dr. Deegan Crist II	dr.deegan.crist.ii@geemail.com	San Jose	California	3481159400913196	39939d1135dfdb62b151269c2ff8a927	American Express	37.3627978984553408	-121.856383432749283
384	2019-01-20 10:41:47	2019-01-20	Ruby Carroll Jr.	ruby.carroll.jr.@geemail.com	San Francisco	California	3158353344399210959	2b90b0641f345c6066afca04ef2454d9	JCB 16 digit	37.742075273828803	-122.442367789104026
385	2019-01-20 12:21:29	2019-01-20	Jeanette Dietrich	jeanette.dietrich@geemail.com	Jersey City	New Jersey	3012541976166059	0670cb7d7c2ca0015f28b1a8651d153d	Maestro	40.7281419346049418	-74.072426874651768
386	2019-01-20 15:05:05	2019-01-20	Cordell Hayes	cordell.hayes@geemail.com	San Francisco	California	3019319761017651	51d4efd8708f1960ac74d5afc4c27759	Diners Club / Carte Blanche	37.7854642160841294	-122.463778945651967
387	2019-01-20 18:12:57	2019-01-20	Dr. Luc Tromp	dr.luc.tromp@geemail.com	Berkeley	California	6011976182669647337	7174759e9049c84edbe612805b3ac518	Mastercard	37.875741768363028	-122.248893528784976
388	2019-01-20 19:57:48	2019-01-20	Leanne Wuckert	leanne.wuckert@geemail.com	San Francisco	California	3158690243930661864	66818c33f2a467f3abc45bcaaa61b657	Discover	37.7762248608380702	-122.465425822224333
389	2019-01-20 21:38:40	2019-01-20	Magdalen Pfeffer	magdalen.pfeffer@geemail.com	San Francisco	California	3052613224381283	815dedfbf454b74747551ff5f8d36f44	American Express	37.7525468140416649	-122.442169448393884
390	2019-01-21 03:37:16	2019-01-21	Cheyenne Pfeffer	cheyenne.pfeffer@geemail.com	Berkeley	California	3158667268010667415	8008300988e68f4b1e55fd9aa113756a	Discover	37.8353384341559789	-122.287568031108435
391	2019-01-21 05:00:20	2019-01-21	Carlos Mayert	carlos.mayert@geemail.com	Carrollton	Texas	4717714056986532	8c0a51d3117fec069271e7338a52eab0	VISA 13 digit	32.9959762763153748	-96.9699385375112257
392	2019-01-21 07:54:07	2019-01-21	Dalia Feeney	dalia.feeney@woohoo.com	San Francisco	California	4717812873986196	ef3c397049b0d6287e6c0817ddd8c48d	VISA 13 digit	37.7647984326965371	-122.429094826498996
393	2019-01-21 08:54:16	2019-01-21	Goldie Ritchie MD	goldie.ritchie.md@geemail.com	Berkeley	California	180008105227344842	c2045979f95917d50343a01082cdfe48	JCB 15 digit	37.892092183316052	-122.286165319781247
394	2019-01-21 14:26:08	2019-01-21	Dellia Gleichner	dellia.gleichner@warmmail.com	San Francisco	California	6011352378179405752	69be1715e7f1c1d8657f7a32df1b0993	Discover	37.7637768316456075	-122.395692906579541
395	2019-01-21 21:55:22	2019-01-21	Enos Pouros	enos.pouros@geemail.com	San Francisco	California	4543177525101	22cf0668d1c0669b8ae4a5d07d97d088	VISA 16 digit	37.7774830338263428	-122.453338328082182
396	2019-01-21 22:08:38	2019-01-21	Alphons Parisian	alphons.parisian@woohoo.com	Berkeley	California	210041313963579337	aa10b71631df5ea78b2acf814a2e6de5	Voyager	37.8426688573755357	-122.2513054019105
397	2019-01-21 23:49:55	2019-01-21	Dr. Davin Reichel	dr.davin.reichel@woohoo.com	Los Angeles	California	3088816091311461787	1dad82457b2dbc9d3aedd4677ada4450	Diners Club / Carte Blanche	34.0626448153384018	-118.397704717795548
398	2019-01-22 07:38:29	2019-01-22	Powell Jast	powell.jast@geemail.com	Bakersfield	California	3745898734102092	3d6d3d7fcbc8773b43f01c161d7bb6b7	JCB 16 digit	35.3989226841077169	-119.060766070083901
399	2019-01-22 13:10:21	2019-01-22	Vinie Hermiston-Boehm	vinie.hermiston.boehm@geemail.com	San Francisco	California	869984481494441745	885dc599f85c4084c4e1ec6aafa09061	Maestro	37.788345247742356	-122.436344995164362
400	2019-01-22 15:07:24	2019-01-22	Myron Waters-Yundt	myron.waters.yundt@warmmail.com	San Francisco	California	3788873072305043	64fb2f7816e41a923648a9d3117e0409	Discover	37.7498789773312282	-122.434732093552981
401	2019-01-22 16:29:54	2019-01-22	Mariel Nitzsche	mariel.nitzsche@geemail.com	San Francisco	California	676228665064979	9591a882ec6157a9d0a4dad04d52c8e1	JCB 16 digit	37.7654653619455942	-122.439842261795832
402	2019-01-22 16:52:52	2019-01-22	Cary Muller	cary.muller@geemail.com	Houston	Texas	6011824793784211298	216dffba2240ae26248bafcce022f618	JCB 15 digit	29.6945474520869546	-95.3337507242817424
403	2019-01-22 20:12:23	2019-01-22	Budd Mills	budd.mills@geemail.com	San Francisco	California	4454357433334310	6291713ce356a85f7dd18a4fabe2a8f5	Maestro	37.7695454794628347	-122.409256374846692
404	2019-01-22 21:04:59	2019-01-22	Elick Luettgen	elick.luettgen@geemail.com	San Francisco	California	6011511685652063595	497818f6928bc65883a1fddc77d85d56	American Express	37.7800887123863092	-122.437865668320313
405	2019-01-23 05:38:28	2019-01-23	Betha Hammes	betha.hammes@woohoo.com	Berkeley	California	3443027117668188	6eb190932bd122c5a4d23473b03f4493	American Express	37.8704397526522953	-122.249562068689301
406	2019-01-23 09:14:44	2019-01-23	Kahlil Oberbrunner-Bailey	kahlil.oberbrunner.bailey@geemail.com	San Francisco	California	3337783821326637263	bbd7682bde3f734b2570faa17ea9b745	JCB 15 digit	37.7706143362465667	-122.465564674696893
407	2019-01-23 09:41:08	2019-01-23	Lollie Davis	lollie.davis@geemail.com	Oakland	California	3421032388772418	8dd2774bbb96efe6f49d6c96111d23b5	Voyager	37.8150584727035053	-122.292127343904355
408	2019-01-23 10:32:29	2019-01-23	Denzell McGlynn	denzell.mcglynn@geemail.com	San Francisco	California	6011319443012936157	b4993e7e40c61f7b1140f7a965779d4c	JCB 15 digit	37.7458807951441457	-122.427292100063227
409	2019-01-23 19:50:14	2019-01-23	Sherilyn Mueller DDS	sherilyn.mueller.dds@geemail.com	Carrollton	Texas	4515656716516213	a31ecdf104d9fe1a5f6a1dec305abc0d	American Express	33.0879789540465907	-96.9411568226620517
410	2019-01-23 21:05:32	2019-01-23	Melvina Ferry PhD	melvina.ferry.phd@geemail.com	Davenport	Iowa	52924072379046313	abe6c0b5f85ea4295da5a675fc83403d	VISA 13 digit	41.5505176474139049	-90.6688377579636864
411	2019-01-24 12:18:57	2019-01-24	Sherri Robel	sherri.robel@geemail.com	San Francisco	California	3088177769699562804	697e839a623b4da5d9f9a0e3f789ed4a	Maestro	37.7688713274676857	-122.424576584683294
412	2019-01-24 13:08:11	2019-01-24	Eithel Runolfsdottir	eithel.runolfsdottir@geemail.com	Oakland	California	3158842888019061522	121c4d02542ea051f5657ebe172a0c84	Mastercard	37.7843655360406103	-122.245309392736019
413	2019-01-24 17:07:53	2019-01-24	Tatianna Bernhard	tatianna.bernhard@geemail.com	San Francisco	California	4500532147119538	be97fd2b3879cc9c1888dad49f881cfe	VISA 13 digit	37.8009483700900972	-122.409551826885405
414	2019-01-24 18:05:16	2019-01-24	Mr. Brenden Wilderman	mr.brenden.wilderman@woohoo.com	Oakland	California	3158475628538702352	945ec5b69118f4d6f062c01cad01a1e2	Mastercard	37.7924206049243878	-122.242828863005997
415	2019-01-24 18:51:06	2019-01-24	Yoshiko Gutkowski	yoshiko.gutkowski@woohoo.com	Provo	Utah	4933924038540079	bdfcd37c30ca13833714f16b0e20462c	VISA 16 digit	40.2946222238495935	-111.608068742850051
416	2019-01-24 19:38:04	2019-01-24	Kyree Hilll	kyree.hilll@geemail.com	Mesquite	Texas	4121371731586151	9290ad60595ef394c189f3f45cb807dc	VISA 16 digit	32.6654616614148026	-96.5327471489284221
417	2019-01-25 00:11:44	2019-01-25	Janell Quitzon	janell.quitzon@geemail.com	San Francisco	California	869929841172905295	bb780b62bf09e371edb76d98293501da	Mastercard	37.7583482857855373	-122.403455641599948
418	2019-01-25 00:33:02	2019-01-25	Dr. Jade Kertzmann MD	dr.jade.kertzmann.md@geemail.com	Oakland	California	3776605496693594	95f9f7c3996b9059b090563c78a0eb0e	Voyager	37.7764026950345055	-122.30141083582761
419	2019-01-25 00:53:15	2019-01-25	Marylin Cremin	marylin.cremin@geemail.com	Joliet	Illinois	676113942695860	2f60ceb5f14cef0284358b8a69051235	Mastercard	41.5749720560245208	-88.2387349336512301
420	2019-01-25 13:02:38	2019-01-25	Mr. Jewell Dare	mr.jewell.dare@geemail.com	San Francisco	California	3096518578408161289	e031bc01c68762155e9c2fbdc73b161f	JCB 15 digit	37.7519415943821173	-122.459879274146971
421	2019-01-25 20:09:47	2019-01-25	Osborne Okuneva	osborne.okuneva@geemail.com	Berkeley	California	3112416828339340863	634ab989e8b8569e8c48e4417db1ce63	Mastercard	37.8250873490949502	-122.268914513095083
422	2019-01-25 21:49:11	2019-01-25	Dr. Vashon Friesen DVM	dr.vashon.friesen.dvm@geemail.com	Indianapolis	Indiana	4680095215464907	2ac6bdc79aa4f1ecb3f8be212623315b	Maestro	39.6908827689018082	-86.1338436708986706
423	2019-01-25 22:22:21	2019-01-25	Mr. Leeroy Schoen	mr.leeroy.schoen@geemail.com	Berkeley	California	3088215395400095563	862fae97c91e458d8a34ad3ae38ba4eb	Mastercard	37.8537936775370767	-122.279394220791829
424	2019-01-26 00:34:11	2019-01-26	Arleth Nolan-Medhurst	arleth.nolan.medhurst@woohoo.com	San Francisco	California	4328477853274	4ede203e43d393454eb461ca11cd4244	VISA 16 digit	37.7608132123027787	-122.450359371538639
425	2019-01-26 01:08:55	2019-01-26	Misty Schuppe-Ziemann	misty.schuppe.ziemann@geemail.com	Long Beach	California	4229592447383952	2f8a2efbcc2308ea48180c76af063973	Maestro	33.7152086050536468	-118.253990689122304
426	2019-01-26 03:31:35	2019-01-26	Sherron Zboncak-Daugherty	sherron.zboncak.daugherty@warmmail.com	Berkeley	California	4793887839799971	3e17b0014d52c26609b8f39be132ca7e	JCB 15 digit	37.8381056242184641	-122.263581590544007
427	2019-01-26 08:44:13	2019-01-26	Dr. Hilary Mertz DDS	dr.hilary.mertz.dds@warmmail.com	Corpus Christi	Texas	3096018540449024350	6378cd1e23fad91ab88f919a2d8ea2c9	VISA 16 digit	27.772161525854095	-97.1638475356917866
428	2019-01-26 15:06:46	2019-01-26	Justice Rowe	justice.rowe@geemail.com	San Francisco	California	869916261793777376	133eb2a73932eca2113494810a16409a	Voyager	37.8065565648448683	-122.471329348691214
429	2019-01-26 17:07:58	2019-01-26	Mrs. Liddie Heaney	mrs.liddie.heaney@geemail.com	San Francisco	California	3096375331823493024	7f71e2ffa5cb8a4a1377d207471012fa	American Express	37.7778775902557413	-122.392883636433695
430	2019-01-26 23:28:24	2019-01-26	Krista Goyette	krista.goyette@geemail.com	Oakland	California	3112999586619333801	9bd29334a96435dcc81825d750360aa7	Mastercard	37.8263313191812216	-122.275007774311831
431	2019-01-27 01:19:21	2019-01-27	Judd Hauck	judd.hauck@warmmail.com	San Francisco	California	210069254453894223	e15b9a7da72e524b2dff5ac495badaea	Voyager	37.784097840382401	-122.425217113325061
432	2019-01-27 04:12:44	2019-01-27	Estefany Legros	estefany.legros@geemail.com	Oakland	California	4794022250377631	bfc35aeb34b70ae9039c1ae4507f01c6	Maestro	37.8052023683815435	-122.25846884266852
433	2019-01-27 15:44:47	2019-01-27	Roland Goyette-Hayes	roland.goyette.hayes@geemail.com	Oakland	California	3088399390333247314	35aa3eb615ce322c1e1e52bb980c355f	VISA 16 digit	37.7814521960314877	-122.256145415662118
434	2019-01-27 18:33:17	2019-01-27	Jessika Koepp	jessika.koepp@woohoo.com	Oakland	California	4724758546099894	2035d157887a32f791039636a72c9904	JCB 15 digit	37.7831633423528146	-122.253930926782829
435	2019-01-27 19:37:35	2019-01-27	Ms. Frona Kertzmann MD	ms.frona.kertzmann.md@geemail.com	San Diego	California	4483265548655211	dcba54b2cc70bec5c75b533bc5b8129e	JCB 16 digit	32.8867999320916837	-117.06618438082748
436	2019-01-27 22:26:40	2019-01-27	Leander Moore IV	leander.moore.iv@woohoo.com	San Francisco	California	4036728177066234	3610350dff867f6e32e984c32b3d9980	Voyager	37.7959311790066224	-122.42955876892151
437	2019-01-27 23:26:02	2019-01-27	Pranav Conroy	pranav.conroy@woohoo.com	Dallas	Texas	210020921846384793	ce722cd46e493e583b6edd6acd1b4836	American Express	32.7609253529265558	-96.7282744410410515
438	2019-01-28 01:58:31	2019-01-28	Dr. Luis Turcotte	dr.luis.turcotte@geemail.com	Oakland	California	4939632590432577	ecc5b49b6484f6bb90149eaaee314524	American Express	37.811640845482323	-122.266707449768631
439	2019-01-28 12:27:20	2019-01-28	Aggie Jaskolski	aggie.jaskolski@geemail.com	Oakland	California	53723542688721338	c4f8ee1a41f3393b87473a7fae9c9f8c	Discover	37.7945179718669806	-122.26078958797055
440	2019-01-28 20:02:30	2019-01-28	Miss Verdie Mosciski	miss.verdie.mosciski@warmmail.com	San Antonio	Texas	4319041772342762	10eda4a852dc674836586658ce96ca5f	VISA 16 digit	29.5053195349942889	-98.6139523402623723
441	2019-01-28 21:30:54	2019-01-28	Kate Boehm	kate.boehm@warmmail.com	Jacksonville	Florida	3033653626149325	ecf00b38c99b9cfe30aa7d8b9a1e99ca	Voyager	30.4068492692016079	-81.5757882506664913
442	2019-01-28 22:32:37	2019-01-28	Anika Waters-Gislason	anika.waters.gislason@geemail.com	San Francisco	California	3012038280000546	eba96617d78455daf3d3a61f34dc0dc2	American Express	37.7479637571306412	-122.43173746587577
443	2019-01-29 04:10:24	2019-01-29	Arden Collier	arden.collier@geemail.com	Phoenix	Arizona	676187449733796	41d9ebe7e7a057c70204072cb970884b	Diners Club / Carte Blanche	33.5288890047863148	-112.018291640460873
444	2019-01-29 12:13:40	2019-01-29	Dr. Michal Bechtelar	dr.michal.bechtelar@geemail.com	Berkeley	California	4327496576441840	2eabe58a237f8630f3f3d035221df142	Diners Club / Carte Blanche	37.8914339023532065	-122.263470353707731
445	2019-01-29 16:04:18	2019-01-29	Lindsay Corwin	lindsay.corwin@woohoo.com	Dallas	Texas	4851746078977	095731051a5e33e1a5fd5dd6a09ee481	Mastercard	32.7606501374200008	-96.6921217039655829
446	2019-01-29 20:09:56	2019-01-29	Zayne Koepp	zayne.koepp@geemail.com	San Francisco	California	869929749799950828	e44e1951830ac4e116bb32510bb2932a	VISA 16 digit	37.7522031175816579	-122.435400698594947
447	2019-01-29 23:03:56	2019-01-29	Mr. Holmes Hilll DVM	mr.holmes.hilll.dvm@geemail.com	Berkeley	California	3337408795052867341	37e4a12c2c83d3bdf351417c61724704	Diners Club / Carte Blanche	37.8799169094636454	-122.247718040150261
448	2019-01-30 06:32:49	2019-01-30	Lonzo Adams	lonzo.adams@geemail.com	Nashville	Tennessee	675908087995638	6b3812c4258ded47fa4b584c8bae0496	Diners Club / Carte Blanche	36.1558477755758858	-86.7392978612706003
449	2019-01-30 12:21:11	2019-01-30	Daquan Grimes-Wisozk	daquan.grimes.wisozk@geemail.com	San Francisco	California	3337292683936510817	1df3e7e04729fd575798f346ba914526	Diners Club / Carte Blanche	37.7770045161853147	-122.476619317599457
450	2019-01-30 13:28:48	2019-01-30	Landen Kuhic	landen.kuhic@warmmail.com	Provo	Utah	6011089917463809771	ce3d596b66644de11c99ca79923ce195	VISA 16 digit	40.2851170511238266	-111.716914478470756
451	2019-01-30 15:14:10	2019-01-30	Mr. Nathanial Moore IV	mr.nathanial.moore.iv@geemail.com	Oakland	California	3040271286809642	f60d260eac2944017901e1328b24d458	American Express	37.8124674355119552	-122.291252395791801
452	2019-01-30 18:41:19	2019-01-30	Nora McCullough-Bartell	nora.mccullough.bartell@geemail.com	Berkeley	California	180052754911621299	f6722e68b2e49669ed6ee3098bfeeac4	American Express	37.8704093373202682	-122.253587141380194
453	2019-01-31 09:53:16	2019-01-31	Elizebeth Monahan	elizebeth.monahan@geemail.com	San Francisco	California	3528619054359092871	d398e590a690c509b42e2440657a5ff2	Discover	37.7775810468002504	-122.439910426448378
454	2019-01-31 15:53:29	2019-01-31	Halbert Johns-Brakus	halbert.johns.brakus@warmmail.com	Fayetteville	North Carolina	4847876329379994	8030a8648d6edbd006cfc9c73fa18e57	JCB 16 digit	35.0812201637096663	-78.8834820480216337
455	2019-01-31 16:09:03	2019-01-31	Martha Kemmer	martha.kemmer@warmmail.com	Chicago	Illinois	4282850945621	4a13363b08e7e1165e7ef102e0aacece	Voyager	41.8127411702949559	-87.65453220741189
456	2019-01-31 23:26:44	2019-01-31	Renada Collins	renada.collins@woohoo.com	San Francisco	California	4354285559309	3cd848a284e57d25513471aa45561cfb	JCB 16 digit	37.7747647614568081	-122.437012406693114
457	2019-02-01 05:40:35	2019-02-01	Katharine Wisozk	katharine.wisozk@geemail.com	San Francisco	California	4714854300255897	ffad20f257a9f3455832ddf38bd78dad	JCB 16 digit	37.731948384866314	-122.48341634760142
458	2019-02-01 17:37:06	2019-02-01	Fidelia Bashirian PhD	fidelia.bashirian.phd@geemail.com	Oakland	California	210077460575175827	3663117018c64bf754fbb9d422f9a833	American Express	37.7580375317973633	-122.252532650553405
459	2019-02-01 18:07:16	2019-02-01	Dewey Hegmann	dewey.hegmann@woohoo.com	Jacksonville	Florida	4930570244569726	980b16bd00ecb5bfba544da16c1a664c	VISA 16 digit	30.4355407249700285	-81.6980005545154313
460	2019-02-01 22:15:27	2019-02-01	Shaun McGlynn	shaun.mcglynn@geemail.com	Phoenix	Arizona	6011197222921717289	8b34e02047842551b2e44ea82c69c322	Diners Club / Carte Blanche	33.4913169452387862	-112.080533103032423
461	2019-02-02 04:30:10	2019-02-02	Dr. Kyson Marvin	dr.kyson.marvin@geemail.com	Sacramento	California	54502396668692101	53b24d1aaa16c8e58b50ae5b2a5de8cc	Mastercard	38.5619730127308529	-121.387011094974724
462	2019-02-02 05:26:50	2019-02-02	Maren Rosenbaum DDS	maren.rosenbaum.dds@woohoo.com	Lexington	Kentucky	4462929457694751	e190c149b2c2375f99bc01b39d5c3dcb	JCB 16 digit	38.0505546235822152	-84.5037556146170914
463	2019-02-02 11:47:17	2019-02-02	Antwain Braun	antwain.braun@geemail.com	San Francisco	California	3337507391886003863	138ef2594a81b4e46cf13dc9bc83ea8c	JCB 16 digit	37.7601836412749492	-122.432458505418182
464	2019-02-02 15:33:25	2019-02-02	Cappie Schowalter	cappie.schowalter@woohoo.com	San Francisco	California	4408778357616704	13d975098c019aa8e4291ef6436ef23d	VISA 16 digit	37.7895725005463987	-122.437321734123003
465	2019-02-03 08:18:54	2019-02-03	Eldridge Becker-Kiehn	eldridge.becker.kiehn@geemail.com	San Francisco	California	6011954904277240049	1223783c6c08d2e4c34da9576d727246	Diners Club / Carte Blanche	37.7878654144155277	-122.423064947667257
466	2019-02-03 11:23:52	2019-02-03	Jazmine Muller	jazmine.muller@geemail.com	Boston	Massachusetts	3096680024422666005	5415e4acbf9c925fd4977f7f63896f67	American Express	42.4285665564406642	-71.0195625320028512
467	2019-02-03 13:29:49	2019-02-03	Dr. Ismael Morissette	dr.ismael.morissette@geemail.com	San Francisco	California	4948674943203494	595e17bd52c7332b9cc6dfb6154308ff	Diners Club / Carte Blanche	37.7861425198664307	-122.443315889101157
468	2019-02-03 15:56:32	2019-02-03	Devan Beahan	devan.beahan@geemail.com	San Francisco	California	53410279855799858	8d3154b44719f72c09405efbe5b9c741	Discover	37.759416620214509	-122.435093267030709
469	2019-02-03 18:08:29	2019-02-03	Aubrie Ziemann	aubrie.ziemann@geemail.com	Columbus	Ohio	3337243377504169060	00a10fe53ee503ed2a93b8fab9d1fea9	Diners Club / Carte Blanche	39.9495043763004247	-83.0127622392263333
470	2019-02-04 04:06:57	2019-02-04	Dr. Gifford Stanton	dr.gifford.stanton@geemail.com	Miami	Florida	630408499252701	3c2e2eddf3ab5866fb305a887ef87d3e	Mastercard	25.7138834857054057	-80.2392840980425461
471	2019-02-04 09:49:29	2019-02-04	Amos Beatty	amos.beatty@geemail.com	Albuquerque	New Mexico	4651029507241	15a4c4fe58aa7de6804aa25f15b4b7e5	Maestro	35.0824920925911528	-106.690541898792247
472	2019-02-04 17:18:42	2019-02-04	Winston Marks MD	winston.marks.md@geemail.com	Oakland	California	3499621972781129	54cb839a292a17586583c606e87c30b1	JCB 16 digit	37.7528388606142329	-122.287319012668121
473	2019-02-04 22:20:43	2019-02-04	Brandon Toy	brandon.toy@geemail.com	San Francisco	California	180060892836315918	793f70ad3b19cf8fe7bc52f95733d801	JCB 15 digit	37.7626279734906092	-122.435172902326542
474	2019-02-05 03:46:25	2019-02-05	Albert Robel	albert.robel@warmmail.com	San Antonio	Texas	52003527732775241	e7f01a5972bcb414e54834bb6fb66540	JCB 16 digit	29.5038527149312202	-98.621478265926612
475	2019-02-05 05:11:26	2019-02-05	Sharday Shields	sharday.shields@geemail.com	Arlington	Texas	3158708918341820247	4db1c25dfc44bc694b06d79eb0181c2f	VISA 16 digit	32.7331441505130343	-97.0806397396631553
476	2019-02-05 15:07:26	2019-02-05	Jones Kling	jones.kling@geemail.com	San Francisco	California	210083714276424237	831567f11d67617005cda68b5e54bb1f	JCB 16 digit	37.7717881094321655	-122.435899765495179
477	2019-02-05 16:02:18	2019-02-05	Dr. Joseph Morar	dr.joseph.morar@geemail.com	San Francisco	California	3528027191891986024	6e9681d6889d75667d5ecad5750ec663	VISA 16 digit	37.7765547519810525	-122.454128308028373
478	2019-02-06 02:37:48	2019-02-06	Kacey Rath-Gleichner	kacey.rath.gleichner@geemail.com	Oakland	California	4441606114225320	2b4ea5dd744d21aea749d939cdc98d4c	Discover	37.7521204346947385	-122.269066084294082
479	2019-02-06 10:49:13	2019-02-06	Johnathon Huel	johnathon.huel@woohoo.com	Miramar	Florida	3528256480510572634	5b3af8f869cc10de113d082364c58dda	Maestro	25.9207250334303829	-80.3712864487424525
480	2019-02-06 14:55:58	2019-02-06	Adelyn Johnson PhD	adelyn.johnson.phd@geemail.com	Sugar Land	Texas	4101159392800993	9f029db1d50ddf0bc1354557e49ec81a	JCB 16 digit	29.6069173927936689	-95.5207210617147382
481	2019-02-06 16:34:01	2019-02-06	Verena Altenwerth	verena.altenwerth@geemail.com	Berkeley	California	4167707111826	fc7b59c7a51eff0c06ed82f522a7d95e	American Express	37.8606534401919532	-122.312841156179076
482	2019-02-07 04:45:40	2019-02-07	Ms. Milda Breitenberg	ms.milda.breitenberg@warmmail.com	Edison	New Jersey	869957971443230820	ec3f6e06d6a5d272de3402afbafd5ed9	American Express	40.5292888332586685	-74.3731167053390294
483	2019-02-07 05:13:03	2019-02-07	Donie Moore	donie.moore@warmmail.com	Jersey City	New Jersey	3528207087671471132	a33f2d2509be81e6ac8cfbfacca6d662	VISA 16 digit	40.7629754249878218	-74.0685722602952268
484	2019-02-07 14:07:16	2019-02-07	Charle Grimes	charle.grimes@warmmail.com	San Francisco	California	3471045650877797	0b7e16803ab248a4417cd7625532e0fc	JCB 16 digit	37.7695366065476605	-122.421927490858394
485	2019-02-07 19:56:18	2019-02-07	Charity Zulauf	charity.zulauf@woohoo.com	Oakland	California	869961079585631393	be56767b9b3ab25734bb0fb9eee9e877	JCB 15 digit	37.8205115770077285	-122.256050682046578
486	2019-02-08 08:58:11	2019-02-08	Davy Wilderman	davy.wilderman@geemail.com	San Francisco	California	210085823609364644	83eb93fb6667f4b4da357d01a18efc06	JCB 16 digit	37.7665887109687048	-122.471421614179235
487	2019-02-08 09:39:08	2019-02-08	Celie Beahan	celie.beahan@geemail.com	Stockton	California	52483597242789874	32ab24866911216f51287106369da962	Discover	37.9995263292185967	-121.310627356645838
488	2019-02-08 09:39:36	2019-02-08	Yoel Schmidt	yoel.schmidt@geemail.com	San Francisco	California	6011942245881414991	eef526b3415ff2ea9f942371f053d350	Diners Club / Carte Blanche	37.7554496427986876	-122.432951266208761
489	2019-02-08 12:19:09	2019-02-08	Loy Senger	loy.senger@warmmail.com	San Francisco	California	3047628141321878	3386e4fb46cfa0ed963d0f4fd7276f53	JCB 16 digit	37.7867928173741703	-122.450651966670478
490	2019-02-08 23:25:28	2019-02-08	Taurean Prohaska	taurean.prohaska@woohoo.com	Tempe	Arizona	4934009860008	66c3fe2363a80cbdc16d7117aec6a5ec	Mastercard	33.4783594102054778	-111.872259717018522
491	2019-02-09 06:01:07	2019-02-09	Mrs. Arabella Nicolas	mrs.arabella.nicolas@woohoo.com	San Francisco	California	3461199399938774	4fee5c47bdd54ac2e3ae4368e9dc7245	VISA 13 digit	37.7608811654087191	-122.404083345429683
492	2019-02-09 08:18:10	2019-02-09	Oris Nitzsche	oris.nitzsche@geemail.com	Los Angeles	California	6011892515321906974	351e6d2aff5f760efd4f990122aee871	VISA 16 digit	34.0600163494102617	-118.401999248889453
493	2019-02-09 15:25:52	2019-02-09	Dr. Kyleigh McCullough	dr.kyleigh.mccullough@geemail.com	Berkeley	California	3096337475572353256	27ee2730d998ea1ec9dd1627bf862320	Voyager	37.8426503877316094	-122.270511196450855
494	2019-02-09 20:07:38	2019-02-09	Minor Reichel-Heaney	minor.reichel.heaney@geemail.com	Berkeley	California	3010338275646713	279b14c03e0ae4af85abc2769dea6db9	JCB 16 digit	37.8458721773060773	-122.272308723532959
495	2019-02-09 23:17:08	2019-02-09	Sibyl Stehr	sibyl.stehr@woohoo.com	Jersey City	New Jersey	55894396522752576	de9790753c57c46aa98d609d1f4548e0	Mastercard	40.762948459660258	-74.0770945190873107
496	2019-02-10 03:51:40	2019-02-10	Dr. Cohen Stiedemann Jr.	dr.cohen.stiedemann.jr.@geemail.com	Rancho Cucamonga	California	6011469017794129849	88558d8046d4c308dffaf8e7056f0c67	VISA 13 digit	34.2049748394165221	-117.596389472578466
497	2019-02-10 06:29:18	2019-02-10	Deetta Gaylord	deetta.gaylord@woohoo.com	San Francisco	California	869965976244530666	ce722ae9cf99411088a5420f5d81f59f	JCB 16 digit	37.7986127449142231	-122.423590073406601
498	2019-02-10 18:42:14	2019-02-10	Terra Nicolas	terra.nicolas@geemail.com	San Francisco	California	869937976049147695	ee486a15e4a5d1c6e3a60f68a0600212	JCB 16 digit	37.7675041551445076	-122.461317228166322
499	2019-02-10 19:22:24	2019-02-10	Theola Goyette	theola.goyette@geemail.com	Honolulu	Hawaii	3027029531337790	3538ebe05f319d964199d4ae3d67ab90	JCB 15 digit	21.288315537500381	-157.861026310941583
500	2019-02-10 23:16:31	2019-02-10	Mr. Margarito Klein	mr.margarito.klein@geemail.com	San Francisco	California	3037564250595731	287c6a40ad9cc70316c2edec4e24f4cd	VISA 16 digit	37.7565354465000453	-122.433695627664051
501	2019-02-11 06:43:34	2019-02-11	Kristin Koch	kristin.koch@geemail.com	Berkeley	California	676291434972757	3fb8088b1770244bb7f63ea253fd0dad	VISA 16 digit	37.8716051631120507	-122.258468862267421
502	2019-02-11 08:38:59	2019-02-11	Dequan Smitham	dequan.smitham@geemail.com	Spokane	Washington	4597023593069	576898b0fa0c097fcb0c74f91b81c218	Diners Club / Carte Blanche	47.6590673543285561	-117.380984414358807
503	2019-02-11 08:39:46	2019-02-11	Phebe Keebler	phebe.keebler@geemail.com	Los Angeles	California	3486092248382982	d756d8f26db7787b02ea116d6f0022f1	JCB 16 digit	34.0469281793437872	-118.336398808424548
504	2019-02-11 10:30:53	2019-02-11	Damarcus Hintz	damarcus.hintz@geemail.com	San Francisco	California	3158526317045570994	fafcbfd6fcf359080f0cdb7f60f6ee67	American Express	37.785290060287565	-122.437731993268685
505	2019-02-11 16:00:11	2019-02-11	Hurbert Rempel-Kovacek	hurbert.rempel.kovacek@geemail.com	San Francisco	California	4207626967328587	1dad9585ef1e0259131815772d1e8e3f	JCB 15 digit	37.7829095694703554	-122.427078218348868
506	2019-02-12 00:42:35	2019-02-12	Leone Wuckert	leone.wuckert@geemail.com	San Francisco	California	3055731015713048	7f22ef9ffb2057ad725752bffe7f8eb9	American Express	37.8090051650725201	-122.47272428806609
507	2019-02-12 06:00:51	2019-02-12	Oley Lindgren	oley.lindgren@warmmail.com	Greensboro	North Carolina	3793496363945948	e67a02c820c170416097f2d0db9555f3	Maestro	36.1008895444799265	-79.782865328572683
508	2019-02-12 07:30:01	2019-02-12	Velma Von MD	velma.von.md@woohoo.com	Rancho Cucamonga	California	3419557469846743	47c96cb370109c1bb4f7a63a95b9bc56	American Express	34.1204108645666366	-117.606267645955825
509	2019-02-12 21:45:52	2019-02-12	Cecile Thompson	cecile.thompson@geemail.com	Oakland	California	4033428909887477	1bec4d728b4089275681560a41027c12	Discover	37.8267218048013802	-122.283745734813365
510	2019-02-12 23:12:42	2019-02-12	Nikko Schaden	nikko.schaden@warmmail.com	San Francisco	California	6011318239579122624	c1d2cec79f9a403933ca7cd57215892e	JCB 16 digit	37.7684350433174743	-122.444957510773861
511	2019-02-13 02:55:37	2019-02-13	Mrs. Alyse Murphy	mrs.alyse.murphy@warmmail.com	Berkeley	California	4625827569815658	6a8e779e59834e0374e7ec4dd55ffcf5	American Express	37.8816648947456898	-122.22571547173564
512	2019-02-13 07:08:34	2019-02-13	Miss Cassondra Kuphal DDS	miss.cassondra.kuphal.dds@geemail.com	Berkeley	California	6011629712728355158	5be05ae02e8062e324f8bb201fd2acd3	VISA 16 digit	37.8493457773575344	-122.274675291462287
513	2019-02-13 10:26:58	2019-02-13	Jerrad Bednar	jerrad.bednar@geemail.com	Glendale	Arizona	3337362318851744001	a37cfbb8ce5dec5479f85ded67a67d7b	JCB 15 digit	33.6317026936676342	-112.279416302244726
514	2019-02-13 12:48:13	2019-02-13	Mr. Gilmore Hamill	mr.gilmore.hamill@geemail.com	Portland	Oregon	6011126260229799084	fa94b2e1a94871b2a7bb7c659efb3077	Diners Club / Carte Blanche	45.6300264886934315	-122.59630385860801
515	2019-02-13 15:33:06	2019-02-13	Deonta Cartwright I	deonta.cartwright.i@geemail.com	Oakland	California	3088691745076080773	390cb8c094432a57e025ea68ed054167	VISA 13 digit	37.7921790381026028	-122.247461589238299
516	2019-02-14 05:42:14	2019-02-14	Chelsea Bartell MD	chelsea.bartell.md@geemail.com	Milwaukee	Wisconsin	6011954055856369996	9c56c3f94e8bab749c21cb99b0d6d4d9	JCB 16 digit	43.0769619734577844	-87.9131469441678348
517	2019-02-14 07:00:03	2019-02-14	Joe Rath	joe.rath@woohoo.com	San Francisco	California	3096189034379657853	a45301b1a5bc2a3b8d54da47e69aaa73	Discover	37.7685382464512642	-122.426285451617346
518	2019-02-14 15:39:55	2019-02-14	Champ Blick III	champ.blick.iii@geemail.com	Richardson	Texas	3764623491563500	6abe6ddbc729023999e4f4486d283335	Diners Club / Carte Blanche	32.8828611747130708	-96.7260483858402864
519	2019-02-14 16:42:12	2019-02-14	Marlene Rogahn-O'Connell	marlene.rogahn.o'connell@woohoo.com	Oakland	California	676154650008821	d02d0dea9dd51b9c36ba371ecd20c345	VISA 13 digit	37.7977034302287507	-122.271256726202552
520	2019-02-14 20:02:39	2019-02-14	Dr. Isiah Thompson III	dr.isiah.thompson.iii@woohoo.com	San Francisco	California	3112819633355014357	4c4173b5c8d84a6a57dc8af81d3cd32d	JCB 15 digit	37.7788683573055195	-122.418720035419923
521	2019-02-15 03:52:43	2019-02-15	Ms. Beatriz Treutel	ms.beatriz.treutel@geemail.com	San Francisco	California	4352887752322	ff28e341b0b7784751c4ea0c8bf9102c	VISA 16 digit	37.78809946542723	-122.40686036931902
522	2019-02-15 05:34:00	2019-02-15	Felice Schulist	felice.schulist@warmmail.com	Oakland	California	3034410398870797	eb12c34f8f563d2f75cee8bad63c7bf3	JCB 16 digit	37.8139683385450383	-122.241296693202315
523	2019-02-15 09:23:23	2019-02-15	Ninnie Kuphal	ninnie.kuphal@warmmail.com	El Paso	Texas	060497422790754	71598fc6bc50f177cdf9db1fe2f82ee8	JCB 16 digit	31.8079920815598243	-106.390721308670948
524	2019-02-15 10:55:54	2019-02-15	Olan Rolfson	olan.rolfson@geemail.com	San Francisco	California	3337296408202241087	146fb26b6e4b1938c67c0b3d5b97297a	JCB 15 digit	37.7572277861375412	-122.459078885942915
525	2019-02-15 12:36:04	2019-02-15	Desean Fisher	desean.fisher@woohoo.com	Tulsa	Oklahoma	4233650753830	e3ed8de84c302a1640fadd1db3774d88	American Express	36.1183071447439445	-95.9360639828678217
526	2019-02-16 00:27:44	2019-02-16	Sampson Ward Sr.	sampson.ward.sr.@geemail.com	Tucson	Arizona	3012429333875390	04618129816aef265a02f804eb2db8aa	VISA 16 digit	32.0665989426005638	-110.936725176753839
527	2019-02-16 02:11:12	2019-02-16	Mrs. Elvira Heathcote PhD	mrs.elvira.heathcote.phd@warmmail.com	Berkeley	California	3042956401558839	a8a5aa1898778304795f9315d546ef6a	JCB 16 digit	37.8775592077657492	-122.24962010355614
528	2019-02-16 02:49:05	2019-02-16	Rudolfo Christiansen II	rudolfo.christiansen.ii@warmmail.com	Wilmington	North Carolina	3751327042041330	c949751c13d8edcefd3f4e11682bb9e7	JCB 16 digit	34.1094633435186054	-77.8061511854633778
529	2019-02-16 12:18:31	2019-02-16	Tena Dietrich-Haley	tena.dietrich.haley@geemail.com	Berkeley	California	3041756152521304	15211d873033d30aa54ba07df7815e1d	VISA 16 digit	37.8489113100337136	-122.286455711427053
530	2019-02-16 17:29:59	2019-02-16	Mr. Davy Wolff	mr.davy.wolff@geemail.com	San Francisco	California	3158683233930570461	0620e850e0067adc8a38ef9edc0702c7	JCB 16 digit	37.759334020739324	-122.428502253539435
531	2019-02-17 05:19:21	2019-02-17	Mr. Andres Schuster I	mr.andres.schuster.i@geemail.com	Oakland	California	4582965531897	7303ca6c26b123a0900ccbc78cef82a3	Mastercard	37.8062391247704497	-122.277141765105625
532	2019-02-17 11:33:08	2019-02-17	Virgle Brekke	virgle.brekke@geemail.com	San Francisco	California	180002336307519807	809fc8c50bb8407b9279e1c55289389a	VISA 16 digit	37.8157828007552084	-122.422023594032652
533	2019-02-17 14:35:13	2019-02-17	Cyndi Kuvalis	cyndi.kuvalis@woohoo.com	Tuscaloosa	Alabama	6011382168818539044	806697ef3be3a6c7ff74f231aece4bd7	Diners Club / Carte Blanche	33.1424023782424584	-87.4504939119893976
534	2019-02-17 17:36:33	2019-02-17	Hosea Davis	hosea.davis@geemail.com	San Francisco	California	210004149671277557	10edbd7b1df6f309ce2a352972303bca	VISA 16 digit	37.7802161542884036	-122.407433044080392
535	2019-02-17 21:48:22	2019-02-17	Javen Flatley	javen.flatley@geemail.com	Brownsville	Texas	4506014654830074	124bf75675a52b0d00cee0d51ed4bc9f	Mastercard	26.0867637432258554	-97.4981895384565007
536	2019-02-18 00:16:29	2019-02-18	Jaydon Romaguera	jaydon.romaguera@geemail.com	San Francisco	California	180025507257963871	8ef3b158c2db022a20db63cf9d3a0281	VISA 16 digit	37.7623711171423366	-122.421353196351546
537	2019-02-18 01:37:37	2019-02-18	Tella Zieme	tella.zieme@geemail.com	San Francisco	California	210026292555099475	5fa72938c767270a6a812bd946a33134	American Express	37.7712549788224834	-122.424492363209055
538	2019-02-18 04:48:43	2019-02-18	Kwame Stoltenberg	kwame.stoltenberg@geemail.com	New York	New York	676333702446338	557ebd5a4cb82f00eb9fa6625e4af916	JCB 16 digit	40.5876607288364326	-73.9496806620050222
539	2019-02-18 05:22:21	2019-02-18	Lucina Simonis	lucina.simonis@geemail.com	Berkeley	California	6011125736646882422	e3fe0b1b975098da89b8972889481515	Discover	37.8790436484067286	-122.263810040553921
540	2019-02-18 15:11:01	2019-02-18	Steward Dare	steward.dare@warmmail.com	Irvine	California	4494884449169747	30b9b64c636ec7d50a0200ff6b021b7b	Mastercard	33.6161987415064161	-117.791277867742991
541	2019-02-19 01:59:56	2019-02-19	Samir Gleichner	samir.gleichner@geemail.com	San Francisco	California	4862899645533482	9f3382a883ef49a003110a7523d449cd	Maestro	37.7660273838674385	-122.462299255639962
542	2019-02-19 02:18:21	2019-02-19	Corda Orn	corda.orn@warmmail.com	Madison	Wisconsin	630484260135375	9e2627a6f6d1fb409eebe19ab37fdaf4	VISA 13 digit	43.1008693867802606	-89.4439824434813175
543	2019-02-19 05:39:56	2019-02-19	Stevie Johnson	stevie.johnson@warmmail.com	Oakland	California	4321633651302	9df96360602fa61081a980c431703d0d	Discover	37.7835013758313991	-122.286983985375556
544	2019-02-19 20:08:55	2019-02-19	Khloe Bruen-Russel	khloe.bruen.russel@geemail.com	Pasadena	Texas	3088360667770809713	69e762ac2754d0d32c4462e2770985f1	JCB 15 digit	29.7365288064688436	-95.0776824364852189
545	2019-02-19 21:27:50	2019-02-19	Shelia Lehner	shelia.lehner@geemail.com	San Francisco	California	3485208835185775	53254bb54fc1654935d923c700ae4f34	VISA 13 digit	37.785726782684641	-122.425217754190854
546	2019-02-20 03:41:00	2019-02-20	Jerilyn Robel PhD	jerilyn.robel.phd@geemail.com	Fullerton	California	54050835552841973	1ff446bb9dbc6f17f18105793d99c6c2	VISA 16 digit	33.8890543811179725	-117.991679577875885
547	2019-02-20 08:12:53	2019-02-20	Thekla Gibson	thekla.gibson@geemail.com	Berkeley	California	4212020279205	58c3935d910d173507a116f346d27795	Maestro	37.9249998206892442	-122.230495906412273
548	2019-02-20 10:13:31	2019-02-20	Babette Heidenreich	babette.heidenreich@geemail.com	Berkeley	California	6011524463276565741	1ad6364a97d5f02d9ab4c4b3eab759e9	Diners Club / Carte Blanche	37.8767885577202819	-122.227252292130089
549	2019-02-20 12:19:16	2019-02-20	Mr. Tavon Hahn Jr.	mr.tavon.hahn.jr.@geemail.com	San Francisco	California	4591753479995	aed890d3a21bda32b9a9e35564accc47	American Express	37.7501801310064664	-122.435997484601501
550	2019-02-20 14:02:16	2019-02-20	Linus Daniel	linus.daniel@geemail.com	Chicago	Illinois	503852752646860	ca3ea51f63690913c6a30cb7ed315d30	Maestro	41.7780428903944809	-87.7588489539019747
551	2019-02-21 06:08:12	2019-02-21	Gidget Hilll-Gerhold	gidget.hilll.gerhold@woohoo.com	San Francisco	California	3420254976796283	406e166b2798963ef495fc399d7e39a2	VISA 16 digit	37.7855928946856423	-122.420970314007135
552	2019-02-21 06:12:14	2019-02-21	Kathyrn Jacobi	kathyrn.jacobi@woohoo.com	San Francisco	California	3158846879644168283	ec7e1f49c1a0de04ef9fdb148cea4237	Diners Club / Carte Blanche	37.7605255720695752	-122.457997991002586
553	2019-02-21 07:57:51	2019-02-21	Miss Kasie Stokes	miss.kasie.stokes@woohoo.com	Berkeley	California	55099485190495049	b8880f8462fd2c32025f156ed0a59672	Maestro	37.8614802359019649	-122.291611670402958
554	2019-02-21 12:05:48	2019-02-21	Hunter Reichert	hunter.reichert@geemail.com	Tampa	Florida	6011513776690933879	f730e0955eaa55e69d08f19655e5a772	VISA 13 digit	27.9959555672131479	-82.5642396773423997
555	2019-02-21 13:26:22	2019-02-21	Ms. Alysha D'Amore	ms.alysha.d'amore@warmmail.com	Tulsa	Oklahoma	4095384385380062	95c0118cd94ed9c76f1ee47f4432b17a	VISA 16 digit	36.0293338454697221	-95.9505299507129905
556	2019-02-22 00:46:56	2019-02-22	Alexande Roob II	alexande.roob.ii@warmmail.com	Oakland	California	3010707472855048	4d8d0744d27ba7914f2dda18862031cd	VISA 13 digit	37.7920718193232048	-122.258197808593437
557	2019-02-22 08:04:46	2019-02-22	Dorotha Effertz	dorotha.effertz@geemail.com	San Francisco	California	3158231135808419944	e3613acdcec28178e66f86568b3a3ccc	VISA 13 digit	37.7807712608467199	-122.412020559576717
558	2019-02-22 10:47:21	2019-02-22	Tayler Cole	tayler.cole@geemail.com	San Francisco	California	6011474534977603658	a3bf121290790f42d8d6384f159e9dc9	American Express	37.7986118719586841	-122.449859906100798
559	2019-02-22 11:20:21	2019-02-22	Vicie Rath MD	vicie.rath.md@geemail.com	Phoenix	Arizona	3757186396024530	dce17fce42fa47b3f62f64b11bc41b55	Voyager	33.6089660063784592	-112.002216163130853
560	2019-02-22 14:03:45	2019-02-22	Caswell Morar-Zulauf	caswell.morar.zulauf@geemail.com	Chicago	Illinois	676374226931082	c94b9a7ad91be118819572f6c949f157	Discover	41.9162932777147788	-87.6236687741737796
561	2019-02-22 16:43:31	2019-02-22	Janyce Keeling	janyce.keeling@warmmail.com	San Francisco	California	3158800655840933298	cdca5cd08c397d688907156b04c1b911	VISA 13 digit	37.7727744041818312	-122.427097109102448
562	2019-02-23 08:23:27	2019-02-23	Avery Dietrich MD	avery.dietrich.md@geemail.com	Newark	New Jersey	3746916593740387	2c7fe21c5bfe9a393ce99a0d5cdbb8cb	VISA 16 digit	40.7515137744981857	-74.2150799651838895
563	2019-02-23 08:26:48	2019-02-23	Russ Osinski-Macejkovic	russ.osinski.macejkovic@geemail.com	Oakland	California	3037078043249019	649e5d01696161b2a5431f3c5ed7a3da	JCB 16 digit	37.7931725732471051	-122.259947356842062
564	2019-02-23 09:12:16	2019-02-23	Anie Schinner	anie.schinner@geemail.com	San Francisco	California	6011957517839072093	c14fd2332cae2dc4ac3c2d033e1be10b	Diners Club / Carte Blanche	37.7866775662366265	-122.430604995369833
565	2019-02-23 14:07:50	2019-02-23	Dedra Harber DDS	dedra.harber.dds@warmmail.com	San Francisco	California	6011387034434818391	ca56612c87f215d0924b007221cc9dd4	American Express	37.7493782232356025	-122.415751135446342
566	2019-02-23 22:40:11	2019-02-23	Rossie Bechtelar	rossie.bechtelar@geemail.com	Berkeley	California	869963189180954757	88788b07ec88145603e6266b56cf3fc8	VISA 16 digit	37.8650880853043716	-122.254490282600074
567	2019-02-23 23:15:45	2019-02-23	Dameon Lesch	dameon.lesch@geemail.com	Tampa	Florida	4706735809946617	d31ca7109943fe27e798e70c03c48405	Discover	27.8835443504735814	-82.421422556157026
568	2019-02-24 00:14:50	2019-02-24	Cherilyn Hilll	cherilyn.hilll@geemail.com	New York	New York	3031883228474605	dc7a4929de26d9ce93b2343f879bcf5c	JCB 16 digit	40.7282352416999629	-73.9909025298327236
569	2019-02-24 07:45:55	2019-02-24	Jaye Lowe	jaye.lowe@geemail.com	Oakland	California	3528758667289385544	9311d6a149278bf1a32b0654cc1a3f51	Voyager	37.7995125671179295	-122.270265162245281
570	2019-02-24 15:38:56	2019-02-24	Porter Schaden	porter.schaden@geemail.com	San Francisco	California	4343903358225390	4dd44e8130a3483c843cd6335a92475f	VISA 13 digit	37.7696514484802179	-122.441911534636205
571	2019-02-24 17:08:23	2019-02-24	Lenna Prosacco	lenna.prosacco@geemail.com	Fresno	California	869909114350587580	a2a7bc78117f22886465a2ec95057bb7	Maestro	36.7113499296702415	-119.828905772661429
572	2019-02-24 21:13:03	2019-02-24	Dr. Chaka King	dr.chaka.king@geemail.com	Oakland	California	4141868781678446	88d738e2a9113e12dd2536b85723e2a7	JCB 15 digit	37.7665401849862334	-122.272451701898319
573	2019-02-24 22:10:42	2019-02-24	Mr. Axel Hand III	mr.axel.hand.iii@woohoo.com	San Francisco	California	675947281988296	fd0e3c33a93d94375d510cb867ca7b81	American Express	37.7865057279630463	-122.439434210420131
574	2019-02-25 03:24:11	2019-02-25	Cody Reynolds-Howell	cody.reynolds.howell@geemail.com	Oakland	California	3703458206330711	fa5693bcdc3bf6b9f577ed87e5d87b39	VISA 16 digit	37.7870933495403136	-122.30773667894735
575	2019-02-25 06:02:28	2019-02-25	Marcel Rosenbaum-Goyette	marcel.rosenbaum.goyette@warmmail.com	San Francisco	California	4403025395415	0149f646555293bd6dce394be2af9cb0	JCB 16 digit	37.7640946927476762	-122.456193039962798
576	2019-02-25 06:19:52	2019-02-25	Laci Hoppe	laci.hoppe@geemail.com	San Francisco	California	3484339267216985	53419ae09a276d9ff7ca4e559756dae9	American Express	37.7655020224959728	-122.427260227569434
577	2019-02-25 07:20:05	2019-02-25	Jazlyn Walker	jazlyn.walker@warmmail.com	Houston	Texas	54485472628633112	525257855078f14ad2c568b6b411918c	JCB 16 digit	29.8433388950381442	-95.2911641537692446
578	2019-02-25 22:17:52	2019-02-25	Dr. Douglas Roberts DDS	dr.douglas.roberts.dds@geemail.com	Hampton	Virginia	869981182606701959	fb8e6ead620638b3b06643cc8d9449b4	Maestro	37.0135739787500384	-76.223498819079623
579	2019-02-26 01:08:01	2019-02-26	Monica Kunde DVM	monica.kunde.dvm@geemail.com	Oakland	California	3528553836330033745	672ab2ff0745201f7aedfa9b800b9f9f	JCB 15 digit	37.8356789044323349	-122.276882130510188
580	2019-02-26 01:31:27	2019-02-26	Jensen Hettinger-Prohaska	jensen.hettinger.prohaska@woohoo.com	San Francisco	California	210062633331926678	87037c6d5c25912d3e8ed81d6112913c	JCB 15 digit	37.765889369570445	-122.437964704491435
581	2019-02-26 08:46:59	2019-02-26	Maribel Hudson	maribel.hudson@geemail.com	New York	New York	3088832707272407408	6fbf5498c160e08001ba3a0770195c39	JCB 15 digit	40.72053564826399	-73.9830669541273238
582	2019-02-26 10:16:06	2019-02-26	Mrs. Alvina Conroy PhD	mrs.alvina.conroy.phd@geemail.com	San Francisco	California	869962996635548377	b956a8db8919865937cbe3557c3f9f53	American Express	37.7719454043600749	-122.429804269758876
583	2019-02-26 10:24:07	2019-02-26	Makaila Macejkovic MD	makaila.macejkovic.md@geemail.com	New York	New York	630477576629479	a70fb99c73108da9bb18941e0fd2ee58	Mastercard	40.717476465342564	-74.0368078983750166
584	2019-02-26 10:39:44	2019-02-26	Alesha Kris PhD	alesha.kris.phd@geemail.com	San Francisco	California	3337196302330224001	54d941d12ccf61ac7b96da5a1ab7a9ca	VISA 16 digit	37.8018164214819663	-122.444210239933099
585	2019-02-27 12:00:59	2019-02-27	Murdock McClure	murdock.mcclure@geemail.com	Phoenix	Arizona	869993516733147378	10eb3bbc3ddb0b6b41dce8fb85bf56a5	Mastercard	33.5380711747266389	-112.050518152250362
586	2019-02-27 14:44:01	2019-02-27	Brandy Wisoky-Schinner	brandy.wisoky.schinner@geemail.com	San Francisco	California	4412069972264292	d4768beaa783d6dfd76e815850ae3447	Voyager	37.8008224507447963	-122.418379447805634
587	2019-02-27 16:18:57	2019-02-27	Tawana Sawayn-Pacocha	tawana.sawayn.pacocha@warmmail.com	Oakland	California	51252583561238817	82d0919c771f8f4ee580078b0cf4f312	VISA 13 digit	37.8279764768974474	-122.242826253988369
588	2019-02-27 21:05:20	2019-02-27	Miss Mozella Hayes	miss.mozella.hayes@geemail.com	Berkeley	California	4473852806109528	3cf90f6e99aa073791dee211869360dc	JCB 15 digit	37.8801818007367146	-122.288229890037783
589	2019-02-27 23:43:02	2019-02-27	Mr. Oren Goyette	mr.oren.goyette@geemail.com	Riverside	California	4587896529488639	50d11656435d7d513f6208e94d021b91	JCB 16 digit	33.9366055212862747	-117.324881143306186
590	2019-02-28 08:24:01	2019-02-28	Fidel Johnston	fidel.johnston@woohoo.com	Colorado Springs	Colorado	3337000019544920515	70890306789889fd289388d0b9005d56	Voyager	38.8912632448647173	-104.70093266672157
591	2019-02-28 14:19:43	2019-02-28	Mr. Toma Raynor	mr.toma.raynor@geemail.com	New York	New York	6011883359042856171	4a1d7371ee26cd30490734b04a13ea94	Maestro	40.6727452295124507	-73.944149577048421
592	2019-02-28 14:42:29	2019-02-28	Mr. Sherwin Grimes MD	mr.sherwin.grimes.md@warmmail.com	San Francisco	California	3112773324926835652	66d083ba23060e15e413558ed7af7afe	Diners Club / Carte Blanche	37.791631536443731	-122.433225783238896
593	2019-02-28 19:36:41	2019-02-28	Deja Marquardt-Bernier	deja.marquardt.bernier@warmmail.com	Oakland	California	3021564310576248	45c3be1f35b0797ff949109d1ac5dc1c	Mastercard	37.7824551856025721	-122.24229758089993
594	2019-02-28 21:37:27	2019-02-28	Mr. Stone Hermann	mr.stone.hermann@warmmail.com	Berkeley	California	4350268418349	d8b0f4a19b1d8c31f1314ab6840b5e00	VISA 16 digit	37.8410270794358752	-122.273166719200503
595	2019-02-28 22:56:15	2019-02-28	Thompson Lynch	thompson.lynch@geemail.com	San Francisco	California	4227654212686	490d4453e5ee6470a4c520aa1a708d58	Maestro	37.7386778914954988	-122.424888558698754
596	2019-03-01 02:04:49	2019-03-01	Lawton Morissette	lawton.morissette@geemail.com	San Francisco	California	869925431811425204	b2633d87cbac8e4df0e71c515de2ba19	American Express	37.7689113345231249	-122.476083813433604
597	2019-03-01 03:09:53	2019-03-01	Kristyn Kassulke	kristyn.kassulke@geemail.com	Boise	Idaho	3158276326129335127	ddcbf163b016c6ffeb4d9607fbcda215	JCB 16 digit	43.6995388695642362	-116.173417441426594
598	2019-03-01 03:25:16	2019-03-01	Fleda Dietrich	fleda.dietrich@geemail.com	New York	New York	53885723166199411	4e7cc00c611168fdc68b5350417d3f32	Mastercard	40.7095383159108479	-73.8405751434981852
599	2019-03-01 06:08:11	2019-03-01	Cason Rippin	cason.rippin@woohoo.com	San Francisco	California	561270289621594	4a5bbe8c5a452e708b19422737e98d28	Maestro	37.7783252452355711	-122.433672571858182
600	2019-03-01 09:57:45	2019-03-01	Lizbeth Kerluke DDS	lizbeth.kerluke.dds@geemail.com	Oakland	California	4116021226460480	94a4c6bc57605303a115a6bc4f3fb5cd	VISA 13 digit	37.8019758077976107	-122.238551744435597
601	2019-03-01 11:06:22	2019-03-01	Deron Doyle	deron.doyle@geemail.com	Berkeley	California	3046784486810362	b60c962fd06d61bc22aec3d7b9660c84	VISA 13 digit	37.8787951415946651	-122.248577565806073
602	2019-03-02 00:13:09	2019-03-02	Dr. Jule Kozey DDS	dr.jule.kozey.dds@warmmail.com	Orlando	Florida	4741434359864	ffed91857e853ca17dde25e48b2e4bde	American Express	28.3698725993078185	-81.307649112675719
603	2019-03-02 01:20:20	2019-03-02	Brittani Hirthe	brittani.hirthe@geemail.com	San Francisco	California	6011818555439608691	bca8b495ce1814d078a24575ca46d94b	JCB 16 digit	37.7683829866122309	-122.426409732606558
604	2019-03-02 04:03:58	2019-03-02	Mr. Fenton Kessler PhD	mr.fenton.kessler.phd@geemail.com	Murrieta	California	52070982859152997	12efc7c0f332c2e449470457f655aa1f	VISA 13 digit	33.546574390503018	-117.287133561065048
605	2019-03-02 09:52:16	2019-03-02	Aja Pacocha PhD	aja.pacocha.phd@woohoo.com	San Francisco	California	3112656309455214173	6d16386dd7dd66d363700865dae09c1b	JCB 16 digit	37.7769121706762405	-122.44060284638411
606	2019-03-02 10:38:55	2019-03-02	Abdullah Bins	abdullah.bins@geemail.com	San Francisco	California	4899925863401271	b4249e74afa0800f5a598617c50135cb	VISA 16 digit	37.739201283345885	-122.416014458934995
607	2019-03-02 16:38:13	2019-03-02	Dina Aufderhar	dina.aufderhar@warmmail.com	San Francisco	California	869987579324993608	c356b816d4cd08b4604e1382f0b77e0d	JCB 15 digit	37.7781194706244676	-122.430315392425257
608	2019-03-02 19:10:13	2019-03-02	Press Larkin	press.larkin@warmmail.com	Oakland	California	3528113296624815062	db09c5bc2173e8dc5fb45820c7db52c3	VISA 16 digit	37.7496638076714319	-122.286511927761381
609	2019-03-03 02:01:52	2019-03-03	Ella Walter	ella.walter@geemail.com	Oakland	California	503872558354873	3b96d837c66f57e653cb501a553c4b8c	American Express	37.8183799025969307	-122.264743862220698
610	2019-03-03 09:18:49	2019-03-03	Bunk Considine	bunk.considine@geemail.com	San Francisco	California	4174948492930565	d9d99b32ef346508ed2a0d0931bfcbe5	Mastercard	37.798150715417961	-122.424829843487032
611	2019-03-03 12:02:01	2019-03-03	Markell Walker II	markell.walker.ii@warmmail.com	Chicago	Illinois	3112931068162613443	3bc9acae3b2ce22beab8517782fd72e5	Mastercard	41.788866437163577	-87.658135422787808
612	2019-03-03 12:14:23	2019-03-03	Mrs. Latonya Gerlach DDS	mrs.latonya.gerlach.dds@geemail.com	Berkeley	California	869948894497204578	6f121751e6f10c3428f2925fe61fa093	JCB 16 digit	37.8426923478261443	-122.235188106210416
613	2019-03-03 20:53:31	2019-03-03	Kirt Bosco III	kirt.bosco.iii@geemail.com	San Francisco	California	869940389125643550	28805711577c7e80133441505b8dd482	VISA 16 digit	37.7805693784773808	-122.445459416171943
614	2019-03-03 22:16:47	2019-03-03	Geri Olson	geri.olson@woohoo.com	New York	New York	3059033673112845	447562ffe5a772fabb0b405283c365a3	Mastercard	40.6549770510979016	-73.9649367164250435
615	2019-03-04 01:57:44	2019-03-04	Miss Dorla McCullough	miss.dorla.mccullough@geemail.com	Berkeley	California	4291540452427	6ac8801c80807f33534fc4e6cb2e982b	JCB 16 digit	37.892406220369331	-122.258414473300846
616	2019-03-04 05:48:38	2019-03-04	Loyd Watsica IV	loyd.watsica.iv@geemail.com	Stockton	California	4842733956147282	3fd61a64bbbaf0686099795d0b559cd8	VISA 13 digit	38.0286437108378905	-121.407668580076844
617	2019-03-04 06:30:45	2019-03-04	Mrs. Anice Goldner PhD	mrs.anice.goldner.phd@geemail.com	San Francisco	California	52823299366735739	5155819df3bcbe582b9f84b1163f51aa	JCB 16 digit	37.7728727510121445	-122.39496347345009
618	2019-03-04 09:26:25	2019-03-04	Marci Gibson	marci.gibson@geemail.com	Berkeley	California	3088302116684084055	d646e11e62b932b68bcf2200dfe51f9e	Maestro	37.8319694958785675	-122.261616385079009
619	2019-03-04 10:07:59	2019-03-04	Miley Pfannerstill	miley.pfannerstill@geemail.com	Antioch	California	53056656711365207	c486d90e5eba630b6c5ba123cc15430f	VISA 16 digit	37.9278885035574476	-121.765101328975334
620	2019-03-05 00:59:29	2019-03-05	Delos Monahan	delos.monahan@geemail.com	Peoria	Illinois	3756909804509458	e38a44d2e15f2fc47ff09fae3521c856	VISA 13 digit	40.8213620076291264	-89.518296768691016
621	2019-03-05 01:16:14	2019-03-05	Carlota Legros	carlota.legros@geemail.com	San Francisco	California	3717299284225579	eaf50b3188b577297871d00a90c84c1c	VISA 13 digit	37.759933237892497	-122.439782387120502
622	2019-03-05 02:02:32	2019-03-05	Dr. Pamela Erdman	dr.pamela.erdman@woohoo.com	Stockton	California	55355438387805883	9152c2f3f4f821b8f2e9c149e17a773f	VISA 16 digit	38.0612551090970683	-121.351867701214928
623	2019-03-05 15:44:35	2019-03-05	Stasia Champlin	stasia.champlin@woohoo.com	Berkeley	California	52445486098029345	3ecfba21f0f7790d56c7cadfbffc78f2	VISA 16 digit	37.8398790310144051	-122.302640915344313
624	2019-03-05 16:18:12	2019-03-05	Giovanni Kautzer	giovanni.kautzer@woohoo.com	San Francisco	California	4572489013357	453c36e10be60fe5350f9d75c277242e	Mastercard	37.7762517454362765	-122.414365449837447
625	2019-03-05 22:51:24	2019-03-05	Daulton Kub	daulton.kub@geemail.com	San Francisco	California	4020975388243999	2c2e07b7bfc906980179f4532b42359d	Voyager	37.749893815521709	-122.424565980540137
626	2019-03-06 02:39:42	2019-03-06	Donta Kassulke	donta.kassulke@warmmail.com	San Francisco	California	3015307214060299	e9deb8f233a45abafdcad8f53e199d97	American Express	37.7694670843885589	-122.423252948921899
627	2019-03-06 04:32:54	2019-03-06	Daisye Koepp	daisye.koepp@geemail.com	San Francisco	California	639094063276367	379dba8f82a58a44faa6f99d58485b0d	JCB 16 digit	37.7999272669033672	-122.488251705473758
628	2019-03-06 05:02:17	2019-03-06	Annabell White PhD	annabell.white.phd@geemail.com	New York	New York	4452926129803	b659326aed86aa07678600d80b835ecf	JCB 16 digit	40.602001752400767	-73.8404822142690449
629	2019-03-06 05:18:40	2019-03-06	Gay Sipes	gay.sipes@woohoo.com	Oakland	California	4500161552221355	a0a499731c8f1a047033f92fa4dbd547	JCB 16 digit	37.806355970408859	-122.29800714985889
630	2019-03-06 05:56:55	2019-03-06	Corey Jacobson	corey.jacobson@geemail.com	Oakland	California	180057603248295266	929b88fd65ea0a5c6af4e665f1fc68e8	VISA 16 digit	37.7829678518579399	-122.277039411618475
631	2019-03-06 07:31:08	2019-03-06	Dr. Coral Rath	dr.coral.rath@warmmail.com	Chesapeake	Virginia	3056717898735306	85d1460d06bf3c9a0440addaf7dcb480	Diners Club / Carte Blanche	36.5908107785280805	-76.3475134551834316
632	2019-03-07 00:24:51	2019-03-07	Lem Langworth	lem.langworth@geemail.com	San Francisco	California	4861613114394826	abe6c8c002f2e4ddd31d48f6945509a9	Diners Club / Carte Blanche	37.7634568598262632	-122.421412081826418
633	2019-03-07 04:02:14	2019-03-07	Jordyn Kertzmann-Purdy	jordyn.kertzmann.purdy@geemail.com	San Francisco	California	869942311843600512	17c3e615dd3bcd9c009f7e09a3ddf12f	JCB 16 digit	37.7974117520670561	-122.445817215518233
634	2019-03-07 07:05:09	2019-03-07	Kassie Herman	kassie.herman@geemail.com	San Francisco	California	51633470827433764	d9f872818b1028f9e22e8e56a856bcae	JCB 15 digit	37.7512292285099065	-122.446639856310753
635	2019-03-07 07:13:46	2019-03-07	Bryon Mayert V	bryon.mayert.v@geemail.com	Abilene	Texas	180049106377546641	1f4cc68ede8fd4c81a3ffc98f429cc2d	JCB 15 digit	32.4899164747521283	-99.82193931596764
636	2019-03-07 08:33:33	2019-03-07	Doris Robel	doris.robel@geemail.com	Berkeley	California	51030184218747331	58a096dc9a9680613d65c4adbd7a77f0	Mastercard	37.8519103715394394	-122.261904816348363
637	2019-03-07 20:27:29	2019-03-07	Oran Greenholt	oran.greenholt@warmmail.com	Raleigh	North Carolina	4890443985633630	3447a5824f8477ab7baab90b14fde44a	Maestro	35.8639921699784665	-78.6222325100500115
638	2019-03-08 06:18:58	2019-03-08	Dayanara Langosh	dayanara.langosh@geemail.com	Oakland	California	210076341293527815	ff7f16736985aee2d767ffc51b5d432f	VISA 16 digit	37.8284864756669137	-122.268788757595601
639	2019-03-08 07:21:04	2019-03-08	Ronan Stracke-Hammes	ronan.stracke.hammes@geemail.com	San Francisco	California	3035052375586621	b10a242dc4ac85fa2eeee5318266c1c3	VISA 13 digit	37.7824541088922388	-122.439599083063612
640	2019-03-08 10:36:48	2019-03-08	Dora Kilback	dora.kilback@warmmail.com	San Francisco	California	3096099243262539834	face97f91764a8f807e637f47994149a	Voyager	37.735668220492812	-122.449722799116799
641	2019-03-08 14:32:09	2019-03-08	Devyn Koepp	devyn.koepp@geemail.com	Tacoma	Washington	55412602009142675	71fa529e5dba20a990923ceac554df5c	JCB 15 digit	47.2799762994635842	-122.430587580823527
642	2019-03-08 15:37:25	2019-03-08	Mrs. Kaitlin Auer MD	mrs.kaitlin.auer.md@geemail.com	Pomona	California	55688020331164274	cfee523b930b39dadf419c685e527f2c	Voyager	34.1409567602947348	-117.753057371309396
643	2019-03-08 16:44:34	2019-03-08	Claiborne Tillman	claiborne.tillman@woohoo.com	San Francisco	California	639015288150731	f74b8ba4482cf22d4a1f3ed5825d3f64	Discover	37.7344238612647729	-122.421622857107835
644	2019-03-09 03:20:44	2019-03-09	Burke Dooley	burke.dooley@geemail.com	San Francisco	California	3049837250027733	5e289235d36479d34bc88d946b2571ed	JCB 16 digit	37.7591920381344579	-122.441903838509802
645	2019-03-09 05:00:23	2019-03-09	Dr. Benji Lehner	dr.benji.lehner@geemail.com	San Francisco	California	3158140968575096309	f13b8f41aadc25fca52d2f2b1089d60e	Voyager	37.7435684230413884	-122.458001801981723
646	2019-03-09 06:43:24	2019-03-09	Leala Effertz DVM	leala.effertz.dvm@warmmail.com	San Francisco	California	4328459492940773	8d0f289c048940723df93f27661875bd	American Express	37.7416483398004274	-122.43811895450267
647	2019-03-09 10:07:40	2019-03-09	Damien Collier	damien.collier@geemail.com	Miami Gardens	Florida	54482250131470740	af93a0a9c45b18b1e0abfab1286ff9d0	American Express	26.0265339497882842	-80.2837981358416357
648	2019-03-09 10:27:48	2019-03-09	Mahala Rempel-Hudson	mahala.rempel.hudson@geemail.com	Berkeley	California	4525881933400326	4a38ebdb32d15853f988bc0a8084e760	American Express	37.8662366555232524	-122.278849712754891
649	2019-03-09 16:04:14	2019-03-09	Dr. Minoru Adams IV	dr.minoru.adams.iv@warmmail.com	San Francisco	California	6011213665591097012	59d4d55483807f259ac6c6315118c453	VISA 16 digit	37.7620099116290788	-122.395518650969848
650	2019-03-09 17:25:19	2019-03-09	Tawanna Green	tawanna.green@warmmail.com	Fresno	California	3337531169482079267	7d6eda9f6dad3a7fbed554145bfcb6e2	Discover	36.8629525199871537	-119.779157433902483
651	2019-03-10 01:03:04	2019-03-10	Alida Gerhold	alida.gerhold@warmmail.com	Oakland	California	676392217782041	e56ced5794d433314e67b24ea2c793c3	JCB 15 digit	37.8051876861839489	-122.274738641044308
652	2019-03-10 02:54:38	2019-03-10	Brooks Ward	brooks.ward@geemail.com	San Francisco	California	4550365458168730	3b6289be34c900dfce40349e3d9fc45a	VISA 16 digit	37.7490385161002706	-122.477908467392439
653	2019-03-10 06:20:21	2019-03-10	Alethea Wolf	alethea.wolf@geemail.com	Clearwater	Florida	869987050519455258	e5a3bdb0a0746bd63839a7fcd703a6a6	JCB 15 digit	27.8901315367441605	-82.8272142573058545
654	2019-03-10 08:41:15	2019-03-10	Mr. Tristan Hodkiewicz	mr.tristan.hodkiewicz@geemail.com	San Francisco	California	4300724569490	91b3c5fe46fd1257b67a521d9e6f0c93	VISA 16 digit	37.768138765983629	-122.429596446102195
655	2019-03-10 12:36:12	2019-03-10	Mrs. Thelma Mitchell	mrs.thelma.mitchell@geemail.com	San Francisco	California	3528243232527718098	f30a877c5b8132ad002132c0faafb0da	JCB 16 digit	37.7683329339286047	-122.430571286424424
656	2019-03-10 17:14:33	2019-03-10	Dr. Jeanetta Weissnat	dr.jeanetta.weissnat@geemail.com	Sunnyvale	California	210015419156258688	6ba1cdb731948e37626aeb40d69d5f74	Diners Club / Carte Blanche	37.4018551401786539	-122.097237858428812
657	2019-03-10 18:03:35	2019-03-10	Eola Zieme	eola.zieme@geemail.com	Oakland	California	3528317499816661070	604968555fda17c1d0f78305cc9b5839	Discover	37.7816857680470761	-122.258557355075482
658	2019-03-11 02:02:13	2019-03-11	Kesha Lynch	kesha.lynch@geemail.com	New York	New York	675902276541063	52ea27c3fa2cac301b927cafaaaf090b	VISA 13 digit	40.7292128176186239	-73.9908224050782621
659	2019-03-11 03:46:15	2019-03-11	Bryon Kunde	bryon.kunde@warmmail.com	San Francisco	California	869995430724788745	756095ab4844be26501a359f47287cc6	JCB 15 digit	37.7648891408044207	-122.457454043376899
660	2019-03-11 04:20:51	2019-03-11	Arnie Fritsch	arnie.fritsch@warmmail.com	Oakland	California	210046518850401560	fd0e249b330c1340187db0528d608a93	VISA 13 digit	37.7976805716711226	-122.267220718796409
661	2019-03-11 12:52:29	2019-03-11	Marry Effertz-Hagenes	marry.effertz.hagenes@geemail.com	San Francisco	California	3528286176071705951	7b6bdbc1481a25d0d0f82ed8c13b6708	Mastercard	37.7799216977286889	-122.40307021277313
662	2019-03-11 18:09:04	2019-03-11	Lanny Wintheiser	lanny.wintheiser@geemail.com	San Francisco	California	3406005402955689	dc08bec95c8be1b521ed8a4d3553668d	Mastercard	37.7759083728819149	-122.423812643965192
663	2019-03-11 19:39:04	2019-03-11	Dijon Olson-Bins	dijon.olson.bins@woohoo.com	Miami	Florida	3734330333158450	7bc66f98684b385fcd7fc21e90e6634f	VISA 13 digit	25.7342334620792421	-80.1711053689349455
664	2019-03-12 01:06:56	2019-03-12	Dr. Claude Johns MD	dr.claude.johns.md@geemail.com	San Antonio	Texas	639016087157869	a7a9125af6fdaed9c23bebeb3f3f9fea	VISA 16 digit	29.4152820205386725	-98.4946671252906327
665	2019-03-12 13:43:50	2019-03-12	Dr. Jeff Bogisich II	dr.jeff.bogisich.ii@geemail.com	Oakland	California	869972086885159253	07b52a1e6b4bc7dd12b054c5f66f5769	JCB 16 digit	37.8235986183867041	-122.255545601783396
666	2019-03-12 13:44:06	2019-03-12	Delton Kutch III	delton.kutch.iii@geemail.com	Berkeley	California	4673107046512	0b9a6e29539063fde6d1b2d0bc18272d	JCB 16 digit	37.8747701479685617	-122.294614470520287
667	2019-03-12 21:26:25	2019-03-12	Dr. Ewing Hammes	dr.ewing.hammes@geemail.com	Los Angeles	California	53488850276327482	a466488abbb017920f9a2fb32bcda9ce	Voyager	33.9206256967835103	-118.446519994036478
668	2019-03-12 22:19:29	2019-03-12	Vance Rath	vance.rath@geemail.com	Oakland	California	53452934093685462	8cec06f08cb3f1317411fabc59a95d9a	Mastercard	37.840777926783872	-122.232015867932546
669	2019-03-12 22:20:08	2019-03-12	Mr. Theo Runolfsson III	mr.theo.runolfsson.iii@geemail.com	San Francisco	California	3096422296167484769	4a7ba2f0de98eb9993e50bb5e5bb2d6b	JCB 16 digit	37.7553374060537834	-122.441372212314334
670	2019-03-13 01:28:23	2019-03-13	Ms. Carma Walker MD	ms.carma.walker.md@warmmail.com	Berkeley	California	4385325641835554	58b87c3cf41d6e7d5d8a368f32a57725	VISA 16 digit	37.8541899352975264	-122.290623718137468
671	2019-03-13 01:40:42	2019-03-13	Kael Mueller	kael.mueller@geemail.com	Santa Clara	California	3112051434874221236	ae6dc1dc6acb4588adff4db14dede190	Voyager	37.30109986274541	-121.941169058438021
672	2019-03-13 02:08:03	2019-03-13	Ms. Cari Koelpin DDS	ms.cari.koelpin.dds@geemail.com	San Francisco	California	4689986463255	ea089e5f99132824fd328085c6d9649b	VISA 13 digit	37.7862850240327219	-122.412019506273495
673	2019-03-13 05:13:06	2019-03-13	Abagail Buckridge	abagail.buckridge@geemail.com	San Francisco	California	210043467800511982	bef63794a3ea35adae8c310a260869f4	Maestro	37.7496298570356359	-122.430490268666787
674	2019-03-13 14:31:45	2019-03-13	Clarence Wisoky	clarence.wisoky@geemail.com	Oakland	California	4533569199468455	07ae004773580d37615a45650a8c7241	Diners Club / Carte Blanche	37.818193424815739	-122.276740962681913
675	2019-03-13 17:44:16	2019-03-13	Leora Nikolaus	leora.nikolaus@geemail.com	Durham	North Carolina	3528963553323703820	003f28a1b040fba409a2d738d7a07e33	American Express	36.0018529525272513	-78.8676554093040494
676	2019-03-14 05:06:24	2019-03-14	Roby Heathcote	roby.heathcote@geemail.com	San Francisco	California	52865144675118780	48e8382d3fae324c4a75658e42ae115f	Maestro	37.7286153946908627	-122.438809570779014
677	2019-03-14 13:32:34	2019-03-14	Dr. Johney O'Hara DVM	dr.johney.o'hara.dvm@geemail.com	San Francisco	California	180022591464885591	61aa5ecda5df42f108b8c42f2d98a83e	Maestro	37.7618615054096693	-122.453602493207526
678	2019-03-14 15:09:57	2019-03-14	Brandon Aufderhar	brandon.aufderhar@geemail.com	San Francisco	California	3431159844161437	33b439deec84b006450a1b251cbf7f6d	JCB 15 digit	37.7918715825567162	-122.404569832525794
679	2019-03-14 16:05:04	2019-03-14	Diego Shanahan-Kohler	diego.shanahan.kohler@geemail.com	Phoenix	Arizona	4634758424060397	bd2b0ce787d808d1fb71e627766d72e3	Mastercard	33.6378715786084541	-112.014300103571642
680	2019-03-14 17:11:46	2019-03-14	Presley Streich	presley.streich@warmmail.com	Oakland	California	210098436585082109	30872c517ba32e9312c9d6a9be637bbf	American Express	37.8526638699208604	-122.27001111000834
681	2019-03-14 17:31:55	2019-03-14	Demetrius Koch Jr.	demetrius.koch.jr.@geemail.com	San Diego	California	3750159722118380	e37b05605d5d17ecbedee62fadcf97e4	VISA 16 digit	32.8586509255293748	-117.060726343598219
682	2019-03-15 00:32:40	2019-03-15	Mr. Granville Gulgowski	mr.granville.gulgowski@geemail.com	San Francisco	California	869918610575801291	7a57de833cf5fe8b865aa4b1ff8838f3	American Express	37.7732176972221083	-122.418701231951331
683	2019-03-15 04:08:54	2019-03-15	Miss Brittny McClure DDS	miss.brittny.mcclure.dds@geemail.com	San Francisco	California	869939878903574287	890338a73e244485128c73276b31d172	American Express	37.7614436738403612	-122.463697352308344
684	2019-03-15 09:46:42	2019-03-15	Mrs. Lakesha Bahringer	mrs.lakesha.bahringer@geemail.com	San Francisco	California	4215311307055758	dddf1a0b08847ac38bcfb4244f36eb04	JCB 16 digit	37.7770460807721236	-122.416559917540013
685	2019-03-15 09:54:35	2019-03-15	Jaheem Howell	jaheem.howell@warmmail.com	San Francisco	California	3009695158452084	59856bd96b1ef2deea0961f0af1e8316	VISA 16 digit	37.7787531071723777	-122.434516479422001
686	2019-03-15 13:02:58	2019-03-15	Dallas Yost	dallas.yost@geemail.com	Ontario	California	52007636642789204	7c155891ddb71ccb0b940eb63bd08b39	JCB 16 digit	33.9649430225282885	-117.585595973358309
687	2019-03-15 20:11:02	2019-03-15	Mannie Kub	mannie.kub@geemail.com	Raleigh	North Carolina	869964916082745316	f9d7bc3440da2cbe013ea54cad7b2dad	JCB 16 digit	35.7903662217449394	-78.6973491179693525
688	2019-03-15 20:47:55	2019-03-15	Council Orn	council.orn@warmmail.com	San Francisco	California	589365074754832	4bf16ccb65eac9e510317bd198048abc	American Express	37.7833463870061976	-122.42147064679159
689	2019-03-16 04:15:51	2019-03-16	Konnor Will	konnor.will@geemail.com	Oakland	California	51787817358686786	9893f9c9a60a3c67d77a3d53031b5ee3	Discover	37.7771638660951155	-122.292760697699876
690	2019-03-16 06:34:18	2019-03-16	Octavio Homenick	octavio.homenick@geemail.com	San Francisco	California	869939549862082931	316c15a135be2024d01080a5dd314fcd	Voyager	37.7809232063243172	-122.444830064232534
691	2019-03-16 11:47:34	2019-03-16	Clemence Turcotte	clemence.turcotte@geemail.com	Berkeley	California	6011785359162533278	12d6373da580f6de54fc2c5dac85e5f2	VISA 16 digit	37.8650759157615298	-122.259323645529335
692	2019-03-16 13:34:04	2019-03-16	Marisela Strosin	marisela.strosin@geemail.com	San Francisco	California	53428268023169086	21175de5c19aa2dd35ff2f2e6f5aab83	JCB 15 digit	37.7521111557282936	-122.459801512613794
693	2019-03-16 16:23:32	2019-03-16	Mindi Swaniawski	mindi.swaniawski@geemail.com	Chesapeake	Virginia	3112244588980168082	385f2ecb67862c399c640032e4f20f64	Mastercard	36.5907553258590426	-76.351057799843332
694	2019-03-16 18:39:25	2019-03-16	Lafe Bauch-Walter	lafe.bauch.walter@geemail.com	Manchester	New Hampshire	3337199192877096947	755b389a820b17b0b71649a83f501776	Diners Club / Carte Blanche	42.9785847039498421	-71.3710625250250104
695	2019-03-16 20:30:27	2019-03-16	Mr. Reece Parker DVM	mr.reece.parker.dvm@geemail.com	San Francisco	California	4260903677177545	d066a35721684ecabded8faabb261ea6	VISA 16 digit	37.7703345245960378	-122.399470122575707
696	2019-03-16 23:08:01	2019-03-16	Shad Kunde V	shad.kunde.v@geemail.com	San Francisco	California	676242036736801	8db6d6022fe93a05cc71b5ce2b7a7dea	JCB 16 digit	37.7793818895122442	-122.419290499565165
697	2019-03-17 00:22:15	2019-03-17	Logan Carroll	logan.carroll@woohoo.com	San Francisco	California	3528037984101330886	7d4c34c3d3c286fc8697ecfe7c6e9b46	VISA 13 digit	37.7634289271116543	-122.445872937213224
698	2019-03-17 02:02:46	2019-03-17	Lady DuBuque-Buckridge	lady.dubuque.buckridge@geemail.com	San Francisco	California	180035102110411512	03328b7797b2eb937c83cd4ded59f76a	Discover	37.8053764656165825	-122.423070105096755
699	2019-03-17 06:17:53	2019-03-17	Jami Witting	jami.witting@geemail.com	Portland	Oregon	4556016790051860	5e530806b436a8d20917a0f04db753f9	VISA 13 digit	45.4871614717300972	-122.686686964146801
700	2019-03-17 13:21:04	2019-03-17	Lovie Huels	lovie.huels@geemail.com	San Francisco	California	4094893652032033	635212fd02eb3a6c52c7b776be821b4a	VISA 16 digit	37.8023526374096122	-122.41090093668555
701	2019-03-17 13:28:14	2019-03-17	Breana Pouros DDS	breana.pouros.dds@geemail.com	San Francisco	California	3492454454497585	a1715db13ac631fc82cc56ab66fecdad	VISA 16 digit	37.784431135024164	-122.419048754221521
702	2019-03-17 21:23:18	2019-03-17	Dr. Roswell Dibbert	dr.roswell.dibbert@warmmail.com	San Francisco	California	676229852744985	c23b351253e2534780b12ff1925e1696	VISA 16 digit	37.7967498361633218	-122.391021864463653
703	2019-03-17 23:38:27	2019-03-17	Cash Gibson	cash.gibson@geemail.com	Oxnard	California	3442815254470454	ef737ece032ef5ef9425c95f307eee68	Diners Club / Carte Blanche	34.1752905695188787	-119.233968273448198
704	2019-03-18 02:35:32	2019-03-18	Harm Runte	harm.runte@geemail.com	Oakland	California	180013644912451952	8e8a66b6c8b97888080a1e853620a0ca	American Express	37.8205308234196025	-122.282558411347409
705	2019-03-18 04:41:33	2019-03-18	Ramsey Graham	ramsey.graham@geemail.com	Berkeley	California	3454740062286212	f9f5c5c90fd09dfe37d48c41a552ad86	VISA 16 digit	37.8476094434203674	-122.277873547732185
706	2019-03-18 05:19:15	2019-03-18	Leonie Dickinson PhD	leonie.dickinson.phd@geemail.com	Bakersfield	California	210061332805662262	030ccc83bd5df6b121446e6772659009	VISA 13 digit	35.3498188484169518	-119.009895224663609
707	2019-03-18 09:26:01	2019-03-18	Raina Zulauf	raina.zulauf@geemail.com	San Francisco	California	869901784805758438	54716e18c4137eb9ad2e1e7c69dd2ce9	JCB 16 digit	37.7642247379625928	-122.418497936814489
708	2019-03-18 11:20:35	2019-03-18	Velda Armstrong	velda.armstrong@warmmail.com	San Francisco	California	3112734553750147176	4b4e0f61077b547e367d90c0587d8f5b	JCB 16 digit	37.7846350454708144	-122.471497949908809
709	2019-03-18 20:56:55	2019-03-18	Miss Annmarie Jenkins	miss.annmarie.jenkins@geemail.com	Berkeley	California	180039329134501905	d855801bb59cf78cacc351ecad58502f	JCB 16 digit	37.8865785279520324	-122.252959159031306
710	2019-03-18 23:04:03	2019-03-18	Dr. Landan Considine PhD	dr.landan.considine.phd@geemail.com	Washington	District of Columbia	4828990634040986	91fa997588fc4b43f40c7a343ffde5ea	Voyager	38.9547751009263123	-76.9424058338373982
711	2019-03-19 06:51:16	2019-03-19	Constantine Hayes Jr.	constantine.hayes.jr.@geemail.com	San Francisco	California	4449360286384406	9acb2dfafa9f5d314dfa3c188cf05ce5	Discover	37.7732463169114112	-122.4042289417891
712	2019-03-19 07:47:21	2019-03-19	Maxx Heidenreich	maxx.heidenreich@geemail.com	Arvada	Colorado	3088602918616867276	a4729c57c8da8bb88520e55d100f72b0	American Express	39.7737424033869047	-105.240855270062767
713	2019-03-19 16:12:17	2019-03-19	Harmon Zemlak	harmon.zemlak@geemail.com	Hialeah	Florida	3437849232065976	411cfb1bc6864a1ff7c66884ffce765a	Discover	25.836818624984101	-80.3959120379198282
714	2019-03-19 19:10:32	2019-03-19	Mr. Gaines Bruen DVM	mr.gaines.bruen.dvm@geemail.com	San Francisco	California	589313175030736	14c052542f02fef0fdfbb835b05e8381	Maestro	37.7637171014684299	-122.415891104834003
715	2019-03-19 19:27:02	2019-03-19	Elgin Leannon	elgin.leannon@geemail.com	San Francisco	California	6011137761724992063	529e821ae4f57d44f096d6a8927504cc	VISA 16 digit	37.7868387799914558	-122.464047624744722
716	2019-03-19 21:21:29	2019-03-19	Wong Koelpin	wong.koelpin@geemail.com	San Francisco	California	3761925877701007	61311fe3dbba9b38352454b20b432b70	JCB 16 digit	37.7727402837961534	-122.427798318503449
717	2019-03-20 01:54:37	2019-03-20	Zella Feest	zella.feest@geemail.com	San Francisco	California	3112312330965780830	8c7a8af223d0dbaede7f9c85079a27ac	American Express	37.7519309529553482	-122.451800888168862
718	2019-03-20 05:54:31	2019-03-20	Kailee Ondricka-Friesen	kailee.ondricka.friesen@geemail.com	Saint Paul	Minnesota	4931125968483	538fb17588f6c5912d0e74bb5fb045b5	VISA 16 digit	44.9939189068447831	-93.1074185008447586
719	2019-03-20 12:40:49	2019-03-20	Dr. Stetson O'Connell	dr.stetson.o'connell@geemail.com	San Francisco	California	3088801753109601422	53d4a7a499ccac5d32e3e9a70920340a	VISA 13 digit	37.7657601834347574	-122.422788308659761
720	2019-03-20 15:50:16	2019-03-20	Bird Vandervort	bird.vandervort@geemail.com	Murrieta	California	3088224142758879233	dcb6f42e4bbaddb213966b336547a622	Discover	33.6602783354561765	-117.187920187729972
721	2019-03-20 17:46:50	2019-03-20	Mrs. Odie Schaefer	mrs.odie.schaefer@geemail.com	Berkeley	California	869920402937008716	59b5811386b2f9cbd4125309fd262536	VISA 16 digit	37.8601384760119899	-122.258464592176196
722	2019-03-20 22:32:42	2019-03-20	Mrs. Marta Torp PhD	mrs.marta.torp.phd@warmmail.com	San Francisco	California	6011870166902965777	f71de84ed5dec26f6cae2c29113fe192	JCB 16 digit	37.7368484797354	-122.426505089921022
723	2019-03-21 03:47:36	2019-03-21	Clarine Bernier	clarine.bernier@geemail.com	San Francisco	California	502005580593688	0985ee3688f7af2853c8c3aa55281d52	VISA 13 digit	37.7939831726593525	-122.432283143880525
724	2019-03-21 04:10:54	2019-03-21	Winnie Waters	winnie.waters@geemail.com	Oakland	California	4447386091147	3b4a30cbba00e6f3b3e583987b1f649e	VISA 16 digit	37.8434449501678074	-122.265320407326882
725	2019-03-21 10:10:26	2019-03-21	Dr. Eben Streich	dr.eben.streich@geemail.com	Oklahoma City	Oklahoma	869922292174440120	6dd61e24d147ac3f69cbd3e853672baa	Maestro	35.3721427674781523	-97.5503690030787141
726	2019-03-21 17:09:43	2019-03-21	Eppie Krajcik PhD	eppie.krajcik.phd@geemail.com	Anchorage	Alaska	869931250640996066	d50b45db7985d1880c323e306b9cc348	VISA 16 digit	61.1183417211968489	-149.303541140270596
727	2019-03-21 18:39:00	2019-03-21	Gay Kertzmann	gay.kertzmann@geemail.com	San Francisco	California	4303890273053	c25a35798c0a74ec034323d7ce718519	VISA 16 digit	37.7775340943106528	-122.426137703755131
728	2019-03-21 23:58:32	2019-03-21	Flossie Abshire	flossie.abshire@geemail.com	Berkeley	California	3158559706885869500	4cf75a2a6f6f0436ad07d15210134bfa	VISA 16 digit	37.8807280875182215	-122.250155643472624
729	2019-03-22 03:10:18	2019-03-22	Prosper Schaefer	prosper.schaefer@geemail.com	Oakland	California	6011459848467096374	ea39fa4d075eba37080f8e41b585f0e5	Voyager	37.7964936352592318	-122.273638328040121
730	2019-03-22 03:25:08	2019-03-22	Harold Price	harold.price@geemail.com	San Francisco	California	3096537668204302265	7ddc3f2791efb1ea49065777e1c1a51f	Maestro	37.7616162281736507	-122.423772583650575
731	2019-03-22 04:00:43	2019-03-22	Hoyt Witting	hoyt.witting@woohoo.com	New York	New York	53641670188552306	7dc85c83cd656357c33b7eba7fe2f756	Voyager	40.5805369049068503	-74.0104040708754241
732	2019-03-22 04:45:45	2019-03-22	Lurena Reinger	lurena.reinger@warmmail.com	San Francisco	California	3418767440691198	9629e5c548d8d69153052f8f5ad50174	VISA 16 digit	37.7944518298167722	-122.441868355795421
733	2019-03-22 09:15:25	2019-03-22	Mrs. Hertha Abbott DDS	mrs.hertha.abbott.dds@geemail.com	New York	New York	4590358852083482	bd4bd28c5a9f0b845f552718a9de2675	VISA 16 digit	40.6261745160203418	-73.8551640602189963
734	2019-03-22 18:04:44	2019-03-22	Berdie Auer-Gusikowski	berdie.auer.gusikowski@woohoo.com	San Francisco	California	210070944288900941	2a4aeb4848cbb5ade350bf58d0f3c8a9	JCB 16 digit	37.7356947514212777	-122.44601674163772
735	2019-03-22 23:39:46	2019-03-22	Valorie Goyette	valorie.goyette@woohoo.com	San Francisco	California	52472357994556721	f7f1afdbee3e63ba73005a25309646c4	Diners Club / Carte Blanche	37.7287556995201925	-122.413166782253157
736	2019-03-23 08:34:52	2019-03-23	Elvia Zemlak PhD	elvia.zemlak.phd@geemail.com	Washington	District of Columbia	6011369390558395174	28613696284883607c80cf29292db73f	VISA 16 digit	38.8093142219152298	-77.0750991741407745
737	2019-03-23 09:23:16	2019-03-23	Kandi Gorczany DDS	kandi.gorczany.dds@geemail.com	San Francisco	California	4300161683093	cafea7dab932f6941d0413e5b967c114	American Express	37.7814945550371135	-122.422980118031447
738	2019-03-23 17:04:37	2019-03-23	Lia Schimmel	lia.schimmel@geemail.com	Miami	Florida	3096925451428669060	c6b64aebc2a56eb4024084140a70a0d3	JCB 16 digit	25.6777230955798181	-80.1654736977409641
739	2019-03-23 18:02:29	2019-03-23	Manuelita Pacocha	manuelita.pacocha@geemail.com	San Francisco	California	3738658036748789	f105ba8434981da04c91943e8ef74c35	VISA 16 digit	37.7508806706666249	-122.418945939628131
740	2019-03-23 18:50:55	2019-03-23	Dr. Elza Watsica	dr.elza.watsica@geemail.com	San Francisco	California	6011969858463692103	00ff426e5a633ea46c7d685fbbf017bf	Diners Club / Carte Blanche	37.7438647602834862	-122.430243603306366
741	2019-03-23 21:28:51	2019-03-23	Uriah Dickinson III	uriah.dickinson.iii@geemail.com	San Francisco	California	869900198427676368	b387478af18c1e9ac0a9a5d83accfa57	Mastercard	37.7731733297547407	-122.417226750787705
742	2019-03-23 22:58:08	2019-03-23	Damien Paucek Sr.	damien.paucek.sr.@geemail.com	Oakland	California	3158484551232976487	6b98a541e7d25ee5d1a165a15ffa0713	Discover	37.7932168319478308	-122.258466401386542
743	2019-03-24 01:20:46	2019-03-24	Ford Grady	ford.grady@woohoo.com	Oakland	California	4531705447200405	08f76590ef32f737e954f931cc502bc6	Discover	37.7869945627328576	-122.265924130302011
744	2019-03-24 02:41:06	2019-03-24	Akeelah Kunde	akeelah.kunde@geemail.com	San Francisco	California	3021610627302933	effeb62e8e09e5d93ef8ba9cdd317012	Diners Club / Carte Blanche	37.7745881581449581	-122.462845393017489
745	2019-03-24 03:13:26	2019-03-24	Ottilia Boehm-Ryan	ottilia.boehm.ryan@geemail.com	San Francisco	California	4128860530954050	761d28cca71c1bd086ca52d699ac0727	VISA 16 digit	37.7761101166943547	-122.448250036930361
746	2019-03-24 05:39:24	2019-03-24	Lessie Kulas	lessie.kulas@geemail.com	San Francisco	California	3158081422375781703	19bb70d1ffd81eb2e204f9ae2cae26ee	VISA 16 digit	37.7789551120394265	-122.424707257542423
747	2019-03-24 05:42:18	2019-03-24	Venie Hamill	venie.hamill@geemail.com	San Francisco	California	869961727597859333	e8f7f861fc3877430a4d0e20e3b5dd6d	American Express	37.7506972290799467	-122.447262953589828
748	2019-03-24 12:41:59	2019-03-24	Maybelle Davis	maybelle.davis@geemail.com	Phoenix	Arizona	4874640399257	7d0c2831a6e47b621e3558566433a019	JCB 16 digit	33.6233318714823568	-112.023299838968001
749	2019-03-24 19:24:18	2019-03-24	Mr. Jameel Zboncak	mr.jameel.zboncak@geemail.com	San Francisco	California	3096280317183411379	9075ddca06a0b277d5bb6401d35b2ea5	JCB 16 digit	37.7644452659312222	-122.439642286684048
750	2019-03-24 20:46:48	2019-03-24	Ellery DuBuque-Mayer	ellery.dubuque.mayer@geemail.com	Oceanside	California	53761602225185398	408eadeb2301d452e541854f93cf321c	VISA 13 digit	33.1495860481057321	-117.288602298506348
751	2019-03-25 01:47:33	2019-03-25	Garrison Beatty	garrison.beatty@woohoo.com	Berkeley	California	3039057866515068	27ba0252916eac9bed8c0c4c52610d82	JCB 16 digit	37.8601450367786185	-122.2992019167515
752	2019-03-25 08:31:21	2019-03-25	Mateo Jacobi	mateo.jacobi@warmmail.com	Hartford	Connecticut	4028716590631536	229506ab0fba93db213f470407209628	Mastercard	41.6662408938180704	-72.6998388525456249
753	2019-03-25 16:17:55	2019-03-25	Dr. Verl Runolfsson	dr.verl.runolfsson@warmmail.com	Memphis	Tennessee	4038278142450	5afa39a2e4cb02da56655dbe87731b47	VISA 16 digit	35.0517986927714205	-90.0003013159405469
754	2019-03-25 18:44:38	2019-03-25	Dr. Burleigh Grimes II	dr.burleigh.grimes.ii@woohoo.com	San Francisco	California	3023233996503763	975c3e3f212652e60cf14a4c18708af1	JCB 16 digit	37.7872523169941843	-122.422088676234239
755	2019-03-25 22:22:16	2019-03-25	Frederick Reynolds-Feest	frederick.reynolds.feest@geemail.com	Berkeley	California	4798369357651	8d549bc4c2a0a45b94a00ff35d5aa379	Mastercard	37.8988317772004351	-122.245150502837646
756	2019-03-25 22:34:19	2019-03-25	Micah Prosacco	micah.prosacco@warmmail.com	Berkeley	California	869953982594393907	36920b4281eb6d1b7456250cca76c167	Mastercard	37.8471945181723015	-122.262140511099702
757	2019-03-25 23:02:59	2019-03-25	Mr. Renaldo Schinner III	mr.renaldo.schinner.iii@woohoo.com	San Francisco	California	51295777414909421	faec497410336445963c3ec0edb1afff	Diners Club / Carte Blanche	37.7780809609239867	-122.40460553643787
758	2019-03-26 01:00:44	2019-03-26	Caro Kassulke	caro.kassulke@woohoo.com	Green Bay	Wisconsin	4267907929474132	da62c8fe9cc4d38a8fb48445a6d569a2	VISA 16 digit	44.5777676217321286	-88.06412105381564
759	2019-03-26 02:42:51	2019-03-26	Willie Rohan	willie.rohan@warmmail.com	San Francisco	California	869943090424144731	7efe1fac14380860924bf634b15a4c8d	Voyager	37.7550301609012777	-122.423136746590558
760	2019-03-26 06:30:32	2019-03-26	Tiara Volkman	tiara.volkman@woohoo.com	San Francisco	California	869956569479572445	8fedbbe6397dc14763122fb584b25fc6	Discover	37.7738368904593926	-122.424877614494008
761	2019-03-26 09:10:41	2019-03-26	Dominque Schaefer	dominque.schaefer@geemail.com	San Francisco	California	52348442786963608	1636a57f79d357906752088f68dfedf4	VISA 13 digit	37.7915986655404836	-122.430371813000406
762	2019-03-26 09:28:17	2019-03-26	Veta Connelly	veta.connelly@geemail.com	San Francisco	California	3088379028617380542	6817299c68129d3f761e3f9d3e389d01	American Express	37.8016378692751331	-122.421767860082909
763	2019-03-26 17:10:24	2019-03-26	Desirae Kohler PhD	desirae.kohler.phd@geemail.com	San Francisco	California	3158455449436255037	886e236ed1b8a087e47cced0da8735d8	Maestro	37.8232827626776711	-122.435064074307178
764	2019-03-26 23:10:46	2019-03-26	Park Hoeger-Quigley	park.hoeger.quigley@geemail.com	Honolulu	Hawaii	6011334501316996978	2415ad892bb0847d079b81ce6199737b	Discover	21.3735511979304249	-157.790414483214164
765	2019-03-27 01:28:27	2019-03-27	Ms. Camryn Schamberger	ms.camryn.schamberger@warmmail.com	San Francisco	California	869960015974736592	cb8dacf4b334805ba1f57afdf4482194	JCB 15 digit	37.7892276514023209	-122.411922927841161
766	2019-03-27 03:53:44	2019-03-27	Aubrie Morar	aubrie.morar@geemail.com	Oakland	California	53425124325175979	f2f45583767b3c893c4d530bd17daaea	VISA 16 digit	37.752195430985914	-122.264357712218313
767	2019-03-27 04:04:25	2019-03-27	Pate DuBuque	pate.dubuque@geemail.com	Las Vegas	Nevada	3701861688217854	40b06aed695867b6c986050c69982710	VISA 16 digit	36.2145025001008065	-115.31048127270526
768	2019-03-27 04:25:57	2019-03-27	Kody Goyette	kody.goyette@warmmail.com	San Francisco	California	3494478313333770	a0a73363bfdf192183b50c01fba68fa7	American Express	37.809469849101319	-122.428244522000682
769	2019-03-27 08:06:12	2019-03-27	Oland Hackett II	oland.hackett.ii@woohoo.com	Los Angeles	California	210017064537035716	3c811b56165738ac53e4fac7f41aa110	VISA 16 digit	34.1169903958082159	-118.447815520408739
770	2019-03-27 14:03:47	2019-03-27	Selena Kris	selena.kris@warmmail.com	Berkeley	California	589313279101664	4211340083416e0a7073b4cfdd31c4ea	JCB 15 digit	37.8660527231542403	-122.28330293256677
771	2019-03-27 21:21:19	2019-03-27	Celestia Jenkins	celestia.jenkins@geemail.com	Berkeley	California	3041011528654052	be50574626f527267401c572231f4f0a	Voyager	37.9069897839276351	-122.269188212452519
772	2019-03-28 03:53:15	2019-03-28	Shirlie Adams	shirlie.adams@warmmail.com	Berkeley	California	4646820385912184	ef501fc11ed2ec9952718994a0be4f65	JCB 15 digit	37.8906163658309225	-122.282303807233191
773	2019-03-28 04:37:29	2019-03-28	Miss Londyn Torphy MD	miss.londyn.torphy.md@geemail.com	San Francisco	California	4009799725602	661d7b2bbf6c57195f79847b6d517470	Voyager	37.7822844362511319	-122.421928870270889
774	2019-03-28 13:39:48	2019-03-28	Mr. Malik Pagac	mr.malik.pagac@warmmail.com	Wichita	Kansas	180010797641978217	69ddbe6d29c4d3008a5c793c9b2ed11c	American Express	37.6816074701834438	-97.3423781743008618
775	2019-03-28 15:08:06	2019-03-28	Caren Hickle	caren.hickle@geemail.com	San Francisco	California	503837070469236	e858378333ea16b45407e087d656e366	VISA 16 digit	37.7243678635195678	-122.396119916418868
776	2019-03-28 16:17:13	2019-03-28	Braulio Cruickshank-Schumm	braulio.cruickshank.schumm@geemail.com	Arlington	Texas	3096928452250657949	50dc7d737ac8056a8f0220d4de21943f	Mastercard	32.6489988580595707	-97.1983013546586108
777	2019-03-28 17:48:31	2019-03-28	Stewart Wunsch	stewart.wunsch@geemail.com	Oakland	California	502012572924863	7b83ed98f59401bb7347114f8e3da385	JCB 15 digit	37.802378989190359	-122.24930484776489
778	2019-03-28 23:30:45	2019-03-28	Jossie Rohan	jossie.rohan@geemail.com	Oakland	California	630451593639779	d1e776ded775922ac5d17ca246ab0f1b	JCB 16 digit	37.8075314282770663	-122.300675453593882
779	2019-03-29 06:03:36	2019-03-29	Garvin Russel DVM	garvin.russel.dvm@geemail.com	Oakland	California	3158132753005412411	518d732eef804145dc40cea3d08b1296	Mastercard	37.8222691562247277	-122.272181560839343
780	2019-03-29 07:22:15	2019-03-29	Lee West	lee.west@woohoo.com	Pomona	California	180089769522528029	49dc3628b127b8ff62a654acf7c20669	Mastercard	33.9756310232486598	-117.757747916501387
781	2019-03-29 07:36:44	2019-03-29	Tiarra Fadel	tiarra.fadel@geemail.com	Berkeley	California	4631778218422	9f6aaab9a5560a0f702bb3072818abb1	Diners Club / Carte Blanche	37.8942224630002116	-122.248219712237329
782	2019-03-29 14:27:28	2019-03-29	Miss Graciela Stanton	miss.graciela.stanton@geemail.com	Irvine	California	3772647564464791	6b291cbf73987b0dcfe6dba6fa388d37	American Express	33.5823367486257141	-117.692755609658732
783	2019-03-29 16:47:05	2019-03-29	Linn Maggio	linn.maggio@geemail.com	Oakland	California	3112534488577584487	e8a17a655a4429ae6f90f16fdbf75a23	American Express	37.8046302949953628	-122.274426151948063
784	2019-03-29 18:52:28	2019-03-29	Kendell Tillman-Ullrich	kendell.tillman.ullrich@geemail.com	San Francisco	California	676109310708012	8210a51f83166701ae4595346bf12a9e	Mastercard	37.7384783375806592	-122.434082045895309
785	2019-03-29 19:01:58	2019-03-29	Aldona Krajcik MD	aldona.krajcik.md@woohoo.com	San Francisco	California	4323629644718724	c69d8b83da6a6a399c39b289f6e124dd	Mastercard	37.7542738826300237	-122.425863884694266
786	2019-03-29 21:12:29	2019-03-29	Amalia Prosacco	amalia.prosacco@geemail.com	Berkeley	California	4727887144651728	91600389c384508d8600479a7c83a0d8	JCB 16 digit	37.9059962261323093	-122.291129002374362
787	2019-03-30 02:18:30	2019-03-30	Giovanny Schinner	giovanny.schinner@geemail.com	San Francisco	California	4592376099380972	0e257b348aeaf731594e313da275f721	Voyager	37.7661140315586721	-122.431207193152559
788	2019-03-30 04:31:38	2019-03-30	Lovisa Quitzon	lovisa.quitzon@geemail.com	Berkeley	California	4243071043398542	28662faf6a522763b8f798e330de7aa7	JCB 15 digit	37.888096442781908	-122.257276230525704
789	2019-03-30 04:32:49	2019-03-30	Nilda Huel	nilda.huel@warmmail.com	St. Louis	Missouri	52114516833640764	7926be6fd5b8b48b7094af28b1eaada3	Discover	38.5814186826970413	-90.201328002009916
790	2019-03-30 05:24:30	2019-03-30	Melisa Lesch-Purdy	melisa.lesch.purdy@warmmail.com	Oakland	California	869921670930584094	c8babf7a64e782ef6f3487057d7f4039	VISA 13 digit	37.8013772709627389	-122.244578382968555
791	2019-03-30 05:35:50	2019-03-30	Deane Gutkowski-Swaniawski	deane.gutkowski.swaniawski@geemail.com	Omaha	Nebraska	6011242791239941216	31f241ca6c62c9dbf78e93db65d10374	American Express	41.2175024137046222	-95.9801074123591178
792	2019-03-30 16:03:11	2019-03-30	Odile Smith-Nicolas	odile.smith.nicolas@woohoo.com	San Francisco	California	4031671834864	4a45c2d1cc09872c1621d8c86482bcc1	JCB 15 digit	37.8139156044890115	-122.468698810621689
793	2019-03-30 16:16:03	2019-03-30	Dr. Nyasia Waelchi PhD	dr.nyasia.waelchi.phd@geemail.com	Oakland	California	630407371856316	7d52530f63bfa442808a610fd891b8e8	JCB 15 digit	37.7818093014092824	-122.268114644751634
794	2019-03-30 16:53:17	2019-03-30	Marcie Corwin	marcie.corwin@geemail.com	Oakland	California	4425073672143454	1727c44c609c842b0337758b87222d12	Maestro	37.7779956927078615	-122.279054808235458
795	2019-03-31 10:10:55	2019-03-31	Keegan Wintheiser	keegan.wintheiser@geemail.com	San Francisco	California	869935867608290616	94860f5fc6b880ca04664cb2d3dd2173	JCB 16 digit	37.7860237240813035	-122.404230458433233
796	2019-03-31 10:31:10	2019-03-31	Lorenza Medhurst	lorenza.medhurst@geemail.com	Everett	Washington	4487227062204	c71d9c1b79db0554b39b5598a089b9e4	VISA 13 digit	47.9981535532403782	-122.198631612037872
797	2019-03-31 10:47:58	2019-03-31	Dr. Yaakov Bruen	dr.yaakov.bruen@warmmail.com	Berkeley	California	869981510765024724	28715e8e03249f1b5c247db1849dd1be	VISA 13 digit	37.8441706228375594	-122.263685306494068
798	2019-03-31 11:46:17	2019-03-31	Grayce Pouros	grayce.pouros@warmmail.com	San Francisco	California	3096390945527613677	ae69f79d3cf844990b4898fe20540b05	Discover	37.7606178150602645	-122.468974094239442
799	2019-03-31 13:40:57	2019-03-31	Brittnee Jones	brittnee.jones@geemail.com	San Francisco	California	3003805142947695	7631a89bdc4ef56e1423bb96ccf61039	JCB 16 digit	37.7876038717596572	-122.450104524802086
800	2019-03-31 20:56:36	2019-03-31	Abe Dickens	abe.dickens@geemail.com	Coral Springs	Florida	869916145693165792	cfb6962042c3d92164c026df6d4c8b67	Diners Club / Carte Blanche	26.2039148976624041	-80.29805001948327
801	2019-03-31 22:08:29	2019-03-31	Vara Hills DDS	vara.hills.dds@geemail.com	Oakland	California	3096026540948872192	551bb8884569c384bce412e9a9b6a677	VISA 16 digit	37.7948136387481028	-122.298095836150793
802	2019-03-31 22:16:26	2019-03-31	Nancy Jacobs	nancy.jacobs@geemail.com	San Francisco	California	4915515530110312	b5f4577ec337497c90dc6216037c41cf	American Express	37.7585634558343486	-122.453703203112823
803	2019-04-01 02:43:32	2019-04-01	Mr. Jaden Block II	mr.jaden.block.ii@warmmail.com	San Francisco	California	4176657919773718	da06b56e765530b2767b514864558561	American Express	37.8186248479762881	-122.438607989454653
804	2019-04-01 04:18:06	2019-04-01	Ara Bednar	ara.bednar@geemail.com	San Francisco	California	4078377744822	e705dcff93a0686a532e05d8af066605	Diners Club / Carte Blanche	37.7997620354376522	-122.403949523589048
805	2019-04-01 06:05:33	2019-04-01	Basil Pacocha III	basil.pacocha.iii@warmmail.com	San Francisco	California	4527801895541188	46b7ee4899bcc64eb6e83aa3e366e798	JCB 15 digit	37.7831023615493962	-122.444616569690908
806	2019-04-01 08:48:17	2019-04-01	Madilynn Block	madilynn.block@woohoo.com	Berkeley	California	6011568937762474150	c8f6d555f6a91aa39916e5d4ce750ade	American Express	37.8597529493583309	-122.282209368035268
807	2019-04-01 12:00:57	2019-04-01	Arlie Wiegand	arlie.wiegand@geemail.com	San Francisco	California	6011259258399776220	56287285cd8f581c7a4b2aa859e3abae	JCB 16 digit	37.7569139701514231	-122.425762725151671
808	2019-04-01 15:16:34	2019-04-01	Ettie Prohaska-Marks	ettie.prohaska.marks@woohoo.com	San Francisco	California	3088812916103215187	11c2968492388add1441548ae3dd04ca	Discover	37.8054942307991269	-122.44327137607533
809	2019-04-01 18:55:03	2019-04-01	Nita Homenick DDS	nita.homenick.dds@geemail.com	Fayetteville	North Carolina	869947422006718416	2dc2ce31de945e6bcb0b88fb14fb04b5	JCB 16 digit	35.1710065042387683	-78.9692642940338771
810	2019-04-01 23:31:30	2019-04-01	Samatha Hoppe PhD	samatha.hoppe.phd@geemail.com	Columbia	Missouri	6011554086700342388	f5372618b11099888b88a84008fdb3c9	VISA 16 digit	39.049884803395031	-92.252089101221145
811	2019-04-02 00:26:18	2019-04-02	Venus Boyer	venus.boyer@geemail.com	Berkeley	California	4597597275258956	3923f233b49fe9d8206fe7706e49911e	JCB 16 digit	37.8752490772866111	-122.273458759278526
812	2019-04-02 04:17:05	2019-04-02	Elmyra Cremin	elmyra.cremin@warmmail.com	Fort Worth	Texas	4506596197760	826d7a549c1240ca9db453f6f25320fb	VISA 16 digit	32.7528855635840443	-97.2975228797465519
813	2019-04-02 04:24:27	2019-04-02	Cleola Russel	cleola.russel@geemail.com	San Francisco	California	6011324386692328273	5edf8f04e016e3210ef3f3212a07dfe3	Mastercard	37.765849443878075	-122.427690550026966
814	2019-04-02 09:13:26	2019-04-02	Janette Bins-Wilderman	janette.bins.wilderman@geemail.com	Fort Wayne	Indiana	54931024446770152	cf76fc575c8969113fbe17c2c37a00d9	American Express	41.157010132797808	-85.1752911331351896
815	2019-04-02 10:17:30	2019-04-02	Philomene Emard MD	philomene.emard.md@geemail.com	Oakland	California	3337626597806046727	62efd04b89b027036a26bffe2cedcf35	JCB 16 digit	37.7968440796199729	-122.244343915908459
816	2019-04-02 15:27:01	2019-04-02	Jarrett Koepp	jarrett.koepp@geemail.com	Oakland	California	4554568550863	b60bb94250a935ccd993437a36df4ed5	American Express	37.8127593766147569	-122.263364627991365
817	2019-04-02 20:17:36	2019-04-02	Easter Gerhold MD	easter.gerhold.md@geemail.com	San Francisco	California	6011533971334034103	03c99ebe3d71f71e6989916ced8af4a9	Mastercard	37.7602154152081013	-122.44365512172169
818	2019-04-03 00:30:53	2019-04-03	Gay Schowalter	gay.schowalter@warmmail.com	San Francisco	California	3752930806177114	51b8690711e3d8464d27be58d13d7c94	VISA 13 digit	37.760293008268583	-122.447666369492723
819	2019-04-03 02:31:37	2019-04-03	Mr. Kristoffer Romaguera	mr.kristoffer.romaguera@geemail.com	San Francisco	California	3039088545493005	ddd34cfb31e4fc68ab94f69bd68ee68c	Diners Club / Carte Blanche	37.7693941002218949	-122.460104402659766
820	2019-04-03 06:40:53	2019-04-03	Hakim Kautzer	hakim.kautzer@warmmail.com	San Francisco	California	3764974877113331	ccf2bf5f22d2fa460f34e6e56bdd6872	American Express	37.7606208405879187	-122.409685893514791
821	2019-04-03 06:59:11	2019-04-03	Ms. Shara Kertzmann	ms.shara.kertzmann@geemail.com	San Francisco	California	3337400332195877249	d10625706f13a35dabc7e0f4215eb7a4	VISA 16 digit	37.7594841631586249	-122.438338549768403
822	2019-04-03 08:13:37	2019-04-03	Mrs. Madie Zieme	mrs.madie.zieme@geemail.com	San Francisco	California	4223637066141	908672e29fc55d87587abbb812eb4660	Diners Club / Carte Blanche	37.7721180841149788	-122.426709799005678
823	2019-04-03 09:12:45	2019-04-03	Vere Kertzmann	vere.kertzmann@geemail.com	Durham	North Carolina	3011084694909394	7711d1f68b264bceb8cab467ec5f9d89	Maestro	35.8975314991328815	-78.9535919896695759
824	2019-04-03 11:37:33	2019-04-03	Ms. Meaghan Stroman	ms.meaghan.stroman@warmmail.com	San Francisco	California	3027777778267423	ffb5a910609a1bc264735aa5dc3b493c	VISA 13 digit	37.7658650282923958	-122.397159574745899
825	2019-04-03 19:28:23	2019-04-03	Arthor O'Conner-Jaskolski	arthor.o'conner.jaskolski@woohoo.com	Norfolk	Virginia	3475438147962007	7a08d30ae334bddba3eefb1e4cabc0a0	JCB 16 digit	36.9343138764631007	-76.167832495738196
826	2019-04-04 00:38:41	2019-04-04	Joaquin Blick	joaquin.blick@woohoo.com	San Francisco	California	180073192775411009	16ada3bc5b814735698f1f2b3f09911c	Maestro	37.7927437188220807	-122.439905535969288
827	2019-04-04 06:43:06	2019-04-04	Mikal Gutkowski	mikal.gutkowski@geemail.com	San Francisco	California	3088718175476809564	ae9784c0facc1913281f86b8647c26b1	Mastercard	37.8354895915812577	-122.428994260288462
828	2019-04-04 10:27:07	2019-04-04	Nealy Collins	nealy.collins@geemail.com	Miami	Florida	4845415757861	d3cb798c40b59a7eac83be109e845c86	VISA 16 digit	25.7542723765734607	-80.2391952902417671
829	2019-04-04 15:22:47	2019-04-04	Arden Beahan	arden.beahan@geemail.com	San Francisco	California	503859354037828	4108f9d39bd17ff7b4a25557baf6b0d3	Diners Club / Carte Blanche	37.7686238080701813	-122.439681150632296
830	2019-04-04 18:52:39	2019-04-04	Mahalie Mosciski	mahalie.mosciski@geemail.com	Berkeley	California	869964153932393242	128eb75d9deedd3543e5ed0a4d8decdb	JCB 16 digit	37.8570330710281056	-122.291988338418406
831	2019-04-04 21:19:18	2019-04-04	Ms. Drucilla Heller	ms.drucilla.heller@geemail.com	New Orleans	Louisiana	4135998369916	10db1b24e9b4d6a0786e99d09784c8f2	Diners Club / Carte Blanche	29.9905364139951764	-89.9283786747865435
832	2019-04-04 23:32:33	2019-04-04	Miss Ilah Ferry DDS	miss.ilah.ferry.dds@warmmail.com	San Francisco	California	3033956913036042	4ae050bb8028d290870d900c127916f9	JCB 16 digit	37.7439371354749511	-122.438458836198876
833	2019-04-05 02:44:03	2019-04-05	Dennie Rodriguez	dennie.rodriguez@geemail.com	San Francisco	California	3158114471714721848	0536923b14684bf2ea9452278b86ad49	JCB 15 digit	37.7548224571512847	-122.437949838905737
834	2019-04-05 03:36:11	2019-04-05	Bud Rippin	bud.rippin@geemail.com	San Francisco	California	3158233964238304428	190d4fe010eac8333680892a782a079f	Diners Club / Carte Blanche	37.7501636921411006	-122.41919155523955
835	2019-04-05 07:23:47	2019-04-05	Buell Moen-Kautzer	buell.moen.kautzer@geemail.com	San Francisco	California	869925480537050754	3846600138c924724d1080f440558750	American Express	37.7790919787163588	-122.436095441505515
836	2019-04-05 08:18:41	2019-04-05	Demetric Ankunding	demetric.ankunding@geemail.com	New York	New York	4083199759958	ee90daefddb7093f21b3b6fe214b887d	JCB 16 digit	40.5638807771019643	-73.9662347356684506
837	2019-04-05 10:19:54	2019-04-05	Justus Wolff	justus.wolff@geemail.com	San Francisco	California	3470402889809052	de9861593885845f31ff6ce318727d6f	JCB 15 digit	37.7746222808597665	-122.451333810578731
838	2019-04-05 11:56:01	2019-04-05	Mr. York Ryan	mr.york.ryan@geemail.com	Atlanta	Georgia	51771519004167884	907e3c0abcf5e424fcfdda2cb9e11597	Maestro	33.7056028058096757	-84.4479928975969614
839	2019-04-05 15:01:32	2019-04-05	Melonie Kling-Will	melonie.kling.will@warmmail.com	San Francisco	California	6011542961200972105	d911abb1014cf45d859068d09a11582f	Discover	37.7854526807901294	-122.444280687337425
840	2019-04-05 15:36:09	2019-04-05	Rafe Glover	rafe.glover@woohoo.com	San Francisco	California	4615840977168299	1fa3cb651b3e072623be121c262096ae	Diners Club / Carte Blanche	37.7711959112023195	-122.435806830163472
841	2019-04-05 18:44:43	2019-04-05	Orma Schumm	orma.schumm@geemail.com	San Francisco	California	3036252439875635	2a6fd1fa02695314a2746f0369f10ea8	Diners Club / Carte Blanche	37.7717510860976518	-122.435682153842521
842	2019-04-06 04:16:56	2019-04-06	Dr. Horton Feest DDS	dr.horton.feest.dds@woohoo.com	San Francisco	California	3475924413448664	edc70a63af4e88c6187b9c1c6a13deb1	Maestro	37.771210886072808	-122.448860806957157
843	2019-04-06 04:51:32	2019-04-06	Elyssa Ebert	elyssa.ebert@geemail.com	Oakland	California	3096747900812872710	4665772dae789724a0cdc184418f0c0c	Voyager	37.8176103957554588	-122.280633650118745
844	2019-04-06 05:00:34	2019-04-06	Tennessee Becker	tennessee.becker@geemail.com	Philadelphia	Pennsylvania	3037292763501216	869c041f42fecee7eff2c888baee69c9	Voyager	40.0366726845927516	-75.217966086826479
845	2019-04-06 11:10:20	2019-04-06	Dr. Kamryn Sanford	dr.kamryn.sanford@geemail.com	Oakland	California	3457241731414100	692e477e990a439ea55774f730399bb9	Maestro	37.7904973381612734	-122.276589171922623
846	2019-04-06 11:20:26	2019-04-06	Sara Dickinson-Kovacek	sara.dickinson.kovacek@geemail.com	San Francisco	California	3112794661374292885	79af5f9e68e671b253b2661321cf6895	VISA 16 digit	37.7841357145811045	-122.461896739359418
847	2019-04-06 11:50:49	2019-04-06	Loreen Stoltenberg	loreen.stoltenberg@geemail.com	Oakland	California	210019029014145682	15aead01d6d06f0dafc5af45e6c69f03	JCB 16 digit	37.8144022569325315	-122.305046980943743
848	2019-04-06 12:31:04	2019-04-06	Shirlene Greenfelder	shirlene.greenfelder@geemail.com	Oakland	California	4117596136228365	9e7726e32714e18b0c22de4930e3df85	JCB 16 digit	37.8108108486239942	-122.277896326028099
849	2019-04-06 18:15:06	2019-04-06	Emerson Brekke	emerson.brekke@geemail.com	Bakersfield	California	3096812228718008902	3617caf6e56601a4309361238befa24f	JCB 16 digit	35.3089972333226356	-118.989293536198502
850	2019-04-07 04:17:01	2019-04-07	Derrek O'Connell	derrek.o'connell@geemail.com	San Francisco	California	210013701222558791	c33e9c5439ab9ee3c680d47d25c81fb3	JCB 15 digit	37.7634080521886659	-122.399547556802091
851	2019-04-07 04:47:19	2019-04-07	Ashlee Buckridge-Fay	ashlee.buckridge.fay@geemail.com	Omaha	Nebraska	3112107730994969487	6479a01b3c776cc526ac16224f8bfcd0	VISA 16 digit	41.3123775206185897	-96.0765886593259921
852	2019-04-07 09:07:18	2019-04-07	Calla Berge MD	calla.berge.md@geemail.com	San Antonio	Texas	6011029292187447461	47849682ee821de86d56e436ead4d590	VISA 16 digit	29.4475314951106917	-98.5426744751933938
853	2019-04-07 18:01:54	2019-04-07	Rowan Schamberger	rowan.schamberger@woohoo.com	San Francisco	California	4587728999039073	dfde5e57f813a1a81130c2e2e9dd6b0a	VISA 13 digit	37.7668406421285141	-122.399513787977327
854	2019-04-07 18:24:09	2019-04-07	Evert Lind	evert.lind@geemail.com	Oakland	California	3025522582097455	fea9701fff24b7a7d084e417ce7604aa	JCB 16 digit	37.816459782345369	-122.299480175702371
855	2019-04-07 20:20:44	2019-04-07	Gavyn Brakus-Feest	gavyn.brakus.feest@geemail.com	Berkeley	California	589302102660996	c0f4c80ad8364e4db9358892faa51a16	JCB 16 digit	37.8446422997209808	-122.272967650713227
856	2019-04-07 20:57:22	2019-04-07	Dr. Damaris Kulas DDS	dr.damaris.kulas.dds@geemail.com	San Francisco	California	3112037770540312399	66a4f3219d2793ddd121eee32bc7e902	Discover	37.7805073591632166	-122.410607138227746
857	2019-04-07 21:22:21	2019-04-07	Kelley Schmeler	kelley.schmeler@geemail.com	Oakland	California	51481455806652503	52a40a7c84bef9f7dc6eaa085ebdc653	VISA 16 digit	37.8025034092627195	-122.261857085441065
858	2019-04-08 11:41:20	2019-04-08	Elfreda Murphy	elfreda.murphy@geemail.com	San Francisco	California	4678185406942	6cd9ea6ca8f41a9772884ed524d6f185	JCB 16 digit	37.7934096062007185	-122.446207957961391
859	2019-04-08 12:01:09	2019-04-08	Jeffery Walter-Rice	jeffery.walter.rice@woohoo.com	San Francisco	California	3430307766749322	ae35c30c92f8298a22bf4a57b6e7ca59	Maestro	37.8313557997639833	-122.397888449600032
860	2019-04-08 12:18:46	2019-04-08	Alondra Bogisich	alondra.bogisich@woohoo.com	New York	New York	3433311098140868	d9cd06ec518044862c6898b699b7907c	VISA 16 digit	40.5737815488353348	-73.9941434733930947
861	2019-04-08 12:22:26	2019-04-08	Dr. Tyshawn O'Kon	dr.tyshawn.o'kon@geemail.com	San Francisco	California	561235939028128	f176b44f82e023cfa7b50ea6d4dcbaa0	Mastercard	37.7812304012434126	-122.436027484625455
862	2019-04-08 13:37:52	2019-04-08	Felicity Gutmann-Raynor	felicity.gutmann.raynor@geemail.com	San Francisco	California	180077043243037148	f1c753de84f821c788ec223221d878c8	Diners Club / Carte Blanche	37.7660848523684365	-122.407783501618113
863	2019-04-08 14:03:18	2019-04-08	Andre Bayer	andre.bayer@woohoo.com	Alexandria	Virginia	4993120298811	ca2511fed7dda3174008c36ec9cc7ff7	Voyager	38.7485613998606766	-77.0838711874544629
864	2019-04-08 15:17:59	2019-04-08	Daija Considine	daija.considine@geemail.com	San Francisco	California	53407895352696605	e65001e526a66ef8172a35bc85a6278a	Mastercard	37.7964889552856036	-122.427306388647239
865	2019-04-09 00:25:24	2019-04-09	Leonora Erdman-Hilll	leonora.erdman.hilll@woohoo.com	San Francisco	California	3096055591282174996	310da15d6505353e3398828ad7ed27ad	American Express	37.7485068706078764	-122.434204788210366
866	2019-04-09 09:51:06	2019-04-09	Ms. Caprice Klocko PhD	ms.caprice.klocko.phd@geemail.com	San Francisco	California	3717480340719397	732358455bb1f43e5e72a7bcd8514224	American Express	37.7647152253531857	-122.426274019867122
867	2019-04-09 10:54:03	2019-04-09	Hetty Gutmann-Mante	hetty.gutmann.mante@geemail.com	San Francisco	California	630418433164359	ac95b0f7544151c3e87ffb7529338238	Voyager	37.7664592673422774	-122.412307983824022
868	2019-04-09 13:40:09	2019-04-09	Rigoberto Kuhlman	rigoberto.kuhlman@geemail.com	San Francisco	California	51365782677162234	2539cabe0f8644f29eb2bf65e252ae22	Voyager	37.7592828744079938	-122.428711589348097
869	2019-04-09 17:00:24	2019-04-09	Malissie Carroll	malissie.carroll@warmmail.com	Oakland	California	869910075916890007	f94bff46d06630994284736645dfbd8a	Diners Club / Carte Blanche	37.8189685088699079	-122.251969891342114
870	2019-04-09 21:09:34	2019-04-09	Dr. Micky Bashirian Jr.	dr.micky.bashirian.jr.@geemail.com	Colorado Springs	Colorado	4259408461380035	10282510d4f6a3cd96f9b70c2b4c67a1	JCB 16 digit	38.9659500099767016	-104.778987686584514
871	2019-04-09 21:59:55	2019-04-09	Ms. Christeen Kautzer DDS	ms.christeen.kautzer.dds@geemail.com	San Diego	California	3059195879827144	76419ed04aa8ae3665cd89570e6cb5c8	VISA 13 digit	32.8469701495554318	-117.184013860570275
872	2019-04-10 01:28:07	2019-04-10	Mathew Keebler	mathew.keebler@warmmail.com	Oakland	California	210013572786469414	f23ba2a45499a5d9ff01c849878cc241	JCB 16 digit	37.8012891285026313	-122.259065540834371
873	2019-04-10 05:02:46	2019-04-10	Loretta Funk MD	loretta.funk.md@woohoo.com	Philadelphia	Pennsylvania	3026494694434530	18853a777e4075ec696b4c976bce308e	VISA 13 digit	39.9302365292754047	-75.0924642969287959
874	2019-04-10 05:12:39	2019-04-10	Kelcie Nitzsche	kelcie.nitzsche@geemail.com	San Francisco	California	4487183164442333	d739c01a6e0fa9b7f8b22e8234e4932d	Diners Club / Carte Blanche	37.7725354263260726	-122.429921635686568
875	2019-04-10 05:16:40	2019-04-10	Melinda Russel	melinda.russel@geemail.com	Berkeley	California	55767259306368189	23473e8ed60663fa489071257ba8920f	VISA 16 digit	37.8578701054878124	-122.266581220963999
876	2019-04-10 09:06:12	2019-04-10	Margot Senger-Will	margot.senger.will@geemail.com	El Paso	Texas	3769207943939032	3545028c266b6e0404a13216f75a95dd	American Express	31.8347256706856214	-106.345740344978879
877	2019-04-10 16:35:36	2019-04-10	Mrs. Matilde McKenzie MD	mrs.matilde.mckenzie.md@geemail.com	Berkeley	California	4810830237971981	51a4d0490c6b6e761cb023507b2f3a14	JCB 16 digit	37.8682473822043235	-122.286033592135084
878	2019-04-10 23:36:17	2019-04-10	Joaquin Ankunding	joaquin.ankunding@geemail.com	San Francisco	California	53975742749666549	c90ef629de2f717c658f60dbbf20d78e	JCB 16 digit	37.7617404789093314	-122.449077585456692
879	2019-04-10 23:58:14	2019-04-10	Mekhi Batz	mekhi.batz@geemail.com	Oakland	California	4336947761668190	4ff22e9e22281ca984701bd52f4ec009	Diners Club / Carte Blanche	37.8040388214346166	-122.291454301294706
880	2019-04-11 00:27:24	2019-04-11	Jocelyne Batz-Mayert	jocelyne.batz.mayert@warmmail.com	Laredo	Texas	6011029342439244271	9e7493346c4593cc77baec80ef2a395e	VISA 13 digit	27.5850759893372661	-99.4647046484526243
881	2019-04-11 04:01:40	2019-04-11	Messiah Paucek	messiah.paucek@woohoo.com	San Francisco	California	3112012633451845600	37016bb4e27395cfce0d1131c2e1f627	Discover	37.7505720621714573	-122.43307809988633
882	2019-04-11 07:50:32	2019-04-11	Cletus Toy	cletus.toy@geemail.com	San Francisco	California	869996706835663672	67332c7286ca38add00c9627de278f94	Mastercard	37.7822735065859163	-122.467966161776559
883	2019-04-11 10:55:20	2019-04-11	Rafaela Prosacco	rafaela.prosacco@geemail.com	San Francisco	California	53499202499010718	5cc6fad7ba9fd92325209f486fcb7f13	Voyager	37.7846993736742647	-122.396379125813681
884	2019-04-11 11:20:41	2019-04-11	Bryn Schroeder	bryn.schroeder@geemail.com	Oakland	California	3490296249840815	3654b2e80de747ff68ec2605c62f10f1	Mastercard	37.8241498882506235	-122.232740892217976
885	2019-04-11 13:40:38	2019-04-11	Consuela Hoeger	consuela.hoeger@geemail.com	San Francisco	California	503860122297546	975215c7129cb5859dd9b947bb328f8f	VISA 13 digit	37.7605799952092411	-122.408953921824789
886	2019-04-11 15:28:23	2019-04-11	Latrell Mayer	latrell.mayer@geemail.com	San Francisco	California	3466859407391747	91d7054b7da00519898ce874406c161e	JCB 16 digit	37.7690781312931421	-122.425333662998796
887	2019-04-11 16:37:48	2019-04-11	Harvey Yundt-Goodwin	harvey.yundt.goodwin@geemail.com	Austin	Texas	3337579479221401257	6d6e925b327480ff6a9bf1d8971ae45e	JCB 16 digit	30.325554787007718	-97.7179993183590483
888	2019-04-12 01:04:28	2019-04-12	Manson Boyle	manson.boyle@woohoo.com	San Francisco	California	3096798609208092605	d60e1425d338fae23111786232fd8824	Discover	37.8240966433706447	-122.445077245310742
889	2019-04-12 03:01:18	2019-04-12	Dottie Mueller	dottie.mueller@geemail.com	Orlando	Florida	4851070807469559	be81b7c248762e895b16bff574f55665	JCB 16 digit	28.4694049770742659	-81.2367124373059681
890	2019-04-12 03:27:32	2019-04-12	Shayla Murazik	shayla.murazik@warmmail.com	Sacramento	California	676265795648958	b6504be2c3eba5e5f7540f1ecad51aef	Maestro	38.6561451553631557	-121.370417347016186
891	2019-04-12 09:02:09	2019-04-12	Vicki Tromp	vicki.tromp@woohoo.com	San Francisco	California	060466228073848	d47f4004d486af7f3c9638fa2b8e39de	Voyager	37.7423836351728283	-122.447745568040759
892	2019-04-12 14:08:41	2019-04-12	Charisse Denesik	charisse.denesik@geemail.com	Oakland	California	869914864851225774	8f79804cb165054790619ed1aeb08a37	Diners Club / Carte Blanche	37.8388096121565383	-122.260636937653018
893	2019-04-12 19:01:59	2019-04-12	Porsche Bergstrom	porsche.bergstrom@warmmail.com	San Francisco	California	4512865471209	21aa672403a1019a3525e8a838dc6d73	JCB 16 digit	37.7513679655536762	-122.40365811573156
894	2019-04-12 19:09:03	2019-04-12	Emanuel Beatty Jr.	emanuel.beatty.jr.@geemail.com	San Francisco	California	589345974112844	06b79a77cfa96426d89d9786e7115619	Discover	37.7862343736346489	-122.434112673665467
895	2019-04-12 20:04:21	2019-04-12	Dr. Mossie Kris DDS	dr.mossie.kris.dds@warmmail.com	San Francisco	California	4963913587068	42ab3c79ec2abed2497b394342f4ee4f	VISA 13 digit	37.7644243674926656	-122.434038282597172
896	2019-04-12 22:14:31	2019-04-12	Mr. Omer Konopelski MD	mr.omer.konopelski.md@woohoo.com	Oakland	California	3025310127049474	1442218ff844605748415db98d68d7d8	VISA 13 digit	37.7865201296937911	-122.271201166103765
897	2019-04-13 00:13:04	2019-04-13	Rashad Gislason	rashad.gislason@geemail.com	San Francisco	California	6011283195585026509	b7d49e8bdcce1a697aeebc54b570de1f	VISA 16 digit	37.8035069096825822	-122.435635949876612
898	2019-04-13 05:33:19	2019-04-13	Mr. Shayne Orn	mr.shayne.orn@geemail.com	San Francisco	California	55918297753795346	2e608a08917f2debbbb98834780365cf	Mastercard	37.7669642674590875	-122.432032797090628
899	2019-04-13 05:38:47	2019-04-13	Mrs. Elena West PhD	mrs.elena.west.phd@warmmail.com	San Francisco	California	3528468647236415181	caed85734dc069bb6089ba64cd0c1f4b	VISA 13 digit	37.7638883550994038	-122.410408499926334
900	2019-04-13 10:23:16	2019-04-13	Davante Shanahan	davante.shanahan@geemail.com	San Francisco	California	4983648537824	63f60cc7f616346a188889f41b0fbba1	VISA 13 digit	37.7576089520577725	-122.437524761855883
901	2019-04-13 15:48:21	2019-04-13	Liddie Medhurst	liddie.medhurst@geemail.com	San Francisco	California	180095486353585794	20a5b912ed802d23784be4200b95642f	Discover	37.7781698266277388	-122.442843097374762
902	2019-04-13 19:21:26	2019-04-13	Michial Bogan	michial.bogan@geemail.com	Washington	District of Columbia	3112121821278875433	626c82aa1784c6a3ca5216c49a5fa0f6	VISA 13 digit	38.9614398937471194	-77.0192108630880767
903	2019-04-13 19:25:08	2019-04-13	Mr. Donny Von	mr.donny.von@geemail.com	San Francisco	California	3021202593667869	f9cce46152410610066a05d7bfb59bad	VISA 13 digit	37.7373862643215006	-122.40757553899499
904	2019-04-13 22:43:45	2019-04-13	Dr. Mattie Dicki DDS	dr.mattie.dicki.dds@geemail.com	Thornton	Colorado	3528158208289297409	4623b4ce8771c0ef49fb46f7e55a1065	American Express	39.997714662864432	-104.932640655960142
905	2019-04-14 00:19:43	2019-04-14	Duff Mohr	duff.mohr@geemail.com	San Francisco	California	3058968278145115	30615dcf7e3ebd886ce8aa59b4ff1562	Voyager	37.7372253033495753	-122.419714451313141
906	2019-04-14 07:52:24	2019-04-14	Ladarius Mueller-Spinka	ladarius.mueller.spinka@geemail.com	San Francisco	California	3337237767515104320	ee52e3f28d41b1a9df604767d06a0a0e	Mastercard	37.7973596142899879	-122.446899204747709
907	2019-04-14 08:29:39	2019-04-14	Edson Hansen	edson.hansen@geemail.com	Laredo	Texas	869988665734834695	0eec90397e4691fb00c0fad0688bbcc0	Voyager	27.4792579078298083	-99.5071465408902611
908	2019-04-14 08:42:04	2019-04-14	Dr. Anna Medhurst PhD	dr.anna.medhurst.phd@geemail.com	Berkeley	California	6011449984580294308	ca12b85f8726902efa376638dce917de	VISA 13 digit	37.8661349024644736	-122.290985919249096
909	2019-04-14 09:19:03	2019-04-14	Arra Schroeder	arra.schroeder@geemail.com	Berkeley	California	53680691285455179	a311e4ddee92404e2426e2f079d62af4	VISA 16 digit	37.8717803557267274	-122.27342170614989
910	2019-04-14 14:24:17	2019-04-14	Sonya Frami	sonya.frami@geemail.com	Berkeley	California	3112832802530831083	d0b814da5d7c80a5cde2cd76c7545307	JCB 16 digit	37.8578861778368037	-122.273450496206451
911	2019-04-14 17:03:13	2019-04-14	Stone Koch	stone.koch@geemail.com	Berkeley	California	676376722539707	3f17f190f7173f27b5b61e0e88414adb	Voyager	37.9081960188553424	-122.256793097730295
912	2019-04-14 20:24:20	2019-04-14	Dr. Rosco Berge Jr.	dr.rosco.berge.jr.@woohoo.com	San Francisco	California	4526907361712566	b0cba1afdb4cc2413885b023a774ce68	Maestro	37.7810746095115206	-122.455747890097783
913	2019-04-14 20:51:07	2019-04-14	Kadeem Zboncak-King	kadeem.zboncak.king@warmmail.com	Stockton	California	869918975165783195	e70fae893d84d52de2066cf08253a32b	VISA 16 digit	37.9381803670629907	-121.314755418905236
914	2019-04-15 00:46:32	2019-04-15	Mr. Garold Wyman IV	mr.garold.wyman.iv@geemail.com	Oakland	California	3040159940828530	eadfe3f5c5caa213ab7781397bcd685d	Maestro	37.8542278004474966	-122.235551416775436
915	2019-04-15 04:28:28	2019-04-15	Vina Greenfelder	vina.greenfelder@geemail.com	Oakland	California	4234886866057	0b798c675137eabc0355aa20f459d986	VISA 16 digit	37.8080665059641063	-122.294583953183533
916	2019-04-15 06:59:48	2019-04-15	Marcus Roberts	marcus.roberts@geemail.com	Berkeley	California	210023784264659261	a764ff838152283216ec0ba91a98a863	VISA 16 digit	37.8936057224240841	-122.240646249332059
917	2019-04-15 07:57:19	2019-04-15	Taft Robel-Lockman	taft.robel.lockman@woohoo.com	Madison	Wisconsin	4679521493173004	5dff021c0b8340fe5cce5373cc104194	JCB 16 digit	43.1706308455180405	-89.507813524257017
918	2019-04-15 08:25:32	2019-04-15	Mammie Rath	mammie.rath@geemail.com	San Francisco	California	4555716353388929	9631daad13ebb14d8407da441c1f038c	JCB 16 digit	37.7862422676387126	-122.42814412909496
919	2019-04-15 11:11:09	2019-04-15	Talan Mertz-Hilll	talan.mertz.hilll@geemail.com	San Francisco	California	180060907890909016	e6dc7f25ff862a998115cb3308b44515	Maestro	37.802641635440196	-122.45987947168949
920	2019-04-15 17:20:28	2019-04-15	Carlton Padberg	carlton.padberg@warmmail.com	San Francisco	California	3010319191675184	c20286821245df15433b258e776e11c3	JCB 16 digit	37.7735037701267018	-122.480285060544801
921	2019-04-15 21:34:16	2019-04-15	Roosevelt Graham	roosevelt.graham@warmmail.com	Elk Grove	California	3756330234007411	4d249d5ba13e51b9fe4d0792d60286c3	JCB 16 digit	38.3667762479562313	-121.408085981281474
922	2019-04-16 02:25:33	2019-04-16	Toby Lynch	toby.lynch@geemail.com	San Francisco	California	3096784204313358905	e0688c38bc685dd5a638bf6da128e59d	VISA 13 digit	37.791587030472563	-122.401775763881886
923	2019-04-16 08:49:17	2019-04-16	Remington Bergstrom	remington.bergstrom@geemail.com	Pittsburgh	Pennsylvania	53047826843483069	9d335df780bcf686ee56081953534485	Voyager	40.5379968670617785	-79.8976395068861649
924	2019-04-16 12:02:46	2019-04-16	Montie Mosciski MD	montie.mosciski.md@geemail.com	Berkeley	California	180029699772270142	5ca2424734cb70ba39a8f430ced7fb85	JCB 16 digit	37.8443145825762102	-122.262901822891607
925	2019-04-16 12:17:57	2019-04-16	Dr. Andres Schneider II	dr.andres.schneider.ii@geemail.com	San Francisco	California	210010190329873753	15ecd4d6acd3fb1f6075d9aa151e2642	American Express	37.7735668789327264	-122.410208456765332
926	2019-04-16 18:45:13	2019-04-16	Anabel Kessler	anabel.kessler@woohoo.com	San Francisco	California	4060322195215822	09a8da20a8f65ec00397488946991b3c	American Express	37.7756697024604122	-122.474150746345913
927	2019-04-16 22:06:13	2019-04-16	Luis Dicki	luis.dicki@geemail.com	Gilbert	Arizona	4394324249033	fa57dc1cedcf31e858f095b5d5abf75f	JCB 16 digit	33.3341352401647697	-111.765742622888084
928	2019-04-16 22:40:13	2019-04-16	Dr. Tarah Funk DDS	dr.tarah.funk.dds@geemail.com	Berkeley	California	4348870316086989	fc6e12f156b41ae5e355f8b50bd98c2c	Diners Club / Carte Blanche	37.8817743800725495	-122.265674879740388
929	2019-04-16 23:15:01	2019-04-16	Scot Lebsack	scot.lebsack@geemail.com	San Francisco	California	4620145439990139	2ea283a6a23a3e00937e98ef791acbed	JCB 15 digit	37.7709840647489088	-122.426132636654515
930	2019-04-17 00:00:11	2019-04-17	Scotty Jaskolski Sr.	scotty.jaskolski.sr.@warmmail.com	San Francisco	California	3088226077886523022	3a994f7e3f07b18f9e066251820ca545	Voyager	37.7955484206890304	-122.429723398522682
931	2019-04-17 00:07:42	2019-04-17	Doretta Leannon	doretta.leannon@geemail.com	San Francisco	California	180012581026706247	538087ef977d54629010ad1e49f4fd8e	Maestro	37.7756040413541143	-122.442059150831412
932	2019-04-17 01:18:09	2019-04-17	Zain Hayes	zain.hayes@geemail.com	San Francisco	California	3337381399092291579	36979f63efb38a1cb882d59e581f6670	VISA 16 digit	37.7592021627190206	-122.442038642491411
933	2019-04-17 13:07:10	2019-04-17	Marcelle Berge	marcelle.berge@geemail.com	San Francisco	California	3158171076349034507	6512c8d076389f607a86bd59a86ec972	Diners Club / Carte Blanche	37.7634858837275758	-122.45595550518938
934	2019-04-17 18:30:14	2019-04-17	Neha Langosh	neha.langosh@geemail.com	Oakland	California	4960945370933990	6fe7bc331596bc3bcec7968fde111bbd	Mastercard	37.8204513484593008	-122.246509954544507
935	2019-04-17 19:19:23	2019-04-17	Nicolas Kiehn	nicolas.kiehn@geemail.com	Austin	Texas	4211483305213608	928ba4b43229749704e12a7d339d5873	JCB 16 digit	30.3898602946322391	-97.7547585430793475
936	2019-04-17 22:49:30	2019-04-17	Mrs. Jill Considine	mrs.jill.considine@geemail.com	Louisville	Kentucky	3337938635218646701	90cd56885a004a74c7943070203f7ad2	Voyager	38.2412722129277896	-85.6581377015054244
937	2019-04-17 23:23:45	2019-04-17	Santino Mohr	santino.mohr@geemail.com	San Francisco	California	4600010272966683	402a1e9c92f5520d6685c79069666894	Diners Club / Carte Blanche	37.7767670939874236	-122.443064161419827
938	2019-04-18 00:33:28	2019-04-18	Wyatt Farrell	wyatt.farrell@geemail.com	San Francisco	California	4385983390852	fe186fe709132cec874b717b220bfdbb	JCB 16 digit	37.7879735309579914	-122.431085835225232
939	2019-04-18 03:27:15	2019-04-18	Zaid Quitzon DDS	zaid.quitzon.dds@geemail.com	Houston	Texas	3112426199247075290	ef95f5dedcf9b42cc35586c49c0c5539	VISA 16 digit	29.8085986133743077	-95.3396362192943769
940	2019-04-18 05:09:48	2019-04-18	Dr. Semaj Reilly	dr.semaj.reilly@geemail.com	San Francisco	California	6011377083145488897	d65b6202340a8197fc1a3dc3bfa62767	VISA 16 digit	37.7849350069043339	-122.456815199045778
941	2019-04-18 05:57:12	2019-04-18	Doshia Nicolas-Watsica	doshia.nicolas.watsica@warmmail.com	San Francisco	California	4913778457500160	80a339de7ae91531903681a5306e1bfd	VISA 16 digit	37.7464932209019963	-122.402659319334205
942	2019-04-18 06:36:28	2019-04-18	Diane Hegmann	diane.hegmann@geemail.com	Berkeley	California	54585347502244872	ed54ee013e41425db9dd1d0c6105b44b	JCB 16 digit	37.8736236553525174	-122.28615726085512
943	2019-04-18 09:06:36	2019-04-18	Lorayne Ryan	lorayne.ryan@geemail.com	Houston	Texas	869959168630164098	caf45249a9b16274334ca45f27d473ec	Mastercard	29.7023999649643891	-95.3844848804190804
944	2019-04-18 09:18:52	2019-04-18	Ashton Howell-Harris	ashton.howell.harris@geemail.com	San Francisco	California	3096697858719504234	03b538667947f644dd9a4110f79358b3	Diners Club / Carte Blanche	37.779410227736598	-122.405661314332633
945	2019-04-18 10:26:47	2019-04-18	Stanley Nikolaus	stanley.nikolaus@geemail.com	San Francisco	California	3112034084401565910	782ad89151d09658dd651c956bf358cc	Voyager	37.7943769529797748	-122.449774409391793
946	2019-04-19 05:34:19	2019-04-19	Murl Fahey	murl.fahey@geemail.com	Berkeley	California	869978428364918599	2954bb4ac0a42b9f6d791124dd304916	VISA 13 digit	37.8736462653328445	-122.280944353749092
947	2019-04-19 06:36:50	2019-04-19	Jeana Shanahan	jeana.shanahan@warmmail.com	Oakland	California	6011155155055977602	cd881e66f854b40f57364dca473ab176	Voyager	37.8041238484335977	-122.267901022754742
948	2019-04-19 08:17:59	2019-04-19	Hollis Lowe-Parker	hollis.lowe.parker@geemail.com	San Francisco	California	869946929143133417	39a0e21897cf45f79cc9cbeac79a9d02	American Express	37.789105498591276	-122.447142373333421
949	2019-04-19 08:34:07	2019-04-19	Frederica Mosciski	frederica.mosciski@geemail.com	Mesa	Arizona	4840032968171287	378f83e40d85ef6d0a6728333085b018	Discover	33.4858709997177115	-111.721364709304268
950	2019-04-19 14:10:43	2019-04-19	Ervin Koepp	ervin.koepp@woohoo.com	Berkeley	California	3158655045143223793	6f4ae78ce8bd11dfb754f327245855ad	JCB 16 digit	37.8936006108829631	-122.246608168085814
951	2019-04-19 19:06:09	2019-04-19	Sheilah Okuneva	sheilah.okuneva@geemail.com	Chicago	Illinois	3528152650882431776	8fa5e8f67710fd1f9c149f34df451376	VISA 13 digit	41.8612985387280574	-87.5856372883573187
952	2019-04-19 19:35:37	2019-04-19	Abagail Hammes	abagail.hammes@geemail.com	San Francisco	California	6011840744569439554	96072d8c17acba28db7b4e6f096817a6	Discover	37.8033192823400626	-122.430007609714451
953	2019-04-19 21:05:08	2019-04-19	Paulina Tromp	paulina.tromp@geemail.com	San Francisco	California	869982543768852816	c28b72cef5c69c877688aee423e253e1	American Express	37.7470990614054145	-122.426777934728847
954	2019-04-19 21:06:18	2019-04-19	Annmarie Heller	annmarie.heller@geemail.com	San Francisco	California	6011556847097711032	850c7238c97d5acb1546cd43958e0b2c	JCB 15 digit	37.7638452808542624	-122.487122360705087
955	2019-04-20 04:34:02	2019-04-20	Miss Sheree Rempel PhD	miss.sheree.rempel.phd@geemail.com	Berkeley	California	4120822418837938	9759a4b2103b67ebf7e57224dfc92cac	VISA 16 digit	37.8807000974379093	-122.233474308450027
956	2019-04-20 05:55:56	2019-04-20	Elayne Parker	elayne.parker@geemail.com	San Francisco	California	3088053163432776120	3dfd052db9f750014964582781ea1ea4	Maestro	37.7335394408178431	-122.420259836223707
957	2019-04-20 12:16:19	2019-04-20	Garnet Bayer	garnet.bayer@warmmail.com	Oakland	California	4458526109088378	9ee302f47277128044a44a0a29e24132	Discover	37.8035274616229273	-122.243287257995576
958	2019-04-20 13:37:08	2019-04-20	Miss Lillie Stokes DVM	miss.lillie.stokes.dvm@geemail.com	San Francisco	California	4809118286917	99213eb5d3ba888948cc7dae19cc1137	Mastercard	37.7353133856437992	-122.427642567261358
959	2019-04-20 18:21:36	2019-04-20	Etta Hane	etta.hane@warmmail.com	San Francisco	California	3429990949493398	c998c37398545425e546bfebcee5d270	Discover	37.7755420519325753	-122.440304930108837
960	2019-04-20 20:14:21	2019-04-20	Aurelio Kertzmann	aurelio.kertzmann@geemail.com	Oakland	California	869977735485848443	ba86ed5081eef9a1ed98cd0745f89ebd	American Express	37.7879469545165492	-122.264453120675952
961	2019-04-20 21:38:52	2019-04-20	Ms. Hallie Senger PhD	ms.hallie.senger.phd@geemail.com	San Francisco	California	53064873194800796	316e983bbc1ba765764a296e8ce70941	JCB 16 digit	37.7776920458778349	-122.439689553446115
962	2019-04-20 21:47:03	2019-04-20	Earlene Bins	earlene.bins@warmmail.com	Surprise	Arizona	3026416492466752	9939d6e30dcc42fbcf4aeb7b5b36169f	JCB 15 digit	33.6594739253394337	-112.35879870059415
963	2019-04-20 23:14:21	2019-04-20	Lesli Walker	lesli.walker@woohoo.com	Berkeley	California	4052653459054766	81c56e5ce4078be6730f1b9e8172c244	JCB 16 digit	37.8772120761795676	-122.252142705802186
964	2019-04-20 23:44:40	2019-04-20	Carissa Stiedemann	carissa.stiedemann@geemail.com	Boston	Massachusetts	6011682332004101640	2a37492880af5c04e73e34684e75d0f5	VISA 16 digit	42.4226772372778527	-71.1021773727096615
965	2019-04-21 00:58:58	2019-04-21	Linna Beahan	linna.beahan@geemail.com	San Francisco	California	3158963686243757029	d31e0a48221e98d447935b7843d1159d	Voyager	37.8038704733144684	-122.453679083395471
966	2019-04-21 04:54:53	2019-04-21	Corrine Swaniawski-Barrows	corrine.swaniawski.barrows@geemail.com	San Francisco	California	52872226423766332	a6efa080a07d8fcbd5bda9b571433ba2	VISA 13 digit	37.7666105919974484	-122.450187473072987
967	2019-04-21 06:53:33	2019-04-21	Beaulah Borer-Schumm	beaulah.borer.schumm@geemail.com	Oakland	California	51920300005376448	6924587418869d31e2d3041aef2de109	VISA 16 digit	37.8101301183349108	-122.264117414111581
968	2019-04-21 09:24:07	2019-04-21	Unnamed Nolan-Ledner	unnamed.nolan.ledner@geemail.com	San Francisco	California	4100281816825231	0eafbd281ae20be8106f6e0310096898	Maestro	37.7924387184353492	-122.447487662719197
969	2019-04-21 10:20:18	2019-04-21	Monica Friesen PhD	monica.friesen.phd@woohoo.com	Portland	Oregon	589313591682912	15971a267a46beb9742d38b5c0ea9393	VISA 16 digit	45.5806055155470986	-122.638735517300674
970	2019-04-21 11:29:04	2019-04-21	Dr. Nada Larkin DVM	dr.nada.larkin.dvm@geemail.com	San Francisco	California	54314799101026696	81ba428a72cc45b078790fe07945ffa0	VISA 16 digit	37.7672385671410353	-122.426804532965306
971	2019-04-21 21:34:32	2019-04-21	Eller Hermiston	eller.hermiston@geemail.com	San Francisco	California	6011443079270682940	d3eed68474d4b4ae2f10a16d5414a06d	VISA 16 digit	37.7967544063937027	-122.465133336487213
972	2019-04-21 22:44:28	2019-04-21	Chip Wolff	chip.wolff@warmmail.com	St. Petersburg	Florida	3096714928816274954	a02c35189ca60d51c70eec00a3481255	JCB 16 digit	27.7818632008861748	-82.7121837349966142
973	2019-04-21 23:48:11	2019-04-21	Kelly Ullrich-Purdy	kelly.ullrich.purdy@geemail.com	San Francisco	California	180008239976357992	d787aba7494769b39f89175d218d53c3	VISA 16 digit	37.7970382732986394	-122.469095028131065
974	2019-04-22 01:48:25	2019-04-22	Ole Emmerich-Hamill	ole.emmerich.hamill@geemail.com	San Francisco	California	869944256063452771	7463bfbbbbf51f4fcbd54899c2730141	American Express	37.7813565088236913	-122.458356181984499
975	2019-04-22 03:37:14	2019-04-22	Maximillian Jast-Kihn	maximillian.jast.kihn@warmmail.com	Houston	Texas	3088233146908472640	9a0e8fed058eac877587783e716342ef	Maestro	29.7355658985286944	-95.403037827510019
976	2019-04-22 09:38:08	2019-04-22	Ms. Lulie Gerlach	ms.lulie.gerlach@geemail.com	San Francisco	California	180048789281423410	d35256d3d73d9fac6f94dcb616a70fdf	JCB 16 digit	37.7855173549386691	-122.486110598699781
977	2019-04-22 13:20:18	2019-04-22	Golden Hand	golden.hand@woohoo.com	Philadelphia	Pennsylvania	210049517622852198	4ea2edddc62bef88a16763a443fd5768	VISA 16 digit	40.0058421322569231	-75.0528300179067998
978	2019-04-22 14:51:57	2019-04-22	Jeb Shields	jeb.shields@geemail.com	San Francisco	California	180039710857848740	3fa43d910236bfaafe6d789d311785a9	JCB 15 digit	37.7755786757583252	-122.420789985099773
979	2019-04-22 15:46:55	2019-04-22	Thedore Pfeffer Jr.	thedore.pfeffer.jr.@geemail.com	San Francisco	California	4111083246632329	98f4ce6e60b8f83378ffa0d5434a812e	Maestro	37.7621536771992439	-122.395227191116049
980	2019-04-22 15:47:17	2019-04-22	Griffin Schaden	griffin.schaden@geemail.com	San Francisco	California	4276451121392	da7df31edd537a79da5b36d814289650	Maestro	37.7978093542197087	-122.455693737836455
981	2019-04-22 18:50:22	2019-04-22	Dr. Imo Armstrong	dr.imo.armstrong@geemail.com	San Francisco	California	4412428626623	52e9da134fdb49ff884ff896bd188e6e	JCB 15 digit	37.7537230608015832	-122.447832919152077
982	2019-04-23 00:46:08	2019-04-23	Evelena Kshlerin	evelena.kshlerin@woohoo.com	Tulsa	Oklahoma	4153307961042	110c0931f075a26044112e7006acb915	American Express	36.1481284752391261	-95.9744074444241733
983	2019-04-23 01:16:38	2019-04-23	Mrs. Blanchie Aufderhar DDS	mrs.blanchie.aufderhar.dds@geemail.com	Oakland	California	4651593149636041	8800ed96c84ccacb14398de09bba72e9	Discover	37.8424384503944111	-122.277352600921375
984	2019-04-23 01:54:06	2019-04-23	Sister Bernier	sister.bernier@geemail.com	Berkeley	California	3446019846362065	d73c8d4a67c9f39378bd81bf17d63ef1	JCB 15 digit	37.8818671296154577	-122.230991305280455
985	2019-04-23 09:01:43	2019-04-23	Vida Mitchell-Armstrong	vida.mitchell.armstrong@geemail.com	Oakland	California	3088385872600119462	b32c721761065eabcf1d66ca4671a8bc	JCB 15 digit	37.7930336148003221	-122.269839510019168
986	2019-04-23 10:56:45	2019-04-23	Montgomery Lesch	montgomery.lesch@geemail.com	Oakland	California	4245449599886	31f01e6b4fb916f8273d16f245f079f2	JCB 15 digit	37.805524618378584	-122.279203698241915
987	2019-04-23 11:23:39	2019-04-23	Bettye Swaniawski	bettye.swaniawski@geemail.com	Oakland	California	54908339917427002	d49dc81a13eecf5cc8a8f275ba421f62	JCB 15 digit	37.7790250328904378	-122.253000616762989
988	2019-04-23 18:53:57	2019-04-23	Aida Langosh-Hammes	aida.langosh.hammes@geemail.com	Saint Paul	Minnesota	180046484928759358	a469f3008221e3c120439de0245586ec	Voyager	44.9459824006013591	-93.1289531050514512
989	2019-04-23 19:00:33	2019-04-23	Dr. Oswald Hilll	dr.oswald.hilll@geemail.com	San Francisco	California	869993871700445044	f23fa700150ade34fdd2c1d1a11703cd	VISA 13 digit	37.7588794290930849	-122.442907462127451
990	2019-04-24 04:42:19	2019-04-24	Merilyn Boyer	merilyn.boyer@geemail.com	San Francisco	California	180075175405038613	aeab79833ee58dbf86aaa2280ee9511a	Discover	37.7674853035937517	-122.410645745539242
991	2019-04-24 05:18:12	2019-04-24	Dustin Heidenreich DVM	dustin.heidenreich.dvm@warmmail.com	San Francisco	California	180069887139858656	f85e0557d28ec05d8170baee859cb2c7	Diners Club / Carte Blanche	37.7978738881361949	-122.445411534498589
992	2019-04-24 05:32:48	2019-04-24	Eber Hilpert Sr.	eber.hilpert.sr.@warmmail.com	New York	New York	676381088725312	626fd9875bc11f61683acda3caaf5cbe	Maestro	40.6073471690285928	-73.9117907583609224
993	2019-04-24 11:16:09	2019-04-24	Amiyah Vandervort	amiyah.vandervort@warmmail.com	San Francisco	California	4167255174835610	c8662cb76da27d9fff372e8f55e26673	Diners Club / Carte Blanche	37.8063229548231519	-122.420742604986415
994	2019-04-24 16:01:09	2019-04-24	Daxton Von	daxton.von@warmmail.com	San Francisco	California	3742322450604804	376d49b615c486da46285186c0778105	Discover	37.7800707370911937	-122.424908040663695
995	2019-04-24 16:01:19	2019-04-24	Erin Schmidt	erin.schmidt@geemail.com	San Angelo	Texas	589383662271333	7a1409f135b10e605af701e74e8056d0	American Express	31.3509687514662723	-100.515787434356298
996	2019-04-24 20:52:43	2019-04-24	Miss Mechelle Harris PhD	miss.mechelle.harris.phd@geemail.com	Oakland	California	53533158136153337	e31f88f9cadc3dd281f4ad8059a64cee	Voyager	37.8483316773500533	-122.311768417395967
997	2019-04-24 21:04:14	2019-04-24	Jaylee Hirthe	jaylee.hirthe@geemail.com	Oakland	California	3424711889296483	a907d9a18564f53a64749b3f2b1f1601	Mastercard	37.8223083990287989	-122.271311035914877
998	2019-04-25 03:09:24	2019-04-25	Albertus Donnelly	albertus.donnelly@woohoo.com	Oakland	California	3045838492355605	38b477b6db155117f3b46620c9db6ca5	Diners Club / Carte Blanche	37.800444177251471	-122.285556702697036
999	2019-04-25 05:23:19	2019-04-25	Cleda Kassulke	cleda.kassulke@warmmail.com	San Francisco	California	6011648813640128421	eeb9bdc0cad62b021fac50043c8738a5	Voyager	37.7967000860143258	-122.416398535752805
1000	2019-04-25 08:55:00	2019-04-25	Ashtyn Reinger	ashtyn.reinger@geemail.com	Oakland	California	210043875382448250	23302aa7d16c606b784f420524c7a526	JCB 16 digit	37.7893291227097166	-122.312966506605775
1001	2019-04-25 11:47:39	2019-04-25	Andra Conroy	andra.conroy@warmmail.com	San Francisco	California	180096503985979119	4c6a617c7358c5a2a7132a1f1f539595	VISA 16 digit	37.8064934994336355	-122.42843711280166
1002	2019-04-25 13:56:34	2019-04-25	Dr. Jason Schaefer II	dr.jason.schaefer.ii@warmmail.com	Berkeley	California	53383965756502531	a2f3019c5e8f179a461ca106101407d7	Discover	37.8579028637109545	-122.294849194712185
1003	2019-04-25 16:30:00	2019-04-25	Mendy Rosenbaum	mendy.rosenbaum@warmmail.com	Berkeley	California	3487368173620045	0f5e84c9bebe95f2eadae5103edd2093	JCB 15 digit	37.8881313206165231	-122.275027836892349
1004	2019-04-25 17:52:26	2019-04-25	Clarabelle Corwin	clarabelle.corwin@woohoo.com	San Francisco	California	4810226168530773	8b3f0bd6dfb60eae33650085d4df0afb	Voyager	37.7648112460111207	-122.469689097706919
1005	2019-04-25 20:50:36	2019-04-25	Wilkie Quitzon	wilkie.quitzon@geemail.com	San Jose	California	3096755812871082355	db5275e1357c615fd0805ad5145b1abe	Maestro	37.2694650078479199	-121.719917690077423
1006	2019-04-25 21:53:58	2019-04-25	Jahir Lind	jahir.lind@geemail.com	Irvine	California	180030243296458367	f84c14f30a977aec181e4c545bfe5a62	American Express	33.7249620111674133	-117.799228611030799
1007	2019-04-26 05:31:34	2019-04-26	Arnetta Dietrich	arnetta.dietrich@geemail.com	San Francisco	California	869984614414955796	093f174e77a9f579db4b7e1a56f2e465	Maestro	37.7554474069355095	-122.447877809241163
1008	2019-04-26 08:54:37	2019-04-26	Hunter Bernier	hunter.bernier@geemail.com	San Francisco	California	3088772599262992313	f4333e1819cda7f35ede8befeb845263	Mastercard	37.7671688284732383	-122.412988691789167
1009	2019-04-26 09:02:42	2019-04-26	Tal Bednar	tal.bednar@geemail.com	San Francisco	California	869991371736505608	d5a73877c8a747b975398400aeacb1e4	VISA 16 digit	37.7508483523916496	-122.42849619496873
1010	2019-04-26 09:38:44	2019-04-26	Mrs. Grace Mraz PhD	mrs.grace.mraz.phd@warmmail.com	Oakland	California	51022880906166631	93731f6030db7b296615e28fa99ddeac	Diners Club / Carte Blanche	37.8550607392141529	-122.302807653441974
1011	2019-04-26 12:01:50	2019-04-26	Laurine Nicolas	laurine.nicolas@geemail.com	Olathe	Kansas	4420401042064	8b38627e0744f2212543101a8948ec83	JCB 15 digit	38.9299560571678001	-94.7565415791869157
1052	2019-04-30 23:20:20	2019-04-30	Mahalia Stracke	mahalia.stracke@geemail.com	San Francisco	California	4760882995813	95d4007c1a690a479b80b0337837a7d7	JCB 16 digit	37.7931231595871679	-122.418012285585476
1012	2019-04-26 17:15:49	2019-04-26	Dwaine Ritchie III	dwaine.ritchie.iii@geemail.com	Berkeley	California	6011960913569337431	0d3d41257763d29922c6e2e29693115e	JCB 16 digit	37.841066429001124	-122.246238508552565
1013	2019-04-26 18:48:12	2019-04-26	Amaya Kub	amaya.kub@geemail.com	Garden Grove	California	4173293551389077	05d1917467104569a4f75cecef26b2a0	Mastercard	33.7175819064315405	-117.975095058374109
1014	2019-04-26 19:49:00	2019-04-26	Boone Ortiz	boone.ortiz@geemail.com	Berkeley	California	3096052875782936720	e5d71672be089e669e200a5414e1ac6b	American Express	37.8435180158744373	-122.272011185096005
1015	2019-04-26 20:51:02	2019-04-26	Clayton Sporer	clayton.sporer@warmmail.com	San Francisco	California	4050781284300484	14ecaa4263ceb58fa3404a9fa4c5faf1	JCB 16 digit	37.7538909652226948	-122.443809202527802
1016	2019-04-26 23:06:34	2019-04-26	Gearld Schimmel	gearld.schimmel@geemail.com	San Francisco	California	3096614153370434958	e47c7e281f959c1611837edcce81f64d	American Express	37.7377446232766687	-122.406704408847119
1017	2019-04-27 01:15:58	2019-04-27	Mignon Windler	mignon.windler@woohoo.com	San Francisco	California	210095482810433181	8c067391e6a9bbdf31b0269f54eeea4e	Mastercard	37.7552614421326496	-122.437397415086991
1018	2019-04-27 02:38:57	2019-04-27	Katherin Hartmann	katherin.hartmann@geemail.com	Santa Ana	California	4783595718203336	3e0275447147db57727b78b374e0403c	VISA 13 digit	33.7210432321868865	-117.948817629871883
1019	2019-04-27 03:21:23	2019-04-27	Ernest Heller PhD	ernest.heller.phd@geemail.com	San Francisco	California	3088404746639620038	2b199d92da75fe6e8e42ca80dac3410d	JCB 16 digit	37.7326493096146436	-122.45758255722707
1020	2019-04-27 04:39:05	2019-04-27	Dr. Bishop Pfeffer	dr.bishop.pfeffer@geemail.com	San Francisco	California	869940806484586179	94b86af74db0b759a1f0b5b24dc24020	Diners Club / Carte Blanche	37.7531720581629457	-122.448676125808902
1021	2019-04-27 06:41:14	2019-04-27	Samira Stiedemann	samira.stiedemann@woohoo.com	Berkeley	California	6011317313305682424	7fcd9e8af6f47426010c3d2aa3880ce6	American Express	37.8365145680456507	-122.249330639014033
1022	2019-04-27 14:49:57	2019-04-27	Eduardo Hermiston	eduardo.hermiston@geemail.com	San Francisco	California	4868035191269619	a29ad82dff86897ab090954f3c2c85b1	Maestro	37.7711849246987086	-122.430174602052873
1023	2019-04-27 14:57:14	2019-04-27	Saverio Hessel DVM	saverio.hessel.dvm@geemail.com	Chicago	Illinois	3732529289903114	90e5c5b8f50516de0323386ec40b41cf	JCB 16 digit	41.798489566410332	-87.7616950082156819
1024	2019-04-27 22:57:46	2019-04-27	Colt Effertz	colt.effertz@geemail.com	San Francisco	California	6011495472029260018	e5cefb8e11fe3fd18fbf261a39fee322	JCB 16 digit	37.765162835425528	-122.446463765673016
1025	2019-04-27 23:05:50	2019-04-27	Charlton Runte	charlton.runte@woohoo.com	San Francisco	California	4302585324769541	8f063fc1420688fbb2dc9de0d529a14b	Voyager	37.786952305428521	-122.415463259357082
1026	2019-04-28 02:07:52	2019-04-28	Henriette Cole	henriette.cole@geemail.com	Oakland	California	180070225138311384	1ab0310bb13ca145eefa3cc69c1aba7a	JCB 16 digit	37.8359547080502523	-122.26966580822365
1027	2019-04-28 04:40:35	2019-04-28	Lyndsey Hilll	lyndsey.hilll@woohoo.com	San Francisco	California	53058149823248907	1cc891b8e4a768b78d62a599471ffbba	Mastercard	37.7875248414252312	-122.42388345466702
1028	2019-04-28 13:31:01	2019-04-28	Yuridia Bradtke-Kessler	yuridia.bradtke.kessler@geemail.com	Hartford	Connecticut	53982285502738775	2c2292eb76852a371d5ab6e18f8b7735	JCB 16 digit	41.7811336616069084	-72.6000622450731754
1029	2019-04-28 15:10:56	2019-04-28	Luna Hilll-Schmeler	luna.hilll.schmeler@geemail.com	San Francisco	California	4847737532188152	fa2704a2d139bf7af876f1853aac3436	VISA 16 digit	37.7683801558970131	-122.43627049448645
1030	2019-04-28 15:28:42	2019-04-28	Alver Terry	alver.terry@geemail.com	San Francisco	California	4007296500404121	3e2df7528114d912ae2a6d24b045554e	VISA 16 digit	37.7769449611433075	-122.422712261987527
1031	2019-04-28 17:00:36	2019-04-28	Bliss Mraz	bliss.mraz@woohoo.com	Washington	District of Columbia	676164820501688	e3afdd7a4c52c02c816399de526359a3	Voyager	38.8383361516319212	-76.9811080517925319
1032	2019-04-28 19:51:05	2019-04-28	Mr. Brayan Altenwerth	mr.brayan.altenwerth@warmmail.com	San Francisco	California	210083256107563650	ef9596669bf2ad1f8580896e99fda6a7	VISA 16 digit	37.7904123303372401	-122.460209304437839
1033	2019-04-28 20:04:23	2019-04-28	Deon Donnelly	deon.donnelly@warmmail.com	San Francisco	California	676385469162300	00c994fc3c23509b6063540819204816	Mastercard	37.7729440010449409	-122.447244382039074
1034	2019-04-28 22:13:16	2019-04-28	Harmon Cormier	harmon.cormier@geemail.com	Oakland	California	3022129429475333	67cf01f1b08b060b6a53646befb70f37	American Express	37.7862940959357374	-122.272216398524151
1035	2019-04-28 22:30:36	2019-04-28	Isreal Ruecker III	isreal.ruecker.iii@geemail.com	Oakland	California	869916709621441144	1faa18f982144ff3a4ad512144d132ff	Discover	37.7798201614217888	-122.230280733954615
1036	2019-04-29 00:49:36	2019-04-29	Dr. Chadwick Funk Jr.	dr.chadwick.funk.jr.@geemail.com	Berkeley	California	4189259736207445	a2e5c3dfcda30fe062a0e4338af02508	VISA 16 digit	37.8876432549359237	-122.220416411459823
1037	2019-04-29 03:28:14	2019-04-29	Mrs. Katerina Corkery	mrs.katerina.corkery@geemail.com	San Francisco	California	55232478187926660	890fe6249898f120a97cd46489c54f51	JCB 16 digit	37.761208596558113	-122.430122606832143
1038	2019-04-29 07:12:29	2019-04-29	Verl Jakubowski	verl.jakubowski@woohoo.com	Riverside	California	3528402830508796806	fab327167c432f1d855a64cfbacfa001	Diners Club / Carte Blanche	33.8621135930012898	-117.329053555938216
1039	2019-04-29 10:43:42	2019-04-29	Dylan Ryan IV	dylan.ryan.iv@geemail.com	San Francisco	California	3057428591460437	a4c1e72b6365b343485e9a7b99b5418f	Mastercard	37.745953926173776	-122.439729572913748
1040	2019-04-29 13:44:27	2019-04-29	Dr. Dellie Kemmer DVM	dr.dellie.kemmer.dvm@warmmail.com	San Francisco	California	6011997646017765947	4fab4be77fbbcc559f205c8c127a4bd1	VISA 13 digit	37.7476782818003826	-122.446731849253354
1041	2019-04-29 14:01:44	2019-04-29	Loria Ziemann	loria.ziemann@geemail.com	San Francisco	California	6011802656665990783	12942345179abbd7d41b6daa074081e7	JCB 15 digit	37.767352950796905	-122.408944883557439
1042	2019-04-29 15:05:41	2019-04-29	Mr. Barnard Kuhlman IV	mr.barnard.kuhlman.iv@warmmail.com	San Francisco	California	4214702918050	64614f5d5f8972b8baea47db1ca67748	Mastercard	37.7434943195722497	-122.462594091349715
1043	2019-04-29 21:52:16	2019-04-29	Raymond Gutkowski MD	raymond.gutkowski.md@geemail.com	Gresham	Oregon	4832282003033	738a7cafc6b4511a96b2f99cb2d59ff8	VISA 13 digit	45.4470064613457723	-122.506590975009274
1044	2019-04-30 00:39:50	2019-04-30	Destini Jast-Dietrich	destini.jast.dietrich@geemail.com	San Francisco	California	6011486514234520883	7a8ff81bdb66817f977f7475460df6a0	Maestro	37.7631341024261928	-122.409524342762651
1045	2019-04-30 02:51:12	2019-04-30	Antwan Bins Sr.	antwan.bins.sr.@geemail.com	San Francisco	California	869958989709159029	b5e06c2cc63c59313d5066526c8ddd8e	Voyager	37.7991235213152379	-122.417636103612907
1046	2019-04-30 04:20:23	2019-04-30	Corrina Beatty	corrina.beatty@warmmail.com	Berkeley	California	210095087959204739	c09a0498c499993b66d29a72adae5981	VISA 16 digit	37.8651933559372225	-122.289424924626687
1047	2019-04-30 09:46:22	2019-04-30	Dr. Kaley Sawayn DVM	dr.kaley.sawayn.dvm@geemail.com	San Francisco	California	3052684864318331	9fb6723399aa30413649ce02389074c9	JCB 15 digit	37.7818841888455026	-122.424950168694608
1048	2019-04-30 17:40:48	2019-04-30	Tula Kozey	tula.kozey@geemail.com	Springfield	Illinois	869981756126242659	0fd1da8f6d09cb30e5b7794dc2cd3bf5	JCB 16 digit	39.7791765120033176	-89.7368511494718462
1049	2019-04-30 20:35:15	2019-04-30	Neil Terry-Hahn	neil.terry.hahn@geemail.com	New York	New York	4443811892883500	d1961c5427579e76698274db07225917	JCB 16 digit	40.5789970674775518	-73.8436757991451742
1050	2019-04-30 20:40:00	2019-04-30	Miss Rowena Bergnaum PhD	miss.rowena.bergnaum.phd@geemail.com	San Francisco	California	3714573974945198	32fe1d44bc73d20aa6b8300e0fdb1e31	Mastercard	37.7999699115936068	-122.447928491211115
1051	2019-04-30 20:40:46	2019-04-30	Mr. Amarion Eichmann Sr.	mr.amarion.eichmann.sr.@geemail.com	San Francisco	California	4886046784001549	282becd4221d124486adaaad363df101	Mastercard	37.7843613824536106	-122.467166161024167
1053	2019-05-01 03:38:52	2019-05-01	Aileen Schoen-Collins	aileen.schoen.collins@warmmail.com	Berkeley	California	53174499758236206	ce2ecb3baa0aece7c988a4979b68cd48	JCB 15 digit	37.9196197793573759	-122.247260701466345
1054	2019-05-01 03:58:39	2019-05-01	Bonnie Hane-Stokes	bonnie.hane.stokes@geemail.com	San Francisco	California	4870145125742	49878933ec48cc5f26095e570886fbdd	JCB 16 digit	37.7879237901104688	-122.386382360909167
1055	2019-05-01 06:15:33	2019-05-01	Mr. Buell Thompson Sr.	mr.buell.thompson.sr.@geemail.com	Oakland	California	4321648811004959	33b1dae7dbc3fca77b146390342d6be6	JCB 16 digit	37.804693318125679	-122.276138388343554
1056	2019-05-01 09:45:46	2019-05-01	Dr. Edie Hoeger	dr.edie.hoeger@geemail.com	Moreno Valley	California	3754590723671751	7468adee03bbe7c2fb4c490b4854dbb3	Discover	33.9968086120199402	-117.122582762312888
1057	2019-05-01 10:13:17	2019-05-01	Nicolette Reichel	nicolette.reichel@geemail.com	San Francisco	California	3007427099764506	25f9d9dccca98f97b253aa96edb698bd	VISA 16 digit	37.7626228929193104	-122.403561152313799
1058	2019-05-01 12:34:40	2019-05-01	Kennith Jakubowski	kennith.jakubowski@geemail.com	San Francisco	California	4658269633631391	b56359689f03cf65b45b5661c436a6cd	Voyager	37.7646042991306885	-122.435818906660543
1059	2019-05-01 16:55:58	2019-05-01	Deana Cassin	deana.cassin@geemail.com	Mesa	Arizona	4303888978993618	59fa6cf51a647eaa259ad310f26e0288	VISA 16 digit	33.4278423242881857	-111.624443261080984
1060	2019-05-01 21:47:48	2019-05-01	Jann Abernathy	jann.abernathy@geemail.com	San Francisco	California	4171674919294	74f415716e925b8b182c079e7ca6b064	VISA 16 digit	37.7851673470360225	-122.460943681889546
1061	2019-05-01 23:10:34	2019-05-01	Alfonse Beer	alfonse.beer@warmmail.com	Berkeley	California	3337457751114868249	c5b0e765e1af2ada848ab6232539a4dc	Mastercard	37.8766579058223911	-122.304387156943264
1062	2019-05-02 01:39:09	2019-05-02	Melbourne Terry	melbourne.terry@geemail.com	Gainesville	Florida	51795484857661164	6896bb5b62e6f977b4522027cfe5786c	Voyager	29.6314043734513213	-82.2465194511566438
1063	2019-05-02 03:08:39	2019-05-02	Mr. Fabian Thiel IV	mr.fabian.thiel.iv@geemail.com	San Francisco	California	4080660565070	1c96c2f634fc7f5f0a30d20191b5c49e	Diners Club / Carte Blanche	37.7056476228137072	-122.440554799641106
1064	2019-05-02 04:03:11	2019-05-02	Lane Braun-Schroeder	lane.braun.schroeder@geemail.com	San Francisco	California	3449989039970261	e5b4ca694591401c4aa1498f70a2d05d	Diners Club / Carte Blanche	37.8111406561205925	-122.42755118453141
1065	2019-05-02 07:12:43	2019-05-02	Mr. Merwin Beatty III	mr.merwin.beatty.iii@warmmail.com	Oakland	California	4193867721710662	86b7d43fca942b095bdeadd1e22cd18c	JCB 16 digit	37.8325691379779059	-122.233345805241882
1066	2019-05-02 14:37:57	2019-05-02	Dr. Dakotah Hyatt	dr.dakotah.hyatt@geemail.com	Columbus	Ohio	3768636615801040	6f722b834263c15b24e49771af7c4a93	VISA 13 digit	39.9223510862372777	-82.9969011668816279
1067	2019-05-02 15:27:58	2019-05-02	Buddy Bosco	buddy.bosco@geemail.com	San Francisco	California	55842089239399293	12e98d07715217633e17c13bac944896	American Express	37.7853125129906644	-122.4842783859485
1068	2019-05-02 20:06:44	2019-05-02	Ludie Lindgren	ludie.lindgren@geemail.com	San Francisco	California	3040328747312259	07e1fe9c00a2790b70c224585e63ef18	VISA 16 digit	37.7835968999751941	-122.463053785127272
1069	2019-05-02 20:49:58	2019-05-02	Shanika Christiansen	shanika.christiansen@geemail.com	Berkeley	California	869969145289862055	cf83de8deb792991547d493be8131db8	Mastercard	37.8925599236274664	-122.276977021447308
1070	2019-05-02 22:15:51	2019-05-02	Hobert Crooks	hobert.crooks@geemail.com	San Francisco	California	869960645617634893	3ebecfa2d16ee0959d15eb9599a932c1	JCB 16 digit	37.784475825068192	-122.422610129689019
1071	2019-05-03 05:26:47	2019-05-03	Dr. Lucas Conroy IV	dr.lucas.conroy.iv@warmmail.com	Berkeley	California	6011886263697227414	dec6c44ccc13c7cc181fff002f5d3791	Discover	37.8630449147884178	-122.28669700329128
1072	2019-05-03 06:08:48	2019-05-03	Mr. Kerwin Ruecker	mr.kerwin.ruecker@warmmail.com	San Francisco	California	3112022563722838696	3080d9ed10b735b36656870b44fe311e	VISA 13 digit	37.7560052474877423	-122.416432628539326
1073	2019-05-03 09:30:56	2019-05-03	Miss Jaiden Bergnaum	miss.jaiden.bergnaum@geemail.com	Berkeley	California	52815845909439971	0378fad2d7eba7110f43c581579b9a22	VISA 16 digit	37.8698342179997596	-122.270337344868622
1074	2019-05-03 09:57:16	2019-05-03	Alisa Lubowitz	alisa.lubowitz@geemail.com	Sunnyvale	California	869973975250318040	78ead57d94bb42f569a9cc4e1e7f5866	Diners Club / Carte Blanche	37.4018659504588697	-122.06052475028784
1075	2019-05-03 11:17:00	2019-05-03	Jarod Ebert	jarod.ebert@geemail.com	San Francisco	California	54914416008440359	e4fb2b9a85697f3f4af177e348e6402d	VISA 16 digit	37.7847648855565694	-122.39634822537748
1076	2019-05-03 14:49:59	2019-05-03	Wiliam Nolan	wiliam.nolan@geemail.com	San Francisco	California	060463861259909	92f3671d98302991cb6ca414ae2bea79	JCB 16 digit	37.7734657766527064	-122.443716649745539
1077	2019-05-03 18:03:22	2019-05-03	Laken Connelly	laken.connelly@woohoo.com	San Francisco	California	3030776635726958	1276219b85e9a18ee25f0b9315adaf58	Diners Club / Carte Blanche	37.7573490012375643	-122.443338542063159
1078	2019-05-03 19:43:00	2019-05-03	Miner Streich-Schneider	miner.streich.schneider@geemail.com	Berkeley	California	3030649464989569	ccadc2c5193dc6b02bf5fd21080a174e	VISA 13 digit	37.8845760187088914	-122.318851300022629
1079	2019-05-03 19:59:29	2019-05-03	Dr. Hosea Mohr IV	dr.hosea.mohr.iv@geemail.com	Montgomery	Alabama	6011288279506154312	b4f2fb871f4f3e7e85cce07e51c71d94	Mastercard	32.3213940410807723	-86.2028973861284555
1080	2019-05-03 20:04:56	2019-05-03	Fiona Koelpin-Pacocha	fiona.koelpin.pacocha@geemail.com	San Francisco	California	3487832987173780	4da6e4bf13f6afa6bd3b6e43486f6076	Voyager	37.783105736694111	-122.413848192909398
1081	2019-05-03 22:19:27	2019-05-03	Chance Heller Sr.	chance.heller.sr.@geemail.com	Oakland	California	3158927131755017236	0391a39fba74a33f128d76e3dcfb8018	Mastercard	37.8160292704035328	-122.291330605884724
1082	2019-05-04 00:07:36	2019-05-04	Kacie Hagenes DVM	kacie.hagenes.dvm@geemail.com	San Francisco	California	3088626280974888077	e5fef6df5d8835188c70cdef06f94abd	Maestro	37.7882377471342821	-122.45355388062751
1083	2019-05-04 00:13:25	2019-05-04	Lizzie Emmerich-O'Hara	lizzie.emmerich.o'hara@warmmail.com	San Francisco	California	180033255860243675	f8a260813611169a55f92b433c4c13aa	American Express	37.7252849781235113	-122.423097503889025
1084	2019-05-04 03:40:07	2019-05-04	Debbi Purdy	debbi.purdy@geemail.com	Charleston	South Carolina	869926236389011842	46ddfbd590718635462a3acbd5e13325	American Express	32.8124990357548043	-79.8599653772227498
1085	2019-05-04 03:43:32	2019-05-04	Mr. Hollis Hoppe	mr.hollis.hoppe@geemail.com	San Francisco	California	3528442768720456548	8ac1dc343c817fa0961e9614fe3eda01	JCB 15 digit	37.7590160668273569	-122.457309430829156
1086	2019-05-04 05:16:42	2019-05-04	Mr. Lionel Howe	mr.lionel.howe@warmmail.com	Oakland	California	4434984251462991	45948b1c6570644a5a45cb88648edf09	Maestro	37.7811670405354079	-122.263300055606692
1087	2019-05-04 13:12:29	2019-05-04	Dr. Corine Hyatt	dr.corine.hyatt@geemail.com	San Francisco	California	3528864357249428888	130cb07965a30e25726ccff4b12a77a9	VISA 16 digit	37.7573108413707104	-122.432888981712253
1088	2019-05-04 14:04:49	2019-05-04	Oris Satterfield	oris.satterfield@geemail.com	San Francisco	California	4920543849300781	e90042f32fa5fcb6285dda2f3b2842ae	JCB 16 digit	37.7906837886014557	-122.455786743096496
1089	2019-05-04 18:22:36	2019-05-04	Janae Jacobson	janae.jacobson@woohoo.com	San Francisco	California	55694491276911320	3d9dddad79784ea5cabd3fe40ad0e924	VISA 16 digit	37.7434101126662327	-122.430732437916461
1090	2019-05-04 20:13:37	2019-05-04	Harden Koss	harden.koss@warmmail.com	San Francisco	California	4351266731558484	715def527cbd0270c189e05b9952bf54	Diners Club / Carte Blanche	37.7970890714804355	-122.428510984484504
1091	2019-05-04 23:44:12	2019-05-04	Mr. Cap Luettgen	mr.cap.luettgen@geemail.com	Paterson	New Jersey	4087800596721786	7efcd1d914a86e0ec96ad4fce94fa684	VISA 13 digit	40.8351141239006097	-74.066444680324949
1092	2019-05-05 02:50:59	2019-05-05	Abbigail Block	abbigail.block@geemail.com	San Francisco	California	4303705853762035	f1eb57990037585912b60f4ecb57b7de	VISA 16 digit	37.7834750802838499	-122.432835590544457
1093	2019-05-05 03:23:11	2019-05-05	Orson Braun	orson.braun@geemail.com	San Francisco	California	4893773962764272	425dbcc31ca647f3f1a9482b96e3f42a	VISA 13 digit	37.8002261806233477	-122.452500584198219
1094	2019-05-05 06:45:53	2019-05-05	Miss Tammy Zboncak DDS	miss.tammy.zboncak.dds@woohoo.com	San Francisco	California	3158599621640488664	6610d6c0fa9cfb4c5a6740afca47d231	Diners Club / Carte Blanche	37.7578945026261508	-122.456665568107582
1095	2019-05-05 08:17:16	2019-05-05	Yee Frami-Hilll	yee.frami.hilll@geemail.com	San Francisco	California	3112091207790916739	a724c24e021604c43b1f90985753103a	VISA 16 digit	37.7875914485484117	-122.391264709781964
1096	2019-05-05 11:51:45	2019-05-05	Mr. Niko Sipes	mr.niko.sipes@geemail.com	San Francisco	California	869928220472168410	dfdad5837a49689aacab4112a45ee086	Discover	37.7798358909579193	-122.44578234868986
1097	2019-05-05 15:04:04	2019-05-05	Harry Mertz	harry.mertz@woohoo.com	Oakland	California	3088891555445543718	3b1a1d31dd0ff4ef6c3fbc331e19708a	VISA 16 digit	37.7942385364841584	-122.264731135125501
1098	2019-05-05 17:54:09	2019-05-05	Merlin Cole	merlin.cole@warmmail.com	Portland	Oregon	3021387100308584	24e85f8e9a55bed0ca1ed1515d0a91fa	VISA 16 digit	45.6343750323988502	-122.633595476252964
1099	2019-05-05 19:34:02	2019-05-05	Jaliyah Cremin	jaliyah.cremin@geemail.com	San Francisco	California	4565149870612	0b38c6592ee6ec0cd2627e7021d32914	Discover	37.7979658864207906	-122.416007073539888
1100	2019-05-05 19:35:55	2019-05-05	Alline Kuphal	alline.kuphal@woohoo.com	Chicago	Illinois	3158645272185170095	06750441e1637b0c782519607800b7dd	Mastercard	41.9107642262078812	-87.5930070261500759
1101	2019-05-05 19:56:36	2019-05-05	Mr. Jaydon West	mr.jaydon.west@warmmail.com	San Francisco	California	6011316208083049104	16eb0ab82e40d7f1914cdbe1c2cf65b7	JCB 15 digit	37.7366707122128986	-122.443307396340217
1102	2019-05-05 20:56:29	2019-05-05	Duff Abbott	duff.abbott@geemail.com	San Francisco	California	3059305582908566	53f21e6f0e52ea448381d1a3741adbbd	Diners Club / Carte Blanche	37.7659716162979393	-122.475102165560472
1103	2019-05-06 00:47:50	2019-05-06	Oliver Moen	oliver.moen@geemail.com	Oakland	California	3494075024403924	04720f6bdce02d677d1a6456a05d6ce0	Diners Club / Carte Blanche	37.8262845462972734	-122.211569813329163
1104	2019-05-06 04:36:09	2019-05-06	Sanai Tromp	sanai.tromp@geemail.com	Oakland	California	4661635029846832	f0f06a241841b9930c177d974f79441c	VISA 16 digit	37.7813285478901122	-122.253305835288046
1105	2019-05-06 07:09:05	2019-05-06	Christophe Kshlerin	christophe.kshlerin@geemail.com	San Francisco	California	3712066243595573	6f605bb0fdd5e5ce3cf9a5cef83d99d9	JCB 16 digit	37.7716393155110239	-122.438286261588686
1106	2019-05-06 09:50:46	2019-05-06	Rona Nolan-Jones	rona.nolan.jones@geemail.com	San Francisco	California	4372900374693472	296c7b6a8d70121f8158c4ac3c0dd6a6	Voyager	37.7657333963203641	-122.452715802498886
1107	2019-05-06 10:46:05	2019-05-06	Jorge Goodwin IV	jorge.goodwin.iv@geemail.com	San Francisco	California	6011082549437839688	b0676526af847eef3631b130471b7194	VISA 16 digit	37.7640723866733197	-122.447104456185656
1108	2019-05-06 13:04:24	2019-05-06	Kaeden Hartmann II	kaeden.hartmann.ii@warmmail.com	Ontario	California	210059106875502630	61b3e5f0fee97644e16ba214b5297010	American Express	34.0193477254040531	-117.629344896935677
1109	2019-05-06 15:46:09	2019-05-06	Dorman Shanahan	dorman.shanahan@woohoo.com	San Francisco	California	4068117362888787	b9424c01727f7835dc13bf18514ebaef	VISA 16 digit	37.7659704281600099	-122.473268761803169
1110	2019-05-06 16:10:47	2019-05-06	Gino Roob III	gino.roob.iii@warmmail.com	San Francisco	California	3437123059494960	420978f3df02a870505294dce0a4647d	Mastercard	37.7796764336098647	-122.442791080951196
1111	2019-05-06 19:04:29	2019-05-06	Gwendolyn Tillman	gwendolyn.tillman@geemail.com	Cape Coral	Florida	3704034841264679	46b4adf74b33061640472e83e21758d4	Mastercard	26.7222323838125924	-82.0518879225082713
1112	2019-05-07 03:07:11	2019-05-07	Houston Auer	houston.auer@geemail.com	Indianapolis	Indiana	4458515480657596	96c56580432b2a50065aff7c7699c9c2	JCB 16 digit	39.8054442774977488	-86.1576498790379617
1113	2019-05-07 06:00:36	2019-05-07	Lia Douglas-Heller	lia.douglas.heller@woohoo.com	San Francisco	California	53331423763458068	fe24b18f2e5ca51f2daaed579ecaa08d	Diners Club / Carte Blanche	37.7736941303987805	-122.430731382688066
1114	2019-05-07 06:28:34	2019-05-07	Mr. Dilan O'Reilly	mr.dilan.o'reilly@geemail.com	San Francisco	California	210089999208623766	8ccde94eb7ff279e1f107e01912d0b87	Maestro	37.7870202895411467	-122.424449971238175
1115	2019-05-07 07:18:44	2019-05-07	Vivien Spinka	vivien.spinka@warmmail.com	Berkeley	California	4269457253037830	66fa0b96324722a4bb4f2a8bc6a59fe7	Discover	37.874015225440381	-122.266823053562092
1116	2019-05-07 10:49:14	2019-05-07	Janis Kling	janis.kling@woohoo.com	San Francisco	California	55051426763081812	a93c83c48896afa327ac94c728b4a976	Voyager	37.774314377113221	-122.463635973532561
1117	2019-05-07 11:56:18	2019-05-07	Beecher Nitzsche	beecher.nitzsche@warmmail.com	Orange	California	4600247397866881	0ca300b0da73831fc4930d25e8ce4087	JCB 15 digit	33.820742675278332	-117.94710005983822
1118	2019-05-07 12:42:45	2019-05-07	Festus Green IV	festus.green.iv@woohoo.com	San Francisco	California	3337975893319601703	ec14013dbf9532a807e063927494713b	Voyager	37.7409826053832944	-122.463382726641058
1119	2019-05-07 16:22:10	2019-05-07	Miner Kiehn	miner.kiehn@geemail.com	Berkeley	California	4033701806655860	a4859dcfaa93ba5bfe9917bc5ebd1881	Diners Club / Carte Blanche	37.8462927489435828	-122.278870912576437
1120	2019-05-07 23:59:05	2019-05-07	Faith Kiehn	faith.kiehn@geemail.com	San Francisco	California	3528509239724432299	34653a421bb7768e9113e7cd23fa882d	Mastercard	37.7848442440588812	-122.418696446376586
1121	2019-05-08 01:35:53	2019-05-08	Mr. Cason Erdman	mr.cason.erdman@geemail.com	San Francisco	California	4611537605142720	05cfac43ab49dd94cd47207e31d00cff	Mastercard	37.8102577799767658	-122.43416550606598
1122	2019-05-08 02:20:22	2019-05-08	Mr. Alvaro Towne V	mr.alvaro.towne.v@geemail.com	Broken Arrow	Oklahoma	4505283750584	4b65d207addfd6b330ae35e76b244fd5	VISA 13 digit	36.0870329228937621	-95.6931356177609445
1123	2019-05-08 02:21:28	2019-05-08	Lasonya Cronin	lasonya.cronin@geemail.com	Oakland	California	4416961215593428	a1eca2acdf9cfb8c59a6b2c1f664156e	Discover	37.8029135466303217	-122.28088735583168
1124	2019-05-08 09:25:23	2019-05-08	Kristin Durgan II	kristin.durgan.ii@woohoo.com	Oakland	California	869923252204845085	c61983b0a62261d9843d7d6ddfbe88ce	Voyager	37.8062754808138664	-122.270353371429465
1125	2019-05-08 10:58:19	2019-05-08	Roe Sauer	roe.sauer@geemail.com	San Francisco	California	210010144069746497	607943202f6d6e3e90fc1478e05ab981	Discover	37.7760701567142334	-122.408178446277333
1126	2019-05-08 12:57:26	2019-05-08	Dr. Machelle Wiegand	dr.machelle.wiegand@geemail.com	San Francisco	California	4595857110687542	13480e22e0cda170b3905d2cfbdc98b7	Mastercard	37.7706189957082685	-122.428957500761641
1127	2019-05-08 16:01:51	2019-05-08	Aretha Tillman	aretha.tillman@geemail.com	San Francisco	California	52469187082638221	88232076d36978cd25c1058f44dfe4a6	Diners Club / Carte Blanche	37.7800492331146387	-122.430128829272093
1128	2019-05-08 17:09:34	2019-05-08	Rosey Hudson PhD	rosey.hudson.phd@warmmail.com	San Francisco	California	3158213355168845783	b8b0f1a70d58836574adcf37bcfff1f5	JCB 16 digit	37.7844320430424574	-122.411794359214795
1129	2019-05-08 18:55:01	2019-05-08	Wilfrid Tillman	wilfrid.tillman@geemail.com	Garden Grove	California	4526100085258757	074ff56b78f7833f183fa5293025ea6c	Diners Club / Carte Blanche	33.7675391209602296	-117.968274495566263
1130	2019-05-09 01:59:56	2019-05-09	Rubin Mann DVM	rubin.mann.dvm@geemail.com	Berkeley	California	4569291610644	e0ee524e0d9ac4972b11be5b8541a37b	Discover	37.8612908780966322	-122.284619976196666
1131	2019-05-09 02:22:10	2019-05-09	Jimmy Murphy	jimmy.murphy@warmmail.com	San Francisco	California	3088254159163694240	04983e19c731fce102d706627c5b1c5e	JCB 16 digit	37.793954086944467	-122.436467008159354
1132	2019-05-09 05:25:06	2019-05-09	Jolette Rippin	jolette.rippin@warmmail.com	Madison	Wisconsin	676209114847107	41a281673f8e70aa84ea39ac37b19600	VISA 16 digit	43.092724399359156	-89.4480886103469857
1133	2019-05-09 10:22:06	2019-05-09	Brittnie Abernathy	brittnie.abernathy@geemail.com	San Francisco	California	3528213544119516847	4812ad68018d767bc96808b52e0edf42	JCB 15 digit	37.7600156832522273	-122.430137814116222
1134	2019-05-09 14:40:56	2019-05-09	Gavyn Hermiston	gavyn.hermiston@geemail.com	San Francisco	California	3058558846224706	8e505af78264691a8776aeb75268d09e	Mastercard	37.7841648980398119	-122.420603208639122
1135	2019-05-09 17:00:21	2019-05-09	Joleen Pfeffer	joleen.pfeffer@geemail.com	New York	New York	4487119730181	4e14ae97c5773f2e5f1b1a8b1cd679de	Diners Club / Carte Blanche	40.5758477810528149	-73.9410838908877253
1136	2019-05-09 20:44:57	2019-05-09	Carnell Heaney	carnell.heaney@woohoo.com	San Francisco	California	869979515124078018	67f64a0440f589ab52450a4b88880a4f	Mastercard	37.8161287728972297	-122.446841553111682
1137	2019-05-09 21:15:11	2019-05-09	Konner Stokes	konner.stokes@woohoo.com	San Francisco	California	210002717692103150	b150ffd777b9e083e8ebb3bc2e8ad06d	American Express	37.7443256572502648	-122.426039405523753
1138	2019-05-09 23:02:18	2019-05-09	Jeffery Kub	jeffery.kub@geemail.com	San Francisco	California	54610017879816953	1eb7710417d4f30980d572a13041e8c8	JCB 16 digit	37.7826159108672286	-122.430376557161978
1139	2019-05-10 00:34:32	2019-05-10	Ely O'Reilly	ely.o'reilly@geemail.com	Hollywood	Florida	869942706799094125	c0b5ed06d30a2a1741bceb9bf3ee9ad4	Diners Club / Carte Blanche	26.1224514435920838	-80.0881684472601734
1140	2019-05-10 00:59:30	2019-05-10	Ingrid Collier	ingrid.collier@geemail.com	Berkeley	California	869975358254241518	08101a905e41d373df8319d22b8c289a	Voyager	37.8792380408467011	-122.279622312049796
1141	2019-05-10 01:46:09	2019-05-10	Sandie Schumm	sandie.schumm@warmmail.com	San Francisco	California	630408105736014	ceedf6f838459d69b8d9c99a5a35a046	Voyager	37.7632001681096767	-122.420478366657989
1142	2019-05-10 08:07:26	2019-05-10	Tripp Brakus	tripp.brakus@geemail.com	Fairfield	California	4141952780070449	2c4d5069ee55051e20208c82dc3ceb29	Diners Club / Carte Blanche	38.1619704804040509	-122.033779466851058
1143	2019-05-10 08:23:19	2019-05-10	Cristian Braun	cristian.braun@geemail.com	Berkeley	California	4179941720833	e16d94b83e3ab15c4cc5deaa237d5397	VISA 13 digit	37.8709795732290431	-122.319629104505111
1144	2019-05-10 14:03:38	2019-05-10	Mrs. Esta Corkery	mrs.esta.corkery@geemail.com	Oakland	California	869977121291692665	fe676179babd10069e9b3da4ef5fdd23	Mastercard	37.856266762484907	-122.295681790342101
1145	2019-05-10 15:37:59	2019-05-10	Moriah Lind	moriah.lind@geemail.com	San Francisco	California	4544448525466	2318387947ad8016cc7a991f3607694e	Discover	37.76621976585065	-122.42037854970053
1146	2019-05-10 15:44:18	2019-05-10	Merilyn Lebsack DVM	merilyn.lebsack.dvm@geemail.com	Oakland	California	3158092014930417274	46ae9abd8b24672b9f52f8709d8dd748	Mastercard	37.7810656723724918	-122.247595754681768
1147	2019-05-10 19:37:47	2019-05-10	Jajuan Hammes	jajuan.hammes@geemail.com	San Francisco	California	3736487817821579	73269522a85b2d75d7826de15b7aea16	VISA 16 digit	37.8058845345749717	-122.376174790640462
1148	2019-05-10 20:44:10	2019-05-10	Pleas Hyatt	pleas.hyatt@geemail.com	San Francisco	California	4215085168759	9120e31367691b219bdd1d99b806929e	VISA 16 digit	37.7943038289436117	-122.441145468657211
1149	2019-05-10 23:48:45	2019-05-10	Marolyn Durgan	marolyn.durgan@geemail.com	San Francisco	California	3037081356135262	c5e6cb1c5c134caed38b05c4971e60d1	Diners Club / Carte Blanche	37.8196735155148858	-122.437725503126813
1150	2019-05-11 01:16:02	2019-05-11	Mr. Pinkney Boyle III	mr.pinkney.boyle.iii@geemail.com	Spokane	Washington	675975846547778	01e399d534aca841a3896a1ed57957be	JCB 16 digit	47.5733788451883939	-117.478892607837167
1151	2019-05-11 01:45:25	2019-05-11	Dr. Kolby Herzog Sr.	dr.kolby.herzog.sr.@geemail.com	San Francisco	California	3088262261100275602	bfdd9eb059751f2c53235dacfb877161	VISA 16 digit	37.7531516996446399	-122.454353509179782
1152	2019-05-11 04:16:12	2019-05-11	Minervia Smith	minervia.smith@woohoo.com	Oakland	California	180038779564818198	6a7ef78e274017b61f89a44dde53c349	VISA 13 digit	37.8283138985883838	-122.273654833438655
1153	2019-05-11 08:09:17	2019-05-11	Unique Nicolas	unique.nicolas@warmmail.com	Chicago	Illinois	869964787622721251	2919aaa714f6289c734d9afa51c6ac89	VISA 16 digit	41.8435333856683229	-87.6127170616790636
1154	2019-05-11 09:20:26	2019-05-11	Ms. Norita Tremblay MD	ms.norita.tremblay.md@warmmail.com	San Francisco	California	502007684615110	b5038cf22bbb4e29a6141fefed6a4c4f	Discover	37.7676908868980945	-122.452660751943085
1155	2019-05-11 10:15:10	2019-05-11	Haden Gulgowski I	haden.gulgowski.i@geemail.com	Berkeley	California	3005489836240812	05b01a8002c45c6754e1aca94f63f2e6	VISA 13 digit	37.8722686237737207	-122.286475931749379
1156	2019-05-11 12:41:02	2019-05-11	Lugenia Skiles	lugenia.skiles@geemail.com	San Francisco	California	3780096474183580	753dc39617f8e5b6eaf7fdda46a2a649	Mastercard	37.7999158837705167	-122.431915001963134
1157	2019-05-11 13:29:46	2019-05-11	Daisha Abshire DVM	daisha.abshire.dvm@geemail.com	San Francisco	California	502085381823302	3ee2aad274853bd4273a6be211cc8a0f	Voyager	37.7602630574848774	-122.433823572828246
1158	2019-05-11 19:37:54	2019-05-11	Kristoffer Bailey	kristoffer.bailey@geemail.com	San Francisco	California	4964621558778152	867a2a979d51001a6b07fda36800b5ee	American Express	37.7432857236629928	-122.446698850324395
1159	2019-05-11 22:01:26	2019-05-11	Merritt Runte	merritt.runte@woohoo.com	San Francisco	California	676331737538566	98f51e4499f6b2f4ff778367b80d211e	JCB 16 digit	37.8002071523081682	-122.418476503374876
1160	2019-05-11 23:07:20	2019-05-11	Mr. Zachery Kassulke V	mr.zachery.kassulke.v@geemail.com	San Francisco	California	503851424570995	90a84867f47974c97d39def2316a30fa	JCB 16 digit	37.8023264991712367	-122.42821333326772
1161	2019-05-12 01:28:43	2019-05-12	Daryle Hyatt	daryle.hyatt@geemail.com	Berkeley	California	210041229454035805	225eed912f8de3cd73193ef9b65269ec	Maestro	37.836144612146235	-122.312183636044693
1162	2019-05-12 04:35:21	2019-05-12	Ansel Boyle	ansel.boyle@woohoo.com	Berkeley	California	589384567383074	715705c83119f275f70838b6c7aff4d7	Mastercard	37.8681621736859384	-122.234199063158115
1163	2019-05-12 04:44:13	2019-05-12	Fielding Huel	fielding.huel@geemail.com	Victorville	California	869977224292363854	1891ff3900fb0ed6148bf7fb40b60e5a	Discover	34.6060418395556511	-117.358011668516696
1164	2019-05-12 11:44:02	2019-05-12	Mr. Keifer Gutmann DVM	mr.keifer.gutmann.dvm@woohoo.com	Oakland	California	4007941098309253	dd6d1c56cdc936edbcdef25a8fc130ec	Diners Club / Carte Blanche	37.8034279813717262	-122.220631711854395
1165	2019-05-12 15:08:24	2019-05-12	Dwaine Smitham	dwaine.smitham@geemail.com	San Francisco	California	55978906393233917	dc0009d6800407cb1d7c8b2b1f896b54	Maestro	37.8050459487493598	-122.408562655736361
1166	2019-05-12 15:15:14	2019-05-12	Jeryl Witting PhD	jeryl.witting.phd@woohoo.com	San Francisco	California	4612907414595450	4e1bdd1b60c4047da85d277e23f8aef5	JCB 16 digit	37.7685679334962785	-122.44099151509829
1167	2019-05-12 15:16:48	2019-05-12	Mr. Rand Stark	mr.rand.stark@woohoo.com	Las Vegas	Nevada	589379657433284	8218e677a44cf0af2989eb3d3078c306	JCB 16 digit	36.2226008223935949	-115.202450640147916
1168	2019-05-12 16:06:19	2019-05-12	Margie Spencer	margie.spencer@warmmail.com	San Francisco	California	52034998169876740	4a96ca247bdc484d8b194b08c6b61628	JCB 15 digit	37.7993937630305652	-122.447878849233817
1169	2019-05-12 17:30:26	2019-05-12	Norbert Herzog	norbert.herzog@geemail.com	Berkeley	California	4634987050552	a7056ffdd71206edf5324f3eb2b7f061	American Express	37.8502265965993558	-122.296815853231209
1170	2019-05-12 19:42:37	2019-05-12	Jarett Bayer	jarett.bayer@geemail.com	Oakland	California	869989330611340030	5a8abe0a4ceb74a1ece6d1bb8f29956e	JCB 15 digit	37.7889921601308316	-122.293895371163572
1171	2019-05-12 23:26:56	2019-05-12	Mrs. Alverda Klein PhD	mrs.alverda.klein.phd@geemail.com	San Francisco	California	180073007963654634	61859c7ca6e27134fdb04ed16c35dfcd	Maestro	37.7912594463609395	-122.414952779956238
1172	2019-05-13 02:05:19	2019-05-13	Rich Medhurst	rich.medhurst@geemail.com	San Francisco	California	4984458566916771	232d65d33eb0296f9fd40b5f859f91d3	JCB 16 digit	37.7717581008751608	-122.420229664017043
1173	2019-05-13 03:23:34	2019-05-13	Tillie Steuber	tillie.steuber@geemail.com	Rochester	New York	3795126536640195	3ee1c9f493f634571d88b298ccb61bc4	VISA 16 digit	43.0840972346696987	-77.5630299450602365
1174	2019-05-13 04:54:00	2019-05-13	Simmie Jast	simmie.jast@geemail.com	Oakland	California	3096131543358552322	827adb38917da98352f053374960c00e	Mastercard	37.8302114539770429	-122.260205606983973
1175	2019-05-13 05:43:32	2019-05-13	Mr. Pierce Schmidt	mr.pierce.schmidt@woohoo.com	San Francisco	California	6011297354933185392	abaf494122f47c1515a40c8e93e7f732	VISA 13 digit	37.7487937183570779	-122.459708118832864
1176	2019-05-13 06:55:51	2019-05-13	Amani Hegmann PhD	amani.hegmann.phd@woohoo.com	Berkeley	California	869957875952941166	80b6693e8da08622b999456d0654dc3f	Voyager	37.8515867992930524	-122.285841445325232
1177	2019-05-13 07:35:36	2019-05-13	Dr. Bettie Lebsack DDS	dr.bettie.lebsack.dds@geemail.com	San Francisco	California	3462762254971096	93f47fe60a3a2b912ebd63a5d98231eb	VISA 16 digit	37.7747825100084	-122.448215885292996
1178	2019-05-13 09:31:42	2019-05-13	Angelic Bernhard	angelic.bernhard@geemail.com	San Francisco	California	3039498270260075	8e97e1aca1c568d82884555c77f65cf6	Maestro	37.7561170325807183	-122.434986870713274
1179	2019-05-13 11:42:41	2019-05-13	Grant Monahan	grant.monahan@woohoo.com	Jacksonville	Florida	3158430488334818652	8460df8cefcadb64a0216e9ad0626303	JCB 16 digit	30.422386582480371	-81.6224104067854626
1180	2019-05-13 21:55:12	2019-05-13	Dr. Miya Lind	dr.miya.lind@woohoo.com	San Francisco	California	52133114474491106	198d54b688b3341babee904aa65b57bd	Diners Club / Carte Blanche	37.7417050778180183	-122.420253977098341
1181	2019-05-13 23:44:28	2019-05-13	Alijah Dietrich PhD	alijah.dietrich.phd@warmmail.com	San Francisco	California	6011911535896688648	0567e9e2914ff1776acb9ecafd66d4e5	VISA 16 digit	37.7909637814662602	-122.453168363663679
1182	2019-05-14 05:49:10	2019-05-14	Channing Davis	channing.davis@geemail.com	San Francisco	California	4109944211552608	2339747c8411c6c9ecc6c30b670dd707	VISA 16 digit	37.7841354942762919	-122.441936674383825
1183	2019-05-14 05:52:44	2019-05-14	Alvin Gleason	alvin.gleason@geemail.com	Oakland	California	3052043162909913	1de2c1858fe3d3f18c1af765cc1c3861	Diners Club / Carte Blanche	37.7829709046828697	-122.257211442370547
1184	2019-05-14 10:49:45	2019-05-14	Huey Boehm-Lesch	huey.boehm.lesch@woohoo.com	Oakland	California	3787342813193846	9239ef4469e33999c8057c6a5792722d	VISA 16 digit	37.7909018331696771	-122.264622996061249
1185	2019-05-14 11:17:14	2019-05-14	Miss Maiya Kris DVM	miss.maiya.kris.dvm@geemail.com	Akron	Ohio	54930056854750996	32d41c0dde111491132eacd586903a17	Discover	41.0808654838074006	-81.5665664765831053
1186	2019-05-14 12:05:38	2019-05-14	Alabama Mraz	alabama.mraz@geemail.com	Atlanta	Georgia	3052942341560879	1c1dd0a8c5a4f785bdf04f9fbbd1f08d	VISA 16 digit	33.6746697670124462	-84.4636371991176276
1187	2019-05-14 13:00:51	2019-05-14	Breonna Borer	breonna.borer@geemail.com	Berkeley	California	3721281851595703	5ebf550b7dc132ba940e79cf53463e05	JCB 15 digit	37.8143465245672203	-122.24842261385561
1188	2019-05-14 15:34:06	2019-05-14	Adin Zemlak	adin.zemlak@geemail.com	Oakland	California	3096077524969682308	95a0e8dd64e5edef7ec47a6e990719fc	American Express	37.8184139144534299	-122.302860956754316
1189	2019-05-14 16:18:55	2019-05-14	Dr. Vikki Bosco MD	dr.vikki.bosco.md@geemail.com	San Francisco	California	3017995817018686	d6936dc6834cb9d6a01dd1ef64eb7026	American Express	37.7666286753531466	-122.457115002618522
1190	2019-05-14 22:54:14	2019-05-14	Nikolas Fahey-Harber	nikolas.fahey.harber@geemail.com	San Francisco	California	3054589983579580	f49efd7c09e65148111f063b91ad66e8	American Express	37.7935983830309254	-122.469358066040456
1191	2019-05-15 01:52:04	2019-05-15	Michal Feil-Nicolas	michal.feil.nicolas@geemail.com	San Francisco	California	675942526191236	4882cf915176935b1bdd78e02622bcaa	JCB 16 digit	37.7658598034971007	-122.449563395885832
1192	2019-05-15 02:09:13	2019-05-15	Jeffie Stiedemann	jeffie.stiedemann@geemail.com	Los Angeles	California	4293222036616254	c833b422db8943dee7d6dfc37c17c12c	VISA 16 digit	34.0608610572159236	-118.441723821264873
1193	2019-05-15 06:19:06	2019-05-15	Flor Stokes	flor.stokes@geemail.com	Berkeley	California	4414707117441154	2439cbc06a512f478607b68ad6668e21	JCB 16 digit	37.869234222460932	-122.276519838519476
1194	2019-05-15 10:12:15	2019-05-15	Dr. Allyn Parker	dr.allyn.parker@warmmail.com	San Francisco	California	3039188217724628	a9bd3f2982bc887614464ddb003d0ac9	JCB 16 digit	37.7524515840728156	-122.41639281660882
1195	2019-05-15 12:06:50	2019-05-15	Vera Witting	vera.witting@geemail.com	Aurora	Illinois	4858030266986793	bd71e3eeb37f2efd9d0cca78763b3f84	JCB 15 digit	41.8362997629437601	-88.2024302876949235
1196	2019-05-15 14:31:31	2019-05-15	Cherish Schmidt	cherish.schmidt@geemail.com	San Francisco	California	869982311973588223	c69de3a243ca98bc1bba8b74a2ee2b14	VISA 16 digit	37.7962634174392136	-122.411435394899343
1197	2019-05-15 15:15:09	2019-05-15	Michal Gislason V	michal.gislason.v@warmmail.com	Oakland	California	3158660764262595723	e3326a03b68399e917acd5e8d82fbdf4	JCB 15 digit	37.8126117910358062	-122.239273941436565
1198	2019-05-15 19:17:31	2019-05-15	Mrs. Rosann Schimmel	mrs.rosann.schimmel@geemail.com	Oakland	California	4028782824543145	64a26f4796b6fc40315fbb49a2adee33	American Express	37.7973745909256351	-122.275924741754793
1199	2019-05-15 21:11:55	2019-05-15	Mr. Savion Gibson III	mr.savion.gibson.iii@warmmail.com	San Francisco	California	4329661569973	1c96fc41ddac638c6344a052ff0dd032	JCB 16 digit	37.7548965207902327	-122.427098670655141
1200	2019-05-16 00:38:05	2019-05-16	Dr. Gaylene Harber PhD	dr.gaylene.harber.phd@geemail.com	Denver	Colorado	3528019847580683608	5a44284e3cdf56250da241a8cb47f810	American Express	39.7273622965492308	-104.794672000060231
1201	2019-05-16 01:40:18	2019-05-16	Euna Purdy	euna.purdy@geemail.com	Berkeley	California	4750798520322075	bd6b24ec9d24b9123e37d8cf05eec31d	VISA 16 digit	37.8688765332148449	-122.292219463181169
1202	2019-05-16 01:44:38	2019-05-16	Hobart Jacobs	hobart.jacobs@geemail.com	San Francisco	California	51812144567450519	de2294338a7f462fde4d02303331aca2	JCB 16 digit	37.7932262050615009	-122.450236687183491
1203	2019-05-16 03:02:49	2019-05-16	Mr. Willis Cassin IV	mr.willis.cassin.iv@warmmail.com	San Francisco	California	3009333357301924	664760551e07e8fab6a8afdb9febf159	Discover	37.7575230346666117	-122.42924840519413
1204	2019-05-16 05:57:59	2019-05-16	Vonetta Miller	vonetta.miller@warmmail.com	San Francisco	California	3403302467586829	c20286cbe200b1b306fbe42372099d59	Mastercard	37.7913527421067172	-122.396941384413438
1205	2019-05-16 16:36:06	2019-05-16	Mrs. Aubrie O'Reilly DDS	mrs.aubrie.o'reilly.dds@woohoo.com	San Francisco	California	3027687325639729	e20388766dfaf22d13b646c45501bbb6	VISA 16 digit	37.7771612810296062	-122.43255426483509
1206	2019-05-16 19:57:39	2019-05-16	Janel Hermiston-Cummings	janel.hermiston.cummings@geemail.com	San Francisco	California	4877288032774227	d9b26f70c52df8032538eae65ac1ee80	VISA 16 digit	37.7712808209800386	-122.423584433141258
1207	2019-05-16 20:13:27	2019-05-16	Estie Leannon	estie.leannon@warmmail.com	Phoenix	Arizona	3434227856181093	7ef755ce9389ce019036a90a30ad757d	VISA 13 digit	33.5139779688257775	-112.154867329627649
1208	2019-05-16 22:19:54	2019-05-16	Tamisha Reichert-Swaniawski	tamisha.reichert.swaniawski@geemail.com	San Francisco	California	3528875353567349969	cf1331baf6b5bbf510ec18f303139cc1	Maestro	37.7929426282297669	-122.451714862933088
1209	2019-05-17 00:26:33	2019-05-17	Mr. Reinaldo Williamson	mr.reinaldo.williamson@geemail.com	San Francisco	California	210085583217413999	4a70f4592774a116ea4b7ba3cbc9616b	Maestro	37.772759916384345	-122.450415966104075
1210	2019-05-17 01:20:23	2019-05-17	Dr. Zaria Paucek DDS	dr.zaria.paucek.dds@warmmail.com	San Francisco	California	3434026391942252	9910404e7f4cdfe064a27e75f2d00be2	VISA 16 digit	37.7566917398204609	-122.415757193880978
1211	2019-05-17 02:07:35	2019-05-17	Izayah Stroman	izayah.stroman@geemail.com	San Francisco	California	53114042278067041	14e57854f30ac850c7eb523293fa788c	Mastercard	37.7729284750379009	-122.433913941733664
1212	2019-05-17 03:02:07	2019-05-17	Ms. Joell Mante	ms.joell.mante@warmmail.com	Oakland	California	6011358750132988617	06e53ac56ccebb22cbe6bdb85c3e4e99	VISA 16 digit	37.8187805841449673	-122.246125106073734
1213	2019-05-17 03:10:14	2019-05-17	Yasmine Nienow DDS	yasmine.nienow.dds@woohoo.com	San Francisco	California	4396281407594959	be380a01139db56b0235146cf51c86e4	Discover	37.7594790923647352	-122.447916252336427
1214	2019-05-17 05:12:20	2019-05-17	Mr. Lionel Hoppe II	mr.lionel.hoppe.ii@geemail.com	Richardson	Texas	4171657844400556	23a5238933129e0464c901a4a97febe6	VISA 16 digit	32.9096780827503608	-96.7619678338751186
1215	2019-05-17 06:46:20	2019-05-17	Mellissa Schoen	mellissa.schoen@geemail.com	San Francisco	California	3337935913939873497	1ba8217f5eb7033a2833aae4d8243bc7	Mastercard	37.7875764450356755	-122.423495208105763
1216	2019-05-17 08:32:20	2019-05-17	Tarah Wiza	tarah.wiza@geemail.com	Berkeley	California	4267659674024063	bc6e578306a1e7c41255d68b76be9b17	JCB 16 digit	37.9002757314293888	-122.223753407476778
1217	2019-05-17 11:55:17	2019-05-17	Mr. Ah Zboncak	mr.ah.zboncak@geemail.com	San Francisco	California	3158208736386238199	349d726a4344560bb4394883e0216ef6	VISA 16 digit	37.806952479211553	-122.422524622005028
1218	2019-05-17 15:31:24	2019-05-17	Dr. Jabari Auer IV	dr.jabari.auer.iv@geemail.com	Oakland	California	3528541675995771073	b2444646c9e99653f2a33b6efe9ba76c	Discover	37.8060520413532046	-122.301593106881455
1219	2019-05-17 20:10:53	2019-05-17	Jaimee Ledner	jaimee.ledner@geemail.com	Dallas	Texas	561254900484384	62483e1e9ffe84af330d509e3d56ea77	Maestro	32.7681730837367482	-96.7784006159249657
1220	2019-05-18 03:10:46	2019-05-18	Mel Powlowski	mel.powlowski@geemail.com	Baltimore	Maryland	3420796475719935	0688187d2f4976b50612bd33c708b519	VISA 16 digit	39.3713357097003609	-76.5421728727892088
1221	2019-05-18 03:42:56	2019-05-18	Dr. Tonja Wolf DVM	dr.tonja.wolf.dvm@geemail.com	San Francisco	California	180097614093753855	1e64aa476970bbceaadd22d723a5217f	JCB 16 digit	37.7663954804201367	-122.441795425893005
1222	2019-05-18 05:28:26	2019-05-18	Abbott Weber PhD	abbott.weber.phd@geemail.com	San Francisco	California	180030199440412538	18356bb2c84aced937ad584c9b558525	JCB 16 digit	37.7683994301440009	-122.394657433965023
1223	2019-05-18 10:32:10	2019-05-18	Mr. Dalton Schinner	mr.dalton.schinner@geemail.com	San Francisco	California	3528394056049026871	ccc9b4bacb1c15f074148c3277719def	VISA 13 digit	37.753418283586214	-122.424332210745604
1224	2019-05-18 11:51:22	2019-05-18	Nakia Heathcote	nakia.heathcote@geemail.com	Amarillo	Texas	210096901590024927	fbf9b64efcca70289c0942afbe00e2e3	American Express	35.195325722654907	-101.873355068997299
1225	2019-05-18 13:57:18	2019-05-18	Cassie Bogan	cassie.bogan@geemail.com	San Francisco	California	6011938111379245154	d995db341c0356818447b5bc5c7c20a9	VISA 16 digit	37.7551697863247639	-122.472072151531165
1226	2019-05-18 14:10:11	2019-05-18	Dr. Kash Yost	dr.kash.yost@woohoo.com	Berkeley	California	4188189566279	f43e8a4aec67fe8a911259d7bf5dc198	VISA 16 digit	37.9086643158757539	-122.229175402507266
1227	2019-05-18 14:43:26	2019-05-18	Anabel Mann	anabel.mann@geemail.com	Berkeley	California	3706805634111336	f1ff8f4ce6cc0fc249d98859cc9006fe	American Express	37.8837955061951206	-122.252159522694214
1228	2019-05-18 19:59:57	2019-05-18	Dr. Shaquille Funk II	dr.shaquille.funk.ii@warmmail.com	Oakland	California	4333795022800554	2b7ba5e3ff77378a8d16663b2270defe	JCB 16 digit	37.8172191141671306	-122.266628747288266
1229	2019-05-18 23:21:00	2019-05-18	Tayshaun Schumm Sr.	tayshaun.schumm.sr.@woohoo.com	San Francisco	California	3044601300578482	a105bc1a4ff8c92a69428dcf732bbdf0	VISA 16 digit	37.7517812196072597	-122.451426887713055
1230	2019-05-18 23:22:02	2019-05-18	Kameron Conroy	kameron.conroy@geemail.com	San Francisco	California	869986960693385454	59906380b74d0348ac616710e68c3be3	VISA 16 digit	37.7617230310966221	-122.448786472572181
1231	2019-05-19 01:08:00	2019-05-19	Mabel Mraz	mabel.mraz@geemail.com	Oakland	California	3036140126344629	193d913afe415fe28127f4ae3a02862f	Maestro	37.7898901095807673	-122.312431246304982
1232	2019-05-19 01:39:30	2019-05-19	Lilburn Dare	lilburn.dare@geemail.com	New York	New York	3746771755607597	7374ba55b6022043116ea6a7e64f3445	Discover	40.6772613079510634	-74.0349356883566827
1233	2019-05-19 03:47:16	2019-05-19	Dr. Mozelle Dickens DVM	dr.mozelle.dickens.dvm@woohoo.com	San Francisco	California	4758576220205556	f6f6776d03b022b66c353648ff8637b1	VISA 16 digit	37.7927205304283618	-122.474380488960037
1234	2019-05-19 06:48:29	2019-05-19	Ottilie Treutel	ottilie.treutel@geemail.com	Baltimore	Maryland	4086159923279989	078d5d0487f463f90bc7e4d1d15d117b	Maestro	39.3817905264906543	-76.7100968439150677
1235	2019-05-19 07:14:10	2019-05-19	Francisco Satterfield	francisco.satterfield@geemail.com	Berkeley	California	4818769893210	e6f637df681d2e6fa5b7c5e9acce441b	JCB 16 digit	37.8448017930213396	-122.312530962576076
1236	2019-05-19 10:14:15	2019-05-19	Arthur Rice	arthur.rice@geemail.com	San Francisco	California	4396486762043571	bdbd1716233748b85077903a7ab9cf92	Voyager	37.768056251615775	-122.416535509141582
1237	2019-05-19 13:07:29	2019-05-19	Amiyah Reilly	amiyah.reilly@warmmail.com	San Francisco	California	502042240943730	69ffe3e688e508473f58884e1a2323b3	Diners Club / Carte Blanche	37.7727041121002785	-122.411970667513629
1238	2019-05-19 13:15:37	2019-05-19	Landon Tillman	landon.tillman@woohoo.com	San Francisco	California	52738319412053178	59df2e68df229e63dd6360c5ed325f0b	JCB 16 digit	37.7988471645964026	-122.439503885908408
1239	2019-05-19 15:36:17	2019-05-19	Autry Franecki	autry.franecki@woohoo.com	San Francisco	California	6011985148958547453	4322a3a1c659be30cfd6e24a6ac0f108	Diners Club / Carte Blanche	37.7917855135404182	-122.444748714817592
1240	2019-05-19 19:55:41	2019-05-19	Deanna Waters-Raynor	deanna.waters.raynor@woohoo.com	San Francisco	California	869966889270252932	1cf088bc599623f5bde7c4e82f580582	VISA 13 digit	37.7530248312482684	-122.435418289612102
1241	2019-05-19 20:40:29	2019-05-19	Mr. Everet Baumbach	mr.everet.baumbach@woohoo.com	San Francisco	California	4890867670421309	c5d12bfba7ba00acbead261d9b576d88	JCB 15 digit	37.8047378386053836	-122.433022682013657
1242	2019-05-20 02:48:04	2019-05-20	Glen Welch	glen.welch@geemail.com	San Francisco	California	3337795522259442087	ae0419b05072681defd37434079dd02b	Mastercard	37.7798937998800071	-122.406841956694223
1243	2019-05-20 03:39:37	2019-05-20	Dr. Douglas Terry	dr.douglas.terry@geemail.com	Oakland	California	3475657173959856	8b6a1f1ec5c1cbfe53a873565d262c88	VISA 16 digit	37.8148033875143526	-122.277620014952504
1244	2019-05-20 07:35:25	2019-05-20	Jayde Dickinson	jayde.dickinson@geemail.com	San Francisco	California	3337399285304002567	722d072bc790ca5b67f42c40c09be4be	American Express	37.7530891559181683	-122.447717472539381
1245	2019-05-20 08:38:38	2019-05-20	Kelli Schulist	kelli.schulist@geemail.com	San Francisco	California	4896967539052974	327701efa8cc9259922666c900833a14	Discover	37.8229776411827388	-122.471140362534129
1246	2019-05-20 15:17:54	2019-05-20	Leonia Kub	leonia.kub@geemail.com	San Francisco	California	3158148640461886356	209f6fe30522783742ca37178baf842e	Maestro	37.7727014744995984	-122.480674741419875
1247	2019-05-20 15:27:55	2019-05-20	Terell Johns	terell.johns@geemail.com	Sterling Heights	Michigan	3337324012739841975	03f402f5fbc0509021f414ae50e00218	VISA 13 digit	42.5535290611989794	-82.975728767567503
1248	2019-05-20 17:52:08	2019-05-20	Mrs. Marleigh Schamberger	mrs.marleigh.schamberger@geemail.com	Oakland	California	4396635282169643	f5956347a24fb3f39ffdf121a1a9414b	Discover	37.8242503666210936	-122.243210138236307
1249	2019-05-20 19:13:33	2019-05-20	Rosena Walter DDS	rosena.walter.dds@geemail.com	San Francisco	California	4084062428178189	071559750bfd5b38ce0b7599c2e7cf86	Voyager	37.7387268575069541	-122.434875402423643
1250	2019-05-20 19:53:01	2019-05-20	Marita Schulist-Durgan	marita.schulist.durgan@geemail.com	San Francisco	California	4667800336073991	8da6168a31c594006bb29162720064b0	JCB 16 digit	37.7915733264184084	-122.417726238520132
1251	2019-05-20 22:30:21	2019-05-20	Ericka Gerhold	ericka.gerhold@geemail.com	Louisville	Kentucky	3022448618773252	4eb52f965d5cf9d13514408b1cd0700a	JCB 16 digit	38.0935164634507117	-85.6496336738184141
1252	2019-05-21 00:33:41	2019-05-21	Nolan Beier DDS	nolan.beier.dds@geemail.com	Berkeley	California	210056404015679043	570e317477ea6f5b1325e6aade13654b	VISA 16 digit	37.8833468712766006	-122.297321991805219
1253	2019-05-21 01:43:51	2019-05-21	Nathan Kunze-Schmidt	nathan.kunze.schmidt@geemail.com	San Francisco	California	6011109855543638222	1d95d3259af4cba5282a7f26e3bade00	JCB 16 digit	37.7904814403838145	-122.412381893829775
1254	2019-05-21 03:00:34	2019-05-21	Mr. Shep Walter	mr.shep.walter@geemail.com	San Francisco	California	869971668667846917	d078f06c33e8b82f1650655adf4e9bf1	VISA 13 digit	37.7886632807838296	-122.432188126733749
1255	2019-05-21 03:28:40	2019-05-21	Hymen Bahringer	hymen.bahringer@geemail.com	San Francisco	California	3711627918468064	7c0aecf1aad222cafd4017401149b856	Voyager	37.8082988111075551	-122.408931705524836
1256	2019-05-21 12:22:44	2019-05-21	Tanja Grady DVM	tanja.grady.dvm@geemail.com	Independence	Missouri	3112190900879142165	b31ca0364b0f231ec8f9a256c8cf948b	VISA 16 digit	39.0398951791711184	-94.3536017681289394
1257	2019-05-21 15:57:57	2019-05-21	Leopold Quigley-Heaney	leopold.quigley.heaney@geemail.com	San Francisco	California	4034822543051285	21f3fadde32b6e31c5f18648590572b5	JCB 16 digit	37.7785461272413627	-122.446218464001944
1258	2019-05-21 19:59:47	2019-05-21	Lelia Watsica	lelia.watsica@geemail.com	Oakland	California	4604491084757641	89bf7c1649a2cd870fd87e7e159ece60	JCB 16 digit	37.8112955098431982	-122.299100357515087
1259	2019-05-21 22:37:27	2019-05-21	Marlyn Mohr	marlyn.mohr@warmmail.com	San Francisco	California	3528875246243865434	bd80efc38ce84a0e05abde5eb9955cc3	Discover	37.7833354451768741	-122.454950072976004
1260	2019-05-21 22:43:58	2019-05-21	Banks Jacobson-Becker	banks.jacobson.becker@geemail.com	Phoenix	Arizona	3000866424204877	335f15c864d9bd25759eacd9d43d8d68	VISA 13 digit	33.668086571705345	-112.099560496855901
1261	2019-05-22 01:42:11	2019-05-22	Anita Lockman	anita.lockman@geemail.com	San Francisco	California	869920861980731138	0a14ae6fd514b03962f3eac61634636c	VISA 16 digit	37.7608507395522679	-122.446208916667118
1262	2019-05-22 02:48:10	2019-05-22	Rosann Hodkiewicz	rosann.hodkiewicz@woohoo.com	San Francisco	California	3011685024594308	b2eb444f03f8e6f75e4156fe8e531ad5	VISA 13 digit	37.7680195552454734	-122.42174559760717
1263	2019-05-22 06:13:24	2019-05-22	Valeria Purdy	valeria.purdy@woohoo.com	San Francisco	California	3744059010816407	c970857732c2bb978772b91161da4c0f	Voyager	37.7780098430410973	-122.437942769999481
1264	2019-05-22 08:11:16	2019-05-22	Mr. Barrie Buckridge II	mr.barrie.buckridge.ii@geemail.com	San Francisco	California	53005762965871296	b30f28afe6a806087984c32302951c4b	VISA 16 digit	37.8172767391670419	-122.433749017294801
1265	2019-05-22 12:02:26	2019-05-22	Demetrius Stracke	demetrius.stracke@geemail.com	Phoenix	Arizona	3415963615604701	bd7b39333b2493f3567c0786ce043619	VISA 16 digit	33.5034933756969906	-112.039908320309976
1266	2019-05-22 12:45:00	2019-05-22	Maxwell Lockman	maxwell.lockman@geemail.com	San Francisco	California	4269980141869007	02cfbe255324fe03f63962cce289db82	Mastercard	37.7388083959129546	-122.449872756985116
1267	2019-05-22 13:50:23	2019-05-22	Sharleen Bosco	sharleen.bosco@geemail.com	Oakland	California	3004230019599272	6fcc405447edd1b45af7a0a5ccd41434	Maestro	37.7868842147378032	-122.251822808766846
1268	2019-05-22 16:18:17	2019-05-22	Dr. Albertina Jakubowski DVM	dr.albertina.jakubowski.dvm@geemail.com	Durham	North Carolina	4164314737012945	77aac029b7b65540128e4c1e5f2c292c	JCB 15 digit	36.0767674577668274	-78.9075826353762295
1269	2019-05-22 20:16:29	2019-05-22	Germaine Jaskolski	germaine.jaskolski@geemail.com	San Francisco	California	3796443052739072	452a78c586b267557fd4ec598b1a4126	VISA 16 digit	37.7657901042288842	-122.464496437104728
1270	2019-05-23 04:09:13	2019-05-23	Madison Cremin	madison.cremin@warmmail.com	Berkeley	California	4912926752235	0375f8e258deba316c618e111263d04b	Voyager	37.9099110137007855	-122.252661318887689
1271	2019-05-23 05:16:43	2019-05-23	Dr. Aisha Gislason	dr.aisha.gislason@geemail.com	Oakland	California	4065966214675567	d407c5506ec0218131d21d5767f3b0b6	Diners Club / Carte Blanche	37.8194786219351258	-122.259925245931967
1272	2019-05-23 07:02:41	2019-05-23	Dicy Barton	dicy.barton@geemail.com	Berkeley	California	4982013182218268	986f696651dd79cefaefad8ea21e0439	Voyager	37.8731704376058147	-122.271874685112124
1273	2019-05-23 07:23:20	2019-05-23	Dr. Arta Ortiz	dr.arta.ortiz@geemail.com	Berkeley	California	6011179476345849274	5e18c46df4789f7297c3c6b7ae9cfcd6	JCB 15 digit	37.8429888455125152	-122.289538421513555
1274	2019-05-23 12:12:25	2019-05-23	Kathaleen Okuneva	kathaleen.okuneva@geemail.com	San Francisco	California	4948526693214768	02fbccc5911b044995fcee9f11725c49	VISA 16 digit	37.7845225154635997	-122.427405843256224
1275	2019-05-23 12:30:06	2019-05-23	Dawn Leannon	dawn.leannon@warmmail.com	San Antonio	Texas	4375340729515004	c26be97d25546b6e15130458349d5888	Maestro	29.5382355470746774	-98.5966830464381729
1276	2019-05-23 13:21:18	2019-05-23	Philo Howell	philo.howell@warmmail.com	Berkeley	California	3088386395126565207	394f6a5829832f14f88f515d89dcaac3	JCB 16 digit	37.8541009337028882	-122.253623028462684
1277	2019-05-23 18:05:30	2019-05-23	Samual Leannon	samual.leannon@geemail.com	Dallas	Texas	54879556809438251	1852332b851a8f5caee4c5d4a934b863	Mastercard	32.7763877331551186	-96.7766461355108731
1278	2019-05-23 19:40:37	2019-05-23	Olan Predovic DVM	olan.predovic.dvm@warmmail.com	Berkeley	California	3016414477656638	735c87cefb166bc8c1a5985cc8a0244e	Mastercard	37.8773027860421436	-122.269307340886868
1279	2019-05-23 21:47:15	2019-05-23	Cornel Stehr	cornel.stehr@geemail.com	San Francisco	California	180041914301610773	741c4b297a1e42cb481c924e6ec52637	JCB 15 digit	37.7657327586091682	-122.43355238652515
1280	2019-05-24 00:37:02	2019-05-24	Celestia Weimann	celestia.weimann@woohoo.com	Berkeley	California	4118841752084562	d70e70441d2a7b4056f7d71ff89fa3a8	Maestro	37.8571433765868335	-122.246838236977496
1281	2019-05-24 03:13:19	2019-05-24	Alphonse Collier MD	alphonse.collier.md@geemail.com	Berkeley	California	4822357947511	6c5e99c986591066d345a2df93f9411a	VISA 16 digit	37.8503042103510694	-122.29892129236265
1282	2019-05-24 04:00:21	2019-05-24	Kierra Reinger	kierra.reinger@geemail.com	Oakland	California	4073760949171301	350fe1f7717aa87fdb8e967c7afa1d9b	VISA 16 digit	37.8303772529269011	-122.254691597433563
1283	2019-05-24 05:31:23	2019-05-24	Mr. Travis Durgan	mr.travis.durgan@geemail.com	Richardson	Texas	55212842264391094	5ad04b310590901f40a023f30daec1d4	VISA 16 digit	32.924400571943444	-96.7138266548741683
1284	2019-05-24 07:32:42	2019-05-24	Ciera Rath	ciera.rath@geemail.com	West Valley City	Utah	53524880966702930	6cc827417918c7ec1532c6f97928e72f	Mastercard	40.6339476505983583	-112.077615564338117
1285	2019-05-24 09:46:40	2019-05-24	Dejuan Little MD	dejuan.little.md@geemail.com	Berkeley	California	4659937175910	e7d0b699f916c8b1620203baca637a15	VISA 13 digit	37.8751833970232852	-122.282684311989186
1286	2019-05-24 14:41:16	2019-05-24	Elmore Macejkovic IV	elmore.macejkovic.iv@geemail.com	San Francisco	California	4032504825236	b0430a64046f39b278cd287cc2ef2e68	JCB 16 digit	37.8018073148863962	-122.448521203593344
1287	2019-05-24 14:46:32	2019-05-24	Valery Kling	valery.kling@geemail.com	San Francisco	California	4674454692751260	5e1d34c303e8d03d9b9277f64afb9703	Discover	37.7351830542918734	-122.442095930761965
1288	2019-05-24 15:38:37	2019-05-24	Domingo Kuvalis-Quigley	domingo.kuvalis.quigley@geemail.com	San Francisco	California	675945221495067	4ff4bd99570b213ca711783baf200325	Voyager	37.7821905920199157	-122.440279144286691
1289	2019-05-24 18:26:12	2019-05-24	Perley Sipes	perley.sipes@warmmail.com	Berkeley	California	869903478757256172	bae5fccbc73e087b7351be06feb0dbea	Voyager	37.8842697783344775	-122.289094377086059
1290	2019-05-24 23:37:33	2019-05-24	Maximo Greenfelder	maximo.greenfelder@geemail.com	San Francisco	California	3455274265452131	3124e05e0226f6f207b9ac02c5ab9687	VISA 13 digit	37.7952191641479516	-122.438451844175603
1291	2019-05-25 00:15:28	2019-05-25	Loy Considine	loy.considine@woohoo.com	San Francisco	California	3088517663865566849	a6260815369adc57ed79e1274eca5ad0	JCB 16 digit	37.7749748509486096	-122.431726898398679
1292	2019-05-25 06:17:56	2019-05-25	Miss Phyllis VonRueden DVM	miss.phyllis.vonrueden.dvm@warmmail.com	San Francisco	California	52041533023076871	7215c0b08eafeafc5223fe7deb4898c0	Discover	37.7651151094833892	-122.410851353007473
1293	2019-05-25 06:28:37	2019-05-25	Cherilyn Lakin	cherilyn.lakin@geemail.com	Chattanooga	Tennessee	3427004931885207	3c73236a8be24573b0ac7f64959e2f55	JCB 16 digit	35.07368963680603	-85.2489995718762259
1294	2019-05-25 09:01:11	2019-05-25	Zettie Parker	zettie.parker@geemail.com	San Francisco	California	210099314856169104	a5134ae116e8757666c97e43d15b46ee	JCB 16 digit	37.7931131513659224	-122.442773828621426
1295	2019-05-25 13:24:38	2019-05-25	Leesa Towne	leesa.towne@geemail.com	San Francisco	California	6011551236765592947	ac4deaf5091cd2f0a0e859fffabb4522	JCB 16 digit	37.8148719531779705	-122.419837469732414
1296	2019-05-25 13:51:49	2019-05-25	Mr. Laddie Reinger Jr.	mr.laddie.reinger.jr.@geemail.com	San Francisco	California	6011560365878091767	7ce4e31314a93e4c0fb526d9a56da616	Maestro	37.7645369131251982	-122.451107032279367
1297	2019-05-25 15:34:10	2019-05-25	Debroah Barton-Little	debroah.barton.little@geemail.com	Oklahoma City	Oklahoma	4183680278409	2ce73211fb24fdfbedb94a10c7f38024	JCB 16 digit	35.4865552487228086	-97.4941459291976003
1298	2019-05-25 17:19:12	2019-05-25	Miss Erline Wuckert	miss.erline.wuckert@geemail.com	San Francisco	California	3112024894846477451	385dacfae6cc1cb5ca2c8fdfb343d2f9	JCB 16 digit	37.8004360865512723	-122.420058991095217
1299	2019-05-25 17:23:27	2019-05-25	Mr. Sabastian Zboncak PhD	mr.sabastian.zboncak.phd@geemail.com	San Francisco	California	869963953856264019	1a7bcf02ccd12b4768087bf1619c51d1	American Express	37.7784262840841834	-122.444665878903706
1300	2019-05-25 18:53:01	2019-05-25	Dr. Hardie Waelchi PhD	dr.hardie.waelchi.phd@geemail.com	Berkeley	California	589372294174171	1c3c62d5fc96e75de3cf3e0dc9ca6e99	American Express	37.8560173231994455	-122.267217739642604
1301	2019-05-25 19:08:04	2019-05-25	Mrs. Nella Powlowski	mrs.nella.powlowski@geemail.com	San Francisco	California	4334334450326988	3388120b17e7ea653bfa35d9a71a7834	JCB 16 digit	37.7638036609400842	-122.400261511884111
1302	2019-05-25 21:57:22	2019-05-25	Sasha Cummerata	sasha.cummerata@geemail.com	Oakland	California	3733062006542980	1815516af2a9cec8e67c07ac6dd3c837	VISA 16 digit	37.8392435344263518	-122.243472682361329
1303	2019-05-26 00:50:48	2019-05-26	Thekla Sauer DDS	thekla.sauer.dds@woohoo.com	San Francisco	California	4124979908264	11a35b267bc608a04818a9296706d4df	VISA 13 digit	37.7734522452374222	-122.446479887184211
1304	2019-05-26 01:47:20	2019-05-26	Louella Schneider	louella.schneider@woohoo.com	San Francisco	California	3088278890748075057	632a1f4b266603a837476c760f61513f	Voyager	37.7616261579223931	-122.42457208057904
1305	2019-05-26 01:53:03	2019-05-26	Anissa Walsh	anissa.walsh@woohoo.com	Oakland	California	4341857911253426	0763829af5de48dcd154228fda282e98	Voyager	37.7985264630913562	-122.318407385649536
1306	2019-05-26 03:53:31	2019-05-26	Rhoda Reinger DDS	rhoda.reinger.dds@geemail.com	San Francisco	California	51897305998674427	8404680669833669d9c09ab2f15c0cd6	VISA 13 digit	37.7790920187745911	-122.433389220565473
1307	2019-05-26 06:30:26	2019-05-26	Sherlyn Bernier	sherlyn.bernier@geemail.com	San Francisco	California	589371711871922	413a02ba2b010b438c9b69cfa3f6de14	JCB 16 digit	37.7455735745819609	-122.409008036863
1308	2019-05-26 10:13:15	2019-05-26	Mr. Oland Friesen	mr.oland.friesen@warmmail.com	San Francisco	California	55347904195086207	b2cdb6775b833cc245ef10155d1475ad	Diners Club / Carte Blanche	37.7828631798472685	-122.460183438184472
1309	2019-05-26 10:44:09	2019-05-26	Eris Walsh	eris.walsh@geemail.com	San Francisco	California	3485978742694115	a462b3d54c0626411ea91a5741b80892	American Express	37.8313583418054691	-122.433279285512242
1310	2019-05-26 12:22:01	2019-05-26	Shaina Anderson DVM	shaina.anderson.dvm@geemail.com	Ontario	California	3474057101777523	22d9b50412ce1d54cee352126a2f965f	JCB 15 digit	34.0098678121954237	-117.550662275041276
1311	2019-05-26 13:54:11	2019-05-26	Antonetta Spencer	antonetta.spencer@geemail.com	San Francisco	California	3528922224346243315	8fa7688efc78afea2d5f7d6038b99c38	JCB 15 digit	37.8038881168375767	-122.428001046910339
1312	2019-05-26 20:30:32	2019-05-26	Cleave Hane DDS	cleave.hane.dds@geemail.com	Berkeley	California	52055952798408205	760a7dbc71814728474002c6ec2e4a64	Diners Club / Carte Blanche	37.8725623488482626	-122.321896630427133
1313	2019-05-26 21:11:29	2019-05-26	Kay Mills	kay.mills@geemail.com	Berkeley	California	210071198566649501	0b60c037a58f93f8827b1a63ac5c1240	Mastercard	37.8649017788132625	-122.247550058563633
1314	2019-05-26 22:00:26	2019-05-26	Mr. Marvin Witting	mr.marvin.witting@geemail.com	San Francisco	California	3483071450235610	7ae724798547051425e63904457c8a60	VISA 16 digit	37.7789945397974023	-122.411043682318493
1315	2019-05-26 23:43:04	2019-05-26	Genie Stanton	genie.stanton@geemail.com	Jacksonville	Florida	4170843713535653	4329cf27e24395a259185fa42e917239	Voyager	30.2500115653086468	-81.6244859726246546
1316	2019-05-27 02:42:12	2019-05-27	Lorri Corkery	lorri.corkery@geemail.com	Oakland	California	180089245805289183	d6630993157a04f773aaf4a777284637	VISA 16 digit	37.8303501021245765	-122.283730775769413
1317	2019-05-27 03:45:09	2019-05-27	Dayse Wolff	dayse.wolff@geemail.com	San Francisco	California	180099209210436068	52b6ee4695dc3f6794f76848a169c359	Voyager	37.7750167318842571	-122.4468236520391
1318	2019-05-27 06:36:59	2019-05-27	Caryn Ziemann	caryn.ziemann@geemail.com	San Francisco	California	503860178100172	763539937664a71f196b75e691a3060f	Mastercard	37.7555506237051191	-122.415599239021063
1319	2019-05-27 07:17:58	2019-05-27	Orlando Toy	orlando.toy@woohoo.com	Philadelphia	Pennsylvania	3112515414847720589	2f8dee409e3378ca4125ef2a3ad9547c	VISA 16 digit	40.0505274632439026	-75.1580775525320348
1320	2019-05-27 07:24:35	2019-05-27	Celina Jakubowski	celina.jakubowski@warmmail.com	San Francisco	California	4558502054661708	d754590f14c6ef353b9ef3238633db22	Diners Club / Carte Blanche	37.7883370080737819	-122.450412900153609
1321	2019-05-27 09:46:57	2019-05-27	Torrie Lynch	torrie.lynch@geemail.com	San Francisco	California	4922083503727	58bf67ea6d0ad5899eee59cabf4e68cc	JCB 16 digit	37.7788844094128393	-122.446651137585917
1322	2019-05-27 17:26:31	2019-05-27	Freda Casper	freda.casper@geemail.com	Oakland	California	3462495859529197	69f0465c58f350cfd262864ef368ccc5	Maestro	37.8072953790913076	-122.288838707382027
1323	2019-05-27 20:52:02	2019-05-27	Llewellyn Dickens	llewellyn.dickens@woohoo.com	Oakland	California	4186790918467	42da40d7145821c985ecd3ad1856d522	Mastercard	37.7781131106289152	-122.255166805916787
1324	2019-05-27 22:01:54	2019-05-27	Dr. Migdalia Barton	dr.migdalia.barton@geemail.com	New York	New York	869959754283842294	e3ba8217c3ae836245c108f1d376468e	Mastercard	40.5977669498641021	-73.9135505839146703
1325	2019-05-28 01:52:19	2019-05-28	Domingo Bosco	domingo.bosco@warmmail.com	Minneapolis	Minnesota	869971053923668464	9c776d5dc1d66b0b8ba63d3af6b9e682	Mastercard	44.9833190446805204	-93.3015022898830466
1326	2019-05-28 02:44:46	2019-05-28	Mrs. Cadence Koelpin DDS	mrs.cadence.koelpin.dds@warmmail.com	San Francisco	California	4319619806314525	037d61a0aace14777743ac794bb516dd	Mastercard	37.7675710440293457	-122.437591128604751
1327	2019-05-28 03:59:11	2019-05-28	Donal Swaniawski	donal.swaniawski@geemail.com	San Francisco	California	869949282840082397	1ee971501409764ae366c7fabbcb8445	Maestro	37.7713294453022144	-122.404148085177624
1328	2019-05-28 08:41:50	2019-05-28	Seymour Friesen	seymour.friesen@warmmail.com	San Francisco	California	3337984375341461909	a7d2aa1816632aacf411e7eb150bf5a0	JCB 16 digit	37.7944791859750069	-122.411940030328893
1329	2019-05-28 09:22:17	2019-05-28	Miss Addison Larson MD	miss.addison.larson.md@woohoo.com	San Francisco	California	4505689243457	c73ef18af479d5b4bf450f86ced896ea	American Express	37.8057265269127569	-122.41708674901507
1330	2019-05-28 10:00:53	2019-05-28	Raina Torp PhD	raina.torp.phd@geemail.com	San Francisco	California	180008245517994052	8b9f28b9ec1f71b68569d3004d5d7e77	VISA 16 digit	37.7756909906554128	-122.403812084500785
1331	2019-05-28 15:46:27	2019-05-28	Dr. Sammie Mayert I	dr.sammie.mayert.i@geemail.com	San Francisco	California	4538950619261	cc22aafa4d37d4ee28b4d34fe6695b14	Discover	37.7565235600996587	-122.407187274794254
1332	2019-05-28 16:07:18	2019-05-28	Angella Metz	angella.metz@geemail.com	San Francisco	California	3000725268115203	bf3eaa439aa23127d38617d096634eca	VISA 13 digit	37.7769988558244236	-122.426394139840411
1333	2019-05-28 17:59:45	2019-05-28	Admiral Mann	admiral.mann@geemail.com	Winston–Salem	North Carolina	3029220479789914	7fe3aa756fdbeb9077273b4f60ee1982	VISA 16 digit	36.0527089347828138	-80.2219692394267696
1334	2019-05-28 20:04:43	2019-05-28	Justice Ankunding-Bergnaum	justice.ankunding.bergnaum@geemail.com	San Francisco	California	639001662464484	f1bd26f4af918963051458c195dee649	American Express	37.8197316063598876	-122.417392257405538
1335	2019-05-29 01:19:13	2019-05-29	Cap Collier	cap.collier@woohoo.com	Berkeley	California	3096843715930650811	534c78072efb97d3a9261ecc4c91ec1c	Maestro	37.8285354873593818	-122.270320188316873
1336	2019-05-29 06:20:30	2019-05-29	Nelle Koepp	nelle.koepp@geemail.com	San Francisco	California	869911252666603349	bbe03a2b3afe172395126e6b637ad6b6	VISA 16 digit	37.7732221592305706	-122.448354546413626
1337	2019-05-29 10:54:43	2019-05-29	Lurline Wolf	lurline.wolf@geemail.com	Oakland	California	3028054698576955	ed9d1f93ce97dbee3d90118541c9b793	Mastercard	37.7815142683725824	-122.278224216687846
1338	2019-05-29 10:59:49	2019-05-29	Corey Dicki	corey.dicki@geemail.com	Oakland	California	3112231243604701901	471f693879588ba3115c3d97fffa09b8	VISA 16 digit	37.8113495782706508	-122.271840479380998
1339	2019-05-29 11:41:55	2019-05-29	Porter Kuhic MD	porter.kuhic.md@geemail.com	Saint Paul	Minnesota	676345783634566	fe920980edb91ded7369f5776f853375	Diners Club / Carte Blanche	44.9605437502671066	-93.1739176648467833
1340	2019-05-29 16:17:46	2019-05-29	Cornel Sporer	cornel.sporer@geemail.com	Nashville	Tennessee	4350414015045080	90e0223d3e780de1eeea4ec2e84f71ff	Discover	36.077936150890956	-86.7603980466164586
1341	2019-05-29 17:47:13	2019-05-29	Mr. Carlie Hand	mr.carlie.hand@warmmail.com	San Francisco	California	4580722310944	03f81edf0a795078ec27f3a7a46841a0	Voyager	37.7819040546500844	-122.44246180636587
1342	2019-05-29 18:19:17	2019-05-29	Nehemiah Erdman	nehemiah.erdman@woohoo.com	San Francisco	California	676268316404562	506566fb4a4040881dabd9ca1fdc2d1c	American Express	37.761397461218138	-122.459197975739087
1343	2019-05-29 20:47:55	2019-05-29	Dr. Laquan Swaniawski	dr.laquan.swaniawski@geemail.com	San Francisco	California	4396281871311	b1d4019520bf31cf40c303e4ff987b53	Mastercard	37.7345529320258208	-122.420020560727991
1344	2019-05-29 23:20:02	2019-05-29	Otis Yundt-Schmitt	otis.yundt.schmitt@geemail.com	San Francisco	California	210019981905288049	6ef81ab1789df3e1fa404aefdb147002	American Express	37.7987142112369483	-122.410844514898884
1345	2019-05-30 00:43:14	2019-05-30	Miss Sherita Weber	miss.sherita.weber@geemail.com	San Francisco	California	869952480270300008	faafc04de8e5d224286e148fa7ff33b0	Mastercard	37.7990800446996573	-122.442100592489879
1346	2019-05-30 02:05:03	2019-05-30	Drema Wunsch	drema.wunsch@geemail.com	New York	New York	869989423631974134	47af34cc40f0c0878b47178241710416	VISA 13 digit	40.7099971060398929	-73.9303098354384218
1347	2019-05-30 06:51:05	2019-05-30	Nell Schultz	nell.schultz@geemail.com	San Francisco	California	3112431032898448214	f5554969190f961694d94b30cfe23f1c	VISA 16 digit	37.7490792393528238	-122.425978254754796
1348	2019-05-30 08:01:14	2019-05-30	Dr. Stephanie Luettgen	dr.stephanie.luettgen@geemail.com	Winston–Salem	North Carolina	3010307219135588	ddb8f7c20fd8754a1114a95d5da275ab	Voyager	36.0035632523473339	-80.3198846614584312
1349	2019-05-30 12:30:13	2019-05-30	Orren Hammes	orren.hammes@geemail.com	San Francisco	California	3792510827008845	b084935ccf6d98a851ecc8a9f74fe16e	Diners Club / Carte Blanche	37.7365217748303223	-122.449010839401339
1350	2019-05-30 14:27:10	2019-05-30	Jerri Ward	jerri.ward@geemail.com	San Francisco	California	3765374645211278	77953eab5a67577950a417eb333a664c	VISA 13 digit	37.8118711229511462	-122.398359053760217
1351	2019-05-30 19:30:05	2019-05-30	Cassidy Gutmann	cassidy.gutmann@warmmail.com	Berkeley	California	869904171010880479	49967a15a3005eb12b25eabbef022065	Voyager	37.8713159981736638	-122.273236838727726
1352	2019-05-30 20:19:25	2019-05-30	Simon Buckridge	simon.buckridge@geemail.com	Oakland	California	3021524490158910	3976cbaadb5b27e7e905c7cc04c8d5a9	JCB 16 digit	37.8203872721308869	-122.298892786994898
1353	2019-05-30 20:25:46	2019-05-30	Dana Larkin V	dana.larkin.v@geemail.com	San Francisco	California	4275731852834	4c634590ec8d8d8996174c4566b51c72	American Express	37.7820837000113201	-122.410947229896323
1354	2019-05-30 23:11:43	2019-05-30	Arley Leffler-Barton	arley.leffler.barton@geemail.com	San Francisco	California	3795601676533756	33d59ea5ea4e1aa5da4ea94447e4c45a	VISA 16 digit	37.7754829747136753	-122.412083964249163
1355	2019-05-31 03:12:38	2019-05-31	Georgeanna Cassin	georgeanna.cassin@geemail.com	Coral Springs	Florida	6011024794066945106	77fdffe0f147a3612a462afe99658a4a	Voyager	26.2463931015755989	-80.3150937675621321
1356	2019-05-31 04:00:37	2019-05-31	Mr. Mathew Wisoky	mr.mathew.wisoky@geemail.com	San Francisco	California	210026623454192203	d651f7292ce3f4c9f9f7f9ab3a20f0df	Voyager	37.7394710768686608	-122.411190661222776
1357	2019-05-31 07:59:13	2019-05-31	Holland Shanahan	holland.shanahan@geemail.com	Berkeley	California	3096265144124036878	de7710ea830ee4f4ca9d480c419b0a5a	Voyager	37.8600419838799951	-122.259596945324006
1358	2019-05-31 09:07:11	2019-05-31	Katheryn Morissette	katheryn.morissette@geemail.com	San Francisco	California	4227104373186029	221f0b59de570c55fb9b82e6039a810b	American Express	37.7802780251355657	-122.447592144578749
1359	2019-05-31 09:24:51	2019-05-31	Lex Littel	lex.littel@geemail.com	San Francisco	California	6011479734635262971	7e8e560a58c6682e27a1cf7fdce3ecf0	JCB 15 digit	37.7718211117154254	-122.446423215110059
1360	2019-05-31 10:21:48	2019-05-31	Amari Hoppe	amari.hoppe@geemail.com	Oakland	California	3158384256429946928	50fac094d3a9793b3366b57399f6d905	American Express	37.8252839633523266	-122.273550501890483
1361	2019-05-31 13:12:11	2019-05-31	Mrs. Birdella Ondricka	mrs.birdella.ondricka@geemail.com	San Francisco	California	4054891870922	25d38ebf742eef25e0eba80a117ad380	Diners Club / Carte Blanche	37.7839063621171363	-122.433681604332563
1362	2019-05-31 16:04:32	2019-05-31	Ramsey Mohr	ramsey.mohr@geemail.com	Sacramento	California	51491803656231530	bc057748b7f75ae000620e04813351ef	Diners Club / Carte Blanche	38.6526830227378753	-121.517968643201883
1363	2019-05-31 17:40:03	2019-05-31	Gerardo Von	gerardo.von@woohoo.com	San Francisco	California	4087195310364785	c7546a2c244e902ea28ec18edaec69aa	Diners Club / Carte Blanche	37.8110216065699163	-122.433734493119729
1364	2019-05-31 18:38:05	2019-05-31	Aryan Rolfson II	aryan.rolfson.ii@warmmail.com	San Francisco	California	3759201417128935	eb7ac40bcdbdba67ba9da810159bef72	Voyager	37.7813161592144482	-122.450814255856201
1365	2019-05-31 19:47:05	2019-05-31	Darien Fisher	darien.fisher@geemail.com	Oakland	California	4215254719110672	ed98a2f0720dd2b8105e543f48344e27	VISA 16 digit	37.8079523357828577	-122.25737022122442
1366	2019-05-31 20:03:56	2019-05-31	Phyliss Rowe-Paucek	phyliss.rowe.paucek@geemail.com	San Francisco	California	4658979774899975	68551db5e994724100a3979d59824ec9	American Express	37.7769327680641638	-122.387687994629104
1367	2019-05-31 21:51:54	2019-05-31	Squire Hodkiewicz	squire.hodkiewicz@woohoo.com	San Francisco	California	4163589878766398	3cfeb01c26a867d9bb4c4519785a8d5d	American Express	37.7735222905031733	-122.379066310623443
1368	2019-06-01 02:15:37	2019-06-01	Oma Cole	oma.cole@woohoo.com	San Francisco	California	869974860843745215	fcb9da06685468c846575ce661a66999	Mastercard	37.7585120030923207	-122.464214975390362
1369	2019-06-01 03:31:44	2019-06-01	Stafford Halvorson-Effertz	stafford.halvorson.effertz@geemail.com	San Francisco	California	675963237589112	a6cfb1fb9876c195847a6618a419940a	Discover	37.7942100473277023	-122.411012960115883
1370	2019-06-01 04:16:34	2019-06-01	Hollie Haag	hollie.haag@geemail.com	San Francisco	California	3735051273748295	706fd7bd34dc89f53788f9b223e2e053	Maestro	37.7594811481171462	-122.41165595636393
1371	2019-06-01 04:59:47	2019-06-01	Dr. Robbie Marquardt I	dr.robbie.marquardt.i@warmmail.com	San Francisco	California	52013215840010986	1f704d6c503bd89c082f5494ccbb2093	VISA 13 digit	37.7986605965858686	-122.421916415418124
1372	2019-06-01 08:00:21	2019-06-01	Rodger Jast-Botsford	rodger.jast.botsford@geemail.com	Berkeley	California	4850032786657	bca4bbf73409ba15625a4a6c053d4201	VISA 16 digit	37.8666186921340042	-122.303026186369294
1373	2019-06-01 09:10:54	2019-06-01	Miss Patricia Johnston MD	miss.patricia.johnston.md@geemail.com	San Francisco	California	869919961095235729	33af4f07678be225fa654999c58b7cd6	Voyager	37.7990412137041005	-122.462732221113399
1374	2019-06-01 11:11:35	2019-06-01	Bethann Konopelski	bethann.konopelski@geemail.com	San Francisco	California	869995167028018888	40f8e63f2df2c73f0ddaad7e6da4a850	Diners Club / Carte Blanche	37.7645492109385117	-122.444902733102879
1375	2019-06-01 12:16:41	2019-06-01	Yoshiko Marks	yoshiko.marks@geemail.com	San Francisco	California	210025180127278654	2fc9f44e9f6e99b7fe8cf9eb0f1f9fef	Voyager	37.7731625830700182	-122.424737592831065
1376	2019-06-01 14:17:42	2019-06-01	Ana Lueilwitz	ana.lueilwitz@woohoo.com	San Francisco	California	503809035123893	7b001b5be85fc1ea12ba1fa1cada73ec	JCB 15 digit	37.7955959970931374	-122.435792234791535
1377	2019-06-01 17:01:05	2019-06-01	Dr. Henri Bins Sr.	dr.henri.bins.sr.@warmmail.com	Dallas	Texas	4259448672514311	39ae75ec244c5898b38072839f26a5e3	Maestro	32.6994555399093798	-96.6976709722969616
1378	2019-06-01 18:32:54	2019-06-01	Lois Beatty	lois.beatty@geemail.com	Montgomery	Alabama	3055799915520334	1606b197659773b4f02950370a491c69	JCB 16 digit	32.2506286507870996	-86.3163080648671723
1379	2019-06-01 20:16:26	2019-06-01	Ms. Cilla Hartmann	ms.cilla.hartmann@geemail.com	San Francisco	California	869956326001225863	b3c4cb2aed036c20a02fa4f922a7d60c	VISA 13 digit	37.7525193832466783	-122.44966521066705
1380	2019-06-02 00:24:19	2019-06-02	Miss Mariela Kuphal PhD	miss.mariela.kuphal.phd@geemail.com	St. Petersburg	Florida	53174130661804323	0944892b10db397af71f471ea7395204	Voyager	27.7977543379534033	-82.6434885396979695
1381	2019-06-02 01:01:58	2019-06-02	Mrs. Tamala Pollich	mrs.tamala.pollich@woohoo.com	Berkeley	California	210029194240246551	81e1945c4818f8c29c14843860e259a5	Discover	37.8935061172853267	-122.264359423499755
1382	2019-06-02 02:58:04	2019-06-02	Almon Gutmann	almon.gutmann@geemail.com	San Francisco	California	869969429901473412	ab25991913d936dc4f52f1130675d70f	Voyager	37.7471517133466747	-122.407989489176046
1383	2019-06-02 04:19:30	2019-06-02	Alyson Collier	alyson.collier@geemail.com	San Francisco	California	4153312817973	08be157edfd2073aff89227a6e17bd4e	Maestro	37.7869909752574173	-122.428808103695488
1384	2019-06-02 06:57:03	2019-06-02	Terell McCullough	terell.mccullough@geemail.com	Oakland	California	676333666003448	12d4b1c1a97758569e704bdf0eae4448	Maestro	37.7855318503749373	-122.251071015215857
1385	2019-06-02 07:23:24	2019-06-02	Miss Kaiya Spencer	miss.kaiya.spencer@geemail.com	Berkeley	California	3088764983539970031	838447d9446f5719a0eb0bc670178eba	Maestro	37.8709841516143655	-122.277787074650846
1386	2019-06-02 08:24:43	2019-06-02	Dr. Rory Lehner	dr.rory.lehner@geemail.com	San Francisco	California	3088483411458091217	23b537d3d78948cfce8e6469c847e3be	VISA 16 digit	37.7691843721855136	-122.430053493734292
1387	2019-06-02 11:40:12	2019-06-02	Marlon Legros	marlon.legros@warmmail.com	San Francisco	California	3158946392535740805	70df73e6dd7f0e10108ca5ec9181db2c	JCB 16 digit	37.7889133368209116	-122.443369345564946
1388	2019-06-02 13:30:20	2019-06-02	Tella Howell PhD	tella.howell.phd@geemail.com	Berkeley	California	52449780727953388	da67e17ced9a8e3bc741c6ab6eab576a	Mastercard	37.8751940119953829	-122.292285813280643
1389	2019-06-02 18:10:23	2019-06-02	Ilene Tromp PhD	ilene.tromp.phd@geemail.com	Oakland	California	3029455299681715	754f0e78fe34c1dbf5829fcbfa1a1e5a	Diners Club / Carte Blanche	37.811105735131747	-122.272667292930294
1390	2019-06-02 18:50:01	2019-06-02	Mr. Ferman Goldner Jr.	mr.ferman.goldner.jr.@geemail.com	San Francisco	California	3036720007868448	ad1ec70d9ab4beb762f34df352ff843e	Voyager	37.7988304445436611	-122.456812255658264
1391	2019-06-02 20:29:22	2019-06-02	Lucretia Turner	lucretia.turner@geemail.com	Atlanta	Georgia	180063940298472870	94e228776a17efc6ac6406bdb7ae873f	JCB 16 digit	33.6852955960944342	-84.3662807121917666
1392	2019-06-02 21:54:36	2019-06-02	Elvie Wilderman	elvie.wilderman@geemail.com	San Francisco	California	180098644947321236	ee62f894082557931711fb06bde72807	Diners Club / Carte Blanche	37.7624449988748481	-122.422311125337316
1393	2019-06-03 01:59:48	2019-06-03	Russel Willms III	russel.willms.iii@warmmail.com	College Station	Texas	6011517409867306374	b0e7b05541259537a8c97d0700abc7ec	Maestro	30.6148789067331712	-96.289795520700153
1394	2019-06-03 04:44:23	2019-06-03	Mr. Geno Johns	mr.geno.johns@geemail.com	San Francisco	California	3088415747182716469	583477cdc2257279cc7f51d02e9d1007	Mastercard	37.7520364320580697	-122.401382176877249
1395	2019-06-03 05:59:55	2019-06-03	India Botsford-Abshire	india.botsford.abshire@warmmail.com	Los Angeles	California	180082548120782791	e57dcc9185600acdf01bf9e73462fefa	VISA 16 digit	33.9487666705023443	-118.36945604733117
1396	2019-06-03 06:39:54	2019-06-03	Dr. Evelin Kilback	dr.evelin.kilback@geemail.com	San Francisco	California	6011725613674825751	9e8d4da61043ec0f56c4ea2290094202	JCB 16 digit	37.7995007321133443	-122.413899265746664
1397	2019-06-03 11:13:17	2019-06-03	Dr. Dempsey Ondricka I	dr.dempsey.ondricka.i@woohoo.com	San Francisco	California	4869318819183514	cadc3f5937363b9351318e5771ebf2a6	JCB 16 digit	37.7925934191061046	-122.450339178441098
1398	2019-06-03 12:02:05	2019-06-03	Miss Emily Beier	miss.emily.beier@woohoo.com	Berkeley	California	3112989943134478078	fc60428c917d1fb08f889f0e30c0de5f	VISA 13 digit	37.879671751941423	-122.265962272468229
1399	2019-06-03 15:06:05	2019-06-03	Odell Rutherford-Mills	odell.rutherford.mills@woohoo.com	Oakland	California	3096240612263004543	c1166b2cb7473a1e530156c58ebe1ea3	Diners Club / Carte Blanche	37.8022050472669306	-122.229508151899779
1400	2019-06-03 17:31:02	2019-06-03	Knox Cronin	knox.cronin@warmmail.com	San Francisco	California	3337778194694080681	bc54ef01ffbdc13d7423b2c6ce0120c0	VISA 16 digit	37.7664538416276443	-122.429543378235522
1401	2019-06-03 19:12:15	2019-06-03	Dr. Delmas Haag	dr.delmas.haag@geemail.com	San Francisco	California	3030242870003942	f16d45dbed1472677db643629532dcd3	JCB 16 digit	37.7827120216016326	-122.40779591248743
1402	2019-06-03 20:24:14	2019-06-03	Skylar Conroy	skylar.conroy@geemail.com	San Francisco	California	4227551621765	b91aadb7c9c070976e81b1677f909d97	Mastercard	37.8065124947369569	-122.433262518600245
1403	2019-06-03 21:41:55	2019-06-03	Duane Anderson	duane.anderson@warmmail.com	Oakland	California	639032086956276	ea210469eaf423134ef3b520bf398b50	Mastercard	37.7935141034583282	-122.266840561064512
1404	2019-06-03 23:24:14	2019-06-03	Mr. Shelley Kunze	mr.shelley.kunze@warmmail.com	San Francisco	California	3088136867070383582	984e591f372469eb1a3d39019d5f0480	VISA 16 digit	37.7448672318656975	-122.440672640553245
1405	2019-06-04 02:23:31	2019-06-04	Rianna West	rianna.west@geemail.com	Oakland	California	3158320710041157907	427831758f7ac8ae5ceb71c9343f775a	JCB 16 digit	37.7967137673076436	-122.292224090996541
1406	2019-06-04 03:22:50	2019-06-04	Alyssia Rosenbaum-Hickle	alyssia.rosenbaum.hickle@woohoo.com	San Francisco	California	3158012372401171169	77dbac8c0debe11b099e936b389cd5cc	Discover	37.7969403523552216	-122.440582167964564
1407	2019-06-04 08:16:09	2019-06-04	Adrian Padberg	adrian.padberg@geemail.com	San Francisco	California	55225988542984377	896fadbd802ca3039b175bf48ddf7eb7	Discover	37.7677253453075039	-122.44297712396083
1408	2019-06-04 12:50:27	2019-06-04	Ms. Audie Bruen	ms.audie.bruen@geemail.com	San Francisco	California	4126677014624732	0ce46c3518145d02a6f9266b5e93d46a	VISA 16 digit	37.7687629509699008	-122.445972182429102
1409	2019-06-04 13:05:52	2019-06-04	Jamiya Terry	jamiya.terry@geemail.com	Berkeley	California	4754018137038741	ebf26e546cd1588c70deeb8cc0a067da	JCB 16 digit	37.8500885742555369	-122.274335661503272
1410	2019-06-04 19:52:49	2019-06-04	Lue Collins	lue.collins@woohoo.com	Little Rock	Arkansas	210073673955682154	8ca71f806dbf80ddaa7008726196b762	Discover	34.687519554542007	-92.3651272836014527
1411	2019-06-04 19:58:36	2019-06-04	Jaime Kozey	jaime.kozey@woohoo.com	San Francisco	California	3728605404555272	85c4c9128b4af9bee3bd162e0ebe07de	American Express	37.7706614686476883	-122.440649552377707
1412	2019-06-04 20:04:26	2019-06-04	Dionicio Stroman	dionicio.stroman@geemail.com	Washington	District of Columbia	3096605227618135816	5a5ad54ec2b7b5a13f1f437608025432	Diners Club / Carte Blanche	38.895226089636239	-76.9459003081757658
1413	2019-06-04 20:34:46	2019-06-04	Twyla Hodkiewicz	twyla.hodkiewicz@geemail.com	San Francisco	California	6011284049693780839	63649194bb16ed4bff6e035626832b53	American Express	37.7663138663601643	-122.413318317996442
1414	2019-06-04 21:43:38	2019-06-04	Rinda Kris-Quitzon	rinda.kris.quitzon@geemail.com	Berkeley	California	6011226192520570840	94d581a6b7dfa13387349fec45845d69	JCB 16 digit	37.9034125349030973	-122.292826956320269
1415	2019-06-04 23:36:58	2019-06-04	Delvin Walsh	delvin.walsh@geemail.com	San Francisco	California	4313189763517987	a8752aa301ae935cec745d7169052ebf	Discover	37.7536076279841453	-122.467074760723619
1416	2019-06-05 00:37:13	2019-06-05	Zaida Murphy DDS	zaida.murphy.dds@woohoo.com	New York	New York	4977788818028	dccbaf0ed2bf8534965283bce9f815f1	JCB 15 digit	40.6444073446318512	-73.8949061758246302
1417	2019-06-05 01:40:57	2019-06-05	Jase Brown-Will	jase.brown.will@geemail.com	San Francisco	California	53339376814161713	82b04dbb41ec3e2f3b96e266746b6601	American Express	37.8127740694234333	-122.440542633908308
1418	2019-06-05 02:30:05	2019-06-05	Miss Coletta Spinka MD	miss.coletta.spinka.md@warmmail.com	San Francisco	California	869941713017478040	c6b68235c8f4c5ce6f92e4809ad62ec3	Voyager	37.7767576228790531	-122.420094465735517
1419	2019-06-05 04:10:34	2019-06-05	Metha Gottlieb-Lang	metha.gottlieb.lang@woohoo.com	San Francisco	California	4032604766559612	b5fc9d7c91504ec6db2ac5f80152cfc1	JCB 15 digit	37.7768746828692414	-122.450925207659552
1420	2019-06-05 06:12:58	2019-06-05	Arietta Howell	arietta.howell@geemail.com	Anaheim	California	869958164643173607	1f16eecc36462b06d0119c4d9f3d3242	VISA 16 digit	33.8138649702370131	-117.749199121512845
1421	2019-06-05 08:58:16	2019-06-05	Mr. Gaither Zemlak	mr.gaither.zemlak@geemail.com	San Francisco	California	3158469442201339916	3295444e957265c3efe40ac64e68774f	VISA 16 digit	37.7546576320392546	-122.394361361641757
1422	2019-06-05 11:19:23	2019-06-05	Cordell Toy	cordell.toy@geemail.com	San Francisco	California	502007382074214	1671511dc7c39ee521249cb0ff8e0abb	JCB 16 digit	37.7459426535485889	-122.387837593666973
1423	2019-06-05 12:17:07	2019-06-05	Carisa Zulauf	carisa.zulauf@woohoo.com	Oakland	California	6011444130434415195	1a1b2bb4b726e9e7046324190166a283	JCB 16 digit	37.8006174888131383	-122.273029744260924
1424	2019-06-05 14:21:22	2019-06-05	Nicholas McDermott	nicholas.mcdermott@geemail.com	San Francisco	California	3528463501094553960	c85a5ef50f73dfa1ab2888e585e04be6	VISA 16 digit	37.7718889674277918	-122.432894451321999
1425	2019-06-05 17:44:04	2019-06-05	Dr. Thornton Quitzon	dr.thornton.quitzon@geemail.com	Oakland	California	4568159531472601	0726f1bc05f0efb45e82fc1a8e6dfcb2	Maestro	37.7984845885434524	-122.266283302862803
1426	2019-06-05 20:44:04	2019-06-05	Jayce Dare I	jayce.dare.i@geemail.com	San Francisco	California	3735311016907198	4e29fce423dc93acfc21ab7288444dda	Voyager	37.7581242156961565	-122.423127240926291
1427	2019-06-06 02:35:55	2019-06-06	Ms. Billye Champlin	ms.billye.champlin@woohoo.com	San Francisco	California	3718658735990801	3eed67c57ac38dfed7fc1ce6ad6802f6	JCB 16 digit	37.7637315888149558	-122.414478433505849
1428	2019-06-06 04:58:35	2019-06-06	Godfrey Schoen	godfrey.schoen@woohoo.com	Oakland	California	3048357178551533	840e66098f508282624b4c7985c0ee9b	JCB 16 digit	37.8141925480861403	-122.289279281982928
1429	2019-06-06 05:48:39	2019-06-06	Danny Schultz	danny.schultz@geemail.com	San Francisco	California	501820839476874	ef0c62cfc4c424c439c5cc2c2cdf44d4	JCB 16 digit	37.7489823974601322	-122.397855937179344
1430	2019-06-06 06:50:59	2019-06-06	Mr. Aloysius Gutmann	mr.aloysius.gutmann@geemail.com	San Francisco	California	210014302694850524	30739928ed418dcb0d8232a8f045a84e	VISA 16 digit	37.8267823964129377	-122.434868414861853
1431	2019-06-06 12:43:19	2019-06-06	Greyson Berge	greyson.berge@geemail.com	San Francisco	California	4188907732964119	8401b951ae8bbff40bd967a45bccbcbf	Mastercard	37.7602051928875682	-122.419482835825647
1432	2019-06-06 19:00:01	2019-06-06	Dr. Wheeler Johnston	dr.wheeler.johnston@geemail.com	Oakland	California	3088203639142540368	72ac525285deb8072215eb06dfae416e	JCB 16 digit	37.7899100271812713	-122.258131427237117
1433	2019-06-06 19:58:43	2019-06-06	Rosemarie Bernier DVM	rosemarie.bernier.dvm@geemail.com	Boulder	Colorado	3528698534406500830	a682fc95780a768bfd59fcd4199661ef	JCB 15 digit	40.0635956613793951	-105.285358313625309
1434	2019-06-06 20:39:46	2019-06-06	Lisha Keebler PhD	lisha.keebler.phd@geemail.com	Oakland	California	3430209847106078	e99c8b32b4dd55cb33d5cf4023728e20	JCB 16 digit	37.7892103163034392	-122.308662061082515
1435	2019-06-06 21:05:27	2019-06-06	Ms. Kadence Huels PhD	ms.kadence.huels.phd@geemail.com	San Francisco	California	4622588806179133	ae6c87aabf2b41d8c6f312c3fb12a500	VISA 16 digit	37.7758464806628922	-122.441105926319963
1436	2019-06-06 23:23:49	2019-06-06	Dr. Abb Lubowitz	dr.abb.lubowitz@woohoo.com	Austin	Texas	4676294966897	36005bfd6b18e0ecb63585fd177e5da0	Mastercard	30.3928801894314589	-97.8117576313909183
1437	2019-06-06 23:48:12	2019-06-06	Sonya Emmerich DDS	sonya.emmerich.dds@geemail.com	San Francisco	California	3005174380352144	c0a6ce82706cfcbbd898102178ccbb86	VISA 16 digit	37.7687274020991453	-122.439510602743056
1438	2019-06-07 02:31:06	2019-06-07	Carlos Farrell	carlos.farrell@geemail.com	San Francisco	California	630445176879299	68d27c94901ec81aae07e70b4b3ebef9	VISA 13 digit	37.8034530575054575	-122.417031774933122
1439	2019-06-07 03:16:49	2019-06-07	Bristol Haag	bristol.haag@geemail.com	San Francisco	California	4614911018071403	b2ff90a7db83a23dd13233b5b7ca1594	VISA 16 digit	37.7686792439821275	-122.416335202881939
1440	2019-06-07 03:32:13	2019-06-07	Glenn Kerluke-Romaguera	glenn.kerluke.romaguera@geemail.com	Berkeley	California	869926965847062274	bd8ddd84767b167e3e39f22d40aff0e4	Discover	37.8938582039212548	-122.29140751687477
1441	2019-06-07 05:31:03	2019-06-07	Texanna Gutkowski	texanna.gutkowski@geemail.com	Berkeley	California	869929381625966891	b4dc4ecfc48ad4cdc7504cf1b0870b72	Discover	37.8964446107618684	-122.282666523006441
1442	2019-06-07 05:45:42	2019-06-07	Pedro Toy	pedro.toy@geemail.com	Berkeley	California	180037415854783138	d8b3aacfee030fbf998f8ce6320f1440	JCB 15 digit	37.8614632471141661	-122.298787150886199
1443	2019-06-07 08:32:32	2019-06-07	Fiona Koepp	fiona.koepp@woohoo.com	Chicago	Illinois	869940283367442484	91c478bfbeca9344a0a2f23f3d7d4e12	VISA 13 digit	41.7957591397989532	-87.692809596148507
1444	2019-06-07 09:25:41	2019-06-07	Mrs. Larue Rath	mrs.larue.rath@geemail.com	Salem	Oregon	4513758655671421	f99aa7b8372e8e3bad22b01064ecb535	Voyager	44.9040518443368342	-123.008000634300345
1445	2019-06-07 11:56:00	2019-06-07	Elwyn Beatty-Ullrich	elwyn.beatty.ullrich@geemail.com	Berkeley	California	4618689513058	a8b719300a126eb6d078c98a06ad0f05	JCB 16 digit	37.8936185515312474	-122.280162603671329
1446	2019-06-07 14:31:54	2019-06-07	Adelard Hane-Nikolaus	adelard.hane.nikolaus@geemail.com	San Francisco	California	55392704287221595	5880c5399c0c29ccdc1b8fc587395272	VISA 16 digit	37.7746822116159677	-122.44525693835439
1447	2019-06-07 15:10:04	2019-06-07	Semaj Mueller-Bernier	semaj.mueller.bernier@geemail.com	San Francisco	California	3043832171082780	f84edc02379a04d3cad981d238f06810	VISA 13 digit	37.7874932517299342	-122.478616679964063
1448	2019-06-07 19:49:49	2019-06-07	Jaxen Mohr	jaxen.mohr@geemail.com	San Francisco	California	4035886507959	15a5ce35268f2976deeaa163f10525c6	Discover	37.777644616393296	-122.436829006779902
1449	2019-06-07 21:04:17	2019-06-07	Orla Conn	orla.conn@geemail.com	San Francisco	California	869977464561039997	33f99866ed2f7717bf6f80763d3bdb6b	Discover	37.7548741534987613	-122.414962632173783
1450	2019-06-08 01:07:10	2019-06-08	Mrs. Tamela Abbott DVM	mrs.tamela.abbott.dvm@geemail.com	San Francisco	California	3447416155673257	72ccb2170fa37e3852af2a1ee62177b9	Voyager	37.7630271121667889	-122.418713111383141
1451	2019-06-08 01:07:45	2019-06-08	Hamza Schumm	hamza.schumm@woohoo.com	San Francisco	California	4878525247640142	2690e3a1f428277a89f157e60119e9c6	VISA 16 digit	37.7761692225114061	-122.421783155407866
1452	2019-06-08 02:01:36	2019-06-08	Braden Monahan	braden.monahan@geemail.com	San Francisco	California	4062688921547110	3c4f8d228e4bdd289ef124c7aa88f7af	VISA 16 digit	37.7624717778666721	-122.438583414284409
1453	2019-06-08 03:26:41	2019-06-08	Dr. Halley Hoeger MD	dr.halley.hoeger.md@warmmail.com	San Francisco	California	3337940930208010521	e0872ba8225224676c5a78a7d04c01bd	Diners Club / Carte Blanche	37.7788534722205753	-122.423508651664079
1454	2019-06-08 06:10:05	2019-06-08	Freddie Wilderman	freddie.wilderman@geemail.com	Berkeley	California	501874478261642	91f3db667c477eb0fa3e7c0612790109	Discover	37.8808404690791107	-122.264702844366028
1455	2019-06-08 07:00:29	2019-06-08	Rylan Douglas Jr.	rylan.douglas.jr.@woohoo.com	San Francisco	California	4002671376825127	1d2af24ac3aa83c31155fdfb20d7d45c	American Express	37.7673516545467294	-122.460302944374476
1456	2019-06-08 08:48:10	2019-06-08	Hilton Kerluke	hilton.kerluke@geemail.com	San Francisco	California	3456423994824404	138dd436c2070e3f526001b4caee1558	VISA 13 digit	37.7646438429767883	-122.435815502461082
1457	2019-06-08 10:53:24	2019-06-08	Elmina Koepp	elmina.koepp@woohoo.com	Stockton	California	4490591110611642	5f2c5554e8c63cdc5a49103114d3b4e4	American Express	37.9057987911358509	-121.383678608210005
1458	2019-06-08 11:49:21	2019-06-08	Mrs. Dorris Davis DVM	mrs.dorris.davis.dvm@geemail.com	San Francisco	California	3780772577260703	7bd988ef4d6c9e8f4740c23378ad0752	Voyager	37.7770365147258573	-122.426134052687686
1459	2019-06-08 14:44:04	2019-06-08	Alberto Fay	alberto.fay@geemail.com	Los Angeles	California	869953390927696626	d7e52085feb44c99d7ed88cf675572cc	American Express	34.0413590707682019	-118.504323259041826
1460	2019-06-08 14:56:20	2019-06-08	Mr. Vaughn Bartell	mr.vaughn.bartell@geemail.com	San Francisco	California	4431095777858258	ab81245c142861a9f2510a5405c31ef8	JCB 16 digit	37.7540838077193186	-122.427295526183144
1461	2019-06-08 15:29:23	2019-06-08	Winthrop Rutherford	winthrop.rutherford@geemail.com	San Francisco	California	869962975105797052	e32a1801458afacca9daf52137ef614f	Mastercard	37.7568838477710784	-122.419561966730456
1462	2019-06-08 16:57:06	2019-06-08	Lynwood Upton-VonRueden	lynwood.upton.vonrueden@woohoo.com	San Francisco	California	3528307207107566466	d9a5a34b6881ac1e66cebdf7681da51f	VISA 13 digit	37.7688809805247203	-122.434856562818936
1463	2019-06-08 22:58:58	2019-06-08	Walker Nikolaus V	walker.nikolaus.v@geemail.com	San Francisco	California	4083636246493085	aec42a7799ceef66a9131180a4db6973	Mastercard	37.7798512961233541	-122.464777688860693
1464	2019-06-09 01:37:30	2019-06-09	Nellie Von MD	nellie.von.md@geemail.com	Berkeley	California	3088087390263585060	5ebe9fd0d47b4c99ca208f0f05d7531e	Diners Club / Carte Blanche	37.8744606428323252	-122.252496674127428
1465	2019-06-09 01:53:14	2019-06-09	Jordon Prosacco	jordon.prosacco@geemail.com	Oakland	California	869954809745098698	5e61a0b2a01c4fe1cb1e5aaf41a088f0	Voyager	37.7614946761001917	-122.271513534144418
1466	2019-06-09 06:00:08	2019-06-09	Jaylyn DuBuque	jaylyn.dubuque@geemail.com	Oakland	California	3088818790962464671	308cc2e60ab07f7066b16bd5fdfbe9f8	JCB 15 digit	37.8016699740643105	-122.268609704281374
1467	2019-06-09 08:17:15	2019-06-09	Violeta Mayer	violeta.mayer@warmmail.com	San Francisco	California	180004494922709176	592622263746fa5c9c6bbf7eec494055	American Express	37.7344761188877911	-122.418850232015529
1468	2019-06-09 09:59:26	2019-06-09	Ms. Dorathea Terry	ms.dorathea.terry@geemail.com	San Francisco	California	210034077781879596	20767f2dfb4737f03c145869ef3ef7ec	Diners Club / Carte Blanche	37.8115179485989046	-122.428797642246096
1469	2019-06-09 12:31:44	2019-06-09	Cedrick Turcotte-Renner	cedrick.turcotte.renner@geemail.com	San Francisco	California	4199234314201	c6ef415c054b6688f2d14aa0746dd64c	VISA 16 digit	37.7408155050846332	-122.445735100703374
1470	2019-06-09 17:32:58	2019-06-09	Lyric Howe	lyric.howe@geemail.com	San Francisco	California	869982659100544281	e104d691e144d8e7cafaa35e87a9e0ad	VISA 13 digit	37.8114848225974427	-122.458547396736833
1471	2019-06-09 18:30:30	2019-06-09	Dr. Margarett Larkin	dr.margarett.larkin@geemail.com	St. Louis	Missouri	4539792251028488	b4e0d5178167c48fd0aa95212a1e9021	VISA 16 digit	38.6095969896454392	-90.270276170922827
1472	2019-06-09 19:47:33	2019-06-09	Mrs. Shirleen Mueller	mrs.shirleen.mueller@geemail.com	San Francisco	California	210045326002078976	ef242aa499624edbf8421ece200f7263	Voyager	37.7400222707600363	-122.469732120509633
1473	2019-06-09 20:23:45	2019-06-09	Andrae Kutch	andrae.kutch@woohoo.com	Oakland	California	869950594243113561	711421cffb695fc589d8c5f64b1ab84d	Discover	37.8101488366237248	-122.256585621055308
1474	2019-06-09 21:02:32	2019-06-09	Jaron Luettgen	jaron.luettgen@geemail.com	Long Beach	California	54563633993963807	3f652d7699e1ba872fd4f4e8bfced205	VISA 16 digit	33.7378848565563558	-118.177830890116468
1475	2019-06-09 22:47:32	2019-06-09	Aydin Bosco-D'Amore	aydin.bosco.d'amore@geemail.com	San Francisco	California	4598349177306189	7d3f4b458869a3afc3e1160e271d9ec0	JCB 16 digit	37.767773178796638	-122.41073450971318
1476	2019-06-10 01:57:33	2019-06-10	Tawanda Sanford-Collier	tawanda.sanford.collier@geemail.com	San Francisco	California	3039017081567914	38454a90409c579ac8279663c16a772d	Discover	37.7860454766456471	-122.413372195562104
1477	2019-06-10 05:09:25	2019-06-10	Mr. Spencer Zieme I	mr.spencer.zieme.i@geemail.com	San Francisco	California	4380814491064139	9f82232d100e5ffea1bdb270f5cab86c	Maestro	37.7912113367949516	-122.431614506952499
1478	2019-06-10 05:50:27	2019-06-10	Miss Ireland Weber PhD	miss.ireland.weber.phd@geemail.com	San Francisco	California	4572634755147430	9c1cc5ae6c6346c776d24ae1cdcc0fcc	JCB 15 digit	37.7701183237384583	-122.410780319076025
1479	2019-06-10 05:55:16	2019-06-10	Dr. Ottis Klein DVM	dr.ottis.klein.dvm@geemail.com	Bridgeport	Connecticut	3445343477504337	7434177abf9fbcdde086765f113ae4a7	Maestro	41.2729790282133919	-73.2167494498092708
1480	2019-06-10 07:55:11	2019-06-10	Aarav Hettinger	aarav.hettinger@geemail.com	San Francisco	California	869921502056235336	9b8ebcc2b64c4e72e75c63be738de1b9	Discover	37.8017963398762902	-122.422122378576162
1481	2019-06-10 10:05:36	2019-06-10	Laney Rippin	laney.rippin@woohoo.com	Oakland	California	4677396736330022	d46c4b2e566e01483190a4154e218672	VISA 13 digit	37.8164040444102909	-122.256109114658926
1482	2019-06-10 11:13:06	2019-06-10	Adelia Russel	adelia.russel@geemail.com	San Francisco	California	3528274553582406556	1ca69a171f172c145c0c2f6cbf6a0d85	VISA 16 digit	37.7427655197387395	-122.434011121675283
1483	2019-06-10 19:25:30	2019-06-10	Tony Gibson	tony.gibson@geemail.com	Denver	Colorado	3096248255697898064	4f400a4c4625f14b4640ca0aef20a3bf	Maestro	39.7574151355359646	-104.808393501049281
1484	2019-06-10 19:38:04	2019-06-10	Katlynn Ziemann	katlynn.ziemann@woohoo.com	San Francisco	California	3419447351246014	caf176833b70ea278d10841f4592fe05	VISA 16 digit	37.7871640109755447	-122.44587089953653
1485	2019-06-10 20:28:44	2019-06-10	Kayleigh McGlynn	kayleigh.mcglynn@geemail.com	San Francisco	California	52304918378633586	e1c46e4af73771d18d0a7f8b454718f6	JCB 16 digit	37.7579753395479116	-122.452572778135291
1486	2019-06-10 21:38:52	2019-06-10	Clotilde Skiles	clotilde.skiles@geemail.com	Oakland	California	869968809049492732	a9e42c8737520e77255d9d7df0418875	JCB 15 digit	37.8002630712175929	-122.300419096890622
1487	2019-06-11 01:31:45	2019-06-11	Mr. Alva Mayer Sr.	mr.alva.mayer.sr.@woohoo.com	Oakland	California	869984212570283838	bf98ab6d266193c85888a54c298767f3	Diners Club / Carte Blanche	37.8463255190755063	-122.263228503673943
1488	2019-06-11 02:14:20	2019-06-11	Herschel McDermott	herschel.mcdermott@warmmail.com	San Francisco	California	869956416349042706	87bac3cd2ce7004515d4ba1c1b26b603	American Express	37.7612515744416513	-122.41971143916227
1489	2019-06-11 02:51:34	2019-06-11	Wilmer Rau	wilmer.rau@warmmail.com	San Francisco	California	3158311863768636537	dea2e6091976ddb92d5b3ffaed27cd56	JCB 15 digit	37.7436094027521776	-122.429289633206068
1490	2019-06-11 02:56:50	2019-06-11	Dr. Jayce Rosenbaum	dr.jayce.rosenbaum@geemail.com	San Francisco	California	3158766015275081216	5b0ccfa281aadb958710bddeacf67f18	Voyager	37.7723950272648139	-122.470606228236747
1491	2019-06-11 08:21:32	2019-06-11	Rosaline Bailey	rosaline.bailey@geemail.com	San Francisco	California	3409931568532219	c4935d5002191b8233de6e3989233ca2	JCB 15 digit	37.766088140839436	-122.388567702173745
1492	2019-06-11 10:39:19	2019-06-11	Miss Lindy Schneider	miss.lindy.schneider@woohoo.com	San Francisco	California	4995129142863335	d6ff20bc8aa0eba1405f8e391bfa9b43	Maestro	37.7993264077170892	-122.432121412964733
1493	2019-06-11 13:01:39	2019-06-11	Ms. Maritza King PhD	ms.maritza.king.phd@geemail.com	San Francisco	California	3038744867270162	0d2ce8b5b8aa8ca98ae245b77457f029	VISA 16 digit	37.7697039533926713	-122.396375338995341
1494	2019-06-11 13:58:25	2019-06-11	Alva Friesen-Schroeder	alva.friesen.schroeder@warmmail.com	Charlotte	North Carolina	6011208259585406921	7e8122c546db04df898d9ca963847c1b	JCB 16 digit	35.1997349166098985	-80.8792754759490577
1495	2019-06-11 18:04:17	2019-06-11	Leopoldo Jacobs	leopoldo.jacobs@geemail.com	Pittsburgh	Pennsylvania	3088641263415029437	8dd36cc7240a90352f4276215b381f3f	American Express	40.5314264273691904	-79.9228531366385511
1496	2019-06-11 22:52:20	2019-06-11	Bell Nader	bell.nader@geemail.com	San Francisco	California	502064222472926	56285ff4a151fb4f2e0a3e64a906410a	VISA 16 digit	37.7555354093592825	-122.430607852066572
1497	2019-06-12 01:13:29	2019-06-12	Andre Ziemann	andre.ziemann@woohoo.com	San Francisco	California	3422321580317216	78491d96eb2073ac9a490245bd09eea3	VISA 13 digit	37.750497813875441	-122.420795715368541
1498	2019-06-12 01:51:01	2019-06-12	Jemima Shields	jemima.shields@warmmail.com	Worcester	Massachusetts	3337268846073456934	67196eee630c1f9d43ab068f14ff33ea	VISA 16 digit	42.1966002631168848	-71.7966129070866828
1499	2019-06-12 04:34:18	2019-06-12	Michael Schmidt-Douglas	michael.schmidt.douglas@warmmail.com	San Francisco	California	869982970308777726	553f7af948ac710ce73168c2fec9bba6	Diners Club / Carte Blanche	37.814670741488861	-122.431521578563334
1500	2019-06-12 08:27:16	2019-06-12	Reggie Sipes	reggie.sipes@geemail.com	San Francisco	California	3088957447310513870	a8cf1cbc4d666e0e06658d448176dbee	Voyager	37.7710194338587186	-122.419560340164011
1501	2019-06-12 10:32:01	2019-06-12	Alba Bogisich	alba.bogisich@warmmail.com	San Francisco	California	4038383302684	98bb6fed6df013ce126881236d0050e7	JCB 16 digit	37.7468737700430168	-122.390470207313527
1502	2019-06-12 10:33:08	2019-06-12	Tracy Hills	tracy.hills@geemail.com	San Francisco	California	3427613624212949	09bb88d48e0057223ae84420f4597432	Mastercard	37.7353473384040399	-122.41593470803015
1503	2019-06-12 12:13:23	2019-06-12	Philo Zulauf	philo.zulauf@geemail.com	San Francisco	California	4838526234706	ff90edc3b3ddf0c09889e016944435c6	Maestro	37.7800457034389936	-122.419329480199139
1504	2019-06-12 14:05:19	2019-06-12	Dr. Jodie Lowe MD	dr.jodie.lowe.md@geemail.com	College Station	Texas	3038409613633077	a49f811d33299d33fd2eaebd96baf73a	Diners Club / Carte Blanche	30.5568400134842832	-96.3075294236965505
1505	2019-06-12 15:26:54	2019-06-12	Jelani Larson	jelani.larson@woohoo.com	San Francisco	California	3470046307999761	6b6db7bc476d81c95507f9f1e9eddf72	JCB 16 digit	37.7722902949761661	-122.437000683640619
1506	2019-06-12 20:59:40	2019-06-12	Ms. Kaley Miller MD	ms.kaley.miller.md@geemail.com	San Francisco	California	180073253659494493	808f3a37a9b0896938a60d3dae9434e8	Maestro	37.7721390879150505	-122.422684952682076
1507	2019-06-12 22:34:43	2019-06-12	Galen Hoeger	galen.hoeger@geemail.com	San Francisco	California	4303656233402141	edec5c7a8c30de4669460604ec8a7d18	VISA 16 digit	37.7720463367923216	-122.441070797181254
1508	2019-06-13 00:38:08	2019-06-13	Janay Gutmann	janay.gutmann@geemail.com	San Francisco	California	869990624008962886	a18a9b9ece9607b394d9f84718014a39	Voyager	37.8158385909700669	-122.415206647709979
1509	2019-06-13 02:18:04	2019-06-13	Rogers Medhurst I	rogers.medhurst.i@geemail.com	San Francisco	California	589390947456910	52b98b4639155f688237f362d88d670b	Voyager	37.7876397270629667	-122.41150077270639
1510	2019-06-13 09:46:59	2019-06-13	Rafael Bernier Jr.	rafael.bernier.jr.@geemail.com	Oakland	California	630471993329441	5be20bb437386331421505ba7799ec59	Voyager	37.7895177485567686	-122.259433017758212
1511	2019-06-13 11:02:42	2019-06-13	Lue Huel	lue.huel@geemail.com	San Francisco	California	869987733317097774	ad5b9c9f785cdb5d1bd6d9df1a7008bc	American Express	37.7967855079403634	-122.424405075148897
1512	2019-06-13 13:14:58	2019-06-13	Tasha Beahan DVM	tasha.beahan.dvm@geemail.com	San Francisco	California	3033576169961592	0313cc5a059fe1c905164862888c8f0f	Diners Club / Carte Blanche	37.7635651453673731	-122.414971399487627
1513	2019-06-13 14:20:28	2019-06-13	Janiah Johnston-O'Kon	janiah.johnston.o'kon@geemail.com	San Francisco	California	3088329713156839278	038a5f9bad7c3b0b1707ff651c34b0d2	American Express	37.7971107056185289	-122.473964218393334
1514	2019-06-13 17:28:41	2019-06-13	Jimmie Nolan I	jimmie.nolan.i@woohoo.com	Las Cruces	New Mexico	6011663113453259920	78477eeecaed79dc73459f14a0d1acd2	JCB 15 digit	32.3454626155585032	-106.690111789957427
1515	2019-06-13 18:03:48	2019-06-13	Chelsea Murazik	chelsea.murazik@geemail.com	San Francisco	California	3112876868705942150	a7d8c2c568e50edc92a10f30865cd6b5	JCB 16 digit	37.769532786376935	-122.423142042611943
1516	2019-06-13 18:36:32	2019-06-13	Desirae Hegmann	desirae.hegmann@geemail.com	San Francisco	California	3112428891139375949	714349594ab64bdcae2a85822b090122	JCB 16 digit	37.7574552931230514	-122.404235286433362
1517	2019-06-13 20:02:17	2019-06-13	Josephine Armstrong DDS	josephine.armstrong.dds@geemail.com	San Francisco	California	3020686826049500	e0898388617fd3f00869f07e0408e892	Diners Club / Carte Blanche	37.7485725148834277	-122.448872358022243
1518	2019-06-13 23:56:21	2019-06-13	Mr. Roel Ankunding	mr.roel.ankunding@woohoo.com	Clearwater	Florida	4946750606305503	c4bd6b872343b88ed3ca36f928b42606	JCB 16 digit	27.888316410187258	-82.8319003474231721
1519	2019-06-14 02:08:56	2019-06-14	Elza Mills	elza.mills@geemail.com	New York	New York	3158071631470523164	b937bf66b871b3b70b96701c95d97924	JCB 15 digit	40.6152181649338431	-74.0061118459690306
1520	2019-06-14 05:23:39	2019-06-14	Mrs. Marquita Conn	mrs.marquita.conn@geemail.com	San Francisco	California	3763266868434730	8feac9fe1021a1440b7716688b186103	JCB 16 digit	37.7476513903432149	-122.384306838136879
1521	2019-06-14 08:44:16	2019-06-14	Farrell Dibbert	farrell.dibbert@woohoo.com	Berkeley	California	4842018016986105	63cf5cbae0b96577e48f6e0519521ca2	JCB 16 digit	37.8588583797066676	-122.318441947641148
1522	2019-06-14 08:55:15	2019-06-14	Audrey Huels-Fahey	audrey.huels.fahey@geemail.com	Oakland	California	53975667903257035	5a4f7d3ea84dffc1c559da8746d09d44	American Express	37.786328536824513	-122.292069496393623
1523	2019-06-14 11:47:20	2019-06-14	Juwan Schneider-Prohaska	juwan.schneider.prohaska@geemail.com	San Francisco	California	3096828232186340377	a7ce869336e62cb57ff279b97465e177	Mastercard	37.8230074248795347	-122.430814007230779
1524	2019-06-14 15:15:08	2019-06-14	Mr. Tyrin Beatty	mr.tyrin.beatty@geemail.com	San Francisco	California	4854554996794155	59ccaa1394d91bd33f20b7e11313fa6d	VISA 16 digit	37.7747640538066491	-122.434287730309833
1525	2019-06-14 17:09:53	2019-06-14	Cuba Mohr DDS	cuba.mohr.dds@geemail.com	San Francisco	California	3158911514949668311	386023e8ff381b3bb4b7ddde9b274f8d	VISA 16 digit	37.7746548894561514	-122.426953911734074
1526	2019-06-14 17:15:44	2019-06-14	Herschel Mann DVM	herschel.mann.dvm@geemail.com	San Francisco	California	4405943986617043	aceea4c3dc2e3cde71eb640f9814521d	American Express	37.7633011482940475	-122.422784447538803
1527	2019-06-14 18:51:07	2019-06-14	Mr. Isaiah McLaughlin MD	mr.isaiah.mclaughlin.md@woohoo.com	Oakland	California	4861132343430	f63508a3d46fba3787beb21414b02836	Mastercard	37.8145496004028416	-122.262983512694532
1528	2019-06-14 21:32:51	2019-06-14	Tariq Gorczany	tariq.gorczany@geemail.com	San Francisco	California	3337948699645964143	9268e8f4860ec534deac8e022d4f6ad4	JCB 16 digit	37.8063516843883036	-122.453759805562015
1529	2019-06-14 22:09:28	2019-06-14	Tillie Langosh	tillie.langosh@geemail.com	Oakland	California	3722095993092604	73c77d1cfda94781446b6148f3b0b3d7	Mastercard	37.8080376601676349	-122.260678962929887
1530	2019-06-14 23:39:10	2019-06-14	Kenley Stracke	kenley.stracke@geemail.com	Lincoln	Nebraska	3484504056669054	45ce9aede5b58a74784573cf9987f184	Voyager	40.8443369863573409	-96.6152044939503156
1531	2019-06-15 01:19:28	2019-06-15	Severo Weissnat-Monahan	severo.weissnat.monahan@geemail.com	San Francisco	California	676298008107504	95fd3c98dda8396988bdffe203c89966	Mastercard	37.760679139909719	-122.457864526602762
1532	2019-06-15 02:29:51	2019-06-15	Michael Schamberger II	michael.schamberger.ii@geemail.com	Bakersfield	California	3004016660065717	0f4b406f0fb1bf9b339b68a29b60d1d1	JCB 16 digit	35.3526482294954363	-118.984286440423872
1533	2019-06-15 02:43:24	2019-06-15	Dr. Victorine Aufderhar MD	dr.victorine.aufderhar.md@geemail.com	San Francisco	California	51317866687208837	f603cfcd241647961d890b590aca91ae	VISA 16 digit	37.7598974947816259	-122.392073720722934
1534	2019-06-15 03:57:56	2019-06-15	Malvin Hirthe	malvin.hirthe@geemail.com	Oakland	California	3112790578238085681	c6c6206b222d469121e1c2405671d040	VISA 16 digit	37.7884862774356023	-122.250306493272504
1535	2019-06-15 09:09:47	2019-06-15	Daniele Jenkins	daniele.jenkins@woohoo.com	San Antonio	Texas	501875958262760	6ad8408c44739b02988930e32f43e73c	Diners Club / Carte Blanche	29.5267397981207829	-98.4850115307442735
1536	2019-06-15 10:52:44	2019-06-15	Nick Grady	nick.grady@geemail.com	San Francisco	California	869918789011210471	3a221b2006088bd0a9b90772ca3e6499	VISA 13 digit	37.7354418985009517	-122.450099500153101
1537	2019-06-15 13:08:37	2019-06-15	Leanne Mills	leanne.mills@geemail.com	Berkeley	California	3112225776361474798	d0743c621b0b1e9139cb0c5bf4c2a626	Maestro	37.8955141841507768	-122.257295094768054
1538	2019-06-15 13:57:55	2019-06-15	Dr. Christena Strosin	dr.christena.strosin@geemail.com	San Francisco	California	3088974540594388214	129d743ef25bc423b72f1b12d3532e84	VISA 13 digit	37.7615856746452181	-122.431421321068441
1539	2019-06-15 18:22:53	2019-06-15	Nikhil Larson V	nikhil.larson.v@woohoo.com	Berkeley	California	52091676353625574	a17ff571a92f5ae03c22bb017fd747c3	Maestro	37.8950850456819097	-122.296247106870993
1540	2019-06-15 19:04:52	2019-06-15	Ariel Connelly	ariel.connelly@geemail.com	San Francisco	California	3096352446205779480	7dc3b733840b302ab0f33bdb7f588e78	VISA 13 digit	37.7503515733805699	-122.453873234054811
1541	2019-06-15 21:44:21	2019-06-15	Mr. Americo VonRueden V	mr.americo.vonrueden.v@geemail.com	San Francisco	California	4347569938298	cbec628756dbecdce5e543ab90b0c6e4	VISA 16 digit	37.7860495136680612	-122.449927394461653
1542	2019-06-15 21:51:43	2019-06-15	Mike Bins Jr.	mike.bins.jr.@geemail.com	Berkeley	California	503815361046699	713d7731dac26b3fb67649fff133af0a	Discover	37.8332720052640283	-122.266782736770352
1543	2019-06-16 05:46:04	2019-06-16	Dr. Almond Auer	dr.almond.auer@geemail.com	Springfield	Massachusetts	3010091660579789	580087efe212aebf564a20c14e749342	VISA 16 digit	42.0784028943832951	-72.5279057947080616
1544	2019-06-16 06:23:31	2019-06-16	Ms. Lavenia Lang	ms.lavenia.lang@warmmail.com	San Francisco	California	3337270546611632840	ecbf3dcdeec49134143a57f2e2b2135d	JCB 15 digit	37.7927251294179385	-122.427753097085272
1545	2019-06-16 08:16:43	2019-06-16	Myrtice Buckridge PhD	myrtice.buckridge.phd@woohoo.com	San Francisco	California	4644463453769335	28bef9f4f8a73b78037603f854c9de67	Maestro	37.7862488923475865	-122.450479909391831
1546	2019-06-16 12:30:07	2019-06-16	Ms. Bethzy Hermann	ms.bethzy.hermann@woohoo.com	San Francisco	California	210081857466852162	7f98ed9c6bf309aebd8f4effdb5e3ea2	Maestro	37.7836735819030878	-122.41446299941191
1547	2019-06-16 13:04:24	2019-06-16	Felton Abernathy	felton.abernathy@geemail.com	San Francisco	California	3528706934847337125	37477cd29d4d68fd63c7589650b20500	JCB 16 digit	37.776893316142889	-122.451024302264415
1548	2019-06-16 15:39:37	2019-06-16	Anabella Hane	anabella.hane@woohoo.com	Oakland	California	869912910533393084	f8cd9b0f589b3fe98b9699b4ce24b14a	Discover	37.8246887039983051	-122.251906121245682
1549	2019-06-16 19:17:47	2019-06-16	Tre Watsica	tre.watsica@geemail.com	San Francisco	California	53576266319454485	1869fd2f1ae1b76ff6e740c909a35f66	VISA 16 digit	37.7737881362051624	-122.414829124462457
1550	2019-06-16 20:11:21	2019-06-16	Juliette Hettinger MD	juliette.hettinger.md@woohoo.com	San Francisco	California	3088083518953591246	4e1fe82d9baddbd5c3bcc1e4c5c53fca	Voyager	37.7851461519128335	-122.442570448158605
1551	2019-06-16 20:51:40	2019-06-16	Mr. Warner Lowe	mr.warner.lowe@geemail.com	San Francisco	California	180003277802344623	fef578e9adc016487b9e99c3a8b8d62d	VISA 16 digit	37.766249524774004	-122.390716251112423
1552	2019-06-16 21:26:00	2019-06-16	Laquita Murray	laquita.murray@warmmail.com	Oakland	California	210024958527390026	a0a124b659c788776cda0c6eda4de442	Voyager	37.7789568448390654	-122.267959301111915
1553	2019-06-16 21:46:08	2019-06-16	Zion Gottlieb MD	zion.gottlieb.md@woohoo.com	Omaha	Nebraska	210086180880580417	7690c12aa3fd3a61caee3ad8c00e5dd9	American Express	41.3059878744330291	-95.9757857307907187
1554	2019-06-16 22:09:59	2019-06-16	Lyndon Hartmann	lyndon.hartmann@geemail.com	San Francisco	California	3769903004985589	972d06713bb38350d7d39ca5313f72ed	Maestro	37.7853570720118057	-122.43066253404325
1555	2019-06-16 22:26:46	2019-06-16	Verena Mante	verena.mante@geemail.com	San Francisco	California	869944719468868198	8266f80b23d76cf3356a6cc9eef3b02f	JCB 16 digit	37.7597954962899962	-122.448583568850182
1556	2019-06-17 00:41:25	2019-06-17	Launa Bradtke-Bartoletti	launa.bradtke.bartoletti@geemail.com	San Francisco	California	4613396836068297	5a8c4ddfa2ca4d7ef25d578fd4086ce1	JCB 16 digit	37.7578639762935424	-122.448632659223335
1557	2019-06-17 02:03:52	2019-06-17	Abbigail Hauck	abbigail.hauck@geemail.com	Oakland	California	3030018290847005	6d92928dedc1909d604af4612c8e5380	VISA 16 digit	37.8198182139133081	-122.25626940577402
1558	2019-06-17 03:14:23	2019-06-17	Jayla Weissnat	jayla.weissnat@woohoo.com	San Francisco	California	3528386798173564736	8fc03fff18ac6c1a4f3fe1729a26b162	VISA 16 digit	37.7397558952306227	-122.430954404618944
1559	2019-06-17 06:12:42	2019-06-17	Hayleigh Wilkinson	hayleigh.wilkinson@warmmail.com	San Francisco	California	4284199186062953	f7bf01f5396c6818982067666b0b3468	Discover	37.7418242879365238	-122.444342331957529
1560	2019-06-17 06:28:17	2019-06-17	Mr. Kit Cruickshank Jr.	mr.kit.cruickshank.jr.@geemail.com	San Francisco	California	630452777696346	1edd4707e6e2d214f50291c417a9f78c	Diners Club / Carte Blanche	37.7851849476013797	-122.424400171815392
1561	2019-06-17 08:49:45	2019-06-17	Hartley Nienow	hartley.nienow@warmmail.com	Westminster	Colorado	4306466083905	7a3d16a6194e29235cde5c0e2ed8aeac	JCB 16 digit	39.9470071878124031	-105.113192422236878
1562	2019-06-17 10:21:08	2019-06-17	Debbi Wisozk DDS	debbi.wisozk.dds@warmmail.com	San Francisco	California	869929034206352847	8841dcaec17ce80cba7b243b4f33a1ed	JCB 16 digit	37.8285944705625354	-122.43183705438453
1563	2019-06-17 12:02:44	2019-06-17	Colt Cronin-Champlin	colt.cronin.champlin@warmmail.com	San Francisco	California	869983777054295384	6a3ccdb6c4a8a02d3c539f11f3d21d22	VISA 16 digit	37.7841965115628966	-122.447009881302392
1564	2019-06-17 13:32:09	2019-06-17	Cassidy Daniel	cassidy.daniel@geemail.com	San Francisco	California	4534265530238520	7d2dba54eaf9bbf1104ba008b45a2ee2	Diners Club / Carte Blanche	37.7888538839069952	-122.442402506702763
1565	2019-06-17 22:11:44	2019-06-17	Kay Mitchell DVM	kay.mitchell.dvm@geemail.com	Newark	New Jersey	3112828600061414709	d042794d6dcb865fac2b2fb2cf16e7e4	Discover	40.7440267105966853	-74.1688540406733807
1566	2019-06-17 23:40:18	2019-06-17	Bruno Reichert	bruno.reichert@geemail.com	Berkeley	California	3763097684588908	5c3a472c8d83011ae7182c5e6fcc77a7	American Express	37.855939840150036	-122.324306481858031
1567	2019-06-18 05:24:18	2019-06-18	Dr. Helena Lindgren PhD	dr.helena.lindgren.phd@geemail.com	Richmond	California	4146749072755652	d4fea46a8ea2279fe7002b4d2cf9c19e	JCB 16 digit	37.8946007245641212	-122.300188233316319
1568	2019-06-18 05:36:07	2019-06-18	Abelardo Hudson Jr.	abelardo.hudson.jr.@geemail.com	San Francisco	California	3055838954035448	82aeeebdc30452b6e73072ca6a65fef9	JCB 16 digit	37.7500489309569573	-122.385266792297884
1569	2019-06-18 06:44:50	2019-06-18	Aisha Schimmel	aisha.schimmel@warmmail.com	San Francisco	California	4440806234117859	eed15552a8c61a7c9cf4c02a0ae80594	VISA 13 digit	37.7781908628157268	-122.442502001900962
1570	2019-06-18 06:59:47	2019-06-18	Ms. Melvina Hilll PhD	ms.melvina.hilll.phd@geemail.com	Jacksonville	Florida	6011287103926060647	0baf9a8fb322f41278f8b8c39a3deac7	American Express	30.3475049173977212	-81.6750339583106353
1571	2019-06-18 10:32:35	2019-06-18	Leonardo Lockman	leonardo.lockman@geemail.com	San Francisco	California	561238590967634	c2c682159f308c9c026b40d673eddae6	VISA 13 digit	37.7573930681350021	-122.451305756855518
1572	2019-06-18 13:07:35	2019-06-18	Roswell Funk-Mayer	roswell.funk.mayer@geemail.com	San Francisco	California	4522376067919632	978a95be2647f0856c49dd4f6cec5d09	JCB 16 digit	37.7610758577786285	-122.42459757286862
1573	2019-06-18 14:18:39	2019-06-18	Naomi Ritchie PhD	naomi.ritchie.phd@geemail.com	Berkeley	California	4555781358243206	839956a03c2581717bc2b6aa93d9ba2c	JCB 15 digit	37.8469153936428384	-122.288119146235729
1574	2019-06-18 17:04:59	2019-06-18	Dr. Gilberto Pfeffer II	dr.gilberto.pfeffer.ii@geemail.com	San Francisco	California	6011394626085622930	81a2a5c641c7bb4394031238aaeaacab	VISA 16 digit	37.7879382428942279	-122.481895998428755
1575	2019-06-18 18:29:33	2019-06-18	Elianna Kirlin	elianna.kirlin@geemail.com	San Francisco	California	6011188969179018510	ba9b1817ec716e38b358ea2f4891bb32	VISA 16 digit	37.7703716312033535	-122.467956865479536
1576	2019-06-18 19:37:33	2019-06-18	Lisa Sporer	lisa.sporer@geemail.com	San Francisco	California	6011313953595026958	3432e39fa4ecc0bc9aed492cb5dbab6a	VISA 16 digit	37.7643207833219705	-122.407863945721402
1577	2019-06-18 22:01:25	2019-06-18	Cassie Schinner	cassie.schinner@geemail.com	Berkeley	California	55553813683740002	9eaa76825272ae12ddc63c318671cbba	Diners Club / Carte Blanche	37.8471692981852073	-122.280328436804083
1578	2019-06-19 00:04:42	2019-06-19	Fidelia Roob PhD	fidelia.roob.phd@geemail.com	San Francisco	California	561293957673499	dd79ad0c459be0ca54b255e2553978eb	Mastercard	37.7842633239166688	-122.422019882517404
1579	2019-06-19 07:12:52	2019-06-19	Wing Schmitt	wing.schmitt@geemail.com	Kansas City	Missouri	3033083013516052	099c33e678c35e86099aa000027d646c	VISA 16 digit	39.0658170460093785	-94.6061801240071674
1580	2019-06-19 07:22:00	2019-06-19	Mr. Maverick Hane Jr.	mr.maverick.hane.jr.@geemail.com	San Francisco	California	3158771173989716982	740eb549804a58b74f53e947c3cab3ab	Mastercard	37.7741583264847449	-122.435526985341539
1581	2019-06-19 12:36:11	2019-06-19	Kurt Legros	kurt.legros@geemail.com	San Francisco	California	4544881523649172	dd260fdfe40a1677c23e1047eee47751	JCB 16 digit	37.7685415599774217	-122.432723666655278
1582	2019-06-19 15:24:15	2019-06-19	Blanchard Beatty	blanchard.beatty@woohoo.com	San Francisco	California	639059311072405	95dabb273a85920d25ae8780f3d983fa	VISA 13 digit	37.7728974459171312	-122.44142862911518
1583	2019-06-19 19:13:42	2019-06-19	Lizabeth Considine	lizabeth.considine@geemail.com	San Francisco	California	3024643776888029	c32d965fcc6a74d3e510636110ad2357	Diners Club / Carte Blanche	37.7774556615469024	-122.472535328935834
1584	2019-06-19 21:42:49	2019-06-19	Saul Shields-Crist	saul.shields.crist@geemail.com	San Francisco	California	54282000692298762	3e1d31a0beecb9ad0e89fc243c7076c3	JCB 15 digit	37.8097599814193401	-122.443678866684337
1585	2019-06-19 21:45:40	2019-06-19	Zackary Runolfsson	zackary.runolfsson@warmmail.com	San Francisco	California	210002669597900190	c02f9d9170032e3643048450d9b56bac	VISA 13 digit	37.8093044618313101	-122.411349316401072
1586	2019-06-19 23:37:41	2019-06-19	Dr. Kelsea Crist	dr.kelsea.crist@woohoo.com	San Francisco	California	3088547971108335938	73e4f1efbd95bc1f7a149375a91de8a2	American Express	37.8002418858080844	-122.416359558196632
1587	2019-06-19 23:47:58	2019-06-19	Mrs. Leisha Kemmer MD	mrs.leisha.kemmer.md@geemail.com	Oakland	California	180045464562573704	12723bd94a24d8a966f3d275fcedb57a	VISA 13 digit	37.7896059510013416	-122.275150108672392
1588	2019-06-19 23:57:25	2019-06-19	Dr. Merlin Sawayn II	dr.merlin.sawayn.ii@geemail.com	Seattle	Washington	3045551187451940	b68ced05707448d5ab7e85f8f9c9d370	JCB 16 digit	47.6454423537868976	-122.26394192421958
1589	2019-06-20 00:03:01	2019-06-20	Easton Carroll	easton.carroll@geemail.com	Oakland	California	3455909851568994	c68e217444d41e7bbd559fff67d164fc	Voyager	37.8206965112288245	-122.23392758437592
1590	2019-06-20 01:38:23	2019-06-20	Christion Zulauf-Reynolds	christion.zulauf.reynolds@woohoo.com	Oakland	California	54728996611734799	fc2c354001023ed2db9746c5d469c946	Voyager	37.7590185837398522	-122.297926718258836
1591	2019-06-20 03:16:22	2019-06-20	Racheal Langworth	racheal.langworth@geemail.com	San Francisco	California	3158326301085480142	09c7dc9dae8192455df43f057cafe0fc	VISA 16 digit	37.7795711284905025	-122.440767865088262
1592	2019-06-20 06:54:58	2019-06-20	Tarik Cremin	tarik.cremin@warmmail.com	Oakland	California	3337977632657521398	f262849d2e9f0ce91acf529424a31f46	VISA 16 digit	37.8071805378065662	-122.280978911309887
1593	2019-06-20 10:17:01	2019-06-20	Dr. Henri Lind	dr.henri.lind@warmmail.com	Berkeley	California	4603963811334382	9913cf0c3107654cec2c03fab2f637f9	Mastercard	37.9141919465194235	-122.296964351178332
1594	2019-06-20 10:27:28	2019-06-20	Harlow O'Keefe-Reichert	harlow.o'keefe.reichert@warmmail.com	San Francisco	California	3096416796755032233	b5527f14d5942fa540cb7233080cddb5	JCB 16 digit	37.7849007218615185	-122.450546224552085
1595	2019-06-20 11:23:48	2019-06-20	Vonnie Kautzer	vonnie.kautzer@geemail.com	Wichita	Kansas	3700483023755844	c84e07a42242da03fee8f9f113851ff0	VISA 16 digit	37.6523872270591582	-97.4157994532227463
1596	2019-06-20 21:21:47	2019-06-20	Myron Littel	myron.littel@woohoo.com	San Francisco	California	210072662227932688	c233993d5a916f7a5f0e448e0d1c6fcf	VISA 16 digit	37.7399728854838443	-122.437446466033848
1597	2019-06-20 22:27:41	2019-06-20	Ell Reichert-Walter	ell.reichert.walter@woohoo.com	San Francisco	California	676229150355310	231f809582ad76c8af84aec8ca405387	Diners Club / Carte Blanche	37.7595892788460006	-122.413712850727435
1598	2019-06-20 22:46:53	2019-06-20	Louisiana Sauer-Haley	louisiana.sauer.haley@warmmail.com	San Angelo	Texas	4239139185064	377bd264ed82720714d2e54a1c36225b	Mastercard	31.4356356988813701	-100.548912369191655
1599	2019-06-20 23:54:28	2019-06-20	Isadore Rogahn-Mann	isadore.rogahn.mann@geemail.com	Oakland	California	869937273798230587	08a94986c610b06fbb5e2dee5e60643b	Mastercard	37.8264811495662485	-122.285568215742614
1600	2019-06-21 01:22:27	2019-06-21	Samantha Ledner	samantha.ledner@geemail.com	Berkeley	California	210089536706403448	24b18ef4312893dbf94a4f6fafe082e9	VISA 16 digit	37.8875947851688935	-122.287161079536716
1601	2019-06-21 02:14:25	2019-06-21	Cristina Hauck DVM	cristina.hauck.dvm@geemail.com	San Francisco	California	4004778166406857	b2f46b22aaf6e0ff7db113d203d606ef	VISA 13 digit	37.7720577278293561	-122.447825903174362
1602	2019-06-21 03:31:05	2019-06-21	Newt Cummings	newt.cummings@geemail.com	Oakland	California	3096562015907598807	6577cb8e5ac23c368d22aeb8a7bc62f0	VISA 16 digit	37.7881092101580691	-122.285790960879424
1603	2019-06-21 03:47:48	2019-06-21	Frieda Rosenbaum	frieda.rosenbaum@geemail.com	Oakland	California	503836186800623	74b5b5be90769c6ecb4caa2112ca0cb0	Mastercard	37.8047295498143328	-122.289037476769352
1604	2019-06-21 10:09:41	2019-06-21	Bob Daniel	bob.daniel@geemail.com	San Francisco	California	3028099157577929	2e2673f75ae4a3d0d238892c3b1b4418	JCB 15 digit	37.7885758832928573	-122.45899104712494
1605	2019-06-21 10:40:51	2019-06-21	Tanya Paucek	tanya.paucek@warmmail.com	Berkeley	California	869990134741056954	d8f4bd9598c52fc06bf0d8495bb2f3ea	Mastercard	37.8264929835802519	-122.295865763283913
1606	2019-06-21 10:57:10	2019-06-21	Dr. Dorcas Monahan DVM	dr.dorcas.monahan.dvm@warmmail.com	San Francisco	California	180079843774586720	0f9cf9c32f1fd1b5f33ffa257b6fef39	Diners Club / Carte Blanche	37.7701817129054476	-122.414138247548721
1607	2019-06-21 13:56:15	2019-06-21	Miss Merrilee Herzog	miss.merrilee.herzog@geemail.com	Ventura	California	561237998509006	1cf87d47031724c95a4b72ead8ea1079	JCB 16 digit	34.186885029512645	-119.337639582912246
1608	2019-06-21 13:56:59	2019-06-21	Cecil Jones	cecil.jones@geemail.com	San Francisco	California	3158234237894303979	296c6c34100e3b34dd74f1f51742f35b	VISA 16 digit	37.7835417373374511	-122.427412838054806
1609	2019-06-21 17:30:39	2019-06-21	Catharine Bartoletti	catharine.bartoletti@geemail.com	Oakland	California	210038890265576157	470a939d916a2935974f19184a6d62d8	American Express	37.8180464311021183	-122.305251860202887
1610	2019-06-21 21:04:26	2019-06-21	Keshaun Nienow	keshaun.nienow@geemail.com	Riverside	California	4103943583791	dca4f8c0c805940e727583c2ec567e48	Maestro	33.9464641137927785	-117.440024469277631
1611	2019-06-21 22:26:55	2019-06-21	Jaylin Boyle	jaylin.boyle@geemail.com	San Francisco	California	869928657604112305	a6967020613959eba68f34b4f74ba82f	American Express	37.7717826978270494	-122.429125008165997
1612	2019-06-21 23:19:10	2019-06-21	Olivia Rippin	olivia.rippin@geemail.com	San Francisco	California	52094485182762997	e752f9a42a1714015855142514a8a990	Maestro	37.7856905498304556	-122.407615756509657
1613	2019-06-22 02:13:28	2019-06-22	Maliah McDermott	maliah.mcdermott@geemail.com	San Francisco	California	180062372779293958	af8a57779be6a57911279906a55fd568	American Express	37.7534548934530747	-122.445018197882575
1614	2019-06-22 04:32:11	2019-06-22	Lindsey Thompson	lindsey.thompson@geemail.com	San Francisco	California	3041347815074012	74194f081be68b5c8c171bc0bedbf489	VISA 16 digit	37.7732642520901294	-122.422392543429126
1615	2019-06-22 04:57:43	2019-06-22	Ms. Bristol Thompson MD	ms.bristol.thompson.md@geemail.com	Berkeley	California	180082589346902078	a6c894a5d094aa9a60313eb99cac7ba9	JCB 16 digit	37.8582433527542221	-122.235361883979067
1616	2019-06-22 05:23:13	2019-06-22	Coral Huel MD	coral.huel.md@geemail.com	San Francisco	California	210029836188537017	320e90828ef9a68e59ab1bfbab5df2a6	Mastercard	37.7787445905324972	-122.443336703463288
1617	2019-06-22 05:56:27	2019-06-22	Shamar Pfannerstill	shamar.pfannerstill@geemail.com	Berkeley	California	6011531652527004424	e5c6610807b7d1baf5dabcaadab11413	Discover	37.8761532760302089	-122.264061299120741
1618	2019-06-22 07:32:27	2019-06-22	Linette Rutherford	linette.rutherford@warmmail.com	Oakland	California	3720240262935560	88f0b0cbbf48026d3d3784f99c95a85a	VISA 13 digit	37.7959283369625823	-122.273903607398296
1619	2019-06-22 08:45:35	2019-06-22	Elton Senger	elton.senger@geemail.com	San Francisco	California	3528254996106815881	51836336cae375eb2e82ca4259083b5f	Diners Club / Carte Blanche	37.7750472558853119	-122.439506733098696
1620	2019-06-22 11:44:59	2019-06-22	Tasha Bode	tasha.bode@geemail.com	Dallas	Texas	3088482129824230977	d2d1db7c9d767a4c0f85d57bf6015e6c	VISA 16 digit	32.7948025190543433	-96.6860774796418809
1621	2019-06-22 11:50:46	2019-06-22	Denzil Howell	denzil.howell@geemail.com	San Francisco	California	3421428832524449	6dd7ae3cdebaf05309df6872fdc0d672	JCB 15 digit	37.7507478773825937	-122.451686577791932
1622	2019-06-22 14:51:24	2019-06-22	Meadow Moore MD	meadow.moore.md@geemail.com	San Francisco	California	3709741203798251	1069dba55c5a50659bda06b9d5f61250	Voyager	37.7519355767960363	-122.452848935328333
1623	2019-06-22 17:08:50	2019-06-22	Mamie Auer	mamie.auer@geemail.com	San Francisco	California	3088954541637357848	9e8faf784784a53d65b877ada6cdf4f6	Maestro	37.7867115575680543	-122.448717458188526
1624	2019-06-22 18:02:49	2019-06-22	Merry Bauch	merry.bauch@geemail.com	San Francisco	California	4824647227828425	9ebfe20932ef1122215272f0ebee81ed	Mastercard	37.7882750932580507	-122.40237357474841
1625	2019-06-22 19:18:05	2019-06-22	Demetrios Leffler	demetrios.leffler@warmmail.com	San Francisco	California	3528832700231952861	506115526c0c487e32ceac533f531966	VISA 13 digit	37.7744691665909897	-122.412107914677989
1626	2019-06-22 20:04:51	2019-06-22	Cael Durgan	cael.durgan@geemail.com	Anchorage	Alaska	4884501235869979	8877d17a8fbf784aeefc51689e8e4cc1	Mastercard	61.2722692285880441	-149.248900355969738
1627	2019-06-23 01:07:01	2019-06-23	Hazel Marks	hazel.marks@geemail.com	San Francisco	California	060467243578472	c7242fea98ca5cf02903552545401802	JCB 16 digit	37.764134036824565	-122.422754118264791
1628	2019-06-23 01:48:22	2019-06-23	Dr. Miles Dickinson	dr.miles.dickinson@geemail.com	Oakland	California	180012675507893795	2f27f2a9e4e9323059ee4081bcc7f141	Maestro	37.8502547296726561	-122.281868759216195
1629	2019-06-23 02:31:43	2019-06-23	Phillis Tromp	phillis.tromp@geemail.com	San Francisco	California	3112060726806088875	50cb8905d6e78bc17968980175080795	American Express	37.775596673831771	-122.44829214444627
1630	2019-06-23 02:49:36	2019-06-23	Rudolf Orn-Ledner	rudolf.orn.ledner@warmmail.com	Berkeley	California	3528802341249715184	3da7b86c43c102c17e86945d1ccd318a	JCB 16 digit	37.8855249952470032	-122.273753557921239
1631	2019-06-23 03:18:10	2019-06-23	Lucky Kreiger-Stanton	lucky.kreiger.stanton@geemail.com	San Francisco	California	3112460713665789781	306ceead718e0c20ebef3f064d4835ed	American Express	37.78937264059104	-122.435379314615204
1632	2019-06-23 05:04:57	2019-06-23	Jemal Cartwright	jemal.cartwright@geemail.com	Berkeley	California	3492062569625428	2a168253a01f47aed22f007b81d3ad01	VISA 13 digit	37.8196209172687787	-122.308290187652915
1633	2019-06-23 06:33:13	2019-06-23	Augustine Upton	augustine.upton@geemail.com	San Francisco	California	53460018426580218	5f6815af587511c5f725ad0d4fab06bc	JCB 16 digit	37.7839986288064154	-122.431948237084512
1634	2019-06-23 07:29:37	2019-06-23	Mitchell Spinka	mitchell.spinka@geemail.com	San Francisco	California	3030572210911879	ff09af8a50073d435c9072eab8ee573e	JCB 16 digit	37.8011536516994582	-122.449042812535907
1635	2019-06-23 12:35:20	2019-06-23	Tyquan Boehm I	tyquan.boehm.i@geemail.com	Denver	Colorado	869915662997004023	77fb9e821d31c4a6a6cf4489d2c69fea	VISA 16 digit	39.852038386795293	-104.961421760661906
1636	2019-06-23 21:59:16	2019-06-23	Ashlea Padberg	ashlea.padberg@woohoo.com	San Francisco	California	3705537635719707	2fad55ea9a55e701f0237e550dccb4c0	Diners Club / Carte Blanche	37.7519152884430014	-122.450473340834776
1637	2019-06-23 22:17:54	2019-06-23	Roberta Runolfsson	roberta.runolfsson@geemail.com	San Francisco	California	3112940976979879297	7e776a393deb347f15ca727612742a03	VISA 16 digit	37.7755037217718765	-122.445950318576152
1638	2019-06-23 22:52:28	2019-06-23	Ivie Howell MD	ivie.howell.md@geemail.com	San Antonio	Texas	4654820025003203	95c1217f1a3fb5aa1df16be53164136d	VISA 16 digit	29.5416522862926136	-98.5790875640533812
1639	2019-06-23 23:00:46	2019-06-23	Roswell Reichel IV	roswell.reichel.iv@woohoo.com	Berkeley	California	869993334645165664	1711bbf461b9890d095387e266716034	Voyager	37.8801944309120771	-122.280043749565152
1640	2019-06-24 00:46:04	2019-06-24	Aydan Nitzsche IV	aydan.nitzsche.iv@woohoo.com	Oakland	California	4084387425620473	7339c2cada89854a86893d7562982d8d	VISA 16 digit	37.8205709634613925	-122.239182493779097
1641	2019-06-24 02:24:25	2019-06-24	Rozanne Shanahan	rozanne.shanahan@geemail.com	San Francisco	California	3112334051397347295	662695e0ad1464278dc7856480f367f6	Maestro	37.7409861563708304	-122.426280207692031
1642	2019-06-24 08:18:18	2019-06-24	Dr. Uriah Lynch III	dr.uriah.lynch.iii@geemail.com	Oakland	California	869990942803035439	c7036dbf21fe63a79a718e75588650ed	Maestro	37.8304159742880373	-122.233416047765246
1643	2019-06-24 11:45:15	2019-06-24	Dr. Jerrilyn Koelpin	dr.jerrilyn.koelpin@warmmail.com	Norfolk	Virginia	3019076957877153	9f1716b8268654bc67a47187664b7cd8	VISA 16 digit	36.9281299038343178	-76.185333893914148
1644	2019-06-24 13:57:17	2019-06-24	Nakisha Bahringer	nakisha.bahringer@geemail.com	Oakland	California	4705547634167496	8cfa3629971198692646a61300e319f1	Mastercard	37.783662393008818	-122.295325033540408
1645	2019-06-24 15:42:35	2019-06-24	Carlos Moore	carlos.moore@geemail.com	Oakland	California	4586835891597	2e430e9d1307119539093f342ad5f250	JCB 16 digit	37.823381255822575	-122.319999567759055
1646	2019-06-24 15:45:31	2019-06-24	Seth Funk-Stark	seth.funk.stark@geemail.com	San Francisco	California	3112891495509940270	ddcc69e2539b1511c9a349431e1abd26	VISA 13 digit	37.7519627243265674	-122.429792559879502
1647	2019-06-24 16:06:52	2019-06-24	Dr. Narcissus Howe MD	dr.narcissus.howe.md@geemail.com	Nashville	Tennessee	4413919488242	41587639299fba7c69fa3973c471db4f	JCB 16 digit	36.1661812293466127	-86.7457417711056706
1648	2019-06-24 16:44:21	2019-06-24	Tawanda Lang	tawanda.lang@geemail.com	San Francisco	California	6011160517939898135	e41c08e6f5520208ab0067f59ce827be	JCB 15 digit	37.7760046390781383	-122.4013014367425
1649	2019-06-24 16:50:53	2019-06-24	Judson Marks-Wilkinson	judson.marks.wilkinson@geemail.com	San Francisco	California	3417358933388467	8880965e0d1cce00d2465dbe0f421ccb	JCB 16 digit	37.7684187461475034	-122.440198702314532
1650	2019-06-24 17:14:18	2019-06-24	Ronal Kub PhD	ronal.kub.phd@woohoo.com	Oakland	California	502022376017186	e90067af5f3359bc1dbf3f27aa2dea9c	Diners Club / Carte Blanche	37.8276726892945803	-122.246648491610955
1651	2019-06-24 17:20:22	2019-06-24	Dustan Hintz	dustan.hintz@geemail.com	San Francisco	California	210012725909286203	2068cf89166a766d60efb403ae7d17d3	VISA 16 digit	37.7620377927125404	-122.457132983259555
1652	2019-06-24 18:16:27	2019-06-24	Dewey Greenholt	dewey.greenholt@geemail.com	Berkeley	California	180058329823967835	202462580ed6f52472d37c2cbe28e36d	Mastercard	37.8398257041405017	-122.260085265001194
1653	2019-06-25 05:05:32	2019-06-25	Caylee Frami	caylee.frami@woohoo.com	San Francisco	California	4618163047078910	9cf8becf114fdd08a6509bcf3f716777	Diners Club / Carte Blanche	37.7854759243578329	-122.430252808507504
1654	2019-06-25 05:38:16	2019-06-25	Makhi Vandervort	makhi.vandervort@geemail.com	San Francisco	California	6011423085025451378	94ea8372914d3a7588bd297b044fa45e	VISA 13 digit	37.7984434000783409	-122.416722121052288
1655	2019-06-25 05:52:11	2019-06-25	Miss Jorja Stark MD	miss.jorja.stark.md@woohoo.com	San Francisco	California	3088681306760055191	6e9b9c5cd34e4d63f787f3bccdd7891c	VISA 16 digit	37.786468621871137	-122.416138395338351
1656	2019-06-25 08:29:16	2019-06-25	Kamron Volkman-Padberg	kamron.volkman.padberg@warmmail.com	San Francisco	California	3096761922113506053	263932ae8fd942b8294f142da5584b17	Mastercard	37.7671872929040973	-122.404276830108756
1657	2019-06-25 10:39:02	2019-06-25	Christi Wiegand	christi.wiegand@geemail.com	Oakland	California	4789687259595750	5f1721476b76b6a723ca73b324cce05f	JCB 16 digit	37.8033926138654834	-122.268747531891407
1658	2019-06-25 12:44:49	2019-06-25	Montana Nikolaus	montana.nikolaus@geemail.com	San Francisco	California	3112374795183787806	f9887eeac1ca70fdfbe19ab0c61d8c7a	American Express	37.7785025082013135	-122.454328292452672
1659	2019-06-25 14:28:50	2019-06-25	Mel Hauck MD	mel.hauck.md@geemail.com	San Francisco	California	869988289315414726	63799d1c069c2d0ab3b7942f5bdba999	VISA 16 digit	37.7686623100117558	-122.401108498859273
1660	2019-06-25 15:11:33	2019-06-25	Dione Cronin	dione.cronin@geemail.com	Oakland	California	676364499002109	5e7625baec966211f191ddf7e878447b	Maestro	37.7871531725605294	-122.25195442122272
1661	2019-06-25 18:16:45	2019-06-25	Dr. Ottie Kuhlman III	dr.ottie.kuhlman.iii@geemail.com	San Francisco	California	869985221057705634	41a90a1adcdf85e964cb2d541b4f232e	Mastercard	37.7747285277227007	-122.441965853947778
1662	2019-06-25 21:35:33	2019-06-25	Ms. Kizzie Zemlak PhD	ms.kizzie.zemlak.phd@geemail.com	Boston	Massachusetts	210049969495622275	08a6d54434baa8434691988b55567fff	VISA 16 digit	42.4072988518681413	-71.0743978680063009
1663	2019-06-25 22:29:31	2019-06-25	Dr. Ebba McClure	dr.ebba.mcclure@geemail.com	Los Angeles	California	53126804321245486	f8744befc12203bc6afa9060a98e43bd	JCB 15 digit	34.0059721581503709	-118.499529138346389
1664	2019-06-25 23:54:45	2019-06-25	Malvina Brekke	malvina.brekke@woohoo.com	Oakland	California	180008899843750859	a922d36cbd144ce4769bd7f5af63d2c9	JCB 16 digit	37.7759489725304505	-122.292449711378609
1665	2019-06-26 00:52:20	2019-06-26	Zaire Stark-Veum	zaire.stark.veum@geemail.com	Oxnard	California	4817743993740	a4e3c34b9037d38c61b92950f2703a48	Discover	34.2557036504570434	-119.23574701053127
1666	2019-06-26 00:56:07	2019-06-26	Mr. Jadyn Wehner II	mr.jadyn.wehner.ii@geemail.com	San Francisco	California	3024932233176213	ee51bd23151cbf721cf0ace36fd8bc35	American Express	37.7359551710813648	-122.412324774015389
1667	2019-06-26 01:41:13	2019-06-26	Cari Bartoletti	cari.bartoletti@warmmail.com	San Francisco	California	6011778320400606044	ce575b11063146649fe973df01bb0014	Maestro	37.8123132941843849	-122.430784351381632
1668	2019-06-26 04:13:04	2019-06-26	Kirstin Klocko	kirstin.klocko@geemail.com	San Francisco	California	6011334253599190321	6e89157bc92ed79b1caceb6a2b12de6b	Voyager	37.7703382428710484	-122.447806540672318
1669	2019-06-26 07:18:55	2019-06-26	Miss Layla King MD	miss.layla.king.md@geemail.com	Honolulu	Hawaii	3759120457814495	5b2698724168cd000671348d61b89270	Voyager	21.2987938324671262	-157.860153309742373
1670	2019-06-26 09:22:12	2019-06-26	Maryellen Jones MD	maryellen.jones.md@geemail.com	San Francisco	California	51113676385139838	972b1df9f9f493c01b5561c9c6f7ccc2	Discover	37.7741400055031846	-122.425612393451601
1671	2019-06-26 11:53:57	2019-06-26	Miss Nakisha Pfannerstill	miss.nakisha.pfannerstill@geemail.com	San Francisco	California	4436116435412299	7e5ec53637abe1658c85a5b085ab714c	JCB 15 digit	37.7547377633483734	-122.46954989245755
1672	2019-06-26 13:35:49	2019-06-26	Kathey Ferry	kathey.ferry@geemail.com	San Francisco	California	3023147522104047	4fbf8b3c5c606c3ed1043dde0e30fb3c	Discover	37.782388644335434	-122.4324500886447
1673	2019-06-26 15:03:08	2019-06-26	Roxy Rowe-Braun	roxy.rowe.braun@woohoo.com	San Francisco	California	3709771260445918	8b847712b67dc522a78f1a963564bf60	JCB 16 digit	37.7729980057855173	-122.44499440723547
1674	2019-06-26 20:02:06	2019-06-26	Ayden Senger Jr.	ayden.senger.jr.@warmmail.com	Berkeley	California	6011865289812784661	afe7350eafea77306bf0688340ab7368	American Express	37.8813974019069803	-122.264045873490929
1675	2019-06-26 20:34:17	2019-06-26	Elmo Champlin-Waelchi	elmo.champlin.waelchi@geemail.com	Oakland	California	6011706208087341638	5f8b9967769d5ef37d8c984e60d1376d	Voyager	37.7836364575677095	-122.268565307408764
1676	2019-06-26 23:08:55	2019-06-26	Mrs. Josefita King DDS	mrs.josefita.king.dds@woohoo.com	San Francisco	California	51712685226112370	9fd0505b85ad58c482c441f3fd6a0643	Diners Club / Carte Blanche	37.770336882354151	-122.409738331681794
1677	2019-06-27 04:00:22	2019-06-27	Alissa Reichert DDS	alissa.reichert.dds@geemail.com	Oakland	California	869943681111605735	9a4a5ccb4c67229fa6e7198e647d8807	JCB 15 digit	37.7755798563847236	-122.292258678629423
1678	2019-06-27 07:08:41	2019-06-27	Liza Connelly	liza.connelly@geemail.com	San Francisco	California	3337068371241486004	063b3f00295043dab8f680c2ee272060	VISA 16 digit	37.7760727806121679	-122.477278107219362
1679	2019-06-27 09:52:34	2019-06-27	Jakobe Harber	jakobe.harber@woohoo.com	Oakland	California	561286226216769	f06e9f09756f6e569dbaff54801e7e21	JCB 16 digit	37.7973641895264194	-122.288239613067446
1680	2019-06-27 10:04:24	2019-06-27	Shavon Schultz-Sawayn	shavon.schultz.sawayn@geemail.com	Beaumont	Texas	4474584165003328	c7daabf37989769642c4b579c67d7c96	VISA 16 digit	30.1667565768189725	-94.0662100530017256
1681	2019-06-27 10:14:42	2019-06-27	Glynda Ritchie-Will	glynda.ritchie.will@geemail.com	Oakland	California	6011119509868028398	e2b2638e81b5758ced06986eddcadca8	JCB 16 digit	37.8144638549782215	-122.242370917898754
1682	2019-06-27 11:05:20	2019-06-27	Case Kassulke-Mohr	case.kassulke.mohr@geemail.com	San Francisco	California	4555191119141	028d4d0dc3e8ca5a296c9dafecda5436	VISA 16 digit	37.7556380266481426	-122.45355088739278
1683	2019-06-27 12:24:49	2019-06-27	Davina Kuvalis	davina.kuvalis@geemail.com	Oakland	California	4625228341565283	f854b9d7addf9b8b1db56a99e713706e	JCB 15 digit	37.7901076917409924	-122.268469831903985
1684	2019-06-27 14:00:50	2019-06-27	Mr. Ralph Frami	mr.ralph.frami@geemail.com	San Francisco	California	4381838964110102	a0dcd7bc9137b2db5f3210d643387725	Voyager	37.7473248361092288	-122.461609941779173
1685	2019-06-27 15:07:48	2019-06-27	Miss Mittie Corwin PhD	miss.mittie.corwin.phd@geemail.com	San Francisco	California	180067496115721169	63bb3b5e9d8c9b1cbe3e354639e96302	American Express	37.7581663735039967	-122.426152540420048
1686	2019-06-27 19:27:38	2019-06-27	Ms. Maliah Trantow	ms.maliah.trantow@woohoo.com	Philadelphia	Pennsylvania	869960613989403719	87902429d9dd349b0977ae77b5f5fb1f	VISA 16 digit	39.9472612787462751	-75.1476251390196381
1687	2019-06-27 19:56:21	2019-06-27	Dr. Alan Simonis Jr.	dr.alan.simonis.jr.@geemail.com	San Francisco	California	4654807434703374	9a40a33d9da6f3a809c1145d50fdb254	Voyager	37.7888670307643366	-122.427594125068893
1688	2019-06-27 23:15:21	2019-06-27	Dominick Kassulke-Orn	dominick.kassulke.orn@geemail.com	Berkeley	California	3528558730095861454	9101ce57879b53ba875ec6c915cf3531	JCB 16 digit	37.8991898475318578	-122.237638540955459
1689	2019-06-28 02:09:16	2019-06-28	Larry Steuber-Ortiz	larry.steuber.ortiz@geemail.com	San Francisco	California	4688984898777	1b91ead38bd95a414b5eb8a6873163ee	Discover	37.7745329722844119	-122.421447176226266
1690	2019-06-28 03:32:18	2019-06-28	Jennings Lowe Sr.	jennings.lowe.sr.@geemail.com	Philadelphia	Pennsylvania	51100250493578512	74ba4c8365748702da90dc9ca53b3e1f	VISA 16 digit	39.9910706226207324	-75.0369842745728874
1691	2019-06-28 05:26:43	2019-06-28	Goldie Gorczany	goldie.gorczany@geemail.com	San Francisco	California	3337133861858295962	adbb70eb4322ce8c62117cbdfc30500c	JCB 16 digit	37.7458639701808707	-122.441264630504463
1692	2019-06-28 09:10:46	2019-06-28	Garnett Sauer	garnett.sauer@geemail.com	Berkeley	California	3088609016505675174	b289c2d86a454fce42faf7da7484d5e1	VISA 16 digit	37.8520721104846629	-122.253663409621282
1693	2019-06-28 11:29:15	2019-06-28	Miss Cheryl Dooley DVM	miss.cheryl.dooley.dvm@geemail.com	San Francisco	California	3012483888251093	d6aaa97853c9a1a5069047e7dedc267b	VISA 16 digit	37.7473654595229462	-122.427889527037991
1694	2019-06-28 11:48:36	2019-06-28	Dr. Jelani Kilback II	dr.jelani.kilback.ii@geemail.com	San Francisco	California	3057409154245753	69951db6d284b6956dc1f2bb01f2c869	Discover	37.763724628397533	-122.427649009904286
1695	2019-06-28 11:50:27	2019-06-28	Tammie Little	tammie.little@geemail.com	Tyler	Texas	4996538631614	9582a8cb63958456b23fe958cc0a2bc6	JCB 16 digit	32.3297761037528559	-95.3684844462774635
1696	2019-06-28 13:20:50	2019-06-28	Bethel Barrows-Muller	bethel.barrows.muller@woohoo.com	San Francisco	California	3158361550375083687	096307e77926e14f8edb3b914dfa6b73	Voyager	37.7882994139912753	-122.421375664721253
1697	2019-06-28 15:25:53	2019-06-28	Fannie Schultz	fannie.schultz@warmmail.com	San Francisco	California	6011579368029825900	ea6a14e157dc2ec3af4ba5281638386b	Discover	37.7668137544785694	-122.435689226925632
1698	2019-06-28 15:32:28	2019-06-28	Idella Marks	idella.marks@geemail.com	Oakland	California	589371564436468	00a051c6d5bd9a4aef16a6544c79eab1	American Express	37.8416716570597842	-122.281177017866568
1699	2019-06-28 15:49:50	2019-06-28	Erla Becker	erla.becker@woohoo.com	San Francisco	California	3438932908727068	2f4e391644f8a60aa92c7628bb43f7c6	JCB 16 digit	37.7729945295956213	-122.424825440953583
1700	2019-06-28 16:14:59	2019-06-28	Neha Waelchi	neha.waelchi@geemail.com	San Francisco	California	210084720387696000	119b81ac56cbfb4f3d1d9de7549c4f8a	Voyager	37.7701441373343059	-122.408814561170871
1701	2019-06-28 22:02:17	2019-06-28	Mrs. Pairlee Leuschke PhD	mrs.pairlee.leuschke.phd@geemail.com	San Francisco	California	52159145955156296	961c801083b058800fd7671a4fbc3666	VISA 13 digit	37.775992114109556	-122.418930122965804
1702	2019-06-28 22:57:30	2019-06-28	Mrs. Candida Gulgowski	mrs.candida.gulgowski@geemail.com	San Francisco	California	869922667485345805	2fa4b2c30d06298604855a00828454c4	JCB 15 digit	37.7688698163171637	-122.433469268727464
1703	2019-06-28 23:54:36	2019-06-28	Keli Weissnat	keli.weissnat@geemail.com	San Francisco	California	676324146501176	37efb51401e385b9cd546e7806c6b35f	VISA 16 digit	37.8119605603491422	-122.422847097816216
1704	2019-06-29 02:15:27	2019-06-29	Miss Rosella Thompson DDS	miss.rosella.thompson.dds@geemail.com	San Francisco	California	869903375672118273	df9f927fd98197e3b7a6ce957414ee50	Voyager	37.7999201604187149	-122.446564648157462
1705	2019-06-29 04:45:36	2019-06-29	Miss Lucinda Haag	miss.lucinda.haag@geemail.com	San Francisco	California	3528004298101894836	ef96b195248cad0d988c79036a8f78a4	JCB 16 digit	37.7632058195859486	-122.459092606009662
1706	2019-06-29 09:47:59	2019-06-29	Marci Bernier	marci.bernier@geemail.com	San Francisco	California	4471346641320780	b4e489350085273440f0717261775028	VISA 13 digit	37.7735053684452708	-122.45590051168432
1707	2019-06-29 10:34:31	2019-06-29	Derald Schiller	derald.schiller@geemail.com	Oakland	California	3088242010214556943	f19ea986cfee7a46dc24ef57970df0b0	VISA 16 digit	37.8026475557204265	-122.278303491982513
1708	2019-06-29 10:55:14	2019-06-29	Kory Mueller	kory.mueller@geemail.com	San Francisco	California	869998202712225577	d7c30123c544f0fab2e160af074b8185	Voyager	37.7677991091783625	-122.459543421448103
1709	2019-06-29 14:12:27	2019-06-29	Malissie Wilkinson DVM	malissie.wilkinson.dvm@woohoo.com	Simi Valley	California	4262361629443	7d7092e126a0f0585fe55f5f2942c40f	JCB 15 digit	34.2343619089346376	-118.728053821310411
1710	2019-06-29 15:08:41	2019-06-29	Linnie Bogan DDS	linnie.bogan.dds@geemail.com	Costa Mesa	California	3158270575333636698	2576a5e170f645900e9c2179cd04bcad	American Express	33.6282258302919601	-117.82916645890586
1711	2019-06-29 15:31:43	2019-06-29	Taraji Maggio	taraji.maggio@geemail.com	San Francisco	California	52779470185184474	9a3cf55f386368a6a53ac71c4d746eb4	VISA 16 digit	37.7989795336671008	-122.389584780079886
1712	2019-06-29 15:31:44	2019-06-29	Mr. Billy Leuschke	mr.billy.leuschke@warmmail.com	San Francisco	California	869983796043906521	a1462baadc8a720a71003841302079c3	VISA 16 digit	37.7746819227042394	-122.425444383152097
1713	2019-06-29 15:54:25	2019-06-29	Charley Morissette	charley.morissette@geemail.com	San Francisco	California	52041664803284763	4036378e9850f91f2f699cade55702cf	American Express	37.7837665248634735	-122.409178291447333
1714	2019-06-29 16:51:50	2019-06-29	Jeanette Ullrich	jeanette.ullrich@geemail.com	Oakland	California	4462114901731	b1eab3012773e5d14c7aecc54cbb3704	Mastercard	37.7997900188224918	-122.251556572213829
1715	2019-06-29 16:54:39	2019-06-29	Dr. Dessie Sauer MD	dr.dessie.sauer.md@geemail.com	Oakland	California	3011120053295296	7f88bcceae1ecf97576640898f7ddb2f	Discover	37.8167081371102114	-122.259481723856624
1716	2019-06-29 18:04:55	2019-06-29	Dr. Vander Schmeler Jr.	dr.vander.schmeler.jr.@geemail.com	Oakland	California	180080113159770308	ad55dcae91087b3ba0898ab16b20809d	American Express	37.7794706906929108	-122.329329895548668
1717	2019-06-29 22:26:09	2019-06-29	Alden Stiedemann	alden.stiedemann@geemail.com	San Francisco	California	3031156792152653	9bbc5ac767482e295a26c4ec91c7d625	JCB 16 digit	37.7988484762042773	-122.415332482759979
1718	2019-06-29 23:00:44	2019-06-29	Zion Oberbrunner	zion.oberbrunner@geemail.com	Oakland	California	3158263530920078860	ad678b08ea688f523a4d5145a2b09b6a	Maestro	37.7779244463983801	-122.276538974363746
1719	2019-06-30 01:09:04	2019-06-30	Dr. Ewell Wuckert DDS	dr.ewell.wuckert.dds@woohoo.com	San Francisco	California	4960687149778	fb6dd911acde69932292abbd15880185	Discover	37.8271001410872714	-122.391089575955021
1720	2019-06-30 03:37:35	2019-06-30	Precious Nicolas	precious.nicolas@geemail.com	San Francisco	California	3052126516306249	ec153fb076fde57bbe364817a1cc5de6	American Express	37.7809151576027134	-122.444039402163085
1721	2019-06-30 05:53:14	2019-06-30	Amina Feeney MD	amina.feeney.md@geemail.com	Berkeley	California	3009050018660296	ea78d5f3bb27a2e5ba9d2ba7fe733800	Maestro	37.8404085652906943	-122.283911946047525
1722	2019-06-30 06:34:04	2019-06-30	Theda Hauck	theda.hauck@geemail.com	San Francisco	California	3528053599046795156	5aaffe5beaffe6630830d090cefefcde	JCB 16 digit	37.7393168116186644	-122.452649792272837
1723	2019-06-30 08:18:30	2019-06-30	Mercedes Kemmer-Wisozk	mercedes.kemmer.wisozk@geemail.com	San Francisco	California	52869787848677227	b7de7454c98f614923b0b30e554abd29	VISA 16 digit	37.7880993185003433	-122.434968577960404
1724	2019-06-30 12:21:16	2019-06-30	Erika Purdy	erika.purdy@geemail.com	Chicago	Illinois	3088705009621550523	e7f8b1b34cbe55d4dac5f39883a2d504	Mastercard	41.8243928714957107	-87.6179882747616574
1725	2019-06-30 12:27:48	2019-06-30	Chynna Jacobson	chynna.jacobson@geemail.com	Sacramento	California	3096126258656021337	f2885b2a57efbaed88161b33b7425d7c	Mastercard	38.5190782842025143	-121.44072402708828
1726	2019-06-30 12:30:17	2019-06-30	Braxton Hilll	braxton.hilll@woohoo.com	Berkeley	California	3528778974936330568	b6a7fbcc9778cd7dc342db1b3a7e3562	Mastercard	37.8731282745136255	-122.241965897660947
1727	2019-06-30 15:05:37	2019-06-30	Chyna Ziemann	chyna.ziemann@geemail.com	San Francisco	California	210097080476892563	76bc08047cccf76ec64ffa0028b49180	Voyager	37.7945142740886482	-122.389364606651426
1728	2019-06-30 16:40:00	2019-06-30	Tinie O'Kon	tinie.o'kon@geemail.com	Oakland	California	4377547024317	fdea36fafaf7caf3f4d60aa6c8fc87b6	Discover	37.7929799769841139	-122.291631616396103
1729	2019-06-30 19:46:31	2019-06-30	Mrs. Scarlet Wintheiser DVM	mrs.scarlet.wintheiser.dvm@geemail.com	Oakland	California	676265761204919	eb8c381cc383d52e38fd4c09c119d697	Voyager	37.794149825814138	-122.247469980104214
1730	2019-06-30 21:40:34	2019-06-30	Dr. Frona Kilback DVM	dr.frona.kilback.dvm@warmmail.com	San Francisco	California	3096452482341259748	5cf5c05ea3bad5874a8e9b4461a9820b	Mastercard	37.8171579331483727	-122.388512880758427
1731	2019-06-30 22:40:29	2019-06-30	Antione Abernathy	antione.abernathy@woohoo.com	San Francisco	California	180074434283645333	e81461c6360c581b44dc63b7b3bc7555	JCB 16 digit	37.7917717680010412	-122.429263205028576
1732	2019-06-30 23:14:07	2019-06-30	Porter Huel	porter.huel@geemail.com	San Francisco	California	3028975821397119	787a892c12c803c448c1df7224093332	JCB 16 digit	37.7817298263766972	-122.426536907409769
1733	2019-07-01 05:56:59	2019-07-01	Ebba Gutkowski	ebba.gutkowski@geemail.com	Oakland	California	3449125453327528	6e9f2fff45f2af3f8824879f03c0e398	VISA 16 digit	37.7941988305489147	-122.298452407097201
1734	2019-07-01 08:01:43	2019-07-01	Jaelynn Metz	jaelynn.metz@geemail.com	Los Angeles	California	3158752632641876933	20031b450f6ea27967cd0d6436c8df85	Discover	34.1024711803864662	-118.4975089767009
1735	2019-07-01 12:42:47	2019-07-01	Kami Hoeger	kami.hoeger@geemail.com	San Francisco	California	675989325615477	37e59cc07f432fe279f26c8bcc4e59cd	JCB 16 digit	37.7954828329824863	-122.434592880386006
1736	2019-07-01 13:42:03	2019-07-01	Laddie Luettgen	laddie.luettgen@geemail.com	San Francisco	California	3434734802486922	b37b4113e6cc3744fc547ffe51a6676c	JCB 16 digit	37.7517680302159206	-122.396228804206018
1737	2019-07-01 14:38:04	2019-07-01	Julianne Lind-Breitenberg	julianne.lind.breitenberg@geemail.com	Oakland	California	3158434953952153662	56603690f1b7d1be4533ee62a42abd3b	VISA 13 digit	37.7928806907595813	-122.245524879610628
1738	2019-07-01 17:56:01	2019-07-01	Dr. Indiana Nikolaus PhD	dr.indiana.nikolaus.phd@warmmail.com	San Francisco	California	869999582485265101	af8b1d1d9986024b117e2a91d506be54	VISA 16 digit	37.7467817411112065	-122.442489801379352
1739	2019-07-01 18:37:59	2019-07-01	Taniyah Lesch	taniyah.lesch@warmmail.com	San Francisco	California	869975945455642146	84d5f28f68beb8a2378cf5fa5b559545	JCB 16 digit	37.7870490962360819	-122.475875883465662
1740	2019-07-01 19:56:39	2019-07-01	Delwin Smith	delwin.smith@geemail.com	Phoenix	Arizona	210022167432171347	f3014f84b30ec8b278de8fabffe6db02	American Express	33.5708233534291409	-112.076030092399947
1741	2019-07-01 20:11:24	2019-07-01	Hildred Upton	hildred.upton@geemail.com	San Francisco	California	3158431336179983884	41e86529ef6f52891adb8492856f1148	Diners Club / Carte Blanche	37.7733662391658669	-122.467133460621994
1742	2019-07-01 20:33:29	2019-07-01	Kristoffer Koch	kristoffer.koch@woohoo.com	San Francisco	California	3782367016218921	7cb219e043b0f241b299d44c08b3e095	JCB 16 digit	37.7963030701347336	-122.419484580529883
1743	2019-07-01 22:47:37	2019-07-01	Ricky Wiza	ricky.wiza@geemail.com	Berkeley	California	3337764959916467957	e052eb63e2a4078a5eb0a8507a30bf08	JCB 16 digit	37.8636719753038591	-122.278670064599225
1744	2019-07-02 02:23:16	2019-07-02	Connie Klocko	connie.klocko@woohoo.com	Los Angeles	California	210054579657732390	c45a69c1748d22966e4e37e2242f7534	Discover	34.1169310362875464	-118.419217071634904
1745	2019-07-02 09:36:50	2019-07-02	Celie Mayer	celie.mayer@geemail.com	San Francisco	California	6011743217698564608	2a0412fbb5abf64b0fd4a3faa0877054	Voyager	37.7758541393207139	-122.458065209820063
1746	2019-07-02 11:42:40	2019-07-02	Mr. Milan Quigley	mr.milan.quigley@woohoo.com	Berkeley	California	4937873195032493	4d5e934f5e40e4b41acc1d50f8f33978	Maestro	37.8800364609212394	-122.30731957910659
1747	2019-07-02 14:18:10	2019-07-02	Mr. Jerimiah Herzog Sr.	mr.jerimiah.herzog.sr.@warmmail.com	San Francisco	California	6011307018816507364	2afb4cd1c2d80f4b6dd7a800cd88e71d	VISA 16 digit	37.7695946622997525	-122.472350047923015
1748	2019-07-02 15:14:52	2019-07-02	Miss Norma Fritsch PhD	miss.norma.fritsch.phd@geemail.com	San Francisco	California	180023958586250278	4e733ef8fcb4e433f30457a1823fa251	Maestro	37.8156344583121466	-122.421373123309976
1749	2019-07-02 15:41:20	2019-07-02	Ah Erdman	ah.erdman@geemail.com	Philadelphia	Pennsylvania	3009802207334525	d81f80e459af1728acefe13f66ac59b5	VISA 16 digit	40.0766620846424217	-75.169338151336845
1750	2019-07-02 16:34:42	2019-07-02	Tella Waelchi	tella.waelchi@geemail.com	Berkeley	California	3033155315173988	7f53bfd06a05fd323743ac2f0c89a9f8	JCB 15 digit	37.8463343906986438	-122.277440371431851
1751	2019-07-02 16:48:10	2019-07-02	Leigh Heathcote	leigh.heathcote@geemail.com	San Francisco	California	589314741564356	83de7b289d6f196c7a66ef39e1bba43d	JCB 16 digit	37.7580090395461028	-122.419914143375038
1752	2019-07-02 17:41:53	2019-07-02	Willian Carter	willian.carter@geemail.com	Berkeley	California	869981583060441406	7cf8e7f4181ab82c3cebcd50ae3df117	Diners Club / Carte Blanche	37.8623393000891824	-122.230217916031705
1753	2019-07-02 20:59:10	2019-07-02	Madaline O'Reilly	madaline.o'reilly@woohoo.com	San Francisco	California	4485661539993736	ff7756f07ccbcc26592557eb7579ce2e	Discover	37.7873986445012164	-122.443634905058019
1754	2019-07-02 21:21:18	2019-07-02	Dr. Maxx D'Amore DVM	dr.maxx.d'amore.dvm@woohoo.com	San Francisco	California	3096887127713025004	3d3910db9fb4282ec5d7419a45b0ee40	JCB 16 digit	37.7806500762485697	-122.454234254701959
1755	2019-07-02 23:11:54	2019-07-02	Mr. Aryan Morissette Sr.	mr.aryan.morissette.sr.@geemail.com	San Francisco	California	3528597468066113851	a8f82c49e88447e9f090bad0d462065a	Voyager	37.7547537428617801	-122.403658818709673
1756	2019-07-03 01:35:12	2019-07-03	Adrien Johnson-Fisher	adrien.johnson.fisher@warmmail.com	Berkeley	California	6011127898903724867	cec299ba9d78172f495d975f5cb11c66	Maestro	37.8760579407517355	-122.261015799713391
1757	2019-07-03 01:54:44	2019-07-03	Gaylon Boyle	gaylon.boyle@geemail.com	Berkeley	California	6011476053391545344	56d39d70fbc605500489d45dde84276a	Mastercard	37.8777777649300873	-122.251584523999142
1758	2019-07-03 04:00:06	2019-07-03	Caydence Satterfield	caydence.satterfield@geemail.com	San Francisco	California	4017150342143496	67df027b64d55678f487707584f64e51	VISA 16 digit	37.7682535980938709	-122.451808748469745
1759	2019-07-03 07:14:47	2019-07-03	Torrance Hegmann	torrance.hegmann@geemail.com	San Francisco	California	52476182213644140	af4da499c0e570a0a4032895a1a0eee8	JCB 16 digit	37.758702575020294	-122.433471478969338
1760	2019-07-03 08:24:08	2019-07-03	Miss Chiquita Dooley DDS	miss.chiquita.dooley.dds@geemail.com	Oakland	California	6011990773152153627	7ae81aa82bb91e989d991be8321be3d5	JCB 16 digit	37.8030939424241836	-122.244344046951525
1761	2019-07-03 10:39:26	2019-07-03	Henri Kuhic I	henri.kuhic.i@geemail.com	San Francisco	California	3158682734455438167	fb193157c55ea401c504ac613ce4cc4d	Maestro	37.7857569115516014	-122.402413940057244
1762	2019-07-03 13:19:06	2019-07-03	Thad Wunsch	thad.wunsch@geemail.com	Minneapolis	Minnesota	3748939773598241	73203d5b7e8726fa81ca7da8e98b17d3	Mastercard	45.0597442396070775	-93.3186869656473306
1763	2019-07-03 14:10:56	2019-07-03	Nell Bruen DVM	nell.bruen.dvm@woohoo.com	Berkeley	California	4908338026712171	fa8d5ffeadbe4979a14589d555999daa	Mastercard	37.8896537333168482	-122.279739583919863
1764	2019-07-03 14:31:13	2019-07-03	Cain Eichmann	cain.eichmann@geemail.com	San Francisco	California	869910190803705166	7667d169d2b8dc657e5334793f745cba	Voyager	37.7488941232646127	-122.43208607429365
1765	2019-07-03 15:35:44	2019-07-03	Olga Renner	olga.renner@geemail.com	Oakland	California	54011484695954035	b5a44dbbbb63fb1b77fa868f95d533b9	Maestro	37.8138253561346005	-122.265108608584924
1766	2019-07-03 20:01:01	2019-07-03	Rocky Ankunding II	rocky.ankunding.ii@geemail.com	Nashville	Tennessee	6011503770898651591	a12f6bfe0cef6cff4ef6c8674261ba08	American Express	36.1705542346585531	-86.8256106388196258
1767	2019-07-04 02:20:53	2019-07-04	Irving Sanford	irving.sanford@geemail.com	San Francisco	California	3337205755647913815	2d5de18d62a39a2ea57d98f85194425f	Maestro	37.7412885686675565	-122.42814591454011
1768	2019-07-04 04:46:10	2019-07-04	Dr. Yasmeen Blanda	dr.yasmeen.blanda@woohoo.com	New York	New York	6011895645175692839	0aebcbda1db8ea36abdb42c6e0da3920	Diners Club / Carte Blanche	40.6250660870447717	-73.8816810335393939
1769	2019-07-04 04:52:17	2019-07-04	Chelsea Rodriguez-Hammes	chelsea.rodriguez.hammes@geemail.com	San Francisco	California	54110680983772308	47fb25018e6a4e230090e825faebcff6	VISA 16 digit	37.7747628313948596	-122.42306655008106
1770	2019-07-04 06:10:36	2019-07-04	Wayne Bayer-Sporer	wayne.bayer.sporer@geemail.com	San Francisco	California	869924848590475186	93bdb4e6454bef1013524cb97d785913	Voyager	37.789394227985774	-122.420083475158165
1771	2019-07-04 06:47:45	2019-07-04	Shaquita Roberts	shaquita.roberts@geemail.com	Berkeley	California	4699399224217549	23e1582143b1459fdb22256d567af8ae	VISA 16 digit	37.8561203451081454	-122.242900715600257
1772	2019-07-04 08:33:51	2019-07-04	Dot Hand	dot.hand@woohoo.com	Oakland	California	4830637293903	cce07a7408b38959af16b600d9820d82	JCB 16 digit	37.8048264658113595	-122.291113553003612
1773	2019-07-04 09:04:45	2019-07-04	Mr. Bailey Batz	mr.bailey.batz@warmmail.com	San Francisco	California	4923567378734638	8a0713435faff1913a70caf7e0e54770	American Express	37.7461737030644215	-122.418565288141565
1774	2019-07-04 11:52:12	2019-07-04	Jalon Marks III	jalon.marks.iii@woohoo.com	San Francisco	California	4001000301505	f03a5d01398a3385dba2952e1cbd7821	VISA 16 digit	37.766114817533456	-122.463089841745813
1775	2019-07-04 13:00:06	2019-07-04	Dr. Edra West	dr.edra.west@geemail.com	San Francisco	California	4549352766402	19df57a30cae0f7f46e5dbe52c984bcc	JCB 16 digit	37.7954346663653027	-122.396624419035561
1776	2019-07-04 20:01:01	2019-07-04	Bethzy Beer	bethzy.beer@geemail.com	Kansas City	Kansas	180093798031746826	a3af0b44fed5ad99a30dbd797ea96f45	Voyager	39.1107694707717783	-94.8181658356387089
1777	2019-07-04 20:28:00	2019-07-04	Hjalmar Conroy	hjalmar.conroy@geemail.com	San Francisco	California	3710416794000014	c840c47becea1b10616762c4329b85e0	JCB 16 digit	37.7770111477096222	-122.43273441428029
1778	2019-07-04 22:28:32	2019-07-04	Chesley Jacobs	chesley.jacobs@warmmail.com	San Francisco	California	4858623849984820	bccba4f458cff969dc18e9f2f6a83a09	VISA 16 digit	37.7528780389892376	-122.423241189535844
1779	2019-07-05 04:38:16	2019-07-05	Bart Doyle I	bart.doyle.i@geemail.com	San Francisco	California	869962584965836982	c705118af20093248b51e8cc52e066f9	VISA 16 digit	37.7561952629249831	-122.419209838683784
1780	2019-07-05 05:13:56	2019-07-05	Doloris McLaughlin-Bayer	doloris.mclaughlin.bayer@geemail.com	San Francisco	California	503857516949930	cc96a949761ce500a2ef30eebb74e4c0	Discover	37.7241060734200886	-122.447571224091917
1781	2019-07-05 07:16:38	2019-07-05	Marlie Auer	marlie.auer@geemail.com	San Francisco	California	6011177540120472990	ee0b4bebe8983eb2b2eb5197939b44af	VISA 16 digit	37.7621058110144077	-122.445455044498644
1782	2019-07-05 07:45:44	2019-07-05	Antonio Greenholt V	antonio.greenholt.v@geemail.com	Oakland	California	180036721753673887	9ee338d72213a25db8b0f9ab0fe3e946	Diners Club / Carte Blanche	37.8135107055981052	-122.26101881823196
1783	2019-07-05 10:29:34	2019-07-05	Bertina Macejkovic DDS	bertina.macejkovic.dds@geemail.com	San Francisco	California	4377515968875437	e0be39009c0c799773cd790914babe9f	VISA 13 digit	37.7411992257731299	-122.450133299300504
1784	2019-07-05 11:07:11	2019-07-05	Ernestina Pacocha-Koepp	ernestina.pacocha.koepp@warmmail.com	Columbus	Ohio	4555395220625613	0e1c682b13e4c88ee03221207e671462	Discover	39.9002260867085283	-83.0653506879929466
1785	2019-07-05 13:02:59	2019-07-05	Addison Prosacco	addison.prosacco@woohoo.com	San Francisco	California	210006955042874981	ca317da2a458fa65f6b43e0d82e6c392	VISA 16 digit	37.7730060650472339	-122.442225342669389
1786	2019-07-05 13:39:47	2019-07-05	Alannah Beer	alannah.beer@woohoo.com	Berkeley	California	4126862624948685	5472d0e19544e966ace83f89c60e9960	Voyager	37.8452136215223192	-122.283584613472314
1787	2019-07-05 16:55:19	2019-07-05	Eudora Lynch-Emard	eudora.lynch.emard@geemail.com	San Francisco	California	3096882644831512270	6f7a7a0fac5600adf5c277d6cf795b39	VISA 13 digit	37.7820779680362904	-122.447232655360466
1788	2019-07-05 17:40:21	2019-07-05	Demarion Tromp	demarion.tromp@geemail.com	Berkeley	California	3112542201343602875	5cfbaf215894d8952a8975d9a9ce3053	Discover	37.8791891556525258	-122.26898691139823
1789	2019-07-05 20:51:46	2019-07-05	Littleton Zemlak	littleton.zemlak@geemail.com	Oakland	California	3528901594785170749	a9918d8bae06f9bc95e2f11cd5164a42	Voyager	37.7975081677966358	-122.273208279840574
1790	2019-07-05 21:53:03	2019-07-05	Xavier Hills PhD	xavier.hills.phd@geemail.com	San Francisco	California	52360502465287141	42dc6fef2e321321f0e4ef615d5e550e	Voyager	37.770460807767833	-122.416341978170294
1791	2019-07-05 22:18:43	2019-07-05	Porfirio Bruen	porfirio.bruen@woohoo.com	Berkeley	California	869946336115938783	896d16dbf48bdbc93c95ca161e151aee	American Express	37.8772034437935048	-122.276747746133879
1792	2019-07-05 22:49:40	2019-07-05	Aleck Macejkovic	aleck.macejkovic@geemail.com	San Francisco	California	869941336365928877	e11093399e201fdca38959380590486f	VISA 16 digit	37.7793640794696444	-122.424155621172247
1793	2019-07-05 23:08:51	2019-07-05	Arland Cruickshank	arland.cruickshank@warmmail.com	Denver	Colorado	4069720119184712	649260d4d32c8c40dc06558f7611cbab	Maestro	39.8349591302737593	-104.848951048847667
1794	2019-07-06 01:39:17	2019-07-06	Bee Hegmann	bee.hegmann@warmmail.com	San Francisco	California	180070614158892771	7ba63ac0c419ccef81ec9fd9211ab8b8	JCB 16 digit	37.8079745502256301	-122.420932939893035
1795	2019-07-06 01:53:05	2019-07-06	Reatha Funk	reatha.funk@woohoo.com	San Francisco	California	51014383333091407	02a683147004d229c9e12ebd048bbf5c	JCB 16 digit	37.7535721276876828	-122.426161603090861
1796	2019-07-06 05:48:47	2019-07-06	Alvera Wolf	alvera.wolf@geemail.com	San Francisco	California	3759622120472601	72836858b91f6a062851a4b32b34c1d3	VISA 16 digit	37.782174255157571	-122.407108661886639
1797	2019-07-06 07:04:39	2019-07-06	Mr. Grafton Lindgren	mr.grafton.lindgren@geemail.com	San Francisco	California	869903496568977984	f0dcd10e76761e31fb683df4beaca4a3	VISA 13 digit	37.7734907276012564	-122.407123578402192
1798	2019-07-06 12:00:48	2019-07-06	Riley Lockman	riley.lockman@geemail.com	San Francisco	California	6011812034613669826	208d5efde9f1dc79b4bd510502e184bd	Discover	37.777164065784973	-122.438773889230617
1799	2019-07-06 13:08:58	2019-07-06	Donavan Green	donavan.green@woohoo.com	San Francisco	California	3009217101185487	64a6ad18f700b1538270537a8a8d7d88	Mastercard	37.7357034982744537	-122.427983519633102
1800	2019-07-06 13:42:34	2019-07-06	Nolan Herman	nolan.herman@warmmail.com	San Francisco	California	869948237637281157	d8455133d30d6864e179da0c016b61ec	VISA 16 digit	37.7307895597284713	-122.466707813166764
1801	2019-07-06 14:23:44	2019-07-06	Milo Larkin	milo.larkin@geemail.com	San Francisco	California	3088136950045808436	fb68ea0029e48793c007732dab7c92e5	Maestro	37.7572499409152584	-122.432887212795066
1802	2019-07-06 17:01:08	2019-07-06	Beckham Cassin	beckham.cassin@geemail.com	Berkeley	California	4612118009127	0b2fed922fd7cbd242faf7c5f132c30a	VISA 16 digit	37.8781947930434555	-122.25935713158259
1803	2019-07-06 17:53:05	2019-07-06	Iris Koch	iris.koch@geemail.com	San Francisco	California	3096648098476469368	5c1b9f8c9be43aa7dd1b35ba8fbd93c9	VISA 16 digit	37.7622033123152221	-122.413740043690098
1804	2019-07-06 20:53:08	2019-07-06	Rheta Schaefer	rheta.schaefer@geemail.com	Oakland	California	4059389363437119	b5c3b479a96e3bbffb459e5f364bd8af	Voyager	37.7883723744259754	-122.284660573966889
1805	2019-07-06 20:53:25	2019-07-06	Spencer Bergnaum	spencer.bergnaum@geemail.com	San Francisco	California	3088555663584268274	5ee82c6a973e6bcc1c5071c66cd7644a	American Express	37.7633840783562604	-122.414305417043735
1806	2019-07-06 21:07:32	2019-07-06	Mazie Hagenes DVM	mazie.hagenes.dvm@geemail.com	San Francisco	California	6011928012820218091	4ee2828a2d9b14497d9880e1055c9f1c	Voyager	37.7968458134552421	-122.453448406768658
1807	2019-07-06 23:11:44	2019-07-06	Shanita King DDS	shanita.king.dds@geemail.com	Nashville	Tennessee	3112461808798204960	75f9f2e634c7c8f8fa5052d68d731bf2	Voyager	36.0891071697819967	-86.7501112969964652
1808	2019-07-06 23:44:43	2019-07-06	Kiley Marvin MD	kiley.marvin.md@geemail.com	Milwaukee	Wisconsin	676362636570749	43a6765dca38496662b3b0bd8e81c2f0	Discover	43.1189525547057357	-88.0087432760845871
1809	2019-07-07 01:33:32	2019-07-07	Odell Fadel	odell.fadel@geemail.com	San Francisco	California	180084195010745989	2728beb310e2e85349ebbbbbf8172677	American Express	37.7529559862550173	-122.461370544528904
1810	2019-07-07 05:50:07	2019-07-07	Cassidy Osinski	cassidy.osinski@woohoo.com	Berkeley	California	4978846311832	e7d91b4773e8c8e705de7903499b89fc	Discover	37.8704017959859485	-122.295010733846397
1811	2019-07-07 05:57:54	2019-07-07	Ailene Deckow MD	ailene.deckow.md@warmmail.com	Oakland	California	4882689082394431	7541388c9d8cf648503a9962932801da	JCB 15 digit	37.7873670645272668	-122.24694159785146
1812	2019-07-07 07:03:33	2019-07-07	Mrs. Jannette Braun	mrs.jannette.braun@geemail.com	San Francisco	California	3528451283818313229	8f6b73a5d82bb593c1a51f74bc6d34c7	JCB 16 digit	37.8103910228521158	-122.460505843361901
1813	2019-07-07 07:56:03	2019-07-07	Royce Nitzsche	royce.nitzsche@geemail.com	San Francisco	California	869907734760745361	74cf1a9f0cda21b6002d936c9856ca5a	Diners Club / Carte Blanche	37.7838149059627568	-122.44433320719817
1814	2019-07-07 09:35:59	2019-07-07	Alexina Collier DDS	alexina.collier.dds@woohoo.com	Dayton	Ohio	3007697070894205	db31e7b783b54c01e02888f5520e9dcc	Voyager	39.8094999800227569	-84.2481807789955326
1815	2019-07-07 10:08:20	2019-07-07	Mrs. Oralia Mills	mrs.oralia.mills@geemail.com	Berkeley	California	4881037097900795	081570e5d9dfff8a02ef9d8c865742ec	JCB 16 digit	37.8721440601059598	-122.314600900850436
1816	2019-07-07 10:46:49	2019-07-07	Lige Beatty	lige.beatty@warmmail.com	San Francisco	California	3484140606933037	4eaedb47019be462ba55404659348447	VISA 16 digit	37.7907669373069908	-122.432537178816986
1817	2019-07-07 11:28:44	2019-07-07	Estrella Jacobs MD	estrella.jacobs.md@woohoo.com	San Francisco	California	3431989411484634	94bbee2f12ebb7fa6e009f56465688a6	JCB 15 digit	37.8136566772273923	-122.40885418173194
1818	2019-07-07 12:15:28	2019-07-07	Edgardo Tromp-Wolff	edgardo.tromp.wolff@woohoo.com	Albuquerque	New Mexico	180035018191344739	4be785f2c0e81e782c0c2403b443985f	VISA 16 digit	35.0388461501471724	-106.747184558499242
1819	2019-07-07 14:20:25	2019-07-07	Patrick Daniel	patrick.daniel@geemail.com	Berkeley	California	55236986280340346	0d7acce1c4cecaaba5ac1351e59999c2	VISA 13 digit	37.8617121982567184	-122.279242060377968
1820	2019-07-07 16:28:23	2019-07-07	Ricardo Bechtelar	ricardo.bechtelar@geemail.com	San Francisco	California	6011704575516839719	bba2e85ce0f272147fffdb2c63c3e7c9	JCB 16 digit	37.7755954667088716	-122.427427634188348
1821	2019-07-07 19:07:05	2019-07-07	Soloman Daniel	soloman.daniel@warmmail.com	San Francisco	California	3528554798451468655	2e7563ec9758f015026bf8d585815706	JCB 16 digit	37.7317198630408157	-122.413767424674774
1822	2019-07-07 20:20:17	2019-07-07	Jenelle Feil-Boyer	jenelle.feil.boyer@geemail.com	San Francisco	California	55100952046677598	9a9759735a5903fb52c51c5af49f2902	Discover	37.7944603941864727	-122.424795420474325
1823	2019-07-07 23:45:32	2019-07-07	Bridger Weimann	bridger.weimann@geemail.com	San Francisco	California	3053781489249120	d3fb31cd3be3f0c9afcb925bad575fd6	JCB 16 digit	37.7784724319046461	-122.468723321331055
1824	2019-07-08 00:25:41	2019-07-08	Yoel Turner	yoel.turner@geemail.com	Los Angeles	California	54487976743520887	b536721c44033225123672a2530289c1	Mastercard	34.1110013036854554	-118.31269117728732
1825	2019-07-08 02:20:30	2019-07-08	Yolanda Crona	yolanda.crona@geemail.com	San Francisco	California	3158312708266254292	d9c78dd97e35226d94b9709579438a1b	Mastercard	37.7582652788937168	-122.424519882448919
1826	2019-07-08 02:35:33	2019-07-08	Dr. Lannie Gusikowski	dr.lannie.gusikowski@geemail.com	San Francisco	California	4392383827833746	4d38d06c56a26a36da45a45826f3c73f	JCB 16 digit	37.7542172802013312	-122.425916385188884
1827	2019-07-08 03:48:50	2019-07-08	Joselin Langosh DVM	joselin.langosh.dvm@geemail.com	Berkeley	California	3112921094887416989	437c404768bf2291120024be8682512a	VISA 13 digit	37.8754991066396869	-122.254889948325484
1828	2019-07-08 11:42:19	2019-07-08	Deena Klein-Koepp	deena.klein.koepp@geemail.com	San Francisco	California	4352135575343	b836d7492ee9de60b839550f424b9d4c	Diners Club / Carte Blanche	37.7771408180695261	-122.44257739681241
1829	2019-07-08 11:58:10	2019-07-08	Blake Walker DVM	blake.walker.dvm@woohoo.com	San Francisco	California	3112424091395414052	f6b036ceedd37898fee11135b3e2ee89	VISA 16 digit	37.7744546957444385	-122.427916716187625
1830	2019-07-08 13:44:34	2019-07-08	Brittani Shields DDS	brittani.shields.dds@geemail.com	Boston	Massachusetts	3056705445814153	0a0d2c30ef05e28f794350e6884fd6d7	American Express	42.4241215036883972	-70.9708284915376453
1831	2019-07-08 14:12:20	2019-07-08	Ab Raynor	ab.raynor@geemail.com	San Francisco	California	3096856891104151391	8dd1fa674c970af77fd3579382171806	Voyager	37.7744749709506848	-122.445773595112584
1832	2019-07-08 18:49:29	2019-07-08	Dr. Jed Lockman	dr.jed.lockman@warmmail.com	San Francisco	California	869921544272178486	8498aed3d37b2f59ce5a86160c685a90	American Express	37.7677160244173393	-122.44745905044411
1833	2019-07-08 20:49:20	2019-07-08	Arnetta Kerluke	arnetta.kerluke@geemail.com	San Francisco	California	4290871818438	0fd570f813ea0c15919eafbc816a2db3	VISA 13 digit	37.7955127589477655	-122.414794606951972
1834	2019-07-08 22:59:22	2019-07-08	Nunzio Sanford Sr.	nunzio.sanford.sr.@woohoo.com	Oakland	California	4834975488281705	031fb86a289fd9ece4f8ea00d1a752af	Maestro	37.8218465872742087	-122.257458304555399
1835	2019-07-09 01:17:04	2019-07-09	Ozell Farrell	ozell.farrell@warmmail.com	San Francisco	California	51132933182405566	a3d6c40855fdd70031e56a0343e43dc2	Discover	37.751080196950916	-122.471875257309236
1836	2019-07-09 02:29:02	2019-07-09	Urijah Rempel	urijah.rempel@geemail.com	Berkeley	California	869900091562740711	d8e9d1881e7ac3a0885086184352d891	Diners Club / Carte Blanche	37.8969400401716925	-122.236112900157764
1837	2019-07-09 02:45:56	2019-07-09	Burdette Baumbach I	burdette.baumbach.i@geemail.com	Jersey City	New Jersey	3718551318694033	8565cf144b70321962ab49a065e260c4	Diners Club / Carte Blanche	40.7659993555802842	-73.9677378710780289
1838	2019-07-09 05:19:02	2019-07-09	Berdie Bruen-Marks	berdie.bruen.marks@geemail.com	San Francisco	California	3000898619871459	db4fa7cc2a250e2112ec9de96e0efe92	Discover	37.7493336172001932	-122.425612853785935
1839	2019-07-09 12:43:56	2019-07-09	Hayward Parisian-Wolf	hayward.parisian.wolf@woohoo.com	San Francisco	California	210059272502398600	dc4d60760db1dd0eed1eeaafe79d947a	Mastercard	37.7965669138288121	-122.43554081822343
1840	2019-07-09 13:41:56	2019-07-09	Alexandro Keeling	alexandro.keeling@warmmail.com	San Francisco	California	3474766309491741	bc3f3dcddd772789fabe460c1af26249	Maestro	37.7624873600191364	-122.437075788410127
1841	2019-07-09 14:11:55	2019-07-09	Dr. Jay Heller II	dr.jay.heller.ii@geemail.com	San Francisco	California	210093234755988113	266be937feb3870d1c9408dae2be10f2	JCB 16 digit	37.7541905743241628	-122.430983958242592
1842	2019-07-09 15:07:30	2019-07-09	Ms. Erlinda Willms	ms.erlinda.willms@geemail.com	Oakland	California	4378294557705459	2d8e3c10338fa386cbf6d628d80cdb34	VISA 16 digit	37.8375409241705043	-122.249149365139502
1843	2019-07-09 16:03:55	2019-07-09	Sondra Bailey	sondra.bailey@warmmail.com	San Francisco	California	4680050119635193	6a2e30bac5eaafed6b9a6c32361eb9d7	VISA 16 digit	37.7623880137137249	-122.434135329503235
1844	2019-07-09 18:00:53	2019-07-09	Anton Mosciski	anton.mosciski@geemail.com	Berkeley	California	4774946872800980	d74b1d24215c3c1ff09186cae2c65977	Mastercard	37.8881894292158279	-122.237701274871668
1845	2019-07-09 19:25:09	2019-07-09	Samiyah Hodkiewicz-Douglas	samiyah.hodkiewicz.douglas@geemail.com	San Francisco	California	4949609070353323	45013f242e52e0c29d6804ab87662229	Mastercard	37.75227316620051	-122.424622838520108
1846	2019-07-09 20:47:36	2019-07-09	Shelvia Jenkins-Hermiston	shelvia.jenkins.hermiston@warmmail.com	Los Angeles	California	3045704202940310	30ae76b525d1f664bd8d8801d36e87cd	Diners Club / Carte Blanche	34.009306891062856	-118.401395679916433
1847	2019-07-10 00:04:49	2019-07-10	Janessa Graham	janessa.graham@geemail.com	San Francisco	California	4120035666397543	54e5370c4d3bc5bee6d80978efef551f	Diners Club / Carte Blanche	37.7865562583664811	-122.453384041870834
1848	2019-07-10 01:24:07	2019-07-10	Dr. Lex Rutherford Jr.	dr.lex.rutherford.jr.@warmmail.com	San Francisco	California	53146240577607275	cb0a3a1f0caca404661a7631676d44a4	Diners Club / Carte Blanche	37.7863048380692632	-122.427892791234967
1849	2019-07-10 01:46:57	2019-07-10	Rylan White	rylan.white@geemail.com	San Francisco	California	4361847387171298	1d96cd88a9a6f764269650ba517da245	VISA 16 digit	37.7781089137574	-122.443075656255786
1850	2019-07-10 02:04:44	2019-07-10	Trish Lesch	trish.lesch@geemail.com	San Francisco	California	3770369515488587	53700635cd84a943013171627079291b	Diners Club / Carte Blanche	37.7974245071331723	-122.429038753592849
1851	2019-07-10 03:04:08	2019-07-10	Jasiah Kessler	jasiah.kessler@geemail.com	Los Angeles	California	3449259672873598	28f0c1c0c1e38a46f701b1f3d85dd10d	Discover	33.9867181450460052	-118.328371452632538
1852	2019-07-10 06:39:14	2019-07-10	Bertina Muller-Ankunding	bertina.muller.ankunding@geemail.com	Berkeley	California	6011609419880745648	810843eea735582f6c86970b0f1e8ddd	JCB 16 digit	37.8703442295534316	-122.261329543407641
1853	2019-07-10 07:42:56	2019-07-10	Hollie Frami	hollie.frami@geemail.com	San Francisco	California	060436197259314	f9f4f51477fc10f476521480aa7663c9	Voyager	37.7497638151967791	-122.449022663094638
1854	2019-07-10 10:16:44	2019-07-10	Vonda Nitzsche-Collier	vonda.nitzsche.collier@warmmail.com	Oakland	California	55412395075780391	19275cb193a89d43934d54ddc8b25926	Discover	37.7849745016438874	-122.267880794642153
1855	2019-07-10 13:56:56	2019-07-10	Schley Johnson-Considine	schley.johnson.considine@geemail.com	San Francisco	California	3088385335198328986	77eff0f2d278c5210f778d84485dc4a0	JCB 16 digit	37.7650565440059509	-122.409854125725687
1856	2019-07-10 17:21:17	2019-07-10	Rashad Gleason	rashad.gleason@geemail.com	Berkeley	California	561266645390684	fd3c2199688f2be0aab23f13cb1a9973	Mastercard	37.8533083493017983	-122.276521201377264
1857	2019-07-10 17:37:34	2019-07-10	Cary Konopelski	cary.konopelski@geemail.com	Modesto	California	4878118788270279	016fc58b5316b4d08cf12d1bcc940a81	Voyager	37.6516233233734994	-120.994994367912412
1858	2019-07-10 20:35:43	2019-07-10	Domingo Greenfelder	domingo.greenfelder@geemail.com	Berkeley	California	4793633279129042	2dd753cf92e76bd2b3f7b44248c1d424	JCB 15 digit	37.8996875408665232	-122.279873470960382
1859	2019-07-10 23:18:14	2019-07-10	Deonta Ward-Kub	deonta.ward.kub@warmmail.com	Oakland	California	4793970163416	566110c5378479f62cd7da0bb84e8fa7	American Express	37.8039294669681141	-122.257421769190898
1860	2019-07-11 04:07:08	2019-07-11	Althea Pfannerstill	althea.pfannerstill@woohoo.com	Berkeley	California	3158336184204772161	30e4949685690dba093315b5c3ff4e28	JCB 16 digit	37.8542081162944228	-122.272868569305857
1861	2019-07-11 06:36:53	2019-07-11	Kristopher Schamberger	kristopher.schamberger@geemail.com	San Francisco	California	210045231082874767	cb1e3b7b56b301a3c3c97fd7bc3ed6b8	Mastercard	37.7862044290972037	-122.425181428262519
1862	2019-07-11 07:18:14	2019-07-11	Dr. Caleb Lubowitz II	dr.caleb.lubowitz.ii@warmmail.com	San Francisco	California	210064078319944889	350d7f13398e049095c17cac241534ca	VISA 16 digit	37.750647398012859	-122.425723948688599
1863	2019-07-11 11:34:26	2019-07-11	Hurbert Swaniawski	hurbert.swaniawski@woohoo.com	Oakland	California	3088133175269326278	4e3144d94c5241c5000cb507611e1e0f	Discover	37.7986912546755747	-122.325517708913935
1864	2019-07-11 13:42:46	2019-07-11	Cannie Schinner	cannie.schinner@geemail.com	San Francisco	California	6011780367139108897	9bb6d19b92b7dbf1fa9a49067bb87fe5	VISA 16 digit	37.7792653769597067	-122.414251282124042
1865	2019-07-11 13:50:18	2019-07-11	Mr. Buell Hermiston I	mr.buell.hermiston.i@warmmail.com	Oakland	California	51535091508064139	164315361cdb6cf83ec35eeb8b2bfd73	American Express	37.7982822678108263	-122.299481019636218
1866	2019-07-11 14:09:24	2019-07-11	Rayna Luettgen DDS	rayna.luettgen.dds@geemail.com	Berkeley	California	639090063543228	de3b0dc5aacffe169fed62614f436ec1	Discover	37.8806759929993646	-122.261909745222894
1867	2019-07-11 14:56:36	2019-07-11	Dr. Elma Maggio MD	dr.elma.maggio.md@woohoo.com	Berkeley	California	53903380338014404	568cc79c8c2e19c1df52e3ca2c324682	VISA 16 digit	37.8682601068574129	-122.294197155528906
1868	2019-07-11 18:06:01	2019-07-11	Mrs. Noretta Konopelski	mrs.noretta.konopelski@geemail.com	San Francisco	California	3096095246830310533	64310fdcaba65accb644fda56add74db	VISA 16 digit	37.7665854323604151	-122.445738322507324
1869	2019-07-11 18:18:43	2019-07-11	Theophile Ward	theophile.ward@geemail.com	Baltimore	Maryland	4599594455012145	51266230351aaa9278c03722550c7913	JCB 15 digit	39.2805470193736213	-76.6704090484902281
1870	2019-07-11 20:49:17	2019-07-11	Dr. Caleb Goldner DDS	dr.caleb.goldner.dds@geemail.com	San Francisco	California	3112764012230690639	222f647e0a80a7223e404a630892815f	VISA 16 digit	37.7919659643011485	-122.432931234386132
1871	2019-07-11 21:15:00	2019-07-11	Miss Enola Sporer	miss.enola.sporer@geemail.com	San Francisco	California	869981497609783683	685265887b53de56a6038efe084a6804	VISA 13 digit	37.7609868340147088	-122.434437753153674
1872	2019-07-11 23:16:38	2019-07-11	Melony Cronin-Abbott	melony.cronin.abbott@geemail.com	Chicago	Illinois	3112843662122080672	13e43785cd6a8aa02b0f64d1249bd448	Discover	41.7979694744873811	-87.6084426567919508
1873	2019-07-12 02:38:38	2019-07-12	Ossie Wilkinson	ossie.wilkinson@geemail.com	San Francisco	California	4841980015577592	5de59dec78a89599405dafbf82cbe225	VISA 16 digit	37.7598706029239608	-122.419166463746919
1874	2019-07-12 04:43:13	2019-07-12	Ms. Channie Braun	ms.channie.braun@geemail.com	Oakland	California	869986196154483096	7e8ba64a24dc82751af3b0c201741507	VISA 13 digit	37.8106445580138413	-122.313357490458188
1875	2019-07-12 05:47:28	2019-07-12	Michelle Harber	michelle.harber@geemail.com	San Antonio	Texas	869968693922963641	a7de69c3489b497ab4e75399e93532e0	VISA 16 digit	29.5378900781344633	-98.441211354110763
1876	2019-07-12 06:09:18	2019-07-12	Ayden Armstrong II	ayden.armstrong.ii@geemail.com	San Francisco	California	3528450627612729421	0154c3a81a778119f68fc012bb677b86	VISA 16 digit	37.7702226329268669	-122.441412115841615
1877	2019-07-12 06:18:29	2019-07-12	Miss Sammie Reinger DDS	miss.sammie.reinger.dds@geemail.com	Berkeley	California	180051214475270661	98ce55c96d8f503462ff275eae6e0bad	Voyager	37.8847193120594028	-122.277161009602239
1878	2019-07-12 11:32:13	2019-07-12	Lexi Muller	lexi.muller@woohoo.com	San Francisco	California	180088396104093858	38b32bc423d7f781ad21ebf0acd29623	VISA 16 digit	37.7629348152985074	-122.42575818053507
1879	2019-07-12 12:15:15	2019-07-12	Yasmeen Hermiston DDS	yasmeen.hermiston.dds@warmmail.com	San Francisco	California	4492884137634798	07aa3747a60ad078eb6dff3ced7fc895	Mastercard	37.7888506625945411	-122.445927084061012
1880	2019-07-12 12:53:19	2019-07-12	Miss Amey Cummings DDS	miss.amey.cummings.dds@geemail.com	Albuquerque	New Mexico	676141257284608	2f69e4bcae7e42f879a01cc9b49ddd24	VISA 16 digit	35.189549126675729	-106.646524684883289
1881	2019-07-12 14:25:07	2019-07-12	Lesli Schimmel	lesli.schimmel@geemail.com	San Francisco	California	52529912807801939	132a4e42bfd21ec5208bf73cb86fd204	Voyager	37.7499313800814917	-122.417167117799366
1882	2019-07-12 15:51:15	2019-07-12	Dr. Kristoffer Rice MD	dr.kristoffer.rice.md@geemail.com	Berkeley	California	210037149888295724	2d91339a9528cfeedd8ec61c71d8b6a9	VISA 13 digit	37.8745828748327042	-122.271959110489703
1883	2019-07-12 17:16:17	2019-07-12	Ms. Danae O'Connell	ms.danae.o'connell@geemail.com	San Francisco	California	6011057089276282782	b888f5025703cce992b4a619d66ad82b	Maestro	37.736687755422615	-122.415589400439003
1884	2019-07-12 17:58:54	2019-07-12	Melina Hammes	melina.hammes@geemail.com	San Francisco	California	54173740441838317	afb660c8b37698c4384b7550ce5a2c50	Mastercard	37.7670916349464107	-122.476545857027588
1885	2019-07-12 19:26:04	2019-07-12	Rishi Kertzmann	rishi.kertzmann@geemail.com	San Francisco	California	4945498551675717	c4d350c32040ad20a4403b17b72bf614	American Express	37.7787320083108895	-122.437530839257178
1886	2019-07-12 19:33:44	2019-07-12	Dalton Turcotte	dalton.turcotte@geemail.com	San Francisco	California	3010512634917672	3ac69f10510d93d6c7f5a80cf94c2b16	VISA 16 digit	37.7892665239477026	-122.426278278826217
1887	2019-07-12 21:53:42	2019-07-12	Arvel Hamill	arvel.hamill@warmmail.com	Berkeley	California	4113605321804783	1d1ec0f984368c865f47a23c803c5884	VISA 16 digit	37.8543360773977398	-122.27944693050415
1888	2019-07-12 22:02:02	2019-07-12	Miss Rosalinda Koch DVM	miss.rosalinda.koch.dvm@woohoo.com	San Francisco	California	210099769977802687	ab98100521a490a7442bd15ddb3807a3	Discover	37.7602121455127389	-122.429446051399196
1889	2019-07-12 22:33:52	2019-07-12	Shelby Walsh	shelby.walsh@woohoo.com	Oakland	California	4677122651342952	6d86d69de4f61ff9295836a1d731e869	VISA 16 digit	37.7711731442702501	-122.240368751640446
1890	2019-07-13 00:10:27	2019-07-13	Mayra Hills	mayra.hills@geemail.com	San Francisco	California	6011763699153473109	4ecadcc95c65759ba219a5d963c826f6	JCB 15 digit	37.7612021716954374	-122.405883503107034
1891	2019-07-13 00:35:35	2019-07-13	Beryl Friesen	beryl.friesen@geemail.com	San Francisco	California	3096601643665215174	c487984906ad96c84c908c13a58b84fb	Mastercard	37.7487772666697197	-122.412534348600133
1892	2019-07-13 01:25:09	2019-07-13	Jesse Powlowski	jesse.powlowski@woohoo.com	Chattanooga	Tennessee	6011905484452625694	3176220dfda7e2ba979a3df5b2dd1f01	VISA 16 digit	35.0054670542795208	-85.1761369420975427
1893	2019-07-13 01:25:18	2019-07-13	Dr. Loni Bartell MD	dr.loni.bartell.md@woohoo.com	Berkeley	California	4990249682776500	714c4712ed8b291af361cc678fe4529f	Voyager	37.8712215935909242	-122.27324363071773
1894	2019-07-13 01:52:56	2019-07-13	Martell Boyer	martell.boyer@geemail.com	San Francisco	California	55364604459269246	68925231eeb2caa1132138baa1577865	JCB 16 digit	37.7569310107770804	-122.450473183279101
1895	2019-07-13 03:28:57	2019-07-13	Palma Daniel	palma.daniel@geemail.com	Oakland	California	589317832642668	0dd62cf8db8b7ff5085c3b3964e76261	JCB 16 digit	37.8010483717713441	-122.296708484851038
1896	2019-07-13 05:38:51	2019-07-13	Mr. Ivey Bruen I	mr.ivey.bruen.i@geemail.com	San Francisco	California	4871592254325071	f70d6b1733cdb6d9f1d790810ee2156e	JCB 15 digit	37.7740021882940482	-122.415589948539349
1897	2019-07-13 06:11:43	2019-07-13	Kanesha Corkery	kanesha.corkery@geemail.com	Allen	Texas	502071342355527	e2a6d451a8f22bbf59c963f54d7e3e9a	Diners Club / Carte Blanche	33.1756769915603087	-96.6680845934845507
1898	2019-07-13 08:24:22	2019-07-13	Cheyenne Bogisich	cheyenne.bogisich@geemail.com	Oakland	California	4005430047240	0cec803a1edbbf880d91d195dc034f52	VISA 16 digit	37.8049727278972583	-122.268492301534422
1899	2019-07-13 08:39:51	2019-07-13	Ms. Angelina Cummings PhD	ms.angelina.cummings.phd@geemail.com	San Francisco	California	3456418558753346	6bb38d2d91ae063cd6e4eee92e18446d	Maestro	37.7704552865134104	-122.4228079527403
1900	2019-07-13 08:45:03	2019-07-13	Eldred Gleichner	eldred.gleichner@warmmail.com	San Francisco	California	3782382967759070	69fb4a8df619fdecb68fb1101c72877a	VISA 13 digit	37.777090102728458	-122.410447647465702
1901	2019-07-13 12:09:59	2019-07-13	Rory Lesch III	rory.lesch.iii@geemail.com	Berkeley	California	6011454629988078348	fdd8557146720e2ee9e738aeea9583ea	American Express	37.8864342207290292	-122.273159810214636
1902	2019-07-13 15:16:59	2019-07-13	Mr. Peter Weber	mr.peter.weber@geemail.com	San Francisco	California	180014666330219884	8d8f1f7c85f618ceea97e499377ff314	VISA 16 digit	37.7705727260874298	-122.446627008074614
1903	2019-07-13 22:56:52	2019-07-13	Chancey Dach	chancey.dach@geemail.com	Oakland	California	4142819955933678	f0df4b27c7afa3f9128b45ad76f227e9	Mastercard	37.7581072644136739	-122.251314178280836
1904	2019-07-13 23:01:50	2019-07-13	Lempi Schumm	lempi.schumm@warmmail.com	San Francisco	California	3088859292374771942	0fc0b088f38995d529e4ffb918a7ad60	JCB 16 digit	37.758984676480857	-122.436772603213484
1905	2019-07-14 01:03:27	2019-07-14	Tambra Mertz	tambra.mertz@geemail.com	San Francisco	California	6011246127286178145	8d5ae012975d9eae06215ac3bea3d608	Discover	37.7821278378875931	-122.43798556002136
1906	2019-07-14 01:55:27	2019-07-14	Alyse Krajcik	alyse.krajcik@woohoo.com	Phoenix	Arizona	3733283782435716	16ae34c937a80f52ab825105ecad9288	VISA 13 digit	33.5561721874799588	-112.101482104363299
1907	2019-07-14 04:06:19	2019-07-14	Barrett Johnston	barrett.johnston@geemail.com	San Francisco	California	869998066995696071	3249b01fb8c7768265f199c7d9f4360d	Discover	37.7524543996291797	-122.46694132877272
1908	2019-07-14 07:34:16	2019-07-14	Juliann Littel	juliann.littel@woohoo.com	San Francisco	California	210060627256817310	1a6f0d70c2314e36fcef23ad09594ccd	Discover	37.7818787451038247	-122.423025747062809
1909	2019-07-14 09:39:47	2019-07-14	Mrs. Zaida Lind DDS	mrs.zaida.lind.dds@geemail.com	San Francisco	California	4070193163212	39b3aaa67552ca5d9e573df3fc0207b7	American Express	37.7527252171402594	-122.455771243188309
1910	2019-07-14 09:57:39	2019-07-14	Jule Ullrich	jule.ullrich@geemail.com	Berkeley	California	4509902352285	7a9b1acb3737f0fccb3b0593ff779d28	Maestro	37.8919920842449898	-122.298094069684694
1911	2019-07-14 10:05:07	2019-07-14	Dr. Arrie Batz MD	dr.arrie.batz.md@geemail.com	Evansville	Indiana	4575750895117328	961418b208655c8356fc1fa8a2ec8b50	VISA 16 digit	38.0134343902252567	-87.4749789647225242
1912	2019-07-14 13:03:07	2019-07-14	Ms. Emelia Davis PhD	ms.emelia.davis.phd@geemail.com	San Francisco	California	869920024319589178	04a29d16f18671b1dff79fd8abd83989	Voyager	37.7891438065622083	-122.459740080187743
1913	2019-07-14 13:35:22	2019-07-14	Sigurd Turcotte-Gutkowski	sigurd.turcotte.gutkowski@geemail.com	Berkeley	California	503869222276193	5933ae07d2affa67fc98b671c093c461	Discover	37.8636727302940486	-122.270952344330254
1914	2019-07-14 17:13:15	2019-07-14	Bena Little	bena.little@geemail.com	Berkeley	California	4827431653143618	19ea870ea9304abeabba68a5211034a8	Voyager	37.8781339536491046	-122.275188097600306
1915	2019-07-14 17:33:44	2019-07-14	Rosie Ratke PhD	rosie.ratke.phd@warmmail.com	San Francisco	California	3021647910018537	ba73b718cd407034d3bf0fc748346cb8	VISA 16 digit	37.7634844997165118	-122.417557058371813
1916	2019-07-14 17:37:49	2019-07-14	Dr. Davey Carroll	dr.davey.carroll@geemail.com	Oakland	California	4190897863111802	2059fdb7e82026e277ff10df5da456ee	Discover	37.8148127571192987	-122.294245779611359
1917	2019-07-14 20:47:33	2019-07-14	Menachem Parisian-Lueilwitz	menachem.parisian.lueilwitz@geemail.com	San Francisco	California	589372223854323	1bd9c994eefd06c9731ea21ef4a69618	Maestro	37.8135513961438718	-122.415553502929001
1918	2019-07-14 22:17:02	2019-07-14	Marty Jacobi	marty.jacobi@woohoo.com	Berkeley	California	53726205836354835	3de6ff8f3a3aecce1f51806512bb72c0	Discover	37.8613608849888053	-122.250246439867368
1919	2019-07-15 00:44:01	2019-07-15	Lelah Volkman	lelah.volkman@geemail.com	Berkeley	California	4128094164302416	4e79f83c2301071c3ef54a97850112f2	JCB 15 digit	37.8787307787531304	-122.277129205044972
1920	2019-07-15 01:03:04	2019-07-15	Zela Nicolas	zela.nicolas@warmmail.com	San Bernardino	California	4561254068016041	f4dff048910565118cebd7b441852c09	VISA 16 digit	34.0678810798827527	-117.287035893487186
1921	2019-07-15 02:36:31	2019-07-15	Unique Fritsch	unique.fritsch@warmmail.com	San Francisco	California	54048334598073200	24e7c83e710431a8b98ff2d830799854	VISA 16 digit	37.7743849703062082	-122.416681330649084
1922	2019-07-15 03:21:50	2019-07-15	Melvin Gusikowski	melvin.gusikowski@geemail.com	San Francisco	California	3776215588280886	1d7b5ebc701d2230a8adecb88d5fd9fd	JCB 16 digit	37.7482921655256902	-122.38384224294235
1923	2019-07-15 05:54:51	2019-07-15	Dr. Barnett Blick Jr.	dr.barnett.blick.jr.@geemail.com	New York	New York	180061626973166349	64547f80a18a2497395956a92dc73ccd	VISA 16 digit	40.7266918338127439	-73.882064462442699
1924	2019-07-15 10:09:22	2019-07-15	Pam Denesik	pam.denesik@geemail.com	San Francisco	California	6011995823073263842	3c891ad8d3e3a6657af13ad5a2e00ead	Voyager	37.7520822000356162	-122.422449760275597
1925	2019-07-15 11:40:33	2019-07-15	Hampton Barton	hampton.barton@woohoo.com	San Francisco	California	180020249682591267	482601dc7d83678e53ded2eac8ca1c52	JCB 16 digit	37.7692123501521948	-122.447884788027736
1926	2019-07-15 12:14:20	2019-07-15	Mr. Dion Mohr I	mr.dion.mohr.i@geemail.com	San Francisco	California	180021142416786221	23635293f0188592d7e50703befa0f47	Maestro	37.7580844319499747	-122.448992616961192
1927	2019-07-15 12:25:53	2019-07-15	Diann Paucek	diann.paucek@geemail.com	San Francisco	California	3488872571034690	66b7bde44c1d01c2b65ede802d5b8ee3	Diners Club / Carte Blanche	37.76654757070812	-122.43343655924015
1928	2019-07-15 12:27:55	2019-07-15	Dr. Mylee Von DDS	dr.mylee.von.dds@woohoo.com	San Francisco	California	54146016333651397	b0b22db1495d33accca6f9f6f7996449	Maestro	37.7597567267335279	-122.465766652288323
1929	2019-07-15 15:11:16	2019-07-15	Kennard Tillman IV	kennard.tillman.iv@geemail.com	Berkeley	California	3461640171749376	5f6ff576c3b12fb00c3958affa69c79e	Discover	37.8768651542081258	-122.26284479450014
1930	2019-07-15 15:27:15	2019-07-15	Dr. Joe Stiedemann	dr.joe.stiedemann@warmmail.com	Oakland	California	6011783488907517213	c3bc4adebefa7e356976d4bb7ae5ec5e	Diners Club / Carte Blanche	37.7825283985875302	-122.264715020585726
1931	2019-07-16 01:24:21	2019-07-16	Arsenio Ledner-Herzog	arsenio.ledner.herzog@warmmail.com	San Francisco	California	501812000393855	c69f0d9fdd41441ffc51e6e514892227	JCB 16 digit	37.8022444408239835	-122.452978255053807
1932	2019-07-16 02:21:10	2019-07-16	Berry Ruecker	berry.ruecker@woohoo.com	San Francisco	California	869904482668843960	5bcb8eb7566f76a8041c267a84d8544a	JCB 16 digit	37.7717827649702826	-122.438347573046826
1933	2019-07-16 07:04:42	2019-07-16	Shawn Bechtelar-Corkery	shawn.bechtelar.corkery@woohoo.com	Berkeley	California	210083516449959357	746174c321d75d3cc3d78c26040898e1	Voyager	37.8865204924335544	-122.285754961424118
1934	2019-07-16 09:57:02	2019-07-16	Earlene VonRueden	earlene.vonrueden@geemail.com	Oakland	California	3432298818134266	b658271b3314d658fc3587f4f6b37f96	JCB 16 digit	37.7975819615116748	-122.233248191487789
1935	2019-07-16 10:11:04	2019-07-16	Mr. Cal Altenwerth Sr.	mr.cal.altenwerth.sr.@geemail.com	San Francisco	California	3450930447192367	39dad568884ca8f825cf4649f8aadf36	JCB 16 digit	37.7579739937659298	-122.418016251287057
1936	2019-07-16 11:03:47	2019-07-16	Dexter Cole	dexter.cole@geemail.com	Berkeley	California	210092623022776767	e5d8b7695f6fc96fb58e6f164319c3c6	American Express	37.8444848255299746	-122.272510990318168
1937	2019-07-16 11:05:57	2019-07-16	Olive Hagenes PhD	olive.hagenes.phd@geemail.com	El Paso	Texas	180044698416682739	2c3c31dd0aa63e0754b808566b11f736	VISA 13 digit	31.7805798038668961	-106.496357771566139
1938	2019-07-16 16:05:53	2019-07-16	Dr. Marni Swift	dr.marni.swift@geemail.com	San Francisco	California	3025844172050862	eecf95f8cec83ab5c8da5d345192ea42	JCB 15 digit	37.7936397109296465	-122.425551090244099
1939	2019-07-16 17:14:15	2019-07-16	Eliana Braun	eliana.braun@woohoo.com	San Francisco	California	4309503665668	9efed3d759c773821ca48b8991eb0d35	Voyager	37.7564247093746701	-122.429470014914742
1940	2019-07-16 18:18:53	2019-07-16	Mr. Alto Wunsch	mr.alto.wunsch@geemail.com	San Francisco	California	6011910882931931240	d13cd2580db6fcd552d071a33caaed5b	Diners Club / Carte Blanche	37.7775376103143756	-122.433784399016574
1941	2019-07-16 21:25:43	2019-07-16	Teela Considine	teela.considine@geemail.com	San Francisco	California	6011563185053070189	7d609d1e26fea62a95f1328fefe1841e	Voyager	37.7867053719600889	-122.428417005744436
1942	2019-07-16 22:29:56	2019-07-16	Shelly Gerhold	shelly.gerhold@woohoo.com	Omaha	Nebraska	3088447541710498019	7f25aa3b42d3b240031276bb0d6414e5	VISA 16 digit	41.2968029899202307	-95.9529266751952576
1943	2019-07-17 03:32:47	2019-07-17	Dr. Malik Kunde	dr.malik.kunde@geemail.com	San Francisco	California	4815943793949161	20de71b9b400cb56ac7ef3606c76efbb	VISA 16 digit	37.7569741603739999	-122.457109617751044
1944	2019-07-17 06:40:03	2019-07-17	Buell Runte	buell.runte@geemail.com	Berkeley	California	3058441668396011	2105e0a5c49ad59cb4fbb6d6aa2aafb1	JCB 15 digit	37.8485890250710852	-122.259164509139751
1945	2019-07-17 06:59:44	2019-07-17	Wyatt Walter	wyatt.walter@geemail.com	San Francisco	California	4780923224304	39ccea234fd557f04b4a2796093ca5d3	Mastercard	37.7935922167142451	-122.412386148699568
1946	2019-07-17 09:28:57	2019-07-17	Hanson Wehner	hanson.wehner@woohoo.com	San Francisco	California	180065230728069399	90f263ac1bc26df6f7967a0d93cfb373	VISA 16 digit	37.7504622080517933	-122.433452997649511
1947	2019-07-17 10:32:52	2019-07-17	Mr. Isham Ankunding Sr.	mr.isham.ankunding.sr.@geemail.com	San Francisco	California	53171488341617827	81f85d3db9ef9a5aa8393a6d7ee39e5b	VISA 16 digit	37.7687060071263971	-122.412069529633541
1948	2019-07-17 12:03:02	2019-07-17	Kaela Klocko	kaela.klocko@geemail.com	Oklahoma City	Oklahoma	869910527575326640	8cdfc65ab680aeee44c6935cbf71d5da	VISA 16 digit	35.4769039451520882	-97.4361667398724762
1949	2019-07-17 17:20:19	2019-07-17	Hertha Hahn	hertha.hahn@geemail.com	San Francisco	California	180048267796852092	fa9df522545d387f339520cf11245e05	JCB 16 digit	37.7483526635954192	-122.437780749651736
1950	2019-07-17 18:04:39	2019-07-17	Mervin Orn	mervin.orn@woohoo.com	Oakland	California	52520787375664284	f2cf301d5316cd20cddb3e1ec2b68c86	JCB 16 digit	37.7813625862489815	-122.252789959547101
1951	2019-07-17 18:55:36	2019-07-17	Wally Schmitt	wally.schmitt@geemail.com	Jacksonville	Florida	3337071506970583118	0bcd9773995291436f72801d0268253b	Voyager	30.4201242606673397	-81.5635910428207467
1952	2019-07-17 19:24:22	2019-07-17	Toivo Murphy-Mann	toivo.murphy.mann@geemail.com	San Francisco	California	51433044177171696	15e19852b6f6d02f129b940452d6e76f	Voyager	37.7660529766127908	-122.447022271312605
1953	2019-07-17 19:55:20	2019-07-17	Hernan Zieme	hernan.zieme@geemail.com	Berkeley	California	3494635837805233	376ed988b5d5f5bad95a172508094095	Mastercard	37.8623293909215448	-122.257064469729059
1954	2019-07-17 22:02:19	2019-07-17	Ruby Bayer	ruby.bayer@geemail.com	Berkeley	California	53156600643396673	83ca32975115c043af141197f28a4bad	Mastercard	37.905708134193091	-122.242673407028718
1955	2019-07-17 23:57:59	2019-07-17	Diamond Hammes	diamond.hammes@geemail.com	Oakland	California	4569775617427448	d04cbcef6009c2e6bfb5543cc2406ae1	Voyager	37.828516084953435	-122.240178343700777
1956	2019-07-18 04:57:22	2019-07-18	Delbert Reinger	delbert.reinger@warmmail.com	San Francisco	California	869933549945135579	b4d603a32bca0c08cc04dc4a0aab3750	American Express	37.7786889490881137	-122.395933233491036
1957	2019-07-18 08:28:43	2019-07-18	Elbert Lebsack	elbert.lebsack@woohoo.com	San Francisco	California	6011995210658572518	666f01667fce441fbd11724be2e7ff16	JCB 16 digit	37.7540781881482701	-122.464427105492476
1958	2019-07-18 13:15:44	2019-07-18	Ivette Huels	ivette.huels@woohoo.com	Elgin	Illinois	675998896156357	3439cdbbc1a49f382fca65e036d56216	American Express	41.9956369547456489	-88.3499058899290901
1959	2019-07-18 13:19:28	2019-07-18	Savanah Wintheiser DDS	savanah.wintheiser.dds@geemail.com	Oakland	California	52586580731105899	fae75098340aae9441d75331e973b4e3	VISA 16 digit	37.8147771135788417	-122.257793285941133
1960	2019-07-18 15:35:23	2019-07-18	Kody Gorczany V	kody.gorczany.v@warmmail.com	San Francisco	California	4900216667303864	f39685a624d53bdd6ff594be47988dde	JCB 16 digit	37.7917463405416072	-122.46176599373122
1961	2019-07-18 16:18:23	2019-07-18	Miss Lota Kunze PhD	miss.lota.kunze.phd@geemail.com	San Francisco	California	3008523879677584	808ba36656370aee436c41ac2fa0c529	VISA 16 digit	37.773124294641633	-122.410576626385691
1962	2019-07-18 17:07:04	2019-07-18	Izabella Strosin	izabella.strosin@geemail.com	Austin	Texas	3774071043423278	fd3a37ca519a7cced6a8e5445a896e2a	Maestro	30.3254227459091688	-97.7921515151631127
1963	2019-07-18 18:02:55	2019-07-18	Kasey Smith	kasey.smith@geemail.com	San Francisco	California	53588986226776193	d0f8c3a6d32b9337e833ce090d2729be	Voyager	37.7989890293732813	-122.435281555568679
1964	2019-07-18 21:59:54	2019-07-18	Erykah Rolfson	erykah.rolfson@geemail.com	Berkeley	California	6011345990551119916	c5fe9705a67e4592582fea8eb8d388bf	JCB 15 digit	37.8567504136544244	-122.255896008866884
1965	2019-07-18 22:08:34	2019-07-18	Richie Smith	richie.smith@woohoo.com	San Francisco	California	4007650428488675	75e1bcf349f1e193ace5ee24a14d045d	VISA 13 digit	37.7911373904297818	-122.427250475143182
1966	2019-07-18 22:12:15	2019-07-18	Ilda Jaskolski	ilda.jaskolski@geemail.com	Oakland	California	3731265055062840	489e3b5bfb6de5ff9e4821c859e2c36a	VISA 16 digit	37.8209396959703668	-122.265577995885891
1967	2019-07-18 23:08:53	2019-07-18	Indiana Ratke	indiana.ratke@geemail.com	Oakland	California	4155758524471360	5138aad14851a1fcc113706c0acfd928	Diners Club / Carte Blanche	37.789482082454839	-122.293647859372186
1968	2019-07-19 00:10:00	2019-07-19	Lailah Johns	lailah.johns@geemail.com	Oakland	California	869920252537115043	09fed0fa163617214263959d5b87697d	Discover	37.7886175483095528	-122.268438228758228
1969	2019-07-19 00:27:13	2019-07-19	Girtha Okuneva	girtha.okuneva@geemail.com	San Francisco	California	676129814375712	800814a00e828dafc0b428eb385cc1af	Voyager	37.755552648723274	-122.454983037862917
1970	2019-07-19 00:55:19	2019-07-19	Braylon Huel	braylon.huel@warmmail.com	San Francisco	California	180077044975938966	387418d5f487c316cd45c9bb461445a0	JCB 16 digit	37.7840658660259123	-122.418203805418088
1971	2019-07-19 01:16:20	2019-07-19	Landen Haley	landen.haley@geemail.com	Santa Ana	California	4863046156309808	6c075617d50f8aa414369ad6e7cb6316	VISA 13 digit	33.6688195960700511	-117.881602075502272
1972	2019-07-19 01:58:54	2019-07-19	Mr. Carmelo Stanton	mr.carmelo.stanton@geemail.com	New York	New York	3019924883912802	74d7df08af2e1de1e9342cd5d700d71d	JCB 16 digit	40.6351574696823974	-73.8797634333733413
1973	2019-07-19 03:29:41	2019-07-19	True Marquardt PhD	true.marquardt.phd@geemail.com	Berkeley	California	3054576522370431	408ae937c514a2ecb6b2c4bd9fffd522	VISA 16 digit	37.8623590799980789	-122.260500350779054
1974	2019-07-19 05:08:57	2019-07-19	Jamal Beier I	jamal.beier.i@woohoo.com	Oakland	California	4382009372324847	72fa74c86b53eeafc85b6b5f21f86d0c	VISA 13 digit	37.8029735381394687	-122.286203143842613
1975	2019-07-19 07:11:42	2019-07-19	Cyntha Bradtke	cyntha.bradtke@geemail.com	San Francisco	California	3337125007181160545	2f260df54d59d140a7beeba6ed0716bd	JCB 16 digit	37.7676353798219608	-122.404470046014183
1976	2019-07-19 08:52:32	2019-07-19	Benson Hilll	benson.hilll@warmmail.com	San Francisco	California	3112033975416930265	3263ce2725d891db487985bc6707e87e	JCB 16 digit	37.7690998537961775	-122.441314092694711
1977	2019-07-19 08:54:07	2019-07-19	Masao Olson MD	masao.olson.md@warmmail.com	Berkeley	California	3406698209170765	fb0700dd8e256381dd66fd6cef30eee6	VISA 16 digit	37.8382910637025134	-122.235085850767973
1978	2019-07-19 10:06:27	2019-07-19	Christian Koelpin	christian.koelpin@geemail.com	Oakland	California	4299481046652	d12ae410b02aa3c46e4a3e2ba11a541f	JCB 16 digit	37.8019443052229036	-122.274961522497847
1979	2019-07-19 16:24:47	2019-07-19	Acey Considine PhD	acey.considine.phd@woohoo.com	San Francisco	California	4947300920193364	1ab4a9cbe01f47f0bfd75cdd7c6e44cc	JCB 15 digit	37.7626638135677482	-122.443274823820815
1980	2019-07-19 16:26:28	2019-07-19	Miss Karri Lockman	miss.karri.lockman@geemail.com	San Francisco	California	4306981286382694	f7b050a852437867a473ff13fb6b01e2	JCB 16 digit	37.7687567380867648	-122.450448021841964
1981	2019-07-19 19:27:11	2019-07-19	Maegan Reichel	maegan.reichel@geemail.com	San Francisco	California	6011527423253712556	4874aa3cb38c108ec1bf62b7f3a9599a	Mastercard	37.7630219250011905	-122.445126448584702
1982	2019-07-19 21:51:57	2019-07-19	Buren Robel PhD	buren.robel.phd@warmmail.com	San Francisco	California	3158536603790580223	58748979a54f0a2e2e7c487c766800e8	Voyager	37.7790812311220066	-122.400757599927175
1983	2019-07-19 22:38:32	2019-07-19	Mr. Triston Schaefer	mr.triston.schaefer@geemail.com	San Francisco	California	6011202629060263078	04afff51bbb0aa6b333e1c1923d2a1b1	VISA 13 digit	37.7915139338151604	-122.456340651277714
1984	2019-07-20 02:27:44	2019-07-20	Cael Harber	cael.harber@woohoo.com	San Francisco	California	3046396858312230	62809ab07fa0729afcd5c6a67015a4c2	JCB 16 digit	37.7760410664107837	-122.448549996648069
1985	2019-07-20 03:43:09	2019-07-20	Dr. Bishop Homenick PhD	dr.bishop.homenick.phd@geemail.com	San Antonio	Texas	3528898367531662300	4b54ee16d1d67d87020451e6a3114ec9	JCB 16 digit	29.5247729436565187	-98.4391105757396616
1986	2019-07-20 06:18:52	2019-07-20	Chandler Blanda	chandler.blanda@geemail.com	San Francisco	California	210071452097071739	466fff981f207c1c5421531e28b37580	Mastercard	37.7780098598790275	-122.438758569081685
1987	2019-07-20 08:08:34	2019-07-20	Gorge Breitenberg	gorge.breitenberg@geemail.com	Rockford	Illinois	210045802122857713	83523e5dcbafc372e980a4218eff6286	Mastercard	42.1923241941735157	-89.0532094084009458
1988	2019-07-20 10:19:24	2019-07-20	Bo Frami	bo.frami@woohoo.com	Berkeley	California	3706372449977674	3696f0367d6edf8c76800d60309b4fa3	JCB 15 digit	37.8786348266475699	-122.270703363487229
1989	2019-07-20 10:47:43	2019-07-20	Isham Kunde-Franecki	isham.kunde.franecki@geemail.com	San Francisco	California	869977503241130880	aac3f5f2aced9dadbde4aab1ae8afd33	American Express	37.7738987642971296	-122.430219942450009
1990	2019-07-20 11:35:08	2019-07-20	Ms. Alverda Wilderman	ms.alverda.wilderman@geemail.com	Oakland	California	3528383616330484221	01d1cea4ed2e5b761338fdf532561411	VISA 13 digit	37.8146703680756957	-122.29792374178345
1991	2019-07-20 12:27:27	2019-07-20	Lazaro Rosenbaum-Gorczany	lazaro.rosenbaum.gorczany@geemail.com	San Francisco	California	3158283308099824505	d9732834e9f178fcb6c5f5059821cd2a	Diners Club / Carte Blanche	37.7666513714737704	-122.424135066656916
1992	2019-07-20 12:48:50	2019-07-20	Akeelah Abshire DVM	akeelah.abshire.dvm@geemail.com	Oakland	California	676346523295940	6fd05163ab6ad42f79f8069d2e322fb2	JCB 15 digit	37.7855257323236557	-122.277675918707729
1993	2019-07-20 13:14:19	2019-07-20	Willie Heathcote	willie.heathcote@geemail.com	San Francisco	California	3035039937774357	45a4f25963d653ba106f3982fc168b3b	VISA 16 digit	37.8002686815361315	-122.423341353169704
1994	2019-07-20 14:40:00	2019-07-20	Kalyn Hahn MD	kalyn.hahn.md@geemail.com	Oakland	California	4089526961950928	4ff040e72a3e24536f0b8233e4fa9e88	Discover	37.7804399108933708	-122.245159809323681
1995	2019-07-20 15:31:04	2019-07-20	Nasir Quitzon	nasir.quitzon@woohoo.com	Berkeley	California	3112299260472417476	17aef01634358331f5f02dfbd4b79f5d	VISA 13 digit	37.8528103664088391	-122.241855704965985
1996	2019-07-20 22:23:59	2019-07-20	Yael Cummerata	yael.cummerata@woohoo.com	San Francisco	California	210091149916639821	5b8195657d9518ef5fa79391627069c6	JCB 15 digit	37.7795767470141541	-122.43787791504144
1997	2019-07-20 22:38:08	2019-07-20	Mr. Maynard Sporer	mr.maynard.sporer@woohoo.com	San Francisco	California	55368773728186014	c6fb7c778bc7b70e435d3d21de94b385	JCB 16 digit	37.7946746423209987	-122.420071991502311
1998	2019-07-20 23:33:47	2019-07-20	Parker Bartoletti	parker.bartoletti@warmmail.com	San Francisco	California	3096736300902008049	4cabae1e7bc2de6217d3bc320e80f091	Mastercard	37.7907964660618489	-122.43019697063221
1999	2019-07-21 00:48:50	2019-07-21	Delton Cormier	delton.cormier@woohoo.com	San Francisco	California	869936856437149175	6a963d19647cf5184d155d1e2759b413	VISA 16 digit	37.7695379887190157	-122.448022098779958
2000	2019-07-21 02:10:11	2019-07-21	Shaniya Reichert-Huel	shaniya.reichert.huel@geemail.com	Berkeley	California	4507529078566607	504e86ea085eb5758d5f9ca83516f006	VISA 13 digit	37.8287047123928275	-122.272519939552836
2001	2019-07-21 02:54:24	2019-07-21	Deirdre Kilback	deirdre.kilback@geemail.com	Berkeley	California	3029236341922335	c0e552a5e7ef7dcb1423e1edb606c1b3	JCB 15 digit	37.8766992009782442	-122.26061254876619
2002	2019-07-21 03:06:14	2019-07-21	Deangelo D'Amore	deangelo.d'amore@warmmail.com	San Francisco	California	4479415903141325	957a6ca514be3066eda955ec4818467d	JCB 16 digit	37.7590038177621992	-122.440362310591368
2003	2019-07-21 03:34:04	2019-07-21	Mrs. Deb Jast	mrs.deb.jast@geemail.com	Berkeley	California	3337154277528638289	b7c5684153bf85489a36c16d83165544	American Express	37.8987527003586706	-122.253651181483477
2004	2019-07-21 06:31:04	2019-07-21	Candis Mante	candis.mante@woohoo.com	San Francisco	California	6011465513511478885	f6e68039cf3ee21e2d2a21f9884b28f9	Voyager	37.7415829895485118	-122.414315417696244
2005	2019-07-21 07:07:02	2019-07-21	Nikko Bosco	nikko.bosco@geemail.com	San Francisco	California	4897320711345437	036e3744deaf3f7ce791bc4991956e7b	Discover	37.7657899504781085	-122.441917529415292
2006	2019-07-21 08:34:18	2019-07-21	Della Pfeffer-Huels	della.pfeffer.huels@woohoo.com	San Francisco	California	210001093834798237	ccaa2828440ad17ff6313ba465496327	JCB 16 digit	37.7862794390362282	-122.45427749380589
2007	2019-07-21 11:58:50	2019-07-21	Mr. Wright Green III	mr.wright.green.iii@geemail.com	Berkeley	California	210086890498297580	e8188ec2a2774505fba66b2bff8d49c6	JCB 16 digit	37.8664037780242637	-122.294204499807066
2008	2019-07-21 12:15:59	2019-07-21	Miss Leeann Terry DVM	miss.leeann.terry.dvm@geemail.com	San Francisco	California	6011646374173719385	a8aabcab239d7717e5ff6108bbe2ea69	American Express	37.7749238622446271	-122.439769553589414
2009	2019-07-21 14:30:11	2019-07-21	Lilah Schinner	lilah.schinner@geemail.com	San Francisco	California	869973133683717491	529ad106b05bdc2b244792525861d664	Discover	37.7740084191094567	-122.463360273915555
2010	2019-07-21 15:28:08	2019-07-21	Armin Ziemann	armin.ziemann@geemail.com	New York	New York	4683994459380448	694367e3dbc4a68a4ffd55e7cae46d0d	Mastercard	40.7319295473154597	-73.8585080380912871
2011	2019-07-21 21:13:47	2019-07-21	Miss Charlene Marks MD	miss.charlene.marks.md@geemail.com	Kenosha	Wisconsin	210008693824203180	b7b57238134a436a5bd7361368519f20	Maestro	42.6449166399266559	-87.8684467224631476
2012	2019-07-21 22:45:32	2019-07-21	Ms. Alyse Kunde	ms.alyse.kunde@geemail.com	Berkeley	California	3528195191445850078	e93890bb09d7430023ff64be74544f4e	Mastercard	37.9153479726847564	-122.261294024381996
2013	2019-07-21 23:59:35	2019-07-21	Job Ward PhD	job.ward.phd@geemail.com	San Francisco	California	51737444624974077	c6023d6ecc550becac412659420ca245	Maestro	37.7783641877632022	-122.432027984510199
2014	2019-07-22 02:55:38	2019-07-22	Elsworth Ledner-Davis	elsworth.ledner.davis@geemail.com	Berkeley	California	4784350451658174	e370e07c9b6de05fa147367ba3be6a1a	VISA 16 digit	37.8899847197287798	-122.323696811666665
2015	2019-07-22 05:01:18	2019-07-22	Deforest Bashirian	deforest.bashirian@geemail.com	San Francisco	California	4308574020746	c45f2b96256a887895df5986a2c1d147	VISA 16 digit	37.7473864233614975	-122.458880086918683
2016	2019-07-22 05:04:55	2019-07-22	Yancy Stehr	yancy.stehr@geemail.com	San Francisco	California	4921095448003158	a4d9652e709245a6e45c0270115ee92b	Diners Club / Carte Blanche	37.7844033260571166	-122.421921951201881
2017	2019-07-22 05:42:04	2019-07-22	Angelo Kuphal	angelo.kuphal@geemail.com	Pueblo	Colorado	4353611014492	4f9ca477165ab8241769eb01d391a072	JCB 16 digit	38.2296905685659496	-104.584092105305942
2018	2019-07-22 07:27:43	2019-07-22	Johan Witting	johan.witting@geemail.com	San Francisco	California	180045445293642801	82f8907f0e8e94b8ce3d8d6e3c56664f	Discover	37.7909647686758063	-122.407777639132505
2019	2019-07-22 07:35:00	2019-07-22	Gaetano Grant	gaetano.grant@geemail.com	San Francisco	California	4373762582035279	e3dab31bf839cf4ab96ab26cf544b264	Discover	37.7722227387956693	-122.380883617556549
2020	2019-07-22 08:05:20	2019-07-22	Lorenz Schuppe	lorenz.schuppe@geemail.com	Dallas	Texas	3096086230984532937	298fb8f8c45a9933f226469cb58c7448	VISA 16 digit	32.8320385331094258	-96.7314252918083213
2021	2019-07-22 09:59:41	2019-07-22	Florian Greenholt	florian.greenholt@geemail.com	Oakland	California	4788017265996415	700fdac3a0b78298c9e02e66b3754b85	JCB 16 digit	37.8423213855152198	-122.253152626418995
2022	2019-07-22 14:30:10	2019-07-22	Martika Schmitt	martika.schmitt@woohoo.com	San Francisco	California	3096679361017944659	05d9d44e4c60b4f4824bd9d4899f3aba	Maestro	37.7817164279948301	-122.463103561137657
2023	2019-07-22 15:08:18	2019-07-22	Blaise Mayert	blaise.mayert@geemail.com	Berkeley	California	3043220906412870	fdd16af78d26733bbc6d862fd08d4b50	VISA 16 digit	37.8398737279938757	-122.276550294454267
2024	2019-07-22 16:57:32	2019-07-22	Jace Gulgowski	jace.gulgowski@geemail.com	San Francisco	California	210084127397172602	ff17393045cfdfc079028c1d5647ac00	VISA 16 digit	37.7721667784110693	-122.396512456898037
2025	2019-07-22 18:38:26	2019-07-22	Minna Douglas	minna.douglas@geemail.com	Berkeley	California	4007798106337753	39bde4def836b493a802f8b438fb730c	Voyager	37.8788537674245944	-122.283729453097308
2026	2019-07-22 20:41:13	2019-07-22	Destry Johnson-Feest	destry.johnson.feest@geemail.com	Berkeley	California	4522295475795	c87f4d077bf2dcc2f691942eeef75dc0	Maestro	37.8936013048117744	-122.267652808894923
2027	2019-07-23 06:12:20	2019-07-23	Linnie Wiegand	linnie.wiegand@warmmail.com	Tempe	Arizona	3088500721268589609	a299414605d1e0afc632634e96d757b9	JCB 16 digit	33.420771970452364	-111.898312562707062
2028	2019-07-23 07:16:51	2019-07-23	Jenna Prohaska	jenna.prohaska@geemail.com	San Francisco	California	4425141821818	1a0d21670adf2f87bac52e3717931f6b	VISA 13 digit	37.7702356634653142	-122.395382184910062
2029	2019-07-23 08:04:41	2019-07-23	Hortense Dickinson	hortense.dickinson@geemail.com	San Francisco	California	53424161392917041	60affa69cd19d215ecdece8faa084f3d	VISA 13 digit	37.7782172071136131	-122.465676946919814
2030	2019-07-23 08:13:39	2019-07-23	Petra Cartwright	petra.cartwright@geemail.com	Berkeley	California	4794738135423	1077f61d981211a916a0e3b1976c9f77	JCB 16 digit	37.8931278923103534	-122.251725952848247
2031	2019-07-23 11:57:34	2019-07-23	Janel Lindgren	janel.lindgren@warmmail.com	San Francisco	California	3053559274525593	7e9d91f9b369e6b4ffa7844327cce56a	Maestro	37.7820262233275699	-122.44140863760218
2032	2019-07-23 13:07:13	2019-07-23	Dr. Zelda Schiller DVM	dr.zelda.schiller.dvm@woohoo.com	San Francisco	California	55634002893133066	d40dbc10330e760cdbd96de7856c2115	JCB 16 digit	37.7471824331374677	-122.461387284227499
2033	2019-07-23 14:00:40	2019-07-23	Freddie Von	freddie.von@geemail.com	San Francisco	California	630413121108628	2490043678038bd3b41209fe52e2fedf	Voyager	37.7863023720958964	-122.398019845794977
2034	2019-07-23 15:29:02	2019-07-23	Dennis Baumbach	dennis.baumbach@geemail.com	Berkeley	California	869983228189926956	922a721712a641906ba64983136cde0d	VISA 16 digit	37.8658183800027004	-122.298305885542121
2035	2019-07-23 16:20:12	2019-07-23	Ms. Marnita Tromp DDS	ms.marnita.tromp.dds@geemail.com	Huntsville	Alabama	3528148160631660136	f39e38489a5af382cae0236ad4c39024	VISA 16 digit	34.6676542691197227	-86.7689688195027458
2036	2019-07-23 16:21:05	2019-07-23	Devaughn Trantow	devaughn.trantow@geemail.com	San Francisco	California	3745435891446713	aa8aab1dc1af8eba759b62338b7597ca	Maestro	37.7379846198919537	-122.453939717725675
2037	2019-07-23 19:48:04	2019-07-23	Gerry Leffler-Ward	gerry.leffler.ward@woohoo.com	San Francisco	California	180069707299724664	2a6a850f4691b4765035d5ea56341a01	VISA 13 digit	37.7732336952137331	-122.473138668296485
2038	2019-07-23 20:35:52	2019-07-23	Eugenie Pfannerstill	eugenie.pfannerstill@geemail.com	Berkeley	California	3096672520372577191	f5e2d5f930f06da2ccb91413e9f70477	JCB 16 digit	37.8562229703099149	-122.243377441153541
2039	2019-07-24 03:20:17	2019-07-24	Roxana Blanda PhD	roxana.blanda.phd@warmmail.com	San Francisco	California	4163508030976	c71b3aa2a03800ba708db0c55cfe5edc	American Express	37.765871737532045	-122.409201999608257
2040	2019-07-24 04:20:16	2019-07-24	Mr. Hubbard Vandervort	mr.hubbard.vandervort@warmmail.com	Berkeley	California	6011871381160993655	44d1c59a5eb9087c3c171ccbf3aec31d	Diners Club / Carte Blanche	37.86199131551448	-122.290700318248156
2041	2019-07-24 06:40:06	2019-07-24	Mr. Jayson Walter III	mr.jayson.walter.iii@geemail.com	San Francisco	California	55043400418430030	73847dc4648613d973bb6d9419d6313e	Mastercard	37.7601007640615336	-122.460076529804013
2042	2019-07-24 07:46:50	2019-07-24	Kim Weimann-Blick	kim.weimann.blick@warmmail.com	Nashville	Tennessee	6011656895690925003	054d6b4685bb3092635326647affee2d	JCB 16 digit	36.2224731472443793	-86.7128869035188075
2043	2019-07-24 08:26:46	2019-07-24	Darrius Hansen	darrius.hansen@geemail.com	San Francisco	California	869941236447252652	1eab72d2614505b2c981b6fa74d95ebf	VISA 16 digit	37.7884263198757964	-122.428733112984645
2044	2019-07-24 12:00:57	2019-07-24	Nellie Price	nellie.price@geemail.com	San Francisco	California	3708318833544867	691f5d20d4386e062906e2e9126a37fc	VISA 16 digit	37.7461247941160067	-122.46459682890513
2045	2019-07-24 12:25:13	2019-07-24	Samie Lemke	samie.lemke@geemail.com	San Francisco	California	3030961613375263	84a924f51791bd2fd79efe96967f7403	JCB 15 digit	37.7326751657829007	-122.483718875118498
2046	2019-07-24 13:27:39	2019-07-24	Mrs. Jalisa Hansen	mrs.jalisa.hansen@warmmail.com	Oakland	California	4347788309958	074c1052bb389668001eb106d7cd038f	JCB 16 digit	37.7951618799612561	-122.291011750373869
2047	2019-07-24 13:42:38	2019-07-24	Dr. Canyon Stanton DDS	dr.canyon.stanton.dds@geemail.com	San Francisco	California	53734021276730602	120a2e82a24e42c7891683f042cc7470	VISA 16 digit	37.8013453511365753	-122.430370770817134
2048	2019-07-24 15:46:41	2019-07-24	Romaine Halvorson	romaine.halvorson@geemail.com	San Francisco	California	3023661774905430	fe7d8ed53e93434bb8ddc96f110f9e21	Mastercard	37.7630005995625737	-122.418376866180722
2049	2019-07-24 20:10:42	2019-07-24	Jarrod Walker	jarrod.walker@geemail.com	Baton Rouge	Louisiana	210047091988161810	65c3f56aad7b6be409aff9ad965a1fa9	Voyager	30.4850912420291458	-91.125456147372347
2050	2019-07-24 23:18:30	2019-07-24	Yolonda Nienow	yolonda.nienow@warmmail.com	San Francisco	California	3023728968885759	ade871cace800e29e289e0f13fc50d4f	American Express	37.7670723558481072	-122.404445104588717
2051	2019-07-24 23:26:41	2019-07-24	Todd Klein	todd.klein@geemail.com	San Francisco	California	3012281073799441	a8d0eb60dd35ea926655d7e29eebcc9c	American Express	37.7454487112518535	-122.421067500656079
2052	2019-07-25 03:22:43	2019-07-25	Terance Kemmer	terance.kemmer@geemail.com	Oakland	California	3467000413138652	437985a45ac6cb290d7278914c220c34	VISA 13 digit	37.8228293609053026	-122.255873665112759
2053	2019-07-25 03:24:39	2019-07-25	Guthrie Wolf Jr.	guthrie.wolf.jr.@warmmail.com	Berkeley	California	676269345726256	564510c2708cd34e35ad58a7c423686d	JCB 16 digit	37.8454020620831812	-122.268905075865078
2054	2019-07-25 03:28:25	2019-07-25	Myles Fadel DVM	myles.fadel.dvm@geemail.com	San Francisco	California	4787640214285118	70fc409b4d4ddf5e04c5e16eb63ad8ad	Diners Club / Carte Blanche	37.7320739671654692	-122.42162399737353
2055	2019-07-25 08:11:26	2019-07-25	Mr. Melvin Carter	mr.melvin.carter@geemail.com	San Francisco	California	4853504558928593	6a02d68f44bf5c7c37658d94ed79f80a	VISA 16 digit	37.7847953481199426	-122.419770211381447
2056	2019-07-25 08:54:54	2019-07-25	Mrs. Jacalyn Hermann DVM	mrs.jacalyn.hermann.dvm@warmmail.com	Berkeley	California	210061582860028748	95b01acdb1cf9f0ecea917038a63a154	VISA 16 digit	37.8367937780884276	-122.225757335768293
2057	2019-07-25 12:43:27	2019-07-25	Malcom Graham	malcom.graham@warmmail.com	Lewisville	Texas	3414174107330521	be011f89400f207d318bb7121c3ee924	VISA 16 digit	32.9966399493612315	-96.9029720007937527
2058	2019-07-25 13:20:07	2019-07-25	Pallie Kertzmann PhD	pallie.kertzmann.phd@geemail.com	San Francisco	California	869901909572207471	890f86586521ca536e87c5e813433915	Discover	37.7842393586648129	-122.440066490704083
2059	2019-07-25 14:03:33	2019-07-25	Shane Grimes-Cummings	shane.grimes.cummings@geemail.com	San Francisco	California	561245578506326	bcf79e2563ea01db18e717395dca10aa	JCB 16 digit	37.8028580741887907	-122.450788010204874
2060	2019-07-25 18:34:31	2019-07-25	Garfield Nolan-Roberts	garfield.nolan.roberts@geemail.com	San Francisco	California	3753320601500653	ea1333805f40573c8823ae006c37c89b	VISA 16 digit	37.7780054182711211	-122.444775201143742
2061	2019-07-25 19:01:35	2019-07-25	Juan Mohr	juan.mohr@geemail.com	San Francisco	California	3429937593362908	875324931a8ee9ecd24e0a59d6f8645b	Diners Club / Carte Blanche	37.753820340232167	-122.399933615882247
2062	2019-07-25 19:12:01	2019-07-25	Gearld Emmerich	gearld.emmerich@geemail.com	Berkeley	California	53072064149340282	9127685c197fe1e59e12d1ac9dbf2724	American Express	37.8715228007327482	-122.288508702108231
2063	2019-07-25 23:35:29	2019-07-25	Darwyn Greenholt	darwyn.greenholt@geemail.com	Seattle	Washington	3722058946886761	b8a5b0b285d530905b002c38e3c77435	American Express	47.5701367347426682	-122.367941755653916
2064	2019-07-25 23:39:36	2019-07-25	Clifton Lockman-Larson	clifton.lockman.larson@warmmail.com	San Francisco	California	3022906818004620	0571fd649145dda1277ef77e843d5d72	VISA 16 digit	37.7833022106850152	-122.418369796576144
2065	2019-07-26 02:10:47	2019-07-26	Olivine Bogisich	olivine.bogisich@geemail.com	Berkeley	California	3337473214377551762	e54bfd502620eae8f4afb4e1a9fc70ce	JCB 16 digit	37.8544957503543529	-122.256671452355619
2066	2019-07-26 04:23:35	2019-07-26	Flonnie Prohaska-Connelly	flonnie.prohaska.connelly@geemail.com	San Francisco	California	3001335778955566	ba59372a669431d576fd4fdd39ad0b92	Discover	37.7395549019471872	-122.397947564190076
2067	2019-07-26 06:25:15	2019-07-26	Larry Crooks	larry.crooks@warmmail.com	Raleigh	North Carolina	3158787782706701606	64fed0dce6ee7e1ef23a3ca5e5057192	Maestro	35.7485848628584293	-78.5999896733027015
2068	2019-07-26 06:57:02	2019-07-26	Dr. Sheri Luettgen PhD	dr.sheri.luettgen.phd@woohoo.com	San Francisco	California	869984226856264452	48248c91455c4eef2ce398ac8fd4f077	Discover	37.7809805097971463	-122.428563224890013
2069	2019-07-26 07:18:43	2019-07-26	Mr. Omar Prohaska	mr.omar.prohaska@geemail.com	San Francisco	California	502041790025138	59fe083ba19f3fd47825a76a40756f5b	JCB 16 digit	37.7728517987862062	-122.393344284330936
2070	2019-07-26 07:27:18	2019-07-26	Mr. Arne Quitzon DDS	mr.arne.quitzon.dds@geemail.com	Berkeley	California	3033140592687249	33a70c37f2551b336231ba38c665028a	VISA 16 digit	37.8607822010980541	-122.308408644775099
2071	2019-07-26 10:59:30	2019-07-26	Winton Gerhold	winton.gerhold@geemail.com	San Francisco	California	6011608289670300230	df176b8f920f6361ba7731208a046794	JCB 15 digit	37.7635646899946451	-122.422811490216802
2072	2019-07-26 11:55:14	2019-07-26	Yael Konopelski	yael.konopelski@woohoo.com	San Francisco	California	676232209672529	62e0e16da64b4c995f6d1dd894d76a34	Diners Club / Carte Blanche	37.7596379421532689	-122.442670639132714
2073	2019-07-26 13:53:16	2019-07-26	Amare Runolfsson	amare.runolfsson@geemail.com	Berkeley	California	6011489437205007598	9e5129086b101022c3ddbc01a00b84a4	VISA 16 digit	37.8928596563569258	-122.268770550325428
2074	2019-07-26 15:56:56	2019-07-26	Lary Herzog-Lehner	lary.herzog.lehner@geemail.com	Pittsburgh	Pennsylvania	4436411952860	7c08c8a87c0125063fe28bdc5c68f94f	Voyager	40.5044956067532311	-80.0261772052556353
2075	2019-07-26 18:11:50	2019-07-26	Preston Price	preston.price@geemail.com	Berkeley	California	869985988202506295	b5ac4c3048bb7987a2b09b70827ed5ff	VISA 16 digit	37.8657367382242569	-122.263783247194027
2076	2019-07-26 19:39:10	2019-07-26	George White	george.white@warmmail.com	Oakland	California	3088393434907644849	20db31a47c5265da08c139ac96b0c5df	VISA 16 digit	37.828291988239144	-122.255851652000374
2077	2019-07-26 20:14:58	2019-07-26	Gabriella Wuckert	gabriella.wuckert@geemail.com	Berkeley	California	3088132742135538237	ba9e53ae4493d6530cc3b6ae17d46343	Discover	37.8749260055253245	-122.256756132910482
2078	2019-07-26 20:53:08	2019-07-26	Laurette Strosin	laurette.strosin@geemail.com	San Francisco	California	676370281139595	21fa9a032c36211341918ce22a4ccf97	American Express	37.8042654897508399	-122.451633902434793
2079	2019-07-26 21:39:22	2019-07-26	Dejon Watsica	dejon.watsica@warmmail.com	San Francisco	California	4859438099199360	55b8f507a33a42f77b03580f99f0bf0b	JCB 15 digit	37.7865273663084906	-122.437786554650216
2080	2019-07-27 03:29:48	2019-07-27	Dr. Sannie Langosh	dr.sannie.langosh@warmmail.com	San Francisco	California	3015203736857835	5f8cb2d5e40d74186d85f3fba6afc223	VISA 16 digit	37.744190084203737	-122.450018688140375
2081	2019-07-27 07:18:07	2019-07-27	Mr. Clemon Hoeger	mr.clemon.hoeger@woohoo.com	Long Beach	California	3048653187472152	e97db304910f660b67d1baf2b9d7c3ad	Diners Club / Carte Blanche	33.751095135678348	-118.093776866064587
2082	2019-07-27 09:19:56	2019-07-27	Simona Ullrich	simona.ullrich@geemail.com	Oakland	California	52211871992633247	add748603dc42c01eb65f078d93a9701	Maestro	37.801614555433602	-122.282050111377572
2083	2019-07-27 09:49:59	2019-07-27	Abbey Okuneva DVM	abbey.okuneva.dvm@warmmail.com	San Francisco	California	869999118282597501	619d78f434f2b8598295c12f65cc688c	Mastercard	37.8035835947088614	-122.410465423139811
2084	2019-07-27 10:54:37	2019-07-27	Caren Hintz	caren.hintz@geemail.com	San Francisco	California	3528208707542299284	19c40796714a4a5e670b4540fe624e28	VISA 16 digit	37.7770762021344737	-122.395545459503893
2085	2019-07-27 11:36:59	2019-07-27	Dicy Kerluke PhD	dicy.kerluke.phd@warmmail.com	Oakland	California	180026731091815340	6c68663ecae922488f7ecf625d6a475e	Discover	37.8149899833045424	-122.280499961228188
2086	2019-07-27 11:52:37	2019-07-27	Donn Rau	donn.rau@geemail.com	San Francisco	California	3791732956887192	90e00b4439fbc9e1d1f164032318e182	Diners Club / Carte Blanche	37.7871408419657371	-122.427148920418048
2087	2019-07-27 13:25:02	2019-07-27	Mr. Brown Casper IV	mr.brown.casper.iv@geemail.com	San Francisco	California	52034538801196923	bca1048e61636ea8af2cbbbd1f182d4c	JCB 15 digit	37.7409749632489095	-122.429546731763494
2088	2019-07-27 15:34:59	2019-07-27	Rylee Rice	rylee.rice@geemail.com	San Francisco	California	589312340292288	d75c6cfcddb43dd54700ffd5cbf2aee5	JCB 15 digit	37.7460448126276376	-122.406563212850841
2089	2019-07-27 16:03:26	2019-07-27	Mrs. Erin Stroman DDS	mrs.erin.stroman.dds@geemail.com	Berkeley	California	3046400855731846	4edcdab92555358eb095e464a4df682a	Voyager	37.8464155364980712	-122.261599999505322
2090	2019-07-27 17:38:26	2019-07-27	Jayvion Block	jayvion.block@geemail.com	San Francisco	California	3158824851118251628	c9fd47f1a2a9805fe222da433eee0907	JCB 16 digit	37.7842601557718396	-122.452024608280226
2091	2019-07-27 18:20:45	2019-07-27	Miss Natalya Cole DVM	miss.natalya.cole.dvm@geemail.com	San Francisco	California	3112529840808832423	238377c73d3c7d301708cdc9f4b51ffc	Maestro	37.7691432397047322	-122.423969636600134
2092	2019-07-27 20:38:54	2019-07-27	Dr. Stacy Schuster	dr.stacy.schuster@geemail.com	Sioux Falls	South Dakota	4454950630168711	6601c37ecdd6931826973bb121dfbc58	Discover	43.6111838284965572	-96.6968490344174256
2093	2019-07-27 21:05:10	2019-07-27	Hilliard Parisian	hilliard.parisian@geemail.com	San Francisco	California	3337160172132318455	35d78050eaee4abbd7c8d7a5d146d781	American Express	37.7645215453792673	-122.435648099303279
2094	2019-07-27 23:31:28	2019-07-27	Lavelle Blanda-Hagenes	lavelle.blanda.hagenes@woohoo.com	San Francisco	California	869970061633283780	a9324f8220cfbcb1402f434f9a673387	VISA 13 digit	37.7907477080136758	-122.422123561210796
2095	2019-07-28 01:14:33	2019-07-28	Enrique Smith	enrique.smith@woohoo.com	San Francisco	California	6011114644774004939	1aa2fcddfeb008659c7e1c3d27825095	Diners Club / Carte Blanche	37.7473897848461561	-122.424249507420612
2096	2019-07-28 01:26:38	2019-07-28	Hymen McDermott Sr.	hymen.mcdermott.sr.@woohoo.com	Oakland	California	3096941692906136896	81c7608b44f8ae0c7503cfcb93d6a82f	JCB 16 digit	37.8074544892414934	-122.294925227545875
2097	2019-07-28 01:30:44	2019-07-28	Alvah Blanda	alvah.blanda@geemail.com	Oakland	California	54841721123607834	61f930cca4f11a89187846d23ccbbe9a	Diners Club / Carte Blanche	37.7640400544298345	-122.267969653816309
2098	2019-07-28 02:17:11	2019-07-28	Parley Welch	parley.welch@geemail.com	Memphis	Tennessee	4720767542253284	a175643a5a296e6d22063d153776d8a9	VISA 16 digit	35.0221775606341694	-89.9533217536076961
2099	2019-07-28 02:59:36	2019-07-28	Rowland Anderson	rowland.anderson@geemail.com	San Francisco	California	4896805707548490	bbc09e6d2450363782fbe54f5e7aeff2	VISA 13 digit	37.7783384719009945	-122.433576800872515
2100	2019-07-28 03:30:25	2019-07-28	Betsy Hamill	betsy.hamill@geemail.com	San Francisco	California	4109577036710728	984141877713236de0a0fe7e292318e3	VISA 13 digit	37.7598626978347625	-122.41131747554661
2101	2019-07-28 04:31:52	2019-07-28	Bea Wolf	bea.wolf@woohoo.com	San Francisco	California	3158115520830835517	eceace885a6412ef9172fbb31eb00391	VISA 16 digit	37.767276605318969	-122.454606429127438
2102	2019-07-28 06:06:27	2019-07-28	Mr. Zayden Waelchi III	mr.zayden.waelchi.iii@geemail.com	San Francisco	California	060481733258198	db6cf5d394f86ddacf4eb76dc8edbb8e	VISA 16 digit	37.7670595634916992	-122.446792730024043
2103	2019-07-28 09:41:12	2019-07-28	Ms. Roxanna Price	ms.roxanna.price@geemail.com	Berkeley	California	4882764055501328	ab52a47f27289bed0090575c4129045f	Diners Club / Carte Blanche	37.9127495799893595	-122.313888885069048
2104	2019-07-28 10:14:48	2019-07-28	Jordon Schumm	jordon.schumm@geemail.com	San Francisco	California	4647176550184532	b5b9dde841da1f9b6e7406e2e8d49d6a	Maestro	37.7697811679943172	-122.409200939018831
2105	2019-07-28 15:53:39	2019-07-28	Ms. Paris Hermann PhD	ms.paris.hermann.phd@geemail.com	San Francisco	California	180052947698180519	094fa1ad18b7771dacf8c93060f14f2a	Maestro	37.7706266999355407	-122.431270012978487
2106	2019-07-28 16:49:13	2019-07-28	Oren Cartwright	oren.cartwright@geemail.com	Berkeley	California	180064355378599493	94418eb12c6f69d975b803958ae59582	JCB 16 digit	37.8857208233704696	-122.252340778772052
2107	2019-07-28 17:29:36	2019-07-28	Ora Hyatt	ora.hyatt@geemail.com	San Francisco	California	180070835714861576	a818da81abf90cdc0717644a0b247f66	VISA 13 digit	37.8031618561378977	-122.430546720954567
2108	2019-07-28 20:19:30	2019-07-28	Bridger Lind	bridger.lind@geemail.com	Berkeley	California	51647383266957652	d5d3225c404129dfe99e9ea7fdcbd82a	JCB 16 digit	37.8488403100485087	-122.28059128520799
2109	2019-07-28 23:39:43	2019-07-28	Auston Pacocha Sr.	auston.pacocha.sr.@geemail.com	Nashville	Tennessee	6011948050756566527	f2bd78c35abbab3f19bf27522982d230	Mastercard	36.2692967393092758	-86.7289981813542568
2110	2019-07-29 00:13:04	2019-07-29	Delora Langworth-Tremblay	delora.langworth.tremblay@warmmail.com	Oakland	California	675992112423287	8e805d1e2d5795b22e36615f4caed863	Diners Club / Carte Blanche	37.796342334430463	-122.304061080931973
2111	2019-07-29 01:20:21	2019-07-29	Hillary Boyer	hillary.boyer@geemail.com	Phoenix	Arizona	3737349454985928	74482ce01767ee17f793df42d97dc5a4	JCB 15 digit	33.6254316221855589	-112.141515090635423
2112	2019-07-29 03:17:54	2019-07-29	Iris Gutkowski	iris.gutkowski@geemail.com	San Francisco	California	869979570595487735	c6f1da54c56b2bae45fe179b0656e2eb	VISA 16 digit	37.7803490204921033	-122.420141153710276
2113	2019-07-29 03:39:31	2019-07-29	Ms. Anita Thompson	ms.anita.thompson@warmmail.com	Berkeley	California	4675106378705	29ff432f2d4096aedc5596cba417f939	JCB 15 digit	37.8666027603607489	-122.246853927132634
2114	2019-07-29 05:48:43	2019-07-29	Ovila Lueilwitz	ovila.lueilwitz@geemail.com	San Francisco	California	3459929182935213	0f3000786fb506b7164158e4cce130d6	VISA 16 digit	37.776271215981545	-122.409956129228661
2115	2019-07-29 08:20:30	2019-07-29	Elda Heathcote	elda.heathcote@geemail.com	San Francisco	California	51642215823938459	51b616accac04fb548bc672899b82a8e	American Express	37.7993184898736772	-122.416325800333922
2116	2019-07-29 08:59:08	2019-07-29	Declan Walter	declan.walter@geemail.com	Berkeley	California	55749268065794959	98f6b35d28c1b34f89630033d405cf71	Maestro	37.8590557074325673	-122.302290862282632
2117	2019-07-29 09:44:26	2019-07-29	Dwain Hand	dwain.hand@geemail.com	San Francisco	California	4771275946648644	f89aad9664a89e2f7424a2700f6a609b	Diners Club / Carte Blanche	37.7889709606268624	-122.43380615780822
2118	2019-07-29 14:49:45	2019-07-29	Mrs. Sherrill Parisian	mrs.sherrill.parisian@geemail.com	San Francisco	California	6011515510402999995	6238bcc4cd792a21b64048e3c92cc37a	JCB 15 digit	37.7753198991441366	-122.402596327789595
2119	2019-07-29 15:40:12	2019-07-29	Bennie Wilkinson-Quigley	bennie.wilkinson.quigley@geemail.com	San Francisco	California	4647061392973872	360f12f635f77e93468edb3664778f3a	JCB 16 digit	37.768596770441448	-122.428396766472673
2120	2019-07-29 16:53:51	2019-07-29	Mr. Mathias Lehner PhD	mr.mathias.lehner.phd@geemail.com	San Francisco	California	3337943772365401243	a1fba0fee65a68b181d1040a09bf45e8	Voyager	37.7624072371495245	-122.397040738562566
2121	2019-07-29 17:32:36	2019-07-29	Tarah Bradtke	tarah.bradtke@woohoo.com	Sterling Heights	Michigan	3158268455882183703	986798e42508482c4bf0976d092e3d45	VISA 16 digit	42.5134357509750913	-83.0178003947876419
2122	2019-07-29 19:19:51	2019-07-29	Anjali Powlowski	anjali.powlowski@geemail.com	San Francisco	California	51176020554343646	75dad671602be0257db72b8dcb20cf61	Mastercard	37.782442938294075	-122.398638279483038
2123	2019-07-29 21:58:18	2019-07-29	Lyman Champlin-Krajcik	lyman.champlin.krajcik@geemail.com	San Francisco	California	3158047067018913040	b7a95e10d430fdf5f871616945ab182f	Mastercard	37.7497040169827187	-122.431019301102353
2124	2019-07-30 00:35:20	2019-07-30	Ms. Tilla Howell	ms.tilla.howell@geemail.com	San Francisco	California	53677414412491875	20798ad8be1dc3582594bfafa1c147b7	Mastercard	37.7570585282610267	-122.420161991287685
2125	2019-07-30 01:27:33	2019-07-30	Earlie Halvorson	earlie.halvorson@warmmail.com	San Francisco	California	869968117485306717	b3e9d31d8f317c69ce5aa10ac8da8c66	JCB 16 digit	37.7621789821577067	-122.446761329087735
2126	2019-07-30 01:58:59	2019-07-30	Callum O'Keefe-Bernhard	callum.o'keefe.bernhard@warmmail.com	San Francisco	California	3034770997746957	701db7d7dfbf17af4b4a53168ff68ed0	Maestro	37.7560208820331411	-122.407232302014464
2127	2019-07-30 03:44:13	2019-07-30	Luster Ledner	luster.ledner@geemail.com	Cincinnati	Ohio	6011822425033253894	b1028d5252b5882e65b3337d909a1155	Voyager	39.0522891215745389	-84.5615213603984444
2128	2019-07-30 07:35:30	2019-07-30	Dr. Tyrique Hickle	dr.tyrique.hickle@warmmail.com	San Francisco	California	4346521189806159	ba1c4500c5bb7fa7abe1db45c505c75a	VISA 16 digit	37.7830054749404383	-122.454376816397456
2129	2019-07-30 12:31:27	2019-07-30	Guy Abernathy II	guy.abernathy.ii@geemail.com	Houston	Texas	4209947484501094	f84d8719b33c699350f43f4acfe7a333	JCB 15 digit	29.7782549557819962	-95.3180854308433823
2130	2019-07-30 15:17:53	2019-07-30	Obed Macejkovic	obed.macejkovic@woohoo.com	Berkeley	California	4168696531669	48a5ec4d563da2621ecc277fdc25cebc	JCB 16 digit	37.8607733591470392	-122.27858779561717
2131	2019-07-30 16:18:50	2019-07-30	Dr. Merlyn Grant	dr.merlyn.grant@geemail.com	San Francisco	California	869925881532190331	378297ee4f39e11966bcb1a5ef7d10e6	VISA 16 digit	37.7641504491025373	-122.434019920426451
2132	2019-07-30 21:51:24	2019-07-30	Scottie Dietrich	scottie.dietrich@woohoo.com	San Francisco	California	3014037548140712	06d8041bdbbd109dea4ff35b9e61aaae	American Express	37.7452077667597337	-122.439841967394344
2133	2019-07-30 21:51:46	2019-07-30	Darren Prosacco	darren.prosacco@geemail.com	San Francisco	California	3037932209451415	c29e11f885cac5d2e7912d56e3af914b	VISA 13 digit	37.8024893429513966	-122.467792300328426
2134	2019-07-30 22:25:42	2019-07-30	Festus Boehm	festus.boehm@geemail.com	Berkeley	California	676238863116240	40b60d5a6933eb78eea3373f004c08c7	Discover	37.808866473080073	-122.28552362582812
2135	2019-07-30 23:13:19	2019-07-30	Colten Mosciski	colten.mosciski@warmmail.com	San Francisco	California	3007076567086148	3f0be09de97c76c94a8ee5efddfe53fb	Voyager	37.7862301225662804	-122.42974716295231
2136	2019-07-30 23:29:44	2019-07-30	Ruth Heidenreich	ruth.heidenreich@geemail.com	Oakland	California	501884767092673	1f85814ab43c3e35938e1fcce0c06b71	JCB 16 digit	37.8007902170302046	-122.293561709453556
2137	2019-07-31 00:46:49	2019-07-31	Sherlyn Von-Ondricka	sherlyn.von.ondricka@geemail.com	San Francisco	California	4051632110642	b95a07a21da9b87cd3cdab062ddd9dfa	VISA 13 digit	37.7501438300568921	-122.433556371802013
2138	2019-07-31 06:41:34	2019-07-31	Crystal McLaughlin-Treutel	crystal.mclaughlin.treutel@geemail.com	San Francisco	California	3456711877593033	5546637d52a7142c45c932223aa66810	Diners Club / Carte Blanche	37.7644572506665384	-122.398262299295823
2139	2019-07-31 07:36:09	2019-07-31	Destin Koelpin	destin.koelpin@geemail.com	San Francisco	California	6011751040123147370	d90d5f8d87727cfcf759b7a5e27177b6	VISA 16 digit	37.801050658623403	-122.42816092997414
2140	2019-07-31 09:09:11	2019-07-31	Terry Lang	terry.lang@woohoo.com	San Francisco	California	4907909173730	9cb99c868f9a61d48e45ad20b9c25327	JCB 16 digit	37.7469226333588495	-122.440558259053716
2141	2019-07-31 09:19:59	2019-07-31	Orren Kuphal	orren.kuphal@woohoo.com	San Francisco	California	53807462970845563	165d9f7f191e3e850ea4676effa26090	Diners Club / Carte Blanche	37.7959985745283333	-122.440946191175215
2142	2019-07-31 13:15:24	2019-07-31	Mayo Wisozk	mayo.wisozk@geemail.com	San Francisco	California	180031018071257237	eb1b8c9d5327896612233f8759206dc4	American Express	37.762906712451084	-122.412465808953641
2143	2019-07-31 16:24:52	2019-07-31	Lindsay Pollich Sr.	lindsay.pollich.sr.@geemail.com	San Francisco	California	54198043326132968	c1abeb9a450bd2305fb3a480d2528329	JCB 16 digit	37.7669469415594961	-122.434184192207979
2144	2019-07-31 16:25:00	2019-07-31	Carl Kerluke	carl.kerluke@geemail.com	Berkeley	California	52784798127544808	a69da3db93aaf3097f8754134f3fd27d	VISA 13 digit	37.8484807977618587	-122.264251577695745
2145	2019-07-31 16:53:21	2019-07-31	Adrien Rutherford	adrien.rutherford@geemail.com	New York	New York	561298875970133	6202d85bfec05957d72f321f993e9a2a	American Express	40.7421032497417173	-73.8478661224141746
2146	2019-07-31 17:26:13	2019-07-31	Miss Felipa Orn DVM	miss.felipa.orn.dvm@geemail.com	San Francisco	California	060459421989159	d2562395bc1e6b0cf24cf2fa4a6ddd2f	VISA 16 digit	37.7798051946850606	-122.431330654157975
2147	2019-07-31 20:00:41	2019-07-31	Dr. Alexis Larson DVM	dr.alexis.larson.dvm@woohoo.com	San Francisco	California	54282374749343818	236c7c7d8cf44e0924a55abd36c984a5	Discover	37.7404683941106924	-122.454763311474792
2148	2019-07-31 21:05:11	2019-07-31	Texie Osinski-Pagac	texie.osinski.pagac@geemail.com	Long Beach	California	869956708430905183	0126e2721023501b7fc9d98701dea16c	American Express	33.8759737372219547	-118.102655087287715
2149	2019-07-31 21:16:49	2019-07-31	Kenny Conroy	kenny.conroy@geemail.com	San Francisco	California	180024044194562336	860a8b9d848e5072b3e9121db847f736	Mastercard	37.752425638846681	-122.453993154487932
2150	2019-07-31 23:37:08	2019-07-31	Ebb Nienow	ebb.nienow@geemail.com	San Francisco	California	3004012066200818	cb6773e67010c9b19a565007b6882153	American Express	37.7135002066622462	-122.437846220892837
2151	2019-08-01 04:48:56	2019-08-01	Onie Lesch	onie.lesch@warmmail.com	San Francisco	California	3112783998837013471	23cae4710fbd14e9d1f4a3db5b600466	VISA 13 digit	37.7902818354663381	-122.459327107946649
2152	2019-08-01 10:55:39	2019-08-01	Dr. Elzada Ruecker	dr.elzada.ruecker@geemail.com	San Francisco	California	210019616356544082	aebffb48d67f0dfdb9ab15940505df76	JCB 16 digit	37.7942003986311406	-122.441943790036319
2153	2019-08-01 11:47:14	2019-08-01	Cortez Feil	cortez.feil@woohoo.com	San Francisco	California	3054740685483296	e689da1a0aaa4fd2c21765d09f07a9cf	Maestro	37.7502132306332285	-122.383745853794153
2154	2019-08-01 12:54:01	2019-08-01	Lorena Rogahn	lorena.rogahn@geemail.com	San Francisco	California	4452857368570012	908eef998660173120834614ded01c41	VISA 13 digit	37.7653474256393764	-122.451477767867402
2155	2019-08-01 13:16:35	2019-08-01	Littie Emmerich	littie.emmerich@geemail.com	Oakland	California	180095133116216792	b1589a6f0f48df64b0edfaa8fca4fea3	JCB 16 digit	37.7790625756305687	-122.265992147407914
2156	2019-08-01 13:34:35	2019-08-01	Lilla Haley-Hackett	lilla.haley.hackett@geemail.com	San Francisco	California	180052201603554669	55d260025222349994f2e992652432f7	Mastercard	37.7834998811948282	-122.429291526162856
2157	2019-08-01 15:15:01	2019-08-01	Alisha Skiles	alisha.skiles@geemail.com	San Francisco	California	3039916209629714	37676714d343dc25c7c9015854ebfeea	VISA 16 digit	37.7696986564892256	-122.400409928439572
2158	2019-08-01 15:58:43	2019-08-01	Miss Aiyana Funk MD	miss.aiyana.funk.md@geemail.com	Oakland	California	4794086125762848	932305c1c2e6e4076ca5f70871238c39	VISA 13 digit	37.8283068362255506	-122.27883650405829
2159	2019-08-01 16:23:02	2019-08-01	Cleva Kovacek	cleva.kovacek@warmmail.com	Oakland	California	4112061433929	e08e5f85ccea6110a1a73e78e4fb1874	Discover	37.7993077619454922	-122.271203606039194
2160	2019-08-01 16:27:31	2019-08-01	Mr. Cam Mertz Jr.	mr.cam.mertz.jr.@geemail.com	Berkeley	California	4625676425477439	47c372e2b5234c38c364fed253f3eb9e	American Express	37.8947975150484595	-122.284865787214272
2161	2019-08-01 17:05:26	2019-08-01	Olive Aufderhar	olive.aufderhar@geemail.com	San Francisco	California	180018805646595563	5b80c9dfa9a36eccd01daf89ae483bff	VISA 13 digit	37.7677743319205703	-122.445989758556124
2162	2019-08-01 17:32:39	2019-08-01	Adamaris McCullough	adamaris.mccullough@geemail.com	San Francisco	California	4796194514697191	1064ef204f5fd61ec2e212dae6bea971	JCB 16 digit	37.7742699844743015	-122.396554620818065
2163	2019-08-01 19:25:02	2019-08-01	Chanel Durgan	chanel.durgan@geemail.com	Lincoln	Nebraska	3158390897575921843	a2c8e4a6382c3f812851d29e709bed3f	Mastercard	40.7983150454722292	-96.6171972629774416
2164	2019-08-01 23:55:08	2019-08-01	Marva McDermott	marva.mcdermott@warmmail.com	New York	New York	4492192045044	701c93cc845647ea4cb6c3a6a395bc21	Diners Club / Carte Blanche	40.6781539768204112	-73.9680072644155473
2165	2019-08-02 00:36:42	2019-08-02	Dr. Meaghan Durgan MD	dr.meaghan.durgan.md@geemail.com	Berkeley	California	3029337110710768	25c141c7e8e40a7a96389e5b93c8bea9	JCB 16 digit	37.8846110099631943	-122.280018382618294
2166	2019-08-02 02:44:42	2019-08-02	Dr. Delpha Dietrich	dr.delpha.dietrich@woohoo.com	San Jose	California	060413144332007	085bd8dd495f05ae7db0f1aa15e43d80	Discover	37.3325858757186708	-121.833607740116861
2167	2019-08-02 03:41:55	2019-08-02	Anjali Stamm	anjali.stamm@geemail.com	San Francisco	California	4566670915743	72500088a0c56d36e07ed8c32de8e9da	Mastercard	37.7954540289295835	-122.452901000507595
2168	2019-08-02 06:17:47	2019-08-02	Lonie Schoen	lonie.schoen@geemail.com	San Francisco	California	869927658932374808	cd84306440ded1882ffb56669e9a0b4f	Mastercard	37.7662705775454981	-122.448963815668094
2169	2019-08-02 06:40:15	2019-08-02	Beecher Carter	beecher.carter@warmmail.com	San Francisco	California	51497925220813404	038376e4bbcf0329845817cc14aef38c	JCB 16 digit	37.7517015595939824	-122.457772924248644
2170	2019-08-02 09:21:04	2019-08-02	Algot Kerluke-Labadie	algot.kerluke.labadie@geemail.com	San Francisco	California	4396515518338289	221e430284a9f85e986610bbe133b260	VISA 16 digit	37.7846836922617726	-122.465010552110513
2171	2019-08-02 10:27:02	2019-08-02	Miss Rena Daugherty DDS	miss.rena.daugherty.dds@geemail.com	Oakland	California	3044224345370227	485ec109772c476d1b2e3504b6684dd6	VISA 16 digit	37.7754914009770246	-122.297428769325265
2172	2019-08-02 11:26:39	2019-08-02	Tegan Anderson	tegan.anderson@geemail.com	San Francisco	California	3470887516997405	0eed471a712ac6174af57df82849b145	American Express	37.794413518002159	-122.433324914238739
2173	2019-08-02 11:56:23	2019-08-02	Wes Turcotte	wes.turcotte@geemail.com	San Francisco	California	6011068832678875886	7355d06ffd9832710865e7b2e6462762	Diners Club / Carte Blanche	37.7764607016108656	-122.426946915852255
2174	2019-08-02 12:16:17	2019-08-02	Karl Wilkinson-O'Conner	karl.wilkinson.o'conner@geemail.com	Jacksonville	Florida	4602803904054342	8b263773c61ccd74f813522c1503f3a1	JCB 16 digit	30.4255114755179719	-81.5624751107845469
2175	2019-08-02 12:56:35	2019-08-02	Mr. Madden Langworth DVM	mr.madden.langworth.dvm@woohoo.com	Oakland	California	6011575021055864087	0bdc71e22525599557d0d7d2291ebe2e	Voyager	37.7885230414913948	-122.277740366199509
2176	2019-08-02 13:00:50	2019-08-02	Andrea Bauch	andrea.bauch@woohoo.com	San Francisco	California	55006494757035380	f63172e1ad061ad2c5010db3a4568586	Diners Club / Carte Blanche	37.8160105503666202	-122.437070702479843
2177	2019-08-02 15:19:58	2019-08-02	Mr. Garold Feeney Sr.	mr.garold.feeney.sr.@geemail.com	San Francisco	California	180031543821085745	9cceddccb38f13373772f37f5c9981c7	JCB 16 digit	37.816910244784637	-122.394454861336655
2178	2019-08-02 19:34:09	2019-08-02	Richelle Goyette PhD	richelle.goyette.phd@woohoo.com	Berkeley	California	4180140931338	ef6d4bf8868a90b6201b143f1492a263	VISA 16 digit	37.8565805948042637	-122.292178502035
2179	2019-08-02 22:24:45	2019-08-02	Skip Schimmel-Schneider	skip.schimmel.schneider@geemail.com	San Francisco	California	4600592472838	b625b392f401ea2b25858f2b6d952915	VISA 16 digit	37.7385589980964156	-122.413755381550772
2180	2019-08-03 00:32:36	2019-08-03	Brandyn Wolff	brandyn.wolff@warmmail.com	San Francisco	California	3045589217894887	a87f73dab7115d9c9b965c4d980c2386	Diners Club / Carte Blanche	37.7726749957435715	-122.458227197304694
2181	2019-08-03 03:22:48	2019-08-03	Dr. Brionna Sauer	dr.brionna.sauer@geemail.com	Oakland	California	4302135531399698	ec642318c275fa2842c26005935b2c4f	VISA 13 digit	37.8099881469207659	-122.252358038861686
2182	2019-08-03 04:22:57	2019-08-03	Darell Frami	darell.frami@geemail.com	McKinney	Texas	3765351457832631	42d3ca0190dbe6f5ca4a45df7d6d671e	American Express	33.1339349058121471	-96.6935295488052162
2183	2019-08-03 06:56:25	2019-08-03	Dr. Harlon Pfeffer II	dr.harlon.pfeffer.ii@geemail.com	San Francisco	California	4133734626426	c106af86a60ef25f66bc2d2cadb3418d	JCB 16 digit	37.7900524593147651	-122.452859159220026
2184	2019-08-03 07:41:31	2019-08-03	Conley Oberbrunner III	conley.oberbrunner.iii@geemail.com	San Francisco	California	3158998084214130294	4f96aea826dcb1ff026ce8ae19a0fe06	Mastercard	37.8154653548746964	-122.425571043940209
2185	2019-08-03 07:54:48	2019-08-03	Dr. Rohan Goodwin	dr.rohan.goodwin@geemail.com	San Francisco	California	4564153209421416	3f6e216275b132aa56d25718f15bef27	Voyager	37.763125675962911	-122.428372722542647
2186	2019-08-03 07:57:57	2019-08-03	Harland Abshire	harland.abshire@geemail.com	San Francisco	California	55182404095687558	e849903028d43c20b0d435d0dea798e6	Diners Club / Carte Blanche	37.7989928335698337	-122.44937964156118
2187	2019-08-03 10:06:33	2019-08-03	Ninnie Hills	ninnie.hills@geemail.com	San Francisco	California	675959934908530	f1c7cf24bfd70345b72291207b0c05e5	American Express	37.7434338498637345	-122.485766692882237
2188	2019-08-03 12:44:12	2019-08-03	Doshie Langworth MD	doshie.langworth.md@geemail.com	San Francisco	California	6011684919481084824	0db2f54ca939f4de73405c4c712b08df	VISA 16 digit	37.7511906777585651	-122.430958130085585
2189	2019-08-03 12:59:51	2019-08-03	Sandy Osinski	sandy.osinski@geemail.com	San Francisco	California	6011050173789400581	78564bddfa2fa7ee6d3971b0873a9847	Discover	37.8019212482018006	-122.438556721780259
2190	2019-08-03 13:06:41	2019-08-03	Doshie Langworth	doshie.langworth@geemail.com	Oakland	California	53408528300416953	960a77c6847d75b263e90587983a6a7e	VISA 16 digit	37.7952774701038692	-122.272569449459965
2191	2019-08-03 15:01:54	2019-08-03	Kathie Daugherty	kathie.daugherty@warmmail.com	San Francisco	California	4191820440458230	04e766e2983f55233dad92d0853e731c	Mastercard	37.7702259312549344	-122.438996174509867
2192	2019-08-03 16:29:54	2019-08-03	Ms. Roxane Thiel DVM	ms.roxane.thiel.dvm@geemail.com	Columbus	Ohio	3400188338416152	5a8561c92d464e95001f8f9da3d0a6d8	Mastercard	39.9589362871412206	-82.9708680271871515
2193	2019-08-03 19:27:41	2019-08-03	Brenden Grimes	brenden.grimes@geemail.com	San Francisco	California	54121060576376949	3807db863a11f653a2440157d1f36140	JCB 16 digit	37.7747182409569007	-122.437147895350662
2194	2019-08-03 19:40:55	2019-08-03	Janiyah Ankunding-Carroll	janiyah.ankunding.carroll@woohoo.com	Berkeley	California	869972298970215011	23f713d1dd98938d089cff9a8b28493c	Mastercard	37.8729627567353617	-122.254165454484891
2195	2019-08-03 20:15:57	2019-08-03	Latoria Barton-Bernier	latoria.barton.bernier@geemail.com	Berkeley	California	4804122833770761	88b09a6f04a63cba2f3bb1ed69b50106	Diners Club / Carte Blanche	37.8815087725384814	-122.301964331187193
2196	2019-08-03 22:06:52	2019-08-03	Codey Stark	codey.stark@woohoo.com	Oakland	California	3753669736600899	f39d52928b5c3dbd92ab7d8c032c7d01	VISA 13 digit	37.783384153352408	-122.255594953455613
2197	2019-08-04 00:50:31	2019-08-04	Miss Alverta Conn	miss.alverta.conn@warmmail.com	San Francisco	California	4846936014119385	3c60e5a9f42a14afc77ad2d18487a9ba	VISA 16 digit	37.7788862426175172	-122.453755887512159
2198	2019-08-04 00:53:17	2019-08-04	Mrs. Zina Carroll	mrs.zina.carroll@woohoo.com	San Francisco	California	675966263241276	c6b475abf5d0a2b06c769d4cd5efd1b4	Diners Club / Carte Blanche	37.7376023679846355	-122.415942595518032
2199	2019-08-04 00:54:48	2019-08-04	Palmer Sauer	palmer.sauer@warmmail.com	Corpus Christi	Texas	3002694628377341	47ab708eaf1417cf0cba8a9b12c4740b	JCB 16 digit	27.7425387864869109	-97.1943437410347144
2200	2019-08-04 01:12:15	2019-08-04	Mamie Bernhard	mamie.bernhard@geemail.com	San Francisco	California	060492695171873	d60bbcc1f68c7d8ab3459b38bb2b774c	VISA 13 digit	37.7368471967329953	-122.456925610271199
2201	2019-08-04 03:44:44	2019-08-04	Concha Gulgowski	concha.gulgowski@geemail.com	San Francisco	California	869930604642306362	3b7a7091e678147901457e18613dab48	Discover	37.7714774991525601	-122.404470096854212
2202	2019-08-04 05:46:09	2019-08-04	Kipp Hayes	kipp.hayes@geemail.com	San Francisco	California	869988526647930832	b5e8b7581a72a7b04319653993adfb8c	VISA 16 digit	37.7506358208863873	-122.455127645829918
2203	2019-08-04 09:16:13	2019-08-04	Lige Murphy	lige.murphy@woohoo.com	San Francisco	California	869938174753258366	0bd2f0d3fca274facba3f55bfa223ff1	VISA 16 digit	37.7801170921952689	-122.418035139812929
2204	2019-08-04 09:37:30	2019-08-04	Sylas Crooks PhD	sylas.crooks.phd@geemail.com	Berkeley	California	210026781193362907	584b8ce4feefa82804daf920c45c7515	JCB 16 digit	37.853206396325227	-122.268435006702646
2205	2019-08-04 10:35:11	2019-08-04	Aliza Rath-Bailey	aliza.rath.bailey@geemail.com	San Francisco	California	869902327776749140	1fc3b800332fe316b16a482d01c36d68	Voyager	37.7669302872793153	-122.435674646083527
2206	2019-08-04 10:37:53	2019-08-04	Zachariah Romaguera II	zachariah.romaguera.ii@geemail.com	San Francisco	California	3405213423321292	247be9964c7a258b6cff410bf462eefc	Diners Club / Carte Blanche	37.7835994240278055	-122.410439275616127
2207	2019-08-04 11:30:35	2019-08-04	Christiana Krajcik	christiana.krajcik@geemail.com	Oakland	California	3473587790701419	9a2b50fcc699619769732f8851c0044e	VISA 13 digit	37.7940132828019344	-122.263037130643468
2208	2019-08-04 11:40:45	2019-08-04	Prince Littel	prince.littel@geemail.com	Oakland	California	6011077407209428825	df8e68c2ca38188be52edb6c29f7833f	Discover	37.8095335463399138	-122.252983821883049
2209	2019-08-04 16:30:52	2019-08-04	Dr. Green Collins DDS	dr.green.collins.dds@geemail.com	San Francisco	California	4397599655234831	fc3ece2daac74c0309f621ff4519d60a	JCB 16 digit	37.763018641148939	-122.433657749305837
2210	2019-08-04 18:07:53	2019-08-04	Daphne Keebler	daphne.keebler@geemail.com	Dallas	Texas	869998295039056618	d39e70a7d13e9b8540a824c131296018	Mastercard	32.8495155617866672	-96.7969156570695333
2211	2019-08-04 19:36:58	2019-08-04	Gaston Daugherty	gaston.daugherty@geemail.com	San Francisco	California	180053085029747273	e28d0f0ea30f6b8527ceae1babf89c6d	JCB 15 digit	37.7633221692105039	-122.404294005772542
2212	2019-08-04 23:37:45	2019-08-04	Dejon Satterfield	dejon.satterfield@woohoo.com	San Francisco	California	589357524595071	fed412db71165b59b871dbddc08a9536	VISA 13 digit	37.7505288493610465	-122.427676158949325
2213	2019-08-05 03:13:25	2019-08-05	Izayah Grady	izayah.grady@geemail.com	San Francisco	California	869932707935057234	1218d4cadfb3d1b73b7b978ddaa6cd43	VISA 16 digit	37.7725519517451289	-122.391980407506821
2214	2019-08-05 04:14:53	2019-08-05	Clemente Kirlin	clemente.kirlin@geemail.com	San Francisco	California	3528143435100091251	4091d1b2b54a80c8b5bb0d97a6668767	Mastercard	37.7860693739578579	-122.420774130775541
2215	2019-08-05 08:48:33	2019-08-05	Nery Douglas	nery.douglas@geemail.com	Dallas	Texas	3004222170404426	c6489af5ba575ce5026f0e9e6140ebd9	JCB 15 digit	32.7172929306320839	-96.853742388026788
2216	2019-08-05 09:55:06	2019-08-05	Gottlieb Weber	gottlieb.weber@geemail.com	San Francisco	California	3750005646995264	3e5d6c0fab33ecaeefa0b9e26468d68c	Mastercard	37.7755811872252991	-122.428436043420064
2217	2019-08-05 10:32:02	2019-08-05	Dr. Kimberlee Cronin	dr.kimberlee.cronin@woohoo.com	San Francisco	California	4878574186889161	26d90a478197a30c4db8aa0d7e8d038b	Maestro	37.8061325443649068	-122.437342318026111
2218	2019-08-05 10:34:16	2019-08-05	Elwin Koepp Sr.	elwin.koepp.sr.@warmmail.com	Oakland	California	4279129065820574	1abe77eb9dbd19b3f8c98e0b4d2902ad	JCB 16 digit	37.7642624308191017	-122.283401521132731
2219	2019-08-05 11:39:30	2019-08-05	Besse McKenzie	besse.mckenzie@geemail.com	San Francisco	California	54984376796849093	a1eba689a544bf42665d5640073e6f6e	Maestro	37.7684266639242168	-122.426564451215938
2220	2019-08-05 11:56:25	2019-08-05	Burnell Cummerata	burnell.cummerata@warmmail.com	San Francisco	California	869900524192377587	e077500f93502590ebbaf903eff6641c	Voyager	37.756952637307144	-122.41233714765454
2221	2019-08-05 12:13:20	2019-08-05	Clyda Larson	clyda.larson@warmmail.com	San Francisco	California	3112957626661072475	4f28206885037714052bc4fa323812b3	Mastercard	37.7735314391976544	-122.413038987078508
2222	2019-08-05 12:16:24	2019-08-05	Kaitlynn Bartoletti	kaitlynn.bartoletti@geemail.com	San Francisco	California	501841699699066	3a0586b1d60910f44ea17c1e58cb6d5b	Diners Club / Carte Blanche	37.7772872323579634	-122.439560958316193
2223	2019-08-05 12:58:56	2019-08-05	Marlen Dietrich	marlen.dietrich@geemail.com	San Francisco	California	4659661977048100	6d4f5f2b1d466d86c49f2e532edd4475	VISA 16 digit	37.7589364372360166	-122.453895064853171
2224	2019-08-05 13:28:05	2019-08-05	Miss Jazmine Christiansen	miss.jazmine.christiansen@geemail.com	San Francisco	California	210046191312484853	54e728a75d27731db441a0763d7f7ae3	Maestro	37.7506083371948691	-122.427545008294558
2225	2019-08-05 13:55:37	2019-08-05	Dani Runte	dani.runte@geemail.com	Oakland	California	210063970348312404	fbb80485bdece94ea2fa08ec7f20dca2	VISA 13 digit	37.7919908162372593	-122.288857303793947
2226	2019-08-05 20:58:35	2019-08-05	Dr. Reva Renner	dr.reva.renner@geemail.com	Houston	Texas	3443059638118401	fb2ff2601d7c0efce3d5fc0c7933417d	JCB 16 digit	29.7410198335614062	-95.4408821075238336
2227	2019-08-06 00:32:41	2019-08-06	Kathi Batz	kathi.batz@warmmail.com	San Francisco	California	3030982667314735	8746dbc8d2caf331c662fcc8e2a81a10	Mastercard	37.7791096160935211	-122.428495755513708
2228	2019-08-06 01:58:56	2019-08-06	Lissa Mante	lissa.mante@geemail.com	San Francisco	California	3337112302106852309	d15fd67a7493e038d1605428f0fab451	VISA 13 digit	37.7688465515087586	-122.400166128605974
2229	2019-08-06 05:27:18	2019-08-06	Dotty Kutch	dotty.kutch@warmmail.com	San Francisco	California	676212587137337	5115908c68177aef5d3f3b2b695b791a	JCB 15 digit	37.7679199826017964	-122.423754176846899
2230	2019-08-06 05:45:14	2019-08-06	Mr. Zed Emmerich I	mr.zed.emmerich.i@geemail.com	Oakland	California	3720233733733664	e9ddbddc6a92886fb655071db7986f4e	JCB 15 digit	37.806072734732119	-122.250689570957277
2231	2019-08-06 06:45:21	2019-08-06	Dwane Kemmer	dwane.kemmer@geemail.com	San Francisco	California	6011570552432753176	b6174ff0368658bf42e07dd8a1e38c71	Maestro	37.7639234917780513	-122.441582837147934
2232	2019-08-06 07:34:23	2019-08-06	Garret Stracke	garret.stracke@warmmail.com	San Francisco	California	4087099660687	b97c38b9924c5db4aba46ce7ba0e72c6	JCB 15 digit	37.7479798377606386	-122.424275995945536
2233	2019-08-06 09:10:26	2019-08-06	Benjamine Gorczany	benjamine.gorczany@warmmail.com	San Francisco	California	4055844381139190	b083cf5135233f83298236bd901e31a4	American Express	37.797421846346019	-122.417946504936737
2234	2019-08-06 10:34:27	2019-08-06	Makayla Dooley	makayla.dooley@warmmail.com	Berkeley	California	869959937338206991	fe4681a8f2f3b2986a01857ee04b3464	VISA 16 digit	37.8735902684906023	-122.258433301071889
2235	2019-08-06 11:21:51	2019-08-06	Evan Beatty	evan.beatty@geemail.com	San Francisco	California	6011872328589697663	78b0cfb72546ce65394d3cc2784744fb	Discover	37.7927950242425794	-122.429794158387026
2236	2019-08-06 19:31:51	2019-08-06	Deb Simonis	deb.simonis@geemail.com	Oakland	California	4941758710262499	7828a642591c92155c1eccc7752345a0	VISA 16 digit	37.8119535898383887	-122.262226840428099
2237	2019-08-06 20:52:12	2019-08-06	Mrs. Shirleen Koss DVM	mrs.shirleen.koss.dvm@geemail.com	San Francisco	California	6011805954502573905	cdbfa005b45b667a90e4dfd7cb7d7b34	Voyager	37.7454738104590888	-122.437216559293802
2238	2019-08-06 22:00:21	2019-08-06	Ms. Nannie Fisher	ms.nannie.fisher@warmmail.com	San Francisco	California	4980479038361168	5eb77d4dc62dff0749d5bc6f1eed12f3	VISA 16 digit	37.7829136033194999	-122.435033440661613
2239	2019-08-06 22:56:03	2019-08-06	Kellen Roob	kellen.roob@geemail.com	Atlanta	Georgia	6011619836970643664	f37cc8a8ebfe78a2f2ae827467d86a21	VISA 16 digit	33.6756963222563286	-84.4809520613446949
2240	2019-08-06 23:25:49	2019-08-06	Mrs. Rachel Brekke MD	mrs.rachel.brekke.md@warmmail.com	Chicago	Illinois	676233965464069	d9ad838363b1175377d74fdaa73f6e80	American Express	41.8402502726599579	-87.7785757047619626
2241	2019-08-07 00:01:38	2019-08-07	Dr. Memphis Kertzmann PhD	dr.memphis.kertzmann.phd@geemail.com	Plano	Texas	4237591070030583	2f7fee700b5e84deadec05926ae1629c	VISA 13 digit	33.1298204273071164	-96.7350638897340787
2242	2019-08-07 01:54:11	2019-08-07	Geovanni Gaylord Jr.	geovanni.gaylord.jr.@woohoo.com	San Francisco	California	869994346971575869	efca71da7e1e55725497beccaf23b41a	Voyager	37.7934272850071622	-122.414808500114134
2243	2019-08-07 04:36:45	2019-08-07	Grant Kub	grant.kub@geemail.com	San Francisco	California	4017198736514475	a740087f16d54d82b2e2f785a53fc3d6	Discover	37.7730369973954936	-122.435246866570395
2244	2019-08-07 06:19:28	2019-08-07	Mrs. Gwendolyn Hintz	mrs.gwendolyn.hintz@warmmail.com	Berkeley	California	4847956129476	7da2180cca16b5d93a06ebf0da1b2a13	JCB 16 digit	37.8769148389666981	-122.268328835919164
2245	2019-08-07 08:08:59	2019-08-07	Danelle Willms	danelle.willms@geemail.com	San Francisco	California	6011040762490819742	d1d039d28cd096279d2514714f3289c1	VISA 16 digit	37.7938482726898428	-122.440375974794719
2246	2019-08-07 08:14:08	2019-08-07	Mr. Amerigo Smith	mr.amerigo.smith@geemail.com	Oakland	California	180082814913031386	c6be1698ac40ed49f8dddd9eea429706	VISA 16 digit	37.7910920206929362	-122.239987754129956
2247	2019-08-07 09:19:12	2019-08-07	Pryor Hammes	pryor.hammes@geemail.com	San Francisco	California	3001941021189364	4847140af154094b0cc9cbd0ac593f42	VISA 16 digit	37.7652809988173743	-122.453809142196093
2248	2019-08-07 09:20:51	2019-08-07	Domenic Upton	domenic.upton@geemail.com	Berkeley	California	676335679943288	b85728c831aba0e8e35560607c703796	VISA 13 digit	37.8570776385790069	-122.249163123990229
2249	2019-08-07 10:55:47	2019-08-07	Mr. Alvis Carter III	mr.alvis.carter.iii@geemail.com	San Francisco	California	676363102049002	42d13fa3e85c36acbb6803612cadf133	VISA 16 digit	37.7705246251755113	-122.388198359930612
2250	2019-08-07 11:10:05	2019-08-07	Olan Grimes	olan.grimes@geemail.com	San Francisco	California	3337007817438948002	25ad214a6e90b086c5d0afbd9b256af1	American Express	37.7753216336508615	-122.469477364901934
2251	2019-08-07 12:07:01	2019-08-07	Schley Maggio	schley.maggio@woohoo.com	San Francisco	California	3158187771247150916	7974bb6ff689ad102de6f513dfd45bc2	Diners Club / Carte Blanche	37.7743085338206868	-122.42737929810167
2252	2019-08-07 14:08:39	2019-08-07	Jasmin Nicolas	jasmin.nicolas@warmmail.com	Berkeley	California	4422959346002535	e2119338b5a281d36ae4a00b42e3c68c	JCB 15 digit	37.8742184773417918	-122.28627858551647
2253	2019-08-07 15:56:38	2019-08-07	Enola Stehr-Hirthe	enola.stehr.hirthe@geemail.com	San Francisco	California	3001517612364432	df1e9e1af847abab1595b5314f927b96	VISA 16 digit	37.7517706592450679	-122.478635487440584
2254	2019-08-07 17:43:09	2019-08-07	Launa Leannon	launa.leannon@geemail.com	Boston	Massachusetts	180092109845334950	0ea930636d48f007192d54d5223ac315	Discover	42.4053907093293958	-70.9554207556366947
2255	2019-08-08 00:47:50	2019-08-08	Mrs. Eulalia Miller	mrs.eulalia.miller@geemail.com	Albuquerque	New Mexico	4645489250495294	7f0fb76549b4fc74fb9ec26bd669127c	JCB 15 digit	35.1025520127400767	-106.701633230184768
2256	2019-08-08 02:23:33	2019-08-08	Kathaleen Waelchi-Harris	kathaleen.waelchi.harris@geemail.com	Berkeley	California	3015409230238808	21b76b6eda97fbd9df9153a9bc2f9153	Mastercard	37.8908949254911107	-122.275640697948049
2257	2019-08-08 02:28:54	2019-08-08	Cara Kautzer	cara.kautzer@geemail.com	San Francisco	California	869936068068558480	d1dc3abc8a86eb0e40d44c5a1e8271bf	JCB 16 digit	37.806320043308915	-122.470041689866662
2258	2019-08-08 03:07:17	2019-08-08	Dr. Jame McDermott V	dr.jame.mcdermott.v@geemail.com	San Francisco	California	4801893207298935	2f67f49d726403c0f164bdea28844572	Maestro	37.7922640739004478	-122.451744839174438
2259	2019-08-08 04:09:21	2019-08-08	Annie Nader	annie.nader@geemail.com	San Francisco	California	4635331222250	b541b0b42a09a16d3bcad03548198aed	JCB 16 digit	37.7664964592485575	-122.417649098907205
2260	2019-08-08 06:48:34	2019-08-08	Dr. Colin Zboncak DDS	dr.colin.zboncak.dds@warmmail.com	San Francisco	California	3049568681216625	2783127ac5af8091d048b995b5b83cde	Discover	37.7461671350353214	-122.454156015530202
2261	2019-08-08 08:38:00	2019-08-08	Mrs. Jaelynn Will	mrs.jaelynn.will@warmmail.com	Berkeley	California	6011495510050052505	3e8ee8faad77acf8473b24ee0351b55b	Discover	37.8721424259509334	-122.306598966358436
2262	2019-08-08 10:52:50	2019-08-08	Bird Kemmer	bird.kemmer@woohoo.com	Oakland	California	55655145193851582	9fa401be8e2dd83f321ce5e86cee29f1	Voyager	37.8071532662978171	-122.312303912825016
2263	2019-08-08 17:32:13	2019-08-08	Mr. Erie Lindgren	mr.erie.lindgren@geemail.com	Concord	California	869929590513061652	223d648042cd2bca28ca520cd1e1e802	JCB 15 digit	38.0493265523973889	-122.075986694701385
2264	2019-08-08 19:11:59	2019-08-08	Davin Romaguera	davin.romaguera@woohoo.com	Oakland	California	54551406593261201	5135ed3c5ee019c0165b685813e4912d	Mastercard	37.8171727309426018	-122.252957398931358
2265	2019-08-08 19:35:04	2019-08-08	Ruel Stanton	ruel.stanton@woohoo.com	San Francisco	California	3050731730227188	b791123324f97d2f93bb7d2fbf7bd09c	Voyager	37.7328989483787254	-122.417494953549166
2266	2019-08-08 21:17:16	2019-08-08	Mr. Brantley Kertzmann IV	mr.brantley.kertzmann.iv@geemail.com	San Francisco	California	3703948045629281	7c5ac6b9a1a3a1154d2cf17a466b5d43	Mastercard	37.778639464365078	-122.449112510874642
2267	2019-08-08 21:20:07	2019-08-08	Myrtle Lowe	myrtle.lowe@geemail.com	San Francisco	California	55791172939139655	b1243d23c824d8d935f16ea31466aed6	VISA 16 digit	37.7648340857527103	-122.425178160307439
2268	2019-08-08 22:54:45	2019-08-08	Cleo Bergstrom	cleo.bergstrom@woohoo.com	Berkeley	California	3158304591853093376	ea7fa09e7a3d4f2273d0f58cd0dc0dc6	Discover	37.8690948167863155	-122.291036761177679
2269	2019-08-09 01:12:53	2019-08-09	Dr. Michaele Lynch PhD	dr.michaele.lynch.phd@geemail.com	San Francisco	California	869986823316379264	c0dbb5046876df0e24affa8ea2a8d90d	VISA 16 digit	37.7704966519989469	-122.435427324166568
2270	2019-08-09 03:28:06	2019-08-09	Versie Bode	versie.bode@geemail.com	Tulsa	Oklahoma	3528327510429047784	886e6da367cab33ab3ba8a21b602006e	Voyager	36.0948380234088688	-95.8150774415537683
2271	2019-08-09 03:57:04	2019-08-09	Ana Fritsch	ana.fritsch@geemail.com	San Francisco	California	4019300142445	d77b669b25fa5df4aefea5fc1394f7bf	Maestro	37.7787694403706524	-122.463585233599048
2272	2019-08-09 04:34:19	2019-08-09	Ernst Wilkinson	ernst.wilkinson@geemail.com	San Francisco	California	3442219865970129	3230005d5f6d69c6b8bd3ce06d4b2eaa	JCB 16 digit	37.7643428060677024	-122.449473836715086
2273	2019-08-09 05:04:21	2019-08-09	Kip Schaefer	kip.schaefer@geemail.com	San Francisco	California	3450609688046116	8ccccea6cafbf6a12e498dec1d2b7e2d	VISA 16 digit	37.7677282312983351	-122.424140091540551
2274	2019-08-09 05:12:44	2019-08-09	Hubbard Berge V	hubbard.berge.v@geemail.com	San Francisco	California	3096084632884773630	69ced7a492b6c170db0dfd605b788159	JCB 16 digit	37.7528225873188887	-122.417626806984671
2275	2019-08-09 05:13:07	2019-08-09	Kaylene Kertzmann-Becker	kaylene.kertzmann.becker@geemail.com	San Francisco	California	3408403735105775	1e66a201a51a406041c6eb0d1a03e21c	JCB 15 digit	37.7616244680117035	-122.460980910044128
2276	2019-08-09 08:24:08	2019-08-09	Aida Murazik	aida.murazik@warmmail.com	San Francisco	California	6011064940841798044	26c0c245c7af79fea14b6a332c89fee9	JCB 16 digit	37.7663502077695767	-122.403863584455806
2277	2019-08-09 08:34:47	2019-08-09	Robby Hackett	robby.hackett@geemail.com	San Francisco	California	180006855629418600	47187092fc6a78e6f661fb3906ecb8b7	American Express	37.7667018367161162	-122.417512121198172
2278	2019-08-09 12:27:42	2019-08-09	Abie Towne	abie.towne@geemail.com	San Francisco	California	3790556445194774	e290ed6487260ecf0f9f5ef668b95d3a	VISA 16 digit	37.7419408581350382	-122.430624634099672
2279	2019-08-09 16:18:01	2019-08-09	Mrs. Jesenia Rutherford	mrs.jesenia.rutherford@geemail.com	San Francisco	California	3009430951026954	6f571feae387116580ec9b0a9807c4b8	Mastercard	37.7440333233396359	-122.440067477155807
2280	2019-08-09 16:19:57	2019-08-09	Bradley Gorczany	bradley.gorczany@woohoo.com	San Francisco	California	3112311082494918404	15f79c97de421710984c458832d2ffe9	VISA 16 digit	37.8033852757107809	-122.417359374509843
2281	2019-08-09 16:23:11	2019-08-09	Dr. Collis Schmidt IV	dr.collis.schmidt.iv@warmmail.com	El Cajon	California	869991755441006615	c6248a6495647925ef70e6deb57f8eb6	JCB 15 digit	32.7294250503189801	-116.954995640571795
2282	2019-08-09 16:38:54	2019-08-09	Tilden Balistreri-Harber	tilden.balistreri.harber@geemail.com	San Francisco	California	3492921735736692	af1a74edf08cb54171f1e86ee2936956	JCB 15 digit	37.7851675307405941	-122.454812089133981
2283	2019-08-09 20:45:30	2019-08-09	Mr. Randal Schultz	mr.randal.schultz@geemail.com	San Francisco	California	3042988170485985	83d7a1e6ada7a0d3977668549fccead7	JCB 16 digit	37.7460321883469874	-122.444355332939224
2284	2019-08-09 21:36:30	2019-08-09	Brittany Abshire	brittany.abshire@geemail.com	San Francisco	California	3058561689265851	be59c1ccbae479e6f335125aec681109	Discover	37.7747153717336488	-122.418112819870714
2285	2019-08-10 01:24:04	2019-08-10	Lue Schamberger-Vandervort	lue.schamberger.vandervort@geemail.com	San Francisco	California	4480141479974561	54a32e7dfe423f223e77c248fedc021b	Discover	37.7566530248819845	-122.44489075960719
2286	2019-08-10 02:11:17	2019-08-10	Kalel Hilll V	kalel.hilll.v@geemail.com	San Francisco	California	4787983625411	d86783bd5a429eafdb92bc23efeb522d	VISA 16 digit	37.769556477600652	-122.406431347657744
2287	2019-08-10 03:13:32	2019-08-10	Cornel Barrows-Reichel	cornel.barrows.reichel@geemail.com	San Francisco	California	4964902733291	25a6214e13b16c8ee2b71d6027d81ec9	JCB 16 digit	37.7622148861567553	-122.410463710502697
2288	2019-08-10 04:45:11	2019-08-10	Boyce Gleichner Sr.	boyce.gleichner.sr.@geemail.com	Oakland	California	4358812704440870	7bc243cc9959414d2141b6bae6833c65	VISA 16 digit	37.8097924987839349	-122.262134727366657
2289	2019-08-10 05:24:30	2019-08-10	Tristan Berge-Gislason	tristan.berge.gislason@geemail.com	Berkeley	California	210074956150177529	e3865c73c37d271ac18a7d13e8915ebd	VISA 13 digit	37.8547987502151742	-122.270483918000778
2290	2019-08-10 05:56:24	2019-08-10	Zelma Bradtke	zelma.bradtke@geemail.com	San Francisco	California	3445737067812119	90b642f0eeb1d1345ef0115ed11224dd	JCB 16 digit	37.7502237703205594	-122.470813469946592
2291	2019-08-10 10:17:15	2019-08-10	Marleigh Lemke	marleigh.lemke@warmmail.com	San Francisco	California	869909325201806447	0276850cc43098f0f109c1c13bb0952c	Voyager	37.7766508294859022	-122.396185932130066
2292	2019-08-10 11:22:04	2019-08-10	Annalise Kirlin	annalise.kirlin@geemail.com	San Francisco	California	3009912999090621	ae967817d37c9bd7d6b2212f7b9c5b76	Discover	37.755946045180238	-122.439273303478743
2293	2019-08-10 14:25:51	2019-08-10	Evelena Walter	evelena.walter@geemail.com	San Francisco	California	3158856338609607832	3ad93205ae479fbbce215d87bc6b7d01	Voyager	37.7881771596878195	-122.434601143906647
2294	2019-08-10 15:57:24	2019-08-10	Jordi Hudson	jordi.hudson@warmmail.com	San Francisco	California	51084257028763527	23e170b82384c4c5e2447332e3b2617f	VISA 16 digit	37.7766013064430979	-122.435653354062211
2295	2019-08-10 16:50:31	2019-08-10	Dell Buckridge-Bauch	dell.buckridge.bauch@geemail.com	San Francisco	California	4578471071669316	b2fbe94577b89052a7e5a221ed5c1b72	Maestro	37.8067516681011568	-122.439271932093021
2296	2019-08-10 18:46:13	2019-08-10	Mr. Harvey Ward I	mr.harvey.ward.i@geemail.com	Atlanta	Georgia	3002312208275450	4d80d89844eeefd03df1fd0e7273d58c	JCB 16 digit	33.7745576850414295	-84.4019076256591916
2297	2019-08-10 20:30:19	2019-08-10	Everet Kautzer-Mueller	everet.kautzer.mueller@geemail.com	San Francisco	California	3088798240931615825	385d25f6b7fd38679dcba15012d99433	Diners Club / Carte Blanche	37.7391668373792939	-122.47225610354576
2298	2019-08-10 22:14:52	2019-08-10	Ivy Wintheiser	ivy.wintheiser@geemail.com	Los Angeles	California	4063793549682	957e4c98bc4ea606dfecd1f17e61cce2	VISA 16 digit	33.968131173994017	-118.358030346500868
2299	2019-08-10 22:35:05	2019-08-10	Dr. Omarion Roberts MD	dr.omarion.roberts.md@geemail.com	San Francisco	California	3703934579679058	f323a85e29200ecb227dbf2d56498da1	JCB 16 digit	37.7715101350926119	-122.429730391716291
2300	2019-08-10 23:51:40	2019-08-10	Maximillian Wintheiser Sr.	maximillian.wintheiser.sr.@geemail.com	San Francisco	California	869960519383697758	ba493fe9d3b44ceffb1014729110618c	Diners Club / Carte Blanche	37.7144736408019128	-122.452018921136215
2301	2019-08-11 04:39:59	2019-08-11	Irine Crona	irine.crona@geemail.com	Berkeley	California	3781836267453719	520444dc1076a86bf85b1edf806c37c5	American Express	37.8712988490151119	-122.288082488041979
2302	2019-08-11 06:35:59	2019-08-11	Devyn O'Keefe DVM	devyn.o'keefe.dvm@geemail.com	New York	New York	630443267348530	a87309ca27b1bb901417040099762ec8	Mastercard	40.5977190975323339	-73.8414690974529861
2303	2019-08-11 06:58:41	2019-08-11	Yolonda Sipes	yolonda.sipes@geemail.com	Oakland	California	3019657978241147	48dd8cf18b76d0bebb0e4aac07c4d192	JCB 15 digit	37.7977874610646296	-122.26629631212387
2304	2019-08-11 10:09:49	2019-08-11	Kelly Bergnaum-Graham	kelly.bergnaum.graham@woohoo.com	Oakland	California	3481354195508802	d4e46dc627f73bb311aac270b8116126	Discover	37.8396522883436077	-122.252268100804486
2305	2019-08-11 10:48:08	2019-08-11	Ms. Dawna Borer MD	ms.dawna.borer.md@geemail.com	Costa Mesa	California	4505579966964051	3a36bcf95132d5b3dcb11bf7d775d35a	JCB 16 digit	33.7228420479703672	-117.889270493094998
2306	2019-08-11 11:27:15	2019-08-11	Denice Olson	denice.olson@geemail.com	San Francisco	California	501889973447140	5dbe1adc73090f8dfbf70e9b0d43551f	Maestro	37.7932663895175835	-122.429936138735542
2307	2019-08-11 12:23:12	2019-08-11	Ottie Ritchie	ottie.ritchie@geemail.com	Oakland	California	869976360616425622	ac73adf67197e81718bc83b7b788c957	VISA 13 digit	37.8154283975447427	-122.249534484670178
2308	2019-08-11 13:34:37	2019-08-11	Mrs. Desiree Boyer	mrs.desiree.boyer@geemail.com	San Francisco	California	3409930343249693	055c5d8d0f747ddd411903ed4f5ef191	VISA 13 digit	37.7909946089340352	-122.438799375036012
2309	2019-08-11 13:41:03	2019-08-11	Kristina Donnelly-Considine	kristina.donnelly.considine@warmmail.com	San Francisco	California	4552937233708	9f264b5af3caaaf35a223f536ce50b39	JCB 15 digit	37.7555684128215461	-122.417699908843389
2310	2019-08-11 15:28:06	2019-08-11	Lillia Wiegand	lillia.wiegand@woohoo.com	Oakland	California	55569099600915743	babdbcd9ed44cbfe8738ff92348ab147	VISA 16 digit	37.8263957709647727	-122.273156514316611
2311	2019-08-11 16:16:09	2019-08-11	Alize Hodkiewicz DDS	alize.hodkiewicz.dds@woohoo.com	San Francisco	California	4943853570994741	bc5b61a5d40a5497f8f175ccc6a21c23	Mastercard	37.781393069740723	-122.406777074782156
2312	2019-08-11 17:30:34	2019-08-11	Mel Jakubowski	mel.jakubowski@geemail.com	Oakland	California	3456451906227689	77233b42897a4888aa1119553939e189	JCB 15 digit	37.8309633681193205	-122.263028898731577
2313	2019-08-11 19:17:45	2019-08-11	Gladyce Bashirian-Schowalter	gladyce.bashirian.schowalter@geemail.com	San Francisco	California	630410150811932	781deebaf9d2563091ee30b56e038498	Maestro	37.7758694271413447	-122.404244875790724
2314	2019-08-11 19:30:01	2019-08-11	Vernie Nikolaus	vernie.nikolaus@geemail.com	Berkeley	California	51432903586309398	95270333667f8496f6cf4a142e8942d7	Discover	37.852394211115957	-122.279173118274684
2315	2019-08-11 19:48:48	2019-08-11	Kaitlynn Crooks	kaitlynn.crooks@warmmail.com	San Francisco	California	4301970877892	6494d3afc829dd5c28cac28dd022ed76	JCB 16 digit	37.7666327047187522	-122.442921011276255
2316	2019-08-11 22:44:27	2019-08-11	Tasha Luettgen	tasha.luettgen@geemail.com	San Francisco	California	3792835621103603	d8387f2527d01081285dbf043699b447	Discover	37.7626188830490221	-122.441356533667488
2317	2019-08-12 02:57:13	2019-08-12	Dr. Elisha Halvorson	dr.elisha.halvorson@woohoo.com	San Francisco	California	4932298502260998	2d4e4cc0997286299471fd830d41d364	JCB 16 digit	37.8083604780764801	-122.460387550404249
2318	2019-08-12 04:44:54	2019-08-12	Addyson Halvorson	addyson.halvorson@geemail.com	San Francisco	California	4052080808091	284b0501526eb9caf1f4903ca7a00109	Diners Club / Carte Blanche	37.8048128600557263	-122.411361627605004
2319	2019-08-12 05:01:35	2019-08-12	Peter Stroman	peter.stroman@geemail.com	Oakland	California	4877841748039499	0c455efb32ef2ec8314e8f588f32d67b	JCB 15 digit	37.8239640793810992	-122.291095079337268
2320	2019-08-12 09:44:22	2019-08-12	Mr. Handy Volkman	mr.handy.volkman@geemail.com	San Francisco	California	4185983878840077	d08840442a2545017019443aa163a97a	Discover	37.7930092402987015	-122.452122158182831
2321	2019-08-12 11:35:01	2019-08-12	Darcie Bode	darcie.bode@geemail.com	Oakland	California	3112694241247559918	4dad6d0415db283104ee3045403c2ddc	Diners Club / Carte Blanche	37.8480402205174755	-122.263005277352789
2322	2019-08-12 11:56:13	2019-08-12	Adelard Ledner PhD	adelard.ledner.phd@geemail.com	San Francisco	California	6011898489471620351	0010a6037cf0cc0487f26d2bbe945280	VISA 16 digit	37.7681047338832343	-122.423163307215447
2323	2019-08-12 16:11:59	2019-08-12	Kiley Little DVM	kiley.little.dvm@woohoo.com	Augusta	Georgia	3112461282277099160	3f90df903d9e0a1e62a52fd7757bfc9d	Mastercard	33.281046574303879	-82.1064015785060946
2324	2019-08-12 17:50:27	2019-08-12	Nathanael Schuppe-Ziemann	nathanael.schuppe.ziemann@warmmail.com	San Francisco	California	51086458774013418	4912ccbba94690dc02bdd89d75d735d7	JCB 16 digit	37.7741097460096285	-122.431062102447683
2325	2019-08-12 18:17:18	2019-08-12	Colbert Collins	colbert.collins@geemail.com	San Francisco	California	210092463423521649	0625a75d71c19c228d6e08f70d146a90	JCB 16 digit	37.816835287169063	-122.422955824080987
2326	2019-08-12 19:39:56	2019-08-12	Davy O'Hara	davy.o'hara@geemail.com	San Francisco	California	4527025000432923	10dfd0d841dcb89d1d02755e2a7eee49	Discover	37.7766662180501811	-122.432683915625105
2327	2019-08-12 20:39:43	2019-08-12	Gorden Johnson	gorden.johnson@geemail.com	San Francisco	California	6011271308773948582	f446627159a8eba931e0edf77b99cb26	VISA 16 digit	37.7499311957803201	-122.448664569456
2328	2019-08-12 20:56:22	2019-08-12	Babyboy Greenfelder	babyboy.greenfelder@woohoo.com	San Francisco	California	3158102996704376389	d3b17a98be4dd17b2fe3484c2d1c74f4	VISA 13 digit	37.7929635075902581	-122.461988511766691
2329	2019-08-12 21:05:16	2019-08-12	Dr. Garfield Larson	dr.garfield.larson@geemail.com	Oakland	California	54588477360450654	f204c84174c8e0ae5a4b4edd04caa5dd	Maestro	37.8026513527640304	-122.248391016024641
2330	2019-08-12 21:44:38	2019-08-12	Devan Mills	devan.mills@geemail.com	Lansing	Michigan	4449743413123880	d0edcd4de3d65d82467d4c9f4ccb4b3c	Mastercard	42.6589396164596124	-84.6240178786806752
2331	2019-08-12 22:16:31	2019-08-12	Dr. Charlie Reilly PhD	dr.charlie.reilly.phd@geemail.com	San Francisco	California	4575897022802379	1183d58b6274ed8d304c2afbbea93a3e	Maestro	37.7968347940495093	-122.434755963745133
2332	2019-08-13 05:04:09	2019-08-13	Dorman Marks	dorman.marks@woohoo.com	Vallejo	California	180088015252764553	6af209f3d5d1cbf210688961908c653b	Diners Club / Carte Blanche	38.1485935915816583	-122.317134646080433
2333	2019-08-13 05:17:58	2019-08-13	Drake Zemlak	drake.zemlak@geemail.com	Berkeley	California	4776088733634	745800335e9bc594c7fa14a07240f196	VISA 13 digit	37.851094078824147	-122.270594891741212
2334	2019-08-13 07:32:02	2019-08-13	Dr. Janiyah Shields	dr.janiyah.shields@woohoo.com	San Francisco	California	180012253632139599	2987f9d8641740fbb460e96f29e3e230	Voyager	37.7588974444404002	-122.411487207869456
2335	2019-08-13 07:58:36	2019-08-13	Paul McLaughlin	paul.mclaughlin@geemail.com	Berkeley	California	4160625835782	33758e67c57fb36bb386584499814df7	Voyager	37.8765933028915214	-122.303071685876162
2336	2019-08-13 08:58:46	2019-08-13	Maxx Howe	maxx.howe@geemail.com	Oakland	California	53744543279033559	40d4514e4ff4d5ddcdeb5f0c23edd319	VISA 16 digit	37.8101087852111561	-122.240118649549075
2337	2019-08-13 10:28:43	2019-08-13	Rashawn Gerhold-Stamm	rashawn.gerhold.stamm@warmmail.com	Oakland	California	4567505136219279	29ea8207f667bbe977c4e096784afb44	Voyager	37.8176747954312447	-122.277042315727329
2338	2019-08-13 11:20:36	2019-08-13	Ms. Cathrine Tromp DVM	ms.cathrine.tromp.dvm@geemail.com	Chicago	Illinois	676215943932606	cd6e4379c8a3a59940a44bd26e96bbcb	Voyager	41.9235706927090916	-87.7022915292561009
2339	2019-08-13 11:59:10	2019-08-13	Mr. Mervin Hauck II	mr.mervin.hauck.ii@woohoo.com	Berkeley	California	869994912190390859	2988a6da4ee4075ee2bb7a204e3103b1	American Express	37.8778990510413678	-122.268210796165121
2340	2019-08-13 13:35:27	2019-08-13	Chelsea Heaney	chelsea.heaney@geemail.com	San Francisco	California	3001662112300351	c6da65498dc29af2647537af9fcb9bc7	VISA 13 digit	37.7579293202865713	-122.448634124933065
2341	2019-08-13 14:09:39	2019-08-13	Dr. Lavar Lind Jr.	dr.lavar.lind.jr.@geemail.com	Berkeley	California	4953295772847300	f9858ad00d534106d0fdd7aaa7d65244	JCB 16 digit	37.8435996241177079	-122.248385170156624
2342	2019-08-13 15:45:56	2019-08-13	Madge Goldner	madge.goldner@geemail.com	San Francisco	California	4168337501108090	c494340c1f2464e8b484f26f7092f122	Mastercard	37.7735119363321701	-122.436688495952026
2343	2019-08-13 16:29:52	2019-08-13	Jessy Hyatt	jessy.hyatt@geemail.com	Berkeley	California	4717281541465	c95949506747a174de7c151052246ae9	JCB 16 digit	37.8248512217359902	-122.260121252581541
2344	2019-08-13 20:34:32	2019-08-13	Napoleon Davis	napoleon.davis@geemail.com	San Francisco	California	210018444876070350	a7eca535c1cfbe20c7441274355af580	JCB 16 digit	37.7478479079501668	-122.413974271009749
2345	2019-08-13 20:57:19	2019-08-13	Lamar Boehm	lamar.boehm@warmmail.com	San Francisco	California	4046661804106891	190ecdf0509091f5ebb7c7ea30e0f9cd	Diners Club / Carte Blanche	37.761816497477696	-122.454946981401946
2346	2019-08-14 00:08:11	2019-08-14	Karli Howe	karli.howe@geemail.com	San Francisco	California	869924956559625939	9d87b9c74a1edd0cc212d084b3bb2bb4	JCB 15 digit	37.7405356690232452	-122.407940935058789
2347	2019-08-14 01:40:36	2019-08-14	Hosie Sawayn II	hosie.sawayn.ii@warmmail.com	Oakland	California	3749285634861637	53aed93a21961e7d5010826f4419591a	JCB 16 digit	37.7928462793936859	-122.275450225373774
2348	2019-08-14 03:38:00	2019-08-14	Samir Kilback Sr.	samir.kilback.sr.@woohoo.com	San Francisco	California	4740008943111	747d1e455ecbd115c79a2c0d2af71d6a	Voyager	37.7469847422540852	-122.451792191294771
2349	2019-08-14 12:27:14	2019-08-14	Ms. Ardeth Herman MD	ms.ardeth.herman.md@geemail.com	San Francisco	California	6011319672818138564	e899429ad18192eb917ca56417fe0fc7	American Express	37.7587941594595478	-122.462862685680051
2350	2019-08-14 16:51:09	2019-08-14	Wilton Kertzmann	wilton.kertzmann@geemail.com	San Francisco	California	3112250661562896296	48683717187a7530096fddad87241e95	VISA 16 digit	37.7918886433389005	-122.441346740488228
2351	2019-08-14 17:12:48	2019-08-14	Dr. Terrill Boyer Jr.	dr.terrill.boyer.jr.@geemail.com	Berkeley	California	3158408628475067787	85de3ab1b181cbce77f0e7425e06adb6	VISA 16 digit	37.8889329967902242	-122.259981515341579
2352	2019-08-14 19:38:25	2019-08-14	Idamae Harber	idamae.harber@geemail.com	San Francisco	California	4120442041014	29d3f73c50023c79e0a3e00c1696641e	JCB 15 digit	37.7715142563389961	-122.408709249432249
2353	2019-08-14 21:31:37	2019-08-14	Romello Reichel	romello.reichel@geemail.com	San Francisco	California	3403400203865885	d591eabefbfad2cf03e03309cb97728f	Voyager	37.7875292174529918	-122.477114005644395
2354	2019-08-14 21:51:09	2019-08-14	Mrs. Oleta Hauck	mrs.oleta.hauck@warmmail.com	San Francisco	California	869988613404280898	1b148f78328f10d482b6fdd76420c9d6	Discover	37.74863601353006	-122.44694318167808
2355	2019-08-14 22:17:26	2019-08-14	Enos Glover-Abernathy	enos.glover.abernathy@geemail.com	Austin	Texas	4529463469631750	1efab3c6ff60eafc52cff1e57015f20a	VISA 13 digit	30.3415656342297773	-97.7348402437992405
2356	2019-08-14 22:53:28	2019-08-14	Hettie Hackett	hettie.hackett@geemail.com	San Francisco	California	639054912559769	1dc4dcadbbf5aabc437227c45e4bb8f5	VISA 16 digit	37.7888085081762739	-122.437054342893433
2357	2019-08-14 23:20:48	2019-08-14	Alannah Hahn	alannah.hahn@geemail.com	North Las Vegas	Nevada	869994569099638620	0bf055c415ae1d42f3070ac8a5b4d0b9	Voyager	36.1886605904128373	-115.005820018075042
2358	2019-08-14 23:25:04	2019-08-14	Sherrie Senger	sherrie.senger@geemail.com	Oakland	California	3003698234485686	c3b775d00fcb37ce29822292b729668a	VISA 16 digit	37.7969033006896211	-122.264068383346512
2359	2019-08-14 23:37:13	2019-08-14	Shelley Huels	shelley.huels@geemail.com	Oakland	California	4019188541750099	50ff771b793980835372c61c1daa1507	JCB 16 digit	37.8118083451033655	-122.289028789891262
2360	2019-08-15 02:50:10	2019-08-15	Gisselle Brakus-Dach	gisselle.brakus.dach@woohoo.com	San Francisco	California	4808359987612862	68d2c7abb0a1a94dca87e9d4e46b48fb	American Express	37.7806184884234995	-122.417752927364589
2361	2019-08-15 02:57:53	2019-08-15	Washington Marvin	washington.marvin@geemail.com	San Francisco	California	3528879059542226133	8d45f2931ced7cc8a5ca3db359999d9b	Discover	37.7560990035764945	-122.433852873435796
2362	2019-08-15 03:23:45	2019-08-15	Ewald Lehner	ewald.lehner@geemail.com	New York	New York	3739758718589268	aa387e363e74b49190badc56a6b6969e	JCB 16 digit	40.6615482981074621	-74.0068034908629926
2363	2019-08-15 03:59:33	2019-08-15	Denine Kulas	denine.kulas@geemail.com	San Francisco	California	4761343004353671	e209d14022144f3ce02d16128081f38d	VISA 16 digit	37.7829336655675974	-122.441976069883196
2364	2019-08-15 07:39:37	2019-08-15	Jered Bruen	jered.bruen@geemail.com	Berkeley	California	180047739743128074	b21ef707dea3aa4165275ca4bd387ea7	Maestro	37.8639078211440534	-122.273602866870732
2365	2019-08-15 07:39:53	2019-08-15	Bailey Kirlin	bailey.kirlin@geemail.com	San Francisco	California	210009322547385160	8456d0acce4a328ed8306d58bc3c78ad	Diners Club / Carte Blanche	37.7629570425952465	-122.400466967121716
2366	2019-08-15 08:16:51	2019-08-15	Mr. Roland Williamson Jr.	mr.roland.williamson.jr.@geemail.com	San Francisco	California	3035058448429376	12b675008dbefe3536a1983146b16a61	Maestro	37.7513382443378447	-122.463753028711807
2367	2019-08-15 08:57:05	2019-08-15	Mr. Talmage Kovacek	mr.talmage.kovacek@geemail.com	San Francisco	California	3485860632827536	b0f6646b8cf46598cdbbeaa6daf6d7e1	JCB 16 digit	37.7621546789607123	-122.466995494220271
2368	2019-08-15 09:37:05	2019-08-15	Larue Little	larue.little@woohoo.com	Oakland	California	3112420689960206938	41fe5241c5ec56f8206903a217660c7b	JCB 16 digit	37.8151544567653133	-122.29148057173505
2369	2019-08-15 17:59:36	2019-08-15	Dr. Aydin Bartoletti	dr.aydin.bartoletti@warmmail.com	San Francisco	California	676289183788952	51bfc4647ee41a3bc119eb5fefdbe999	Maestro	37.777422462190863	-122.429514874617169
2370	2019-08-15 18:30:18	2019-08-15	Stephan Collins	stephan.collins@warmmail.com	San Francisco	California	869931011425425022	4a6e1ea398e6c028e11db2b8aa327a9b	Maestro	37.7635653540354568	-122.44471378367291
2371	2019-08-15 18:47:02	2019-08-15	Dean Stehr	dean.stehr@geemail.com	San Francisco	California	3033851016591995	e871c678f2dc0103b0a95c2da305d482	JCB 16 digit	37.7742234301200952	-122.424984079113088
2372	2019-08-15 19:20:35	2019-08-15	Mr. Jerod Mayert DVM	mr.jerod.mayert.dvm@geemail.com	San Diego	California	4837357395238945	72e3a32cd55a00c02d64c5a8eb08f6e3	Discover	32.8354726596336803	-117.107723736520867
2373	2019-08-15 20:16:45	2019-08-15	Mr. Roland Halvorson	mr.roland.halvorson@geemail.com	San Francisco	California	503806614886817	3388416f6ce993046578ce23f77f3b2a	VISA 16 digit	37.7951219271232617	-122.458435761207198
2374	2019-08-16 00:47:39	2019-08-16	Ah Lowe	ah.lowe@geemail.com	San Francisco	California	54733354405624557	a090668dc9ef8382229272c5eef6d26b	VISA 16 digit	37.7499165706689226	-122.455234981095359
2375	2019-08-16 02:15:45	2019-08-16	Idabelle Kessler-Heathcote	idabelle.kessler.heathcote@geemail.com	San Francisco	California	4802711175110990	bc22ec6c07c6f453cd709d3fd9457859	VISA 16 digit	37.7890073828433941	-122.40785496154092
2376	2019-08-16 04:14:04	2019-08-16	Tallie O'Hara-Turcotte	tallie.o'hara.turcotte@geemail.com	Berkeley	California	3096537682732691339	e75a9aa0c1231426e8399763923a2cde	JCB 15 digit	37.872486514062679	-122.254265220905623
2377	2019-08-16 05:37:05	2019-08-16	Iola Schaefer	iola.schaefer@geemail.com	San Francisco	California	3002430473316286	f97b9d69db325446a26ffecec1eaa6e7	Discover	37.7960959409290425	-122.422426537015923
2378	2019-08-16 07:48:23	2019-08-16	Hollis Wisozk	hollis.wisozk@woohoo.com	San Francisco	California	4217223859187426	7a224f68f0595adb7e23775790c3a98e	Mastercard	37.7746152952256509	-122.391742741426413
2379	2019-08-16 08:18:22	2019-08-16	Basil Hand III	basil.hand.iii@geemail.com	San Francisco	California	4154531473390	54e1fd0cf9779632801ff343d40e20be	JCB 16 digit	37.7643083234453982	-122.426883038372367
2380	2019-08-16 09:39:54	2019-08-16	Ana Gislason	ana.gislason@geemail.com	San Francisco	California	210024440091536359	deab824389abb31cd82a6fd779d007e6	Mastercard	37.7784534389998043	-122.410176336472176
2381	2019-08-16 12:00:19	2019-08-16	Chessie Heathcote DDS	chessie.heathcote.dds@geemail.com	San Francisco	California	4412273933294972	620cd424cf6044bd0c630b631a6a9254	American Express	37.7798324323155299	-122.436693778116364
2382	2019-08-16 14:37:11	2019-08-16	Dr. Nakia Ullrich	dr.nakia.ullrich@geemail.com	San Francisco	California	4012508359493531	20a5fdd0a09519abb999fde913d053a3	VISA 13 digit	37.8071533972248304	-122.446754852546306
2383	2019-08-16 14:50:44	2019-08-16	Manda Rutherford-Baumbach	manda.rutherford.baumbach@geemail.com	San Francisco	California	3027225202430811	3f70d5e6e10ab9714d311d67fe2e0d82	JCB 16 digit	37.7753824751893958	-122.452260670005174
2384	2019-08-16 15:59:06	2019-08-16	Love Fay-Gottlieb	love.fay.gottlieb@geemail.com	San Francisco	California	3472460611741504	d80664997a97b0f3fcf038f54347b3e9	Maestro	37.7386342157731178	-122.414038433971172
2385	2019-08-16 18:00:13	2019-08-16	Channing Grant-Effertz	channing.grant.effertz@warmmail.com	San Francisco	California	55499878592858937	167906e64ba9a0e1e03d173c211d923b	JCB 16 digit	37.7648327969083368	-122.446976469795629
2386	2019-08-16 19:17:27	2019-08-16	Madora Bode	madora.bode@woohoo.com	Jacksonville	Florida	3112428352529070632	26e5de252ddebd39c97748b8274cc56d	Maestro	30.31692137709409	-81.6906320820640843
2387	2019-08-16 20:06:26	2019-08-16	Bula Von	bula.von@geemail.com	San Francisco	California	6011258250023242324	1f9acbe9e1146d02f37b14d540b80cda	JCB 16 digit	37.7828208566675059	-122.398264519367146
2388	2019-08-16 21:03:55	2019-08-16	Aubra Hegmann IV	aubra.hegmann.iv@geemail.com	Berkeley	California	3112482910855238108	7d094d6e58355f50eb545fc5a7c540ca	Discover	37.8176854460171299	-122.234199644462137
2389	2019-08-16 23:47:01	2019-08-16	Kayla Rosenbaum	kayla.rosenbaum@woohoo.com	San Francisco	California	501863250459169	344b11d6b3914323748f8ab012ed3ab3	VISA 16 digit	37.7260771696641726	-122.388062151590788
2390	2019-08-16 23:47:48	2019-08-16	Fidelia Gleichner	fidelia.gleichner@geemail.com	Seattle	Washington	6011622137581706247	c940070e9d13ae592c0646e8c2a4e81d	VISA 16 digit	47.5954023868702336	-122.373450414688875
2391	2019-08-17 00:37:24	2019-08-17	Isaiah Turcotte	isaiah.turcotte@woohoo.com	Fairfield	California	4026281955646	16133f49f88a3e976406faccfbb0f2a1	VISA 13 digit	38.277343469963597	-122.1243862965148
2392	2019-08-17 04:47:54	2019-08-17	Tina Swaniawski-Herzog	tina.swaniawski.herzog@geemail.com	Oakland	California	3013891481072618	2917ca513685b3ba0a902b6a11c97dde	American Express	37.8195852858409438	-122.24822733833885
2393	2019-08-17 08:42:57	2019-08-17	Daneen Altenwerth	daneen.altenwerth@woohoo.com	Nashville	Tennessee	3112453110523889581	fb4fcfb2c7e91392bc06d236eaba7121	VISA 13 digit	36.0982889778569316	-86.715304265581068
2394	2019-08-17 09:01:43	2019-08-17	Adriane Reynolds	adriane.reynolds@woohoo.com	Oakland	California	180082978191275385	79fca6528b9cc97361df80a498f3d41a	JCB 15 digit	37.8080398956764228	-122.258598761236684
2395	2019-08-17 10:40:54	2019-08-17	Iliana Lakin	iliana.lakin@geemail.com	San Francisco	California	4865342263731416	1829081e74c395fde8a36ecaad7cf66f	Maestro	37.7544766047317921	-122.466638901646704
2396	2019-08-17 10:47:06	2019-08-17	Aron Schaden	aron.schaden@geemail.com	San Francisco	California	210043087488774841	aed913992111813ea08565c8d43b7a71	VISA 16 digit	37.7855859572599897	-122.420242948278755
2397	2019-08-17 11:36:14	2019-08-17	Barnett Greenfelder IV	barnett.greenfelder.iv@geemail.com	San Francisco	California	4914896235035	7c95ad575c9a1cbf4d4bdd2935a55c89	Maestro	37.7811170033585739	-122.440751543303989
2398	2019-08-17 11:54:53	2019-08-17	Hulda Eichmann	hulda.eichmann@geemail.com	Oakland	California	3088514923070663291	4e282a5cea925b4776935aaba33a578c	VISA 16 digit	37.8043926919128594	-122.239038096165245
2399	2019-08-17 12:02:59	2019-08-17	Yusuf Lowe	yusuf.lowe@geemail.com	San Francisco	California	55836179176618850	b8b330db4f8ca83899ad70b1b9daefe0	Discover	37.8041435024035763	-122.439727887897618
2400	2019-08-17 12:42:54	2019-08-17	Miriam Bauch	miriam.bauch@geemail.com	San Francisco	California	869934538924303869	73db2dd634bd4484a1defa3eeca23d2e	VISA 13 digit	37.8173268730277456	-122.454776742273893
2401	2019-08-17 16:32:50	2019-08-17	Astrid Schoen	astrid.schoen@geemail.com	Oakland	California	3088001279470157867	7ec8ea728b85bf33ccb1ce9d839b42bd	Mastercard	37.8066802315798469	-122.252193116935928
2402	2019-08-17 16:41:20	2019-08-17	Dallas McKenzie	dallas.mckenzie@geemail.com	San Francisco	California	4091138874028	9187356b9d21f5733a13f915904c57d3	JCB 15 digit	37.7847313459467102	-122.426950519280993
2403	2019-08-17 17:28:18	2019-08-17	Shaquille Koepp	shaquille.koepp@geemail.com	San Francisco	California	869972160991845673	2717a01b62f158cc9af521cea6129c0b	Voyager	37.7762453317513973	-122.440663954733694
2404	2019-08-17 18:15:51	2019-08-17	Mr. Presley Gleason Sr.	mr.presley.gleason.sr.@woohoo.com	San Francisco	California	589336017339734	f0cee050e78b395adea0f2cb037fc3aa	Maestro	37.7445646620034196	-122.414620812436695
2405	2019-08-17 18:37:55	2019-08-17	Anita Wiegand	anita.wiegand@warmmail.com	Berkeley	California	3001820349425124	5c6e52662131279e9faa34cb57e4cae8	Mastercard	37.9178159857571728	-122.273771316168634
2406	2019-08-17 19:29:42	2019-08-17	Kobe Buckridge	kobe.buckridge@geemail.com	Oakland	California	3112753939859232900	9ae6d215dad30520cdc33629470151bf	Voyager	37.8055789244979721	-122.236283049533469
2407	2019-08-17 22:28:26	2019-08-17	Ernesto Altenwerth	ernesto.altenwerth@warmmail.com	Oakland	California	4035191886478433	fd42ed62f19aeb65a68f90ac35313817	VISA 13 digit	37.7941486230916013	-122.283467405793289
2408	2019-08-17 22:41:24	2019-08-17	Halsey Boehm	halsey.boehm@geemail.com	Berkeley	California	869982108965768874	0ff19723929b42c0679e07cb4374724b	Diners Club / Carte Blanche	37.861680579434946	-122.241155936966379
2409	2019-08-18 00:14:04	2019-08-18	Mason Shanahan	mason.shanahan@woohoo.com	San Francisco	California	869985169099213010	83999c32952b472b5f422fe2d03080fa	JCB 16 digit	37.7877755953675987	-122.440847109738641
2410	2019-08-18 01:12:52	2019-08-18	Ardith Heathcote	ardith.heathcote@woohoo.com	Berkeley	California	3158932476992875414	b01a6854727628fc12e1ddc4655d5f78	VISA 16 digit	37.8628416331194089	-122.257476828956584
2411	2019-08-18 02:05:15	2019-08-18	Fronie Hoeger	fronie.hoeger@geemail.com	Berkeley	California	869910529974772143	f08c4577e0a00163faee169ddebd071a	VISA 16 digit	37.8603612449146993	-122.232540497380043
2412	2019-08-18 02:06:43	2019-08-18	Levern Fadel IV	levern.fadel.iv@geemail.com	Berkeley	California	3096506357228043553	8a27b2e1fed5448a148c5cad9001a0ef	Diners Club / Carte Blanche	37.8797629520838441	-122.229268045818912
2413	2019-08-18 02:19:28	2019-08-18	Ms. Shane Monahan DVM	ms.shane.monahan.dvm@geemail.com	San Francisco	California	180073920563906826	9a44a9bb5064e85ad4ee69d67ba20011	VISA 13 digit	37.7633962850127318	-122.43509908603464
2414	2019-08-18 03:40:20	2019-08-18	Ms. Susannah Olson DVM	ms.susannah.olson.dvm@geemail.com	San Francisco	California	6011320089435708546	23772871730e0a4905e4bc021b1c0e4d	Mastercard	37.7608380365094192	-122.418325513888746
2415	2019-08-18 06:45:57	2019-08-18	Clemmie Metz-Prosacco	clemmie.metz.prosacco@geemail.com	Berkeley	California	52997419456416731	4b8df3917f01a442fe8d28a32e41ec3c	Diners Club / Carte Blanche	37.8589341658292895	-122.257664412815359
2416	2019-08-18 08:38:16	2019-08-18	Lillard Kuphal	lillard.kuphal@geemail.com	San Francisco	California	3498240083611462	3d485851e3f0cc2d47dc375a5b25ff2f	Discover	37.7633245756992508	-122.462520053108037
2417	2019-08-18 10:52:38	2019-08-18	Dr. Leonardo Wisoky	dr.leonardo.wisoky@woohoo.com	New York	New York	060461656440403	3aa7b6ba02a1cb0c191d72380624fc1a	Discover	40.6265959155969298	-73.9386477241188231
2418	2019-08-18 13:03:07	2019-08-18	Dr. Cari Ward	dr.cari.ward@warmmail.com	San Francisco	California	54360184948539032	aa7f319bb5a255e10763f5d54384a787	JCB 15 digit	37.7370062112885805	-122.459269516301632
2419	2019-08-18 15:58:15	2019-08-18	Doris Cartwright PhD	doris.cartwright.phd@warmmail.com	San Francisco	California	180051133626608019	c1a33c533911be086d03ad0a147178be	JCB 15 digit	37.7706534827182594	-122.432118733763986
2420	2019-08-18 16:55:35	2019-08-18	Lorean Casper	lorean.casper@geemail.com	Oakland	California	52011401750253608	e3989be8980925b3c0d078d3ebf84d9b	JCB 15 digit	37.8232859619577724	-122.277758268675285
2421	2019-08-18 18:35:51	2019-08-18	Mathews Glover-Johnston	mathews.glover.johnston@woohoo.com	San Francisco	California	3112689808514473317	408469d8139dd67c1665ff34c12658e3	VISA 13 digit	37.7827784604671493	-122.415907244500673
2422	2019-08-18 18:39:25	2019-08-18	Nasir Farrell	nasir.farrell@geemail.com	Athens	Georgia	3096535080140032588	70f80852f4bac6bad7ff2d7854b89233	JCB 16 digit	33.9060325456507456	-83.4370392439071082
2423	2019-08-18 19:45:40	2019-08-18	Miss Kaleena Hettinger	miss.kaleena.hettinger@woohoo.com	Oakland	California	4569189324078652	9bdefcdcf42cf2dd04c9a76ae6bb5e67	VISA 16 digit	37.8327047240859713	-122.255037485477629
2424	2019-08-18 22:05:19	2019-08-18	Tariq Kreiger	tariq.kreiger@geemail.com	Oakland	California	6011120746939355536	3d28c57ed46f4ef8e11ea3cae03d9452	JCB 16 digit	37.7931842213737781	-122.246554624353365
2425	2019-08-18 22:55:39	2019-08-18	Dr. Brayden Macejkovic	dr.brayden.macejkovic@geemail.com	San Francisco	California	51788416341091789	5d9ab4aec795f9fe17765f07e7c56859	JCB 16 digit	37.7844623666092048	-122.424167708898892
2426	2019-08-18 23:15:00	2019-08-18	Jenni Moen	jenni.moen@warmmail.com	San Francisco	California	4781342630348846	01bfc5e1c5e1a33f4a88d65bf1864f16	Mastercard	37.7997638428394325	-122.40954634652077
2427	2019-08-19 00:39:52	2019-08-19	Marc Prohaska-Schimmel	marc.prohaska.schimmel@geemail.com	San Francisco	California	3413357656550224	a7cba4934211a0d1273bea6b81348ba2	Voyager	37.7838447689015098	-122.422579533615988
2428	2019-08-19 02:42:15	2019-08-19	Virginia Harvey-Feeney	virginia.harvey.feeney@geemail.com	Fontana	California	3096373578063937134	3d4c12f15c96b71c3f16b918402621ac	VISA 16 digit	34.0386998747158813	-117.412826513992258
2429	2019-08-19 04:22:25	2019-08-19	Ferman Cassin	ferman.cassin@geemail.com	Oakland	California	180009888648497591	ad03fc6bf83c11c24fb42d2e51f00f7f	Mastercard	37.8472832293486121	-122.245489080239352
2430	2019-08-19 04:42:46	2019-08-19	Elda Glover	elda.glover@geemail.com	Berkeley	California	180049691607477931	3afafbbefb0b56de088008f615b6a6b0	VISA 16 digit	37.8685622982408177	-122.280894883831195
2431	2019-08-19 05:31:27	2019-08-19	Precious Reynolds	precious.reynolds@geemail.com	Oakland	California	3761480420390049	ef96dc196ea8f417d6ea0b534648b9ad	VISA 16 digit	37.8014808575596319	-122.285940647564686
2432	2019-08-19 06:31:36	2019-08-19	Tyesha Batz-Weissnat	tyesha.batz.weissnat@woohoo.com	San Francisco	California	676274174865845	69c074ae1df476e49b89ca53ac3cf8b6	American Express	37.7687101549071187	-122.395446445559074
2433	2019-08-19 07:08:08	2019-08-19	Jaquan Green Jr.	jaquan.green.jr.@geemail.com	San Francisco	California	6011201444488589513	49e779e73626b79dc95c1e26255697c0	Maestro	37.7822133230152417	-122.449802053712176
2434	2019-08-19 08:37:59	2019-08-19	Anabella Schinner	anabella.schinner@geemail.com	San Francisco	California	676246690555530	b3978e3b7355de9523e929ed711031fd	American Express	37.77396654535805	-122.445928498980692
2435	2019-08-19 08:39:11	2019-08-19	Louisiana Kreiger-Durgan	louisiana.kreiger.durgan@geemail.com	San Francisco	California	3711388405415957	8aef19843be4f63637f9ce1a81551c76	Discover	37.7463683913672767	-122.448615434803301
2436	2019-08-19 09:34:09	2019-08-19	Ashlee Willms	ashlee.willms@geemail.com	San Francisco	California	676175392211589	0e58940aeff9002de28abfb754220077	Mastercard	37.7863537985007056	-122.440528560731849
2437	2019-08-19 15:12:22	2019-08-19	Katelynn D'Amore	katelynn.d'amore@geemail.com	San Francisco	California	53785430467963633	147a29bb7593760795c48d119c311246	Maestro	37.7682968924256954	-122.417824774404551
2438	2019-08-19 19:54:29	2019-08-19	Lyric Hermiston-Von	lyric.hermiston.von@geemail.com	Berkeley	California	869920154439917106	000e4c0e8194398619f99438ebfadbbf	Discover	37.8392538896990516	-122.264553889393895
2439	2019-08-19 20:15:34	2019-08-19	Catherine Berge	catherine.berge@geemail.com	San Francisco	California	869948327377295044	59fae6f01d8860108a26a961795e4023	VISA 16 digit	37.7653166540022696	-122.387311903299135
2440	2019-08-19 23:03:59	2019-08-19	Coley Stoltenberg	coley.stoltenberg@warmmail.com	Sacramento	California	4052346811558	267aacc4dec577d8d705c46df15b6bb4	American Express	38.6360705472793455	-121.550804718608404
2441	2019-08-19 23:57:37	2019-08-19	Tosha Berge	tosha.berge@geemail.com	San Francisco	California	180091090932861256	821ca9419bd75904d36dcafba82f888c	Discover	37.804370400870603	-122.456575250667072
2442	2019-08-20 01:45:08	2019-08-20	Adrienne Kling	adrienne.kling@geemail.com	Berkeley	California	54992568906971425	c8c619124fac4300b7087ce2a19e0a30	VISA 16 digit	37.8356804858954732	-122.25110259194642
2443	2019-08-20 02:49:03	2019-08-20	Mandie Parker	mandie.parker@geemail.com	Berkeley	California	6011707431690823656	9704ecdb309828f0ee57e858933d93e0	JCB 16 digit	37.8715872627681591	-122.314092856016018
2444	2019-08-20 03:14:47	2019-08-20	Ms. Debbra Kshlerin PhD	ms.debbra.kshlerin.phd@geemail.com	Berkeley	California	869919646295474836	04c699dd414a2fccd94db839942548cc	VISA 13 digit	37.8734379288210476	-122.264952892938368
2445	2019-08-20 04:54:05	2019-08-20	Ted Bahringer III	ted.bahringer.iii@geemail.com	San Francisco	California	180011113833415910	04b33822af604df6ba63826d20a968cb	JCB 15 digit	37.7619044855073867	-122.412835228524401
2446	2019-08-20 05:29:21	2019-08-20	Theodosia Runte MD	theodosia.runte.md@geemail.com	San Francisco	California	55162668908735218	d4589d022280a4cec259887f693c3a19	JCB 15 digit	37.7663681967414036	-122.437579137370818
2447	2019-08-20 06:09:48	2019-08-20	Mayra Bogisich	mayra.bogisich@woohoo.com	Oakland	California	3038057112310265	894a49707cecd4527f6f033b7f753366	JCB 16 digit	37.8160633624452274	-122.247089935452422
2448	2019-08-20 09:00:25	2019-08-20	Evangeline Ebert	evangeline.ebert@woohoo.com	Oakland	California	6011923216073558880	b620fa66b321827c2046b4d651c363a9	VISA 13 digit	37.8078323919090664	-122.299632784996632
2449	2019-08-20 09:31:13	2019-08-20	Tangela McDermott	tangela.mcdermott@geemail.com	Oakland	California	3096324598794617722	65d9b34381553aa6493f349f01bb34c3	Mastercard	37.8071826005412106	-122.292886889636819
2450	2019-08-20 10:12:11	2019-08-20	Valentina Oberbrunner-Bins	valentina.oberbrunner.bins@woohoo.com	San Francisco	California	55801567266944478	b368ee418f0add270fbe7f0a7e602751	JCB 16 digit	37.787434506359908	-122.457523610977162
2451	2019-08-20 10:55:23	2019-08-20	Earlene Tromp	earlene.tromp@warmmail.com	Sacramento	California	4648038285921605	a786d7a2a1c47dfb1de6c78b6add715f	Mastercard	38.4874440332207826	-121.403286471289022
2452	2019-08-20 11:14:32	2019-08-20	Arsenio Cummerata PhD	arsenio.cummerata.phd@geemail.com	New York	New York	4504964169537501	4c78310ed4f8f6b23d05f8581cc22369	Mastercard	40.7004042773265411	-73.9294945214304988
2453	2019-08-20 11:19:05	2019-08-20	Dr. Nikolas Mertz	dr.nikolas.mertz@geemail.com	San Francisco	California	869952006299873814	5fa442455dd9c5a9e578490e7b6eff4d	VISA 16 digit	37.8163890186131226	-122.432227000506856
2454	2019-08-20 20:50:46	2019-08-20	Dr. Denver Volkman MD	dr.denver.volkman.md@geemail.com	San Francisco	California	3088521263413220066	a0e70f4aaeb71add66345e9c05393ab6	Voyager	37.7775692794469293	-122.464822727488283
2455	2019-08-20 23:05:41	2019-08-20	Danika Crist	danika.crist@geemail.com	San Francisco	California	869985619607929077	9f0691e7628c7712308efed9728b2084	Diners Club / Carte Blanche	37.779698482775693	-122.421459767169637
2456	2019-08-21 01:30:47	2019-08-21	Leanna Cummings	leanna.cummings@geemail.com	San Francisco	California	3112961187115348619	ceac21bbfe873ae146f90b37403e5e0b	Diners Club / Carte Blanche	37.7448879925313889	-122.430686539860758
2457	2019-08-21 03:55:57	2019-08-21	Gay Bergnaum	gay.bergnaum@geemail.com	San Francisco	California	630479441105677	e97c529474275893f59d79e21302d325	JCB 15 digit	37.8153471779402111	-122.427763387661429
2458	2019-08-21 04:05:18	2019-08-21	Dr. Kenyatta Abernathy	dr.kenyatta.abernathy@geemail.com	Oakland	California	675932688646408	1d6d536ed4825987842c7969170bf862	JCB 16 digit	37.7401110362360228	-122.292299709223485
2459	2019-08-21 04:43:10	2019-08-21	Cyril Cruickshank Sr.	cyril.cruickshank.sr.@geemail.com	San Francisco	California	869988459910748956	6df44df0465e2d5b9fb545566e3b367b	Discover	37.8052416274041434	-122.437060477366927
2460	2019-08-21 05:02:52	2019-08-21	Chin Beer	chin.beer@geemail.com	Berkeley	California	52730447536858921	289a69ceccbfe804099af020a1e938c1	JCB 16 digit	37.8676989850492589	-122.254214752292057
2461	2019-08-21 05:56:44	2019-08-21	Glen Windler	glen.windler@warmmail.com	Berkeley	California	639070220153756	a98a2dc8d7c53704811b24c8faaeecba	Maestro	37.8711037943692048	-122.270794073521245
2462	2019-08-21 08:52:10	2019-08-21	Tyesha Fadel	tyesha.fadel@geemail.com	San Francisco	California	869949616301503534	c313927d924153034deaf2399a84be45	Mastercard	37.7793426358293374	-122.450606929284874
2463	2019-08-21 14:16:33	2019-08-21	Prince Ryan-Sawayn	prince.ryan.sawayn@geemail.com	San Francisco	California	869995238931702189	d0669860082794a43489fc10a3aaf6d3	VISA 13 digit	37.7707836525857914	-122.415515554825646
2464	2019-08-21 14:48:31	2019-08-21	Marita D'Amore	marita.d'amore@woohoo.com	San Francisco	California	4876327542741622	db9df35aab667a39e2ae7be0e100d0ad	VISA 16 digit	37.7592863193525687	-122.43749748878848
2465	2019-08-21 15:50:16	2019-08-21	Mr. Jerrell Hyatt	mr.jerrell.hyatt@warmmail.com	San Francisco	California	3050448895636612	a3ef8e58e200aa95ee80beebb6bfa35e	JCB 16 digit	37.7932172860307034	-122.420973114724234
2466	2019-08-21 18:24:43	2019-08-21	Khalilah Koss	khalilah.koss@geemail.com	Lafayette	Louisiana	4213585252108	da9db45127a368f340a3c6a0b3e66394	VISA 13 digit	30.2212683701399705	-92.0872211138568701
2467	2019-08-21 19:34:40	2019-08-21	Marva Fritsch	marva.fritsch@geemail.com	Lubbock	Texas	51137189798253388	6ecac42ab353f0ae478425c5b749c0ad	Mastercard	33.4730046425521408	-101.868647731738918
2468	2019-08-21 20:29:30	2019-08-21	Damari Balistreri DDS	damari.balistreri.dds@geemail.com	San Francisco	California	4134531831204964	8ce69db272fd42c0434635b9fbcd349b	Voyager	37.7402023003627036	-122.44532578794059
2469	2019-08-21 20:58:51	2019-08-21	Rowena Swaniawski	rowena.swaniawski@woohoo.com	San Francisco	California	869916612080613288	378e4f26f82c03182b34df307ad14e55	JCB 15 digit	37.7780300014881618	-122.430630252476064
2470	2019-08-22 02:12:38	2019-08-22	Hank Wolff	hank.wolff@geemail.com	San Francisco	California	3744950209492473	f34f23dc75c2852f69626523a9b29171	JCB 16 digit	37.7330195441487959	-122.436504602897131
2471	2019-08-22 02:36:11	2019-08-22	Niko Wilkinson	niko.wilkinson@geemail.com	San Francisco	California	3088264234507490213	3d04801b07e475626f53bd2ce1c371bd	Diners Club / Carte Blanche	37.8099868430115151	-122.456235504314591
2472	2019-08-22 03:27:15	2019-08-22	Dedric Abbott	dedric.abbott@geemail.com	San Francisco	California	52810925291279840	22e0dc06997fe6d1b0bf0aadee78bd13	JCB 16 digit	37.7694076485138055	-122.40367171987198
2473	2019-08-22 04:13:21	2019-08-22	Darien Hackett	darien.hackett@geemail.com	Portland	Oregon	3488197083953124	79f6605e6329a2d29ad6bf7e403a9593	JCB 16 digit	45.442975711625067	-122.583635776815939
2474	2019-08-22 08:49:31	2019-08-22	Mistie Franecki	mistie.franecki@woohoo.com	San Francisco	California	869954685223296131	cfbbb18beeb91bc068ccc96cf184597e	Maestro	37.7590214611023782	-122.409037149638195
2475	2019-08-22 11:22:02	2019-08-22	Latanya Wolff-Tremblay	latanya.wolff.tremblay@geemail.com	San Francisco	California	6011999694374887993	589e104e29ffd0534aa63e2ad1bbac66	Voyager	37.7454129824330664	-122.392119209425658
2476	2019-08-22 12:35:10	2019-08-22	Georgine Ward	georgine.ward@geemail.com	San Francisco	California	3096226523916629495	6343ae0101e563a59d95fd45ff6303f6	JCB 15 digit	37.7563913466876429	-122.42056773501757
2477	2019-08-22 13:47:54	2019-08-22	Heber Bartell	heber.bartell@woohoo.com	Berkeley	California	3112907766667067870	c0c3d0cb8426a18d83f59948045ec2d0	Diners Club / Carte Blanche	37.8896143054504364	-122.256777999626706
2478	2019-08-22 15:13:05	2019-08-22	Dr. Oren Satterfield	dr.oren.satterfield@geemail.com	Berkeley	California	3700311565698074	426227aee18bc77ae1c67bd944d21892	JCB 15 digit	37.8850719552947126	-122.28996977665912
2479	2019-08-22 16:37:57	2019-08-22	Kenneth Hoeger	kenneth.hoeger@geemail.com	Augusta	Georgia	3088567281165848319	aed638d4903055b252d08c0af8382fe2	Discover	33.4086137270294117	-82.1572988466653982
2480	2019-08-22 19:49:01	2019-08-22	Darell Roberts	darell.roberts@geemail.com	San Francisco	California	180079491419482168	8bc13d8b7552a00cf953c393f42cf616	Diners Club / Carte Blanche	37.756606607279295	-122.450421044939247
2481	2019-08-22 21:45:33	2019-08-22	Danniel Effertz	danniel.effertz@geemail.com	San Francisco	California	210003212025648633	0f9b941329b8a1a75369d6424b389eca	Mastercard	37.7648618666853437	-122.425952495044641
2482	2019-08-22 22:20:13	2019-08-22	Dr. Oral Nikolaus	dr.oral.nikolaus@geemail.com	San Francisco	California	3793846572298424	19be9bb09706244128b28497fde43ed5	Diners Club / Carte Blanche	37.7788357689581673	-122.450232528032728
2483	2019-08-23 01:33:50	2019-08-23	Dr. Azaria Schumm MD	dr.azaria.schumm.md@woohoo.com	Atlanta	Georgia	3088413620259979470	75a80c9885a4ca0d73179d1252e6cd65	JCB 15 digit	33.8372433759547775	-84.4526443451687783
2484	2019-08-23 02:13:41	2019-08-23	Keesha Toy DVM	keesha.toy.dvm@woohoo.com	San Francisco	California	210028423608168763	9bfd4ec1c9bdec71467cd0e73076ea0a	JCB 16 digit	37.766862400049618	-122.431035256012038
2485	2019-08-23 02:56:09	2019-08-23	Charlsie Wintheiser	charlsie.wintheiser@geemail.com	Oakland	California	210026221215220593	64357b9a7108f7c055acfb55895e212d	JCB 16 digit	37.8056576867199894	-122.276138940420239
2486	2019-08-23 03:50:03	2019-08-23	Dr. Ieshia Renner MD	dr.ieshia.renner.md@geemail.com	San Francisco	California	4817542048154128	3eebfba72eadc38daef9646dd7de12ba	JCB 15 digit	37.7640045332965499	-122.431839504650071
2487	2019-08-23 04:09:16	2019-08-23	Dr. Nakita Mante MD	dr.nakita.mante.md@geemail.com	Oakland	California	869937393671272322	b01721978dca38492086eb460fa73c91	VISA 13 digit	37.8178958871808533	-122.282333196983501
2488	2019-08-23 04:43:55	2019-08-23	Chaz Wunsch	chaz.wunsch@geemail.com	San Francisco	California	4881916497368	2fc4e27203f89338bf66512d4f96e1c2	Mastercard	37.7741586467210269	-122.442092650579951
2489	2019-08-23 06:29:23	2019-08-23	Miss Florie Sauer DVM	miss.florie.sauer.dvm@geemail.com	Oakland	California	3158261968664287747	ba0c73bdbbedc767c9d7ea0d9007d086	Mastercard	37.807097815725335	-122.266543208973616
2490	2019-08-23 06:47:30	2019-08-23	Wilfred Torp PhD	wilfred.torp.phd@geemail.com	San Francisco	California	869930402904819911	970bbc0d33b9355f199bd7269ac8d6af	Discover	37.8007490872454213	-122.455817923161703
2491	2019-08-23 08:29:33	2019-08-23	Raoul Kuhic	raoul.kuhic@geemail.com	Springfield	Missouri	3096390978924591816	746968b025ca46a2a795287294dab820	JCB 16 digit	37.1741331968650215	-93.3839940791309004
2492	2019-08-23 09:10:48	2019-08-23	Humberto Zemlak	humberto.zemlak@geemail.com	Berkeley	California	4497135714442534	5c1e95ae6ca7e03908f8ac9d6a64c5b5	JCB 15 digit	37.8918859213099424	-122.260193377169585
2493	2019-08-23 10:03:09	2019-08-23	Cindy Willms	cindy.willms@geemail.com	San Francisco	California	3088563515522050919	81e53fc807d3e9d27f7568396400d8af	Maestro	37.7944310660502438	-122.45693677659132
2494	2019-08-23 12:23:31	2019-08-23	Blas Funk	blas.funk@geemail.com	Berkeley	California	869922494396692823	720e84cb4918d0e501ea47192f8b15a7	Diners Club / Carte Blanche	37.8652825435262201	-122.2564271626741
2495	2019-08-23 12:45:34	2019-08-23	Delton Jones	delton.jones@geemail.com	San Francisco	California	51875237802036681	1ea4d14d47a3f8eec8a0637de0fb0d78	Mastercard	37.7843074820711635	-122.434955727754343
2496	2019-08-23 18:34:34	2019-08-23	Lani Lebsack	lani.lebsack@geemail.com	Oakland	California	4024434760422736	43b1943f763841b457ec90f6da0584bb	VISA 13 digit	37.8200321986834709	-122.270342590637952
2497	2019-08-23 23:04:20	2019-08-23	Nash Jerde	nash.jerde@geemail.com	Berkeley	California	4458988739918	b35a5f9a3fb531fdf1a93c83e7acdff2	Diners Club / Carte Blanche	37.8367039814865294	-122.272129871492737
2498	2019-08-23 23:11:57	2019-08-23	Kya Ledner	kya.ledner@geemail.com	San Francisco	California	4641651944044	a8c798904cfb026fbcd50a0e0d134d8a	Voyager	37.7417736261832246	-122.445230512772198
2499	2019-08-24 00:49:33	2019-08-24	Rafe Hauck	rafe.hauck@warmmail.com	Austin	Texas	3010762991861076	315364212278cabd88886f3152af0c79	Maestro	30.3915822308637189	-97.6951337527256527
2500	2019-08-24 03:14:00	2019-08-24	Hazel Klocko	hazel.klocko@geemail.com	San Francisco	California	3016356196560171	6a8ee1aa29b6ed324c2f56f3e3d0cc47	JCB 16 digit	37.7977380003360608	-122.434554847006353
2501	2019-08-24 09:10:49	2019-08-24	Lesly Homenick	lesly.homenick@geemail.com	San Francisco	California	4581578409436252	7ee682a4b762df4d284adede67f2cd7c	Diners Club / Carte Blanche	37.7780911535955966	-122.406492177120143
2502	2019-08-24 09:48:30	2019-08-24	Benita Jakubowski	benita.jakubowski@geemail.com	San Francisco	California	4044742792259249	7b706e659f96200b17ba60103e3c9eeb	Voyager	37.7571810979246294	-122.43271224851847
2503	2019-08-24 10:01:20	2019-08-24	Joy Block	joy.block@geemail.com	San Francisco	California	3112378092546510430	cd57f862528b304e02f869d5eb0ac0bb	American Express	37.7976480598638034	-122.404150039612091
2504	2019-08-24 10:34:13	2019-08-24	Dr. Taina Terry	dr.taina.terry@geemail.com	San Francisco	California	676323948561362	3428ceb7165a485cf319ccc6ca53e5dc	JCB 16 digit	37.7490236705166211	-122.438620244407488
2505	2019-08-24 11:04:40	2019-08-24	Mr. Laron Pagac PhD	mr.laron.pagac.phd@geemail.com	Oakland	California	4226871084571787	0d766dab8b3cc1cdd5c71aaa92a236b2	VISA 16 digit	37.7951671530131676	-122.291271084019996
2506	2019-08-24 12:00:28	2019-08-24	Jordyn Ernser II	jordyn.ernser.ii@geemail.com	San Francisco	California	869978909924970584	b72d8f735c8a42d8f679bde9bf858da1	Mastercard	37.7926983744455782	-122.449649200135397
2507	2019-08-24 13:18:33	2019-08-24	Miss Ludie Fahey	miss.ludie.fahey@geemail.com	Chicago	Illinois	53549736298435600	7eace8121bb3932d8ac86665fbc335ef	VISA 16 digit	41.840553983470798	-87.6362459364842579
2508	2019-08-24 13:22:14	2019-08-24	Draven Fadel-Baumbach	draven.fadel.baumbach@geemail.com	San Francisco	California	3008687084891536	632829543c27005cec9ac3802b83ecc9	VISA 13 digit	37.7549816209478379	-122.428401569529541
2509	2019-08-24 14:06:13	2019-08-24	Verona Smitham	verona.smitham@geemail.com	San Francisco	California	3112694260615885853	42b1bf08b5fc0d26de05c2c729398da2	Mastercard	37.7538175691678575	-122.433116547154214
2510	2019-08-24 14:31:57	2019-08-24	Benton Schmeler	benton.schmeler@geemail.com	San Francisco	California	4363522585041787	9b3e0b6b3517a464991468d868174ed0	Mastercard	37.7924132522830192	-122.441865676989067
2511	2019-08-24 16:38:12	2019-08-24	Jaquelin Brakus	jaquelin.brakus@geemail.com	San Francisco	California	869975179006114013	3529e48ff3b667ad16b9fa3b3e82b78b	Discover	37.7818029182303476	-122.421413194858403
2512	2019-08-24 17:54:23	2019-08-24	Akeem Kling	akeem.kling@geemail.com	San Francisco	California	4272848369893	af13e9d13dbac94bd40254e4574ccea4	VISA 16 digit	37.7543864403980578	-122.412265333288289
2513	2019-08-24 18:49:35	2019-08-24	Emelia Conroy	emelia.conroy@geemail.com	San Francisco	California	869981506214829846	b0947d63ece5c0d3a6df4af4e573a7bb	Discover	37.7802254692161696	-122.412930419144288
2514	2019-08-24 19:00:13	2019-08-24	Reilly Nienow	reilly.nienow@geemail.com	San Francisco	California	3528475336633159482	c0bdeb589c8903dd66a7be952bbf8d33	Voyager	37.7494400731053119	-122.454712951968233
2515	2019-08-24 19:20:48	2019-08-24	Colt Gorczany	colt.gorczany@geemail.com	San Francisco	California	4515179892192907	116a49798d87a76e8fc825e73814cb4c	Discover	37.7840932112700401	-122.430019763176375
2516	2019-08-24 21:11:13	2019-08-24	Jaidyn VonRueden DVM	jaidyn.vonrueden.dvm@warmmail.com	San Francisco	California	3528086401109435369	f1bf24e5a90767710b5b9dbd62a416c9	JCB 16 digit	37.7479509381956859	-122.452339636233788
2517	2019-08-25 00:40:57	2019-08-25	Mr. Ishmael Stiedemann PhD	mr.ishmael.stiedemann.phd@geemail.com	Berkeley	California	180099923929890221	7186331efe706f21dc725dbc6ff6d638	Mastercard	37.8551245116479791	-122.263026437508742
2518	2019-08-25 02:59:01	2019-08-25	Dr. Mikhail Langworth PhD	dr.mikhail.langworth.phd@warmmail.com	San Francisco	California	210075573835784378	47a41f9ec73d6ad5c4b299f2458907ac	American Express	37.784794206616759	-122.421507395418118
2519	2019-08-25 03:19:22	2019-08-25	Leighton Bradtke-Hane	leighton.bradtke.hane@geemail.com	San Francisco	California	180040329232220785	42f15efef138951f61d0cef962fd024b	VISA 16 digit	37.7978308320824894	-122.472106024218178
2520	2019-08-25 03:20:33	2019-08-25	Jamal McLaughlin	jamal.mclaughlin@geemail.com	San Francisco	California	6011572463675469488	397e1f46ef5b5fca185a1c4a5935bd39	Discover	37.7753617664996852	-122.424005779009988
2521	2019-08-25 03:32:38	2019-08-25	Halley Lind	halley.lind@geemail.com	San Francisco	California	3009699349404178	592f027516985c43e9244f7fbcfc090d	VISA 13 digit	37.740582683243808	-122.45497414043372
2522	2019-08-25 06:11:00	2019-08-25	Hale Lebsack	hale.lebsack@warmmail.com	San Francisco	California	6011457883905963028	49a8892317315ffcc4fb4af0e3eb8dda	JCB 16 digit	37.7474701666836978	-122.431590078736164
2523	2019-08-25 09:15:26	2019-08-25	Bob Deckow	bob.deckow@geemail.com	San Francisco	California	4811373200381762	89e53c5e091fb3107c7295580bbd4f24	JCB 15 digit	37.8357773311004379	-122.446831159164987
2524	2019-08-25 10:45:49	2019-08-25	Brook Stokes	brook.stokes@woohoo.com	San Francisco	California	3528253915480493892	acd7e82b0a3076b8b257b86cfc72ed83	American Express	37.7930375382904984	-122.465543174102592
2525	2019-08-25 10:59:09	2019-08-25	Fran Koch DDS	fran.koch.dds@warmmail.com	Dallas	Texas	3112812955145403104	2b4bcdafb973170996fef7a600a0404a	VISA 16 digit	32.7745124853022389	-96.8293652483690437
2526	2019-08-25 13:59:46	2019-08-25	Daisie Cummings	daisie.cummings@warmmail.com	San Francisco	California	4124654436899525	8f04eb3f07afa8f62cee20d95f304b37	Maestro	37.7780528384701526	-122.399569540619353
2527	2019-08-25 14:53:45	2019-08-25	Trevion Nikolaus DVM	trevion.nikolaus.dvm@geemail.com	Berkeley	California	6011187824013469604	26c01253aeaa40908264417af9be415d	VISA 16 digit	37.8223446391333269	-122.31389942113654
2528	2019-08-25 19:15:33	2019-08-25	Dr. Modena Collins	dr.modena.collins@geemail.com	San Francisco	California	869925330661265209	caa4c3cdec52cb2ecc924546f9ff926c	Diners Club / Carte Blanche	37.7759516399178565	-122.40340470181745
2529	2019-08-25 20:00:28	2019-08-25	Dr. Ora Hermann	dr.ora.hermann@woohoo.com	San Francisco	California	3764019275265737	f7cc3d413bd1487bbfc7bac940643603	JCB 15 digit	37.8168377686386989	-122.4354880776079
2530	2019-08-25 20:37:15	2019-08-25	Leander Bernier DVM	leander.bernier.dvm@woohoo.com	Berkeley	California	4872664114800	4e35af136739c144e6a2fec9815d3000	Voyager	37.8651548676043888	-122.253285431523338
2531	2019-08-25 21:12:58	2019-08-25	Demian Friesen	demian.friesen@geemail.com	San Francisco	California	3026231522051064	3d34f88010ac77e2d9a224eff7d00b67	Mastercard	37.8004736929370324	-122.39086891629168
2532	2019-08-25 22:16:10	2019-08-25	Ms. Louann Rutherford	ms.louann.rutherford@geemail.com	San Francisco	California	589353782586118	9a9a807ed1dab28eaca5dac1c91d18e6	JCB 16 digit	37.7732984007226378	-122.433379824799019
2533	2019-08-25 23:18:03	2019-08-25	Dr. Darryn O'Conner	dr.darryn.o'conner@geemail.com	St. Petersburg	Florida	4489489894044242	759b3f37eae820183a95fc40e204bfb0	JCB 16 digit	27.7646100181043138	-82.5808344059515633
2534	2019-08-26 01:28:17	2019-08-26	Emelia Schiller	emelia.schiller@warmmail.com	Berkeley	California	3036933979345143	eeeb1bd0502d0241ac45cccdac7c26d4	VISA 16 digit	37.8425567023162372	-122.306814266445429
2535	2019-08-26 05:11:46	2019-08-26	Ciara Yundt DVM	ciara.yundt.dvm@geemail.com	Boston	Massachusetts	4305171392809	58df4cb3211e76c5933488dd17d9ca21	VISA 16 digit	42.4278695921115556	-71.0639795129604721
2536	2019-08-26 05:14:17	2019-08-26	Bradly Considine	bradly.considine@geemail.com	San Francisco	California	180002182489536387	98a8ad9187156fff8e57f0db755a1fdf	JCB 15 digit	37.7572845073676007	-122.454455664839585
2537	2019-08-26 05:25:52	2019-08-26	Jadyn Abshire	jadyn.abshire@geemail.com	Lakewood	New Jersey	4516908139457783	fa4a553442d4a62ffcf625f1432c36e6	Mastercard	40.1435510241243989	-74.1441165313866009
2538	2019-08-26 06:50:55	2019-08-26	Dr. Sherron Champlin	dr.sherron.champlin@geemail.com	San Francisco	California	502046721837857	aa5a00cdb7e5fd808811af522ad0ae11	Mastercard	37.8136404205200947	-122.419448519620374
2539	2019-08-26 09:16:22	2019-08-26	Domenick Wiegand	domenick.wiegand@warmmail.com	San Francisco	California	3016746341924647	4fc24e3457640d4470d4c99fa9e43699	Voyager	37.7857199795866663	-122.426037165028021
2540	2019-08-26 09:19:47	2019-08-26	Dillon Watsica	dillon.watsica@warmmail.com	Berkeley	California	3337861717287335126	c4f50240dea1c36393ec9a6e9793b5d6	VISA 13 digit	37.8697625941635323	-122.294896811042435
2541	2019-08-26 09:25:12	2019-08-26	Altie Hintz	altie.hintz@geemail.com	San Francisco	California	210037472907143422	be9e88fd20b0e56293f44261a0fa0de1	Discover	37.7849146081214542	-122.446819728542621
2542	2019-08-26 10:58:59	2019-08-26	Gifford Cassin	gifford.cassin@warmmail.com	San Francisco	California	6011211949915031820	99b5fcfe04f6cddabfd1b2a3e9f2afcc	Mastercard	37.7743609234559159	-122.42096320307563
2543	2019-08-26 12:30:39	2019-08-26	Tex Paucek	tex.paucek@warmmail.com	San Francisco	California	503842799100872	6e76522b3d82cc1a9a1028eb96cc2617	Maestro	37.7682154562838335	-122.43429774715338
2544	2019-08-26 12:56:22	2019-08-26	Aaliyah Rowe-Maggio	aaliyah.rowe.maggio@woohoo.com	San Francisco	California	3112692572994910363	f6057c8bf139535edf489aa2ac128b6b	American Express	37.7776740133357904	-122.44694627710804
2545	2019-08-26 15:04:54	2019-08-26	Karyme Gottlieb	karyme.gottlieb@geemail.com	San Francisco	California	210001420808987316	8339e0e7189e9b09ef97ab780f599955	VISA 13 digit	37.7907941406850796	-122.400057456972917
2546	2019-08-26 16:25:40	2019-08-26	Zetta Carroll-Schmidt	zetta.carroll.schmidt@woohoo.com	San Francisco	California	3722584339638949	4d78adc307ef549ea73fff78df93cd49	JCB 15 digit	37.7939065265632763	-122.417914254574569
2547	2019-08-26 20:58:37	2019-08-26	Duane Erdman	duane.erdman@geemail.com	San Francisco	California	3337779446753406341	cd887857fe9190d8c7fa8b001adfa008	Voyager	37.7636370000530874	-122.405337320495192
2548	2019-08-26 21:08:34	2019-08-26	Vance Jast	vance.jast@geemail.com	San Francisco	California	3028984758727140	9813bf97de94d1127a4c26df64412cb9	Diners Club / Carte Blanche	37.7795240013360214	-122.395559526731532
2549	2019-08-27 00:01:58	2019-08-27	Orvel Schuster DDS	orvel.schuster.dds@geemail.com	San Francisco	California	3158143146516921706	55df22ef8952ffadb763db92d8c88762	Maestro	37.7656688135577099	-122.449041863028711
2550	2019-08-27 00:43:33	2019-08-27	Magan Hoeger DVM	magan.hoeger.dvm@geemail.com	Oakland	California	6011773395088427033	e6238eb81e2abec624bbd2bd8bc7f058	Maestro	37.8015291648027372	-122.273953278593623
2551	2019-08-27 03:50:55	2019-08-27	Dr. Claudio Abernathy	dr.claudio.abernathy@woohoo.com	Berkeley	California	6011742376182918521	c36d5672aa837d0561fa46ad72ceac18	JCB 16 digit	37.8920539655030524	-122.282009850703417
2552	2019-08-27 04:30:01	2019-08-27	Mr. Solon Senger	mr.solon.senger@geemail.com	San Francisco	California	3039781809497528	9829aa73562f936833402f02eed5ccdb	JCB 15 digit	37.77716070759503	-122.443021780533059
2553	2019-08-27 06:14:41	2019-08-27	Toby Kerluke-Green	toby.kerluke.green@geemail.com	Gilbert	Arizona	3458449112828108	83df2789ead40e7717ba1e574d01cfc4	Maestro	33.2703629667751457	-111.792093160715325
2554	2019-08-27 07:11:02	2019-08-27	Sada Deckow-Corwin	sada.deckow.corwin@geemail.com	San Francisco	California	4811938909868	659369443270c8bc67d05793a5e5672a	VISA 16 digit	37.7857586501819824	-122.435002923819923
2555	2019-08-27 11:25:12	2019-08-27	Beadie Wuckert	beadie.wuckert@woohoo.com	Port St. Lucie	Florida	501878612747879	074ae872edb6496f23026cad2a142acf	Maestro	27.2715978586714698	-80.3029058822516362
2556	2019-08-27 15:00:46	2019-08-27	Isai Goldner-Smith	isai.goldner.smith@warmmail.com	Oakland	California	3003347783866025	a893669bb8382cf6f98f4e1dc3017796	VISA 16 digit	37.7915192802286981	-122.276632550533165
2557	2019-08-27 16:31:38	2019-08-27	Virge Cremin	virge.cremin@geemail.com	San Francisco	California	4889033832738592	bed54b31d567281435e46d4024d56fe3	Mastercard	37.7852396096262169	-122.424639087912212
2558	2019-08-27 17:52:13	2019-08-27	Susannah Gerhold	susannah.gerhold@geemail.com	San Francisco	California	51101315669290462	23ceded3fd4eb0425ae6accb54d84448	Diners Club / Carte Blanche	37.8111576509892444	-122.425234957942308
2559	2019-08-27 18:40:10	2019-08-27	Irine Olson	irine.olson@geemail.com	San Francisco	California	869936698582463005	8987d54888a96145ce2df49d25d034cc	American Express	37.7196274390604671	-122.410721090724081
2560	2019-08-27 19:34:27	2019-08-27	Dr. Eli Ledner IV	dr.eli.ledner.iv@woohoo.com	Oakland	California	6011995289834102200	eab26ae32befd585e8e84586a8e4698d	VISA 16 digit	37.792325749219259	-122.314953192232096
2561	2019-08-27 22:15:41	2019-08-27	Jailyn Harris	jailyn.harris@woohoo.com	Oakland	California	3528528901027428772	0583062f8ef6128e3be9a13e2ca0f47a	Maestro	37.8208607222987041	-122.260060206055726
2562	2019-08-27 23:52:37	2019-08-27	Dr. Pratt Pfeffer DDS	dr.pratt.pfeffer.dds@geemail.com	San Francisco	California	6011144903336615150	f05ac5e7c0b84d565212afdc2f4227ce	Mastercard	37.7453578755436396	-122.446503114728699
2563	2019-08-28 04:28:11	2019-08-28	Dr. Hilary Wunsch Jr.	dr.hilary.wunsch.jr.@geemail.com	San Francisco	California	3758390785764552	1b75039becdb3fa3a023a72c5c3bebb2	VISA 13 digit	37.7664521040413064	-122.403607870552662
2564	2019-08-28 05:19:09	2019-08-28	Salma Morar-Lockman	salma.morar.lockman@geemail.com	San Francisco	California	3027742570883462	9e25c00f846fe5b4582bea31679f3d2a	Discover	37.800683833540468	-122.432459218784146
2565	2019-08-28 07:45:13	2019-08-28	Max Towne-Klocko	max.towne.klocko@woohoo.com	Glendale	Arizona	210091744395417234	b88983f61db71f82a38c048c9def4c99	VISA 13 digit	33.606750449188425	-112.273149472733579
2566	2019-08-28 08:12:50	2019-08-28	Mr. Kamren Rogahn	mr.kamren.rogahn@geemail.com	San Francisco	California	52941213903220573	188b31ac9b8806a02146275f84060ce3	JCB 16 digit	37.7640143155661221	-122.454209355004366
2567	2019-08-28 08:16:34	2019-08-28	Celine Monahan	celine.monahan@geemail.com	San Francisco	California	4039551451135435	720c7b2b87b5da28bc50d94ef120db49	American Express	37.8037468888470372	-122.421577953983387
2568	2019-08-28 08:37:02	2019-08-28	Vara Raynor-Welch	vara.raynor.welch@woohoo.com	San Francisco	California	3724538106931364	e5656eaabaadb163a9f0a3bc8bca444e	Maestro	37.7813584143857	-122.440164671310626
2569	2019-08-28 08:39:57	2019-08-28	Carl Welch	carl.welch@woohoo.com	San Francisco	California	4854321477023771	960ec45452a7777d1e53c472c130ec18	VISA 16 digit	37.7582669491708955	-122.419529739903808
2570	2019-08-28 10:44:33	2019-08-28	Ms. Goldia Langworth	ms.goldia.langworth@geemail.com	San Francisco	California	3096247092744899097	ee1db66992f4086705632a4399d0e36d	Mastercard	37.852499800153474	-122.42179989838705
2571	2019-08-28 14:00:50	2019-08-28	Eartha Ledner	eartha.ledner@geemail.com	Jacksonville	Florida	6011889841141101561	3f745d43f6e273b46098250f1e366d20	Maestro	30.3681172154430286	-81.6006271703246995
2572	2019-08-28 16:22:03	2019-08-28	Ell Goldner	ell.goldner@geemail.com	San Francisco	California	869991418026428312	0d9b05dcf8aa35e9e5e24da108f71ddf	VISA 13 digit	37.7462732846552811	-122.434335789488671
2573	2019-08-28 20:12:38	2019-08-28	Woodroe Rice	woodroe.rice@geemail.com	Oakland	California	589325196129594	7abe2d9450220c19013d61260f22f638	Diners Club / Carte Blanche	37.7733023141503921	-122.262435855114674
2574	2019-08-28 20:43:07	2019-08-28	Mr. Denver Nitzsche	mr.denver.nitzsche@geemail.com	Berkeley	California	060405130549941	2b0e2dfe6093963f6b7bc0a90cc27869	VISA 13 digit	37.8714892117820696	-122.237895928089799
2575	2019-08-28 23:15:58	2019-08-28	Miss Neveah Ondricka DVM	miss.neveah.ondricka.dvm@warmmail.com	Berkeley	California	3016955871261656	8bcefb739638a5ef2a0626602ac6d48f	VISA 16 digit	37.8674216848306173	-122.265827666071615
2576	2019-08-28 23:33:54	2019-08-28	Jasmin Torphy	jasmin.torphy@geemail.com	San Francisco	California	4579549618192006	128e79387dd3781c2e6c6dce6b0fa00e	VISA 13 digit	37.7621917004308969	-122.414012018370457
2577	2019-08-28 23:52:32	2019-08-28	Madyson Ritchie-Johnson	madyson.ritchie.johnson@geemail.com	Berkeley	California	6011468524110328188	f3f3a703cbb6307adf1b7a359c0ef5ff	JCB 15 digit	37.8421386744895614	-122.284286200405347
2578	2019-08-29 00:31:50	2019-08-29	Johnson Rowe	johnson.rowe@geemail.com	Detroit	Michigan	3088180361007261280	b8928994e6e72a5e52af545c3da278e9	Discover	42.3639013885911595	-83.1671897399358357
2579	2019-08-29 00:37:37	2019-08-29	Millard Graham	millard.graham@geemail.com	San Francisco	California	55901855032302967	81fa6c72b2b7246e7dc30254adb5ac13	VISA 16 digit	37.7850260094654828	-122.435264108574401
2580	2019-08-29 00:59:34	2019-08-29	Alvera Keeling-Zemlak	alvera.keeling.zemlak@woohoo.com	San Francisco	California	3096549096932379676	3e908681f981fb0e98e76ad022f9367d	Mastercard	37.7999758475552454	-122.42822709172134
2581	2019-08-29 03:54:13	2019-08-29	Ardelle Stanton-Langworth	ardelle.stanton.langworth@warmmail.com	Berkeley	California	3158163382859371069	b3d716d34314979b718b19ddc5a94678	JCB 16 digit	37.886495882721448	-122.281637794408937
2582	2019-08-29 03:55:41	2019-08-29	Dr. Mercy Bins	dr.mercy.bins@geemail.com	San Francisco	California	210077147676107300	37e4b157e07fcc32c6e0534f43b2d580	Maestro	37.7811583448506454	-122.431285675532422
2583	2019-08-29 06:18:10	2019-08-29	Rosena Osinski	rosena.osinski@geemail.com	Charlotte	North Carolina	3056399693388043	d64c886b5e34f847757c2579e318196b	American Express	35.1422030306674529	-80.7797678178120435
2584	2019-08-29 11:00:35	2019-08-29	Alan Hudson	alan.hudson@geemail.com	San Francisco	California	869937976404290171	ef7eea7b8f4ae541db257a7a960a9cfd	American Express	37.7693773507248522	-122.436736210707068
2585	2019-08-29 14:34:34	2019-08-29	Mr. Jesus Kautzer	mr.jesus.kautzer@warmmail.com	San Francisco	California	54709499222725515	eeaa3fa44db59c9e13d95cadc9780379	Maestro	37.7604866691137673	-122.476069037377528
2586	2019-08-29 15:16:31	2019-08-29	Ricky Volkman	ricky.volkman@geemail.com	San Francisco	California	4484090471679	b8b97523bc2726eaf7f1f285d56b58a8	VISA 16 digit	37.7803040038691123	-122.421782444372255
2587	2019-08-29 15:57:46	2019-08-29	Amelia Dibbert	amelia.dibbert@geemail.com	San Francisco	California	3337384952969481652	222e8cd14bbf2e8876d3c08f8293f3db	VISA 13 digit	37.7792947385770503	-122.426913517470652
2588	2019-08-29 16:19:59	2019-08-29	Mrs. Katelynn Farrell DDS	mrs.katelynn.farrell.dds@woohoo.com	San Francisco	California	180083270932780611	1845fb098e301e0d9be70505b50e0f9c	JCB 16 digit	37.7592949134775679	-122.441762870291555
2589	2019-08-29 17:29:20	2019-08-29	Dabney Oberbrunner-Stehr	dabney.oberbrunner.stehr@geemail.com	Oakland	California	4053096201941	cc4119e48bdead69da37953874728de2	VISA 16 digit	37.7936882772590081	-122.268957638457721
2590	2019-08-29 18:04:44	2019-08-29	Lucie Walter	lucie.walter@warmmail.com	Berkeley	California	180001328569826948	35bcb071ed3f86ea766a118548880bf2	Mastercard	37.8529084212223168	-122.310230886951075
2591	2019-08-29 18:33:01	2019-08-29	Wendell Fay	wendell.fay@woohoo.com	San Francisco	California	869929894204292968	9544f86d1126bf2b48f69cb06336d16d	Mastercard	37.7695164971283077	-122.440962468458011
2592	2019-08-29 21:40:05	2019-08-29	Kamari Abshire	kamari.abshire@geemail.com	San Francisco	California	4616500224836754	539741b3d9e82162117a9a339dbca338	Discover	37.7661974453410068	-122.41944179007254
2593	2019-08-30 00:20:31	2019-08-30	Miss Lavera Feest	miss.lavera.feest@geemail.com	San Francisco	California	4899520327835717	5bb6ade527af3e84662bff888257b80f	Voyager	37.7397159591643785	-122.446148426226657
2594	2019-08-30 03:17:59	2019-08-30	Shaquita Harber-Wiza	shaquita.harber.wiza@geemail.com	San Francisco	California	3043492363726130	53858699478b368de79661683502636a	Maestro	37.7354477322287494	-122.461611144332892
2595	2019-08-30 04:25:59	2019-08-30	Rhoda West-Blanda	rhoda.west.blanda@woohoo.com	San Francisco	California	4648001800805034	ec4908e10bff18682ae5dd1e45ba659d	VISA 16 digit	37.7975615701015855	-122.465581743482559
2596	2019-08-30 05:41:04	2019-08-30	Russel Jaskolski	russel.jaskolski@warmmail.com	Garden Grove	California	676138465996403	2a8643e99173e537d882f40ecb780b4c	American Express	33.7201249298930108	-118.056014106238251
2597	2019-08-30 06:47:51	2019-08-30	Laverne Dooley-Stoltenberg	laverne.dooley.stoltenberg@woohoo.com	San Francisco	California	210089541852598066	e35c7c019b9355dce0574c24450d04a4	Diners Club / Carte Blanche	37.7880907142732383	-122.431732291246703
2598	2019-08-30 07:56:56	2019-08-30	Ivy O'Connell PhD	ivy.o'connell.phd@woohoo.com	San Francisco	California	3468567478670067	6b5bfa9e5c3ac1f1e74830a76132d1d1	JCB 15 digit	37.7425109641439178	-122.442701005246107
2599	2019-08-30 10:33:11	2019-08-30	Delma Goyette	delma.goyette@geemail.com	San Francisco	California	3743781356880116	5ebd83ae622dd867ac1a6edeafc9e553	JCB 15 digit	37.8042460181958901	-122.42110117583708
2600	2019-08-30 11:09:18	2019-08-30	Shelby Beer	shelby.beer@geemail.com	Oakland	California	676250821704744	ae18cc4964c86984d6feb9400d0341d8	Maestro	37.8260390776703446	-122.282351111447099
2601	2019-08-30 14:00:04	2019-08-30	Olene White	olene.white@geemail.com	Berkeley	California	3088696238678376919	698367c86bff5778a6577478d679e3cb	Maestro	37.8710063576170839	-122.266994791988083
2602	2019-08-30 14:10:56	2019-08-30	Hazel Hoeger	hazel.hoeger@geemail.com	San Francisco	California	6011822619625919959	19ccdfa635fd70b86adcac4b1fff2a58	JCB 16 digit	37.771341525428447	-122.44554633712012
2603	2019-08-30 14:32:28	2019-08-30	Mr. Howell Miller Sr.	mr.howell.miller.sr.@geemail.com	San Francisco	California	52447668813377541	e6a09641e74fcbef28f3961f2e45b94c	American Express	37.7959184357234079	-122.398634428973907
2604	2019-08-30 14:44:21	2019-08-30	Devaughn O'Conner V	devaughn.o'conner.v@geemail.com	San Francisco	California	3096073882501922846	52a67a2072ae148718e262c25b143766	American Express	37.8249195952253316	-122.429930138760241
2605	2019-08-30 17:01:49	2019-08-30	Kaden Tillman I	kaden.tillman.i@geemail.com	Pasadena	California	6011967995218526392	6846fbad58c1dbde6a2b330d988c7b16	VISA 16 digit	34.1649653222732255	-118.133544198451943
2606	2019-08-30 17:44:22	2019-08-30	Jorden Tremblay-Bartell	jorden.tremblay.bartell@geemail.com	San Francisco	California	210009266377691207	4e51eed6a7e8ff4f068b4f88c0c30732	Discover	37.8073080991930013	-122.42893945708839
2607	2019-08-30 19:07:39	2019-08-30	Mrs. Daniela Beier PhD	mrs.daniela.beier.phd@geemail.com	San Francisco	California	869978335681254758	75274bc6c5340e59b0321997f1022e96	VISA 16 digit	37.7536872379809409	-122.461968649403204
2608	2019-08-30 21:05:09	2019-08-30	Mathias Stehr	mathias.stehr@geemail.com	Berkeley	California	52126462869055666	5f1eb9b2b1945e2ed66c8994a04ffe41	Mastercard	37.8648570349001545	-122.255891395220146
2609	2019-08-30 21:36:54	2019-08-30	Emery Erdman	emery.erdman@geemail.com	San Francisco	California	4853093340258808	7af683deb451af7ec76fbafb52263785	Voyager	37.7536853304050695	-122.460014315087633
2610	2019-08-30 21:54:12	2019-08-30	Idabelle Jacobi DVM	idabelle.jacobi.dvm@geemail.com	San Francisco	California	4277575022148776	27433ce40c644bf5f68362b315035fde	Maestro	37.744503295475667	-122.430787759731345
2611	2019-08-30 23:08:58	2019-08-30	Mrs. Alma Watsica	mrs.alma.watsica@geemail.com	San Francisco	California	561259124510757	5dfa71b875b0e572a7e2464763914179	Voyager	37.7608911775184808	-122.438249562817873
2612	2019-08-31 00:12:31	2019-08-31	Geraldo Kilback	geraldo.kilback@warmmail.com	El Paso	Texas	210053524137019498	32a15921440f45d31a9cab53d04b6bc6	JCB 15 digit	31.7659403416622439	-106.500663992900414
2613	2019-08-31 02:49:34	2019-08-31	Venus Will	venus.will@geemail.com	Oakland	California	869968818824300986	fa7358a59086709c595c46ee55c9fa35	Discover	37.7854248303879814	-122.258556752651899
2614	2019-08-31 04:28:33	2019-08-31	Miles Runte	miles.runte@geemail.com	San Francisco	California	3112441202319317854	9e40d7761c13263dca5c41018473218f	VISA 16 digit	37.8087507882913698	-122.436781978104918
2615	2019-08-31 05:34:07	2019-08-31	Desi Price PhD	desi.price.phd@woohoo.com	Oakland	California	3096833429273783179	8a9646b09e43bcc1b9c6764ab0b4b80b	VISA 16 digit	37.8167503714074797	-122.275679111034478
2616	2019-08-31 05:56:13	2019-08-31	Tania Rogahn MD	tania.rogahn.md@geemail.com	San Francisco	California	4720042541523982	883c563ad13e691a1a79b6c050e91910	Discover	37.7683074955963818	-122.43113347031715
2617	2019-08-31 08:19:01	2019-08-31	Adelyn Ondricka	adelyn.ondricka@geemail.com	San Francisco	California	3022708953530900	93c1690a652e0c49cf78f6e653956485	Maestro	37.7366419128237212	-122.397663039167128
2618	2019-08-31 08:42:41	2019-08-31	Mr. Friend Bailey	mr.friend.bailey@geemail.com	San Francisco	California	3493303582748501	f76ec3907b5f8cfe4327dc39491385f8	JCB 16 digit	37.7712056575553987	-122.415803285486987
2619	2019-08-31 08:53:09	2019-08-31	Mrs. Morgan O'Connell DDS	mrs.morgan.o'connell.dds@geemail.com	San Francisco	California	4424120630207342	7d6d9703675ff8a3b398e96275502a35	JCB 16 digit	37.7865244534156446	-122.412217301321803
2620	2019-08-31 10:00:47	2019-08-31	Antionette McCullough	antionette.mccullough@geemail.com	San Francisco	California	4083008094826594	d518ac083508e8962ae30976b73e0f5a	JCB 16 digit	37.7862293162267378	-122.45006516489012
2621	2019-08-31 10:40:56	2019-08-31	Jaxton Schoen	jaxton.schoen@geemail.com	Birmingham	Alabama	3052998907617826	148740ab37435bf95c6205d11c441393	Discover	33.4699342743285015	-86.8942868776861701
2622	2019-08-31 11:08:29	2019-08-31	Patience Schultz	patience.schultz@geemail.com	San Francisco	California	3158494389664637709	151cc8661be5669f5fcb8ccc87fe9fee	Mastercard	37.7886845350983904	-122.443692984351131
2623	2019-08-31 14:01:50	2019-08-31	Mr. Giovanny Barton	mr.giovanny.barton@geemail.com	San Francisco	California	4190173984401	9d71e10f3e1a8ddb04dae2a81ba7795a	Maestro	37.7819828341655821	-122.40127677306225
2624	2019-08-31 15:00:33	2019-08-31	Blanch Hintz-White	blanch.hintz.white@warmmail.com	San Francisco	California	3337565490715484614	3ae164ea1ae4a53bd23ac9c9371343f6	American Express	37.7537249816294391	-122.423826679801863
2625	2019-08-31 15:34:40	2019-08-31	Jory Bogisich	jory.bogisich@geemail.com	Berkeley	California	3088093016025228556	b1b09f343d1dcdb5f1e0cca3465db8a0	VISA 13 digit	37.8742757335691493	-122.306579297585685
2626	2019-08-31 16:21:24	2019-08-31	Katelin Stokes-Denesik	katelin.stokes.denesik@geemail.com	San Francisco	California	4650663372607	70c9414a202413a7c16a988fdb4daf6f	Mastercard	37.7532772972280384	-122.430081742621468
2627	2019-08-31 16:39:36	2019-08-31	Ms. Diandra Labadie	ms.diandra.labadie@warmmail.com	San Francisco	California	3003617404001214	e60fed2329547a3d07e0828cd4e3f9dd	JCB 15 digit	37.7784270521958376	-122.429654298520077
2628	2019-08-31 17:19:16	2019-08-31	Destry Lubowitz II	destry.lubowitz.ii@geemail.com	San Francisco	California	3042393035758355	afd40ac97aed038abdecfc37d6bf3262	Voyager	37.7705611269304242	-122.406386509729415
2629	2019-08-31 19:52:19	2019-08-31	Gena Conroy	gena.conroy@warmmail.com	San Francisco	California	869977061502972128	85de957e1b6fb57a3b5857257c6b2de4	Mastercard	37.7521114110366014	-122.424702574601255
2630	2019-08-31 22:24:58	2019-08-31	Benjman Cremin	benjman.cremin@warmmail.com	San Francisco	California	210052497602346384	8069b4fc000304559c8590523cf6ff6a	Diners Club / Carte Blanche	37.7572802167644355	-122.425137814540363
2631	2019-09-01 00:45:44	2019-09-01	Danica Rogahn	danica.rogahn@geemail.com	Berkeley	California	55866062667888690	860f1d1d751bcd5e8ccc8f5fcae7412d	VISA 16 digit	37.8856779780434181	-122.274060466830775
2632	2019-09-01 01:35:58	2019-09-01	Nello Stokes	nello.stokes@geemail.com	Louisville	Kentucky	3528315934898847116	4944a27ad7e9e6d3596639f6a449abdb	VISA 13 digit	38.1773668664876382	-85.6635252616904666
2633	2019-09-01 02:22:56	2019-09-01	Norene Casper-Funk	norene.casper.funk@geemail.com	Berkeley	California	561268067816220	7b0e710f4aa05ca3854533882b74bcc4	VISA 16 digit	37.8343988724534555	-122.26468717627408
2634	2019-09-01 02:28:49	2019-09-01	Clydie Schuster	clydie.schuster@geemail.com	San Francisco	California	180001709122645216	9c262ea885b5e0284ced0a83cb63311a	American Express	37.7540810700571612	-122.456836846187358
2635	2019-09-01 02:50:19	2019-09-01	Robley Stehr	robley.stehr@warmmail.com	Milwaukee	Wisconsin	4187344290272464	f41cb60d6ed802100833da5397f92fd7	Voyager	43.1574055020783049	-87.9068277100201669
2636	2019-09-01 02:59:02	2019-09-01	Mikala Sanford	mikala.sanford@geemail.com	Berkeley	California	3027536325933477	99360a928a9f5f45ae8cd4521fc551c4	VISA 13 digit	37.8563646973847483	-122.288376624844261
2637	2019-09-01 03:12:08	2019-09-01	Bonita Weber	bonita.weber@geemail.com	San Francisco	California	4621035184855	b0eba1c3452aa86e89f842106985d104	American Express	37.759806904160051	-122.437560342232956
2638	2019-09-01 05:13:17	2019-09-01	Laurance Daugherty V	laurance.daugherty.v@warmmail.com	Philadelphia	Pennsylvania	869915651280628697	46e089a740e5f0f12c5eafbf3ceacaa8	Diners Club / Carte Blanche	40.1087653127457955	-75.1619902430001758
2639	2019-09-01 05:15:39	2019-09-01	Giuliana Hackett	giuliana.hackett@geemail.com	Madison	Wisconsin	3022473923418096	f32d0b7796a59faa4e1024bb852ffe10	Voyager	42.995629782646148	-89.4051480654046031
2640	2019-09-01 08:54:06	2019-09-01	Mr. Autry Farrell Sr.	mr.autry.farrell.sr.@warmmail.com	Memphis	Tennessee	869979429681036502	797aa2bd04afacd2bfebd1e2de31dbaf	JCB 15 digit	35.0403239946413834	-90.0523216259922918
2641	2019-09-01 10:32:42	2019-09-01	Gustaf Schuster	gustaf.schuster@geemail.com	San Francisco	California	675904837756479	ce254af899a9664de61bb02549fd40a7	VISA 16 digit	37.7899077962410388	-122.414876976914641
2642	2019-09-01 11:30:09	2019-09-01	Ingram Mosciski	ingram.mosciski@geemail.com	San Francisco	California	3158147954654333493	064395b7853dd7f9cf04b105cb26af7e	JCB 16 digit	37.7418306083210098	-122.444097400048435
2643	2019-09-01 11:50:51	2019-09-01	Dr. Jase Lindgren	dr.jase.lindgren@woohoo.com	San Antonio	Texas	3158240549647322813	c7423abace945d9648f0d3faa63c68c8	Mastercard	29.5151230465691548	-98.5249540053143988
2644	2019-09-01 13:43:13	2019-09-01	Wm Lynch	wm.lynch@woohoo.com	Oakland	California	3027161975956759	9c8f3c9fe437a6c06ee1fde93eae92dd	JCB 16 digit	37.7904943799931914	-122.265410346430272
2645	2019-09-01 13:44:28	2019-09-01	Maury Senger-Nitzsche	maury.senger.nitzsche@geemail.com	Davenport	Iowa	3096108282423291025	15612f1462a51e2e7b953fc5597fe2aa	Maestro	41.5495812640789879	-90.5977204916961512
2646	2019-09-01 14:04:12	2019-09-01	Dannie Altenwerth	dannie.altenwerth@geemail.com	Oakland	California	3096235342897662576	87b465114d0dd87482fff07086b20150	VISA 16 digit	37.802291394994981	-122.291082229205202
2647	2019-09-01 15:18:13	2019-09-01	Honora Pfeffer	honora.pfeffer@geemail.com	Pittsburgh	Pennsylvania	4555468259406	e0440d6b74cc20eb024d5713698083a8	JCB 16 digit	40.3705007394731012	-79.9645324609879395
2648	2019-09-01 15:22:26	2019-09-01	Christen Romaguera	christen.romaguera@geemail.com	San Bernardino	California	501865408740176	8c670b4a7e1aeb1ff4b42992b4259209	Diners Club / Carte Blanche	34.2392482564583389	-117.263815711370114
2649	2019-09-01 17:44:52	2019-09-01	Elianna Jacobson	elianna.jacobson@woohoo.com	Garland	Texas	4149397209416074	060e91b7fe5e954433bf199b79069967	Maestro	32.9569952554304137	-96.5674313510462667
2650	2019-09-01 18:08:21	2019-09-01	Dr. Kamari Cremin IV	dr.kamari.cremin.iv@geemail.com	Newport News	Virginia	869960621582288312	47672be49190c305e130a878d4510c2f	Diners Club / Carte Blanche	37.1147902301874026	-76.5905112923849458
2651	2019-09-01 18:48:43	2019-09-01	Jenny Smith	jenny.smith@geemail.com	San Francisco	California	3088607322557654014	cd52be506ae4062940889d4657ff6247	Voyager	37.765400579004158	-122.429552243455078
2652	2019-09-01 19:12:48	2019-09-01	Kayli Hilpert	kayli.hilpert@warmmail.com	Berkeley	California	3053541069386225	bf2b25d39e4164dd497006c6395b959b	Maestro	37.8755303649377595	-122.29734763041553
2653	2019-09-01 21:50:57	2019-09-01	Ashlie Stroman-Ledner	ashlie.stroman.ledner@geemail.com	Berkeley	California	210086005788916969	5ff4474665f3e1c18f7fd70bbbd26c5b	Diners Club / Carte Blanche	37.8691441600479735	-122.288244508641739
2654	2019-09-01 22:33:39	2019-09-01	Isaak Reynolds	isaak.reynolds@warmmail.com	Oakland	California	6011074383314325672	be98859e5662d76842bea2f2edbeccdb	JCB 16 digit	37.7482197687570391	-122.29100803940841
2655	2019-09-01 22:52:51	2019-09-01	Salma Hansen	salma.hansen@geemail.com	Berkeley	California	54200978111755869	1fce8626c8860d631a4c11593265b484	Diners Club / Carte Blanche	37.8496415492707428	-122.282890729201881
2656	2019-09-01 23:18:18	2019-09-01	Miss Reba Dooley DVM	miss.reba.dooley.dvm@geemail.com	Berkeley	California	4790722052418	89ad20ca2f2753f8dc8d3c28970afad4	VISA 13 digit	37.8677470093164175	-122.246393315203463
2657	2019-09-01 23:34:56	2019-09-01	Cash Schuster III	cash.schuster.iii@woohoo.com	New York	New York	3337889751508406091	dc712a8ff0b24b84b15a7e42b023bb29	JCB 16 digit	40.6490130509007699	-73.8486439058918478
2658	2019-09-02 00:45:53	2019-09-02	Dr. Jailene Robel DVM	dr.jailene.robel.dvm@geemail.com	Columbus	Ohio	4227626247665549	38caa5dd318682d6053f0f93cb9e3874	JCB 16 digit	39.9035958889916529	-82.9404361195631452
2659	2019-09-02 01:37:51	2019-09-02	Jazmyn Schoen	jazmyn.schoen@geemail.com	Berkeley	California	210080872899734573	97a3e2f8252c1f40dfba0b1326787158	Mastercard	37.8658429844091842	-122.276320017466588
2660	2019-09-02 02:20:38	2019-09-02	Carley Yost	carley.yost@woohoo.com	San Francisco	California	3337109915856448021	2d31a7a9397747c08f2f0913b3289672	JCB 16 digit	37.7559298281845557	-122.456532370429997
2661	2019-09-02 02:53:24	2019-09-02	Shaneka Lakin	shaneka.lakin@geemail.com	Houston	Texas	3791820471449232	5ecf3f135602c9b987bf8e1bf3848351	Mastercard	29.7457332159936421	-95.3863017076175623
2662	2019-09-02 03:20:13	2019-09-02	Arvilla Welch	arvilla.welch@warmmail.com	Berkeley	California	3456187217601432	f66e981feb86b52062843a89f927ef1e	Maestro	37.8652541643995306	-122.295055389762595
2663	2019-09-02 03:58:22	2019-09-02	Ms. Ola Auer	ms.ola.auer@woohoo.com	Costa Mesa	California	55435776408740140	1e3d39d87dd7215cb73e0e4f6bcc681b	Diners Club / Carte Blanche	33.6225798107698566	-117.938493181006237
2664	2019-09-02 04:31:29	2019-09-02	Cinthia Medhurst-Bruen	cinthia.medhurst.bruen@woohoo.com	Kansas City	Missouri	180017785179292062	bc278415197471581cc1713ebc89a066	VISA 16 digit	39.2055583034943851	-94.497977196121596
2665	2019-09-02 04:55:06	2019-09-02	Tempie Hermann	tempie.hermann@geemail.com	Hampton	Virginia	53676534837643585	8e8ba1f715d052337be75126530ecc8a	VISA 16 digit	37.1212834558468359	-76.2332630486790066
2666	2019-09-02 04:55:20	2019-09-02	Eve Zulauf	eve.zulauf@woohoo.com	Oakland	California	869939395217480937	bd6f389633c474b97bf54ee187451fda	Diners Club / Carte Blanche	37.7913413378206329	-122.275935017687843
2667	2019-09-02 05:12:03	2019-09-02	Heaven Kuhic	heaven.kuhic@geemail.com	San Francisco	California	4803804420677720	3a04a3e9ea0289369b8bbf820094df31	Discover	37.7994263568351485	-122.4504869837874
2668	2019-09-02 06:12:15	2019-09-02	Mckenzie Johnston DDS	mckenzie.johnston.dds@woohoo.com	San Francisco	California	4885416489536	90ce4aca3f676b9ccb903ba6deddf65b	American Express	37.7738266642009961	-122.42925741960768
2669	2019-09-02 10:10:28	2019-09-02	Carmen Jacobson MD	carmen.jacobson.md@geemail.com	Visalia	California	4485694996119784	9299393dfdf6075682e874cfa5c23f1d	Mastercard	36.2877768692050111	-119.268938795210431
2670	2019-09-02 11:53:00	2019-09-02	Dr. Cristal Smitham DDS	dr.cristal.smitham.dds@woohoo.com	Tulsa	Oklahoma	4968156847449311	d2179009374b7a8aa4bc69d6caeda00d	American Express	36.109874829966202	-95.8106784514106806
2671	2019-09-02 12:09:45	2019-09-02	Kellee Corwin DVM	kellee.corwin.dvm@geemail.com	San Francisco	California	869906973406814980	750234de0f256fc10652fa3f65c1f61b	Voyager	37.7934016304656524	-122.451304663633238
2672	2019-09-02 14:10:07	2019-09-02	Emery Schaefer	emery.schaefer@geemail.com	Oakland	California	869950679635381262	ffa98d2cb2364c1fafd08204b8b70444	American Express	37.8344416727747017	-122.277824417365466
2673	2019-09-02 14:12:14	2019-09-02	Joeseph Fritsch	joeseph.fritsch@geemail.com	Los Angeles	California	3528446113019598997	7ea2a609aec847192e479da45b615eca	Voyager	33.9757155440613587	-118.446379141089693
2674	2019-09-02 15:48:02	2019-09-02	Darvin Jast	darvin.jast@geemail.com	Berkeley	California	675905056769986	39a0ec18a5168f234cdfb5aca80cbd4a	Discover	37.8601174939074809	-122.257125782711498
2675	2019-09-02 15:58:55	2019-09-02	Omari Corwin Sr.	omari.corwin.sr.@geemail.com	Phoenix	Arizona	3112115212231672174	884995f74e6409e89f62497a9c3e17c0	Mastercard	33.4941056230504088	-112.041691653050862
2676	2019-09-02 18:07:24	2019-09-02	Mr. Archie Daniel	mr.archie.daniel@woohoo.com	San Francisco	California	180017022363935748	b2547e70b6117c47421d74022cccfc3d	American Express	37.7709775399653438	-122.436883281279222
2677	2019-09-02 18:15:32	2019-09-02	Valinda Dickinson-Kuhlman	valinda.dickinson.kuhlman@geemail.com	Berkeley	California	869939461070400196	2f7a60e9ace41730ecb1d86ee8e42f0a	Diners Club / Carte Blanche	37.8806232607760549	-122.27500146592088
2678	2019-09-02 18:49:45	2019-09-02	Mr. Lawyer Nicolas	mr.lawyer.nicolas@woohoo.com	San Francisco	California	3050808712301155	34c2b6dd356d18b1c471188852ebec30	VISA 16 digit	37.7421642248203497	-122.46138047244574
2679	2019-09-02 19:27:13	2019-09-02	Valarie Cassin	valarie.cassin@geemail.com	Jacksonville	Florida	4960872483409355	4625cfd55fe9a8ed705ba4651e56700f	JCB 15 digit	30.2835669882182046	-81.7390432740640023
2680	2019-09-02 19:48:14	2019-09-02	Rhea Schmidt	rhea.schmidt@geemail.com	San Francisco	California	3112767791433661854	e324635f5b31765302efffa2c34b85d3	JCB 16 digit	37.7740232749916416	-122.421954220402014
2681	2019-09-02 23:40:07	2019-09-02	Taniyah Pagac-Mante	taniyah.pagac.mante@geemail.com	El Paso	Texas	6011465983516955536	746f91f32adfebcae955226f75cf7648	VISA 13 digit	31.8144425344016426	-106.458767002958808
2682	2019-09-03 00:25:47	2019-09-03	Dr. Vannie Schinner	dr.vannie.schinner@woohoo.com	San Francisco	California	3758909083442361	3613d77adce9474947cd545c0cac6602	Discover	37.7749182417815845	-122.445751088156058
2683	2019-09-03 00:48:03	2019-09-03	Rashaan Herman DVM	rashaan.herman.dvm@geemail.com	Saint Paul	Minnesota	4485997925054158	38e3982c60801ed637665a69dc41a022	American Express	45.0298551592916283	-93.1024048718422677
2684	2019-09-03 01:03:16	2019-09-03	Ford Reynolds	ford.reynolds@geemail.com	San Francisco	California	180058644446747996	8cab376ffcedb54a40bda8fb84320117	VISA 13 digit	37.8152478999229871	-122.392944004451508
2685	2019-09-03 01:52:29	2019-09-03	Ronan Langosh Sr.	ronan.langosh.sr.@woohoo.com	San Francisco	California	4089988009788944	c103a4654a1a204027d8e87a037b1070	VISA 16 digit	37.7662048767554879	-122.448612714909103
2686	2019-09-03 03:30:18	2019-09-03	King Turner	king.turner@woohoo.com	Durham	North Carolina	869988031055618011	718cb8d7c983bee2e20f110e66648b69	JCB 16 digit	36.0697532319709637	-78.823840071996301
2687	2019-09-03 03:53:31	2019-09-03	Marlys Brakus	marlys.brakus@geemail.com	Riverside	California	52601617041912324	afb0b5be781557b280ffd6bc5e49f5e3	Voyager	34.0313238460984095	-117.434433944753181
2688	2019-09-03 06:25:54	2019-09-03	Adelina Thompson MD	adelina.thompson.md@geemail.com	San Francisco	California	3096265044228738132	11fa99b43dbcdc79c903a63c29f971c2	Diners Club / Carte Blanche	37.7904998355812793	-122.414050532879955
2689	2019-09-03 06:40:17	2019-09-03	Chana Morar	chana.morar@geemail.com	Grand Prairie	Texas	503816884538394	dcb69ab75af1ae8bdbc4f9a7619ed803	American Express	32.7759424099750802	-97.0905545119535276
2690	2019-09-03 07:30:24	2019-09-03	Kayli Schmidt-Mraz	kayli.schmidt.mraz@geemail.com	San Francisco	California	3528949376955961402	b3ddca5e5668c5ac8b54cf45dcb0d35a	VISA 13 digit	37.777193994363337	-122.441284084785295
2691	2019-09-03 08:01:41	2019-09-03	Nathalie Ortiz MD	nathalie.ortiz.md@geemail.com	Oakland	California	4458620528483391	bfe985de05bcef4f1573dadd5a8bee71	Voyager	37.7862966674978296	-122.215943568428727
2692	2019-09-03 08:45:56	2019-09-03	Anjali Wilkinson	anjali.wilkinson@geemail.com	Berkeley	California	51986467879752961	4bedd4bd5e97f30854679df2179eee31	JCB 16 digit	37.8832834022006253	-122.283261709283863
2693	2019-09-03 10:40:01	2019-09-03	Ms. Jocelynn Sawayn	ms.jocelynn.sawayn@geemail.com	Berkeley	California	180094906554056684	11a42471b19c780cf9f887160498540c	VISA 16 digit	37.8837237572396788	-122.260976882440403
2694	2019-09-03 12:28:16	2019-09-03	Abigail Ritchie	abigail.ritchie@geemail.com	Newark	New Jersey	3088887251638664133	82b417eed0e8e2ade0d8a486fcdb806b	Voyager	40.7791185827840152	-74.2281098150391188
2695	2019-09-03 13:00:54	2019-09-03	Mrs. Britt Lowe DDS	mrs.britt.lowe.dds@geemail.com	New York	New York	3337172739330434593	f1d23cc01c8bcc89a0178243e5c696c9	Maestro	40.7562098865155136	-73.982503923111409
2696	2019-09-03 14:24:08	2019-09-03	Iza Jacobi	iza.jacobi@geemail.com	San Francisco	California	3776847561596001	02b3c8ea7ad31495027e81ea6b28f6b1	Mastercard	37.7777097034504052	-122.418777279266436
2697	2019-09-03 15:29:57	2019-09-03	Marybeth Cruickshank	marybeth.cruickshank@warmmail.com	San Francisco	California	3027313040285314	82448a24f1e781f9f9931c59c8247fd8	VISA 16 digit	37.7829392057183711	-122.472969658992298
2698	2019-09-03 17:02:41	2019-09-03	Hymen Tromp	hymen.tromp@geemail.com	Berkeley	California	3054042247866500	2af174147848ec92195b17a98db20959	JCB 16 digit	37.8966421225801255	-122.276896489557487
2699	2019-09-03 17:21:36	2019-09-03	Jensen Dickinson	jensen.dickinson@geemail.com	San Francisco	California	4695388578376	f1bdb84ec122d6cb3a5793942ea7291e	VISA 13 digit	37.7899549932304879	-122.428696238933512
2700	2019-09-03 20:06:47	2019-09-03	Lavonda Swaniawski	lavonda.swaniawski@warmmail.com	Cleveland	Ohio	3158936673453211396	9c9715995af0e4e16e6a9e7909239c5a	JCB 16 digit	41.3866217856146363	-81.6926196411490508
2701	2019-09-03 22:29:25	2019-09-03	Carroll Wolff-Gusikowski	carroll.wolff.gusikowski@warmmail.com	Scottsdale	Arizona	3158360199918724836	774be3bcb0505445a1e2057bfd6f2b0b	VISA 16 digit	33.589512064133956	-111.844157653997087
2702	2019-09-03 22:34:01	2019-09-03	Mr. Corbett Kuvalis MD	mr.corbett.kuvalis.md@warmmail.com	Oakland	California	3088194463269818346	000e94c1b47465235577ec1851528a30	VISA 13 digit	37.7930867715885199	-122.249267249375549
2703	2019-09-03 23:14:44	2019-09-03	Dr. Darrian Greenfelder III	dr.darrian.greenfelder.iii@geemail.com	San Francisco	California	3025061897779382	500fbec4461d8785e88e53980d790396	VISA 13 digit	37.7314465827583305	-122.388143324416276
2704	2019-09-03 23:53:07	2019-09-03	Laverne Mertz	laverne.mertz@geemail.com	Austin	Texas	4298808590569692	1ed8c83804b561104322529abed3da4a	Voyager	30.2349539494734252	-97.734052953147895
2705	2019-09-04 01:28:47	2019-09-04	Hudson Schaden	hudson.schaden@geemail.com	Buffalo	New York	51891333995926703	4b4ca0eb9346ec07801af9ef721fbbec	VISA 16 digit	42.8680512170493557	-78.8907940085444608
2706	2019-09-04 02:07:51	2019-09-04	Mr. Nolan Jaskolski	mr.nolan.jaskolski@woohoo.com	San Francisco	California	3112728707206439490	cf80d47ced0aee2b6f5824a357b2fbfe	Diners Club / Carte Blanche	37.7743948101715148	-122.417508329771508
2707	2019-09-04 02:24:08	2019-09-04	Shirlene White	shirlene.white@geemail.com	Oklahoma City	Oklahoma	869904889827954720	180cf49653a0ff5cfcfe51dde99c3ecf	Discover	35.3798033699769547	-97.53184058036544
2708	2019-09-04 02:29:12	2019-09-04	Mrs. Almeta Ernser	mrs.almeta.ernser@woohoo.com	San Francisco	California	3791149920500035	e5e8af3367f92806cc572710c74293b9	Diners Club / Carte Blanche	37.7872219378509016	-122.455805084092319
2709	2019-09-04 02:44:09	2019-09-04	Dori Brakus	dori.brakus@woohoo.com	San Francisco	California	4735489661662749	55204cdc3db3590934398b018037e009	Mastercard	37.7930150547673804	-122.445492827261845
2710	2019-09-04 03:46:38	2019-09-04	Dr. Rickie Hintz	dr.rickie.hintz@geemail.com	Mesa	Arizona	869998134994665883	1cc083d436827dc5427f7df7d29e257d	VISA 13 digit	33.3139136253070092	-111.735788581648464
2711	2019-09-04 03:49:08	2019-09-04	Dr. Garland Schneider V	dr.garland.schneider.v@geemail.com	San Francisco	California	869947517078781950	a7deb842aeecbc0e7268deba77838f13	JCB 16 digit	37.7972851879880309	-122.434570055699609
2712	2019-09-04 05:26:25	2019-09-04	Edith Roberts-Kris	edith.roberts.kris@geemail.com	Columbia	South Carolina	180015632485814480	d2e2aaef155bbe1a1dd2a2c47b1fff04	American Express	34.0179249594252582	-80.8141544015631013
2713	2019-09-04 07:53:20	2019-09-04	Dr. Blain Jacobson PhD	dr.blain.jacobson.phd@geemail.com	San Francisco	California	4649201316635938	43132ec9b1462fb5395007e6bf21853a	Voyager	37.7694504563219056	-122.474667840899357
2714	2019-09-04 08:54:19	2019-09-04	Consuelo Purdy	consuelo.purdy@geemail.com	Oakland	California	869979930332181357	f719c73814570d0c67608a4c23f08d1f	American Express	37.8173776547161751	-122.275224791238983
2715	2019-09-04 09:12:55	2019-09-04	Dr. Marcel Wisozk	dr.marcel.wisozk@warmmail.com	San Francisco	California	3453489056712970	d574b13d9ca2ea933a0cccb5e0dda053	VISA 13 digit	37.7776468357228978	-122.450121684234219
2716	2019-09-04 10:42:22	2019-09-04	Ms. Francina Kuhic	ms.francina.kuhic@geemail.com	San Francisco	California	869914145897683303	8973f40621f4ec255e29f66ad6cd226b	VISA 16 digit	37.7968542606758717	-122.428576677574
2717	2019-09-04 11:15:57	2019-09-04	Aliana Jacobson DVM	aliana.jacobson.dvm@woohoo.com	Oakland	California	3046579903588983	c11f41f938404632a9df109cd074fe7d	VISA 16 digit	37.79156540457425	-122.264192314078386
2718	2019-09-04 11:19:01	2019-09-04	Antionette Hoppe	antionette.hoppe@woohoo.com	Portland	Oregon	4140922807346	c910f02c1de6482a1797cb06873df3df	Voyager	45.4614417880661748	-122.579704775381842
2719	2019-09-04 12:08:05	2019-09-04	Beryl Quigley	beryl.quigley@geemail.com	Buffalo	New York	676195666106877	d4c704def147374a780a970a3a96618f	Maestro	42.982365053817631	-78.8481554780088345
2720	2019-09-04 12:13:15	2019-09-04	Dr. Ennis Mueller	dr.ennis.mueller@geemail.com	San Francisco	California	3088355422389254118	b1992c2709a2c86259f793b5e4bb194e	VISA 13 digit	37.8010111746567858	-122.444264446542164
2721	2019-09-04 12:48:08	2019-09-04	Mrs. Micah McKenzie	mrs.micah.mckenzie@geemail.com	Boston	Massachusetts	4973350267993493	1c46ca54ac25a4d24ed4a9e5cb00ad97	Mastercard	42.2607013374734706	-70.9685908900059843
2722	2019-09-04 13:42:57	2019-09-04	Aleta Wintheiser	aleta.wintheiser@geemail.com	Oakland	California	3337319129355173967	1e6c4401e367bf3ab4d5e3c15235e594	VISA 13 digit	37.8018659846691776	-122.279608546377318
2723	2019-09-04 16:23:37	2019-09-04	Dr. Jeremey Hettinger	dr.jeremey.hettinger@warmmail.com	Seattle	Washington	4142060938224212	0445cb8c0dd119dca5a6aba02be1146f	Mastercard	47.5438545894734546	-122.258821508746223
2724	2019-09-04 16:49:19	2019-09-04	Robby Cronin	robby.cronin@woohoo.com	Phoenix	Arizona	4612612075547143	9af6c306d0aaa76820b9f97703ad79e9	VISA 13 digit	33.5881014687873432	-112.131033952527133
2725	2019-09-04 17:23:37	2019-09-04	Rocio Jaskolski	rocio.jaskolski@geemail.com	San Francisco	California	4351505538389050	190c660aaa27f0adb587f9b51fde0c93	VISA 16 digit	37.7623036409331618	-122.473023477162002
2726	2019-09-04 17:39:57	2019-09-04	Miss Salma Greenholt	miss.salma.greenholt@warmmail.com	San Francisco	California	869989369125633944	cb7f506bfc5b02761ed671bb16825243	Diners Club / Carte Blanche	37.773642061725532	-122.415907774586358
2727	2019-09-04 18:07:46	2019-09-04	Dr. Hunt Dibbert	dr.hunt.dibbert@warmmail.com	New York	New York	180002984175220410	b0b0dd5404d81c5b8f508a46be7f7b2a	American Express	40.5777209772020555	-74.0369753738760892
2728	2019-09-04 19:42:03	2019-09-04	Shaquita Ward	shaquita.ward@geemail.com	Berkeley	California	55855097158663056	9e0029c98374f454db50d69694c2b8cf	Discover	37.8808139009788434	-122.263028714004818
2729	2019-09-05 01:21:57	2019-09-05	Dr. Jonah Watsica	dr.jonah.watsica@geemail.com	Worcester	Massachusetts	52478111947475453	c3e2d3a77a1b7f6c77ab7eea8de7673a	VISA 16 digit	42.2993495423514432	-71.7843664704143976
2730	2019-09-05 01:30:35	2019-09-05	Dion Hahn-Rice	dion.hahn.rice@geemail.com	Corpus Christi	Texas	3088672226874015967	3fe4e9d16417c118dc9af5edf93fb73b	Mastercard	27.6748074421595796	-97.1689699018668449
2731	2019-09-05 01:42:43	2019-09-05	Jacqulyn Weber	jacqulyn.weber@geemail.com	San Francisco	California	4892855203779523	9da3d9a5cbe5bb1e96d943e915a51ed4	JCB 15 digit	37.8004398446933578	-122.437547837815245
2732	2019-09-05 02:14:03	2019-09-05	Osa Stanton-Bosco	osa.stanton.bosco@woohoo.com	Berkeley	California	4582359253801	e51aa42f6895ad168984e76ca6aa9593	VISA 13 digit	37.8386784616459977	-122.285328433084743
2733	2019-09-05 03:46:31	2019-09-05	Suzette Medhurst	suzette.medhurst@woohoo.com	Houston	Texas	869907222667542362	5afbf67f3f60a906943c9c4c14f40895	Discover	29.7288968746162965	-95.3722992537558127
2734	2019-09-05 05:54:10	2019-09-05	Domenic Bauch	domenic.bauch@geemail.com	New York	New York	210026448367852200	de04a11ce0646b5f5cc0e44ad42101fb	JCB 15 digit	40.6214359940718879	-73.8957733207277983
2735	2019-09-05 06:08:20	2019-09-05	Miss Betsey Aufderhar	miss.betsey.aufderhar@geemail.com	Berkeley	California	4975488831046972	4078bbc4050d39054b8f523a68e389d3	VISA 16 digit	37.8879804635841424	-122.284130126745026
2736	2019-09-05 07:16:46	2019-09-05	Diane Keeling-Howell	diane.keeling.howell@geemail.com	Berkeley	California	51432415861879078	3ce2815668149f0932bf4d357ea08e20	VISA 16 digit	37.8492374518383912	-122.266521096140764
2737	2019-09-05 07:43:55	2019-09-05	Emily Cummings MD	emily.cummings.md@geemail.com	San Francisco	California	54794689245794136	903b7a96a66cacf484b856efab9bc876	Discover	37.7886527081397929	-122.446077182121797
2738	2019-09-05 08:20:19	2019-09-05	Miss Alma Johnston	miss.alma.johnston@warmmail.com	San Francisco	California	4419601181443615	5e5d7a5acb8d94f931dabe86423d3786	JCB 15 digit	37.7719482201633525	-122.431811040502367
2739	2019-09-05 08:40:29	2019-09-05	Raegan Walter	raegan.walter@woohoo.com	Berkeley	California	3469168598830167	dc3c6f2124c8b4e58fbb17e06d742c5d	American Express	37.8588328206355058	-122.284043356868082
2740	2019-09-05 09:34:20	2019-09-05	Hollis Kuvalis	hollis.kuvalis@warmmail.com	Lakeland	Florida	869985034146921983	2875f96258d35578dd1fc7d259089f17	Voyager	28.1249429303053766	-82.0194238942001022
2741	2019-09-05 10:54:56	2019-09-05	Tiara Boyle-Erdman	tiara.boyle.erdman@geemail.com	Columbus	Ohio	4984412824318668	31976563dfdd2bd4a9933c3e9d1dbb39	Diners Club / Carte Blanche	39.9178153462287	-82.9470810226399493
2742	2019-09-05 13:25:19	2019-09-05	Margery Miller	margery.miller@woohoo.com	San Francisco	California	6011917826887365161	b8107595c567c7c7f1b69904007d2484	American Express	37.7814013036596705	-122.422070330420226
2743	2019-09-05 14:15:53	2019-09-05	Mrs. Annie Boyer	mrs.annie.boyer@warmmail.com	Odessa	Texas	6011227478391629263	d15ff49f0c5f0ae6f3ec484cbe763ab4	Voyager	31.9449022254917772	-102.243010432940352
2744	2019-09-05 15:29:27	2019-09-05	Amari Renner	amari.renner@geemail.com	San Francisco	California	51127475460126446	ef16c6e08b2c5921b8317ec2017785a7	Voyager	37.7649102677859503	-122.444341174838769
2745	2019-09-05 16:07:18	2019-09-05	Janie Halvorson	janie.halvorson@woohoo.com	Sunnyvale	California	3158162004528553858	bc6e91f38a6b4223d4d2ed12d7678270	JCB 16 digit	37.3039094672530922	-121.957698358102888
2746	2019-09-05 16:23:02	2019-09-05	Shirlee Anderson DVM	shirlee.anderson.dvm@geemail.com	Tucson	Arizona	3528289254357564967	29c1d483ff2e20f4b648644a3e4b46de	VISA 13 digit	32.2087706818752011	-110.824334544804316
2747	2019-09-05 16:24:53	2019-09-05	Kiley Schimmel	kiley.schimmel@geemail.com	San Francisco	California	3337481989957031349	a2173eb436f56d0fa0d0c9d9f02ab3cb	VISA 16 digit	37.8025644538821695	-122.417407112048437
2748	2019-09-05 18:53:54	2019-09-05	Calhoun Paucek	calhoun.paucek@geemail.com	San Francisco	California	869972473659049979	f4a796779b0ce40ad8382d05db1c5f85	American Express	37.7881126398597829	-122.420645042532158
2749	2019-09-05 19:30:35	2019-09-05	Dr. Brigid Langworth MD	dr.brigid.langworth.md@warmmail.com	Memphis	Tennessee	180049813984207455	fb8c54fa90c4d44783b91e519b277113	VISA 13 digit	35.0933889394693068	-90.0410728070210666
2750	2019-09-05 21:35:48	2019-09-05	Terry McCullough DVM	terry.mccullough.dvm@geemail.com	San Francisco	California	55201160538507202	8dd54fae0a294fc85ca1a451ebb600d1	Voyager	37.779232338921318	-122.403881109623185
2751	2019-09-05 21:37:10	2019-09-05	Marlana Rice PhD	marlana.rice.phd@warmmail.com	Allentown	Pennsylvania	4079937204065352	27380cd2cee19b719dc5126d7a385e60	VISA 16 digit	40.6000267847221394	-75.5050362180467687
2752	2019-09-05 22:35:01	2019-09-05	Rufus Welch	rufus.welch@woohoo.com	San Francisco	California	210074543665715314	cfba59372246b4d5eefe7d076f9330cf	VISA 13 digit	37.769629838177238	-122.429270339706576
2753	2019-09-05 23:10:03	2019-09-05	Vikki Ledner	vikki.ledner@geemail.com	Berkeley	California	3784055589175457	15ce4ff58a874b033bf7a06dada1d3f0	American Express	37.8517991323926566	-122.257229178353484
2754	2019-09-06 00:05:43	2019-09-06	Dr. Jajuan Hilll Sr.	dr.jajuan.hilll.sr.@geemail.com	Boise	Idaho	3036588379187709	d05d5197fd85efea95b34eba4db50cf0	Mastercard	43.5805253344260137	-116.145493178647754
2755	2019-09-06 00:19:15	2019-09-06	Lamont Hartmann	lamont.hartmann@geemail.com	Charlotte	North Carolina	52788439825327198	0bb9f32360c406d9d53b0498343a0555	JCB 16 digit	35.1287787023719389	-80.9094371634945304
2756	2019-09-06 00:19:20	2019-09-06	Demond Kohler	demond.kohler@geemail.com	San Francisco	California	3048148079747969	3eaf73760f6e49f352317d1e7c8583bd	JCB 16 digit	37.766835041713037	-122.43713776878549
2757	2019-09-06 00:25:50	2019-09-06	Ota Dibbert-Kulas	ota.dibbert.kulas@geemail.com	Independence	Missouri	210079757171726285	f57b713cd36075d2607bad166a15458c	JCB 16 digit	38.9911291422806698	-94.4240187475275121
2758	2019-09-06 00:48:59	2019-09-06	Anthony Dickinson-Macejkovic	anthony.dickinson.macejkovic@warmmail.com	Berkeley	California	4973996744922339	93244a71a9c6f97e714b95aef7e2f58b	VISA 16 digit	37.8611257905146275	-122.300164861978701
2759	2019-09-06 02:41:59	2019-09-06	Jaye Barrows	jaye.barrows@geemail.com	Oakland	California	4497534733595	a347e7aea517808f76856eafa5ea25ab	JCB 16 digit	37.8014756418881532	-122.280130579928013
2760	2019-09-06 04:32:14	2019-09-06	Doshia Moen	doshia.moen@woohoo.com	Berkeley	California	561260163277449	5cd52a24d78ea79238541a165bdc0922	VISA 16 digit	37.8541204763375845	-122.261505491493708
2761	2019-09-06 04:57:50	2019-09-06	Mrs. Miya O'Hara DDS	mrs.miya.o'hara.dds@geemail.com	Santa Ana	California	3009342478238725	8ec3868ad0bf4ff23ac33b99ad921186	VISA 13 digit	33.8318835491418852	-117.810110047964372
2762	2019-09-06 05:07:16	2019-09-06	Oswald Larkin	oswald.larkin@geemail.com	Oakland	California	3112198990501537355	61b55419a1c1938c2eef6db68161a743	Voyager	37.7844662748723508	-122.293766719329568
2763	2019-09-06 05:53:43	2019-09-06	Jenny Altenwerth	jenny.altenwerth@warmmail.com	Fontana	California	4786452969587842	beab69d5481f41fd9c98e049ee305de2	Maestro	34.0600628210380663	-117.49129482091368
2764	2019-09-06 05:59:23	2019-09-06	Dr. Tyquan Weimann	dr.tyquan.weimann@geemail.com	Oakland	California	51165354509595346	8981ef96836fb2880b38e8ca6c0a4494	VISA 13 digit	37.8008792307045951	-122.271852067003252
2765	2019-09-06 06:18:32	2019-09-06	Cicero Hessel	cicero.hessel@warmmail.com	Los Angeles	California	51790302714974353	38eb3fcd8d41acda59ef0d32b6d176b2	JCB 16 digit	33.9605508311983186	-118.35392129993923
2766	2019-09-06 06:21:44	2019-09-06	Beckham Rau	beckham.rau@geemail.com	San Jose	California	869901665040165218	d7ba469e5335089ca464515dac1adc36	JCB 16 digit	37.2761928664341582	-121.77698506831527
2767	2019-09-06 06:51:42	2019-09-06	Mr. Woodson Stiedemann	mr.woodson.stiedemann@geemail.com	San Francisco	California	3412589060660949	115da6fabd20e442b3f8d3544407c8cc	Mastercard	37.7766938770199303	-122.409648359561899
2768	2019-09-06 06:55:45	2019-09-06	Minervia Ortiz	minervia.ortiz@geemail.com	Berkeley	California	4618359869749	27471aad18dbe3bd350d5d29c1cf4a94	JCB 16 digit	37.8693937407024066	-122.278904936534445
2769	2019-09-06 07:58:17	2019-09-06	Rudolph Fay	rudolph.fay@geemail.com	Tampa	Florida	4888083445147062	8877971766c9597ddbea94199151068d	JCB 16 digit	28.0346913205109516	-82.4287648011211189
2770	2019-09-06 08:35:36	2019-09-06	Stefanie Reynolds	stefanie.reynolds@geemail.com	San Francisco	California	210005784015888393	aaa6aca6b34788fd5c8ee51b25df1da6	JCB 15 digit	37.7655093822388608	-122.451277322944691
2771	2019-09-06 08:38:34	2019-09-06	Erie Herman	erie.herman@geemail.com	Berkeley	California	3158142816441363528	51622276c6a6b30d2d1450d23b180d02	Maestro	37.8731794451846255	-122.265405246390486
2772	2019-09-06 10:29:12	2019-09-06	Miss Kaia Blanda MD	miss.kaia.blanda.md@warmmail.com	San Francisco	California	676140529735785	3601fa1a6020f366b9a89efe786bf6fe	VISA 16 digit	37.7301839336803368	-122.440986098272191
2773	2019-09-06 10:41:03	2019-09-06	Francisca Runte	francisca.runte@geemail.com	Davie	Florida	676328257134578	bcbe5d4726426b41ab74475b5c6c3fa0	VISA 16 digit	25.9827239987239231	-80.3412784083653264
2774	2019-09-06 13:15:28	2019-09-06	Justine Ward	justine.ward@woohoo.com	San Antonio	Texas	6011555071006684641	8be3327075da9a85b1e265039e04745c	JCB 16 digit	29.5651210756577569	-98.4264080462813382
2775	2019-09-06 13:27:22	2019-09-06	Mr. Claud Cole	mr.claud.cole@geemail.com	Lewisville	Texas	869904820694149672	de58671562225919bb48b9b7d1718500	Mastercard	33.0354774373102913	-97.0224054167076986
2776	2019-09-06 13:38:01	2019-09-06	Yoel Stehr DDS	yoel.stehr.dds@geemail.com	San Francisco	California	210087634387350830	4b034ae754c16b3de1e692f4fe219e4a	Discover	37.7642645092815101	-122.428288571090661
2777	2019-09-06 14:19:08	2019-09-06	Moriah Dickinson	moriah.dickinson@warmmail.com	San Francisco	California	6011923518133164983	a04bdb94ac5e75d5dfaeaa74d40def8f	VISA 13 digit	37.8084178718639734	-122.431655317287124
2778	2019-09-06 20:28:34	2019-09-06	Barrett Kessler	barrett.kessler@geemail.com	Dallas	Texas	180011264191744613	d1c7df305bc29d559bdd224d19b31f65	VISA 16 digit	32.8025206223867869	-96.8048053992874884
2779	2019-09-06 20:32:08	2019-09-06	Mrs. Debroah Swaniawski	mrs.debroah.swaniawski@geemail.com	Norman	Oklahoma	3023938546994367	61e104731cbbae3e18ae15cef6c3213d	Discover	35.2804943301755927	-97.3081184704575577
2780	2019-09-06 21:08:46	2019-09-06	Edwin Collins	edwin.collins@geemail.com	San Francisco	California	4959031205369891	cf208af1ed836b7bfb60a762adf6e037	VISA 13 digit	37.7906378542148218	-122.411904589980665
2781	2019-09-06 22:15:01	2019-09-06	Louanna Christiansen	louanna.christiansen@geemail.com	San Francisco	California	869937056646104025	8678f61260e8537a702dbc5f1f9fd05b	Discover	37.7794910064985814	-122.44819955630318
2782	2019-09-07 00:18:13	2019-09-07	Nathanael Goldner-Dickinson	nathanael.goldner.dickinson@geemail.com	Berkeley	California	3719392774107742	242f6f573b2328f2966f0e6be73dd811	VISA 13 digit	37.8775155072880665	-122.283076132304444
2783	2019-09-07 00:23:27	2019-09-07	Santos Erdman	santos.erdman@geemail.com	Berkeley	California	180077766934972617	4799f98d6cd52c2df4d0c3dc76d0ceb1	JCB 16 digit	37.8901672787349995	-122.259330936676008
2784	2019-09-07 01:54:07	2019-09-07	Karly Hoeger-Murphy	karly.hoeger.murphy@geemail.com	Phoenix	Arizona	589368222760537	df4e34cfc8422908be0f27905d025cc9	American Express	33.5983402191128633	-112.175143554939339
2785	2019-09-07 02:57:21	2019-09-07	Jed Conn	jed.conn@geemail.com	Tampa	Florida	6011223807719189911	0a36e241a78d37a836ffb4a406f789ad	Voyager	27.9997334038488539	-82.4904882808893802
2786	2019-09-07 03:17:55	2019-09-07	Gus Steuber	gus.steuber@woohoo.com	Memphis	Tennessee	3337655910303162133	44cb1d1fc3dd54576856777a4abd48ce	JCB 16 digit	35.1998161803532383	-89.9661554492335824
2787	2019-09-07 03:19:34	2019-09-07	Ransom Jakubowski	ransom.jakubowski@geemail.com	Rockford	Illinois	3528306815544832332	98ae15d69346dd9239499c475d6ef29d	JCB 16 digit	42.2821560544438668	-89.1180886126406477
2788	2019-09-07 03:25:39	2019-09-07	Miss Charlee Stark	miss.charlee.stark@geemail.com	San Francisco	California	869988811354111275	41da5ed30d4ea63278790158f987cd05	VISA 16 digit	37.7855855374448026	-122.443542733812436
2789	2019-09-07 04:38:21	2019-09-07	Dakotah Connelly	dakotah.connelly@geemail.com	Cedar Rapids	Iowa	3021585632999206	f901fbbcf2fc491cb07925ed949ba9d3	Mastercard	41.9048931245766596	-91.6189899332422755
2790	2019-09-07 06:04:43	2019-09-07	Jeannie Leannon	jeannie.leannon@geemail.com	Atlanta	Georgia	4871476151711	8fc332a08c1aa9d5110395f8e8999951	Mastercard	33.6883851249977937	-84.4671605621509372
2791	2019-09-07 06:12:53	2019-09-07	Sumner Bahringer	sumner.bahringer@geemail.com	Los Angeles	California	3088157755051637569	eb9c7aa70a8fe8cb8924b2486425a565	JCB 16 digit	34.0594049362797264	-118.49847461180687
2792	2019-09-07 06:17:28	2019-09-07	Mr. Aloysius Borer	mr.aloysius.borer@geemail.com	Berkeley	California	3780748856433054	2e566755b1fa8a054735072539320745	VISA 16 digit	37.8608268956207965	-122.26202109058282
2793	2019-09-07 06:58:43	2019-09-07	Nila Moore	nila.moore@geemail.com	Santa Maria	California	3013661733580670	2cc6d0c73749f385d2bc2bcdf092d3ca	JCB 15 digit	34.9669597867008264	-120.432883518180986
2794	2019-09-07 08:50:30	2019-09-07	Alvah Weissnat-Gusikowski	alvah.weissnat.gusikowski@geemail.com	Oakland	California	4651526398434593	378bbfc74b8b40acdfb56c6f86866cb0	Diners Club / Carte Blanche	37.8413429234551373	-122.290282355746385
2795	2019-09-07 10:27:57	2019-09-07	Kaya Koelpin	kaya.koelpin@geemail.com	San Francisco	California	4985978015345750	3a981c18337dac90f14eff7dbefa5bea	Voyager	37.7537327608411104	-122.412407589358367
2796	2019-09-07 12:48:35	2019-09-07	Ms. Mirna Littel MD	ms.mirna.littel.md@warmmail.com	Berkeley	California	4739163709671	35680e016b57ee6a60f30a671ce00b95	Voyager	37.8889852319275064	-122.243789908968921
2797	2019-09-07 13:19:03	2019-09-07	Romello Brakus	romello.brakus@geemail.com	San Francisco	California	3739957281312690	363261256b99913bb66272a35f206a45	Maestro	37.7709612201678198	-122.426553230726768
2798	2019-09-07 13:22:37	2019-09-07	Seth Luettgen	seth.luettgen@warmmail.com	San Francisco	California	4418621344344	3d28463b2071ee48ab0a49b3d53190b8	JCB 16 digit	37.7626626100578591	-122.446801040621068
2799	2019-09-07 13:22:42	2019-09-07	Dr. Erika Konopelski MD	dr.erika.konopelski.md@geemail.com	San Francisco	California	53541427657153640	6c85bcbca1ace8bc338127f256ccb05f	Voyager	37.7995724775817266	-122.458818965035348
2800	2019-09-07 15:06:45	2019-09-07	Crissie Jones DVM	crissie.jones.dvm@geemail.com	Boise	Idaho	4370312070919841	53c14df6fc57ac86c21298b27199d7ec	JCB 16 digit	43.6955020545188333	-116.202492077528319
2801	2019-09-07 15:09:22	2019-09-07	Damien Boehm PhD	damien.boehm.phd@geemail.com	San Francisco	California	6011395555197984715	ae3d434ba84c9fd1c39e613867fe4883	Mastercard	37.7855931336139363	-122.411402859049616
2802	2019-09-07 15:16:58	2019-09-07	Mateo Rutherford	mateo.rutherford@warmmail.com	Oakland	California	210069027174758616	44f96d5b364abba4bdb6b88d79448fae	Voyager	37.7994449309218226	-122.278427471268756
2803	2019-09-07 16:21:56	2019-09-07	Cletus Welch	cletus.welch@geemail.com	Berkeley	California	210072665997079168	b6c6bb31c50d41167d1f091e915d554e	VISA 16 digit	37.8581923370423326	-122.273657365383627
2804	2019-09-07 18:14:06	2019-09-07	Tabitha Schimmel-Abshire	tabitha.schimmel.abshire@geemail.com	San Francisco	California	3088951698184631026	de6812e9e31467258b273c9d9a5c015e	VISA 13 digit	37.7627281680284383	-122.482115924970643
2805	2019-09-07 18:18:29	2019-09-07	Mr. Lemon Heller PhD	mr.lemon.heller.phd@geemail.com	Virginia Beach	Virginia	3112848523950580594	a4b7a510b6e18554edf3965e27b587a8	JCB 16 digit	36.7037586020957676	-75.979706181320168
2806	2019-09-07 18:36:53	2019-09-07	Kamila Crist PhD	kamila.crist.phd@geemail.com	San Jose	California	639028190839655	05819d6b01913c8b6d05dcf1b71703b0	Discover	37.3114267040330958	-121.902431411411243
2807	2019-09-07 21:03:48	2019-09-07	Amina Stark	amina.stark@geemail.com	San Francisco	California	4436280595704869	71aca2ed8060be4ff71dff080ee11518	JCB 16 digit	37.7618466230493013	-122.443277408342936
2808	2019-09-07 21:23:42	2019-09-07	Jobe Rippin	jobe.rippin@warmmail.com	San Francisco	California	4743272577071704	1269f47e5116cc15f3ad965589ab6a36	VISA 13 digit	37.7886775536848276	-122.448167639131213
2809	2019-09-07 23:40:08	2019-09-07	Dr. Marcelle Hilpert	dr.marcelle.hilpert@woohoo.com	San Francisco	California	3460119489546692	a8f73ed6749934392d7130a4c3e5d690	Discover	37.756899249645933	-122.457480739098344
2810	2019-09-08 00:15:07	2019-09-08	Melvin Block-Oberbrunner	melvin.block.oberbrunner@woohoo.com	San Francisco	California	3789537432185416	60194429c33a16b3d875cf64b8bc486f	Diners Club / Carte Blanche	37.7682123309977555	-122.442662224522522
2811	2019-09-08 00:42:17	2019-09-08	Leafy Halvorson-Heidenreich	leafy.halvorson.heidenreich@woohoo.com	Tucson	Arizona	4799348300721	54bef425c09e88164975a4439e01ea19	JCB 16 digit	32.1632532413158572	-110.862407107627391
2812	2019-09-08 02:17:03	2019-09-08	Ardella Terry	ardella.terry@geemail.com	El Paso	Texas	4413577831835648	ca617699610ad489c324d2fd9a715607	American Express	31.9169740556567909	-106.4393790897429
2813	2019-09-08 03:03:10	2019-09-08	Miss Kamya Romaguera	miss.kamya.romaguera@geemail.com	Berkeley	California	3096374989904900927	8b02cdcd5a4457dfc4e8595238b6d45d	JCB 15 digit	37.9158114661287797	-122.285395012237075
2814	2019-09-08 03:59:24	2019-09-08	Milburn Lakin	milburn.lakin@geemail.com	Austin	Texas	53029672808579976	676d29ec09da82bb88b0e64181af3af0	VISA 16 digit	30.3024189798288042	-97.6956420434411683
2815	2019-09-08 04:27:59	2019-09-08	Walton Beatty	walton.beatty@geemail.com	San Francisco	California	6011829625865562592	e909afa2d7dd08f743e5f1abdb7e2cc0	Mastercard	37.7430413539222158	-122.405101837007152
2816	2019-09-08 04:29:19	2019-09-08	Virgia Cremin	virgia.cremin@geemail.com	San Francisco	California	3427965299529811	7c283fe4e726d60a222dd1bf6c3c5373	JCB 16 digit	37.7831881275011696	-122.423657312450942
2817	2019-09-08 05:11:55	2019-09-08	Ken Borer	ken.borer@geemail.com	Oakland	California	869967185898290050	f4ea007f77d6ab3a97aad99863807898	JCB 16 digit	37.8009415982178538	-122.255439764809495
2818	2019-09-08 05:14:31	2019-09-08	Philomene Powlowski	philomene.powlowski@geemail.com	Boise	Idaho	3423649708783730	e165d063a9f8682e5414aff8a0499526	JCB 16 digit	43.5128983886119016	-116.182346907975898
2819	2019-09-08 06:06:18	2019-09-08	Carri Bradtke	carri.bradtke@geemail.com	Omaha	Nebraska	4945522092881409	5e7a7efc2049b6173d224d94efcf3b9a	American Express	41.3176676550094086	-96.0046070131123059
2820	2019-09-08 06:10:04	2019-09-08	Lesta Keebler	lesta.keebler@geemail.com	Oakland	California	3096360789381307620	fc486428108752fd69cec592c8d37941	Discover	37.7845483438770202	-122.249683248053273
2821	2019-09-08 06:16:39	2019-09-08	America Hartmann	america.hartmann@woohoo.com	Oakland	California	4728665677446123	f45f76ffbf366a8d8a13f302b25e9596	JCB 15 digit	37.8163687610105868	-122.260055629129738
2822	2019-09-08 06:38:31	2019-09-08	Robyn Kub	robyn.kub@geemail.com	San Francisco	California	3488748968947431	1868b01d79684737fc0a2b5e4f0d79e6	JCB 16 digit	37.7988798094803542	-122.417818695620483
2823	2019-09-08 06:53:08	2019-09-08	Angela Gibson-Kuvalis	angela.gibson.kuvalis@warmmail.com	Portland	Oregon	6011703662122838425	879243aaf1152a3e1295b28fc6ec0d89	VISA 13 digit	45.6286813902091239	-122.601695040520283
2824	2019-09-08 07:27:34	2019-09-08	Mr. Almon Koelpin Jr.	mr.almon.koelpin.jr.@geemail.com	Berkeley	California	4742170990624011	fb1d4ee67efdfeff1bab7f824e0879f1	VISA 16 digit	37.8551842732806705	-122.286196690748127
2825	2019-09-08 07:59:41	2019-09-08	Kelsea Schuster	kelsea.schuster@geemail.com	New York	New York	4081721223287	5dcd2d828b7187e07ee0beb009f36e3a	American Express	40.6314061653092509	-74.0116768302291632
2826	2019-09-08 11:35:58	2019-09-08	Alyssia Kilback	alyssia.kilback@geemail.com	San Francisco	California	3158997936188768469	df7c524a65d30cce95ad5c22dca7b717	Maestro	37.7881180445035909	-122.453267586990606
2827	2019-09-08 11:44:14	2019-09-08	Taylor Moen	taylor.moen@warmmail.com	Oakland	California	3337079370706545673	608bdb3c0f6445fc01e6663e88a932bb	VISA 16 digit	37.8100445493685484	-122.285192101049162
2828	2019-09-08 11:50:56	2019-09-08	Dr. Willian Mosciski V	dr.willian.mosciski.v@geemail.com	Berkeley	California	869944201333024695	ac0c037ce4eff5bf0e26a411b6d017b6	JCB 16 digit	37.8732384479283013	-122.288673285603068
2829	2019-09-08 13:09:50	2019-09-08	Naima Altenwerth	naima.altenwerth@geemail.com	Oakland	California	53808254584715848	a0107dc5acdfb974a55456e34144b519	JCB 16 digit	37.8074729318121925	-122.239773704089217
2830	2019-09-08 15:12:55	2019-09-08	Miss Sandra Moen DDS	miss.sandra.moen.dds@warmmail.com	San Francisco	California	3112544181547328469	60ee579a73f2c74c52e82840678ad9df	Discover	37.7845601317738939	-122.44314875109967
2831	2019-09-08 15:34:12	2019-09-08	Vernelle Weissnat	vernelle.weissnat@geemail.com	Milwaukee	Wisconsin	3031676488577483	2a22df62d4fd45cd7d95805d5fccd75a	Mastercard	43.0561381379228081	-88.0597058018770156
2832	2019-09-08 16:16:03	2019-09-08	Ms. Migdalia Price	ms.migdalia.price@geemail.com	El Paso	Texas	3096475933389234459	a1f147eab652bad8406fb881230dd4be	Discover	31.8364061624571697	-106.408500388775025
2833	2019-09-08 16:45:45	2019-09-08	Tishie Volkman DVM	tishie.volkman.dvm@geemail.com	San Diego	California	3096104286529865503	44dce582abdf7b4e60dbcca65d564eeb	VISA 16 digit	32.7325699401155106	-117.063966838074847
2834	2019-09-08 16:50:57	2019-09-08	Sidney King	sidney.king@geemail.com	Oakland	California	3337800170728772321	54e9977589a23aa8eaa61c3cf4868956	JCB 15 digit	37.8382468873629563	-122.305763430407595
2835	2019-09-08 17:09:08	2019-09-08	Dr. Diane Leffler	dr.diane.leffler@geemail.com	San Francisco	California	4018210536225	209082ce6f31819a2350ab02dcaa1ad3	Diners Club / Carte Blanche	37.7785380743331558	-122.403465074445592
2836	2019-09-08 18:41:39	2019-09-08	Welton Dach	welton.dach@geemail.com	San Francisco	California	3035160806774839	b47bd982aef8e9a2278cc30b6c833f21	VISA 16 digit	37.7866680139090505	-122.422833380614563
2837	2019-09-08 22:29:31	2019-09-08	Mr. Will Wunsch	mr.will.wunsch@warmmail.com	New York	New York	6011669115484508021	99a506dc932476971f75dd1213d786d4	American Express	40.6780108697470268	-73.8850310956023577
2838	2019-09-09 01:18:14	2019-09-09	Mrs. Ever McLaughlin	mrs.ever.mclaughlin@geemail.com	San Francisco	California	180063217871163006	e6f3eaf28e2cf4f03f986f667fb46d3e	Discover	37.836040099210031	-122.403698504705631
2839	2019-09-09 01:27:10	2019-09-09	Miss Jailyn Schoen	miss.jailyn.schoen@geemail.com	San Francisco	California	869930078105430706	1eb664a2fd32120274ead4d919e88986	American Express	37.7738257122074401	-122.414446443038671
2840	2019-09-09 01:42:35	2019-09-09	Diallo Bruen I	diallo.bruen.i@geemail.com	San Francisco	California	3112933276789468541	40368a111ead3e51b4eb9ae26dd1af38	VISA 16 digit	37.7664027905422017	-122.428227401562793
2841	2019-09-09 03:13:09	2019-09-09	Elta Lockman	elta.lockman@geemail.com	Berkeley	California	180010796426343829	3fd32731393d0aaf9cb439284d4db6b4	American Express	37.820569410762289	-122.28253067795805
2842	2019-09-09 04:19:29	2019-09-09	Ms. Brigette Bechtelar	ms.brigette.bechtelar@woohoo.com	Santa Clara	California	3096539400588962524	ec8e2fe461cacee699ef5f637406725b	Diners Club / Carte Blanche	37.3322793450955359	-121.962431035143879
2843	2019-09-09 05:09:17	2019-09-09	Carmelo Schimmel	carmelo.schimmel@geemail.com	Columbia	Missouri	4613398448414828	8e0c8c05806f3f837bf5cf3f38fc25ee	Maestro	39.0395509196792361	-92.4220816751063836
2844	2019-09-09 06:16:33	2019-09-09	Mckenna Ward DVM	mckenna.ward.dvm@geemail.com	Berkeley	California	6011562422037782519	307ad8444f4e9c9b574e3c357fbda7e3	VISA 16 digit	37.848438024884274	-122.279287336598088
2845	2019-09-09 07:58:50	2019-09-09	Miss Mindy Yundt	miss.mindy.yundt@geemail.com	Naperville	Illinois	4059764130379	01c4045190982e58ddf12d7ddafd941c	Voyager	41.8032220174938445	-88.2491088159270589
2846	2019-09-09 08:01:48	2019-09-09	Mrs. Roxie Flatley	mrs.roxie.flatley@geemail.com	Jacksonville	Florida	589386553571703	2da40d473c676ebab2cc983ebcd94c31	Voyager	30.2395206011418267	-81.666188527418683
2847	2019-09-09 08:41:41	2019-09-09	Dominik Windler	dominik.windler@geemail.com	Oakland	California	4159321596795004	eec075a83cc5db02df7a27ee5f87fef1	JCB 16 digit	37.8049206090380565	-122.293983046747925
2848	2019-09-09 09:27:18	2019-09-09	Casen Maggio Jr.	casen.maggio.jr.@geemail.com	Irving	Texas	53790663662660041	93ca207417755e6522aa2a1ed6f2ba96	Discover	32.9499722897492333	-97.0388695520162514
2849	2019-09-09 09:30:15	2019-09-09	Candi Rempel	candi.rempel@geemail.com	San Francisco	California	3096242910536366618	2aef8eb99e851c1cf0de9333ce81cd8d	Voyager	37.7768691744007725	-122.430111543612867
2850	2019-09-09 09:34:07	2019-09-09	Humphrey Rutherford	humphrey.rutherford@geemail.com	San Francisco	California	3337793382547942204	be47032354bb96befa3987624de3e836	Diners Club / Carte Blanche	37.7588151569917798	-122.424184711697905
2851	2019-09-09 10:18:08	2019-09-09	Belinda Herman-Franecki	belinda.herman.franecki@geemail.com	San Francisco	California	51141821914413769	bc9b44037e46e4148e89320abe8d2254	JCB 16 digit	37.7751082701944156	-122.426497414966505
2852	2019-09-09 13:46:04	2019-09-09	Guilford Bradtke I	guilford.bradtke.i@geemail.com	San Francisco	California	4298658080935949	e7f03781c13ae4c0db4889baaf60d14e	JCB 15 digit	37.7950420011749486	-122.399325345774386
2853	2019-09-09 15:31:18	2019-09-09	Morris Huel	morris.huel@geemail.com	Los Angeles	California	869902676051636657	5cedeca944675bec4c06d358599f0787	JCB 16 digit	33.9201151384372253	-118.402742117596034
2854	2019-09-09 16:04:35	2019-09-09	Paris Barrows-Dibbert	paris.barrows.dibbert@warmmail.com	Arlington	Texas	210006898656271849	d86999d7fbc8a1ac0c66e53b8f4bab0a	American Express	32.6621145451225345	-97.0689241379991188
2855	2019-09-09 17:20:15	2019-09-09	Eileen Tremblay-Kertzmann	eileen.tremblay.kertzmann@geemail.com	San Francisco	California	869921153721657247	bf1d91d05658e684ef6e6df8cf540e33	Discover	37.7405738255639918	-122.418397845507059
2856	2019-09-09 19:02:27	2019-09-09	Salvatore Hartmann	salvatore.hartmann@woohoo.com	Berkeley	California	52552058141689554	26912565fce4523dfc2d29dba2259e10	JCB 15 digit	37.874759897986614	-122.254440152768737
2857	2019-09-09 20:25:05	2019-09-09	Lish Kshlerin	lish.kshlerin@geemail.com	San Francisco	California	3036091947474584	665a02727be8078a5e433498d6ad91a8	Diners Club / Carte Blanche	37.7506338452991486	-122.448319118739533
2858	2019-09-09 20:32:48	2019-09-09	Gabriel Parisian	gabriel.parisian@geemail.com	Fort Collins	Colorado	3528668445999459431	fce5d07aa393d1487bb4cf2c4468ee5d	JCB 15 digit	40.5391430622588871	-105.133581184125703
2859	2019-09-09 20:40:49	2019-09-09	Donald O'Keefe	donald.o'keefe@geemail.com	San Francisco	California	3004909143610176	68133bfb9dd0b025fe1503a650ea1c13	Maestro	37.788913206260645	-122.452908905475581
2860	2019-09-09 22:28:31	2019-09-09	Durrell Ernser	durrell.ernser@geemail.com	Oakland	California	4439327341068268	dc1712f5c6fcf72a2615fe953b10ca49	VISA 16 digit	37.8045958836553382	-122.255592632420942
2861	2019-09-09 23:00:34	2019-09-09	Fonda Hermann	fonda.hermann@geemail.com	St. Petersburg	Florida	561283497164653	c3178fb1eea2b757ae1644c15e89ffa9	Voyager	27.7027917340751735	-82.5994233248647305
2862	2019-09-10 00:31:56	2019-09-10	Gaines Rutherford	gaines.rutherford@geemail.com	San Francisco	California	869970172477929014	3de5874e5128f1af8f09f716e70d5a66	JCB 15 digit	37.8064283839717561	-122.43416330681876
2863	2019-09-10 03:24:36	2019-09-10	Dr. Jensen Labadie	dr.jensen.labadie@woohoo.com	San Francisco	California	4850166495661	3c6ec5baf2ae3d7d06291290b873da8a	Voyager	37.7626236638980757	-122.437316277702422
2864	2019-09-10 03:39:19	2019-09-10	Ebbie Ward	ebbie.ward@warmmail.com	San Francisco	California	4318334603764861	c0fd7d31674c80de5199d54fc3b0f379	Discover	37.7115696091040888	-122.459699831681462
2865	2019-09-10 05:26:32	2019-09-10	Dax Leffler	dax.leffler@geemail.com	Miami	Florida	3705357490410015	7412d553caae29f3c16fbc632b264f5c	Discover	25.7273868087351332	-80.308286437146748
2866	2019-09-10 05:27:08	2019-09-10	Jacky Volkman	jacky.volkman@geemail.com	San Francisco	California	869911421244718958	29a3c97aa82653a2759edde3c58e0010	JCB 16 digit	37.760759228780131	-122.436617520818913
2867	2019-09-10 05:31:11	2019-09-10	Zariah Wolf-Shanahan	zariah.wolf.shanahan@geemail.com	San Francisco	California	55321512346011592	fd9e54c2f53781d5d5c2c79521f96180	Discover	37.7940691021393391	-122.410853429819227
2868	2019-09-10 05:38:45	2019-09-10	Mr. Mal Walter	mr.mal.walter@warmmail.com	Pittsburgh	Pennsylvania	6011881213388001615	3f5d91e029809df174249c66efaf759f	JCB 16 digit	40.3523343483407047	-79.902077724568926
2869	2019-09-10 06:29:24	2019-09-10	Refugio Lang Jr.	refugio.lang.jr.@geemail.com	San Francisco	California	3158133881281368194	c4228c607f14ab18e8ed2217456ad8e2	Discover	37.7643459917230615	-122.434573353672619
2870	2019-09-10 07:33:23	2019-09-10	Sariah Dach PhD	sariah.dach.phd@geemail.com	San Francisco	California	501851060718627	b9851c75bad2fe58c99457bd3f9b6391	JCB 15 digit	37.7885197288827044	-122.45355406281152
2871	2019-09-10 08:45:29	2019-09-10	Mr. Ashton Rodriguez DDS	mr.ashton.rodriguez.dds@geemail.com	Durham	North Carolina	3047775057794208	51764b6e8f7ce6b624cbc131b47358d8	VISA 16 digit	35.8856576751232126	-78.8311099994365208
2872	2019-09-10 10:22:14	2019-09-10	Patrice Lehner	patrice.lehner@warmmail.com	San Francisco	California	4232086744363	1b1367aef7bcc8b0855aa432c7f677b7	JCB 16 digit	37.7679830391236422	-122.439895840399032
2873	2019-09-10 13:37:02	2019-09-10	Zavion Steuber	zavion.steuber@geemail.com	San Francisco	California	3003116434433489	ea143a83b499f5fe539db4eb711bbce2	Maestro	37.7859986638691652	-122.43539000595672
2874	2019-09-10 15:12:26	2019-09-10	Messiah Leffler	messiah.leffler@geemail.com	San Francisco	California	3031129159736103	3160aab26bbb0e988072c7f5e66b593c	VISA 13 digit	37.7727624194605127	-122.407259097501466
2875	2019-09-10 16:20:34	2019-09-10	Noretta Douglas	noretta.douglas@geemail.com	San Francisco	California	3112079348549962552	541fc95507a200592f97aa3f021dada0	VISA 16 digit	37.7383740616131291	-122.433838713554067
2876	2019-09-10 16:24:40	2019-09-10	Dr. Emmit Luettgen	dr.emmit.luettgen@geemail.com	Garden Grove	California	676360151297276	3d6bcf181f2bf97d9c6e2af5ec13b581	JCB 16 digit	33.7811468802683024	-118.041272818531837
2877	2019-09-10 17:37:24	2019-09-10	Sherita Renner	sherita.renner@geemail.com	Round Rock	Texas	3337117532228527125	ea454211a02198ab1cae48accd913662	JCB 15 digit	30.6041264315273622	-97.7156027121320392
2878	2019-09-10 17:49:22	2019-09-10	Matthew Homenick MD	matthew.homenick.md@geemail.com	Las Vegas	Nevada	4891256449739390	1afb94e8b322af67f37e7fffff9fd959	Discover	36.1538077168267193	-115.334504912907619
2879	2019-09-10 18:46:05	2019-09-10	Robbin Leuschke	robbin.leuschke@warmmail.com	New York	New York	52520080443971075	159d3ed6bf78c37cd1067526b44cf6a0	JCB 16 digit	40.6870308216419048	-73.9231843262340789
2880	2019-09-10 20:17:58	2019-09-10	Mrs. Elinore Stamm PhD	mrs.elinore.stamm.phd@warmmail.com	Oakland	California	3039903560414027	f3a7820af61d21278160da59b74443f2	VISA 16 digit	37.8294137552630474	-122.23976357527259
2881	2019-09-10 20:45:03	2019-09-10	Kimberli Mayert DVM	kimberli.mayert.dvm@geemail.com	San Francisco	California	55778722952965050	60d9a685fd7506fc133f8bf49493feb3	JCB 16 digit	37.7643951519321064	-122.41627735386183
2882	2019-09-10 21:57:33	2019-09-10	Alexander Romaguera Jr.	alexander.romaguera.jr.@geemail.com	Los Angeles	California	3096066226519600813	df326af19a8619d9ada199a5206b1936	American Express	33.9786966653872256	-118.420248581794269
2883	2019-09-10 22:34:51	2019-09-10	Blanch Gerlach-Marquardt	blanch.gerlach.marquardt@geemail.com	San Francisco	California	6011050326881998320	4301b125e7852bba654a0a1428e3679e	JCB 16 digit	37.7737259611553355	-122.436618652075552
2884	2019-09-10 23:00:14	2019-09-10	Kamryn Johns	kamryn.johns@geemail.com	Long Beach	California	51761617136393576	fbededad9a2277da96d60339a9c751fa	Mastercard	33.8137454472769008	-118.209173004810879
2885	2019-09-10 23:06:55	2019-09-10	Odus Romaguera	odus.romaguera@warmmail.com	Fort Wayne	Indiana	3158816701479841006	b379c7942086511afde7015685285599	VISA 16 digit	41.1235486308828015	-85.1316361941617004
2886	2019-09-11 00:39:17	2019-09-11	Mr. Konner Lynch	mr.konner.lynch@geemail.com	San Francisco	California	3004837269357050	c6b07ae1d9dba610d1217b59f91d2edc	VISA 16 digit	37.7609263861732103	-122.412665257667683
2887	2019-09-11 01:54:03	2019-09-11	Tera Dach	tera.dach@geemail.com	Chicago	Illinois	4350766777048044	c2328c1d295728882f1106de787800a8	American Express	41.7530842222109442	-87.7081673174660637
2888	2019-09-11 03:03:27	2019-09-11	Dr. Waylon Schiller	dr.waylon.schiller@geemail.com	Madison	Wisconsin	869918132001183954	242a082b81f874c37fc7b406a964a995	JCB 16 digit	43.0058288579780594	-89.3698786574766046
2889	2019-09-11 03:25:37	2019-09-11	Deante Koepp	deante.koepp@geemail.com	San Francisco	California	6011853829178431086	d1d87ef9191e847b9b6a2f90515e30fa	Voyager	37.7743588648699031	-122.409307559472779
2890	2019-09-11 04:25:51	2019-09-11	Mr. Derek Barton	mr.derek.barton@geemail.com	San Francisco	California	4167715153513	faaabdecb7d53a96bdf2a6480d6457c8	JCB 16 digit	37.7863864490043042	-122.470285873300213
2891	2019-09-11 04:27:37	2019-09-11	Staci Dooley	staci.dooley@geemail.com	Oakland	California	52568351769807539	df1789cb6cf601cc70ab6bb6cce7835b	VISA 16 digit	37.7766203173597219	-122.267538449914596
2892	2019-09-11 07:07:30	2019-09-11	Gene Gaylord	gene.gaylord@geemail.com	San Francisco	California	6011558339177631031	79e1d71a843f1508b248f2bc2634ff83	Maestro	37.765657612465283	-122.446122724896824
2893	2019-09-11 07:37:15	2019-09-11	Sherry Mante-Marvin	sherry.mante.marvin@warmmail.com	Tallahassee	Florida	3112293144263106512	0d057389eaba9154d6d113c33ddec340	JCB 16 digit	30.4270035137910426	-84.3419076958220444
2894	2019-09-11 09:23:32	2019-09-11	Mia Kuhlman PhD	mia.kuhlman.phd@geemail.com	San Francisco	California	4259709752150	3e9dc55e7db5558e3775d6d4828ba792	Maestro	37.7422820132186629	-122.431705470246584
2895	2019-09-11 09:48:23	2019-09-11	Nana Leannon	nana.leannon@geemail.com	Austin	Texas	53214950355961994	679dbdb50ab82ebe174cf361f0393290	JCB 16 digit	30.2689810088962297	-97.6756875572033323
2896	2019-09-11 12:38:47	2019-09-11	Mr. Mike Volkman II	mr.mike.volkman.ii@woohoo.com	Oakland	California	675918213577010	c2346f36dd0407f48758c701433e37b0	Voyager	37.7751469467210086	-122.277122586534446
2897	2019-09-11 13:23:05	2019-09-11	Kimberlee Greenholt	kimberlee.greenholt@warmmail.com	San Francisco	California	6011142301442930344	edbbcb4355715c695d41c92326105a4a	JCB 16 digit	37.7783397537725989	-122.38127683671506
2898	2019-09-11 15:24:11	2019-09-11	Mr. Cleve Donnelly III	mr.cleve.donnelly.iii@geemail.com	Berkeley	California	3030750189869761	b29b0a3cfc66eb68949d07f6f8f5675f	JCB 16 digit	37.8614315510136095	-122.230884914062969
2899	2019-09-11 17:52:49	2019-09-11	Lakisha Herman DVM	lakisha.herman.dvm@geemail.com	Cary	North Carolina	52109987936180098	c108d0d7b98a0c5ffee678b00413fc35	VISA 13 digit	35.8534250918883828	-78.721239810212694
2900	2019-09-11 18:55:43	2019-09-11	Ezzard Willms	ezzard.willms@woohoo.com	Los Angeles	California	3001258110412031	1a606e9cb9e0fb3bafe46595e111c3ef	Discover	33.9875539384648206	-118.48075956697501
2901	2019-09-11 19:52:57	2019-09-11	Efrain Paucek	efrain.paucek@woohoo.com	San Francisco	California	3088281182611376399	ea3c7ad334e956718cd887f9f1030572	American Express	37.8084855795930608	-122.43240595777624
2902	2019-09-11 19:56:21	2019-09-11	Ms. Payten Stracke PhD	ms.payten.stracke.phd@geemail.com	San Francisco	California	4773766388335557	7f6603db576f1456ac288524d669eedc	Diners Club / Carte Blanche	37.8012278229029306	-122.437348581259926
2903	2019-09-11 20:04:50	2019-09-11	Lorene Ankunding-Gusikowski	lorene.ankunding.gusikowski@geemail.com	Berkeley	California	4366612615064730	30209601285cfc0b8fd736c9594e9dc7	JCB 16 digit	37.8988139427764494	-122.300947787091445
2904	2019-09-11 20:20:51	2019-09-11	Tera Franecki-Senger	tera.franecki.senger@woohoo.com	Berkeley	California	4193537622790	64a37cb75a2ba4ff575642add5bfc642	JCB 16 digit	37.834464622182189	-122.285290604209024
2905	2019-09-11 21:06:06	2019-09-11	Ahmad Little	ahmad.little@geemail.com	Baltimore	Maryland	869997257279379945	c7f49ba2b56c62a6a6862b61e96d9935	Discover	39.2826466812752173	-76.6030235543865672
2906	2019-09-11 21:24:28	2019-09-11	Beatrice Ratke-Herman	beatrice.ratke.herman@geemail.com	El Cajon	California	6011764027467124623	dbeb349e2551e36aaac1f3b138ab855e	JCB 16 digit	32.7720454942442458	-116.875759382051982
2907	2019-09-11 21:26:30	2019-09-11	Taja Monahan	taja.monahan@warmmail.com	Oakland	California	3096495533073489306	a267ca5d87c93bd7ad64880dd8fc1349	JCB 16 digit	37.7944761473392106	-122.278422129016491
2908	2019-09-11 21:54:44	2019-09-11	Jabbar Yost	jabbar.yost@geemail.com	Worcester	Massachusetts	675958076254190	494cc5142def49cecd2fc5d0b579ddf3	JCB 15 digit	42.2969616491515197	-71.754859812070805
2909	2019-09-11 23:03:22	2019-09-11	Verona Bergnaum	verona.bergnaum@geemail.com	Miami	Florida	3158397957326807569	b445c3f5459053f39b84a1fddb0580e2	VISA 13 digit	25.8117735437255362	-80.246329092966775
2910	2019-09-11 23:46:33	2019-09-11	Jethro Lang DDS	jethro.lang.dds@geemail.com	Las Vegas	Nevada	3158357960015314481	19ce79eb84ccf1d1ac77c1fadf55d993	American Express	36.2108726543009283	-115.343770022478324
2911	2019-09-12 00:32:50	2019-09-12	Salomon Terry	salomon.terry@geemail.com	Berkeley	California	4633572222253323	952ed7c5b5e1e4d14eaac71bc0ab53bc	Discover	37.8906606049049586	-122.264774115761114
2912	2019-09-12 02:12:55	2019-09-12	Washington Armstrong	washington.armstrong@geemail.com	San Francisco	California	3046440211867397	0b50d2bfe6ca9dd76ebcd1e325f0cf74	JCB 16 digit	37.7648264926272077	-122.421839258985941
2913	2019-09-12 02:27:19	2019-09-12	Cliff Hilpert-Vandervort	cliff.hilpert.vandervort@geemail.com	Fort Worth	Texas	3337408385856774099	7f772450c58e872896ba6d90fde77f41	VISA 16 digit	32.7820954926833537	-97.4285606705870464
2914	2019-09-12 03:39:00	2019-09-12	Jenniffer Medhurst	jenniffer.medhurst@geemail.com	San Francisco	California	4428187001683	f6cbc6dc39e36227be9581e9dbbc84e1	Discover	37.7683399348901077	-122.414201239053611
2915	2019-09-12 03:55:52	2019-09-12	Dr. Halie Hilll	dr.halie.hilll@woohoo.com	New York	New York	3337216377670185166	99ed118b0e08f315ef073b213b61cea9	Diners Club / Carte Blanche	40.6160282780174171	-73.9806220956508014
2916	2019-09-12 06:13:33	2019-09-12	Ned Jenkins-Jones	ned.jenkins.jones@geemail.com	San Francisco	California	210056189095445486	cf8dd495897f4576b63a7b73fcd15685	American Express	37.7598850596097861	-122.423675052388759
2917	2019-09-12 06:36:33	2019-09-12	Rahsaan Wyman	rahsaan.wyman@geemail.com	Oakland	California	52133659119520636	e86233c617c1b45f3d3a647c6f05574f	Discover	37.802656748785715	-122.263800841280883
2918	2019-09-12 06:56:32	2019-09-12	Dameon Rutherford	dameon.rutherford@woohoo.com	San Francisco	California	6011688234554777312	49dd2247cd507ee00844520f37754baf	JCB 15 digit	37.7778751095373266	-122.412143656032228
2919	2019-09-12 09:09:20	2019-09-12	Atha Larson	atha.larson@geemail.com	Arlington	Texas	869940064921921506	4fca6186c99f1c52b1501b572487360c	Maestro	32.603553835700076	-97.079029746961595
2920	2019-09-12 10:04:39	2019-09-12	Shawn Romaguera	shawn.romaguera@woohoo.com	San Francisco	California	6011371413610939767	a91d094541b53aff1069c1629eeaed5a	VISA 13 digit	37.7684621857167357	-122.451810789832265
2921	2019-09-12 10:38:15	2019-09-12	Clarnce Stehr-Ziemann	clarnce.stehr.ziemann@geemail.com	San Francisco	California	4537172421738	535adba9bcbd3d743edf03c29e44e7d6	VISA 16 digit	37.7838123168753981	-122.437378677531157
2922	2019-09-12 11:08:41	2019-09-12	Dr. Merna Willms MD	dr.merna.willms.md@geemail.com	San Francisco	California	869916386278835850	3f8ac50569806f9b967a879c3501b75f	Discover	37.7773990090557277	-122.409415592234708
2923	2019-09-12 12:42:35	2019-09-12	Dr. Wing Vandervort PhD	dr.wing.vandervort.phd@geemail.com	Nashville	Tennessee	3042164806811156	915a452cfd995b044b5f23a419b356a3	VISA 16 digit	36.1235170167993758	-86.7708071737922637
2924	2019-09-12 13:08:25	2019-09-12	Arlen Zemlak	arlen.zemlak@geemail.com	Mesa	Arizona	6011403109069139329	882fa34d49e903e580521a57f18e5d27	American Express	33.4879031239688345	-111.70696425082869
2925	2019-09-12 15:48:17	2019-09-12	Lina Predovic PhD	lina.predovic.phd@geemail.com	Providence	Rhode Island	6011327780297581913	5a93c7e4cf1d477d951c2a12ad6e76ff	JCB 15 digit	41.7766538624040749	-71.5146733122795837
2926	2019-09-12 17:45:12	2019-09-12	Tavares Cruickshank	tavares.cruickshank@warmmail.com	San Francisco	California	4319272862149	4d51b8e5c3ab8f1e67349bbc16291250	American Express	37.7378909343467939	-122.452111702058986
2927	2019-09-12 18:06:38	2019-09-12	Willene McGlynn	willene.mcglynn@warmmail.com	San Diego	California	180024221921494674	2e8606e4895f4f5c575e5994ded5468d	JCB 16 digit	32.7674689015906324	-117.164392901621767
2928	2019-09-12 20:05:05	2019-09-12	Mr. Knute Botsford	mr.knute.botsford@geemail.com	Berkeley	California	3453117331560001	eda6bfd7e1acde43add1b17ee580d123	JCB 15 digit	37.8910328988301828	-122.265941362173649
2929	2019-09-12 20:08:00	2019-09-12	Miss Lavera Kunze	miss.lavera.kunze@warmmail.com	New York	New York	4202289358345	d4abe7fbcc582710563e28de0c44f92b	Voyager	40.6224512904640278	-73.8717461480189144
2930	2019-09-12 20:25:08	2019-09-12	Clark Hessel-Dach	clark.hessel.dach@woohoo.com	San Francisco	California	3096542406751386297	129f298e9840fe55221a33a4ec9cf1d4	VISA 13 digit	37.7599251782226943	-122.438914680961474
2931	2019-09-12 22:20:55	2019-09-12	Adriene Bergnaum	adriene.bergnaum@geemail.com	Los Angeles	California	3112757386683683492	b5ea9bfd8bb3cd3f55b74f45bf5d4e0f	American Express	34.0306217772752007	-118.442246634698648
2932	2019-09-12 23:08:55	2019-09-12	Ashli Kemmer	ashli.kemmer@geemail.com	San Francisco	California	3528654255483984943	2879ded93555eb52c2c014409a1c7bbf	VISA 16 digit	37.7472436558956304	-122.428301446926028
2933	2019-09-13 00:20:11	2019-09-13	Elouise Rogahn	elouise.rogahn@geemail.com	San Francisco	California	3528132833613431266	5a88d9474b7491a382db103583646ee7	JCB 16 digit	37.7859817339009751	-122.45009121499497
2934	2019-09-13 00:26:43	2019-09-13	Celina Hartmann	celina.hartmann@woohoo.com	Raleigh	North Carolina	3528507651207935238	141a7d1f4e172b85ab0727e29e367115	VISA 13 digit	35.9132567722018763	-78.7229308380216395
2935	2019-09-13 01:58:09	2019-09-13	Darleen Kuhlman	darleen.kuhlman@geemail.com	San Francisco	California	3036753791370321	a65d135dc57d6085ca9eba41994f6f99	Mastercard	37.7742518461446082	-122.449461536822625
2936	2019-09-13 02:59:40	2019-09-13	Anice Bogisich	anice.bogisich@woohoo.com	Winston–Salem	North Carolina	3112490402512744538	4bdfd07ab8ae4f189036c6894b4a0f36	JCB 15 digit	36.036419995245339	-80.2768987571485297
2937	2019-09-13 03:43:22	2019-09-13	Lillia Rohan PhD	lillia.rohan.phd@woohoo.com	Oakland	California	4588228379388	c12d5a36f9daa1ada66994b0f46e7fcd	Diners Club / Carte Blanche	37.8052167446632055	-122.265889365336903
2938	2019-09-13 04:15:36	2019-09-13	Tolbert Spinka	tolbert.spinka@geemail.com	San Francisco	California	3158087333901303827	fbc70d67d173b6e375d14a767761d673	JCB 16 digit	37.8096166101543005	-122.432059002930529
2939	2019-09-13 04:18:02	2019-09-13	Dr. Mia Zulauf DVM	dr.mia.zulauf.dvm@geemail.com	San Angelo	Texas	55434959680630947	996d67a24c2cc9306ff01abe10e09bb1	JCB 16 digit	31.367004136849566	-100.510305481275552
2940	2019-09-13 06:47:05	2019-09-13	Fernando Ruecker	fernando.ruecker@woohoo.com	Philadelphia	Pennsylvania	52545323997152812	91113fac3593ce77205ececd5a1923b8	American Express	39.9598674852360034	-75.1366590482082302
2941	2019-09-13 07:53:09	2019-09-13	Ell Halvorson	ell.halvorson@warmmail.com	Berkeley	California	3528125131333738493	f6d85fb6c7610dc9043f5c7ab7dfa1f5	Voyager	37.8513872859684781	-122.2680465881012
2942	2019-09-13 09:01:12	2019-09-13	Hallie O'Connell	hallie.o'connell@warmmail.com	Los Angeles	California	4378530808954507	fa78764d0560334d429c5c969ec35de5	Diners Club / Carte Blanche	34.0743952895380531	-118.488342179590092
2943	2019-09-13 09:48:06	2019-09-13	Wallace Johns I	wallace.johns.i@geemail.com	Oakland	California	210066904215026216	6980cac71e777a34fc8a39f289ee30d2	Voyager	37.8110449535076043	-122.265657481267951
2944	2019-09-13 09:59:37	2019-09-13	Durrell Haag	durrell.haag@geemail.com	San Francisco	California	6011392624931287539	b352b9d3cdcdc9214e893bbb52d545f0	American Express	37.7489498845147153	-122.430223563520926
2945	2019-09-13 11:02:43	2019-09-13	Jennie West-Schneider	jennie.west.schneider@woohoo.com	Salt Lake City	Utah	3730215210876494	9760042c55c47c37e1c42c04c61570dc	Maestro	40.743009316190701	-111.930307116353887
2946	2019-09-13 11:11:03	2019-09-13	Arley Huel DVM	arley.huel.dvm@warmmail.com	San Francisco	California	3112422155114850664	0751d55ddc9005d2e6d8e51b355630fa	Discover	37.771817078591873	-122.423897535652017
2947	2019-09-13 11:19:24	2019-09-13	Erlene Cormier	erlene.cormier@geemail.com	San Francisco	California	4151938953671011	4243ecca3b0b32fb6040372db714e513	JCB 16 digit	37.8038981803978373	-122.438581531127696
2948	2019-09-13 13:13:30	2019-09-13	Dr. Ebert Schamberger PhD	dr.ebert.schamberger.phd@geemail.com	Austin	Texas	4248097543479	8afedc25ab9086ea6eca6682643f81c7	JCB 16 digit	30.2244884208437057	-97.7840851546969247
2949	2019-09-13 15:47:46	2019-09-13	Carey Bruen-Pfeffer	carey.bruen.pfeffer@geemail.com	Chicago	Illinois	3007066467361618	bca4a5f40aa3c4321290bd0194e2a442	VISA 13 digit	41.9014201388064791	-87.7398437459051621
2950	2019-09-13 15:49:17	2019-09-13	Dot Wilkinson	dot.wilkinson@geemail.com	Oakland	California	4369640213996	f77b956da747a1c0b4df177461b9b108	Mastercard	37.8305581272931946	-122.252074248469569
2951	2019-09-13 15:55:42	2019-09-13	Donat Smith	donat.smith@geemail.com	Birmingham	Alabama	4763511190129	9ac3db13a0bfd17836813883d96416c8	JCB 16 digit	33.5037271144591244	-86.7219844871442831
2952	2019-09-13 16:10:21	2019-09-13	Janiah Schaden	janiah.schaden@geemail.com	Memphis	Tennessee	4915825224087787	46824e2f6847b7e951f11279e77d532e	American Express	35.0140820853013537	-90.0628763453826338
2953	2019-09-13 16:46:31	2019-09-13	Delbert Wyman	delbert.wyman@geemail.com	San Francisco	California	6011701315488271283	d9f004cdeee154c286b857d2e3942691	Diners Club / Carte Blanche	37.7633274349908419	-122.414644465123402
2954	2019-09-13 17:26:36	2019-09-13	Mrs. Siena Ledner PhD	mrs.siena.ledner.phd@geemail.com	San Francisco	California	180065894638564391	ecf986bac405bac0ede0638eedaf4ad1	JCB 16 digit	37.7376381497201905	-122.456708385978402
2955	2019-09-13 18:15:15	2019-09-13	Myla Hyatt	myla.hyatt@geemail.com	Arlington	Texas	3020976831716239	09f52bc19345ac06caef0c003eeef07d	Mastercard	32.6259623744774601	-97.0943359475608929
2956	2019-09-13 18:53:05	2019-09-13	Ms. Eldora Bayer	ms.eldora.bayer@geemail.com	Berkeley	California	869907228282815547	1cb993c2ab66259f5b354cbc97301c6a	JCB 16 digit	37.8661492178660026	-122.254038616640372
2957	2019-09-13 21:16:15	2019-09-13	Darryl Hoppe	darryl.hoppe@geemail.com	San Francisco	California	54885292133240104	dce4ad3eabb841cb3f919d432fa0445c	Discover	37.7640394289343817	-122.422850606898834
2958	2019-09-13 22:23:36	2019-09-13	Mr. Aydan Jacobi II	mr.aydan.jacobi.ii@warmmail.com	San Francisco	California	3426813021439654	655de426364f2c5df2c7c7bdf6179153	VISA 13 digit	37.7914866341144133	-122.402791879735844
2959	2019-09-13 23:43:13	2019-09-13	Durwood Reichel-Treutel	durwood.reichel.treutel@geemail.com	San Francisco	California	869936218689957914	f72c53c1537cc7527d7ad6e82bdaa0c8	Diners Club / Carte Blanche	37.8048744957569127	-122.457014611745436
2960	2019-09-13 23:50:59	2019-09-13	Dr. Pairlee Casper PhD	dr.pairlee.casper.phd@geemail.com	Oakland	California	4210111099205123	e087174b0fe4a768e57471b250c0e582	Diners Club / Carte Blanche	37.7989373497212924	-122.26497986001668
2961	2019-09-14 01:07:59	2019-09-14	Rowan Bayer	rowan.bayer@geemail.com	San Francisco	California	060419689037984	3a1116316ebfd49092b6e911659e71f9	JCB 16 digit	37.7548049707026507	-122.43481364929994
2962	2019-09-14 01:37:56	2019-09-14	Clemence Hickle	clemence.hickle@warmmail.com	San Francisco	California	3784125561436696	e913373c4c307f68e2a5505dac090a80	VISA 16 digit	37.7670101134157008	-122.44394701809766
2963	2019-09-14 02:02:37	2019-09-14	Jim McLaughlin-Paucek	jim.mclaughlin.paucek@geemail.com	San Francisco	California	3112213514625633493	b832942cd3d3428bda96176ae57dd914	JCB 16 digit	37.7583970186463418	-122.447165141762525
2964	2019-09-14 02:41:12	2019-09-14	Layla Schulist DDS	layla.schulist.dds@geemail.com	San Francisco	California	3418338059830962	38d5a39540e3f352c94ff507b331c9e5	JCB 16 digit	37.7466462211834752	-122.428133291691083
2965	2019-09-14 02:46:56	2019-09-14	Mr. Juelz Rosenbaum	mr.juelz.rosenbaum@geemail.com	Omaha	Nebraska	210057726684978028	701436892b3458f08e418b2407821a42	VISA 16 digit	41.2538811250735122	-95.979629333654799
2966	2019-09-14 04:52:07	2019-09-14	Dr. Sanford Zieme I	dr.sanford.zieme.i@geemail.com	San Francisco	California	3453379826919767	32898e886f5630aa6000be350d34be1e	JCB 16 digit	37.7843587120787703	-122.425499978619968
2967	2019-09-14 04:55:25	2019-09-14	Mr. Wirt Schroeder MD	mr.wirt.schroeder.md@geemail.com	San Francisco	California	6011341426906565747	45a1e6adfcf2f5e764872533c50618c0	JCB 16 digit	37.768736657532024	-122.43805982758181
2968	2019-09-14 05:34:42	2019-09-14	Letta Donnelly	letta.donnelly@geemail.com	San Francisco	California	6011177314840880811	c6f5d94b7c21c1efdffe8492aaacf6e1	JCB 16 digit	37.7694151822654263	-122.404663558622062
2969	2019-09-14 06:40:16	2019-09-14	Jody Denesik	jody.denesik@geemail.com	San Francisco	California	6011045009259778957	47197ffb0fb48c4e41ae789455820139	JCB 16 digit	37.7758964434499873	-122.43263999091586
2970	2019-09-14 07:13:49	2019-09-14	Gusta Romaguera	gusta.romaguera@warmmail.com	New York	New York	4418854260681099	4c49b70a177b274abeffa0199505828f	Discover	40.7293550323918438	-74.0365758458513739
2971	2019-09-14 13:32:39	2019-09-14	Shelva Lemke	shelva.lemke@geemail.com	San Francisco	California	3459954439271956	b7c07cafc878a42a92e86d0bad3be0ec	Maestro	37.7777494286561009	-122.389676824107099
2972	2019-09-14 14:13:37	2019-09-14	Lexie Gusikowski	lexie.gusikowski@geemail.com	San Francisco	California	4630531563766403	46841f772482f066e0671557761ac5fa	VISA 16 digit	37.7405251038694018	-122.446044366325154
2973	2019-09-14 14:38:07	2019-09-14	Leticia Schroeder	leticia.schroeder@geemail.com	San Francisco	California	3088844875369248120	67b6b3ff5a42557ec8a1c26f47afa22c	JCB 15 digit	37.8035316855930859	-122.457225565472228
2974	2019-09-14 14:56:49	2019-09-14	Dr. Anfernee Blanda MD	dr.anfernee.blanda.md@geemail.com	Chicago	Illinois	060416706577513	033e8170230bd6ff350277e5ddf3a6f2	Discover	41.821868772229557	-87.6494852000877245
2975	2019-09-14 15:27:00	2019-09-14	Tempie Mann	tempie.mann@geemail.com	Los Angeles	California	4290035930179903	62dcbdc8847095f7604c4be3ac9237bd	Diners Club / Carte Blanche	34.0401506697624896	-118.418978528258577
2976	2019-09-14 15:27:09	2019-09-14	Kent Bernhard PhD	kent.bernhard.phd@geemail.com	Albuquerque	New Mexico	3017011234742260	5e4dbd96ecffa54f8aa7924525f536e3	Mastercard	35.1687073364987981	-106.615676569433518
2977	2019-09-14 16:45:06	2019-09-14	Dr. Durwood Rohan	dr.durwood.rohan@woohoo.com	Oakland	California	3741532339741392	9f681b00952d1f085c5816f8f16a051f	JCB 16 digit	37.8301446044611325	-122.254782775026229
2978	2019-09-14 17:00:16	2019-09-14	Paxton O'Hara	paxton.o'hara@geemail.com	Houston	Texas	3056505115608251	0cddf179867e4733542a89a46559309a	VISA 13 digit	29.7513354150190956	-95.3752218227848374
2979	2019-09-14 18:39:30	2019-09-14	Enos Windler DVM	enos.windler.dvm@woohoo.com	Amarillo	Texas	3764206421927951	f114c001b5350446bf3cc21fb37ff95a	Discover	35.1320646248921733	-101.796998283625399
2980	2019-09-14 18:54:38	2019-09-14	Betsey Hirthe	betsey.hirthe@geemail.com	San Francisco	California	501881248046120	3c3f5c5fe68f6828ea28ea81ac5e2c78	Mastercard	37.7604641633132232	-122.421485428477425
2981	2019-09-14 20:47:50	2019-09-14	Magdalena Hettinger	magdalena.hettinger@geemail.com	San Francisco	California	180001744986107359	6aa8f178792b57260d77bdc81653f27c	VISA 16 digit	37.7697160979614281	-122.382913284149922
2982	2019-09-14 21:18:08	2019-09-14	Will Weissnat	will.weissnat@geemail.com	Memphis	Tennessee	4035380058962	5d22ff44ea5b16831601a734c162da08	VISA 13 digit	35.1033137827713091	-90.0289048423781963
2983	2019-09-14 22:07:42	2019-09-14	Fidencio Ullrich	fidencio.ullrich@geemail.com	San Francisco	California	3462027349260644	a1032b93f0b7d7b0cb2a2d6ea0c25df9	Diners Club / Carte Blanche	37.7482009448651752	-122.439454509160711
2984	2019-09-14 22:27:04	2019-09-14	Charlsie Christiansen	charlsie.christiansen@warmmail.com	Chicago	Illinois	180068309782036853	ad8c44770c84ce99e76455e70e25c2e1	Mastercard	41.849536812102798	-87.5819720514614062
2985	2019-09-14 22:59:09	2019-09-14	Gifford Breitenberg	gifford.breitenberg@warmmail.com	Berkeley	California	3112684192354066068	7f96b639088c0621f1e9686faa22e762	VISA 13 digit	37.8853549271662544	-122.254980177527131
2986	2019-09-14 23:39:47	2019-09-14	Lotta Funk	lotta.funk@geemail.com	San Francisco	California	51235444689339254	f86d0ab5d26250e500ba59942979f13d	Mastercard	37.7585783253888962	-122.451442905205681
2987	2019-09-15 00:10:46	2019-09-15	Dr. Tilden Bahringer Sr.	dr.tilden.bahringer.sr.@geemail.com	Vacaville	California	3096200225631881480	36984a3fd495bedb069fbdaa1ac1ce5a	VISA 16 digit	38.3504193353593408	-122.056980112788466
2988	2019-09-15 02:03:52	2019-09-15	Demetria Brakus	demetria.brakus@geemail.com	New York	New York	3337879497707331837	15c7041c2436335979e5836a8ad50f4b	JCB 16 digit	40.6990366137344353	-74.0097386392660468
2989	2019-09-15 02:07:11	2019-09-15	Mrs. Aubree Kautzer	mrs.aubree.kautzer@geemail.com	San Francisco	California	4672122479766700	d26b32ef10a84abca5930c2f4c44569e	JCB 16 digit	37.7999404231526412	-122.419844747327375
2990	2019-09-15 02:57:49	2019-09-15	Mrs. Adina Lynch PhD	mrs.adina.lynch.phd@geemail.com	San Francisco	California	4917506171505686	774138af1e3907fb524a1ff22d032a5d	Maestro	37.7600516114247213	-122.454199374898948
2991	2019-09-15 03:59:59	2019-09-15	Margarito Stamm-Hayes	margarito.stamm.hayes@woohoo.com	Dallas	Texas	3096712230751470412	1f70856270a0de585b32f963aae7f739	Maestro	32.8414834875419785	-96.7258953523319178
2992	2019-09-15 04:16:20	2019-09-15	Myles Renner	myles.renner@warmmail.com	San Francisco	California	6011183150644305304	4ff912e19e463a7a429ba5b8b5127ad7	JCB 16 digit	37.7919785681100961	-122.437548525977789
2993	2019-09-15 04:49:39	2019-09-15	Mrs. Edla Klein DDS	mrs.edla.klein.dds@geemail.com	San Francisco	California	4599038914728727	50f59c1efb747097dc904c85619f7df4	VISA 16 digit	37.7801086789399747	-122.441157104479842
2994	2019-09-15 04:50:10	2019-09-15	Tessa Walker-Wilkinson	tessa.walker.wilkinson@warmmail.com	Los Angeles	California	869910889644318663	8e77ffdd9395ee415994ab090d636563	Maestro	34.0689074941776653	-118.382665394478664
2995	2019-09-15 05:24:44	2019-09-15	Rayford Reinger	rayford.reinger@geemail.com	Hayward	California	3033328788480848	03727c9fa73f497a3f2188b23837a587	Mastercard	37.5901104800857624	-122.196211977794391
2996	2019-09-15 05:37:54	2019-09-15	Lloyd Bernhard	lloyd.bernhard@geemail.com	San Francisco	California	52655197976132201	9ec9670428752e58ed83f8c198389c60	VISA 16 digit	37.7823458348797985	-122.453354262523021
2997	2019-09-15 05:56:26	2019-09-15	Berniece Kessler	berniece.kessler@geemail.com	Chicago	Illinois	6011510544786323048	96d97ae63072c10f4e04a9cb634b6e10	JCB 15 digit	41.7484456235844661	-87.6958297962352589
2998	2019-09-15 07:02:42	2019-09-15	Baxter Jacobi	baxter.jacobi@warmmail.com	Anchorage	Alaska	502077720665668	b3d045ad95dbc0350d3422d71c3846d1	Mastercard	61.1881395446352698	-149.347169204813611
2999	2019-09-15 07:41:34	2019-09-15	Mr. Greene Smith	mr.greene.smith@woohoo.com	New York	New York	639073299722873	df1d2c7b88a4af9ab5b83a5a74ce8bee	Maestro	40.5961126079540691	-73.9395452812209726
3000	2019-09-15 08:42:06	2019-09-15	Shayna O'Keefe	shayna.o'keefe@geemail.com	Berkeley	California	4313678652175147	275d81e8e1715c737cd7b5eecd17d70a	VISA 16 digit	37.8941565739590231	-122.272733262014512
3001	2019-09-15 10:01:27	2019-09-15	Candice Schiller	candice.schiller@warmmail.com	Oakland	California	6011455732760324796	a3e5497daca5da90aceff0abc675da64	JCB 15 digit	37.8525105603250651	-122.265952763860454
3002	2019-09-15 11:21:24	2019-09-15	Dr. Brigitte Green	dr.brigitte.green@geemail.com	Berkeley	California	4861523109461706	265682cea72e1fd3dcfd68cfb05e6997	Mastercard	37.8982486546099651	-122.242735706216649
3003	2019-09-15 11:22:42	2019-09-15	Dozier Roob DDS	dozier.roob.dds@geemail.com	Berkeley	California	4954005347745247	1fe550493fab6c143e58ba6a1f5e42de	Diners Club / Carte Blanche	37.8851913038122845	-122.231841650320504
3004	2019-09-15 12:05:39	2019-09-15	Elzie Howell-Langosh	elzie.howell.langosh@woohoo.com	Jacksonville	Florida	869975634213113299	0ac51fed85d085b4316df6f163613aaf	JCB 15 digit	30.4048888054728508	-81.6534675820808928
3005	2019-09-15 12:52:35	2019-09-15	Sallie Leannon	sallie.leannon@geemail.com	San Francisco	California	3096841152641663820	285ae3a4979f1deb97fdb55b979066d0	VISA 16 digit	37.7832094755944325	-122.421382268375325
3006	2019-09-15 13:17:40	2019-09-15	Mr. Erle Bradtke	mr.erle.bradtke@geemail.com	Naperville	Illinois	3414892143271934	08d6dd21939f1158788f5cc45f55a6f5	Mastercard	41.6562264830719684	-88.108715618111205
3007	2019-09-15 14:44:24	2019-09-15	Leif Brown	leif.brown@geemail.com	San Francisco	California	210028728669242491	cbdf82d3b520304a4a1d6d8376af575d	Mastercard	37.7486222394386388	-122.421823484780234
3008	2019-09-15 16:16:23	2019-09-15	Narcissus Simonis	narcissus.simonis@geemail.com	Topeka	Kansas	6011643270679731648	2a1c0496c764ce2cfbb7e88f0d3ff725	VISA 16 digit	39.05889376377948	-95.7731662627019062
3009	2019-09-15 19:54:29	2019-09-15	Florene Conroy	florene.conroy@geemail.com	San Francisco	California	3019165298539604	84aba5cb54abcaf5bf3628f3c231bd1b	JCB 15 digit	37.78585472493819	-122.426806717497712
3010	2019-09-15 20:26:02	2019-09-15	Cora Smith	cora.smith@geemail.com	San Francisco	California	3337346457368340621	428b33f8c7c6d4e6e8a3f3111d041b2f	JCB 16 digit	37.7541560243608956	-122.386805038344932
3011	2019-09-15 20:32:43	2019-09-15	Ala Lehner	ala.lehner@geemail.com	San Francisco	California	869956176695178971	2e72b42a6ec52e13fe5a2c74813857ef	JCB 15 digit	37.7865055293328993	-122.427993393854351
3012	2019-09-15 20:43:21	2019-09-15	Rod Walter	rod.walter@woohoo.com	San Francisco	California	676176564175123	11d7a5f4bae760272252b6a67404294c	VISA 13 digit	37.7941526273800648	-122.395190324261463
3013	2019-09-15 21:34:24	2019-09-15	Minervia Balistreri	minervia.balistreri@geemail.com	Indianapolis	Indiana	4461746572945178	33df6f11bdbf29fe7acfde664a359ba9	American Express	39.7297130566563439	-86.1301721710912886
3014	2019-09-15 21:59:29	2019-09-15	Mrs. Jodie Bergstrom	mrs.jodie.bergstrom@geemail.com	San Jose	California	54320255178670694	fe1c5ad22181774779989e2a7e124d5c	Maestro	37.2460549459613901	-121.726859878537809
3015	2019-09-15 22:53:20	2019-09-15	Miss Neta Stokes DVM	miss.neta.stokes.dvm@warmmail.com	San Francisco	California	3475694506187145	25d9a67b5ca4c80605717828f618912d	VISA 16 digit	37.8065810671910612	-122.441081754779404
3016	2019-09-16 00:48:54	2019-09-16	Sam Oberbrunner	sam.oberbrunner@geemail.com	Anchorage	Alaska	52027147505647477	d39e190327b4118581b9ae5deb3e00e0	VISA 16 digit	61.2416557947389819	-149.358979454416044
3017	2019-09-16 02:40:48	2019-09-16	Dorla Kautzer	dorla.kautzer@geemail.com	Rochester	New York	4966486625090	406300319fa2e9a8f0864206f9902b2e	Voyager	43.2140584897227598	-77.6760874182224228
3018	2019-09-16 02:47:59	2019-09-16	Dessie Streich-Pollich	dessie.streich.pollich@woohoo.com	San Francisco	California	3788319231868620	a0c07fbb19de79f4b26856d301e1c6ed	Maestro	37.7814583825489336	-122.434373648267609
3019	2019-09-16 02:57:25	2019-09-16	Denine Stiedemann-Thiel	denine.stiedemann.thiel@geemail.com	Los Angeles	California	502012151670168	8ba871db4a5981faa9add4547f74346c	American Express	34.118518854897097	-118.339872134383015
3020	2019-09-16 03:45:10	2019-09-16	Wess Lindgren	wess.lindgren@geemail.com	Houston	Texas	54330611800990256	5f90f2786eac350891c9a2c3706bfec5	American Express	29.8812718214545399	-95.3282602518811899
3021	2019-09-16 04:27:48	2019-09-16	Menachem Brown Jr.	menachem.brown.jr.@warmmail.com	Berkeley	California	6011051134878111439	af45b33274254857978724672100e1ce	Discover	37.9034085745055904	-122.296801971996942
3022	2019-09-16 05:28:03	2019-09-16	Berenice Mitchell	berenice.mitchell@geemail.com	New York	New York	676218819484116	7af8b35f291d37904cff1762384e088f	JCB 16 digit	40.7387940958365817	-73.9941456053767297
3023	2019-09-16 07:18:55	2019-09-16	Fernand Reinger	fernand.reinger@geemail.com	Tulsa	Oklahoma	210073262017286459	faaa3c1558181f2b3b66417d5bca9f57	VISA 13 digit	36.1687086179289921	-95.8669452156826765
3024	2019-09-16 07:33:19	2019-09-16	Lulla Bailey DDS	lulla.bailey.dds@woohoo.com	Berkeley	California	4614697116797847	bf13a10c2b17e788156d43eb3a2983ed	American Express	37.849783911652473	-122.270366749543143
3025	2019-09-16 12:13:58	2019-09-16	Sherron Pfeffer	sherron.pfeffer@warmmail.com	Berkeley	California	501833975425746	4936e205dd50ddef55b0c2a576a0cace	VISA 16 digit	37.8532834300794576	-122.279342280132823
3026	2019-09-16 13:00:55	2019-09-16	Golden Heaney	golden.heaney@geemail.com	Phoenix	Arizona	3745128563124995	9d803f8fe6e9b97b6da231a88cec7579	VISA 16 digit	33.6236500819146684	-112.042096525470171
3027	2019-09-16 14:14:00	2019-09-16	Dr. Elzie Hammes	dr.elzie.hammes@geemail.com	San Francisco	California	3337995726648671888	bfc552b56a1a4404cc9fac70ab7ebaa7	VISA 13 digit	37.8065359487820487	-122.437897978733062
3028	2019-09-16 14:52:34	2019-09-16	Renard Schulist-Wunsch	renard.schulist.wunsch@woohoo.com	Jacksonville	Florida	3051897172466094	e67361f89bb03de7105fd7af3a9df360	Mastercard	30.2920641645375639	-81.5672054715998485
3029	2019-09-16 15:04:56	2019-09-16	Ronald Streich	ronald.streich@geemail.com	San Francisco	California	3029479141597432	a6ff9d8e592ba57433e092c88545190d	VISA 16 digit	37.7691086456500003	-122.417448084967106
3030	2019-09-16 15:13:50	2019-09-16	Isaias Kihn	isaias.kihn@warmmail.com	Grand Prairie	Texas	4500492903664617	85b06d4ee7da21de76602294d87e9a00	Mastercard	32.7332602743577255	-97.076329381611572
3031	2019-09-16 15:26:10	2019-09-16	Imogene Mertz	imogene.mertz@geemail.com	Berkeley	California	3528759100219800068	6ce85f8788919e0c118d0cdca8689ee5	JCB 16 digit	37.8654855215715287	-122.285790816875135
3032	2019-09-16 15:27:33	2019-09-16	Cleo Legros	cleo.legros@geemail.com	Oakland	California	869992858531816338	02dd67c0da6cda7daeaa410e9cf770c4	VISA 16 digit	37.8107739057453713	-122.273030381484304
3033	2019-09-16 15:44:04	2019-09-16	Ben Friesen PhD	ben.friesen.phd@warmmail.com	San Francisco	California	3112331318691529305	ebd26506d5b03088fdc935f4451fe589	VISA 16 digit	37.7910080649996942	-122.41858839149009
3034	2019-09-16 18:32:38	2019-09-16	Dr. Brenna Feil	dr.brenna.feil@woohoo.com	Oakland	California	4515343633275674	a3b4eca77ba200b46b3afd25fdc48ca3	Voyager	37.8324481535939725	-122.290040022502311
3035	2019-09-16 18:43:38	2019-09-16	Tiana Ziemann	tiana.ziemann@geemail.com	San Francisco	California	3757368311660594	82059b460145132fbaed6c2787cc1de3	VISA 16 digit	37.7753026329460866	-122.438901566285779
3036	2019-09-16 18:49:39	2019-09-16	Don Stokes DDS	don.stokes.dds@geemail.com	Miami	Florida	210002151826459751	d5bce48554983d94ab5d62103267c283	American Express	25.8416245805703113	-80.2101736809000414
3037	2019-09-16 19:04:10	2019-09-16	Kailey Kerluke-Schiller	kailey.kerluke.schiller@warmmail.com	Houston	Texas	3528417547634818345	247df4845d34edb89b3d7155371d9028	Diners Club / Carte Blanche	29.6910871866237365	-95.291966001877185
3038	2019-09-16 20:53:41	2019-09-16	Mr. Zenas Boyle	mr.zenas.boyle@woohoo.com	San Francisco	California	3096473849594032243	65bfa1f508ad4a8cbff94d243cd35f00	JCB 15 digit	37.7887723427468245	-122.431761153659622
3039	2019-09-16 21:30:32	2019-09-16	Chantal Towne	chantal.towne@geemail.com	San Francisco	California	3010189230928971	5693a3260ce3d40feaeacec7a64b6e51	VISA 16 digit	37.7809622672191097	-122.41093024445793
3040	2019-09-16 21:44:55	2019-09-16	Aniyah Fadel	aniyah.fadel@geemail.com	Baton Rouge	Louisiana	210050837257863450	45941255f22b43e1eae2789e81bce7d3	VISA 16 digit	30.4898309914141876	-91.0971992564495565
3041	2019-09-16 21:57:24	2019-09-16	Leilani Gislason	leilani.gislason@geemail.com	Austin	Texas	6011436052066708756	9db5481646d251b6fc36d652ddab826c	Discover	30.4034865847915405	-97.6879908709559572
3042	2019-09-17 02:58:09	2019-09-17	Felicie Romaguera	felicie.romaguera@geemail.com	Phoenix	Arizona	4588364157465	54712da50ae27fc084d80404803b1553	VISA 16 digit	33.6499268395293498	-112.062237944493447
3043	2019-09-17 03:43:28	2019-09-17	Lloyd Sporer V	lloyd.sporer.v@geemail.com	Lafayette	Louisiana	4279129105173760	b7b344ab9b44261172acfd09dc48183f	American Express	30.2663399949181837	-92.0944473407547832
3044	2019-09-17 04:29:18	2019-09-17	Johana Gibson DVM	johana.gibson.dvm@geemail.com	Chula Vista	California	4243503801855123	56453beac04980e4428853280ed28a63	VISA 16 digit	32.7187858351271572	-116.916293195891001
3045	2019-09-17 04:41:29	2019-09-17	Baldwin Waters	baldwin.waters@warmmail.com	Berkeley	California	4319689579229	cdc3bf1dcfd6bd2df167ca8b1a597d5a	VISA 13 digit	37.8882522331142511	-122.265909205601872
3046	2019-09-17 05:03:05	2019-09-17	Dorris Graham	dorris.graham@geemail.com	Frisco	Texas	55906420723893736	ab053d0c135a34021767df2f773559b7	JCB 16 digit	33.0870613778006302	-96.7323417960874679
3047	2019-09-17 05:06:30	2019-09-17	Almira Quigley	almira.quigley@geemail.com	Albuquerque	New Mexico	4125607754383968	71116442a71502160b27c9c270a26589	VISA 13 digit	35.1813085516117567	-106.55747837788202
3048	2019-09-17 05:25:40	2019-09-17	Jaret Prosacco	jaret.prosacco@geemail.com	San Francisco	California	676235101677504	fbbd97ca80c882726f910a13114510f2	JCB 16 digit	37.7546898369534034	-122.433233459629875
3049	2019-09-17 06:21:13	2019-09-17	Colby Doyle	colby.doyle@geemail.com	Garland	Texas	3403078685204656	0040104608fdfe9b95dd9bf6a0b9db03	VISA 13 digit	32.84348717534467	-96.7243191500820245
3050	2019-09-17 07:25:07	2019-09-17	Tavon Champlin MD	tavon.champlin.md@woohoo.com	San Francisco	California	180095473485624550	e1caac36f40a48f691ec40a28891c008	VISA 16 digit	37.7686113246728183	-122.434549828349006
3051	2019-09-17 08:19:57	2019-09-17	Vernell Erdman	vernell.erdman@woohoo.com	Berkeley	California	3158057080895130148	c9b9e35d2f65c5ab0264d31df21e95b6	VISA 16 digit	37.8633284939299628	-122.269302801305386
3052	2019-09-17 10:10:13	2019-09-17	Mistie Aufderhar	mistie.aufderhar@geemail.com	Berkeley	California	3528753787162888581	fc1d171b5449c8b877bed69ce4c9b02a	JCB 16 digit	37.8607931699649001	-122.282387230931278
3053	2019-09-17 10:40:10	2019-09-17	Ms. Anastasia Berge DVM	ms.anastasia.berge.dvm@geemail.com	Oakland	California	3096689894985908916	adef22a7d3fadfa5630478ff33bb6409	JCB 16 digit	37.8331283886459104	-122.265112808853416
3054	2019-09-17 11:22:06	2019-09-17	Dr. Corean Bogan DVM	dr.corean.bogan.dvm@woohoo.com	San Francisco	California	3158028235168353399	9f09c5bc14852e73df20d48f7f84dc71	American Express	37.8177137064813493	-122.455021010459035
3055	2019-09-17 14:34:00	2019-09-17	Kelli Romaguera	kelli.romaguera@geemail.com	Palm Bay	Florida	6011001243263142478	f52089430d6be0a21e67b5e5dbfd4888	Maestro	27.8899385679833607	-80.7035302600193774
3056	2019-09-17 15:36:59	2019-09-17	Franco Prosacco	franco.prosacco@geemail.com	San Francisco	California	4211757605529502	bb61a4d3a1e2c9c207485ee81d9ff385	JCB 16 digit	37.7953264643504099	-122.422395028607028
3057	2019-09-17 16:06:27	2019-09-17	Ray Glover	ray.glover@geemail.com	San Francisco	California	4440413397758619	bf465f8e66217f71ca2c1f1a0312f696	Maestro	37.7843458467253157	-122.416864993618645
3058	2019-09-17 17:00:46	2019-09-17	Hassie Larson	hassie.larson@geemail.com	Fort Worth	Texas	51049953354907795	594a85dfb2a78af6dc2eae8f4ce01e7a	JCB 16 digit	32.8412727687098069	-97.2963888973284554
3059	2019-09-17 17:02:06	2019-09-17	Bertha Dach	bertha.dach@geemail.com	Garden Grove	California	4697105935599865	d3ecaca70df0fe317ecf5962d3c1ed9c	Discover	33.807436035695666	-117.894000475622704
3060	2019-09-17 17:52:22	2019-09-17	Thursa Herzog	thursa.herzog@geemail.com	San Francisco	California	3454881213300120	ad6c4cf937fb4a49932ed18d6adcdc9f	Voyager	37.7483611109691353	-122.418931194633345
3061	2019-09-17 18:21:47	2019-09-17	Dr. Dayne Schiller	dr.dayne.schiller@warmmail.com	Chula Vista	California	210099190969861609	d6c074e30776daa85e8fd803db2d3be6	JCB 15 digit	32.5444854293249506	-116.959777845977612
3062	2019-09-17 18:48:38	2019-09-17	Dell Kunze	dell.kunze@geemail.com	Fort Wayne	Indiana	3711580482759428	07db3a45056ce6e64bda44b8eaccaf33	JCB 16 digit	41.0918593721248229	-85.0881279443144791
3063	2019-09-17 19:03:41	2019-09-17	Dr. Emett Fay	dr.emett.fay@geemail.com	Round Rock	Texas	6011795352789616806	d014147b050d2151b7d37735c444283c	VISA 16 digit	30.5923308308839808	-97.5865417836550648
3064	2019-09-17 19:26:25	2019-09-17	Vick Wisoky	vick.wisoky@geemail.com	Ann Arbor	Michigan	6011379827982768425	14bffee56ba37e0b135285245591b089	Maestro	42.2734384793382105	-83.7497508015591734
3065	2019-09-17 19:57:27	2019-09-17	Mr. Wendell Pfannerstill	mr.wendell.pfannerstill@woohoo.com	San Francisco	California	501896513782555	3da955a1f1b074652066467276fc7edc	American Express	37.746931420326483	-122.440179143921156
3066	2019-09-17 20:18:21	2019-09-17	Celena Stehr	celena.stehr@woohoo.com	San Francisco	California	180071982993959785	d9364cd509441153b5d58bfd197f1313	VISA 16 digit	37.7638573922224907	-122.46248834668755
3067	2019-09-17 21:18:19	2019-09-17	Ms. Magan Quitzon	ms.magan.quitzon@geemail.com	Houston	Texas	3777295736183579	28f98f89e1e11639c75219972969f962	VISA 16 digit	29.7506646022278822	-95.4511017158642403
3068	2019-09-17 21:48:41	2019-09-17	Hung Hintz	hung.hintz@geemail.com	Oakland	California	3088311329194756547	55b8dd5e103f0d102c29fa7f77a54117	Mastercard	37.7646066349569267	-122.237191614062951
3069	2019-09-17 23:40:00	2019-09-17	Jaren Towne	jaren.towne@woohoo.com	San Francisco	California	3337690237963274561	cd3167604713fe36624bca190be4e425	American Express	37.7811869685750139	-122.449175076634305
3070	2019-09-18 00:26:50	2019-09-18	Jemima Goyette	jemima.goyette@geemail.com	San Francisco	California	4216436996289944	af4fc2b0e764ba7081dea6cc77c89750	VISA 13 digit	37.7812966521845865	-122.418663346298203
3071	2019-09-18 02:42:50	2019-09-18	Evertt Schoen	evertt.schoen@warmmail.com	Oakland	California	53619190090061815	7e8d738f7b14171facc72914e8bfa498	JCB 15 digit	37.8195278526824907	-122.260178836588992
3072	2019-09-18 02:49:59	2019-09-18	Cassius Hauck	cassius.hauck@geemail.com	San Francisco	California	6011314702770452912	88a965722125e359559427e3ceb9ada8	Maestro	37.7667080056614921	-122.443543951932938
3073	2019-09-18 03:15:48	2019-09-18	Lacy Cole	lacy.cole@woohoo.com	Berkeley	California	3112834432323501251	85845fa8f4c5510a1ba349b7fa3d8eae	Diners Club / Carte Blanche	37.8609160776316713	-122.250032187159221
3074	2019-09-18 03:18:55	2019-09-18	Amaris Erdman	amaris.erdman@warmmail.com	Boston	Massachusetts	3019918847301565	975d2af975f65ffad6c34fb4189ac5bf	JCB 16 digit	42.3120417460035512	-70.9266747085794833
3075	2019-09-18 05:00:05	2019-09-18	Carla Durgan-Rempel	carla.durgan.rempel@woohoo.com	Bridgeport	Connecticut	3743185443020472	07c304f4a7fc39b9f98b9d1fdc9b473c	Discover	41.243524337576325	-73.2878150178484731
3076	2019-09-18 06:02:22	2019-09-18	Eithel Nitzsche	eithel.nitzsche@woohoo.com	San Antonio	Texas	4615987106742	50f53e2142092672a0bc79f4b3831867	JCB 15 digit	29.4556169027999033	-98.6112283519305208
3077	2019-09-18 06:13:24	2019-09-18	Cathey Durgan	cathey.durgan@woohoo.com	San Francisco	California	210011835137288532	6179de2c9c078e0183aa9b0f0eddbad7	Voyager	37.7650065832602806	-122.441458790641192
3078	2019-09-18 08:03:27	2019-09-18	Jaslene Kihn	jaslene.kihn@woohoo.com	Tucson	Arizona	676184554714075	6169de49a530750fd0e3b22df0408e08	Voyager	32.1611375665798818	-110.937107248813277
3079	2019-09-18 09:03:25	2019-09-18	Renada Boyle-Beatty	renada.boyle.beatty@geemail.com	Louisville	Kentucky	180020586011883950	93a1012b8694edc0608a5e09eb150036	Maestro	38.2157014827147137	-85.630244487018885
3080	2019-09-18 09:42:02	2019-09-18	Ms. Zula Toy DDS	ms.zula.toy.dds@geemail.com	San Francisco	California	4531737301519	82edef2bff55614102a438167948407f	JCB 16 digit	37.7432431272816942	-122.42020363873732
3081	2019-09-18 09:47:22	2019-09-18	Geralyn Heathcote	geralyn.heathcote@geemail.com	San Francisco	California	210002427940111456	20aef588a1fa64d37bea112b65e8cdb7	JCB 16 digit	37.761047712081357	-122.432582986047294
3082	2019-09-18 10:21:20	2019-09-18	Jeramie Welch-Kautzer	jeramie.welch.kautzer@geemail.com	Oakland	California	210013483897945336	ab4c3ccbcf98871aad39911ed14335e5	JCB 16 digit	37.8155185994922149	-122.271568927988753
3083	2019-09-18 10:54:51	2019-09-18	Jonas Fisher	jonas.fisher@warmmail.com	San Diego	California	3004746964821064	3c603bc6753d0a583a13175b920f66c7	Diners Club / Carte Blanche	32.8103616114772834	-117.05396869018675
3084	2019-09-18 12:10:26	2019-09-18	Cordella Veum	cordella.veum@geemail.com	Chula Vista	California	6011027312703533230	68b143a2ff6084f1ae0a81f39b4d83c8	JCB 16 digit	32.6178620024349541	-117.075820427923276
3085	2019-09-18 12:32:43	2019-09-18	Merrilee Doyle-Wisozk	merrilee.doyle.wisozk@geemail.com	San Francisco	California	180078644491203024	d01742695e7399c58733eba345f2318b	American Express	37.779329392984387	-122.417350514933517
3086	2019-09-18 12:43:28	2019-09-18	Dr. Ivonne Bernier	dr.ivonne.bernier@geemail.com	Columbus	Ohio	180016984422727856	e9cb4d0d02812855980cad8f8d2b4606	JCB 16 digit	39.9863926683131581	-83.0275926905453332
3087	2019-09-18 13:33:24	2019-09-18	Aubrey Steuber	aubrey.steuber@geemail.com	Houston	Texas	3096146618783879699	d37f065c99699524b767b25f57a1c89b	VISA 16 digit	29.730933263207227	-95.4140981385964864
3088	2019-09-18 14:05:39	2019-09-18	Kailyn Bogan	kailyn.bogan@geemail.com	San Francisco	California	3730958366467564	96e72e1a62132594ea80dd2a576a6917	Diners Club / Carte Blanche	37.7633658101953245	-122.398564236991547
3089	2019-09-18 15:26:23	2019-09-18	Lawerence Ward	lawerence.ward@woohoo.com	San Francisco	California	869945246832133520	c41f63433cd54f63f8a138003cc7c0ee	VISA 16 digit	37.8063783528988324	-122.453661669968966
3090	2019-09-18 15:59:24	2019-09-18	Virgel Shanahan	virgel.shanahan@warmmail.com	Los Angeles	California	3337051339649820545	b605755dfda5c7cc183bc169bfc31ead	JCB 16 digit	34.0468947174359116	-118.365383326075218
3091	2019-09-18 16:06:36	2019-09-18	Nim Pouros V	nim.pouros.v@woohoo.com	Garland	Texas	3006859310513919	0dfc48e1f08d8c55a2dadc4cdee0ca28	VISA 13 digit	32.8946190966527894	-96.7124802271530086
3092	2019-09-18 16:07:32	2019-09-18	Bryson Osinski	bryson.osinski@warmmail.com	Oakland	California	3096354797694321863	8565a859669d3ead58140e9dc9c746cd	Maestro	37.793028818234113	-122.284462891754544
3093	2019-09-18 16:22:24	2019-09-18	Olivia Howell	olivia.howell@woohoo.com	Westminster	Colorado	676217388750030	a874cfe1fc91d78f8f122d33b1d17fc8	VISA 13 digit	39.9319916525229814	-105.039524900881204
3094	2019-09-18 19:17:06	2019-09-18	Dr. Ali Boyer	dr.ali.boyer@warmmail.com	San Francisco	California	180001666250306955	71020904ce90ed4857ed237e912b69d5	VISA 16 digit	37.7397727934972878	-122.413816339348728
3095	2019-09-18 19:40:21	2019-09-18	Colvin Shields	colvin.shields@geemail.com	Oakland	California	3158462697077815557	12f247977724c13e3069331820f7de4f	VISA 16 digit	37.8000405958401018	-122.321969062342873
3096	2019-09-18 19:41:34	2019-09-18	Asha Morissette DVM	asha.morissette.dvm@geemail.com	Mobile	Alabama	3054851299396293	8eb95e6d7306b941d0a6b710e0f37d04	VISA 16 digit	30.6508201655574126	-88.15188065903709
3097	2019-09-18 20:33:43	2019-09-18	Waino Walker	waino.walker@geemail.com	Denver	Colorado	869999856258583621	da796c131329d06e5e83dbb46f5a3604	VISA 16 digit	39.7891790344431939	-104.977912705742199
3098	2019-09-18 23:35:28	2019-09-18	Mrs. Ozell Lockman PhD	mrs.ozell.lockman.phd@geemail.com	San Francisco	California	4463935239683557	cf7efc95473c130eaca94e030bd1e2d7	Diners Club / Carte Blanche	37.7407881265249117	-122.43139868698978
3099	2019-09-18 23:38:59	2019-09-18	Felipa Gislason	felipa.gislason@warmmail.com	Nashville	Tennessee	3022817255448289	6271b82296d316eb7cb9e57bf5207607	Diners Club / Carte Blanche	36.1699242632959042	-86.7530366778746185
3100	2019-09-19 00:15:03	2019-09-19	Darcy Abernathy-Smitham	darcy.abernathy.smitham@woohoo.com	Peoria	Arizona	869998051130689488	3b2ae6f7fe4672cc3a493c059822c464	Maestro	33.8261796562735029	-112.367866776270802
3101	2019-09-19 01:17:12	2019-09-19	Audrianna Jacobson	audrianna.jacobson@geemail.com	San Jose	California	3337792605491650287	7035f3cc9479cd1f9f9f3f0ffc62ba50	JCB 15 digit	37.2155118839170811	-121.726195083859935
3102	2019-09-19 01:47:01	2019-09-19	Tawanda Gerhold	tawanda.gerhold@woohoo.com	San Francisco	California	180048634316831403	e6e0599dae628dacbfaa2f099eafc596	Mastercard	37.764050424423786	-122.429749554688271
3103	2019-09-19 02:38:07	2019-09-19	Clella Cormier	clella.cormier@geemail.com	Newark	New Jersey	3096696510449753968	6eff4c6ebbf0c7d47b3d21c77413a15b	VISA 16 digit	40.7180529926817911	-74.2557365456804632
3104	2019-09-19 04:19:16	2019-09-19	Ms. Wilhelmine Haag	ms.wilhelmine.haag@warmmail.com	Oakland	California	3421608892067203	c59d4f1baa15ddb1b051831dcbe598fc	Maestro	37.795918576604322	-122.266307098224331
3105	2019-09-19 04:42:27	2019-09-19	Mrs. Adele Mertz	mrs.adele.mertz@warmmail.com	San Francisco	California	561224118954478	1c773d83bb6160697549e318c532f57c	JCB 16 digit	37.7666216191930246	-122.427032419550869
3106	2019-09-19 07:16:56	2019-09-19	May Grimes	may.grimes@geemail.com	Tucson	Arizona	4720588714071928	be55551e0d6631594231eb02e79c85e4	Discover	32.2294165246229625	-110.814973860629266
3107	2019-09-19 07:47:19	2019-09-19	Mai Hessel DVM	mai.hessel.dvm@geemail.com	Denver	Colorado	6011959705725923911	e43932b978603ee006278b042f1e9cac	VISA 13 digit	39.8049757088586631	-104.976999269264198
3108	2019-09-19 09:06:35	2019-09-19	Mrs. Angelina Gibson MD	mrs.angelina.gibson.md@warmmail.com	Seattle	Washington	210031725915733807	6f7ae2287fdd6644dbc8bab7f24a5eda	JCB 15 digit	47.5495305872447815	-122.350446513287352
3109	2019-09-19 09:19:41	2019-09-19	Shea Rippin IV	shea.rippin.iv@geemail.com	San Francisco	California	6011548396185938223	57de17c53dd5170e4b27fe94deb0a7a0	Maestro	37.7942485092889058	-122.452222801707265
3110	2019-09-19 10:54:47	2019-09-19	Lanette Schoen-Casper	lanette.schoen.casper@geemail.com	Orlando	Florida	3112100524876990944	6010dbd67b8278519de5aabebee0d352	American Express	28.4138859041299661	-81.2037003079395703
3111	2019-09-19 11:09:55	2019-09-19	Rylee Emmerich	rylee.emmerich@geemail.com	San Francisco	California	676200116123134	2fa8248e3506efc4eb00806dcd5e15d7	JCB 15 digit	37.758674150610176	-122.440351788033482
3112	2019-09-19 11:24:22	2019-09-19	Linette Jacobi	linette.jacobi@geemail.com	Oakland	California	869960261438778891	a31dec14c410f9275555806458dbf8a5	Discover	37.8223182921768242	-122.265143697094331
3113	2019-09-19 11:55:55	2019-09-19	Saniyah Conn	saniyah.conn@geemail.com	San Francisco	California	6011962706524452396	aa212dde7792d7e69367232b311402bb	JCB 15 digit	37.7710592822463909	-122.405657912901916
3114	2019-09-19 14:16:10	2019-09-19	Irvin McKenzie	irvin.mckenzie@woohoo.com	Columbus	Ohio	675942711893125	2122ff81095bc137a29f0e047a3575b4	JCB 15 digit	39.9390333380129192	-82.9045388644330217
3115	2019-09-19 14:43:47	2019-09-19	Raelyn Maggio	raelyn.maggio@geemail.com	San Francisco	California	869957521299414588	611ec96ff2fa5d77f528672864b64088	VISA 16 digit	37.7842357074571424	-122.447526980208124
3116	2019-09-19 15:11:18	2019-09-19	Sadie Kuhic	sadie.kuhic@woohoo.com	San Francisco	California	3528532973706680399	e469d712c2df5469549551ba83f5ec18	Discover	37.8040605534008094	-122.416960571313467
3117	2019-09-19 15:34:09	2019-09-19	Isamar Langworth MD	isamar.langworth.md@geemail.com	Norman	Oklahoma	55222364890360250	e21d5698db2771e87fd40b39ea707fe9	JCB 16 digit	35.2841145850758977	-97.4276103824630297
3118	2019-09-19 15:57:55	2019-09-19	Kaye Murray	kaye.murray@geemail.com	San Francisco	California	3766883897741591	fb43fca2c3341bc7af135e81106e72b4	Mastercard	37.7545061386269438	-122.437743238052121
3119	2019-09-19 16:47:07	2019-09-19	Dr. Bobbie Harber MD	dr.bobbie.harber.md@geemail.com	Tallahassee	Florida	3088896653322295117	d32e95d7d0f4c5ba8061bb2732e70888	Diners Club / Carte Blanche	30.5398583744674923	-84.2107428730946026
3120	2019-09-19 17:13:09	2019-09-19	Kennth Kozey	kennth.kozey@geemail.com	San Francisco	California	630414124599607	15b0b96f954816929ad86579f2cf18d2	VISA 13 digit	37.8003363195853197	-122.442346337861579
3121	2019-09-19 17:23:04	2019-09-19	Eliseo Fisher	eliseo.fisher@geemail.com	Detroit	Michigan	4353809588881745	db8811834cdbd7e5a488a84510aad115	VISA 13 digit	42.3475203747320919	-83.1394593231964762
3122	2019-09-19 19:08:08	2019-09-19	Djuana Toy	djuana.toy@geemail.com	Raleigh	North Carolina	54783396300818858	47abef6a90d44bdf8bc71d407957b364	Voyager	35.7461264574103055	-78.6933255032107297
3123	2019-09-19 19:19:55	2019-09-19	Mr. Kobe Rogahn	mr.kobe.rogahn@geemail.com	San Francisco	California	6011711893852633724	bc35f723600d24b5b8729699899236de	JCB 16 digit	37.7500811801650613	-122.463482514402088
3124	2019-09-19 19:30:40	2019-09-19	Mr. Auther Vandervort	mr.auther.vandervort@geemail.com	Berkeley	California	060469138988725	667da1a8231fd0c4a6caf3e1958b54fd	VISA 16 digit	37.873348863007962	-122.276286199767824
3125	2019-09-19 21:02:55	2019-09-19	Elian Fisher	elian.fisher@geemail.com	Wichita Falls	Texas	4629043131966	749e170f608d557d02d6fe53e9a0ff43	JCB 16 digit	33.8844893250808141	-98.5863091131594018
3126	2019-09-19 22:19:26	2019-09-19	Valery Tillman	valery.tillman@geemail.com	San Francisco	California	4154351809311476	af83eb6f1c46fe077eadc5d3137e820f	JCB 15 digit	37.7897983133774886	-122.404099085920279
3127	2019-09-19 23:55:19	2019-09-19	Brandee Schultz-Trantow	brandee.schultz.trantow@geemail.com	Los Angeles	California	3025428338953795	42c7c8f8ea4705778195389db00b60c2	Discover	33.9677908475842329	-118.327097397296868
3128	2019-09-20 00:04:09	2019-09-20	Mrs. Eulah Dickinson	mrs.eulah.dickinson@warmmail.com	San Francisco	California	3052933452209703	6df4d2c42257f3653dfae6c2ef94610c	Mastercard	37.7839050782409132	-122.421087277389759
3129	2019-09-20 00:10:46	2019-09-20	Devonta Rempel	devonta.rempel@warmmail.com	Dallas	Texas	210018505186817266	025acccbe55ddae191648e4dfa7b05e8	VISA 16 digit	32.8128404196158101	-96.7071031034421082
3130	2019-09-20 00:17:12	2019-09-20	Jaylon Feeney	jaylon.feeney@geemail.com	San Francisco	California	3058472869316607	9e0b6922f95c0356c47b607ac7624bb2	Maestro	37.7759459277283867	-122.3896506540584
3131	2019-09-20 00:28:02	2019-09-20	Mr. Harrison Kohler MD	mr.harrison.kohler.md@warmmail.com	New York	New York	3046372409246391	775edcc8daf6ebf720f24d4f09283b26	Discover	40.5673290914613744	-73.8965540301416013
3132	2019-09-20 00:43:54	2019-09-20	Mr. Deontae Halvorson V	mr.deontae.halvorson.v@warmmail.com	San Francisco	California	869903315021925408	c3f2371b1a3b8286e86b3fad22e0e5e2	VISA 16 digit	37.7614189735285422	-122.431744480611059
3133	2019-09-20 01:09:59	2019-09-20	Dr. Antonina Ritchie PhD	dr.antonina.ritchie.phd@geemail.com	Cleveland	Ohio	4525856331422726	e9820a57d2e5021485840f72a36651b1	JCB 16 digit	41.5203241184204757	-81.7106163764610898
3134	2019-09-20 02:50:06	2019-09-20	Katelyn Okuneva	katelyn.okuneva@geemail.com	San Francisco	California	3042894681578799	503bd4714f9754b6de2641986bfcde1f	Voyager	37.7590105066006672	-122.439559236115869
3135	2019-09-20 04:13:35	2019-09-20	Janine Bode	janine.bode@geemail.com	San Francisco	California	4288113152697565	8f8ca4b8d2cbdbffb1d9235414af0c5e	VISA 13 digit	37.773170494025365	-122.417256945700572
3136	2019-09-20 05:04:34	2019-09-20	Cindi Effertz-Ondricka	cindi.effertz.ondricka@geemail.com	New York	New York	3051473091372027	2205abf6109a3696594235dfb08dfa53	JCB 16 digit	40.6520594612453152	-73.8733075238659893
3137	2019-09-20 05:23:05	2019-09-20	Ebba McClure	ebba.mcclure@woohoo.com	Wichita Falls	Texas	210096427394963177	0da8e8a6d0b8691e3db29b51a1f29032	VISA 13 digit	33.8653028148885795	-98.5083805933050769
3138	2019-09-20 05:39:18	2019-09-20	Mr. Levern Jacobs	mr.levern.jacobs@geemail.com	Berkeley	California	3088974599438347661	b66712cc7022f553d7f9db9be2d24b5f	Discover	37.8800275428037168	-122.247115433565554
3139	2019-09-20 06:44:57	2019-09-20	Mr. Haiden Reichert	mr.haiden.reichert@geemail.com	San Francisco	California	3158465843774447685	9c204cee188c73158e5e49351049efe7	JCB 16 digit	37.7913862807583314	-122.463874424733433
3140	2019-09-20 07:53:48	2019-09-20	Deangelo Feeney	deangelo.feeney@warmmail.com	Irvine	California	3416663003905079	4caf9139951902c3b3c4d2f153c261f4	Mastercard	33.6460522195339209	-117.769337478514018
3141	2019-09-20 08:25:03	2019-09-20	Jenna Thiel DDS	jenna.thiel.dds@geemail.com	New York	New York	676368228062888	8dc8956b97e57f0e3009a90c60500185	JCB 16 digit	40.6900492819249635	-73.9321164570644527
3142	2019-09-20 08:32:35	2019-09-20	Spring Dach	spring.dach@warmmail.com	San Mateo	California	3432239661778791	088cbdf6856ff15da01dcad2b66376e5	VISA 16 digit	37.476749452657252	-122.367129789604235
3143	2019-09-20 08:53:47	2019-09-20	Babette Denesik	babette.denesik@geemail.com	Philadelphia	Pennsylvania	3023387540732441	8aaf4556f4ab88788864479fb1bd3bef	American Express	39.9321968081366236	-75.1876757688719835
3144	2019-09-20 09:57:53	2019-09-20	Amma Altenwerth	amma.altenwerth@geemail.com	Oakland	California	4167024090086397	080e88972de1016a39631f620d45c59d	JCB 16 digit	37.8386225551818427	-122.259984439822261
3145	2019-09-20 10:55:57	2019-09-20	Lylah Bartoletti	lylah.bartoletti@geemail.com	Visalia	California	3035236563819122	780807832caf712a618bdc34f6b794e7	Discover	36.4242959891866889	-119.266215761763604
3146	2019-09-20 11:05:43	2019-09-20	Landyn Renner V	landyn.renner.v@geemail.com	Oakland	California	4579877498567397	ea931c5a7c0a458c9906864261985880	Mastercard	37.8285289655095767	-122.305479730228726
3147	2019-09-20 11:08:22	2019-09-20	Dr. Candida Schuster	dr.candida.schuster@geemail.com	Oakland	California	3405251108347422	d6dcc7d11a274ee2f68066bb2c6c5b17	VISA 13 digit	37.8126847094665237	-122.287854680542708
3148	2019-09-20 12:28:03	2019-09-20	Winfred Kohler	winfred.kohler@geemail.com	San Francisco	California	3158127743314712558	0da618ab2ba3c6bcce82f78a3325d54d	American Express	37.7758791452974307	-122.440419799306596
3149	2019-09-20 12:35:40	2019-09-20	Chaz Nicolas	chaz.nicolas@woohoo.com	New York	New York	3707843710288115	e93584a1305153329959d23457a44a30	Mastercard	40.6136382854301488	-74.0261566098209443
3150	2019-09-20 13:22:00	2019-09-20	Louetta Ward PhD	louetta.ward.phd@geemail.com	Jacksonville	Florida	210098386050871017	492fe4e9922f1737bd93acd73dbb3f01	JCB 16 digit	30.3060883116960511	-81.6111764224324503
3151	2019-09-20 14:52:41	2019-09-20	Ms. Fronia Batz	ms.fronia.batz@geemail.com	San Francisco	California	210049248841593682	3ececfc36f3ca8ce0f4fdfe7fbf65cbd	JCB 16 digit	37.7523358919531447	-122.436386770854199
3152	2019-09-20 14:53:31	2019-09-20	Joseluis Bradtke	joseluis.bradtke@geemail.com	San Francisco	California	3112540119604498357	a953d9d6aed88d2e6e9583b33c2ebfdc	VISA 13 digit	37.7850349095010145	-122.430054463032548
3153	2019-09-20 17:42:02	2019-09-20	Miss Porsche Turcotte	miss.porsche.turcotte@warmmail.com	Oakland	California	869999546960356230	0d28a04ccf00e39d813a9b28c0528db0	VISA 16 digit	37.7875214814208391	-122.272019426518682
3154	2019-09-20 19:32:27	2019-09-20	Skip Ledner-Konopelski	skip.ledner.konopelski@geemail.com	Oakland	California	4608446516650	f9df02eacceb7bfea357d76a9e78270d	Maestro	37.8258393568469984	-122.281345374312153
3155	2019-09-20 20:12:37	2019-09-20	Dereon Balistreri	dereon.balistreri@geemail.com	San Francisco	California	4981234353454216	08ac02eaf54b593a125fec136f7d4b5e	JCB 15 digit	37.7890062831614628	-122.438828664416732
3156	2019-09-20 21:19:21	2019-09-20	Kristyn Little	kristyn.little@geemail.com	San Francisco	California	4917009443283307	0e9cc41f9bf1d31405ff85a00955f4a9	VISA 16 digit	37.744596394050717	-122.390030523527045
3157	2019-09-20 22:05:19	2019-09-20	Victor Prohaska	victor.prohaska@geemail.com	San Francisco	California	501838213554934	2a3f8798c09493809807c7605df85668	JCB 15 digit	37.7782519715008291	-122.423658756317721
3158	2019-09-20 23:16:14	2019-09-20	Bertram Schoen	bertram.schoen@woohoo.com	Berkeley	California	501829284181756	ee62d45c3f9044fe59c28e5f274038d1	JCB 15 digit	37.8658600636486895	-122.273015021334643
3159	2019-09-20 23:17:59	2019-09-20	Kacy Towne-Douglas	kacy.towne.douglas@geemail.com	New York	New York	52841717120126000	cc64d614a2af4c43fe886700c17cf71c	VISA 13 digit	40.7625633075591196	-73.8952306090284168
3160	2019-09-20 23:47:22	2019-09-20	Tai Hartmann	tai.hartmann@geemail.com	Oakland	California	210058180731812807	5deff97f7390e1a8d6c93d7c3b90ca3a	JCB 16 digit	37.8026498884170365	-122.27525543693973
3161	2019-09-21 00:43:30	2019-09-21	Kaylan Batz	kaylan.batz@geemail.com	Chicago	Illinois	3444358861124774	ffe00c055c3f3972d62803825ed86371	VISA 16 digit	41.8531547228641827	-87.6081074003160012
3162	2019-09-21 01:34:50	2019-09-21	Brandan Armstrong	brandan.armstrong@geemail.com	Greensboro	North Carolina	4299640697932	24dce438015f5fbd0a797c87e07554c9	VISA 13 digit	36.1103493779081859	-79.7814663045555363
3163	2019-09-21 01:50:11	2019-09-21	Kenny Kautzer-Robel	kenny.kautzer.robel@geemail.com	San Francisco	California	869988959691354213	e84273dd988cb26e4b3df5499dc91979	JCB 16 digit	37.7838151877109425	-122.428011092318755
3164	2019-09-21 02:29:03	2019-09-21	Eudora Runolfsson	eudora.runolfsson@woohoo.com	San Francisco	California	3096477917506643583	69bf0b5e04f5e97a1d09db987d4ced01	VISA 16 digit	37.7774928476830709	-122.423034599157873
3165	2019-09-21 03:20:47	2019-09-21	Liddie Armstrong	liddie.armstrong@geemail.com	St. Louis	Missouri	4558879967103592	011ad2112148c2bab82799dbba4eeca1	American Express	38.6940029752131522	-90.2358116700783484
3166	2019-09-21 05:34:09	2019-09-21	Irwin Nolan	irwin.nolan@warmmail.com	Pittsburgh	Pennsylvania	3043863198718627	485cf373a7814678c27f4a50f6977833	VISA 13 digit	40.3945869781497819	-80.0607344417072824
3167	2019-09-21 06:19:30	2019-09-21	Montel Reynolds	montel.reynolds@geemail.com	San Francisco	California	3430867365347422	813fb4e028a6d530381f284a614e46d5	JCB 16 digit	37.7857625543056912	-122.411067370752562
3168	2019-09-21 06:30:54	2019-09-21	Fielding Collins	fielding.collins@geemail.com	Oakland	California	210023849176654765	385e36426959a76179055cfbce9733b9	Discover	37.8087100736886299	-122.290491394221064
3169	2019-09-21 06:34:29	2019-09-21	Dollie Daugherty-Welch	dollie.daugherty.welch@geemail.com	Aurora	Illinois	3037622028026577	8ab140d630bc3a504df08b2bd8ee5e86	American Express	41.763394730467347	-88.3637327801365302
3170	2019-09-21 07:14:56	2019-09-21	Nelia McDermott	nelia.mcdermott@warmmail.com	Nashville	Tennessee	3492653050091730	5acde5f3c5d496b925a174eb8dc7b562	JCB 16 digit	36.205960813502962	-86.7076590778678593
3171	2019-09-21 08:00:42	2019-09-21	Capitola Corwin	capitola.corwin@woohoo.com	Houston	Texas	4290395953318410	9a58f66c1122986005bf8c8a8d6b48df	Maestro	29.7937634185500428	-95.299186707801752
3172	2019-09-21 08:27:40	2019-09-21	Ladarius Watsica MD	ladarius.watsica.md@woohoo.com	Oakland	California	4986583655268582	d600a4527f5970c54a9964ee27ccff5c	VISA 13 digit	37.767043344103179	-122.275587656066904
3173	2019-09-21 08:39:12	2019-09-21	Ms. Tarah Rogahn	ms.tarah.rogahn@warmmail.com	Abilene	Texas	3158296404536581157	8131502e2e1a7cb339102ca9d3a71391	VISA 13 digit	32.4451276395544426	-99.6515269817732303
3174	2019-09-21 09:42:10	2019-09-21	Mr. Theron Wintheiser V	mr.theron.wintheiser.v@geemail.com	San Francisco	California	4279321924649	8614f471f201e18bedda522aed5d0a98	Mastercard	37.7667726835598287	-122.434498618227622
3175	2019-09-21 09:43:52	2019-09-21	Jett Jacobs DVM	jett.jacobs.dvm@woohoo.com	San Francisco	California	3794503637144999	3b6fb1e903aba8f5f6bdadb971b56b31	VISA 13 digit	37.7728140366146476	-122.43118691449186
3176	2019-09-21 10:04:36	2019-09-21	Miss Birdella Waelchi MD	miss.birdella.waelchi.md@geemail.com	San Francisco	California	4472095468824	4c3eab34bb3f0f90bc86adf2eab5a10d	Voyager	37.7584225917560303	-122.406442365637389
3177	2019-09-21 10:25:09	2019-09-21	Halley Sanford	halley.sanford@warmmail.com	San Francisco	California	4026055421941661	361ada0d2e20af5b886a3c1bf889c7eb	VISA 16 digit	37.7852811993590976	-122.454848476465756
3178	2019-09-21 11:00:13	2019-09-21	Timothy Wiza	timothy.wiza@geemail.com	San Francisco	California	3754814250933750	2936e6d5243ad923394af6c550860d11	JCB 16 digit	37.799884196831961	-122.443641450227304
3179	2019-09-21 11:02:11	2019-09-21	Josie Kozey	josie.kozey@geemail.com	San Francisco	California	869915762020914881	3a12777902b83d4d870a2b79ce76a52f	Discover	37.7982395203478632	-122.401975437726094
3180	2019-09-21 11:06:08	2019-09-21	Orvin Kulas	orvin.kulas@woohoo.com	San Francisco	California	51801876586828380	c00d6a31081c1f12f0c762468c86c105	JCB 16 digit	37.7672405341648627	-122.451943751927715
3181	2019-09-21 12:43:58	2019-09-21	Greg Spencer-Gleichner	greg.spencer.gleichner@woohoo.com	Peoria	Arizona	502067249627737	39aa3720f71e8989ec2a7939e6cc7ba7	Voyager	33.8251396727085094	-112.346342675799505
3182	2019-09-21 13:39:13	2019-09-21	Mrs. Eudora Gerlach PhD	mrs.eudora.gerlach.phd@warmmail.com	Henderson	Nevada	4826925796714012	e64ea30eeff0d22f095b1e3edbd7e365	Voyager	35.9226946878645563	-115.130144319838664
3183	2019-09-21 15:53:55	2019-09-21	Mr. Baxter Wilderman DDS	mr.baxter.wilderman.dds@woohoo.com	Portland	Oregon	51846147574987738	4e84503b86d2c384350009968f0a9106	JCB 15 digit	45.615169422876086	-122.636692813318234
3184	2019-09-21 16:26:13	2019-09-21	Ms. Ason Schimmel MD	ms.ason.schimmel.md@geemail.com	Anaheim	California	869991817969379954	58a81af7ed22ed551159f33e62dbf6ac	VISA 13 digit	33.9072919609788812	-117.736081908570966
3185	2019-09-21 18:21:32	2019-09-21	Mr. Terrill Leuschke	mr.terrill.leuschke@warmmail.com	San Francisco	California	869998915584851101	7036048a4b8219616e524d7df9d574dd	VISA 16 digit	37.7737227701351372	-122.438240423655316
3186	2019-09-21 18:54:14	2019-09-21	Miss Dona Klocko DVM	miss.dona.klocko.dvm@geemail.com	San Francisco	California	3112903905199074012	f7eca7d3823849b60408f66fb6dc4b82	American Express	37.7439832455414859	-122.405395493444388
3187	2019-09-21 19:04:49	2019-09-21	Regis Denesik V	regis.denesik.v@geemail.com	Jacksonville	Florida	676146578346986	2fac1781f23989435f2fe87ef5cc5fe2	VISA 16 digit	30.3261984679434455	-81.6593392964996525
3188	2019-09-21 21:16:57	2019-09-21	Lorenza Schultz-Von	lorenza.schultz.von@woohoo.com	Memphis	Tennessee	4332644692242823	9fbeae7533320c99ed67ea41bec48c10	American Express	35.0558359619297093	-90.0747817095160457
3189	2019-09-21 21:24:34	2019-09-21	Dr. Gaetano Lockman	dr.gaetano.lockman@geemail.com	San Francisco	California	3791717472448751	dc3fbd06ae3f90d34052852a72205994	American Express	37.7527161042485915	-122.43775317418347
3190	2019-09-21 21:29:11	2019-09-21	Louis Rutherford Sr.	louis.rutherford.sr.@geemail.com	Oakland	California	3158452826471046004	eeb6e504345e68b42c69ced3d01adde0	VISA 16 digit	37.8044721179038987	-122.284734630708911
3191	2019-09-22 01:16:12	2019-09-22	Jimena Mann	jimena.mann@woohoo.com	San Francisco	California	3096350937334658183	7c1bfd8bf3f95d7eaf6a38927f0b3e4f	Diners Club / Carte Blanche	37.8095715909901742	-122.41703036124018
3192	2019-09-22 02:57:42	2019-09-22	Montie Labadie	montie.labadie@geemail.com	San Francisco	California	3337389975222720439	e3e21f4482b91a6bcdbbe9910cb34b0b	JCB 16 digit	37.7466541920255096	-122.472060656383874
3193	2019-09-22 03:11:49	2019-09-22	Dr. Rahul Goldner	dr.rahul.goldner@geemail.com	Berkeley	California	6011847620355619638	9dd0049e2fc4507daeabe4cea942703d	JCB 15 digit	37.8919762011239598	-122.300002388378815
3194	2019-09-22 04:12:11	2019-09-22	Lue Bogisich Jr.	lue.bogisich.jr.@geemail.com	San Francisco	California	3052016283703522	f4680021e31fa2fc0ce41374652947de	Voyager	37.7877649112518341	-122.396723041732926
3195	2019-09-22 04:19:35	2019-09-22	Mr. Jedediah O'Connell DVM	mr.jedediah.o'connell.dvm@warmmail.com	Charleston	South Carolina	3096956376213874678	84e77731250486340f4cf107f701a4c5	VISA 16 digit	32.8622242561537803	-80.0130648386813732
3196	2019-09-22 06:09:28	2019-09-22	Roderic Haley I	roderic.haley.i@woohoo.com	San Francisco	California	4416889308680028	ae3d8ed4c55cf6c496870c9e438ac1b5	VISA 13 digit	37.7758706034040301	-122.420087177275519
3197	2019-09-22 07:39:13	2019-09-22	Ezekiel Gaylord	ezekiel.gaylord@woohoo.com	New York	New York	869969280636194710	ef42a2f5e537adb3a2f9b12258c7da05	VISA 16 digit	40.7051381703223996	-73.8759207829263005
3198	2019-09-22 07:47:42	2019-09-22	Miss Miesha VonRueden MD	miss.miesha.vonrueden.md@geemail.com	Oakland	California	3436609741930487	a952beb4b7fe03cc1bbdf9fc5614d5ad	VISA 16 digit	37.8122142268316281	-122.272706156281743
3199	2019-09-22 08:11:58	2019-09-22	Ms. Clarinda Spinka PhD	ms.clarinda.spinka.phd@geemail.com	Fairfield	California	4900881340185184	d1e6aeb7d6382b6f66bc20dcf273981f	Mastercard	38.260692342522745	-122.049637818616262
3200	2019-09-22 08:28:35	2019-09-22	River Schiller PhD	river.schiller.phd@woohoo.com	Colorado Springs	Colorado	4511136546005	2caaa64584cecd137dba95e242c372c4	JCB 16 digit	38.8259859925184401	-104.759601418969041
3201	2019-09-22 09:13:26	2019-09-22	Mrs. Linnea Reinger MD	mrs.linnea.reinger.md@woohoo.com	San Francisco	California	4016857200184054	33e2f562bbbb0c9825174deef63c89e8	JCB 16 digit	37.7520564228784608	-122.436002322732449
3202	2019-09-22 09:28:14	2019-09-22	Chantal Crist-Kirlin	chantal.crist.kirlin@geemail.com	Tucson	Arizona	3528534752311288774	598ace241011a163c8dba2b4ba15ca18	VISA 16 digit	32.1643393950112184	-110.831572602711987
3203	2019-09-22 10:52:00	2019-09-22	Jimmie Cummings-Hane	jimmie.cummings.hane@geemail.com	Los Angeles	California	3750269266697523	bbc762edbcff5a7465ac62134fa2844d	JCB 15 digit	34.0112696725275327	-118.355542005551229
3204	2019-09-22 11:26:18	2019-09-22	Tai Fahey	tai.fahey@geemail.com	New York	New York	869980542362510749	cb6bda90834ec41d30e2268b18c2823b	Maestro	40.6347933412753051	-73.862823690323907
3205	2019-09-22 11:31:55	2019-09-22	Herminia Kreiger-Emard	herminia.kreiger.emard@geemail.com	Berkeley	California	3112474357043303099	c4cd60f161aed42dee7a26751bb01f51	Mastercard	37.8157061570992425	-122.282927534697549
3206	2019-09-22 11:33:16	2019-09-22	Zeta Jaskolski	zeta.jaskolski@woohoo.com	Berkeley	California	3042298239402843	78201d5a825cd9d8d710cf62b74358a9	VISA 13 digit	37.8323136651165015	-122.274533918866013
3207	2019-09-22 12:01:56	2019-09-22	Haden Wyman	haden.wyman@geemail.com	San Francisco	California	3112802105393018566	a0865ec68d5da3fb2970d988870e8971	VISA 13 digit	37.7535743625125448	-122.433677684857997
3208	2019-09-22 12:50:01	2019-09-22	Rayne Wehner	rayne.wehner@woohoo.com	Chicago	Illinois	210077481609818745	6ad7b3daa830965a0fd8b802c724fd1f	JCB 15 digit	41.8224775024060165	-87.7811744608946043
3209	2019-09-22 13:23:27	2019-09-22	Darwin Orn-Jast	darwin.orn.jast@warmmail.com	Saint Paul	Minnesota	4569992203466843	9a7677cf67422e53f61b0445c358d2c8	Voyager	45.0462401911556753	-93.131952709917357
3210	2019-09-22 13:23:29	2019-09-22	Effie Trantow-Bergstrom	effie.trantow.bergstrom@geemail.com	New York	New York	676297840883611	3c25923961800541e73d7c82a86e014e	JCB 16 digit	40.7301219045873708	-74.0264522408496504
3211	2019-09-22 13:35:59	2019-09-22	Seldon Farrell	seldon.farrell@geemail.com	Irving	Texas	3158617702752271748	a6cc42da90347f92b3f489592a4003f9	JCB 16 digit	32.7610510433975648	-96.9999446079879988
3212	2019-09-22 13:36:05	2019-09-22	Gilford Gorczany	gilford.gorczany@woohoo.com	Tucson	Arizona	3038234594578616	8c76e6d1042b7ec411088f20260fd9de	JCB 16 digit	32.248284472529221	-110.844747485475978
3213	2019-09-22 14:30:40	2019-09-22	Ms. Elissa Nitzsche	ms.elissa.nitzsche@geemail.com	Garland	Texas	54307525626458000	d4ae3f1a9c8b2f4941890ef343f7a306	JCB 16 digit	32.9631662097528562	-96.7059601518020031
3214	2019-09-22 16:39:58	2019-09-22	Columbus Hintz	columbus.hintz@woohoo.com	Berkeley	California	3337529928730091562	abedc827f48dfc083eef69335080c900	Discover	37.8843485336802672	-122.242024082203514
3215	2019-09-22 17:16:29	2019-09-22	Flonnie Gerhold DDS	flonnie.gerhold.dds@geemail.com	San Francisco	California	210055320984230793	1dc3637864c4d2c9efc061f7c72624d0	Voyager	37.7683478661452909	-122.437713704954334
3216	2019-09-22 17:18:03	2019-09-22	Mr. Doyle Will V	mr.doyle.will.v@warmmail.com	Eugene	Oregon	060433784425036	53f408defca51dff844cadc12a449702	Voyager	44.0704172114104011	-123.169958981823925
3217	2019-09-22 17:44:12	2019-09-22	Dr. Cecily Reichel PhD	dr.cecily.reichel.phd@warmmail.com	New York	New York	210029277426781101	ffb48e398b72afbd134ae188e2f2ae84	Voyager	40.585364551166073	-73.9224805188260916
3218	2019-09-22 18:40:38	2019-09-22	Ciara Lind DVM	ciara.lind.dvm@woohoo.com	Houston	Texas	54474736841349711	0632b47de6961f71d2cee18f325df134	VISA 13 digit	29.7609003687821314	-95.3859776398181936
3219	2019-09-22 18:45:58	2019-09-22	Candis Roberts	candis.roberts@geemail.com	San Francisco	California	53619279005326551	cb4878f4415f077fc6da6f8c26bb6bdb	American Express	37.7572512256395285	-122.429620077311753
3220	2019-09-22 20:47:17	2019-09-22	Mrs. Kristan Blick DVM	mrs.kristan.blick.dvm@geemail.com	New York	New York	3709513168693292	fbaf576f98979694f7c06fb7337b1df5	VISA 16 digit	40.648713909018781	-74.0267178224295321
3221	2019-09-22 20:52:29	2019-09-22	Freda Koch	freda.koch@geemail.com	Austin	Texas	4104390053976585	045d5004f91ba58794b456afc01dff6d	American Express	30.3495323147285703	-97.7066342114709414
3222	2019-09-22 21:49:52	2019-09-22	Vivian Stroman	vivian.stroman@geemail.com	San Francisco	California	3528015224355190496	3cccc31feb291600c499cae4efcac246	Voyager	37.7503184586354337	-122.433184053064281
3223	2019-09-22 22:36:55	2019-09-22	Iridian Baumbach-Brown	iridian.baumbach.brown@geemail.com	San Francisco	California	501860214429197	0d05c2e28d72fca5c08ea99a8ed36230	Diners Club / Carte Blanche	37.7505825941537196	-122.428322103085094
3224	2019-09-22 23:45:53	2019-09-22	Trilby Wunsch-Mraz	trilby.wunsch.mraz@woohoo.com	Berkeley	California	4310312664622085	80d55869ab60dbf49db9d140d2d63d5a	Discover	37.8786059843141842	-122.258238195413242
3225	2019-09-22 23:59:05	2019-09-22	Cordaro Langworth Jr.	cordaro.langworth.jr.@geemail.com	San Francisco	California	3046090026555511	8b724832e8b05b49fabb9186ebcbef74	Voyager	37.7828917893048128	-122.399123276095523
3226	2019-09-23 00:00:02	2019-09-23	Burdette Denesik	burdette.denesik@geemail.com	San Francisco	California	180081304964726556	0f0fe9175bbbc0887c15512e8bc6f4b4	Voyager	37.7689007529932326	-122.445059415052569
3227	2019-09-23 00:45:49	2019-09-23	Daniele Mitchell	daniele.mitchell@warmmail.com	Berkeley	California	4170618408968	e18bfca65dd1182ca0e913a9047cd9c4	VISA 16 digit	37.9032355100580531	-122.259678590988884
3228	2019-09-23 01:13:51	2019-09-23	Ms. Roselyn Jacobson	ms.roselyn.jacobson@geemail.com	San Francisco	California	4729834844795379	a0fc794cc70c5b788752fcb271149375	JCB 15 digit	37.785525261831701	-122.424092655292327
3229	2019-09-23 03:38:28	2019-09-23	Marylin Kris DDS	marylin.kris.dds@geemail.com	Tallahassee	Florida	4008364677659460	4940ca048ef9b1ee251225d7986d8dcb	JCB 16 digit	30.3662344618257158	-84.3108281521141549
3230	2019-09-23 04:43:29	2019-09-23	Mikeal Klocko	mikeal.klocko@woohoo.com	San Francisco	California	3112263429629293765	61abf06d8e2440ae1731db47e8bb2201	Discover	37.7589434803111246	-122.457788317370515
3231	2019-09-23 04:47:57	2019-09-23	Kate Wisoky MD	kate.wisoky.md@woohoo.com	Louisville	Kentucky	3013499815466744	9fc0e5c25e45953de0a15636fd7deaec	Mastercard	38.1647145479820651	-85.7411708188314066
3232	2019-09-23 05:02:51	2019-09-23	Dr. Jamiya Marks DVM	dr.jamiya.marks.dvm@geemail.com	San Antonio	Texas	3337056785925889866	89d99faf91328b605940b85c82c4a323	JCB 15 digit	29.4122260503541675	-98.4319455833010295
3233	2019-09-23 08:13:08	2019-09-23	Dr. Nautica Renner MD	dr.nautica.renner.md@geemail.com	San Francisco	California	3088510950274688786	d543cb719d6b9064e05f58cacb1bbfbe	American Express	37.7864255395862969	-122.454348694151321
3234	2019-09-23 08:45:45	2019-09-23	Madaline Ruecker	madaline.ruecker@geemail.com	South Bend	Indiana	3096418173280834640	a8e8a825e3790075e8eceaf3acbe0e50	VISA 16 digit	41.6091007862385425	-86.1744591826163315
3235	2019-09-23 09:07:20	2019-09-23	Erwin Keebler	erwin.keebler@geemail.com	Dallas	Texas	6011916534562032160	dc0254eaa98b858879f63f7c64dc1df8	JCB 15 digit	32.7939508249789498	-96.7667635258715535
3236	2019-09-23 10:29:47	2019-09-23	Mr. Regan Durgan	mr.regan.durgan@geemail.com	Oakland	California	3112153338385272249	25c9ee4f5790b09d9b30556d78216680	Discover	37.7849097305555404	-122.27665448827193
3237	2019-09-23 10:32:50	2019-09-23	Oralia Schuppe DDS	oralia.schuppe.dds@woohoo.com	Seattle	Washington	3088667983592873369	8b6855408f15c01042ddd512c570e081	Diners Club / Carte Blanche	47.609045491872358	-122.437278868483006
3238	2019-09-23 13:01:58	2019-09-23	Adam Lynch III	adam.lynch.iii@geemail.com	New York	New York	869911586726408896	f0cdd05f940cf5447d2e33f9ab8bf49b	Mastercard	40.6287071129064969	-73.8929343503795479
3239	2019-09-23 13:59:18	2019-09-23	Lacey Stracke-Johns	lacey.stracke.johns@geemail.com	San Diego	California	4644950015402421	e42ba8fba478e05bbccb749b81387fc9	Discover	32.9019199455224012	-117.083326269676917
3240	2019-09-23 14:32:17	2019-09-23	Kerry Gulgowski	kerry.gulgowski@geemail.com	Baton Rouge	Louisiana	51631309153131745	1abcdda6b72c555a65b070914f2bf40a	American Express	30.3472085823982951	-91.2144163355339259
3241	2019-09-23 15:54:40	2019-09-23	Kristie Rodriguez DDS	kristie.rodriguez.dds@geemail.com	Berkeley	California	3025496061977703	ad136d884c413ccb526a2d4bd205bbfc	JCB 16 digit	37.8902711877723135	-122.28024603164701
3242	2019-09-23 16:04:10	2019-09-23	Sherryl Deckow	sherryl.deckow@geemail.com	Oakland	California	3442027683616174	4055561ce9115a4fc30cb1a0f6260410	JCB 16 digit	37.8073541011285386	-122.286927832423288
3243	2019-09-23 16:15:27	2019-09-23	Lorin Hartmann	lorin.hartmann@geemail.com	Sugar Land	Texas	676117546235593	b4e4fd802b2430de2facd57ad8a469e8	VISA 13 digit	29.5488597636628896	-95.7002187604092001
3244	2019-09-23 16:28:42	2019-09-23	Louie O'Connell-Will	louie.o'connell.will@geemail.com	Escondido	California	55023887078846568	1683059a73c8286fe23e7ccec3ed02d6	VISA 16 digit	33.0897908674780297	-117.14427727798558
3245	2019-09-23 16:50:50	2019-09-23	Dr. Melville Kshlerin	dr.melville.kshlerin@warmmail.com	Berkeley	California	210060154347403174	fef0546e950ae52fa4fd231bd0d3a54c	Discover	37.8433759419483948	-122.311567915307904
3246	2019-09-23 17:37:47	2019-09-23	Dereon Osinski	dereon.osinski@warmmail.com	Pomona	California	6011790545916480823	a470081a62cf702758827b5ec569af23	Voyager	34.1257957614064225	-117.733632205190503
3247	2019-09-23 17:46:00	2019-09-23	Francine Cormier	francine.cormier@geemail.com	San Francisco	California	589303433081894	66bd5a44e9699fd020b5442c89230185	VISA 16 digit	37.7857869018596375	-122.379528417494939
3248	2019-09-23 20:25:02	2019-09-23	Mrs. Rhona Bergstrom PhD	mrs.rhona.bergstrom.phd@geemail.com	Oakland	California	180038218898024124	6fca89cdf63deb6b4339295f7e38cf49	American Express	37.7971980680724542	-122.258587691396144
3249	2019-09-23 20:39:15	2019-09-23	Mr. Dozier Yundt	mr.dozier.yundt@geemail.com	San Francisco	California	3158219202554359439	58c23f948d13817047cffea0ad00aad9	VISA 16 digit	37.7353013811776066	-122.413518791436658
3250	2019-09-23 21:08:39	2019-09-23	Ms. Marilla Wuckert DDS	ms.marilla.wuckert.dds@geemail.com	Tallahassee	Florida	869980986552383070	bfa59faee3463e85c360ca96f15fada9	JCB 16 digit	30.5326327938143187	-84.2214781382135982
3251	2019-09-23 23:10:03	2019-09-23	Lotta Von	lotta.von@woohoo.com	San Francisco	California	6011697126982379522	79f3694d3fc6f024cd03cbecaf9cc577	JCB 16 digit	37.769360084988719	-122.42659821310933
3252	2019-09-24 00:16:16	2019-09-24	Miss Naomi Ruecker	miss.naomi.ruecker@geemail.com	Santa Ana	California	4707248340994	8bdf26758386fda92f1b7fb94b6e9f7f	VISA 16 digit	33.6781213568162201	-117.965939121266828
3253	2019-09-24 00:50:21	2019-09-24	Gaines Daniel	gaines.daniel@geemail.com	New York	New York	3015633450659860	2d3c3b33400e2f931d6a137f99f86bd6	JCB 16 digit	40.7345017348639686	-73.9898821335181509
3254	2019-09-24 01:05:36	2019-09-24	Mr. Jamil Feest II	mr.jamil.feest.ii@geemail.com	Dallas	Texas	4449041170205325	334e585f8f7a25dc7d00cad66dbdc998	Discover	32.7991292792178726	-96.8355145707689218
3255	2019-09-24 01:15:48	2019-09-24	Mrs. Yasmine Wolf PhD	mrs.yasmine.wolf.phd@warmmail.com	San Francisco	California	3011155331026246	e76415bfa601246a7a0ced74db393c22	American Express	37.7290096606879288	-122.42615282204342
3256	2019-09-24 03:11:24	2019-09-24	Jayme Huel	jayme.huel@warmmail.com	Baton Rouge	Louisiana	4429128169388388	553a341ff63c78a502adf5fcfc957bc0	VISA 13 digit	30.4847692128017549	-91.0999864683594467
3257	2019-09-24 03:38:21	2019-09-24	Dr. Mearl Purdy II	dr.mearl.purdy.ii@warmmail.com	New York	New York	3762976777110186	4f23c9f2ae5730f10190ab2f7343f155	Discover	40.6990583799071572	-74.017099559017268
3258	2019-09-24 06:27:32	2019-09-24	George D'Amore-Carter	george.d'amore.carter@geemail.com	San Francisco	California	53930415023593317	7198d89c0b6a306916b64ffeb3b11393	JCB 16 digit	37.7655552162337926	-122.448682705394219
3259	2019-09-24 06:29:34	2019-09-24	Ms. Rheta Simonis	ms.rheta.simonis@geemail.com	Oakland	California	3088284517626874002	6aea58bbbe7b3bf404d6ff19be497bfd	Maestro	37.7847751325970549	-122.274837638464092
3260	2019-09-24 06:38:28	2019-09-24	Tory Aufderhar	tory.aufderhar@warmmail.com	Berkeley	California	4628112669115540	c2c5350e86050084178cf95aadf1087c	VISA 16 digit	37.8454619187330223	-122.291579616627345
3261	2019-09-24 08:16:19	2019-09-24	Alvan Hickle-Schiller	alvan.hickle.schiller@warmmail.com	Phoenix	Arizona	3014372098933830	85bacc76cb5b6d18cd8d4f6ef751bb2c	Maestro	33.6491955914933243	-112.058539959315596
3262	2019-09-24 12:03:17	2019-09-24	Ishmael O'Hara	ishmael.o'hara@geemail.com	Oakland	California	3041994723178185	e9d70c5085ab0f1f9174f5c1b3d45d56	Diners Club / Carte Blanche	37.7618903773760266	-122.263871855303293
3263	2019-09-24 12:09:51	2019-09-24	Mr. Edmund Becker DDS	mr.edmund.becker.dds@geemail.com	Berkeley	California	502088728249868	5aef16f052bfb9256d4c1a5d561ece09	VISA 16 digit	37.8763938197490546	-122.231716088789085
3264	2019-09-24 12:13:23	2019-09-24	Rae Gislason	rae.gislason@warmmail.com	San Francisco	California	869989758779578829	0419c2006c3501a69729c02c5512d781	Discover	37.7621806045874706	-122.426117807950732
3265	2019-09-24 12:21:40	2019-09-24	Dr. Carry Watsica DVM	dr.carry.watsica.dvm@geemail.com	San Francisco	California	869945371653353278	9da7e1e6e72f84ae72d2afe947033381	Maestro	37.7565413209819667	-122.437815786581439
3266	2019-09-24 13:23:58	2019-09-24	Destin Pouros	destin.pouros@geemail.com	Lexington	Kentucky	3050207339567035	9c7b372d6f7f8efbe8eb22b2412f15a1	VISA 13 digit	38.0039082442753013	-84.4640474857196182
3267	2019-09-24 14:04:50	2019-09-24	Samuel Boyle Jr.	samuel.boyle.jr.@geemail.com	Philadelphia	Pennsylvania	4505893956892291	833db8a1f6abfcd533b603a1fd5d3643	JCB 15 digit	40.0045776755973677	-75.1089776732858354
3268	2019-09-24 14:29:44	2019-09-24	Aubrey Batz	aubrey.batz@geemail.com	Oakland	California	4390153666272922	3723627af8860dc4d07bd3d4719b27dc	Diners Club / Carte Blanche	37.8277041912556982	-122.256641185466052
3269	2019-09-24 15:51:53	2019-09-24	Dr. Leoma Christiansen	dr.leoma.christiansen@geemail.com	Houston	Texas	630412502211027	f2e6fb50f796538a2c332242d400955c	VISA 16 digit	29.8285953769072876	-95.3852274147342882
3270	2019-09-24 17:05:15	2019-09-24	Helyn Gottlieb	helyn.gottlieb@woohoo.com	Oakland	California	3794159448835075	33715296ee5f6c133a9cf39a12321a87	JCB 16 digit	37.7736046407874397	-122.256625042261803
3271	2019-09-24 17:09:23	2019-09-24	Jo Bednar	jo.bednar@geemail.com	San Francisco	California	54700552205596862	ee9a779d1547626cb7e93f59e48f47a3	Diners Club / Carte Blanche	37.7788600089481292	-122.41743517083296
3272	2019-09-24 17:36:42	2019-09-24	Thyra Eichmann	thyra.eichmann@warmmail.com	Detroit	Michigan	4319836159499097	af0f9e8ecce707a376d4bd0a2b04d3ca	Mastercard	42.2863553947228965	-83.0419024786565387
3273	2019-09-24 18:34:07	2019-09-24	Lester Deckow	lester.deckow@geemail.com	San Francisco	California	4049835436489233	16bfe77fbbbf7078f6ed0fce9cec41dc	Maestro	37.7869665623153779	-122.419360987002392
3274	2019-09-24 19:47:50	2019-09-24	Elana Toy	elana.toy@geemail.com	San Francisco	California	3112419504901218285	23eff5f9da190a1a9e8dccdc4d4326ef	JCB 16 digit	37.7839807323421581	-122.41303902025777
3275	2019-09-24 19:55:24	2019-09-24	Jacklyn McGlynn	jacklyn.mcglynn@warmmail.com	Berkeley	California	869988256619955407	fd5245eb7259f7205e38f0ccef333e48	JCB 16 digit	37.8510119341457028	-122.272722205831073
3276	2019-09-24 21:39:13	2019-09-24	Devyn Boyer-Beer	devyn.boyer.beer@warmmail.com	San Francisco	California	180050626816794904	7f2582e80a7a40b6d5106cd89a42747f	Discover	37.7805681869437535	-122.427584797115102
3277	2019-09-24 21:42:24	2019-09-24	Leonore Kozey	leonore.kozey@geemail.com	Louisville	Kentucky	4847080194222	1a3291dd2b44316f775f724f0ca6b973	JCB 16 digit	38.1832786647040408	-85.5518939720537617
3278	2019-09-24 23:05:44	2019-09-24	Ashlee Koelpin	ashlee.koelpin@geemail.com	New York	New York	53306698157785504	b79124fa9671ccfabf24d112aa01ce5b	VISA 13 digit	40.6296373835522644	-74.0360436431959243
3279	2019-09-25 00:50:00	2019-09-25	Mona Feeney DDS	mona.feeney.dds@warmmail.com	Moreno Valley	California	4189672516102	49008d801bbe013d57dea58d58fe6c08	VISA 13 digit	33.9954780056599475	-117.19582915221973
3280	2019-09-25 02:28:15	2019-09-25	Elmore Konopelski DDS	elmore.konopelski.dds@woohoo.com	Virginia Beach	Virginia	3337806705109364398	f1983c1734b185e0eae346eaad81c7b3	VISA 16 digit	36.8160164863988797	-75.9409225611154
3281	2019-09-25 02:48:10	2019-09-25	Alondra Frami	alondra.frami@woohoo.com	Henderson	Nevada	3088029714715827237	cdb83d08c9915ebf328414153121323a	Maestro	36.0954316496782042	-115.109714309747147
3282	2019-09-25 03:09:16	2019-09-25	Elian Waters	elian.waters@geemail.com	Oakland	California	4074330330121502	3f11958b347f0c91b74e16503ab75d18	Maestro	37.8196875141861142	-122.304973848445002
3283	2019-09-25 03:30:06	2019-09-25	Daisie Corwin	daisie.corwin@geemail.com	Berkeley	California	869915453299780100	e2705da6fd9a4395c6a75d52cbea7d4b	Diners Club / Carte Blanche	37.8974121373683417	-122.287867888175597
3284	2019-09-25 04:13:18	2019-09-25	Iesha Kshlerin DDS	iesha.kshlerin.dds@geemail.com	Chula Vista	California	4538759133811	82a22c630ad7312d3bf8632dc9668349	JCB 15 digit	32.538687930186093	-117.110401706700017
3285	2019-09-25 04:46:37	2019-09-25	Golden Weissnat	golden.weissnat@geemail.com	San Francisco	California	210042495026813073	74453c7453effcd91be2e3ff4a2894cc	VISA 16 digit	37.7516328980862639	-122.44001384847401
3286	2019-09-25 05:34:07	2019-09-25	Essa Parisian	essa.parisian@geemail.com	San Antonio	Texas	180010726661580918	6964677da85c4fffbae3c44572871053	VISA 16 digit	29.52898420561813	-98.5074686204385017
3287	2019-09-25 06:50:03	2019-09-25	Leyla Dach	leyla.dach@geemail.com	San Francisco	California	3112893072118632081	49ffeb543d189d027dfc5936c7f3d4cf	JCB 16 digit	37.7440387037117446	-122.466548965910164
3288	2019-09-25 07:13:13	2019-09-25	Dr. Teagan Hoeger	dr.teagan.hoeger@geemail.com	San Francisco	California	3461289072134245	d1899cb38308532be6f3afa3da08acd9	VISA 16 digit	37.7333873969438898	-122.422419910228186
3289	2019-09-25 07:56:10	2019-09-25	Marc Leffler IV	marc.leffler.iv@geemail.com	San Francisco	California	4386587059327734	456a70563a5694837fe8475fce268f3c	Diners Club / Carte Blanche	37.7594209978695758	-122.448233748574921
3290	2019-09-25 08:26:19	2019-09-25	Dorthey Feeney	dorthey.feeney@geemail.com	Chicago	Illinois	589349816323262	fb4df7a76e2b7586e0684ba529c9a955	Diners Club / Carte Blanche	41.8384551459759493	-87.5908602142270638
3291	2019-09-25 11:28:42	2019-09-25	Ezekiel Gulgowski	ezekiel.gulgowski@warmmail.com	San Francisco	California	4003937001521	869aed2bca399cef23d82ad54122c96b	VISA 16 digit	37.73716394053492	-122.41993721437683
3292	2019-09-25 13:02:53	2019-09-25	Jolette Gorczany-Runolfsdottir	jolette.gorczany.runolfsdottir@woohoo.com	New York	New York	4995044323587043	9088331c2e7ff417e9ad26ce9d32f5c7	Discover	40.6336806534547321	-73.9763394359860484
3293	2019-09-25 13:19:03	2019-09-25	Posey Gusikowski-Boyle	posey.gusikowski.boyle@geemail.com	Santa Clara	California	4702353813630872	39938a0bdf1571ede14802e89f031afc	JCB 15 digit	37.3884340485375404	-121.978783173486221
3294	2019-09-25 14:03:47	2019-09-25	Mrs. Retha D'Amore	mrs.retha.d'amore@geemail.com	Minneapolis	Minnesota	3027850943583519	8e1fd79358bec7b664f8bf97e638670c	American Express	44.94303305583	-93.2444619240976778
3295	2019-09-25 15:27:56	2019-09-25	Sherryl Doyle	sherryl.doyle@geemail.com	San Francisco	California	3096244594114656638	aede6b9d2bb5a57c9813ea68b04d2596	Maestro	37.7953457443720211	-122.394233073798304
3296	2019-09-25 16:11:58	2019-09-25	Unnamed Emard	unnamed.emard@geemail.com	San Francisco	California	869954583053866570	6924a514db23310eeba0edd956ebf4c6	VISA 13 digit	37.7726776373641115	-122.409494976335125
3297	2019-09-25 16:19:32	2019-09-25	Berta Kassulke	berta.kassulke@geemail.com	Providence	Rhode Island	3497403504336850	5a3a2e783bb596bd323a23c254f9def0	JCB 16 digit	41.9230105956405339	-71.3197586817119316
3298	2019-09-25 16:59:59	2019-09-25	Jerald Bogisich	jerald.bogisich@warmmail.com	Laredo	Texas	4962795321959513	1660b58876d6dacf9bdee5e51b6ab583	Maestro	27.5596601583246148	-99.4570471787832702
3299	2019-09-25 17:37:20	2019-09-25	Donn Gleason	donn.gleason@warmmail.com	San Francisco	California	52563466418162063	28db94e0eaa24ca23ff5978661f41757	Mastercard	37.7327002087733945	-122.420517154017162
3300	2019-09-25 18:07:09	2019-09-25	Quincy Miller	quincy.miller@warmmail.com	Chandler	Arizona	4796874068169	2924fefce702d50ff7a57ee4beb28527	Diners Club / Carte Blanche	33.298059831475463	-111.878099089197448
3301	2019-09-25 19:24:19	2019-09-25	Golden Satterfield	golden.satterfield@geemail.com	Seattle	Washington	4977183591329	a9d4d336ed30d3057d2e679f2e9a8aa8	JCB 15 digit	47.5864014147240653	-122.260181734377142
3302	2019-09-25 19:25:57	2019-09-25	Marlana DuBuque	marlana.dubuque@geemail.com	San Francisco	California	4181546008941240	66df8f8e67efc7f6be6445815e6dcbce	VISA 16 digit	37.765147783421142	-122.444688965305502
3303	2019-09-25 19:36:55	2019-09-25	Devyn Wuckert	devyn.wuckert@geemail.com	Oakland	California	3337467675709671262	54aab558c4d0168741462d863f986388	Maestro	37.7914157725684916	-122.274227334448128
3304	2019-09-25 20:53:24	2019-09-25	Consuelo Beier	consuelo.beier@warmmail.com	Berkeley	California	4618209977353201	0a5be6c9c911bb7d73a8e25be5453fd8	Maestro	37.8832824557632506	-122.288287737766822
3305	2019-09-25 21:00:42	2019-09-25	Alex Marvin	alex.marvin@geemail.com	San Francisco	California	3096748662467688200	cb0c9bec9d08ba0efd9fdf33bcddaddd	Discover	37.766526193435439	-122.389941027152688
3306	2019-09-25 21:17:50	2019-09-25	Maxine Marvin	maxine.marvin@geemail.com	Elgin	Illinois	3799981957869723	a7b8d8b6d4b6c27fab3b4e9c7fca0bfd	JCB 16 digit	42.1267877763886034	-88.3460462258949946
3307	2019-09-25 22:17:14	2019-09-25	Hyrum Ortiz	hyrum.ortiz@geemail.com	San Francisco	California	210068673604993488	e98b919a1e6f9f8073c9d6cfc6a52608	JCB 16 digit	37.7886655426756448	-122.411658812895524
3308	2019-09-25 23:25:37	2019-09-25	Anabelle Spencer	anabelle.spencer@geemail.com	Tempe	Arizona	869931742683488191	3e84152035297bef77abaac3d2746cb1	JCB 16 digit	33.470989431013912	-112.009744100089364
3309	2019-09-26 00:15:43	2019-09-26	Kole Bernier	kole.bernier@woohoo.com	San Francisco	California	4149165880910	0bc7a82ca96b6d514e07820d9129c6df	VISA 13 digit	37.766287527632862	-122.42735023966037
3310	2019-09-26 01:27:52	2019-09-26	Ridge Dare-Hansen	ridge.dare.hansen@geemail.com	Milwaukee	Wisconsin	6011223202332349037	24a515a328b906e72008e0b5edc0aede	Discover	43.0345606301531163	-88.0123843240186545
3311	2019-09-26 02:04:52	2019-09-26	Clyda Raynor PhD	clyda.raynor.phd@geemail.com	Las Vegas	Nevada	502014475357720	abffbdf030ebdd47eb1d9d12d376430a	JCB 16 digit	36.2853919517349439	-115.353776924752069
3312	2019-09-26 02:20:04	2019-09-26	Katie Stiedemann	katie.stiedemann@geemail.com	Tacoma	Washington	3528512124552016494	799bca7244c4d39f9173ff6f222ad2e6	Diners Club / Carte Blanche	47.246038086212053	-122.55888095588908
3313	2019-09-26 02:30:41	2019-09-26	Ferd Kuhic	ferd.kuhic@geemail.com	San Francisco	California	3759874029613781	dcd8a033a17aa6dc96513344480f2ab1	JCB 16 digit	37.7414271583937548	-122.412440354791002
3314	2019-09-26 03:19:50	2019-09-26	Antione Flatley	antione.flatley@warmmail.com	San Francisco	California	6011045262395374260	5f58c65bc6870254b09b6233e8dfc6d8	JCB 16 digit	37.7611121766272078	-122.429227771227445
3315	2019-09-26 04:10:24	2019-09-26	Ottis Hammes	ottis.hammes@woohoo.com	Oceanside	California	4922550716238927	e61948da57c2a7f741d18330721fdbe2	VISA 16 digit	33.1799392129648467	-117.235519396521894
3316	2019-09-26 04:23:55	2019-09-26	Andre Reilly	andre.reilly@geemail.com	Fort Worth	Texas	3528161293693541092	9d986c5c20de31d647147aa00c554350	JCB 15 digit	32.8031822626534861	-97.2624693557906852
3317	2019-09-26 04:54:46	2019-09-26	Dylan Yost	dylan.yost@geemail.com	Louisville	Kentucky	502081778813204	bfb4993b780e3612817d0ed97076a563	Maestro	38.1011553231064184	-85.6849872056931332
3318	2019-09-26 05:43:02	2019-09-26	Izola Eichmann	izola.eichmann@geemail.com	San Francisco	California	3112699213923956853	e1cb5be19d2086763d149b04963ff29a	VISA 16 digit	37.7550858033633574	-122.413706604146554
3319	2019-09-26 07:01:30	2019-09-26	Grayson Wyman	grayson.wyman@geemail.com	Berkeley	California	3712619707319771	d2d3863244387f757e4cf3408d5f13bd	VISA 13 digit	37.851938074050409	-122.261557277830093
3320	2019-09-26 07:29:01	2019-09-26	Bliss Hudson	bliss.hudson@warmmail.com	San Francisco	California	3020214385702201	52ee45bfe868d1a944bc16221516ab33	VISA 13 digit	37.7665076241244151	-122.428033212266698
3321	2019-09-26 08:24:40	2019-09-26	Keshia Prohaska	keshia.prohaska@warmmail.com	Lancaster	California	6011674977911248551	abfd02ee197ef6193c8a4e8633e96667	JCB 16 digit	34.6080198425579866	-118.122679156947129
3322	2019-09-26 08:35:24	2019-09-26	Graciela Larson-Roob	graciela.larson.roob@geemail.com	San Francisco	California	4165056674116184	dc095c98c3684f67b1d76a8bf43f959f	JCB 16 digit	37.7746628605341996	-122.428499976128293
3323	2019-09-26 09:49:52	2019-09-26	Ms. Collette Hammes DDS	ms.collette.hammes.dds@geemail.com	Victorville	California	675939426686851	ac625f298b63800c9690b182a0ff0eff	VISA 13 digit	34.5810510685432746	-117.362980797296757
3324	2019-09-26 10:07:45	2019-09-26	Vincent Sauer	vincent.sauer@geemail.com	San Francisco	California	869930385991434738	3434f1b2293dd3fbb465e742bbfc53ca	Mastercard	37.775905864143553	-122.417959346165063
3325	2019-09-26 12:58:37	2019-09-26	Wing Mills II	wing.mills.ii@geemail.com	Los Angeles	California	3337406091646812502	425fcac4fa29edaa5fd6a3fb7783a921	VISA 16 digit	34.0210255399677877	-118.386658172588042
3326	2019-09-26 13:22:32	2019-09-26	Mr. Darrien Homenick	mr.darrien.homenick@geemail.com	San Francisco	California	676280495144372	054a0586cd9504c7d1e79b155ff6b914	VISA 16 digit	37.7479005873282745	-122.442078986075046
3327	2019-09-26 13:35:09	2019-09-26	Dr. Ogden Carter PhD	dr.ogden.carter.phd@geemail.com	San Francisco	California	869972121878575940	7402e8577ff75676fc3433684fad2210	Diners Club / Carte Blanche	37.7681953716058842	-122.439560618565181
3328	2019-09-26 15:20:35	2019-09-26	Evans Gorczany	evans.gorczany@woohoo.com	Virginia Beach	Virginia	3096959793833861942	c0c79dd33276bdcfa915a87456c69f76	JCB 15 digit	36.7735768385417785	-75.9255399758599623
3329	2019-09-26 15:24:58	2019-09-26	Mr. Ceasar Hudson Jr.	mr.ceasar.hudson.jr.@woohoo.com	San Francisco	California	3047161031646279	699f881f92dfd7ed05bc98304351a6ba	JCB 15 digit	37.7574014815070242	-122.452316754501595
3330	2019-09-26 16:27:47	2019-09-26	Gussie Parisian	gussie.parisian@warmmail.com	Berkeley	California	6011911719593027504	1de17ea1eafc0c2cd5c4e3371cfa5de2	VISA 16 digit	37.839651094432547	-122.274339256908348
3331	2019-09-26 17:06:28	2019-09-26	Madilynn Rice	madilynn.rice@geemail.com	New York	New York	4164194648053372	8d7a22e837dd740e2dae3d3d74d9091a	JCB 15 digit	40.7038398693539207	-73.9204627996206227
3332	2019-09-26 18:38:10	2019-09-26	Ceasar Kub	ceasar.kub@geemail.com	San Francisco	California	3008629648152468	63b19a5738d9d5ad05012f4cc8075f1a	VISA 13 digit	37.7532996198377333	-122.452185020511635
3333	2019-09-26 19:33:12	2019-09-26	Afton Farrell	afton.farrell@geemail.com	Sunnyvale	California	6011004652542590835	a2eefe794e7e06b44aee376a27932f7e	JCB 15 digit	37.436137730254984	-122.0056346460443
3334	2019-09-26 22:26:57	2019-09-26	Dr. Giuseppe Schultz V	dr.giuseppe.schultz.v@warmmail.com	Baton Rouge	Louisiana	4437242949043757	d8cbf1b093c583b3558f2c0ff88bdc39	JCB 16 digit	30.3674585218288016	-91.1778549701083421
3335	2019-09-26 22:32:35	2019-09-26	Katheryn Abernathy	katheryn.abernathy@geemail.com	San Francisco	California	4571540182607	c8c7b2f97cccaf4d6f352ce1f1d25896	Diners Club / Carte Blanche	37.7483840929683083	-122.44368080350992
3336	2019-09-26 23:56:47	2019-09-26	Lorene Torphy DVM	lorene.torphy.dvm@geemail.com	Chicago	Illinois	4491518490124	ca0a54ca3df5a6f430a034ff47672eab	Mastercard	41.9312001790687461	-87.7063722937863304
3337	2019-09-27 00:03:06	2019-09-27	Autry Rempel-Pouros	autry.rempel.pouros@geemail.com	Fort Wayne	Indiana	3404710652638610	4fb1d735af52fd163d847ba94c920405	JCB 16 digit	41.0176241189491009	-85.1810537293307561
3338	2019-09-27 01:08:37	2019-09-27	Lynnette Altenwerth	lynnette.altenwerth@woohoo.com	San Francisco	California	3405138924218236	ab5672582f0292e3b98f635c77fbdf14	VISA 16 digit	37.7759255654556085	-122.450192981310252
3339	2019-09-27 01:34:21	2019-09-27	Mr. Nicklaus Bartoletti	mr.nicklaus.bartoletti@geemail.com	Chicago	Illinois	3528516002084575532	79d58390519b6b6c7dbaae18a2c1f502	Discover	41.9217443051118437	-87.6417374339915796
3340	2019-09-27 01:51:36	2019-09-27	Barney Orn PhD	barney.orn.phd@woohoo.com	Pittsburgh	Pennsylvania	54518561304606367	0a924c5c14d5845f0d40a5637c8421aa	VISA 16 digit	40.489748743637648	-80.0427356895230702
3341	2019-09-27 02:56:35	2019-09-27	Dr. Merwin Nader PhD	dr.merwin.nader.phd@geemail.com	Bridgeport	Connecticut	4996550049324304	a63b0d248f857cf766c5318b98b640f2	JCB 16 digit	41.1401749396394933	-73.1543074843373233
3342	2019-09-27 03:20:47	2019-09-27	Wyatt Macejkovic	wyatt.macejkovic@geemail.com	Durham	North Carolina	180061695243922039	a78cfdd26b72622dc8405f83d814f3e5	JCB 16 digit	35.9131053002797032	-78.8884524994898584
3343	2019-09-27 03:31:25	2019-09-27	Ms. Iesha Considine	ms.iesha.considine@geemail.com	Hayward	California	54561367811378094	61eab8f31579585e5266ca86b6579b62	JCB 16 digit	37.6842766115896453	-122.070295118379974
3344	2019-09-27 05:15:13	2019-09-27	Page Hettinger-Rosenbaum	page.hettinger.rosenbaum@woohoo.com	Las Vegas	Nevada	3096664987017808127	e05ed7dd4d688a3df6cd9348f2884791	Discover	36.230225316491719	-115.358915329652277
3345	2019-09-27 05:46:33	2019-09-27	Ms. Sydni Gottlieb	ms.sydni.gottlieb@geemail.com	Jackson	Mississippi	4743698850570	dd31db292b045d1360ae53ccf59382d3	VISA 16 digit	32.2307089149665131	-90.2054700164564025
3346	2019-09-27 05:50:07	2019-09-27	Amirah Renner	amirah.renner@warmmail.com	San Francisco	California	869927197387870119	55543568051bdd439704f0d8dd14be3f	JCB 16 digit	37.7430188630382943	-122.421959472116342
3347	2019-09-27 05:54:52	2019-09-27	Mr. Early O'Reilly	mr.early.o'reilly@warmmail.com	San Francisco	California	561227833145611	b206cbd6f4be0db09d43ab0195f199a3	JCB 16 digit	37.8177069562998653	-122.437215134314528
3348	2019-09-27 05:57:05	2019-09-27	Dr. Raynard Hickle	dr.raynard.hickle@woohoo.com	Newport News	Virginia	180032595326588358	9b2a244270711e8b55eff9a76f3d8a22	JCB 16 digit	37.076719731221722	-76.494975879581645
3349	2019-09-27 06:26:58	2019-09-27	Lavar Goyette	lavar.goyette@geemail.com	San Francisco	California	3019965721673106	2eef5b477489a36cef1699637821af0c	Voyager	37.7523124838864703	-122.43183949013661
3350	2019-09-27 09:16:27	2019-09-27	Mrs. Maurine Friesen	mrs.maurine.friesen@geemail.com	Austin	Texas	6011211148281566515	14890da8a246e2bbc6f75ba86b899029	JCB 16 digit	30.2063698812980199	-97.689177649259193
3351	2019-09-27 10:06:38	2019-09-27	Brigid Gutkowski	brigid.gutkowski@geemail.com	Anaheim	California	210022095321238580	85559e240fd67c64fbad35369ec1aaa7	VISA 16 digit	33.8783053376078627	-117.781395535517845
3352	2019-09-27 10:37:02	2019-09-27	Rey Heaney III	rey.heaney.iii@warmmail.com	Oakland	California	3096305782888150849	6946bc45b57bcc177e5623d500eca8cb	Maestro	37.8006685885268396	-122.281978065989094
3353	2019-09-27 12:25:08	2019-09-27	Uriel Swift	uriel.swift@geemail.com	San Francisco	California	3429152602247906	bd01231b11a3fcff1d44ef0c7a2ad04e	Diners Club / Carte Blanche	37.8186457411806103	-122.429771570890381
3354	2019-09-27 12:41:19	2019-09-27	Kamron Predovic	kamron.predovic@geemail.com	San Francisco	California	180040731510558820	9dcbde8449fa191d23d6535c32b6b53b	Voyager	37.7713405051086113	-122.457174976834068
3355	2019-09-27 13:29:14	2019-09-27	Ayanna Bahringer	ayanna.bahringer@geemail.com	San Francisco	California	3337211102820323557	1696b564687a07d8b77bd9cfaa97853b	Voyager	37.7789450971757788	-122.404928087163512
3356	2019-09-27 14:05:48	2019-09-27	Della Rutherford	della.rutherford@geemail.com	San Francisco	California	3337667524213141420	81b29dc2801f444673c92e7aa25590b8	Maestro	37.7407014680325759	-122.424284457175034
3357	2019-09-27 14:06:11	2019-09-27	Dr. Nile Kertzmann	dr.nile.kertzmann@geemail.com	San Francisco	California	4499662851536503	4d1207449342a5b25685f52ebc4a738d	JCB 16 digit	37.7675135020514645	-122.415683310246777
3358	2019-09-27 14:29:21	2019-09-27	Maxie Crona	maxie.crona@geemail.com	Frisco	Texas	3337383729744586505	ec21b2cf4cf47268883f0437b3bdf263	VISA 16 digit	33.1449063700620101	-96.7635728738479202
3359	2019-09-27 14:57:51	2019-09-27	Reino Greenholt-Kilback	reino.greenholt.kilback@geemail.com	San Francisco	California	6011314499176607724	fb61f4e31636fff61640983641363657	Diners Club / Carte Blanche	37.807506905277549	-122.403088025247541
3360	2019-09-27 15:45:00	2019-09-27	Leslie Braun	leslie.braun@warmmail.com	Modesto	California	3474288102855550	9b9336cc0a1e7b0aae83f51d6baf5bdf	JCB 15 digit	37.5548458927776707	-120.989145210219547
3361	2019-09-27 16:05:11	2019-09-27	Leo Macejkovic	leo.macejkovic@geemail.com	San Francisco	California	180004050635123939	0d0f54e4ad6399d04903e4b5e0198e4d	VISA 16 digit	37.7629839676699817	-122.395812403459331
3362	2019-09-27 18:32:20	2019-09-27	Mr. Donovan Jacobi DDS	mr.donovan.jacobi.dds@geemail.com	Oakland	California	180031365814863379	ddca0bae4c71b47e085e65070b6c6b2b	JCB 16 digit	37.7598331870160777	-122.272453475057873
3363	2019-09-27 18:33:53	2019-09-27	Leeann Abshire	leeann.abshire@geemail.com	San Francisco	California	4177601440961128	2d4738d9fe54a748bc9dfa6520aa046a	Maestro	37.7823647036902344	-122.450437622412252
3364	2019-09-27 19:33:56	2019-09-27	Orpha Cartwright-Nicolas	orpha.cartwright.nicolas@geemail.com	Bakersfield	California	4016407923912850	562255c790ad6d0b1f5616370120dbc7	JCB 16 digit	35.2516814163129766	-118.977469400949033
3365	2019-09-27 19:40:13	2019-09-27	Mr. Marlyn Daniel I	mr.marlyn.daniel.i@woohoo.com	San Francisco	California	6011205848670795934	36b1809f59ef1baf5180e822461b4cf7	Maestro	37.767527012052355	-122.420763804456612
3366	2019-09-27 20:07:53	2019-09-27	Dr. Duard Mueller IV	dr.duard.mueller.iv@woohoo.com	San Francisco	California	3096581679392181432	dd095b7723744b48ddc5cfb36db1c870	Discover	37.7981771747062893	-122.454566500338927
3367	2019-09-27 20:35:11	2019-09-27	Mr. Plummer Kunde MD	mr.plummer.kunde.md@geemail.com	Birmingham	Alabama	4591055926946996	6b58185a81e3c37f1c351222e2500003	Maestro	33.57276523222923	-86.7509900554325526
3368	2019-09-27 20:43:10	2019-09-27	Dr. Ardyce Greenfelder DVM	dr.ardyce.greenfelder.dvm@geemail.com	Nashville	Tennessee	52356057964713473	a5ddd763c1cec8d9355f79672bc4831c	Mastercard	36.1602083639364693	-86.7608725926745592
3369	2019-09-27 21:06:16	2019-09-27	Marcela Green-Herzog	marcela.green.herzog@woohoo.com	Spokane	Washington	52565970609771499	a3154323faec46dc64aa7cc299ea4696	Maestro	47.7026616526540366	-117.484322321591151
3370	2019-09-27 21:42:57	2019-09-27	Bennett Kohler	bennett.kohler@geemail.com	Berkeley	California	3426876780563790	0292ff31b8001e8b1b43b1460af171ed	Discover	37.8808150030609312	-122.250844701094863
3371	2019-09-27 21:49:53	2019-09-27	Erline Anderson	erline.anderson@geemail.com	Pasadena	Texas	3051214020843484	5474a81a444ff76bcb41a8cb3d3094e9	VISA 13 digit	29.693462175397574	-95.1772274897381578
3372	2019-09-28 00:02:27	2019-09-28	Beau Baumbach	beau.baumbach@geemail.com	San Francisco	California	869995839782764192	b167994408863f2afe14be80661a741f	Maestro	37.7799957519508354	-122.422148030739322
3373	2019-09-28 00:52:24	2019-09-28	Hank Paucek PhD	hank.paucek.phd@woohoo.com	Oakland	California	3449256733159470	58f2047eeae5b80feeef366442c25113	Voyager	37.7941227277548535	-122.264882002298137
3374	2019-09-28 00:56:14	2019-09-28	Mr. Edsel Turner	mr.edsel.turner@geemail.com	Bakersfield	California	3158409208175988134	1041adfec7deaa867164672bee83fea2	Discover	35.3835566657304739	-119.097209009369081
3375	2019-09-28 01:20:38	2019-09-28	Alyssa Romaguera	alyssa.romaguera@geemail.com	San Francisco	California	3424951965305937	bb78f55d13e6a6c17bddf66596bc414d	American Express	37.7652242266625393	-122.460226593660224
3376	2019-09-28 04:42:53	2019-09-28	Gilda Howe	gilda.howe@warmmail.com	San Francisco	California	180021902328029782	150836b8d24bfbfd5b09484b58076c26	JCB 15 digit	37.7659222639477505	-122.434225019871036
3377	2019-09-28 05:09:40	2019-09-28	Hanna Kautzer-Schroeder	hanna.kautzer.schroeder@geemail.com	Dallas	Texas	3425047995749456	51c7f6f1f8209cb2667a1c1391795f08	JCB 15 digit	32.7053742972474595	-96.7770993772856798
3378	2019-09-28 05:11:12	2019-09-28	Lillis Mertz	lillis.mertz@woohoo.com	Frisco	Texas	3412018147431793	e95d7bcd0aba72bed18f3c73c354a417	Voyager	33.2307992255311433	-96.9044593521602451
3379	2019-09-28 05:48:02	2019-09-28	Ola Rau DDS	ola.rau.dds@geemail.com	Kansas City	Missouri	4292029666040	e647fd3710ddd310c2180b8c91e4ee94	Discover	39.1498245907783513	-94.5460988740194637
3380	2019-09-28 06:15:13	2019-09-28	Ottie Towne	ottie.towne@woohoo.com	San Francisco	California	3158592912247418288	359176c0937e91aa347953d54e88b77d	Mastercard	37.7954310982583124	-122.454200848456225
3381	2019-09-28 07:31:55	2019-09-28	Luigi Senger	luigi.senger@geemail.com	Lubbock	Texas	561218611302946	175a55bbe03d110ece8d71aba862c24a	VISA 13 digit	33.5908662247512524	-101.95569635856971
3382	2019-09-28 08:14:24	2019-09-28	Ms. Cadence Legros	ms.cadence.legros@geemail.com	San Francisco	California	3005000292975286	ec55769a6946e1dc643a4f73aee49775	Mastercard	37.7720106515519021	-122.40802258438373
3383	2019-09-28 09:40:41	2019-09-28	Mr. Tayler Howe	mr.tayler.howe@geemail.com	San Francisco	California	675980886656398	ed4131f7863946584c8c07b0eb300d77	JCB 16 digit	37.7768486475748517	-122.429579357762051
3384	2019-09-28 09:49:19	2019-09-28	Merle Bahringer	merle.bahringer@geemail.com	San Francisco	California	869911242374390768	d2bbd4091f7f91d8b4a9c05032ca498c	JCB 15 digit	37.7651386816371755	-122.444474458242269
3385	2019-09-28 10:19:57	2019-09-28	Cleora Moore PhD	cleora.moore.phd@warmmail.com	Oakland	California	869954902995169416	b81114b52669455de435e95531e65248	Voyager	37.8095707178908143	-122.261940196651352
3386	2019-09-28 10:56:49	2019-09-28	Abbott Hettinger	abbott.hettinger@geemail.com	Chicago	Illinois	4221493734015043	a9e263b47520a70bef8555b8db1680cf	Voyager	41.8738131732981671	-87.6205869021855221
3387	2019-09-28 10:58:02	2019-09-28	Brande Beier	brande.beier@geemail.com	Fairfield	California	4279670178553487	77c5cddd29f93a9ea961f55b322c22dd	VISA 16 digit	38.279642989452185	-121.999655929115036
3388	2019-09-28 11:28:59	2019-09-28	Mrs. Mozelle Lesch MD	mrs.mozelle.lesch.md@geemail.com	Glendale	Arizona	210048066091149406	44fcf87bb894a847d32d883ec3a38d2f	VISA 16 digit	33.622597407432643	-112.154733342563361
3389	2019-09-28 11:29:02	2019-09-28	Pierre Goodwin DDS	pierre.goodwin.dds@warmmail.com	San Francisco	California	3001375842302049	b24d859a773efeca6615216e5d7907ee	VISA 16 digit	37.7805864335542907	-122.423118355972775
3390	2019-09-28 12:52:30	2019-09-28	Dr. Creed Will	dr.creed.will@woohoo.com	San Francisco	California	3337918874254373920	40b23c455887264330638f3424905452	Maestro	37.7766872468086063	-122.440476574802616
3391	2019-09-28 13:03:02	2019-09-28	Verna Dickinson PhD	verna.dickinson.phd@warmmail.com	San Francisco	California	3158602792802906218	67d31b701a66c4d267f15eacd717f775	JCB 16 digit	37.740376352425983	-122.434772373790167
3392	2019-09-28 13:25:47	2019-09-28	Mr. Rubin Schultz	mr.rubin.schultz@geemail.com	Las Vegas	Nevada	3528950474186903610	0cdbf6f2454fa85d095b1bd5fc44c042	JCB 16 digit	36.1562310305524619	-115.174528443135685
3393	2019-09-28 14:33:33	2019-09-28	Dr. Estevan Robel	dr.estevan.robel@geemail.com	Greensboro	North Carolina	3448051811592564	c14497b1f8d1a8c61486d6c54815c520	JCB 16 digit	36.1279451633919066	-79.9221240735594165
3394	2019-09-28 14:55:39	2019-09-28	Violette Pagac	violette.pagac@geemail.com	San Francisco	California	3528558160724633647	9b6a0192806bafd56f112e98bed27d15	VISA 16 digit	37.7941920059690091	-122.403503301715489
3395	2019-09-28 15:21:28	2019-09-28	Jeanetta McClure-Franecki	jeanetta.mcclure.franecki@geemail.com	San Francisco	California	4474761296781408	ac086c0b27f80c76ccc93d80ad1ddb02	Voyager	37.7633462808288058	-122.431398472803551
3396	2019-09-28 15:41:21	2019-09-28	Ms. Beda Little DDS	ms.beda.little.dds@geemail.com	Long Beach	California	55408533938637806	38ecaf7cab2be46a78da6f4c5f7de4b5	VISA 13 digit	33.7742719264987841	-118.163022490699959
3397	2019-09-28 16:16:50	2019-09-28	Mr. Deacon Jakubowski DDS	mr.deacon.jakubowski.dds@geemail.com	West Jordan	Utah	869926107635758249	307335fce21ca2e395743849a5b9b491	VISA 16 digit	40.6014503480192275	-112.056345390117912
3398	2019-09-28 17:47:17	2019-09-28	Amos Erdman Sr.	amos.erdman.sr.@geemail.com	Fresno	California	3528970472382763289	3438be4e9daa69d60a9a01c4100fd10b	VISA 16 digit	36.8036258365366606	-119.750588947312536
3399	2019-09-28 17:47:21	2019-09-28	Mr. Jasiah Block	mr.jasiah.block@geemail.com	San Francisco	California	676206580936497	b2984b78b57283e5f433649c47eb2236	JCB 15 digit	37.8076859218450565	-122.437407875519568
3400	2019-09-28 17:49:11	2019-09-28	Dr. Gray Trantow	dr.gray.trantow@woohoo.com	Denver	Colorado	3528514931388519295	a7ebf53bd5098a5d8978b8895576a577	American Express	39.8212282459303708	-104.821123193787784
3401	2019-09-28 20:00:02	2019-09-28	Reece Morissette	reece.morissette@geemail.com	San Francisco	California	6011802519606767548	16fa52256a87fe3b4817cd183ef1089e	VISA 13 digit	37.7901552347599008	-122.423943469036814
3402	2019-09-28 20:37:48	2019-09-28	Kathi Cummerata	kathi.cummerata@warmmail.com	Laredo	Texas	3112883134320202152	54203e94a985a85c02c237b526b9516f	Discover	27.460501230293513	-99.5276712376631707
3403	2019-09-28 21:28:02	2019-09-28	Dr. Jadiel Leannon MD	dr.jadiel.leannon.md@geemail.com	San Francisco	California	4586044489628669	491ad3d1edf05d81693eb1cf5982ba2c	VISA 16 digit	37.7609145664247023	-122.424622359100368
3404	2019-09-28 21:43:27	2019-09-28	Rollie Schinner	rollie.schinner@geemail.com	Aurora	Colorado	3446918692255390	09636a58555624613ecf2e1408bd6b2c	Voyager	39.6203729074560158	-104.650808781024821
3405	2019-09-28 22:13:38	2019-09-28	Dr. Allene Pollich MD	dr.allene.pollich.md@geemail.com	League City	Texas	52049639005180342	9b24dbb7b012ad128f9840957e007dff	VISA 16 digit	29.4014012055866445	-95.1430949170593152
3406	2019-09-28 22:19:23	2019-09-28	Jamir Miller	jamir.miller@geemail.com	Columbus	Ohio	4455064290504006	30fa0deb5bbab685f281703672760506	American Express	39.8916027505926749	-82.8915422170192073
3407	2019-09-29 00:03:47	2019-09-29	Sanders Sipes-Williamson	sanders.sipes.williamson@geemail.com	Dallas	Texas	630431232008214	a4cad2b2c8bc3ccea3077359db0cc321	VISA 16 digit	32.8327887829665102	-96.798288580305865
3408	2019-09-29 00:38:39	2019-09-29	Emmett Heller	emmett.heller@geemail.com	Houston	Texas	51620148286557043	db822b8a66dbc80a693119d97f4ec50d	VISA 13 digit	29.736849891215936	-95.3373134167879783
3409	2019-09-29 01:19:46	2019-09-29	Manila Keeling DDS	manila.keeling.dds@woohoo.com	Oakland	California	4544693817312676	f1fcc98d00519ba803f14ffbb3bd83cd	American Express	37.8158193856446587	-122.24547558088652
3410	2019-09-29 01:29:28	2019-09-29	Miss Danyelle Schiller DVM	miss.danyelle.schiller.dvm@geemail.com	Ontario	California	869929504740233182	644c70250a3c8c00de3ffbe2da03a898	Discover	33.9645668523065751	-117.641214468992132
3411	2019-09-29 03:34:59	2019-09-29	Pepper Johnson PhD	pepper.johnson.phd@geemail.com	Oakland	California	3410129018522685	d465ec530d298c3e6116c97e739940b8	Diners Club / Carte Blanche	37.7688677751658588	-122.284280157741748
3412	2019-09-29 04:27:15	2019-09-29	Diego Romaguera	diego.romaguera@warmmail.com	Hollywood	Florida	3337708931934069619	fa15c8057e7b03a01590af2589897fbd	Maestro	25.9820623317211847	-80.0935770278148311
3413	2019-09-29 04:33:52	2019-09-29	Lemmie Dare DVM	lemmie.dare.dvm@geemail.com	Stamford	Connecticut	4746380024108610	027deb6e5cd890d74ad3ecb8546a4de9	JCB 15 digit	41.0272928116727655	-73.585124778145925
3414	2019-09-29 05:47:11	2019-09-29	Johney Kirlin	johney.kirlin@geemail.com	San Francisco	California	4640783930317323	ed86dd252f4fe253651bfce9c5d0f172	VISA 13 digit	37.7615300610177584	-122.452427195876268
3415	2019-09-29 06:13:22	2019-09-29	Jaxson Conroy	jaxson.conroy@woohoo.com	Waterbury	Connecticut	4540297547686070	44c621faffd62196298850626979ffd9	JCB 16 digit	41.472191510353241	-72.9950624721970343
3416	2019-09-29 07:05:13	2019-09-29	Mal Beatty	mal.beatty@geemail.com	Berkeley	California	6011254543310786704	4f8a4ec1f61ba9893d864bf62c455459	American Express	37.8868937081402493	-122.261100280695317
3417	2019-09-29 08:22:27	2019-09-29	Keegan Ebert	keegan.ebert@geemail.com	New York	New York	210015380661791920	62f912571e31c25754ea605ba7e4b4a1	Voyager	40.5746820466816445	-73.8864522464469076
3418	2019-09-29 08:27:08	2019-09-29	Dannielle Okuneva	dannielle.okuneva@geemail.com	Springfield	Missouri	6011490209318595208	c5b6fedf5116e9695597ab902c48dca5	JCB 16 digit	37.2560958509061493	-93.3658395938400218
3419	2019-09-29 08:45:23	2019-09-29	Augustina Thompson DDS	augustina.thompson.dds@geemail.com	San Francisco	California	060480765184884	b33dd5d86d008dad0fd2a8167a432c4d	Discover	37.8019896277845078	-122.40975067200597
3420	2019-09-29 10:07:36	2019-09-29	Karina Welch DDS	karina.welch.dds@geemail.com	Oakland	California	53762717445745448	0cc79405f3e5f7fbd1e5d77d19f88aeb	JCB 16 digit	37.8180951634122096	-122.251917585297932
3421	2019-09-29 10:54:03	2019-09-29	Mrs. Joye Mayert	mrs.joye.mayert@geemail.com	San Francisco	California	180094651710767093	3f72b44730c491bea66ef72925371c79	JCB 15 digit	37.7712877229773056	-122.447269382218835
3422	2019-09-29 11:02:28	2019-09-29	Sammie Hamill	sammie.hamill@geemail.com	Saint Paul	Minnesota	4257219549412928	d0c5756c81ae57c87bd1fd90287edd12	VISA 16 digit	44.8993979293327783	-93.1808191892955477
3423	2019-09-29 13:05:28	2019-09-29	Rollo Lakin	rollo.lakin@warmmail.com	Anaheim	California	3701790868617106	73f7cc8bf8644d550a1fa0f3fc18c7aa	Mastercard	33.7987928916066878	-117.662603583906218
3424	2019-09-29 13:36:40	2019-09-29	Larry Paucek	larry.paucek@geemail.com	Springfield	Massachusetts	6011086796885213843	d5978e955f5513509ee485b9454a1ffc	JCB 16 digit	42.0525451823808254	-72.6314590319618674
3425	2019-09-29 14:31:38	2019-09-29	Randolf Heaney	randolf.heaney@geemail.com	San Francisco	California	6011706413434089845	0bf3ecfccc5a8f840af48275da384ea1	VISA 16 digit	37.7758565343304014	-122.391890263883411
3426	2019-09-29 15:44:28	2019-09-29	Gaige Borer	gaige.borer@warmmail.com	San Francisco	California	210063186412340763	8a5f2cd6cd6a7f1a27f03c278497f229	VISA 16 digit	37.7925039630941981	-122.438776322526252
3427	2019-09-29 17:28:50	2019-09-29	Lindy Jerde	lindy.jerde@warmmail.com	Clarksville	Tennessee	3450037499691898	f2135175881d6505496fc466bc9b9713	JCB 16 digit	36.5775547938082397	-87.3718113024670657
3428	2019-09-29 17:34:48	2019-09-29	Buddie Dietrich	buddie.dietrich@geemail.com	Albuquerque	New Mexico	3088787877201809928	b2f05dc6559f99b03d8733ae660c08b8	JCB 16 digit	35.1477121324412565	-106.581381902059178
3429	2019-09-29 18:26:54	2019-09-29	Sheree Bode	sheree.bode@geemail.com	Albuquerque	New Mexico	180016659674115113	43cc2f6bdbcd15ccfa0726ad157c8f99	Voyager	35.0568744353618484	-106.658961788199477
3430	2019-09-29 18:31:32	2019-09-29	Mr. Kristoffer Denesik	mr.kristoffer.denesik@geemail.com	San Francisco	California	869999021033808005	90cd48852001a35a3b951190382be27e	American Express	37.7786637019650726	-122.453870082063972
3431	2019-09-29 18:52:04	2019-09-29	Mossie Gibson PhD	mossie.gibson.phd@geemail.com	Chicago	Illinois	53585756016814162	05de59f98cc3690c95bbdaa3f7a782f0	Voyager	41.7506099114030604	-87.737963151049982
3432	2019-09-29 19:05:20	2019-09-29	Seneca Ryan	seneca.ryan@geemail.com	Berkeley	California	3158538404626828581	7c8e45e355fa2cb0fa57a79e29bb0d0a	JCB 16 digit	37.8529244386944583	-122.283095116221105
3433	2019-09-29 19:05:30	2019-09-29	Paige Brown-Schroeder	paige.brown.schroeder@warmmail.com	San Francisco	California	180071108652456307	cc012af942247cd14e4e560a7cc4ee30	JCB 16 digit	37.7952326271576737	-122.406679266209821
3434	2019-09-29 19:08:05	2019-09-29	Verna Quitzon	verna.quitzon@woohoo.com	San Francisco	California	869934089601509295	889ff4ccd0d411dd6af4d3109a8d192a	JCB 16 digit	37.7703749014096388	-122.417143515759051
3435	2019-09-29 19:58:27	2019-09-29	Dr. Larkin Turcotte	dr.larkin.turcotte@geemail.com	San Francisco	California	4055506384118634	735e540db776a6ac59d0d38275805aff	JCB 16 digit	37.7551730649932367	-122.430425354171277
3436	2019-09-29 20:56:57	2019-09-29	Verne Runolfsdottir	verne.runolfsdottir@geemail.com	Los Angeles	California	53288840910579624	828733921664272c130bbad4e3961221	JCB 15 digit	33.9647168599400615	-118.323150981403131
3437	2019-09-29 21:06:09	2019-09-29	Dr. Florance Ferry MD	dr.florance.ferry.md@geemail.com	Oakland	California	3479224233095076	fe3af6cd09f4a410e95d6f859da72e9e	VISA 13 digit	37.8392753030757021	-122.310452768980795
3438	2019-09-29 21:22:34	2019-09-29	Jasper Crona	jasper.crona@woohoo.com	San Antonio	Texas	180078122937148889	af194dec7812533f3745bd3d08b6e422	JCB 16 digit	29.4671285547386859	-98.6232990450993157
3439	2019-09-29 21:35:51	2019-09-29	Benjiman Dach	benjiman.dach@geemail.com	San Francisco	California	3158437785127560737	f4c0a359c78316cecdd90d3909fe6ad8	VISA 16 digit	37.7623011538736435	-122.438114310146915
3440	2019-09-29 21:47:00	2019-09-29	Banks DuBuque MD	banks.dubuque.md@geemail.com	San Francisco	California	54740791472529618	8c95216cfdd88a1dda6fb49d9440de88	Discover	37.8128902662823876	-122.393729648247941
3441	2019-09-29 22:20:22	2019-09-29	Dimitrios Russel	dimitrios.russel@woohoo.com	Oakland	California	4473618740532046	053a5caeb078a6213199e5040c368f25	VISA 16 digit	37.8104751508504293	-122.273794381008202
3442	2019-09-29 23:21:13	2019-09-29	Bama Torp	bama.torp@woohoo.com	San Francisco	California	52021616349800316	11fed0a3fc98130f0fd185eed9efacbd	Maestro	37.7864357422692834	-122.455773422336165
3443	2019-09-29 23:21:27	2019-09-29	Crawford Douglas	crawford.douglas@geemail.com	Las Vegas	Nevada	55689036516770304	e105b52bc4caf7245d4c54cf1c8a8296	Diners Club / Carte Blanche	36.1792439138617326	-115.263305034090195
3444	2019-09-29 23:23:56	2019-09-29	Mr. Gael Lebsack	mr.gael.lebsack@geemail.com	Berkeley	California	3733902168975207	97056778a0fdd73e6675185a70853a6e	JCB 16 digit	37.8614369360496781	-122.298891942783328
3445	2019-09-30 00:03:54	2019-09-30	Ms. Jordan Friesen DVM	ms.jordan.friesen.dvm@geemail.com	New York	New York	4313297921501	4e46041d970943d6681ad51217ed1dfd	VISA 16 digit	40.601969344656915	-73.8746610998071702
3446	2019-09-30 00:05:03	2019-09-30	Gisele Hamill	gisele.hamill@geemail.com	Norfolk	Virginia	4535223766572	2e31419c2176258391dec6bb3b7025ed	VISA 16 digit	36.8481390846446146	-76.301076319674408
3447	2019-09-30 00:57:23	2019-09-30	Mr. Clyde Stark	mr.clyde.stark@woohoo.com	San Francisco	California	3528065948260303963	1430d0cb7fc08566f779d60884011594	Mastercard	37.8021480534724077	-122.404558719660969
3448	2019-09-30 02:34:48	2019-09-30	Casey Pollich	casey.pollich@geemail.com	San Francisco	California	3528594013562165584	0453a3a4a0c602aa48b6c7adcba799ea	VISA 16 digit	37.7912430603894762	-122.45187767202431
3449	2019-09-30 03:43:35	2019-09-30	Dr. Cristian Kulas	dr.cristian.kulas@geemail.com	San Francisco	California	3112245986109991948	a7ac8bd2de48082c70e48961b73d83d3	Mastercard	37.7671229675201232	-122.451042430702515
3450	2019-09-30 04:07:43	2019-09-30	Maribeth Ruecker	maribeth.ruecker@geemail.com	Joliet	Illinois	4732673553055624	d4e5e7366381a45ad620a34bce55a6d2	JCB 16 digit	41.456636095405365	-88.2080448226641778
3451	2019-09-30 04:28:01	2019-09-30	Trent Davis-O'Connell	trent.davis.o'connell@geemail.com	Berkeley	California	4457175371607589	a9a895851d52dbc305ece458e15682d7	VISA 13 digit	37.8627834506226364	-122.302026551811949
3452	2019-09-30 04:31:14	2019-09-30	Dedrick Sauer	dedrick.sauer@warmmail.com	New York	New York	3043056748157905	0053de1cf6b612f703197196d287b1f6	Mastercard	40.737521911155433	-73.9117287916026982
3453	2019-09-30 05:01:20	2019-09-30	Adaline Langworth	adaline.langworth@warmmail.com	San Francisco	California	4184925265116372	eb33122100f5c45af8055427d5b97191	VISA 16 digit	37.7671960256107937	-122.444494489359499
3454	2019-09-30 05:12:52	2019-09-30	Ruthe Heaney	ruthe.heaney@geemail.com	Houston	Texas	3020829681564722	74c2b16b01f6cfb616206198278a4ffc	VISA 13 digit	29.74414375671968	-95.3140310297735027
3455	2019-09-30 05:47:34	2019-09-30	Davis Sauer	davis.sauer@geemail.com	San Francisco	California	54555162942437655	12c922303c01771409c2279747052ae8	VISA 13 digit	37.7813146603049503	-122.473125783303487
3456	2019-09-30 08:01:43	2019-09-30	Aldona Hessel	aldona.hessel@geemail.com	San Angelo	Texas	869913849155841104	2b43faa207a1b2307b9a068c5a188778	JCB 16 digit	31.4477560351755443	-100.359702716592707
3457	2019-09-30 10:22:35	2019-09-30	Kayden Runte	kayden.runte@geemail.com	San Francisco	California	180089709097356117	0deec4bd724647e1f4b408bcbb917ba1	Diners Club / Carte Blanche	37.7680676021323336	-122.417167805988342
3458	2019-09-30 11:59:14	2019-09-30	Ewell Stoltenberg	ewell.stoltenberg@geemail.com	Oakland	California	3088942633939203708	0134f304c39486be1ecc5d4963163f33	Mastercard	37.8263682901710112	-122.27119678063255
3459	2019-09-30 12:01:43	2019-09-30	Theophile Barton	theophile.barton@geemail.com	Oakland	California	676186310353213	ceabb38de78b16c6930b126f77b1fd86	Voyager	37.8394601532722703	-122.266794454338807
3460	2019-09-30 12:05:45	2019-09-30	Jayme Schultz	jayme.schultz@geemail.com	Santa Maria	California	4899291638018	077515563a32cc51a8a59b4d00ba9387	JCB 16 digit	34.8346787273015792	-120.417198040793835
3461	2019-09-30 12:35:36	2019-09-30	Gayle Green	gayle.green@warmmail.com	San Francisco	California	676325051680103	f2a546a01d2ce4a08c7a1735cd864e82	Diners Club / Carte Blanche	37.7920995141812881	-122.408404580699113
3462	2019-09-30 14:37:53	2019-09-30	Dr. Hailie Bode DDS	dr.hailie.bode.dds@geemail.com	New York	New York	060414225099739	057e93d284a0f50daa63a7dd51d72667	Voyager	40.719626818060874	-73.9947949941165746
3463	2019-09-30 15:13:38	2019-09-30	Caesar Kessler-Bogan	caesar.kessler.bogan@geemail.com	Oakland	California	4142845949423781	8e45365612d6084bd9e129cbf52818c7	JCB 16 digit	37.8311882862088922	-122.280795341283536
3464	2019-09-30 15:55:44	2019-09-30	Caydence Leuschke-Murazik	caydence.leuschke.murazik@warmmail.com	San Francisco	California	4735702735022124	0b628542676192f85df3f737351bee8a	JCB 15 digit	37.7876073185453265	-122.443956992041166
3465	2019-09-30 16:07:51	2019-09-30	Jerrel Armstrong	jerrel.armstrong@geemail.com	Oakland	California	4171272157172	a22e01eecc70b488606c1b7dadc25bcd	Discover	37.7864099317680271	-122.27710162029021
3466	2019-09-30 16:10:35	2019-09-30	Orlo Jacobi-Ernser	orlo.jacobi.ernser@warmmail.com	Atlanta	Georgia	3337525004981459959	c0237e6fceb1099acf12988e831a63da	Discover	33.7094255777351606	-84.4433718686968149
3467	2019-09-30 17:11:08	2019-09-30	Kassidy Ebert DDS	kassidy.ebert.dds@geemail.com	Glendale	California	4567102290629657	3c5347436f50761abd9f70e5b43f67b9	Discover	34.0934984512381192	-118.258850207495698
3468	2019-09-30 18:47:22	2019-09-30	Jesica Douglas	jesica.douglas@geemail.com	Long Beach	California	3096989924796053847	4a8d4d1aaac01ef176ce7ddfb1fe9bb2	Mastercard	33.7672467819236175	-118.06466757572926
3469	2019-09-30 19:04:24	2019-09-30	Ellyn Hegmann	ellyn.hegmann@geemail.com	Salinas	California	6011139244294310964	993b70c7b468108266c64278c163b24c	VISA 16 digit	36.7521423150084914	-121.619786513055487
3470	2019-09-30 19:30:55	2019-09-30	Dr. Easton Kuhic PhD	dr.easton.kuhic.phd@geemail.com	Oakland	California	3037931144352217	b37d8bd233ba900915323f9559c55a04	VISA 13 digit	37.7876714660010862	-122.264072019574485
3471	2019-09-30 20:26:12	2019-09-30	Mrs. Amira Nitzsche DVM	mrs.amira.nitzsche.dvm@warmmail.com	Houston	Texas	869925633391443255	cdbcfc56e796144e3c4326533ba32561	American Express	29.7908658127844319	-95.4146738828640508
3472	2019-09-30 20:37:19	2019-09-30	Mae Bosco	mae.bosco@geemail.com	Round Rock	Texas	4220193142483293	1a09c0d0b22b10037f83a3dd34d91ca9	American Express	30.4851183287937211	-97.749080666558811
3473	2019-09-30 22:35:24	2019-09-30	Zack Strosin	zack.strosin@geemail.com	Sioux Falls	South Dakota	589345573504391	8bbb594b1de1275b85e738b948d7cfdd	VISA 16 digit	43.4464648794468502	-96.8132095174565848
3474	2019-10-01 00:14:42	2019-10-01	Newton Grady-Hansen	newton.grady.hansen@geemail.com	San Francisco	California	6011487894551420886	690fdcf4cb96c125e1855da1c8391094	JCB 15 digit	37.7963508222657225	-122.43668138215611
3475	2019-10-01 00:21:57	2019-10-01	Bill Koch	bill.koch@woohoo.com	Salem	Oregon	53408942045755726	6723458f9ffb53037c37d8feaf07c21f	Voyager	44.9103219363175299	-123.06521025865041
3476	2019-10-01 01:32:55	2019-10-01	Reinhold Hamill	reinhold.hamill@geemail.com	Berkeley	California	3528357543968721041	b4da60e43226c5d422a43b3b308ce8aa	JCB 15 digit	37.8708769184710619	-122.267723511767755
3477	2019-10-01 02:21:25	2019-10-01	Gaston Dicki	gaston.dicki@geemail.com	Oakland	California	210035992263983626	7b55a34b879ca3e24c0c9745e4560e01	VISA 13 digit	37.8369025500190475	-122.287981747460861
3478	2019-10-01 05:35:09	2019-10-01	Trena Parisian	trena.parisian@geemail.com	San Francisco	California	869913436004985504	0f6f0c417b337eede3f731185d6f071a	JCB 15 digit	37.7660894592491658	-122.419246096888898
3479	2019-10-01 05:39:47	2019-10-01	Cleon Daniel	cleon.daniel@geemail.com	Odessa	Texas	6011807834494881482	0a50f800a4861e0bdaba62f748dc9cc1	Discover	31.843328905246409	-102.362950951062516
3480	2019-10-01 07:02:18	2019-10-01	Dwayne Doyle	dwayne.doyle@warmmail.com	San Francisco	California	3088750964353523979	0b9f172ba9d52c802caedef39e005fbc	Diners Club / Carte Blanche	37.7694742403603669	-122.422729462295848
3481	2019-10-01 07:50:54	2019-10-01	Dr. Oney Thompson	dr.oney.thompson@geemail.com	San Francisco	California	52583340601629541	8540d7314a69b1159f3ec81ffcec2150	Maestro	37.7601755508144379	-122.412694106992575
3482	2019-10-01 08:12:24	2019-10-01	Llewellyn Mraz	llewellyn.mraz@geemail.com	New York	New York	869982611282794895	6527150d41f0229406fe6d5e6e5ba13b	VISA 13 digit	40.5939619092959916	-73.9659322719916617
3483	2019-10-01 09:12:56	2019-10-01	Oleta Kshlerin	oleta.kshlerin@warmmail.com	San Francisco	California	4979341881352	d481c22bf76060d15af6e7304ed853c4	Discover	37.8096023221728785	-122.451808927229195
3484	2019-10-01 09:44:40	2019-10-01	Clemie Wisozk DDS	clemie.wisozk.dds@geemail.com	Charlotte	North Carolina	4568278809740166	02b8f9ebd335bf95a82865f2e9e9a1e2	Mastercard	35.1480386875357453	-80.8806947778388832
3485	2019-10-01 10:29:06	2019-10-01	Enrique Considine	enrique.considine@geemail.com	San Diego	California	3528027198453633654	69bc247a5fc885d997b67b5415058d28	Maestro	32.8178707830674981	-117.042116306200626
3486	2019-10-01 10:49:08	2019-10-01	Karyl Beatty	karyl.beatty@geemail.com	St. Petersburg	Florida	4260366604302794	35169d165fea831ae827de615ef48fa2	Voyager	27.8023083366807562	-82.7295247193783467
3487	2019-10-01 13:44:26	2019-10-01	Karlene Jones-Sipes	karlene.jones.sipes@geemail.com	San Francisco	California	4656902474899105	bbcef29e6dca4136a69fec85cf1edbcf	JCB 16 digit	37.7822774230716476	-122.404475581104307
3488	2019-10-01 13:50:57	2019-10-01	Adriane Weissnat	adriane.weissnat@geemail.com	New York	New York	869900329136655522	2ec77e38bb280b4f99ad8e1c1d2e93fa	Voyager	40.6613628236334748	-73.9237476709660086
3489	2019-10-01 13:54:55	2019-10-01	Laverne Kuhlman	laverne.kuhlman@warmmail.com	Houston	Texas	3017317545014939	6ba2837ad27630e4618675a28b053ea4	Voyager	29.7227197186633951	-95.4050333722509407
3490	2019-10-01 15:29:02	2019-10-01	Alonza Thiel	alonza.thiel@woohoo.com	Laredo	Texas	3498266947942157	958e995f92c98449e08d54c72a7a9d0a	American Express	27.4999795390475548	-99.4188830061357436
3491	2019-10-01 15:37:22	2019-10-01	Laverne Haley	laverne.haley@geemail.com	Oakland	California	3756424243238586	57d96ee8d768373d229ff8890e70a0c1	JCB 15 digit	37.8116590814422935	-122.259262861577568
3492	2019-10-01 15:54:47	2019-10-01	Franklyn Ratke	franklyn.ratke@geemail.com	Charlotte	North Carolina	3337286313223936958	d41de0630bd8a6a9365ed025666fcde1	JCB 16 digit	35.2087020138997602	-80.7480357996132199
3493	2019-10-01 16:12:20	2019-10-01	Mohammed Johnson-Marvin	mohammed.johnson.marvin@woohoo.com	Saint Paul	Minnesota	180087181254770658	ea14967e4cd2d19e3b798ee9b51ee739	VISA 16 digit	44.8554011587925245	-93.029788781542706
3494	2019-10-01 17:53:06	2019-10-01	Mr. Shaun Fisher PhD	mr.shaun.fisher.phd@warmmail.com	Oakland	California	869920888145904888	a67596929e5d28d6ee2ae218b68fd325	American Express	37.8207379235037706	-122.269929755208466
3495	2019-10-01 18:36:14	2019-10-01	Jahiem Tromp II	jahiem.tromp.ii@geemail.com	New York	New York	210020217663433221	539f2681428c64c29a940843dd703065	Mastercard	40.7555048086903966	-73.9819238772045793
3496	2019-10-01 19:32:00	2019-10-01	Mr. Ty Hettinger	mr.ty.hettinger@geemail.com	San Francisco	California	3434137798323069	8df39f24c364142a7fa196a7ab4dfa2a	JCB 16 digit	37.7818013340711971	-122.468372644577059
3497	2019-10-01 20:11:35	2019-10-01	Mychal Kiehn	mychal.kiehn@woohoo.com	Toledo	Ohio	3499045001925509	e0c04ddef66f41b9f6cfdd1cba851ba2	VISA 13 digit	41.6234709448352405	-83.6041167593427019
3498	2019-10-01 20:56:25	2019-10-01	Dr. Devante Carter DDS	dr.devante.carter.dds@woohoo.com	San Francisco	California	3005436260671673	b2ad8e47c104c9460e883cdeec137f2c	Maestro	37.7670992319097749	-122.440592091415681
3499	2019-10-01 21:50:55	2019-10-01	Brody Bailey	brody.bailey@geemail.com	Austin	Texas	3096288494433673629	91781f7cf43e6dd864846b47c01513b4	Diners Club / Carte Blanche	30.2937791691288325	-97.8089453044120205
3500	2019-10-01 21:58:07	2019-10-01	Agustus Ryan	agustus.ryan@geemail.com	Sacramento	California	3013614104531970	431ed22808eddd15637d3f296370a9ce	American Express	38.5205857519324866	-121.534002792207886
3501	2019-10-01 22:10:29	2019-10-01	Nia Bogan	nia.bogan@geemail.com	San Francisco	California	3761340037636020	ad9f544c51f0adde1f16a1c5dcaa1930	VISA 16 digit	37.7846259472921417	-122.469103162093504
3502	2019-10-01 22:53:35	2019-10-01	Rodney Parker	rodney.parker@geemail.com	Little Rock	Arkansas	630431477452481	6209072492ae362bc53d2daa580cc309	Maestro	34.7630310646068281	-92.4440253977071507
3503	2019-10-01 23:22:01	2019-10-01	Alfredo Walsh III	alfredo.walsh.iii@geemail.com	San Francisco	California	561274165270047	e75885015be891ceb1cefea8f072a22a	VISA 16 digit	37.8299539352142489	-122.44011352325343
3504	2019-10-01 23:45:56	2019-10-01	Ms. Iridian Auer MD	ms.iridian.auer.md@warmmail.com	Oakland	California	6011922997259545301	8d3a6a2c67094b60241563f829e500b8	VISA 13 digit	37.794991745559237	-122.245554760681415
3505	2019-10-02 00:00:58	2019-10-02	Mr. Demetrius Trantow	mr.demetrius.trantow@geemail.com	Evansville	Indiana	3461855389515472	39bf6b0ceb52a7bb9b93b9ed1d77e9a6	JCB 16 digit	37.9111151534270476	-87.484033180114622
3506	2019-10-02 00:01:40	2019-10-02	Debera Bauch	debera.bauch@geemail.com	Houston	Texas	502015829692399	034b8b4831ab1fbecbbbcc3ab1bab641	Discover	29.7415482818692922	-95.3720056561302414
3507	2019-10-02 02:01:11	2019-10-02	Denisha Pfannerstill	denisha.pfannerstill@geemail.com	San Francisco	California	3413159923283690	823bdd1e2a2f3ad0c056a54a99dc8805	VISA 13 digit	37.7700611926001812	-122.430501783759283
3508	2019-10-02 03:46:49	2019-10-02	Weston Jenkins	weston.jenkins@geemail.com	San Francisco	California	6011452678449517255	1d672022220aef55a2d036349ab35f7e	Voyager	37.7899439789734615	-122.406606790953006
3509	2019-10-02 03:59:21	2019-10-02	Marcelino Kiehn	marcelino.kiehn@geemail.com	San Francisco	California	54167308850736857	3d5fc3137e81c1501fa9efc07c9ffc83	JCB 16 digit	37.7392168348357231	-122.438955599920902
3510	2019-10-02 05:43:42	2019-10-02	Pauletta Renner	pauletta.renner@geemail.com	San Francisco	California	4265127715077054	0420b4dcc873b788feb9fbf7d0b71a27	VISA 16 digit	37.7618731343689831	-122.437143177936719
3511	2019-10-02 07:27:10	2019-10-02	Lorean Dietrich-Streich	lorean.dietrich.streich@warmmail.com	San Francisco	California	3112920090087210330	94874104c6331a4d33bf66a098570e27	VISA 13 digit	37.7473909172224182	-122.41423238106357
3512	2019-10-02 09:09:50	2019-10-02	Dr. Ila Vandervort DVM	dr.ila.vandervort.dvm@warmmail.com	Oakland	California	502081957954225	b3ff1e79ef6508f7f9b319a468d6df70	Maestro	37.8476208747325558	-122.255729315614147
3513	2019-10-02 10:43:13	2019-10-02	Windell Streich-Ortiz	windell.streich.ortiz@warmmail.com	San Francisco	California	4835631708566	9d427228f86813ae68327392bdf63e0b	VISA 13 digit	37.7735022371114511	-122.400030544712806
3514	2019-10-02 10:55:24	2019-10-02	Salena Hermiston	salena.hermiston@geemail.com	San Francisco	California	3337672510092504278	a15bca79831557898b64a1e2a6bb40c0	Voyager	37.7729496138289207	-122.444663659188251
3515	2019-10-02 11:38:25	2019-10-02	Miss Ernestina Kertzmann	miss.ernestina.kertzmann@geemail.com	Anchorage	Alaska	3337802331119536133	461bff2dd6b79474ff587b87cc1585a3	Diners Club / Carte Blanche	61.0753584344621743	-149.264973518218113
3516	2019-10-02 11:41:58	2019-10-02	Maryam Legros	maryam.legros@geemail.com	Lowell	Massachusetts	3042404575696481	5aa696b8cbd1d0ba104ff9309188de6a	JCB 16 digit	42.7325518486890985	-71.2463817192580535
3517	2019-10-02 14:06:23	2019-10-02	Alva Daniel	alva.daniel@geemail.com	Chula Vista	California	52541083957170642	c770daf1bf2314692e215fcbebd40e65	Discover	32.7155552126232507	-117.063432191102578
3518	2019-10-02 14:50:52	2019-10-02	Alford Anderson	alford.anderson@warmmail.com	Fresno	California	502067477009590	9dbc0a0e1b7cfb836af908c806dd7854	JCB 16 digit	36.810140143834424	-119.817391704545926
3519	2019-10-02 15:07:51	2019-10-02	Marley Rau	marley.rau@woohoo.com	Tulsa	Oklahoma	3056584063521196	aa178c05ddb6d0b9502e8321835279c0	VISA 16 digit	36.0284958780646321	-96.001390294446793
3520	2019-10-02 15:16:06	2019-10-02	Kerwin White-Wisoky	kerwin.white.wisoky@woohoo.com	Oakland	California	3088377203690991166	ec8a98c0c6acce71e50d236a3fc42fd5	Mastercard	37.7871552908481476	-122.26425581772034
3521	2019-10-02 16:50:11	2019-10-02	Dr. Kenji Hamill	dr.kenji.hamill@warmmail.com	San Francisco	California	4404662161110	2c5dca6fe869f04395e9483a24182f2c	VISA 16 digit	37.7926011481922544	-122.399491010944217
3522	2019-10-02 17:33:56	2019-10-02	Add Auer	add.auer@warmmail.com	San Diego	California	3112823335788984560	ce18e92b29001877e0d57b9d36e2ff2d	VISA 13 digit	32.8219676995717009	-117.06352634009906
3523	2019-10-02 17:40:47	2019-10-02	Eartha Rogahn DDS	eartha.rogahn.dds@geemail.com	San Francisco	California	3475114002740115	1e189c76b499427d7ce4c1471e719123	Mastercard	37.8064879544683095	-122.441377283073962
3524	2019-10-02 18:17:39	2019-10-02	Dr. Birt Reynolds Sr.	dr.birt.reynolds.sr.@geemail.com	San Francisco	California	4754593020128	4fb0a32ff2009a269063f5362246c30e	American Express	37.7668461162886828	-122.388365490165924
3525	2019-10-02 18:30:59	2019-10-02	Josh Glover	josh.glover@geemail.com	Odessa	Texas	4241570084400	41ebce135e4ec42383cd4c51d8a8f16d	VISA 13 digit	31.8137816046841451	-102.417465140685806
3526	2019-10-02 18:45:49	2019-10-02	Barnard Renner	barnard.renner@geemail.com	San Francisco	California	55739273357225748	8bf5fdf8d7c7f04b6fd74cd44e38bb95	American Express	37.7779498936781053	-122.425859775203875
3527	2019-10-02 18:51:38	2019-10-02	Ms. Cydney Casper DDS	ms.cydney.casper.dds@geemail.com	San Francisco	California	3112721820859382714	3d118bf061195701c515fe4a9444249c	JCB 16 digit	37.7748832240934291	-122.418743480323101
3528	2019-10-02 19:18:13	2019-10-02	Mr. Dante Schmeler	mr.dante.schmeler@geemail.com	Pembroke Pines	Florida	6011048760638788375	c8a31507fece2927e94343607740f346	VISA 16 digit	26.0520777604114286	-80.3563041852690247
3529	2019-10-02 20:17:09	2019-10-02	Seward Hammes-Brakus	seward.hammes.brakus@geemail.com	Berkeley	California	180054651496011664	155e06443710c52ac79d732e8daa48f6	VISA 16 digit	37.8572620698057705	-122.310156656934922
3530	2019-10-02 20:28:01	2019-10-02	Angella Bradtke	angella.bradtke@geemail.com	San Diego	California	4469392929102	aa38ef062caa7ed3d472d43e9601ae37	Discover	32.8697397231657078	-117.169580451110377
3531	2019-10-02 20:33:22	2019-10-02	Lavonne McLaughlin MD	lavonne.mclaughlin.md@warmmail.com	Phoenix	Arizona	53357188051666016	6c93b484be188d3008100e1c65a7527e	Mastercard	33.6489365139909111	-112.141914002264301
3532	2019-10-02 22:15:32	2019-10-02	Gertrude Hills	gertrude.hills@geemail.com	Oakland	California	4340047350900833	274763d1d96c33770fc73713a8e6a0ac	Diners Club / Carte Blanche	37.7770458378644705	-122.286421880493634
3533	2019-10-02 22:18:16	2019-10-02	Norman Kshlerin-Metz	norman.kshlerin.metz@geemail.com	Berkeley	California	3007588124929073	1a5f348b915ef4ec965a0b98822689e6	Mastercard	37.8719312606124632	-122.258945405697148
3534	2019-10-02 22:29:47	2019-10-02	Posey Moore	posey.moore@geemail.com	Omaha	Nebraska	51507506245453224	e3599ba42cde1a84b6f327756b519668	Mastercard	41.3271651388291303	-95.9650355839286107
3535	2019-10-03 00:03:29	2019-10-03	Valentine Cremin	valentine.cremin@warmmail.com	Oakland	California	869934014076722546	41128ab05f30183ce5500faaa39c0408	Diners Club / Carte Blanche	37.8060148156637865	-122.258469818894028
3536	2019-10-03 00:05:49	2019-10-03	Karin Haley PhD	karin.haley.phd@woohoo.com	San Francisco	California	3096735765855871471	00b828a83c0239a4d4a7d1ff18564bef	JCB 16 digit	37.774298741231398	-122.457869241969689
3537	2019-10-03 00:13:49	2019-10-03	Ean Blanda	ean.blanda@warmmail.com	Dallas	Texas	3096820601925194105	4402aa7231486388e879570d87e9d082	Mastercard	32.8188428296513877	-96.8541150946132774
3538	2019-10-03 01:11:53	2019-10-03	Mrs. Zana Auer MD	mrs.zana.auer.md@woohoo.com	Berkeley	California	869989236326136524	afe1d9f07b5c77ef248b492651f9bbdb	VISA 16 digit	37.8641641613466078	-122.31258463004491
3539	2019-10-03 01:38:01	2019-10-03	Mr. Lenon Wuckert	mr.lenon.wuckert@geemail.com	Oakland	California	4887476356440388	bd8f8dba3a1c1715e70568bd11e53c7a	Mastercard	37.8059335140893111	-122.253282578062851
3540	2019-10-03 02:00:18	2019-10-03	Amari Dietrich DVM	amari.dietrich.dvm@geemail.com	Minneapolis	Minnesota	55801117149685730	bf512773a9581d71591f3cb0e8af63aa	VISA 16 digit	44.8879917845681291	-93.2394418846622131
3541	2019-10-03 02:19:43	2019-10-03	Mrs. Jocelynn Schuppe	mrs.jocelynn.schuppe@geemail.com	St. Petersburg	Florida	3009644871108383	e03035e04f3da0f5a401e9fcc902f0ec	JCB 16 digit	27.6736395543795091	-82.5668217685896906
3542	2019-10-03 03:25:14	2019-10-03	Deward Braun PhD	deward.braun.phd@geemail.com	Chesapeake	Virginia	3026948321389284	a460b79b551f9c2a9d268b55dedfd512	JCB 16 digit	36.6622135488554832	-76.388337610413501
3543	2019-10-03 03:45:27	2019-10-03	Dr. Leota Schowalter DVM	dr.leota.schowalter.dvm@warmmail.com	Henderson	Nevada	3044404533492955	509ff372726d8435ebb60b84d0efc22d	American Express	36.0353523332558581	-115.033071721547103
3544	2019-10-03 04:30:24	2019-10-03	Alford Hahn-Berge	alford.hahn.berge@geemail.com	San Francisco	California	3446716388828763	ebcfbc6931dd7fb2f82421ab3525107e	Diners Club / Carte Blanche	37.7900985808141812	-122.44020678026547
3545	2019-10-03 04:58:18	2019-10-03	Steve Hills	steve.hills@geemail.com	Providence	Rhode Island	4154977554877772	390fe7f37152d14ad969eafbf877e6de	American Express	41.775753133403505	-71.352920270796119
3546	2019-10-03 05:11:03	2019-10-03	Loris Bernhard	loris.bernhard@geemail.com	New York	New York	676154749780133	c9a7bf6627b7058bb872ae19e53cfa51	JCB 15 digit	40.6953737685214705	-73.9374697655335069
3547	2019-10-03 07:20:08	2019-10-03	Trudi Jaskolski DVM	trudi.jaskolski.dvm@geemail.com	San Francisco	California	3088711600041676740	006aafbd878af93aa334e00e68c07edb	American Express	37.8026132466481855	-122.390530289955962
3548	2019-10-03 07:38:23	2019-10-03	Gladys Nolan	gladys.nolan@woohoo.com	Cincinnati	Ohio	3158601089581712102	8eb451922138f2249b95ba9b60f41f9d	VISA 16 digit	39.2205007915616051	-84.528600602577626
3549	2019-10-03 07:48:46	2019-10-03	Dahlia Lemke	dahlia.lemke@warmmail.com	New York	New York	3424482011101443	6e3fb90242924e297ff93f2ea9802f5f	Voyager	40.7262778309863052	-73.9421128890838446
3550	2019-10-03 07:55:21	2019-10-03	Jaycob Kling	jaycob.kling@geemail.com	San Francisco	California	4477559378161	a0f1664a194a49aaba776ad204ccbad8	VISA 13 digit	37.7877969807335461	-122.443321940951662
3551	2019-10-03 09:16:44	2019-10-03	Dolores Hagenes	dolores.hagenes@geemail.com	San Francisco	California	3022840236176555	33586e56c5e76f815548a023b7ac4027	VISA 16 digit	37.7739715341425892	-122.439416174540483
3552	2019-10-03 09:20:57	2019-10-03	Daija Emard	daija.emard@geemail.com	Louisville	Kentucky	6011805634262968962	db090c98c1904d880604e451d5cf4f16	VISA 16 digit	38.1401516254894446	-85.6012133529946198
3553	2019-10-03 09:41:02	2019-10-03	Mr. Mat Osinski MD	mr.mat.osinski.md@geemail.com	Oakland	California	6011222525541099030	41bb67d6d3fed5a34edef6c94201b2b6	Diners Club / Carte Blanche	37.8110353374814423	-122.262303265413408
3554	2019-10-03 11:49:34	2019-10-03	Natasha VonRueden	natasha.vonrueden@geemail.com	New York	New York	4261665031850	7310fdd7a38aaa2ea1aba940cc8fe4ed	VISA 13 digit	40.625334432743486	-73.8596582210052759
3555	2019-10-03 12:06:56	2019-10-03	Antonia Stokes	antonia.stokes@geemail.com	Oakland	California	869923622539541015	8503b113035a042b4eb73b87d96a2c24	American Express	37.8378363442937768	-122.288366868542695
3556	2019-10-03 13:11:43	2019-10-03	Ena Cormier	ena.cormier@geemail.com	Irvine	California	4161432821353	5ee9406c6a998a32b7090cb14cef2b16	VISA 16 digit	33.6961182302344611	-117.702969802917167
3557	2019-10-03 13:14:48	2019-10-03	Arvo Fadel	arvo.fadel@geemail.com	Oakland	California	210093760696170999	7dddbb5ae1f765c222730a55875c32e3	JCB 15 digit	37.7795482951273911	-122.259656724098306
3558	2019-10-03 15:13:41	2019-10-03	Mr. Marlon Weber III	mr.marlon.weber.iii@woohoo.com	Oklahoma City	Oklahoma	210043654520654230	148985f4e33566d838eaf56c42daeb98	JCB 16 digit	35.3739334001116461	-97.5001454834721955
3559	2019-10-03 15:27:43	2019-10-03	Auguste DuBuque	auguste.dubuque@warmmail.com	Oakland	California	3746248073146962	afbe170b6506a6de598eedcff02ff006	JCB 15 digit	37.8196237657061332	-122.265971862200331
3560	2019-10-03 15:38:23	2019-10-03	Jolie Schultz	jolie.schultz@warmmail.com	San Francisco	California	6011581667751382337	29cc7f71cfc03a6fb99531c409c5dc33	Voyager	37.8013267853413026	-122.427683090359125
3561	2019-10-03 15:45:40	2019-10-03	Mrs. Millie Balistreri DVM	mrs.millie.balistreri.dvm@woohoo.com	Los Angeles	California	3036550074170844	e42baaccd76d29cc3b514f057c1a40fa	Mastercard	34.1175621099170243	-118.472544549125431
3562	2019-10-03 16:48:13	2019-10-03	Merrill McLaughlin	merrill.mclaughlin@geemail.com	Augusta	Georgia	3754277332166940	3e856f302faa1dab438eb769adfbd8eb	Discover	33.3010835258960682	-82.1137642116580224
3563	2019-10-03 18:28:28	2019-10-03	Mikel Kozey PhD	mikel.kozey.phd@warmmail.com	Chicago	Illinois	6011721666599855802	23d22c4d6056518009e4e27a35f22553	JCB 15 digit	41.9049740736208847	-87.6167937930703147
3564	2019-10-03 19:38:04	2019-10-03	Renata Pouros	renata.pouros@geemail.com	San Francisco	California	53572848309592285	f5af77be7d1145c3db75a7c41a0e9323	JCB 16 digit	37.7575369001965342	-122.431560864843817
3565	2019-10-03 19:43:50	2019-10-03	Delphine VonRueden	delphine.vonrueden@warmmail.com	Fresno	California	4927501500771347	c3c7a0306cfb262d36ebb44e109d1e24	American Express	36.7185527763668418	-119.780324133356672
3566	2019-10-03 20:10:22	2019-10-03	Chaka Fahey PhD	chaka.fahey.phd@geemail.com	Tempe	Arizona	589372044255130	f638196aef2a661ed3ab9309732d5de3	Maestro	33.3837502724412829	-111.897728481705485
3567	2019-10-03 20:49:33	2019-10-03	Dr. Jasen Rau	dr.jasen.rau@geemail.com	Oakland	California	3027196030096670	affe4597d37c46f13441e1f7ca13f305	American Express	37.8364046536217984	-122.275041067035488
3568	2019-10-03 21:10:10	2019-10-03	Grisel Ebert PhD	grisel.ebert.phd@geemail.com	Dallas	Texas	4581918510743	0c85ec10063016057703dbe641675add	Mastercard	32.7463168972909457	-96.7608156765308109
3569	2019-10-03 21:29:06	2019-10-03	Jovanny Considine	jovanny.considine@geemail.com	Raleigh	North Carolina	4106960026076610	49d5013b17ec2ac00ad80bbeb18344f7	JCB 15 digit	35.7318194104027	-78.5747321505501901
3570	2019-10-03 22:17:33	2019-10-03	Rita Harvey	rita.harvey@woohoo.com	San Francisco	California	3783195502292244	2cb9628ea5fcc1151c49c1ead633fafa	Discover	37.7778111989690686	-122.446530915444995
3571	2019-10-03 22:40:26	2019-10-03	Keisha Mohr-Herzog	keisha.mohr.herzog@geemail.com	El Monte	California	6011483332308819310	a6fdb31130148b01f61cf0ede3e2b84c	VISA 16 digit	34.1547948146894527	-118.021921849416941
3572	2019-10-03 23:14:32	2019-10-03	Hana Schmeler	hana.schmeler@geemail.com	Plano	Texas	3096060912162137148	d71e2338c3b13bd9960b6860bae9f1d4	Maestro	33.1489940751429657	-96.7640604267079425
3573	2019-10-04 00:48:27	2019-10-04	Gray Crist	gray.crist@geemail.com	Berkeley	California	4699260468610122	fbcd1dec2320e6a8f6eec061a81ac808	JCB 15 digit	37.9029887622356938	-122.280209246815502
3574	2019-10-04 02:45:36	2019-10-04	Kristine Lind	kristine.lind@geemail.com	Fort Worth	Texas	3050802305081324	e8d55890674b708d1f01cf702aaed36c	JCB 16 digit	32.6861917590778361	-97.3164819375898702
3575	2019-10-04 02:46:34	2019-10-04	Fae Stamm DDS	fae.stamm.dds@geemail.com	Baltimore	Maryland	630432223638738	385d0f59bc73b35dd4f85c85fdc2e853	JCB 15 digit	39.2769113576505333	-76.6901666141599492
3576	2019-10-04 04:45:17	2019-10-04	Sherie Smitham	sherie.smitham@geemail.com	Tulsa	Oklahoma	3096607550228188000	b36741839d83bbc01aa48bd65832f44f	Voyager	36.1539160147678089	-95.8784835004668707
3577	2019-10-04 04:54:30	2019-10-04	Mont Lang	mont.lang@geemail.com	Berkeley	California	55455242493631129	9c3ebf339735885b438be8ca6a23e255	Maestro	37.835680939289098	-122.283502186359627
3578	2019-10-04 05:22:55	2019-10-04	Perri Bradtke	perri.bradtke@woohoo.com	San Francisco	California	6011018079147501476	f01903b999b88923a2cdd0607166553d	VISA 16 digit	37.8102197992802687	-122.412883774842939
3579	2019-10-04 05:40:48	2019-10-04	Stephanie Schmidt	stephanie.schmidt@geemail.com	Evansville	Indiana	675923179645223	c842d40771e8995da6a98ba8fb26e432	JCB 16 digit	37.9786581462852624	-87.5608555369943389
3580	2019-10-04 05:55:59	2019-10-04	Brandy Rohan DVM	brandy.rohan.dvm@geemail.com	New York	New York	4094445358445389	d17b533b94f6df2f39a7f6e652d4c0e3	VISA 13 digit	40.5990037979781633	-73.9660930804803911
3581	2019-10-04 06:13:38	2019-10-04	Dema Huels	dema.huels@geemail.com	San Francisco	California	676126388226040	12b79475d78c5415836f590ad9fa02ec	Diners Club / Carte Blanche	37.753771835177858	-122.416483724432851
3582	2019-10-04 06:44:06	2019-10-04	Kelby Ernser DDS	kelby.ernser.dds@geemail.com	Berkeley	California	675990793326654	d9021b3431bb38a843b04dbd1061463f	JCB 15 digit	37.894660039915756	-122.250287923823805
3583	2019-10-04 07:06:44	2019-10-04	Jaxton Pagac	jaxton.pagac@geemail.com	San Diego	California	3337528939826170450	a567460058d205235a2c9715d435143f	Discover	32.8548368856377877	-117.234747438542556
3584	2019-10-04 07:42:32	2019-10-04	Alina Schroeder	alina.schroeder@warmmail.com	Nashville	Tennessee	55568315365094131	1b8877ba1c39c95d89a62d69961ce659	Discover	36.074167190411309	-86.7096648499742173
3585	2019-10-04 09:04:05	2019-10-04	Dosha Langosh	dosha.langosh@geemail.com	Elizabeth	New Jersey	3711212375376660	abda40c2f8b3a850c68d3ebde0ed55b9	VISA 16 digit	40.6175938859243004	-74.2350518066380118
3586	2019-10-04 09:30:36	2019-10-04	Makala Stehr	makala.stehr@woohoo.com	McAllen	Texas	4279172125945049	e7ce5cc577962f7db3c0de8c7f680589	JCB 15 digit	26.2777948363058265	-98.2977791461475192
3587	2019-10-04 09:34:39	2019-10-04	Mr. Ibrahim Pouros	mr.ibrahim.pouros@geemail.com	Philadelphia	Pennsylvania	6011509674304652645	53f9be5eff871bfc7d87d48f6d164425	VISA 16 digit	39.9698663447476932	-75.1247564566686776
3588	2019-10-04 09:52:45	2019-10-04	Gerry Koss	gerry.koss@geemail.com	Lakewood	Colorado	676106944774550	9edd76cf5dea68043b6af91213c35bcd	JCB 15 digit	39.6315824418734763	-105.179972731743376
3589	2019-10-04 09:57:02	2019-10-04	Horacio Runte	horacio.runte@woohoo.com	Murfreesboro	Tennessee	3459868488060690	b4ceb8a57730196262b70de3b0d0d710	American Express	35.7855619794342701	-86.3973654200639487
3590	2019-10-04 10:00:02	2019-10-04	Arely O'Hara	arely.o'hara@woohoo.com	Oakland	California	3112399300210046705	0148419b051624d403481f2f785b5bf3	Discover	37.8109469694539158	-122.290408296604539
3591	2019-10-04 10:31:45	2019-10-04	Mareli Zieme	mareli.zieme@geemail.com	Shreveport	Louisiana	4702460543433	935a7afc52d77d55ed6594df18096d6e	JCB 16 digit	32.3925009750533874	-93.790336987769976
3592	2019-10-04 11:09:20	2019-10-04	Dr. Murl Carter MD	dr.murl.carter.md@geemail.com	Oakland	California	676199949368890	3a9010fc16ee28fcecfedda50ff55993	JCB 15 digit	37.7950129897720615	-122.256756769259823
3593	2019-10-04 11:10:43	2019-10-04	Mr. Orren Fisher	mr.orren.fisher@woohoo.com	Oakland	California	869917568723929003	2bd784be9553cd7b24ffd47b0211e131	American Express	37.8103958665642637	-122.23940823187715
3594	2019-10-04 13:00:03	2019-10-04	Kiel Heaney-Kiehn	kiel.heaney.kiehn@geemail.com	Berkeley	California	3158153181073888730	a3b4c9b9163edf304b9ba84f2c7e491d	Diners Club / Carte Blanche	37.8619794311635616	-122.253928912006103
3595	2019-10-04 13:14:05	2019-10-04	Shafter Hodkiewicz Sr.	shafter.hodkiewicz.sr.@geemail.com	San Francisco	California	4313079984445862	41df5b8f00c1800d54d20f83c1dd81f3	American Express	37.7434717820238816	-122.418411324594075
3596	2019-10-04 13:38:05	2019-10-04	Kitty Nolan	kitty.nolan@woohoo.com	San Francisco	California	4593920686379	b25716eb4ddb450f92e151c21c33f2eb	VISA 16 digit	37.807049128705394	-122.451067637311453
3597	2019-10-04 15:28:27	2019-10-04	Kenney Corkery-Bode	kenney.corkery.bode@geemail.com	New York	New York	3096252410726788496	29efc6af2b41d1143f07bee9f8cc9c5a	VISA 16 digit	40.6662459735982083	-73.8831994633551687
3598	2019-10-04 17:40:13	2019-10-04	Pearley Roob	pearley.roob@woohoo.com	Gresham	Oregon	180090061625089084	3d67fbd65d365dd765402e28a7ba5416	American Express	45.5892885021820646	-122.455798604039842
3599	2019-10-04 17:58:42	2019-10-04	Janae Eichmann	janae.eichmann@geemail.com	New York	New York	4015410662616188	5a933201448df7a7f79856fc4729988e	Mastercard	40.5640851580295703	-73.9938810259930762
3600	2019-10-04 18:16:36	2019-10-04	Mrs. Yvette Jaskolski PhD	mrs.yvette.jaskolski.phd@geemail.com	San Francisco	California	4799586996603877	51c4686456d39c92bdb29767f77941a5	American Express	37.7819647634310272	-122.410541286940315
3601	2019-10-04 18:59:28	2019-10-04	Falon Weber	falon.weber@geemail.com	San Francisco	California	52066804258927116	d08c0436902162e0a5e8ac1abc492cee	American Express	37.7792164156537069	-122.412811942119546
3602	2019-10-04 19:20:44	2019-10-04	Kristofer Gleichner	kristofer.gleichner@woohoo.com	Oklahoma City	Oklahoma	4133117357844556	efe4dd9f94561ac4d0654da4c192a217	VISA 16 digit	35.5270417903460611	-97.4319379002217261
3603	2019-10-04 20:28:59	2019-10-04	Darron Kozey-Mayert	darron.kozey.mayert@woohoo.com	Oakland	California	869927298382364536	12ca971d625f9a9a36312b1784dd83a5	Maestro	37.7924445322361962	-122.270463801525764
3604	2019-10-04 20:54:35	2019-10-04	Chase Quitzon	chase.quitzon@geemail.com	Berkeley	California	869930252580835834	080ba7fd506616c631877900f3de01b1	JCB 16 digit	37.8722807688879755	-122.272993849871256
3605	2019-10-04 21:00:41	2019-10-04	Robbie Klein	robbie.klein@warmmail.com	Chicago	Illinois	869902555109734070	fd0c1b4d1775a36cd8d987ff2f6992db	VISA 16 digit	41.7612991390585933	-87.6880800342682676
3606	2019-10-04 21:53:11	2019-10-04	Merna Turcotte	merna.turcotte@woohoo.com	San Francisco	California	6011534160827096576	873e3c1babb7937e046ae6897ec0d7f6	JCB 16 digit	37.809915591991512	-122.43663886399689
3607	2019-10-04 23:06:04	2019-10-04	Izaiah Auer	izaiah.auer@geemail.com	San Francisco	California	4626193652823219	52e956cb742c92a12de22df1707b8ee6	JCB 16 digit	37.769678466165729	-122.450137513931296
3608	2019-10-04 23:42:04	2019-10-04	Maybell Ratke	maybell.ratke@geemail.com	San Francisco	California	3088703010700529976	32eb77f977210b5da37c9f40d6202bbd	Discover	37.7672159646388437	-122.430130747753267
3609	2019-10-05 01:04:54	2019-10-05	Lemon Anderson PhD	lemon.anderson.phd@geemail.com	San Francisco	California	55974565294728914	3d320bdc53b52215fd01004aa5dbec83	Discover	37.7685383027657267	-122.432911329234116
3610	2019-10-05 01:34:35	2019-10-05	Mr. Chad Gusikowski	mr.chad.gusikowski@woohoo.com	Omaha	Nebraska	869945630640672391	4fd21b804f5f9ec15fbb35650e678ffe	VISA 16 digit	41.2286245311755692	-96.120444470189895
3611	2019-10-05 01:59:39	2019-10-05	Adell Zemlak	adell.zemlak@geemail.com	Bellevue	Washington	4767581489334864	1e921ef4eca7ee07a6cdfaf7f117aaa9	Mastercard	47.6210155860237805	-122.103223643830034
3612	2019-10-05 02:18:25	2019-10-05	Jarrad Jaskolski	jarrad.jaskolski@woohoo.com	New York	New York	869999279911357814	43115d5672db95e8cd0c586ec6b46129	Discover	40.7470889882873735	-73.9757657074265182
3613	2019-10-05 03:10:28	2019-10-05	Paityn Barton MD	paityn.barton.md@geemail.com	Fargo	North Dakota	53507629529159372	b51a36516e5576773505021d8dca4200	JCB 15 digit	46.908783801062782	-96.7713787845764273
3614	2019-10-05 04:38:45	2019-10-05	Hortencia Barrows-Hauck	hortencia.barrows.hauck@geemail.com	San Francisco	California	51849947440610290	cd035144fff4bed9afbf1ed8e70360d4	Discover	37.7833935551690061	-122.400368071475484
3615	2019-10-05 04:41:02	2019-10-05	Lavonda Keebler	lavonda.keebler@warmmail.com	San Francisco	California	3096655441757479054	f9e816d1ddfbe894821155d969a48484	VISA 16 digit	37.7669004725544255	-122.41300705418692
3616	2019-10-05 04:57:28	2019-10-05	Drema Sauer	drema.sauer@geemail.com	Oakland	California	4590445781748523	ecad93b34387dd95fca6d3af46fb6c50	JCB 16 digit	37.8164268199847697	-122.234807127671701
3617	2019-10-05 05:41:05	2019-10-05	Almira Christiansen	almira.christiansen@geemail.com	San Francisco	California	869912971323755098	f4320e706ba16aae1bea66e38dc24569	Diners Club / Carte Blanche	37.7875222443599625	-122.430993597326903
3618	2019-10-05 05:57:07	2019-10-05	Lenna Senger DVM	lenna.senger.dvm@geemail.com	San Francisco	California	3088279237237869435	44e0f884069041da9a8c957d981e4457	VISA 16 digit	37.7741422596164114	-122.416841579076106
3619	2019-10-05 06:38:11	2019-10-05	Hamp Hoeger	hamp.hoeger@geemail.com	San Francisco	California	4407038389894162	94596d0c1c916a6956731e1d34707e32	Discover	37.7852910714148251	-122.428598519078903
3620	2019-10-05 07:59:58	2019-10-05	Ismael Becker DVM	ismael.becker.dvm@geemail.com	Berkeley	California	3112074969286321499	995421f27df699fe7951a46838e96e85	Diners Club / Carte Blanche	37.8873176193122703	-122.288884228401344
3621	2019-10-05 08:13:48	2019-10-05	Marquez Hudson	marquez.hudson@geemail.com	Berkeley	California	180083198369728417	4f953b3823a08dcb9ade0bb9bd9b1a60	Maestro	37.8380617215026476	-122.293952391731267
3622	2019-10-05 08:18:33	2019-10-05	Stephan Homenick	stephan.homenick@geemail.com	San Francisco	California	4766410297580	92b7c46bcbfa18c10e86196ac26824f6	VISA 13 digit	37.8039937393270478	-122.489130951110724
3623	2019-10-05 08:19:01	2019-10-05	Ever Reinger	ever.reinger@woohoo.com	San Francisco	California	3020495981408745	0203a03413b298c06ca543d81be6fae0	Mastercard	37.7786147829166481	-122.416958128019516
3624	2019-10-05 08:41:44	2019-10-05	Miss Tricia Zieme	miss.tricia.zieme@geemail.com	San Francisco	California	53545928841088507	332d4f2f645a8e7e773ede7229ff8c98	Voyager	37.7738700182045193	-122.413999937228695
3625	2019-10-05 08:50:01	2019-10-05	Ms. Tierra Terry	ms.tierra.terry@geemail.com	New York	New York	6011689550692843487	5152015651af1fbd80a7aaf0e24d75f1	VISA 16 digit	40.6068410076424442	-73.9640458261955445
3626	2019-10-05 10:04:11	2019-10-05	Miller Morissette	miller.morissette@warmmail.com	San Antonio	Texas	3158616617627433185	cc2919c6c3012157ba8d97c09cfe7244	JCB 16 digit	29.5105856859195974	-98.602122176235909
3627	2019-10-05 10:04:35	2019-10-05	Georgina Nicolas	georgina.nicolas@geemail.com	San Francisco	California	869996151208954756	9c07358ff3373d3c53743d2b1c9227fb	Diners Club / Carte Blanche	37.7931397836482077	-122.422013755503869
3628	2019-10-05 10:09:31	2019-10-05	Shayna Walsh	shayna.walsh@geemail.com	San Francisco	California	4319076535588145	079c9d105cabaca3ac4b45f280d2d2a7	JCB 15 digit	37.7691507233209904	-122.423822595864806
3629	2019-10-05 10:11:10	2019-10-05	Dorian Howell	dorian.howell@warmmail.com	New York	New York	4926568495655	c07c2791b5cf00fa0838dc6bee9c2b72	JCB 15 digit	40.7001209969855822	-74.0247559995751772
3630	2019-10-05 11:06:44	2019-10-05	Mr. Coby Bergstrom	mr.coby.bergstrom@geemail.com	Los Angeles	California	4585444619993	3d8ed8b1288b349b67a0d60e8a5434c5	Diners Club / Carte Blanche	34.0371873535547351	-118.38085942049436
3631	2019-10-05 11:33:16	2019-10-05	Aleah Kerluke	aleah.kerluke@warmmail.com	Indianapolis	Indiana	6011618066076252308	a64f5147cb4b8969d3f7bcedae87cc2f	Mastercard	39.717137192982058	-86.0928639961607729
3632	2019-10-05 12:04:58	2019-10-05	Shante Reilly DVM	shante.reilly.dvm@geemail.com	San Francisco	California	3112339008579738910	f30fba06883804c398ff6664202607d1	VISA 16 digit	37.8039813864367034	-122.446681073900507
3633	2019-10-05 12:39:53	2019-10-05	Mr. Remy Leffler MD	mr.remy.leffler.md@geemail.com	Richardson	Texas	3003062825396846	654217ff81f727adbfd0c89597a61a95	Diners Club / Carte Blanche	32.8895702239826306	-96.7714590070996508
3634	2019-10-05 13:15:26	2019-10-05	Ms. Simone Dare	ms.simone.dare@geemail.com	San Francisco	California	3000868163499775	e2ce810067893be65876dd9e6efa8070	JCB 16 digit	37.7634133801903218	-122.398026196259707
3635	2019-10-05 14:14:57	2019-10-05	Mr. Kent Stehr	mr.kent.stehr@geemail.com	San Francisco	California	3441179432318528	a3a6e25ae40a36eb1e48551de1520cdc	Diners Club / Carte Blanche	37.7687516484292729	-122.428702784661198
3636	2019-10-05 15:04:41	2019-10-05	Charlotte Balistreri-Parisian	charlotte.balistreri.parisian@geemail.com	Berkeley	California	51081519428562228	26c0cd1c5e276867ebc090defc341bac	Mastercard	37.8696696852310524	-122.273018722885595
3637	2019-10-05 16:42:03	2019-10-05	Mr. Gunnar Volkman DVM	mr.gunnar.volkman.dvm@geemail.com	San Francisco	California	3498097503484619	71ac1a704d07bd63266ea7d7d8bcbbb8	Discover	37.7708221318895951	-122.469866499264114
3638	2019-10-05 17:00:54	2019-10-05	Jarad Moore PhD	jarad.moore.phd@geemail.com	San Antonio	Texas	630413983526479	1ce7bfffe8ab673607151aa8e980d271	American Express	29.4782739274274554	-98.5000954211059963
3639	2019-10-05 17:35:41	2019-10-05	Teri Krajcik	teri.krajcik@geemail.com	Phoenix	Arizona	4280974938613	c5f3b798f0154d5eee6d889b03cdcdcb	Maestro	33.5695791372496686	-112.045393023958809
3640	2019-10-05 17:41:16	2019-10-05	Harlan Nitzsche	harlan.nitzsche@geemail.com	Oakland	California	3013993080785887	5b8b28170a0d5af9cd99cdf49176dac5	American Express	37.7952270354948539	-122.260748260759186
3641	2019-10-05 18:01:15	2019-10-05	Finnegan Kling II	finnegan.kling.ii@geemail.com	Philadelphia	Pennsylvania	3528373267189874070	c6b272ed3b93c3ef62ccca11dacff19b	Mastercard	40.0253386032260963	-75.1912148923046999
3642	2019-10-05 19:31:34	2019-10-05	Daphne Stiedemann-Robel	daphne.stiedemann.robel@warmmail.com	Garland	Texas	4747369988486	d207d5271f733825d499f32dd2299dd7	Mastercard	32.8591421246297628	-96.7157938668664627
3643	2019-10-05 20:27:21	2019-10-05	Dr. Dana Sporer DVM	dr.dana.sporer.dvm@geemail.com	San Francisco	California	53224231837260810	d03159a3c0a6ab939adec6a8bf242aeb	JCB 15 digit	37.7930081295791354	-122.423192234964233
3644	2019-10-05 21:26:54	2019-10-05	Tommy Marks MD	tommy.marks.md@woohoo.com	Los Angeles	California	4447037183020	12777e50914f7cec29ba2e527484d7cc	Mastercard	33.9636566755693394	-118.387619299254567
3645	2019-10-05 22:27:55	2019-10-05	Hoyt Farrell	hoyt.farrell@geemail.com	Lincoln	Nebraska	869976525164094950	f4a7eaa36a7256f1934c7c0c60566b31	Discover	40.8538839622419303	-96.6012963780362242
3646	2019-10-05 22:43:03	2019-10-05	Dr. Herlinda Berge	dr.herlinda.berge@geemail.com	Kent	Washington	4500643556127662	7505d70d72c9a3cdf31527ab414956c7	JCB 16 digit	47.4446159767098692	-122.119234892879419
3647	2019-10-06 01:57:15	2019-10-06	Violetta Hills	violetta.hills@geemail.com	Oakland	California	4961037873588775	5cdfc68a9b8d616265fa3fb138deeb93	American Express	37.8369478453152865	-122.240877486545855
3648	2019-10-06 02:31:54	2019-10-06	Conor Kris-Eichmann	conor.kris.eichmann@geemail.com	Fresno	California	6011704373746508712	dfcc87a3e157194e495bc235eb0c21b3	VISA 16 digit	36.7507724508982179	-119.890986261248216
3649	2019-10-06 02:55:26	2019-10-06	Josiephine Heidenreich MD	josiephine.heidenreich.md@geemail.com	Dallas	Texas	4460002780232889	7bbe306544e9a1e332d0a1bec4d549cf	JCB 15 digit	32.863685273918513	-96.8010841052941942
3650	2019-10-06 03:39:07	2019-10-06	Miss Madisen Beer	miss.madisen.beer@geemail.com	San Francisco	California	54370193644656550	db2413b92eeb159421aa6b1fd37f8390	VISA 16 digit	37.776761449316389	-122.44555780953651
3651	2019-10-06 03:41:58	2019-10-06	Seymour O'Hara	seymour.o'hara@geemail.com	Berkeley	California	4743498040620575	c662d81cb558627d2fdfcfb9a4fdc62a	American Express	37.8353514319890039	-122.250095432667052
3652	2019-10-06 04:04:45	2019-10-06	Elzy Herman-Keebler	elzy.herman.keebler@warmmail.com	Oakland	California	4798565697298	cddd1480adaccdc4892c40b44b0b624b	JCB 15 digit	37.8157089224651912	-122.275726717939861
3653	2019-10-06 04:30:21	2019-10-06	Mr. Wiliam Price	mr.wiliam.price@geemail.com	Long Beach	California	6011579389502390055	272530776fddb9f3cce7ae9c661d357c	Voyager	33.796768679219106	-118.117424493764716
3654	2019-10-06 05:17:24	2019-10-06	Mrs. Maida Collins DDS	mrs.maida.collins.dds@geemail.com	Lewisville	Texas	3048516298200970	acd1ce47d3cd9960cfc6fdb7ddc27cb4	VISA 13 digit	32.9865533166084433	-96.9500662735693197
3655	2019-10-06 05:25:48	2019-10-06	Doc Steuber	doc.steuber@geemail.com	San Francisco	California	4619594984467337	283fc27765fe574dfe97d4039cd99085	JCB 15 digit	37.8188834690862663	-122.411813079377254
3656	2019-10-06 06:12:18	2019-10-06	Fernand Macejkovic	fernand.macejkovic@geemail.com	Berkeley	California	3420388713242381	f44163c9cb327c2d707fe64d48b01ec7	Voyager	37.8959683296338454	-122.260298136524995
3657	2019-10-06 06:29:57	2019-10-06	Dejah Stokes	dejah.stokes@warmmail.com	San Francisco	California	3528990068718744740	5bf6f5ef22abf0a96205b9b13033699e	VISA 16 digit	37.7379692120242396	-122.439509630013731
3658	2019-10-06 08:44:56	2019-10-06	Earline Schowalter	earline.schowalter@geemail.com	New Orleans	Louisiana	3528308930742686600	377d4850bf1a4991f5d477dcb9f31fbe	Maestro	29.9950805391199893	-89.9312315002810152
3659	2019-10-06 09:16:28	2019-10-06	Dr. Armando Skiles	dr.armando.skiles@geemail.com	San Francisco	California	6011360393554679236	a7bc46402a8b1da09ef88650d336ad21	American Express	37.77576590213706	-122.437480340410985
3660	2019-10-06 09:26:31	2019-10-06	Asberry Ward	asberry.ward@geemail.com	Berkeley	California	6011746250939718516	e5045e718025741ecdbebe935b463940	Mastercard	37.8491889075565169	-122.273817325227
3661	2019-10-06 09:46:19	2019-10-06	Blas Gislason	blas.gislason@geemail.com	Houston	Texas	4075977672098	32ff3b4532719a4bec2be0a3601a3ff3	JCB 15 digit	29.6977563520971692	-95.4713723509121763
3662	2019-10-06 11:12:15	2019-10-06	Hector Wuckert	hector.wuckert@warmmail.com	Bellevue	Washington	4808451563759	c80cf23538083f0cf16f28c7fecd30b3	VISA 16 digit	47.5526293745447006	-122.190882614074269
3663	2019-10-06 12:10:17	2019-10-06	Debbi Sipes	debbi.sipes@woohoo.com	Berkeley	California	53386204170659041	0a7a80ade6a770e8aa2bbe09fd19a975	VISA 16 digit	37.8592526142582244	-122.304034838491361
3664	2019-10-06 12:28:15	2019-10-06	Bailey Ernser	bailey.ernser@geemail.com	Mobile	Alabama	869985785073007589	46a55788163e11b3f0c302dfa8e0878d	VISA 13 digit	30.7257521819896979	-88.00229959498607
3665	2019-10-06 13:10:31	2019-10-06	Logan Smith Jr.	logan.smith.jr.@woohoo.com	Los Angeles	California	180012991471605564	fe81ff6bc9b2ac5f912bcf32c1458b0a	Discover	34.0132251696061303	-118.397338858525444
3666	2019-10-06 15:39:47	2019-10-06	Michelle Schamberger	michelle.schamberger@geemail.com	Modesto	California	4992563186870181	46430e6dea7a2b6e3c927528fe6aad06	VISA 16 digit	37.5594462355133203	-120.930629617601639
3667	2019-10-06 15:53:58	2019-10-06	Dr. Wilford Stokes II	dr.wilford.stokes.ii@woohoo.com	Sunnyvale	California	6011052450669798252	9b1534cb636729e11d50f0745245c7c2	JCB 16 digit	37.3940396724727009	-122.032058046638227
3668	2019-10-06 16:35:46	2019-10-06	Nigel Emmerich I	nigel.emmerich.i@geemail.com	Kansas City	Missouri	4195554171152458	3302e6aa61fdf21d87e06ff2fa7d23e9	Voyager	39.1256734247621196	-94.5263917000256555
3669	2019-10-06 16:50:55	2019-10-06	Dominique Abernathy DVM	dominique.abernathy.dvm@geemail.com	San Francisco	California	630443721989069	a04eb7623fe4e432f75a7f2f8ac362b2	VISA 13 digit	37.779312461967784	-122.417571223112361
3670	2019-10-06 17:53:12	2019-10-06	Yancy Lemke	yancy.lemke@warmmail.com	Berkeley	California	869948660800177383	a2b863e6d3c67559e541f8d06387a6f1	VISA 16 digit	37.8930155923646339	-122.273500582037542
3671	2019-10-06 18:13:48	2019-10-06	Mr. Thompson Ernser II	mr.thompson.ernser.ii@woohoo.com	San Francisco	California	180089338916368630	41e8bc0006819c53a73f1c3871236da4	American Express	37.738652849424227	-122.432843061198639
3672	2019-10-06 18:28:17	2019-10-06	Taurus Bergnaum	taurus.bergnaum@geemail.com	Berkeley	California	502049006526161	ed3a07af8bbb74eb3353d3c9801dedd9	Diners Club / Carte Blanche	37.8818172647048783	-122.255398693323372
3673	2019-10-06 18:41:55	2019-10-06	Fae Cassin	fae.cassin@geemail.com	Charlotte	North Carolina	3337982060751824190	c7bc642b3032a5f59e30fc31a96b76ee	VISA 13 digit	35.2899459114551561	-80.7397559317238631
3674	2019-10-06 18:52:01	2019-10-06	Kazuo Mayer II	kazuo.mayer.ii@warmmail.com	San Francisco	California	53649008426429908	a89aa6e5c76f56f29d4d5810750528a6	VISA 13 digit	37.7622729646609443	-122.459261911440592
3675	2019-10-06 19:04:12	2019-10-06	Phyllis Swift	phyllis.swift@geemail.com	San Francisco	California	4945034083457892	44b1b122d5c40d7b96572ae89a2b8aac	VISA 16 digit	37.7694276911042621	-122.439372212983599
3676	2019-10-06 19:15:10	2019-10-06	Mrs. Corrine Kessler	mrs.corrine.kessler@warmmail.com	Round Rock	Texas	180067701674103281	de3ffe8fb182e5e10f5bf02fa962eb0e	VISA 16 digit	30.5977060717202747	-97.6381894383430478
3677	2019-10-06 20:22:19	2019-10-06	Arlena Skiles	arlena.skiles@geemail.com	Colorado Springs	Colorado	4180235971046606	f35c28dccaf109fc0e9440785358323b	Maestro	38.9417125895667837	-104.842277494787055
3678	2019-10-06 20:32:15	2019-10-06	Jovan Hamill	jovan.hamill@geemail.com	San Francisco	California	3096598590416648358	cdb628bab692efc9434377c0e4e65b65	American Express	37.7993601471182004	-122.399550263038265
3679	2019-10-06 21:21:20	2019-10-06	Ms. Permelia Bernhard	ms.permelia.bernhard@geemail.com	Chicago	Illinois	4861737506332100	94893ab0f9fcd87fcee8ce7038af2c7d	JCB 16 digit	41.9280390398878637	-87.6889939819026694
3680	2019-10-06 21:24:59	2019-10-06	Miles Roob	miles.roob@geemail.com	Oakland	California	4897154822339249	92bea08e04281256fa66be81288e7ce4	Mastercard	37.7895795806880983	-122.292071795621879
3681	2019-10-06 21:30:08	2019-10-06	Vinton Boyer	vinton.boyer@geemail.com	Los Angeles	California	53515275249563913	7adfc58ceb8c1b04c5160fa13b37f028	JCB 15 digit	34.0853357582684566	-118.462684056301782
3682	2019-10-06 22:12:08	2019-10-06	Augusta Spinka	augusta.spinka@warmmail.com	Des Moines	Iowa	3337510646074394738	4d35f9ad687513c38a2457ab04901a68	Voyager	41.6256675459653138	-93.5778973355002819
3683	2019-10-06 22:54:15	2019-10-06	Turner Stanton	turner.stanton@warmmail.com	Stockton	California	3158521271733013343	26ad3d716bba325da9bbd8ba91fc92d2	Maestro	37.9935970855142955	-121.255968661754579
3684	2019-10-07 00:03:00	2019-10-07	Hugh Labadie	hugh.labadie@geemail.com	Chicago	Illinois	3096941733604708659	1a1e9e3199abd869c7c89850dff9c863	Maestro	41.8872701840311308	-87.6783879782102957
3685	2019-10-07 00:05:44	2019-10-07	Skylar Carter	skylar.carter@woohoo.com	New York	New York	869967584301445667	c6c24c700e30263ef80114dad8f8bca0	American Express	40.6182006623353828	-73.9058809211838934
3686	2019-10-07 00:25:48	2019-10-07	Evangelina Dicki-Kuhic	evangelina.dicki.kuhic@geemail.com	San Francisco	California	4542685115975	9900489172ed555ae95d11dd1c15b033	VISA 16 digit	37.7412270721606262	-122.442182238352999
3687	2019-10-07 00:57:28	2019-10-07	Rodrick Kshlerin-Ritchie	rodrick.kshlerin.ritchie@geemail.com	Peoria	Arizona	6011839293710071323	17835100e7ffa3f94542c0252b7b1ad9	Discover	33.7419425926439445	-112.376186476640413
3688	2019-10-07 01:10:55	2019-10-07	Mr. Rossie Hauck	mr.rossie.hauck@geemail.com	Akron	Ohio	3446366773244307	8ce3010da2b18d74624ee1a00f47a978	American Express	41.1688979226928211	-81.5884860505662886
3689	2019-10-07 02:34:29	2019-10-07	Dr. Mackenzie Gaylord V	dr.mackenzie.gaylord.v@geemail.com	Atlanta	Georgia	3158013499476154876	e9b02a4eb2393dfd344ea833c5acf01b	Voyager	33.830893154888976	-84.3384039092388065
3690	2019-10-07 04:54:45	2019-10-07	Krysten Witting	krysten.witting@geemail.com	Clinton	Michigan	3006612773006289	524f7fab3aeb95644c7510788067f6ad	Diners Club / Carte Blanche	42.5276586793895817	-82.9687990027088631
3691	2019-10-07 05:05:42	2019-10-07	Freddie Ortiz	freddie.ortiz@woohoo.com	Oakland	California	210054593311618929	12c23a084a8c1f3717ecb62b13015cdc	VISA 16 digit	37.7669165122212576	-122.295653624585199
3692	2019-10-07 05:34:48	2019-10-07	Luther Jenkins	luther.jenkins@woohoo.com	Davenport	Iowa	6011426853317216909	5c64cf2ea80cd39c7c09066067fa014b	Discover	41.5583444410268186	-90.5809963646773184
3693	2019-10-07 05:44:08	2019-10-07	Camilo Lynch	camilo.lynch@woohoo.com	San Francisco	California	6011231960300696974	25a531d7eda78ad0ee538066c67d2baa	JCB 15 digit	37.7369635747382262	-122.444405092331024
3694	2019-10-07 05:45:03	2019-10-07	Elliana Paucek	elliana.paucek@warmmail.com	Paterson	New Jersey	3096918898125732766	a91ddcdf1e609a547afa5fc7935391d2	JCB 15 digit	40.8309496189888534	-74.2342211438782584
3695	2019-10-07 06:16:47	2019-10-07	Odus Daniel	odus.daniel@warmmail.com	New York	New York	4028170168240	55eeb013f8c3e0253716472c541931aa	Discover	40.6692845398783689	-73.8676718065876514
3696	2019-10-07 07:09:11	2019-10-07	Dawn Waters	dawn.waters@geemail.com	San Francisco	California	3112146229581685542	26cc03bd04e4ef0be64d8c0e9e09736c	Mastercard	37.7713995657820902	-122.456899898034948
3697	2019-10-07 07:50:19	2019-10-07	Carnell Metz-Collins	carnell.metz.collins@woohoo.com	San Antonio	Texas	4276771823022192	d0e0f18552f01df5aa8132ddcffe3d5a	Diners Club / Carte Blanche	29.4942549162149419	-98.5861575073864316
3698	2019-10-07 08:22:22	2019-10-07	Grover Mitchell-Kuhn	grover.mitchell.kuhn@woohoo.com	San Francisco	California	6011516618255067973	7aa2d16775733a9ec48c642658ffa306	JCB 16 digit	37.7669983436808749	-122.439865000753116
3699	2019-10-07 08:29:12	2019-10-07	Gustavo Auer	gustavo.auer@geemail.com	Phoenix	Arizona	3096101875594378666	0b707178c89adb502db08fa00ec82d0f	American Express	33.5295529645800627	-112.085212027740113
3700	2019-10-07 09:17:54	2019-10-07	Marlyn Adams	marlyn.adams@geemail.com	Tucson	Arizona	4553111090393	efff5aa59e5417ece51e75abf5380fa4	Discover	32.2310261521995116	-110.820055968197437
3701	2019-10-07 09:40:40	2019-10-07	Mr. Kalel Lehner PhD	mr.kalel.lehner.phd@geemail.com	San Francisco	California	180028173449984296	68428faff3453937c350f09958e388a1	JCB 16 digit	37.7695281369429736	-122.461202320374326
3702	2019-10-07 09:53:05	2019-10-07	Dr. Moe Bahringer	dr.moe.bahringer@geemail.com	San Francisco	California	869905570505891488	47c981e5775e518f51effbdcd0f920a8	VISA 16 digit	37.7625332704384391	-122.452948844921025
3703	2019-10-07 10:17:21	2019-10-07	Spurgeon Ziemann	spurgeon.ziemann@woohoo.com	Greensboro	North Carolina	4249742880746	551ab2b9b6e145d7b9a882bc38d9d190	VISA 16 digit	36.0944809139356053	-79.7728279806189278
3704	2019-10-07 10:17:39	2019-10-07	Karly Green	karly.green@geemail.com	San Francisco	California	6011072565682553529	00bf0512b39c742b2dbc3cdbd1ae6137	VISA 16 digit	37.8128916775932922	-122.430679663754702
3705	2019-10-07 11:45:38	2019-10-07	Glennis Kutch	glennis.kutch@woohoo.com	Richmond	Virginia	51288898366219962	e28c603b764a1f4e2138bbbfadee3680	JCB 16 digit	37.5271641661167124	-77.5241235790066412
3706	2019-10-07 12:00:40	2019-10-07	Jerica Jakubowski	jerica.jakubowski@geemail.com	San Francisco	California	3528038731595597556	0ac2dc823e3942a96b56653db5834a07	VISA 13 digit	37.7898563668932752	-122.448196359825261
3707	2019-10-07 12:23:22	2019-10-07	Irvine Sipes	irvine.sipes@geemail.com	San Francisco	California	503881568748420	ee0b9b2f04c1ac03075914f3fe0263e0	Discover	37.7637001337191833	-122.43670538751374
3708	2019-10-07 13:23:00	2019-10-07	Miss Lacy Mohr MD	miss.lacy.mohr.md@warmmail.com	Bakersfield	California	180003466188013940	87915f07fdf2fd3e13af12aeb5f2c001	JCB 16 digit	35.3318777807697657	-118.968389675886556
3709	2019-10-07 18:52:44	2019-10-07	Lee Sawayn-Murphy	lee.sawayn.murphy@geemail.com	San Francisco	California	6011513116645942495	078b994809c11942d85d1de69f932423	JCB 16 digit	37.7541911341046941	-122.414872551168841
3710	2019-10-07 18:56:12	2019-10-07	Tea Larson	tea.larson@geemail.com	San Francisco	California	4857901085842576	07bb3661f91f3d0f711a24ce0b9bb137	VISA 16 digit	37.7744514277122505	-122.433744487883189
3711	2019-10-07 20:22:01	2019-10-07	Annabella Klocko	annabella.klocko@geemail.com	Berkeley	California	180047403206441165	660f2d0737965ed6277f40b5eb76ed54	Diners Club / Carte Blanche	37.8188789886765164	-122.239955828842909
3712	2019-10-07 21:53:01	2019-10-07	Keandre Kunde	keandre.kunde@geemail.com	Washington	District of Columbia	4853397299112944	91fd6ecdc080e29ac61029d9de8d7e04	Voyager	38.9181041922684727	-76.9674750827465175
3713	2019-10-07 22:44:53	2019-10-07	Dr. Jermain Casper	dr.jermain.casper@geemail.com	San Francisco	California	3112516814924174585	29e4e49bca5258359c4a88f531df711c	JCB 15 digit	37.7766251018637291	-122.446752250736367
3714	2019-10-07 23:44:36	2019-10-07	Dr. Thomas Fay PhD	dr.thomas.fay.phd@geemail.com	Chesapeake	Virginia	4635374050519	d7819445a46be822a913381ba074e41c	American Express	36.6021834616787771	-76.2104586590856314
3715	2019-10-08 01:13:10	2019-10-08	Ailene Hirthe-Gleichner	ailene.hirthe.gleichner@geemail.com	Modesto	California	869984249462522733	a22199f0440a3b9dbcba5fcf8b62f425	Discover	37.7284891969058691	-120.94965588382631
3716	2019-10-08 01:23:17	2019-10-08	Tim Emmerich	tim.emmerich@warmmail.com	San Francisco	California	52263790993028941	6738cd45e2cacc2cebd4fe2dad7eebf9	Discover	37.7793755190584264	-122.409642423096486
3717	2019-10-08 02:39:57	2019-10-08	Kole Ebert	kole.ebert@warmmail.com	New York	New York	6011255145615252496	5e44af884d0806cac364f802bfc26c56	Maestro	40.6229748931471235	-73.9233349245402991
3718	2019-10-08 02:59:44	2019-10-08	Almus Gorczany	almus.gorczany@geemail.com	San Francisco	California	4749024507834	565923aa0e235d53d86da7fe47d00fa2	VISA 16 digit	37.7684804175799798	-122.438179771267173
3719	2019-10-08 04:50:25	2019-10-08	Clarissa Schamberger-White	clarissa.schamberger.white@geemail.com	San Francisco	California	51675792502594365	062d69de60796262ff7cb4ae8c1453a0	American Express	37.7957818415582878	-122.459327754388553
3720	2019-10-08 05:07:03	2019-10-08	Mrs. Carmela Weimann DDS	mrs.carmela.weimann.dds@geemail.com	San Francisco	California	4031692467252570	884609db5a4982e9a3f00734b017e689	VISA 13 digit	37.7740614558853167	-122.415171795099894
3721	2019-10-08 05:39:23	2019-10-08	Benjamine Howe DVM	benjamine.howe.dvm@geemail.com	North Charleston	South Carolina	4296154097484099	289cf596e67f46a994491abd391e48a5	JCB 15 digit	32.8320730706837054	-80.0471266849525307
3722	2019-10-08 08:28:12	2019-10-08	Della Koss-Buckridge	della.koss.buckridge@warmmail.com	Garland	Texas	3088855742116335962	970b653615978247070a6a40434fb347	Discover	32.9923626226607709	-96.6854933717448262
3723	2019-10-08 09:38:42	2019-10-08	Abdul Bernier	abdul.bernier@geemail.com	Cleveland	Ohio	502051223728414	69bccd6a90a551e196a627ac7d1354e2	Voyager	41.539754138266666	-81.5866831056080741
3724	2019-10-08 11:12:42	2019-10-08	Dr. Sylas Wyman	dr.sylas.wyman@geemail.com	San Francisco	California	210091639335540253	0880339014305019550e68ce9d74e2db	Diners Club / Carte Blanche	37.7675513496937327	-122.432545033556181
3725	2019-10-08 11:46:47	2019-10-08	Melonie Mayer	melonie.mayer@warmmail.com	San Francisco	California	4245594297039	45bb189d2e89954774e7ea706a446c28	Diners Club / Carte Blanche	37.7794696394398173	-122.422112029292038
3726	2019-10-08 12:24:43	2019-10-08	Cara Bode	cara.bode@geemail.com	Madison	Wisconsin	869998555737648549	d7fea654e7301dc522bfbc5e18d450ab	American Express	43.123667665242408	-89.3479179008282784
3727	2019-10-08 12:44:28	2019-10-08	Vina Mayert	vina.mayert@geemail.com	San Francisco	California	4832278134018643	6f9135b37d0377d984710f3356731911	JCB 16 digit	37.7859436700103686	-122.410758246783516
3728	2019-10-08 13:50:10	2019-10-08	Novella Metz	novella.metz@geemail.com	San Francisco	California	3443523696119700	cf6a58980cae0acc0b4dd9111f9bf458	Voyager	37.8103294575210853	-122.427221726149909
3729	2019-10-08 14:01:52	2019-10-08	Mr. Jamar Will	mr.jamar.will@geemail.com	San Francisco	California	4633042742336925	187556449fae1c654d762050761e4dab	Discover	37.7896632193112936	-122.453479619345757
3730	2019-10-08 14:03:07	2019-10-08	Verdie Simonis	verdie.simonis@geemail.com	San Francisco	California	3088438898223671404	e55799916cfe91009bc78903701c04df	Discover	37.7889697967202451	-122.380727407389045
3731	2019-10-08 14:50:35	2019-10-08	Jerod McKenzie-Jast	jerod.mckenzie.jast@geemail.com	New York	New York	4778694967539412	57fdd4adf921d338578a2d54283235c8	Maestro	40.7218422610536237	-74.00327295762375
3732	2019-10-08 15:57:58	2019-10-08	Carey Grimes	carey.grimes@geemail.com	Phoenix	Arizona	3402473786841608	04ac25f7fa3d681d7cf91f6d3de98ee5	JCB 15 digit	33.5246252626113588	-112.166678505849475
3733	2019-10-08 16:29:41	2019-10-08	Ray Feeney Sr.	ray.feeney.sr.@geemail.com	Denver	Colorado	3158930352297671463	b87494b153a134f78a1db8cdaa63838e	VISA 16 digit	39.778330580615993	-104.888148531621695
3734	2019-10-08 17:29:01	2019-10-08	Mr. Steven West Sr.	mr.steven.west.sr.@geemail.com	San Francisco	California	3038376796033575	7463f7f345d5caa25a44803fd54fd083	Mastercard	37.7492559349442516	-122.470122110022018
3735	2019-10-08 18:24:54	2019-10-08	Gilda Russel	gilda.russel@geemail.com	Oakland	California	3528532662336805308	6622d3ff374165f736d17f7d650e831d	Mastercard	37.8139801880040167	-122.275273785325453
3736	2019-10-08 18:58:14	2019-10-08	Romaine Zieme-Carter	romaine.zieme.carter@geemail.com	San Francisco	California	210097410632367608	16b540f4f932f2fbcd79cbafec6500e3	Discover	37.7624697371808793	-122.401074623419674
3737	2019-10-08 19:40:31	2019-10-08	Gail McClure-Hegmann	gail.mcclure.hegmann@geemail.com	Berkeley	California	3112037447990677353	97fc25053d1e1a3858423698ffd0700e	Mastercard	37.8707420764760627	-122.269584431686383
3738	2019-10-08 20:14:45	2019-10-08	Miss Vickie Stracke	miss.vickie.stracke@geemail.com	Phoenix	Arizona	869911829612676774	96a26d6a1082c866980ad6c5eb5f1f1c	JCB 15 digit	33.6325918890003166	-112.074715318709991
3739	2019-10-08 20:28:10	2019-10-08	Rob Pfeffer	rob.pfeffer@geemail.com	Tucson	Arizona	3096642709148268030	b58ceffceec195179e3eacc0bfe6eab1	Mastercard	32.2179849030956618	-110.926246227719261
3740	2019-10-08 20:54:31	2019-10-08	Verlie Schiller	verlie.schiller@geemail.com	Concord	California	53084723140832672	a7ef351b9917ddf2e7a54ca24c46ac14	VISA 16 digit	37.9017453398954132	-122.073511952039226
3741	2019-10-08 21:11:06	2019-10-08	Neta Windler	neta.windler@warmmail.com	San Francisco	California	4299442689372625	0bf01ace67d2d42b3e02cbb47e959efe	JCB 16 digit	37.7973284694626841	-122.423040956569452
3742	2019-10-08 21:28:53	2019-10-08	Ms. Kyara Block	ms.kyara.block@geemail.com	Virginia Beach	Virginia	3112581589019549681	14f313f876df97c78c860fe418020730	VISA 16 digit	36.7392755333986116	-75.936905083027483
3743	2019-10-08 21:46:57	2019-10-08	Joan Tillman DVM	joan.tillman.dvm@geemail.com	New York	New York	869927459911511506	12151d00b78e5c1cc3edaf6e0ca569f7	VISA 13 digit	40.5962376778237513	-73.8880008652236313
3744	2019-10-08 22:05:36	2019-10-08	Luca Ferry	luca.ferry@woohoo.com	Hampton	Virginia	3528801516389793171	abf9b11d5d1088c70352da95fa47b8f7	Maestro	36.9729352064449373	-76.2124945749159934
3745	2019-10-08 22:15:25	2019-10-08	Dr. Blaze Graham V	dr.blaze.graham.v@geemail.com	Oakland	California	54933500137044302	602fd3e4850677c42a091b3a474de221	VISA 16 digit	37.8049005426291842	-122.307595601291951
3746	2019-10-08 23:19:10	2019-10-08	Celeste Crooks	celeste.crooks@geemail.com	Indianapolis	Indiana	3465225047080051	6b3c66cb90ff10b66d9db9d6f533ebe8	VISA 16 digit	39.7835091277498734	-86.2002762619607097
3747	2019-10-08 23:39:42	2019-10-08	Regenia Ebert	regenia.ebert@woohoo.com	San Francisco	California	4699909703465102	63f16df45a118976b78cfded8364305a	VISA 16 digit	37.7951007230760467	-122.424603641003301
3748	2019-10-09 00:07:33	2019-10-09	Gil Yundt	gil.yundt@geemail.com	Anchorage	Alaska	3753257073490387	2bb97f20358c59e75226f9cc9fa37000	VISA 16 digit	61.2510153329215967	-149.264310818922894
3749	2019-10-09 02:46:05	2019-10-09	Errol Murray	errol.murray@geemail.com	San Diego	California	3112191589028678440	ff2cb53fe9e8550d05b85933709d29a0	Discover	32.9023075021870426	-117.174169832877823
3750	2019-10-09 03:52:28	2019-10-09	Nikki Roberts DDS	nikki.roberts.dds@geemail.com	San Francisco	California	4183598423328196	9ee596d6714322f3dac2bb4126ab7e1b	JCB 15 digit	37.799041190380116	-122.424407536716302
3751	2019-10-09 04:23:16	2019-10-09	Juanita Nikolaus	juanita.nikolaus@geemail.com	Toledo	Ohio	4029596841147	a0ead090e5f2e1c91a281ee0cf6d5bcc	VISA 13 digit	41.690946916414795	-83.6582067210558904
3752	2019-10-09 05:13:28	2019-10-09	Minda Schimmel-Sporer	minda.schimmel.sporer@warmmail.com	San Francisco	California	3337059341438419184	2735ed2d7e029735cd4d4e16166b33c6	Discover	37.7875277256125486	-122.424153494092977
3753	2019-10-09 05:37:16	2019-10-09	Rohan Ferry	rohan.ferry@geemail.com	Colorado Springs	Colorado	869932444837362617	1e4d4577dc8d068512bb72a0b5c9ea79	JCB 16 digit	38.7831576476387667	-104.856607382434234
3754	2019-10-09 06:03:45	2019-10-09	Lonzo Heidenreich PhD	lonzo.heidenreich.phd@geemail.com	Oakland	California	4122780239058662	bcc8734729eb5b01d457bc0d8906111f	JCB 16 digit	37.7925962310534445	-122.266669373377709
3755	2019-10-09 07:04:03	2019-10-09	Ivey DuBuque II	ivey.dubuque.ii@warmmail.com	Oakland	California	869930254835179901	9171df10956145c39caea3a98e5b97f0	Maestro	37.7741950186481432	-122.283673327838258
3756	2019-10-09 07:48:47	2019-10-09	Rikki Bauch	rikki.bauch@woohoo.com	Oakland	California	3158655071037840617	772c05a6dcc3481518e3cc2b48a1d4cb	VISA 16 digit	37.7737828016194968	-122.251139746412989
3757	2019-10-09 09:09:12	2019-10-09	Yvette Lubowitz	yvette.lubowitz@woohoo.com	Oakland	California	3528210415629031051	eaff890dc0e3e51f5af5b9c9c1fed682	VISA 16 digit	37.789613674101588	-122.238911648117124
3758	2019-10-09 09:38:22	2019-10-09	Jasmyn Baumbach	jasmyn.baumbach@geemail.com	Berkeley	California	6011990919762095613	ae75d23f373ac6e7b0d4e1c703b4d428	VISA 16 digit	37.8426813306046199	-122.268492665125706
3759	2019-10-09 10:12:15	2019-10-09	Jabez Osinski	jabez.osinski@geemail.com	Madison	Wisconsin	3088558427159231811	8343554e9ed299a9bc90be18e9dfe77e	JCB 16 digit	42.9938150667093737	-89.4222626387491886
3760	2019-10-09 11:16:35	2019-10-09	Tammie Legros	tammie.legros@geemail.com	Vista	California	180091258344790724	6b6a144ae32dac0c990b1f5c4bbf3a2f	VISA 16 digit	33.2386985470987852	-117.32672061548233
3761	2019-10-09 12:07:20	2019-10-09	Yaakov Daniel	yaakov.daniel@geemail.com	Los Angeles	California	561203658461243	bd13076a6de6d54dea649cc367b7f9ac	VISA 16 digit	34.0501591514196207	-118.443894335207716
3762	2019-10-09 12:33:52	2019-10-09	Elwin Kiehn-D'Amore	elwin.kiehn.d'amore@geemail.com	San Francisco	California	180088008467288856	92e93c9265986aec1b75552cf49906b8	JCB 16 digit	37.7912855452295915	-122.444144372128079
3763	2019-10-09 13:36:08	2019-10-09	Keifer Connelly-Crist	keifer.connelly.crist@geemail.com	Provo	Utah	4946094710513318	52c7e4e777aab2b4ddf9ecbafd2102d8	VISA 13 digit	40.254068683625384	-111.727823311803121
3764	2019-10-09 13:51:28	2019-10-09	Harlan Morar Sr.	harlan.morar.sr.@woohoo.com	Louisville	Kentucky	3005902927973711	4752e7c7f450659ae042fd68244b0b9e	JCB 15 digit	38.0688658932592716	-85.6910536152847158
3765	2019-10-09 15:53:38	2019-10-09	Ingram Dicki	ingram.dicki@geemail.com	San Francisco	California	210010434384767819	d2c18500dab7aa9d3f9995e81d2f2e6b	VISA 16 digit	37.7418692050570286	-122.434363517023215
3766	2019-10-09 17:04:22	2019-10-09	Normand Auer	normand.auer@woohoo.com	San Francisco	California	53997163364949157	d9af098360c724d86bfa563fd106d357	Mastercard	37.7631194253382318	-122.364526888544518
3767	2019-10-09 18:11:31	2019-10-09	Willian Ritchie	willian.ritchie@geemail.com	Honolulu	Hawaii	4428514333650	3268ead716e98d9796eaa3a99703dfae	American Express	21.3500800044026242	-157.769438211407873
3768	2019-10-09 18:14:09	2019-10-09	Marlee Crist-Streich	marlee.crist.streich@geemail.com	Atlanta	Georgia	6011283804524355073	ad4529c542693fe8c53ad8b048f9b762	Discover	33.8409592314433354	-84.4228428104471504
3769	2019-10-09 18:26:20	2019-10-09	Marrion Weimann	marrion.weimann@geemail.com	San Francisco	California	869937228975564620	127c1b5f3081b216ed3f92de0eec5833	Discover	37.7630201285133111	-122.431776626700469
3770	2019-10-09 19:20:38	2019-10-09	Ima Fritsch DVM	ima.fritsch.dvm@geemail.com	San Francisco	California	210098863004660746	98fd7781ca4ef0fa1a8498a6e9a13132	JCB 15 digit	37.7670901312688017	-122.4419950742314
3771	2019-10-09 21:45:42	2019-10-09	Lizbeth Witting	lizbeth.witting@geemail.com	Houston	Texas	210051850767046770	155c11e94783149f7c4ba4085473f417	VISA 16 digit	29.8793086103241876	-95.3012618956171025
3772	2019-10-09 21:53:41	2019-10-09	Falon Buckridge	falon.buckridge@geemail.com	San Francisco	California	3045701864263320	1b54ba4b4f18bfc8f8e4f72499e5ddde	Discover	37.754258353369778	-122.444455977710817
3773	2019-10-09 22:00:37	2019-10-09	Carolina Powlowski	carolina.powlowski@warmmail.com	Elizabeth	New Jersey	869936916450850701	15b07d55bcc33318531211a317dd5797	JCB 16 digit	40.6707537138029949	-74.147901981178677
3774	2019-10-09 22:02:56	2019-10-09	Reatha Bernier	reatha.bernier@geemail.com	Berkeley	California	869915861034348357	6371051545ff30db0b8c9eeb36c97e4e	VISA 16 digit	37.920798119462539	-122.303730202586493
3775	2019-10-09 22:20:38	2019-10-09	Edmond Emmerich Jr.	edmond.emmerich.jr.@warmmail.com	San Francisco	California	6011855415723955965	9a35ff5bcc1593b2d28b40ebe99c4b6b	Voyager	37.7860826846047644	-122.394094935750715
3776	2019-10-09 22:25:05	2019-10-09	Dr. Laron Nader Sr.	dr.laron.nader.sr.@geemail.com	Palm Bay	Florida	4118843388208	52a9161341c0438422dc7dd567726db6	Diners Club / Carte Blanche	27.9487942851468922	-80.617720931146664
3777	2019-10-09 22:26:19	2019-10-09	Katherine Rodriguez-Klein	katherine.rodriguez.klein@warmmail.com	Cleveland	Ohio	6011497289188077860	af721d870dfa92c8db897f596b306c12	Diners Club / Carte Blanche	41.5452405708692964	-81.7634392136946389
3778	2019-10-09 22:52:30	2019-10-09	Hollis Hamill	hollis.hamill@geemail.com	Stockton	California	6011776197059943171	6e89750854ea718cff31eabb80acaa48	VISA 13 digit	37.9485072806674992	-121.307610538331048
3779	2019-10-09 23:45:22	2019-10-09	Dannie Wehner DDS	dannie.wehner.dds@geemail.com	Amarillo	Texas	52878461085741117	e10215023ddb6e0e0629d9dd8ff305c6	JCB 16 digit	35.125417989788204	-101.820140671529629
3780	2019-10-09 23:52:52	2019-10-09	Leitha Kuhic	leitha.kuhic@geemail.com	Oakland	California	3032367914052908	e8d38eaa40098806e859a789ad1fe80a	JCB 16 digit	37.7983634426538515	-122.257855903327041
3781	2019-10-10 00:08:18	2019-10-10	Jaquez Cummings	jaquez.cummings@geemail.com	Chesapeake	Virginia	210081984264819076	5ad67fdf8a7cb8874045600e6041807c	Diners Club / Carte Blanche	36.6303611889254341	-76.2035632490955237
3782	2019-10-10 00:13:07	2019-10-10	Crystal Botsford	crystal.botsford@geemail.com	San Francisco	California	501810026541119	e7bc3a5db1fe8072284a6882eb5c0b12	VISA 16 digit	37.7893162466396362	-122.46070963421127
3783	2019-10-10 01:19:52	2019-10-10	Obed Trantow	obed.trantow@geemail.com	Durham	North Carolina	3096897319974384364	969591aec62e1f0d3f98522c2192aceb	VISA 13 digit	36.0374621695619055	-78.8061526383642104
3784	2019-10-10 01:30:04	2019-10-10	Mr. Malaki Ruecker	mr.malaki.ruecker@geemail.com	Boston	Massachusetts	3158991762537579027	a239c4a88b09ff46037170a8ca8664fd	VISA 13 digit	42.3830853236541145	-71.0549762480843867
3785	2019-10-10 01:41:20	2019-10-10	Shiloh Dooley MD	shiloh.dooley.md@geemail.com	San Francisco	California	3096851891976167090	46e3a8bf0a93a24d3efcecabb6dc8bfb	JCB 16 digit	37.7635429027671137	-122.449100131435387
3786	2019-10-10 02:08:44	2019-10-10	Devonte Dickinson	devonte.dickinson@geemail.com	Los Angeles	California	3337390026269534676	06b63bd36267658286920cee6c8803de	VISA 13 digit	34.1118743141513292	-118.336682882298902
3787	2019-10-10 02:29:31	2019-10-10	Edgardo Thiel	edgardo.thiel@geemail.com	San Francisco	California	676330579053569	99c2fd466d959bdd25f246667266be3e	VISA 13 digit	37.7834461775549073	-122.427393374007551
3788	2019-10-10 02:55:15	2019-10-10	Vickie Lakin DVM	vickie.lakin.dvm@geemail.com	San Francisco	California	52241695568026724	9cae5c6f6967301c64ed4335ac3c9b80	American Express	37.7490995502645248	-122.45031597744898
3789	2019-10-10 03:03:40	2019-10-10	Nathanial Hills	nathanial.hills@warmmail.com	Albuquerque	New Mexico	3405215381892776	f883959a815c595ca5ac1dfc2dc902d1	JCB 16 digit	35.1550170629885059	-106.636080021232004
3790	2019-10-10 03:09:12	2019-10-10	Broderick Mayer IV	broderick.mayer.iv@geemail.com	Berkeley	California	51781464679230550	6793fbd6f4e160d95ad2e2e96d0f821a	VISA 16 digit	37.9009325109245623	-122.246405948778573
3791	2019-10-10 03:48:38	2019-10-10	Liddie Padberg	liddie.padberg@geemail.com	San Francisco	California	3088204430951052722	e3658605996ef89b6dae874362169ee6	Voyager	37.8236933802348076	-122.439551064517005
3792	2019-10-10 04:13:34	2019-10-10	Patti Wisozk	patti.wisozk@geemail.com	Long Beach	California	3029400965042966	6f177442a7510e14872af3fdf472535e	American Express	33.8496581033624651	-118.1768170152951
3793	2019-10-10 05:50:27	2019-10-10	Sam Collins	sam.collins@geemail.com	San Francisco	California	6011946399019859688	1ef55bc224dd99e049b7afa5778741fa	Discover	37.8040322885969431	-122.439290830152331
3794	2019-10-10 05:54:37	2019-10-10	Forest Goodwin	forest.goodwin@geemail.com	Overland Park	Kansas	3112883585250906593	2165036367abf1749f7c705cba879a5d	VISA 16 digit	38.8487392573487043	-94.7252724596805962
3795	2019-10-10 06:34:20	2019-10-10	Roxana Marvin	roxana.marvin@geemail.com	Los Angeles	California	4154107115523695	0e406bc2c0cf8e35110384a262529926	Mastercard	34.106363537661359	-118.441776913636545
3796	2019-10-10 08:34:14	2019-10-10	Cristine Wuckert	cristine.wuckert@geemail.com	Virginia Beach	Virginia	3032210120137578	fd844dff29f53616be9519fadca69862	Discover	36.7219249213300643	-76.1030435245621959
3797	2019-10-10 08:47:45	2019-10-10	Byrd Huel	byrd.huel@geemail.com	Chicago	Illinois	3054829560703884	cdeb3fc069fbe411ba2bdcfe86f8688d	JCB 15 digit	41.9285813103731755	-87.6314564441826178
3798	2019-10-10 08:52:23	2019-10-10	Carlota Tremblay	carlota.tremblay@woohoo.com	El Paso	Texas	54761646660806182	69f0839f6003d5b429d4f65ec385ddaa	Maestro	31.9416799334172161	-106.423961190551523
3799	2019-10-10 09:58:54	2019-10-10	Stacey Hettinger	stacey.hettinger@geemail.com	San Francisco	California	4713847171822	2defc9cb5ec8b4b8f7da0f29fe37e975	JCB 16 digit	37.7459263411011534	-122.412745567442585
3800	2019-10-10 12:23:08	2019-10-10	Fidelia Beier	fidelia.beier@geemail.com	Wichita	Kansas	3030891807881505	c25045ffba8a2aaa91e7613f9e9dc9c8	American Express	37.7405020102735591	-97.3380168268192563
3801	2019-10-10 13:48:50	2019-10-10	Milo Daugherty	milo.daugherty@geemail.com	San Francisco	California	4868345093760650	ce04dfb83c99d758575465934ab2340a	American Express	37.8041620718030416	-122.411142563616465
3802	2019-10-10 13:51:22	2019-10-10	Crista Kunde	crista.kunde@geemail.com	San Francisco	California	4917899965638841	165293b841b81bb680a4ecf90e67dc65	Mastercard	37.7708700147141556	-122.404927434935018
3803	2019-10-10 14:04:18	2019-10-10	Brandan Lakin	brandan.lakin@geemail.com	Cary	North Carolina	180089821229138402	368f3199f0af684a82264dbb97a01394	VISA 13 digit	35.6942605333976459	-78.8510383693121355
3804	2019-10-10 14:34:43	2019-10-10	Theresia Braun DVM	theresia.braun.dvm@geemail.com	Columbus	Ohio	52766914463667044	575872e4a0041adf94fe4846a6725dfb	JCB 15 digit	40.0663917250510266	-83.0617475871231505
3805	2019-10-10 15:37:42	2019-10-10	Cayden Wilderman	cayden.wilderman@geemail.com	Peoria	Arizona	210086724710789449	dd5fdf89f6abe3d0d8e0d9e1ca134aab	VISA 16 digit	33.7446682303480827	-112.239425531907017
3806	2019-10-10 15:52:15	2019-10-10	Kaleb Schowalter-Bernhard	kaleb.schowalter.bernhard@woohoo.com	Temecula	California	869953567702768049	cf03dc32be08fb94e108f4c921ec1e5d	Voyager	33.5921157409105433	-117.033733935673524
3807	2019-10-10 17:22:26	2019-10-10	Loren Schuppe	loren.schuppe@warmmail.com	Anaheim	California	639008142274276	25542d76ec46fc1202dd6709543fa721	JCB 16 digit	33.8030893016438938	-117.680332264790678
3808	2019-10-10 17:22:44	2019-10-10	Clell Kuhlman-Williamson	clell.kuhlman.williamson@geemail.com	San Francisco	California	4260960040507774	3e658e177dc6bc188c244ac78169b110	VISA 16 digit	37.771820604939748	-122.408031961875352
3809	2019-10-10 17:33:18	2019-10-10	Parthenia Goldner	parthenia.goldner@geemail.com	Berkeley	California	4548932933790456	ad3e1a6f984f4742320761ec190f1e63	Discover	37.8698793435854597	-122.280205032783527
3810	2019-10-10 19:19:40	2019-10-10	Orla Bosco	orla.bosco@geemail.com	Dallas	Texas	4868160607081	e5d9a5ed38714df9e2fcb933e082484d	Mastercard	32.7988860515218263	-96.8172893491536257
3811	2019-10-10 19:48:30	2019-10-10	Mr. Raymon Greenfelder	mr.raymon.greenfelder@geemail.com	Gilbert	Arizona	3009049424868147	a73cbfec7ab92b1faf62230f21cb1d18	Mastercard	33.3629173739228406	-111.813634063596282
3812	2019-10-10 20:16:00	2019-10-10	Ms. Francine Miller	ms.francine.miller@geemail.com	San Francisco	California	6011236683819774596	774eb714f3fdd7c719634eb522935f2b	Maestro	37.7801722190966203	-122.409811329694108
3813	2019-10-10 20:50:15	2019-10-10	Unknown Leuschke	unknown.leuschke@geemail.com	Boston	Massachusetts	53625532553535904	121fa008500357d4be449ec570a0c50e	JCB 15 digit	42.3591372605115168	-71.0260182124979877
3814	2019-10-10 21:38:05	2019-10-10	Kasey Hagenes	kasey.hagenes@geemail.com	San Francisco	California	6011066152923015333	32c70729ba2894f2e9351b6180488cde	VISA 13 digit	37.7839652970924078	-122.421918790965037
3815	2019-10-10 22:32:21	2019-10-10	Madeleine Stracke	madeleine.stracke@geemail.com	Los Angeles	California	869904614297992491	0158e93657421fca5300ea7aeb0c94ab	Maestro	33.9536673651408378	-118.454103667008866
3816	2019-10-11 01:53:03	2019-10-11	Winfred Grady	winfred.grady@geemail.com	New York	New York	3528338009629275086	ddaefac4e4b3d238a53de6c0663eeca7	Mastercard	40.6520671043302855	-73.9714378979418399
3817	2019-10-11 01:54:38	2019-10-11	Vince Huel II	vince.huel.ii@geemail.com	San Francisco	California	6011680737676471604	436cf8b7c3a1887b9b441a382d51215f	Maestro	37.8209213373256006	-122.458342353301461
3818	2019-10-11 02:00:02	2019-10-11	Kyree Mueller	kyree.mueller@geemail.com	Oakland	California	630440444343756	6dee5772e66b60e00a3a9c26d9c72a40	Mastercard	37.8130456501804204	-122.28337680686549
3819	2019-10-11 02:25:19	2019-10-11	Charlee Cole	charlee.cole@warmmail.com	Lowell	Massachusetts	6011759799601727266	ad53e8d9de0095100b442bbb80b78e2f	VISA 16 digit	42.7063082162160441	-71.2793410798408047
3820	2019-10-11 03:14:40	2019-10-11	Junious Spencer	junious.spencer@warmmail.com	San Francisco	California	6011658300774003528	492f9e4e8de7a6d782a172bad35ab3b6	Maestro	37.7628715308381473	-122.429214407189235
3821	2019-10-11 03:28:48	2019-10-11	Zaniyah Lockman	zaniyah.lockman@woohoo.com	Phoenix	Arizona	180009985446680970	8ae16e641160ba9c2bcc95859e18f2a6	JCB 16 digit	33.5681711345378346	-112.008300137838731
3822	2019-10-11 03:52:47	2019-10-11	Payten Harris	payten.harris@geemail.com	Oakland	California	53272741725727176	fd57d6e902d31703c22d5bfb2147764e	Mastercard	37.8142058725007075	-122.287343995844381
3823	2019-10-11 04:54:32	2019-10-11	Adrain Romaguera	adrain.romaguera@geemail.com	West Covina	California	4606333225561870	ad9b85d28ffbcd68468f0dca9a70941b	Mastercard	34.1088569893144111	-117.976396327286579
3824	2019-10-11 05:19:33	2019-10-11	Dr. Jamil Christiansen	dr.jamil.christiansen@geemail.com	Minneapolis	Minnesota	4552672823885510	32679288727ca21f6292153604731583	Voyager	44.9831233537375894	-93.3099071364190422
3825	2019-10-11 06:10:13	2019-10-11	Dr. Sharde Koepp PhD	dr.sharde.koepp.phd@geemail.com	San Francisco	California	060403167695869	4e518f497979a3258982a0e576978c8c	American Express	37.7698661023344968	-122.43061712010423
3826	2019-10-11 06:50:41	2019-10-11	Paris Flatley	paris.flatley@warmmail.com	San Francisco	California	3112291776263414487	b4a68dba28031aa4f09b15dffd3a5e76	VISA 16 digit	37.8026041020041674	-122.466841438792898
3827	2019-10-11 07:02:57	2019-10-11	Anastasia Senger DDS	anastasia.senger.dds@warmmail.com	San Francisco	California	869966214679071496	451ae1c993733e527346992274642250	Diners Club / Carte Blanche	37.8161124039305534	-122.449296093464184
3828	2019-10-11 07:45:23	2019-10-11	Miss Suellen White	miss.suellen.white@geemail.com	Fort Worth	Texas	4054988554879826	646d445012db1b2dee01e28f93720f93	JCB 16 digit	32.6963680862970634	-97.4284176581826102
3829	2019-10-11 08:08:41	2019-10-11	Suzie Cruickshank	suzie.cruickshank@warmmail.com	San Francisco	California	4457366674115392	731d9d367d2ea48127154b360f1dbace	Maestro	37.7918008397709215	-122.403303158322572
3830	2019-10-11 09:38:50	2019-10-11	Jann Torp	jann.torp@woohoo.com	Berkeley	California	53538341819238139	ed6ae9467fc46e2bbd06650974fba909	JCB 16 digit	37.8693289254726437	-122.285047288602541
3831	2019-10-11 10:02:29	2019-10-11	Cindi Gerlach	cindi.gerlach@geemail.com	New York	New York	3707063323149733	8ee44f1544dc6b7866bde5e2a0e37c1e	JCB 16 digit	40.734977180160584	-73.8508686890721293
3832	2019-10-11 10:09:30	2019-10-11	Dr. Latifah Stoltenberg PhD	dr.latifah.stoltenberg.phd@geemail.com	Yonkers	New York	180015583027767787	262d9ba152837d8a00e293d91c731e38	VISA 16 digit	41.0355548518910993	-73.8353055993910914
3833	2019-10-11 10:19:03	2019-10-11	Ariel Reichel	ariel.reichel@geemail.com	Port St. Lucie	Florida	3337443674281846359	2137378902e32d74651fe4636c01fa81	JCB 16 digit	27.3551382595807304	-80.4850474544886509
3834	2019-10-11 11:52:13	2019-10-11	Andrae Morar	andrae.morar@geemail.com	San Francisco	California	4637616043883853	155d45294c9716732665b17c691c6946	American Express	37.7520555782144172	-122.406451509291443
3835	2019-10-11 12:39:30	2019-10-11	Mr. Arnoldo Weissnat	mr.arnoldo.weissnat@woohoo.com	Laredo	Texas	3088770308662079990	731c1c9a5e55baf2588f286f8604844b	Diners Club / Carte Blanche	27.6316124329991659	-99.5360464243225778
3836	2019-10-11 12:40:48	2019-10-11	Eusebio Gleichner	eusebio.gleichner@warmmail.com	Davie	Florida	6011033746877869916	231d047284e7edcb8e4fdd23d4040fe8	Maestro	26.1751002564825122	-80.2290199782606237
3837	2019-10-11 13:01:50	2019-10-11	Amberly Halvorson-Brakus	amberly.halvorson.brakus@geemail.com	Philadelphia	Pennsylvania	6011169649148390470	6031bc471fdb2dabb30466088e43d705	American Express	40.079130231724676	-75.1666980746567361
3838	2019-10-11 14:18:10	2019-10-11	Miss Maryjo Hirthe DVM	miss.maryjo.hirthe.dvm@warmmail.com	Montgomery	Alabama	4562839127435692	8c789aae47543eae3adcae55d5edc383	Discover	32.3465017760571101	-86.32394744406119
3839	2019-10-11 14:53:36	2019-10-11	Dann Kiehn	dann.kiehn@woohoo.com	Chula Vista	California	6011096141419462533	737b7d5bd895386b9484e7437550f040	Diners Club / Carte Blanche	32.5987570308845491	-117.045222405786433
3840	2019-10-11 16:38:33	2019-10-11	Delwin Hahn	delwin.hahn@geemail.com	San Francisco	California	3713664345165359	fdb9121ee12fd1509f43e2967758bd05	VISA 13 digit	37.7556044297151416	-122.399199425358432
3841	2019-10-11 17:36:55	2019-10-11	Dortha Sporer	dortha.sporer@geemail.com	San Francisco	California	4204547498830	d0821f5f1ef7d16d73908033a4faed1d	Voyager	37.7680215036321414	-122.441390712607458
3842	2019-10-11 17:44:07	2019-10-11	Mya Kemmer	mya.kemmer@geemail.com	San Francisco	California	55702289732881982	16770418a117ef653edf078e351e94a4	JCB 16 digit	37.7725005754420735	-122.407433686621061
3843	2019-10-11 17:52:39	2019-10-11	Dottie Grady-Koelpin	dottie.grady.koelpin@geemail.com	Philadelphia	Pennsylvania	4078961123204521	d67276f3ac0194ef27a3bfa354b252ed	VISA 16 digit	40.0106463652994506	-75.1621174385204966
3844	2019-10-11 18:27:37	2019-10-11	Tilman Harris	tilman.harris@geemail.com	San Francisco	California	180030348938531289	6d83eaa85ebcc56ca01da93fa7f25bb8	Mastercard	37.8039008132977798	-122.438400111162053
3845	2019-10-11 18:31:05	2019-10-11	Winnifred Abbott	winnifred.abbott@geemail.com	New York	New York	3034877835027027	38546204cacf0470117a91c82c47a4bd	VISA 13 digit	40.6409749604519419	-73.9089380961738556
3846	2019-10-11 18:52:59	2019-10-11	Abel Toy	abel.toy@woohoo.com	San Francisco	California	3035480688933521	f15064143b508dd4947ade8bdd3e1f57	Maestro	37.8002461535353405	-122.404730712553672
3847	2019-10-11 20:20:15	2019-10-11	Krystal Gutmann-Mosciski	krystal.gutmann.mosciski@geemail.com	Berkeley	California	4557335015734889	c28569a66211a749d9090a9fbc64a706	JCB 15 digit	37.8631863602652814	-122.277189559603883
3848	2019-10-11 20:27:28	2019-10-11	Dr. Kimora Schaden DVM	dr.kimora.schaden.dvm@geemail.com	San Francisco	California	3003400994206299	3672e2dab81d2fa8b0f5e60fabe60b4e	Voyager	37.784060175419647	-122.436619158170629
3849	2019-10-11 21:09:31	2019-10-11	Kale Rosenbaum	kale.rosenbaum@geemail.com	Boulder	Colorado	6011743769607807767	89d7de294a611edf2d43b53640fd14e4	Voyager	39.9922543628588301	-105.187530629677326
3850	2019-10-11 21:52:13	2019-10-11	Dr. Gerald Beatty I	dr.gerald.beatty.i@geemail.com	San Antonio	Texas	4510661655312918	ec610862bf79e55dc75de4d5b609d427	JCB 16 digit	29.4024971967168156	-98.6147762153599388
3851	2019-10-11 22:15:09	2019-10-11	Miss Neola Volkman PhD	miss.neola.volkman.phd@geemail.com	Oakland	California	4536314119900502	1658bbeaf11ba040347f901faef3e11c	Diners Club / Carte Blanche	37.7927136761727098	-122.268158782678384
3852	2019-10-11 22:25:24	2019-10-11	Elmire Blanda	elmire.blanda@woohoo.com	San Francisco	California	869927150845696238	603b5a90d2212ebb3396c8e11324495e	Diners Club / Carte Blanche	37.7373191707397098	-122.422941430152065
3853	2019-10-11 22:29:21	2019-10-11	Alvira Leffler	alvira.leffler@geemail.com	Beaumont	Texas	869985704270866937	c6eece775797cbf06f963d8c5194c713	American Express	30.1488205062761914	-94.1436985460363331
3854	2019-10-11 23:08:15	2019-10-11	Hazelle Parker-Rath	hazelle.parker.rath@geemail.com	Fort Lauderdale	Florida	3055667850607541	b18da8ee66402cb95c828060229e9390	American Express	26.1275316184841095	-80.1098774671375651
3855	2019-10-11 23:22:00	2019-10-11	Dr. Dafne Lubowitz	dr.dafne.lubowitz@woohoo.com	San Antonio	Texas	180033627376130242	4d77e8e9f9b1975062ab78538542d6e6	Discover	29.5309410312749456	-98.5068408776376288
3856	2019-10-12 00:00:21	2019-10-12	Harland Lang	harland.lang@warmmail.com	Jersey City	New Jersey	4381119729935707	5ec3f89a33faad1828ecd1ec074dad7f	Discover	40.6585736252307868	-74.0666196200020721
3857	2019-10-12 00:14:16	2019-10-12	Dr. Sebrina Parker DVM	dr.sebrina.parker.dvm@geemail.com	San Francisco	California	3494448006286478	ccfb6cb9fbd9735f49cf2915d1ac60e6	JCB 16 digit	37.8046905202358374	-122.43484088509679
3858	2019-10-12 00:42:08	2019-10-12	Mr. Nehemiah Gleason PhD	mr.nehemiah.gleason.phd@geemail.com	San Francisco	California	4886738546228820	befb4bf8853609f1633983c515e541bd	Maestro	37.7361061324258671	-122.431153050272059
3859	2019-10-12 02:37:05	2019-10-12	Mr. Winfred Yundt DVM	mr.winfred.yundt.dvm@geemail.com	Oakland	California	54150939137936602	f5d4638172f062c6cd722c8e65596445	American Express	37.7875864303377895	-122.290055250436481
3860	2019-10-12 02:42:32	2019-10-12	Wayde Reilly III	wayde.reilly.iii@geemail.com	Houston	Texas	3059362109777347	c6cfcc42b4dce4c5a7a45c47a823aec0	Discover	29.7371592165514826	-95.4452210605159479
3861	2019-10-12 04:22:48	2019-10-12	Less Predovic-Olson	less.predovic.olson@geemail.com	San Francisco	California	675906748313100	72e1206c436848a42a21384ad177bebb	VISA 16 digit	37.8007196862944639	-122.432822436139148
3862	2019-10-12 05:39:29	2019-10-12	Coleton Langworth DVM	coleton.langworth.dvm@woohoo.com	San Francisco	California	4804144522278	129664846d1f307c1fa8e35ae973ae85	Mastercard	37.7785853017666327	-122.444482089259012
3863	2019-10-12 06:35:06	2019-10-12	Trula Sawayn	trula.sawayn@geemail.com	San Francisco	California	3096165115885030582	c477b08553e74bc1f193129ddfa309be	American Express	37.7493524597211092	-122.416359508872446
3864	2019-10-12 07:12:32	2019-10-12	Lular Halvorson	lular.halvorson@geemail.com	San Francisco	California	3158865471122433698	b04f33581dbbd047aa270c80903115df	JCB 16 digit	37.8130170099712828	-122.428579580251267
3865	2019-10-12 07:28:19	2019-10-12	Shannen Price	shannen.price@warmmail.com	Odessa	Texas	4906738035037	eb887e9f1d5725d26620ae7c9e505abf	VISA 16 digit	31.8884450505033143	-102.292040421270201
3866	2019-10-12 08:01:33	2019-10-12	Brisa Bruen	brisa.bruen@geemail.com	San Francisco	California	4720507987488	d7d81ae9a0bcefa0441506e9a3283852	VISA 16 digit	37.7762366155563498	-122.421373341233448
3867	2019-10-12 08:42:39	2019-10-12	Walter Kirlin	walter.kirlin@geemail.com	Jacksonville	Florida	503878173604980	b44e95f4e5e2626435f8ca36b45fee8c	VISA 16 digit	30.3918079862423234	-81.5649554348163406
3868	2019-10-12 10:21:26	2019-10-12	Austyn Sporer	austyn.sporer@geemail.com	San Francisco	California	51872107727459255	1ec388a2bc567e20035cf8e38cef2642	Mastercard	37.7812292107929153	-122.441192054734714
3869	2019-10-12 11:31:26	2019-10-12	Manly Hane	manly.hane@woohoo.com	San Francisco	California	4165962851144479	26737604a2595e470ac1445c3886c4e3	VISA 16 digit	37.7832273073884366	-122.426380845093064
3870	2019-10-12 12:18:31	2019-10-12	Mr. Vicente Goyette	mr.vicente.goyette@geemail.com	San Francisco	California	3337380932514361512	ee68461dfbf63f2ac8352bce251bfa3a	Diners Club / Carte Blanche	37.7614243569325012	-122.424113746901597
3871	2019-10-12 12:56:37	2019-10-12	Patience Osinski	patience.osinski@geemail.com	Oakland	California	4752212348707267	38d2f96d2d950ebffd6aefed8539fdee	Discover	37.8062257759819786	-122.257630113016447
3872	2019-10-12 12:58:37	2019-10-12	Konnor Wintheiser	konnor.wintheiser@geemail.com	San Francisco	California	3112296409253372219	02147de9963dbb8f1c3f8812a69d8583	VISA 16 digit	37.7943554724488422	-122.434344825256602
3873	2019-10-12 13:39:10	2019-10-12	Aleck Bechtelar	aleck.bechtelar@geemail.com	Fort Worth	Texas	4213037132390449	d444499091794b08bb0884900fb920e0	American Express	32.7566784692052764	-97.4211764866307419
3874	2019-10-12 15:47:10	2019-10-12	Ronda Yost DVM	ronda.yost.dvm@geemail.com	San Francisco	California	3112883928110176082	d5f310148905b01fa5732eae7b03d285	JCB 15 digit	37.7981568479178947	-122.437917886872498
3875	2019-10-12 17:08:06	2019-10-12	Erling Walter	erling.walter@geemail.com	Berkeley	California	502009392691763	98842efe0656ab31fe9657f791fdb388	Voyager	37.8490379813060116	-122.260650170215214
3876	2019-10-12 17:46:27	2019-10-12	Haylie Johnson	haylie.johnson@warmmail.com	El Cajon	California	4618736374314	b31a17e2423707e0f568f861b46441e4	Mastercard	32.8446249480366674	-116.933087316499652
3877	2019-10-12 19:11:59	2019-10-12	Dante Swift-O'Conner	dante.swift.o'conner@warmmail.com	San Francisco	California	4277267332606624	aede6ea205b42535c69254d4735eb007	Voyager	37.8199290861877486	-122.427384790323345
3878	2019-10-12 19:28:30	2019-10-12	Blas Larson	blas.larson@geemail.com	Tuscaloosa	Alabama	3479711876012533	d48e057c5926e937c424077e084af624	JCB 16 digit	33.2469926027636973	-87.6066524948090262
3879	2019-10-12 19:30:19	2019-10-12	Mittie Bode	mittie.bode@geemail.com	New York	New York	52329774371136858	b80a24e73731e5591e1b3c9ee645bffb	VISA 16 digit	40.712272709676995	-74.0219010493148062
3880	2019-10-12 21:05:37	2019-10-12	Brittni Jakubowski	brittni.jakubowski@geemail.com	Cincinnati	Ohio	4410359795532	8642afee1275e81d8de47f588d6b1ad8	Voyager	39.1469689698655188	-84.4653164142549002
3881	2019-10-12 22:13:08	2019-10-12	Dr. Hart Fay	dr.hart.fay@woohoo.com	Oklahoma City	Oklahoma	210065703505452871	c57f13996db13a79280efffe54ee57e7	VISA 13 digit	35.5449079094365246	-97.5968046401988687
3882	2019-10-12 22:40:37	2019-10-12	Harve Skiles	harve.skiles@geemail.com	Columbus	Ohio	53419196347282189	dcb995721aa74f93cb2dfa5d681241f2	VISA 16 digit	39.9066347216766317	-83.0448688410922955
3883	2019-10-12 23:26:06	2019-10-12	Ms. Lilah Durgan	ms.lilah.durgan@geemail.com	Saint Paul	Minnesota	51174641016314230	1b2ae606548ab934a435d26f4148aa2f	Discover	45.0135950127556939	-93.1894363983333136
3884	2019-10-12 23:34:11	2019-10-12	Ignacio Donnelly	ignacio.donnelly@woohoo.com	San Francisco	California	3096873689206110953	d32b8b571e17590325337ce67a671ff6	American Express	37.8144017882371628	-122.396331296185522
3885	2019-10-12 23:56:34	2019-10-12	Ms. Renae Boyer PhD	ms.renae.boyer.phd@geemail.com	Lincoln	Nebraska	639025134863668	b90768c45978db2812d5b3762cd9c68f	Maestro	40.7970641226526354	-96.745722283764934
3886	2019-10-13 01:53:43	2019-10-13	Heather Rogahn	heather.rogahn@geemail.com	Hampton	Virginia	3088404404930001124	82ca301692d20998fc5c1dfe01f7023a	JCB 15 digit	37.0456290116086606	-76.2941399317797249
3887	2019-10-13 02:04:29	2019-10-13	Gideon Hammes-Stehr	gideon.hammes.stehr@geemail.com	Baltimore	Maryland	51083201060511544	35d4fd2ecf990c028fcf08b55326c47b	Discover	39.2778594748582677	-76.5467306462135184
3888	2019-10-13 02:52:46	2019-10-13	Allene Hamill	allene.hamill@warmmail.com	Indianapolis	Indiana	4312182323401	4436fea898a0b813f57c193f71a5c304	VISA 13 digit	39.8231061558712227	-86.1996349893245792
3889	2019-10-13 04:34:02	2019-10-13	Mrs. Susan Nicolas PhD	mrs.susan.nicolas.phd@geemail.com	Pembroke Pines	Florida	675984532514936	0c45d811871448ea34012d3c36c8240a	Voyager	26.0506529578976327	-80.376894364403185
3890	2019-10-13 05:07:37	2019-10-13	Dayami Hartmann PhD	dayami.hartmann.phd@geemail.com	Indianapolis	Indiana	3096836746912306709	aacaf0497d3d67b271c680ba71a3ac4c	Maestro	39.8054357029039423	-86.0588159441683445
3891	2019-10-13 05:10:00	2019-10-13	Preston Renner-Thiel	preston.renner.thiel@geemail.com	Los Angeles	California	869962357194252564	72c649717e52cc2d53210744f563283c	Voyager	33.9770828686520403	-118.321982251898561
3892	2019-10-13 05:29:19	2019-10-13	Dr. Branch Schultz PhD	dr.branch.schultz.phd@woohoo.com	Arlington	Texas	4742446534722457	5cd718363e1abeeeded0f8654b6b3d81	Diners Club / Carte Blanche	32.6545795010186737	-97.1410987091276894
3893	2019-10-13 06:59:17	2019-10-13	Jeryl McKenzie MD	jeryl.mckenzie.md@woohoo.com	New York	New York	4285277312200	a44149f2fad3ee256c3ff841d3c95e3e	Discover	40.7480162479672572	-73.9381035391602666
3894	2019-10-13 07:23:04	2019-10-13	Daxton VonRueden	daxton.vonrueden@warmmail.com	San Francisco	California	180046908057172421	2fa90cfabe30af4e7e77f87d30ca44fa	American Express	37.7884986050464136	-122.436166075523886
3895	2019-10-13 08:20:21	2019-10-13	Carlota Ledner	carlota.ledner@geemail.com	New York	New York	630418539068561	51a7c81b070f17ff177b656a0407b608	American Express	40.6304271433260311	-73.9209744517587097
3896	2019-10-13 08:32:22	2019-10-13	Dr. Lenon Huel I	dr.lenon.huel.i@geemail.com	San Francisco	California	3528334639559088358	13ffc785a14f6d05d4d62c8fb476f01e	VISA 16 digit	37.7624473830552176	-122.443158311713489
3897	2019-10-13 08:57:30	2019-10-13	Dr. Yuliana Mertz DDS	dr.yuliana.mertz.dds@geemail.com	Columbus	Georgia	3088617134153433109	42a120b3cadcf9a07e313819942737a9	JCB 16 digit	32.5626266911204851	-84.8464829108841627
3898	2019-10-13 11:18:11	2019-10-13	Emmit Bernhard	emmit.bernhard@geemail.com	San Francisco	California	3049088055458836	12b70ad4f7ed46f1012cb79b512e1961	VISA 16 digit	37.7690784986175387	-122.432677066094953
3899	2019-10-13 12:02:58	2019-10-13	Jerod Kemmer	jerod.kemmer@geemail.com	San Francisco	California	3337307499330563192	9c150a995781c61a70fd1636eece313f	Voyager	37.7499833293299432	-122.45174149140918
3900	2019-10-13 13:03:29	2019-10-13	Dr. Camden Ward III	dr.camden.ward.iii@woohoo.com	San Francisco	California	6011887705837083882	0ec8da5e7090ffd91f248130f61e48e6	Voyager	37.7820439624290074	-122.407064424513806
3901	2019-10-13 13:04:38	2019-10-13	Mr. Uriah Hamill III	mr.uriah.hamill.iii@geemail.com	Sugar Land	Texas	180048734574695696	17a7ca40ad399cb66b2cfce24ae405b9	JCB 16 digit	29.5018625930003822	-95.6695952089976487
3902	2019-10-13 14:09:15	2019-10-13	Dr. Elvina Hayes	dr.elvina.hayes@geemail.com	Newark	New Jersey	180037414976629733	7cb6901ae86669ece1feb92bb2c4e45e	Discover	40.7316670107569578	-74.2212680293455804
3903	2019-10-13 14:27:32	2019-10-13	Haleigh McCullough	haleigh.mccullough@geemail.com	Oakland	California	4966537380222755	b051d39e1bc991b96444918f955f8122	VISA 16 digit	37.8469823689143894	-122.300643766131117
3904	2019-10-13 14:42:08	2019-10-13	Shianne Jacobi	shianne.jacobi@warmmail.com	San Francisco	California	869961158586723431	7bc88a6164b4061df737ed8bae86da2b	VISA 13 digit	37.7400112498084965	-122.433831428838928
3905	2019-10-13 14:47:37	2019-10-13	Marlee Ritchie	marlee.ritchie@geemail.com	San Francisco	California	180084239625615029	1877240026455dca88aa0230b043299d	JCB 16 digit	37.7416117480723869	-122.428834324810254
3906	2019-10-13 15:39:42	2019-10-13	Zachery Spencer	zachery.spencer@woohoo.com	San Francisco	California	869909155116517916	fd0bb446ede20d5a7643f65fed1f514f	VISA 16 digit	37.7702874254663996	-122.396838893048681
3907	2019-10-13 16:40:05	2019-10-13	Myrl Schroeder	myrl.schroeder@warmmail.com	San Francisco	California	4876016590071798	831b41809346646ae8e6079a7c0dd2c6	Discover	37.7260179775833961	-122.438871600002258
3908	2019-10-13 16:54:53	2019-10-13	Alysa Champlin	alysa.champlin@woohoo.com	San Francisco	California	869932147119370493	5da9777321bb954f9043de0a25b7c61a	Voyager	37.7612872768106556	-122.44077221615882
3909	2019-10-13 18:04:27	2019-10-13	Deondre Franecki-Cruickshank	deondre.franecki.cruickshank@woohoo.com	Berkeley	California	4598017636942569	9239cac3f0145ad850f8947e3ccf2471	JCB 16 digit	37.8927499806474941	-122.250489441326025
3910	2019-10-13 18:32:55	2019-10-13	Ebb Orn	ebb.orn@warmmail.com	Lexington	Kentucky	180029134689314460	2e30a85fe52a5b70c21ef40adb1342d6	VISA 16 digit	38.0146600653760132	-84.4446438281230627
3911	2019-10-13 18:49:16	2019-10-13	Lisle Schimmel	lisle.schimmel@geemail.com	Santa Ana	California	52818631545112660	7bfb2cdc409049c25ef0f56fc453c9ba	JCB 16 digit	33.7011960334714473	-117.842937338903539
3912	2019-10-13 19:51:19	2019-10-13	Issac Gottlieb	issac.gottlieb@geemail.com	Austin	Texas	676170466672451	8067da144bacbf9bd1fc456cb3b63e54	Diners Club / Carte Blanche	30.270312373678756	-97.8539506608858716
3913	2019-10-13 20:05:54	2019-10-13	Edmon Schmidt	edmon.schmidt@geemail.com	New York	New York	3014514326976012	7682a7b7ba3c4fe4b13adf1a42868d2f	JCB 15 digit	40.7438328525274969	-73.8824046910170438
3914	2019-10-13 20:24:27	2019-10-13	Dyllan Parisian	dyllan.parisian@woohoo.com	San Francisco	California	210070066350023160	681fb8631ffa2ee120600ecb98c19443	Diners Club / Carte Blanche	37.7694164670483374	-122.405935740351239
3915	2019-10-13 20:32:00	2019-10-13	Jaydon Mayer	jaydon.mayer@geemail.com	Berkeley	California	6011853125517005057	4af7830b0149786466fb7e394f25a4ef	Maestro	37.8624379004525409	-122.245876906570444
3916	2019-10-13 20:42:33	2019-10-13	Duane Douglas II	duane.douglas.ii@geemail.com	San Francisco	California	180054003120885255	88baa468d17e40d599afef75013316bb	Maestro	37.7887507197361501	-122.415940489498396
3917	2019-10-13 20:47:11	2019-10-13	Mr. Elzie Ebert	mr.elzie.ebert@geemail.com	New York	New York	4251173935431065	f62c67e30519fefe2302b093fbc20d00	VISA 16 digit	40.635902049973609	-73.9259148891910911
3918	2019-10-13 21:25:51	2019-10-13	Lilia Huel	lilia.huel@geemail.com	San Francisco	California	3158785095697493550	b4bdfd3fdccc41ba2913c40adf748083	VISA 13 digit	37.7780873327264004	-122.399442856501793
3919	2019-10-13 21:51:46	2019-10-13	Mickey Frami	mickey.frami@warmmail.com	San Francisco	California	3158429981794892996	fd1f91b5a46824d8cd58407544ad9f9c	VISA 16 digit	37.7708941750619545	-122.457869465471703
3920	2019-10-13 22:02:45	2019-10-13	Kristan Johns	kristan.johns@woohoo.com	Houston	Texas	4866270760213555	9d5172f0077c70d163d59cbbaaaff088	Voyager	29.7899536218106746	-95.4468192115906646
3921	2019-10-13 22:31:12	2019-10-13	Marjory Hegmann	marjory.hegmann@geemail.com	San Francisco	California	51441510815968081	99833c7ab509eb4b8c90820d263052c4	Diners Club / Carte Blanche	37.7808139296452339	-122.416868524345858
3922	2019-10-13 23:27:19	2019-10-13	Izaiah Brown	izaiah.brown@woohoo.com	Tempe	Arizona	3337523184271503351	4aed975e1afb11ca9e8fbc07cbf7f05d	JCB 15 digit	33.2901334694042745	-111.97104941350706
3923	2019-10-13 23:38:16	2019-10-13	Dillan Stroman	dillan.stroman@geemail.com	Boston	Massachusetts	210085445563442594	78930dc5d7f2acea1001613521750cc6	VISA 16 digit	42.3100527462251463	-71.0568681590676334
3924	2019-10-14 00:34:53	2019-10-14	Dr. Tella Russel	dr.tella.russel@geemail.com	San Francisco	California	51808230018851698	7e6045926da0ffe8c3a2da37443029ac	Voyager	37.785748561898977	-122.410790008401534
3925	2019-10-14 00:40:36	2019-10-14	Chaz Conn-Treutel	chaz.conn.treutel@geemail.com	San Francisco	California	3337460915252819075	00649fb4ec83bc7fe6d73888f5e86fa4	Mastercard	37.7752712402958934	-122.406798983467723
3926	2019-10-14 00:43:02	2019-10-14	Madeleine Wunsch-Parisian	madeleine.wunsch.parisian@geemail.com	San Francisco	California	502061955185253	38c22e0a0bed268de6ae6be125ac7224	American Express	37.8003079228246222	-122.449126397148447
3927	2019-10-14 01:05:45	2019-10-14	Keshia Casper-Sawayn	keshia.casper.sawayn@woohoo.com	San Francisco	California	6011196436249477878	80d2f24196005382381e5fff67092575	Diners Club / Carte Blanche	37.8086918655604052	-122.449520080642074
3928	2019-10-14 01:10:41	2019-10-14	Jacey Bayer	jacey.bayer@geemail.com	Oakland	California	4505497167791761	ffc45629c712e2fc6b63d716042967ac	VISA 16 digit	37.7981785528253553	-122.279512047704628
3929	2019-10-14 01:16:21	2019-10-14	Mr. Heber Bednar PhD	mr.heber.bednar.phd@geemail.com	Simi Valley	California	3725131604162127	bb613b6bce5e74917457cf2ce5fe4a75	JCB 15 digit	34.3255795405019057	-118.802945895925177
3930	2019-10-14 02:36:15	2019-10-14	Dr. Jasen Bergnaum	dr.jasen.bergnaum@woohoo.com	San Francisco	California	6011263696796894621	e5d9fa65c280d4a6626c9574dc0b9426	VISA 16 digit	37.7744877785424791	-122.417810311407862
3931	2019-10-14 02:36:57	2019-10-14	Tamya McKenzie DDS	tamya.mckenzie.dds@warmmail.com	Oakland	California	6011793921631351341	c07bd13dc24d356ed66e4ca16ba10b45	VISA 16 digit	37.799093480855106	-122.265476370685178
3932	2019-10-14 04:06:34	2019-10-14	Earnest Zulauf	earnest.zulauf@geemail.com	Boise	Idaho	3795254569530248	c7b110dbd763bc337968c2af24e3bb8f	Discover	43.5205256356529873	-116.181717226021746
3933	2019-10-14 04:30:42	2019-10-14	Ruffin Mann	ruffin.mann@geemail.com	San Francisco	California	53671290489998547	9f78ba6be7ad0a298aac288aa45ec716	Diners Club / Carte Blanche	37.7947865573568507	-122.491718850904761
3934	2019-10-14 04:35:54	2019-10-14	Dimitri Koepp DDS	dimitri.koepp.dds@geemail.com	New York	New York	675927436692019	cfe58f6baeee83b4f0574aea23fef476	Mastercard	40.6533826333694179	-73.8669115458510817
3935	2019-10-14 05:38:04	2019-10-14	Sannie Altenwerth	sannie.altenwerth@geemail.com	New York	New York	6011172132597742439	45f45fffde82c110ca5d2bd820243a81	VISA 13 digit	40.7403118415493495	-73.8812353409256701
3936	2019-10-14 07:24:28	2019-10-14	Terrill Bruen	terrill.bruen@geemail.com	Paterson	New Jersey	4963791321901596	91ad6e965755840374430769fc3d2b6c	JCB 16 digit	40.9192325741007892	-74.1357900577571343
3937	2019-10-14 07:24:54	2019-10-14	Vena Mosciski	vena.mosciski@woohoo.com	San Francisco	California	53659044238598116	0e1facc663d09cd777ae08755eb99ba1	JCB 16 digit	37.7855674198272951	-122.390705923325115
3938	2019-10-14 08:42:08	2019-10-14	Dr. Wende Klocko	dr.wende.klocko@geemail.com	Akron	Ohio	6011944668178259860	c12c62bb381bfbd6dfcdcc224a362fe1	VISA 13 digit	40.9830532130151965	-81.5773299951884923
3939	2019-10-14 09:23:10	2019-10-14	Lennie Kunze	lennie.kunze@geemail.com	Virginia Beach	Virginia	6011623299900672663	8eba0426e1c5f94fa54083e295fa96c9	Diners Club / Carte Blanche	36.7897468357067581	-75.9460896215073689
3940	2019-10-14 10:02:58	2019-10-14	Wilkie Hintz	wilkie.hintz@geemail.com	San Francisco	California	3474640588180947	2b3edcddc7434e020b4430685d13e595	American Express	37.7813854602048664	-122.425170668446356
3941	2019-10-14 10:56:30	2019-10-14	Stetson Prosacco	stetson.prosacco@geemail.com	Clinton	Michigan	4832761271231137	ad4c750f5f567d06ea06e0bfe56594f9	Maestro	42.5973872386917449	-82.9221950833760246
3942	2019-10-14 11:33:54	2019-10-14	Beecher Sipes-Dickinson	beecher.sipes.dickinson@geemail.com	New York	New York	210077241134821865	84f0fedd63c44b9c5acfa232cf989e28	American Express	40.7146561887804381	-74.0014378007862632
3943	2019-10-14 12:52:02	2019-10-14	Deandre Mills	deandre.mills@woohoo.com	Los Angeles	California	3158581497056192086	3b423ccb4dc4301e8e3834f511600d6a	VISA 13 digit	33.9498089794866686	-118.328192769595603
3944	2019-10-14 12:54:11	2019-10-14	Mr. Demario Gibson Sr.	mr.demario.gibson.sr.@geemail.com	San Francisco	California	3451120626911923	b1aea7e20bd3c9838d956c302fb7ba77	Maestro	37.7580212487875713	-122.418122888096576
3945	2019-10-14 13:20:04	2019-10-14	Rubin Stamm	rubin.stamm@geemail.com	Washington	District of Columbia	3096746471980341707	63b20e8623b77e238a61c2ce02d0eae5	Diners Club / Carte Blanche	38.9171257874727274	-76.944218521260467
3946	2019-10-14 13:30:27	2019-10-14	Miss Christel Hamill	miss.christel.hamill@geemail.com	San Francisco	California	3030071508891141	d85f125e133ab6cf4179ab92390231eb	VISA 13 digit	37.8031551261581811	-122.425292412748675
3947	2019-10-14 15:09:04	2019-10-14	Dr. Monique Howe DVM	dr.monique.howe.dvm@geemail.com	Boise	Idaho	4975959942018886	5892926d086bf819b1fcc7b21628f875	Voyager	43.5445516683764779	-116.268661600743243
3948	2019-10-14 15:11:50	2019-10-14	Brooks Ritchie	brooks.ritchie@woohoo.com	San Francisco	California	3158434591784939443	7aca1864c7b447ef3e5ae82e46eca4ab	JCB 15 digit	37.7388874861812695	-122.427150801957595
3949	2019-10-14 16:44:01	2019-10-14	Pleasant Green Jr.	pleasant.green.jr.@woohoo.com	Oakland	California	6011478472943083380	3b675616b6e24f1a226eb9df91723426	Diners Club / Carte Blanche	37.8146800956243538	-122.271459590946506
3950	2019-10-14 16:48:50	2019-10-14	Joy Marvin-Wiza	joy.marvin.wiza@woohoo.com	Gilbert	Arizona	180042838588569429	d788bfcfe6fcf4884d9a5ba87dee791b	VISA 13 digit	33.2455901026606568	-111.771760625265912
3951	2019-10-14 17:08:38	2019-10-14	Alpheus Hilpert DVM	alpheus.hilpert.dvm@warmmail.com	Pasadena	Texas	3528372054226705371	c846d2c6ab617669170d995f284a5cf0	Voyager	29.6572522366758449	-95.1029474719840948
3952	2019-10-14 17:13:41	2019-10-14	Argie Wolf	argie.wolf@woohoo.com	Pittsburgh	Pennsylvania	4279675276057869	af8fa0ef9df2dffea72d5055da134942	JCB 15 digit	40.4537927068725196	-79.914177406829225
3953	2019-10-14 18:37:45	2019-10-14	Fay Klocko	fay.klocko@geemail.com	Omaha	Nebraska	55515567622803993	337f1a76b5dfea587a9b6ef9ecafc3b4	Discover	41.2011397675756399	-95.9676622389931282
3954	2019-10-14 18:43:49	2019-10-14	Sybil Gleichner	sybil.gleichner@warmmail.com	Berkeley	California	3528773397727252178	4a3d97d327dd2b58597841fc3965b390	VISA 16 digit	37.8783998460368068	-122.270061173439572
3955	2019-10-14 20:02:31	2019-10-14	Vira Bashirian	vira.bashirian@warmmail.com	Las Vegas	Nevada	3088795623926227800	eff236981e2d5cd31657f9b1b50cd257	JCB 15 digit	36.1601983931947473	-115.354113808015725
3956	2019-10-14 21:17:56	2019-10-14	Cristobal Bergnaum	cristobal.bergnaum@geemail.com	Indianapolis	Indiana	4409447642582571	95928e88d32aecc50109b995f620491b	VISA 13 digit	39.7590709578718986	-86.1502480910826449
3957	2019-10-14 23:19:22	2019-10-14	Devan Goldner	devan.goldner@geemail.com	San Francisco	California	4719223406336	ca0fedd8f423078c88354028b77aa0d1	American Express	37.7784454276766866	-122.446289915451345
3958	2019-10-14 23:40:45	2019-10-14	Isidro Medhurst	isidro.medhurst@woohoo.com	Augusta	Georgia	4227270144152432	364c379f270e7d47b2a7627cd530e2f5	VISA 16 digit	33.3490632103495273	-82.1198561226777741
3959	2019-10-15 01:09:45	2019-10-15	Sanford DuBuque	sanford.dubuque@geemail.com	Berkeley	California	4413727856011829	8bcd8198edb51edb4f160335e40e095d	VISA 16 digit	37.8985297849111475	-122.261693167608783
3960	2019-10-15 01:22:24	2019-10-15	Dr. Kassie Dach PhD	dr.kassie.dach.phd@woohoo.com	San Francisco	California	4897225730882379	082c89db5c7e45afa187b683e48acda8	JCB 16 digit	37.7919574518877113	-122.423280564098832
3961	2019-10-15 02:16:41	2019-10-15	Sabina Koelpin	sabina.koelpin@woohoo.com	Berkeley	California	3009248095696569	885ca89f8b126ff7ddff27058415b31b	JCB 15 digit	37.8388745277074321	-122.268467967588776
3962	2019-10-15 02:30:31	2019-10-15	Tanya Luettgen	tanya.luettgen@geemail.com	New York	New York	180044382872958335	a6168b61f18779f8745695c3d7ce4cb8	JCB 15 digit	40.6554334121048413	-73.8790733484912607
3963	2019-10-15 03:51:29	2019-10-15	Albion Ziemann	albion.ziemann@geemail.com	San Francisco	California	6011556957648587144	d4fb60a96723811320f1f2031cfde6e1	VISA 13 digit	37.8143045500864616	-122.451856640941443
3964	2019-10-15 04:19:35	2019-10-15	Muhammad Buckridge	muhammad.buckridge@woohoo.com	Glendale	Arizona	676270847490896	eda32c187b1e054518c4cfeb9751524d	Maestro	33.4811803336948159	-112.114414935538164
3965	2019-10-15 05:07:42	2019-10-15	Levon Koepp	levon.koepp@geemail.com	Glendale	Arizona	180080479861559796	0080f165a5d799f234627009b85f39f9	JCB 16 digit	33.4705175988137711	-112.283128624062613
3966	2019-10-15 06:25:51	2019-10-15	Miss Lyla Lubowitz PhD	miss.lyla.lubowitz.phd@woohoo.com	San Francisco	California	4294897856497	7467b9e2fd750db09164dbf442dee1ee	VISA 16 digit	37.7635024507578194	-122.441284762469053
3967	2019-10-15 07:51:54	2019-10-15	Edgardo Bergnaum	edgardo.bergnaum@warmmail.com	Oakland	California	3039137764346038	4e5dbe23ffee7ffcaf6ecb8616685def	Discover	37.7789962678423876	-122.243032000982097
3968	2019-10-15 08:00:23	2019-10-15	Aurelio Miller-Kovacek	aurelio.miller.kovacek@geemail.com	Berkeley	California	4516847893864356	9fa65bcec389a5d4ce2091fcbd6cc0a3	JCB 16 digit	37.8945043150436049	-122.259723665337091
3969	2019-10-15 08:00:50	2019-10-15	Johana Hirthe	johana.hirthe@warmmail.com	Columbia	South Carolina	6011950617572280387	9b33299355693380861daa809dae4ea8	VISA 13 digit	33.9877114285513784	-80.8144242535829562
3970	2019-10-15 08:15:31	2019-10-15	Karrie Botsford	karrie.botsford@geemail.com	Spokane	Washington	3088698354752638484	13c1e231d4638a2eb3fd49939448f393	VISA 16 digit	47.7313364737905559	-117.465731942224508
3971	2019-10-15 08:16:35	2019-10-15	Dr. Dale Rau	dr.dale.rau@geemail.com	Berkeley	California	3029291968332730	cbe763f43ac581ba0f5346836bfdf82c	Diners Club / Carte Blanche	37.8951356100242407	-122.24621220508628
3972	2019-10-15 08:33:50	2019-10-15	Tollie Hahn III	tollie.hahn.iii@geemail.com	Dallas	Texas	3112051207009883918	f52236eb8612693d4c4bf1d546aa916b	VISA 13 digit	32.7255341942228384	-96.7465283578690105
3973	2019-10-15 09:43:32	2019-10-15	Hobson Block	hobson.block@geemail.com	Odessa	Texas	869944247761729396	7f9bb3c6456524332151809fb0b3d9d0	VISA 16 digit	31.9393297351442271	-102.335236279122896
3974	2019-10-15 10:28:04	2019-10-15	Rory Murray	rory.murray@geemail.com	New York	New York	4140283052685107	dfa86385a15aa18ac2d83cc4c1e22557	JCB 16 digit	40.6732704063635282	-73.8583661191526772
3975	2019-10-15 10:29:59	2019-10-15	Moira Trantow	moira.trantow@geemail.com	Oakland	California	630472813138327	8e0f076f0a3d70c975c870549c755bfa	American Express	37.8201771079803066	-122.287684547839092
3976	2019-10-15 11:32:55	2019-10-15	Beula McCullough	beula.mccullough@woohoo.com	San Francisco	California	3096698804008307623	1c69815b4fd8656ad106c69557920401	VISA 16 digit	37.8145603355620423	-122.408286850466624
3977	2019-10-15 13:09:41	2019-10-15	Roma Gulgowski-Huel	roma.gulgowski.huel@geemail.com	Fresno	California	676341827309604	957cae76b2b57cb39baff12546005051	American Express	36.8796321336518957	-119.883264787505951
3978	2019-10-15 13:33:23	2019-10-15	Sumner Gaylord	sumner.gaylord@geemail.com	San Francisco	California	6011184467958061219	76fe4805f006743c1856751d9f862ff5	JCB 16 digit	37.7582946774100705	-122.467187476706826
3979	2019-10-15 15:44:54	2019-10-15	Alan Conroy	alan.conroy@geemail.com	Toledo	Ohio	3039613967738064	a684d188813f096b3af564b521cd069d	JCB 16 digit	41.6354880280964039	-83.5873119008593335
3980	2019-10-15 16:02:11	2019-10-15	Dakota Volkman DVM	dakota.volkman.dvm@geemail.com	San Francisco	California	3006912078006434	9a5085767ce936a49d69a19bdd81d17b	Voyager	37.7750539536804411	-122.432331410563123
3981	2019-10-15 16:18:08	2019-10-15	Analia Quigley PhD	analia.quigley.phd@geemail.com	New York	New York	4077727232988952	1b1f050b672e0fd92d85a40d27afb3fc	JCB 16 digit	40.5812305883262283	-73.9611001576192706
3982	2019-10-15 17:33:33	2019-10-15	Makena Hilpert	makena.hilpert@geemail.com	San Francisco	California	3096102321984742830	144a7817f28ba507f063d38285c51c68	VISA 16 digit	37.7422075067116225	-122.418086958812196
3983	2019-10-15 19:17:39	2019-10-15	Reagan Tillman-Upton	reagan.tillman.upton@geemail.com	Saint Paul	Minnesota	54103548892083795	85d112f0aabf2db6bb3207eaf7ec0d06	JCB 16 digit	44.8834887019298989	-93.0853497626524415
3984	2019-10-15 19:58:09	2019-10-15	Iliana Renner-Macejkovic	iliana.renner.macejkovic@geemail.com	Dallas	Texas	4846227044359880	8a9e56e9fdcb928472353986eb8d1e18	JCB 16 digit	32.796496778288116	-96.7013319875541981
3985	2019-10-15 19:58:12	2019-10-15	Aurelia Leannon DVM	aurelia.leannon.dvm@geemail.com	Provo	Utah	4765694996996000	a5bc039991ba932fad8d5f6519040cde	Maestro	40.2387748186729866	-111.635817243126411
3986	2019-10-15 20:31:12	2019-10-15	Mechelle Heller-Jast	mechelle.heller.jast@woohoo.com	Oakland	California	4393466170809	93ef1caf354b6705adf260a69e32cbc7	VISA 13 digit	37.8033140238053207	-122.257172450762155
3987	2019-10-15 21:23:24	2019-10-15	Edson Fisher DVM	edson.fisher.dvm@geemail.com	San Francisco	California	3418814148380276	e52f5b42adb28eebabd8a2c8ce24c51e	Discover	37.7686143523156375	-122.415410564597437
3988	2019-10-15 21:34:25	2019-10-15	Dr. Harlen Predovic	dr.harlen.predovic@geemail.com	Denver	Colorado	3528021703557973207	56fc4f6b634f08df33938b02fa0ccb6d	Maestro	39.8201424116320908	-104.930274860818315
3989	2019-10-15 21:52:42	2019-10-15	Teddie Macejkovic	teddie.macejkovic@warmmail.com	Houston	Texas	3722058112544962	05f240ac83356eee2f3ad34c7e7c86d3	American Express	29.8005807170722647	-95.3537109251614652
3990	2019-10-15 22:04:00	2019-10-15	Mr. Palmer Hagenes II	mr.palmer.hagenes.ii@geemail.com	San Antonio	Texas	3112618760530619389	5bf70c4e53da4b2fe9ee9c52061dab35	VISA 16 digit	29.4148908888060596	-98.5363327585928062
3991	2019-10-15 22:21:27	2019-10-15	Laron Wilderman	laron.wilderman@geemail.com	Thousand Oaks	California	54387525176766607	865fa80382e46716524deab16c7ece24	VISA 16 digit	34.0970048529367915	-118.90926807410159
3992	2019-10-15 22:29:54	2019-10-15	Less Blick	less.blick@warmmail.com	Kenosha	Wisconsin	3797699924436655	4d5153f281a5c0507e8620765c50f195	VISA 16 digit	42.5484859318312232	-87.8519132272102041
3993	2019-10-15 22:40:13	2019-10-15	Waymon Morissette	waymon.morissette@geemail.com	Dallas	Texas	3030864603023614	33bffc2d2723ac8c85d61de854e4b628	VISA 16 digit	32.7547726428873887	-96.7218377322852518
3994	2019-10-15 22:52:14	2019-10-15	Ardelle Runolfsson	ardelle.runolfsson@geemail.com	Fort Worth	Texas	180013671344873982	906b2e4442b07e94cfbd2d7ca4c847d3	Mastercard	32.8432474575992686	-97.4230788185547993
3995	2019-10-16 00:07:46	2019-10-16	Meg Smith	meg.smith@geemail.com	San Francisco	California	4704129813891641	8d03b43f87ca8a82c96c2b10db2cb49e	JCB 16 digit	37.7814948416002281	-122.460214661973524
3996	2019-10-16 00:53:16	2019-10-16	Kenya Raynor	kenya.raynor@woohoo.com	Boston	Massachusetts	180076965283077413	d5401c091409952aa5a1179ce1c38069	VISA 16 digit	42.2968452826309971	-71.0314017901614392
3997	2019-10-16 01:00:07	2019-10-16	Dr. Bradley McLaughlin DVM	dr.bradley.mclaughlin.dvm@geemail.com	Palmdale	California	6011566348647007243	fa9f049b08b08e98294e6dd79908d704	American Express	34.6132815835382814	-118.098008473077414
3998	2019-10-16 01:23:26	2019-10-16	Leighton Reichel	leighton.reichel@geemail.com	West Covina	California	3158200607174273540	45dfa4c97cb7f496fe5b5161ce4ee477	Diners Club / Carte Blanche	34.0656153114154918	-117.935701252247753
3999	2019-10-16 01:48:18	2019-10-16	Tamie Abernathy DDS	tamie.abernathy.dds@geemail.com	Raleigh	North Carolina	4093486421022	35f632944a9cb32dd5399e485a77904c	Discover	35.7938541300728872	-78.580441619216657
4000	2019-10-16 02:01:45	2019-10-16	Ilona Hand-Kuhn	ilona.hand.kuhn@woohoo.com	Berkeley	California	4255923145072638	182066c03239a4ceb0abfd700eea9bdf	Discover	37.8894699185496791	-122.258798990866069
4001	2019-10-16 02:25:07	2019-10-16	Cali Predovic	cali.predovic@geemail.com	Savannah	Georgia	210084346607315799	a3120e0ca2b4e2fd5502c08e60007e27	VISA 13 digit	32.0960263327322863	-81.0957636412385767
4002	2019-10-16 03:46:02	2019-10-16	Terrence Wilkinson	terrence.wilkinson@geemail.com	Los Angeles	California	4627269880511989	920a4c7e4a7c22ce756ad70c7b252a53	Voyager	34.1021454111538773	-118.403458413108439
4003	2019-10-16 04:12:56	2019-10-16	Mr. Camron Marks MD	mr.camron.marks.md@geemail.com	Memphis	Tennessee	180019511242123052	ec407778b81d8c1681b233cf2155e6e5	VISA 13 digit	35.1265148748710772	-90.0302761936351743
4004	2019-10-16 05:50:36	2019-10-16	Keyla Senger	keyla.senger@geemail.com	Oakland	California	3096584856244194907	e563033ff7928609e9a0a09a509a7351	JCB 16 digit	37.786969470561715	-122.262910345519046
4005	2019-10-16 06:01:53	2019-10-16	Dr. Roosevelt Dooley PhD	dr.roosevelt.dooley.phd@woohoo.com	San Francisco	California	3432701529615523	984496e31fa6ed14c0f5524cd4535239	JCB 16 digit	37.7720082808887341	-122.419682654817606
4006	2019-10-16 06:10:22	2019-10-16	Hilbert Ratke III	hilbert.ratke.iii@geemail.com	Murrieta	California	6011012049352015559	96c7f1d978c8cabdd174b6cc31521c9d	JCB 16 digit	33.4831377437900741	-117.267587665970993
4007	2019-10-16 06:33:20	2019-10-16	Joell Sawayn-Daugherty	joell.sawayn.daugherty@geemail.com	San Francisco	California	4985180700118465	6cd43bed67538bbe696a81604418e6a2	Voyager	37.7854558616637277	-122.420041995023396
4008	2019-10-16 07:16:53	2019-10-16	Granville Reichel	granville.reichel@geemail.com	Olathe	Kansas	3096939918650660649	27c56215c6b4eb8f5c52379b4a0ab564	JCB 16 digit	38.9135240106966407	-94.750478863220664
4009	2019-10-16 07:39:21	2019-10-16	Luciana Steuber-Feeney	luciana.steuber.feeney@geemail.com	San Francisco	California	4418292001709236	dab7e286a654430463b27a47aed3459c	VISA 16 digit	37.807363139944961	-122.446950123057292
4010	2019-10-16 07:44:51	2019-10-16	Dr. Horton Schumm DDS	dr.horton.schumm.dds@geemail.com	Philadelphia	Pennsylvania	4411144914019293	ed07775d2b6c32cb4c76551e3116c0ea	Diners Club / Carte Blanche	40.0674337005667383	-75.2269260676477103
4011	2019-10-16 08:12:31	2019-10-16	Wendy Mosciski-Larkin	wendy.mosciski.larkin@geemail.com	San Francisco	California	503896676987470	c1e6d3a3032e874ee2ccf84fb5c94716	VISA 16 digit	37.7855724895201206	-122.422890158245337
4012	2019-10-16 08:43:48	2019-10-16	Marisol Greenfelder	marisol.greenfelder@warmmail.com	San Francisco	California	51149900090838064	fae6ca0aa964d34fe52c49eee195daa6	JCB 16 digit	37.7900882416620334	-122.441838377723442
4013	2019-10-16 09:24:42	2019-10-16	Beula Greenfelder	beula.greenfelder@geemail.com	Oakland	California	4348858814310480	d09b56c624a8d7776c1991533b0e6c71	JCB 16 digit	37.8116027081064843	-122.272390425499268
4014	2019-10-16 10:59:40	2019-10-16	Dr. Jeremy Stanton	dr.jeremy.stanton@warmmail.com	San Francisco	California	4714447109825158	c6ca9f94211ffd934e9613a8cf49e2f5	American Express	37.7805224819649084	-122.463229160518409
4015	2019-10-16 12:13:39	2019-10-16	Krystal Hane	krystal.hane@geemail.com	San Francisco	California	54938301459628532	df4c669013d53a9419501c214db3af0b	JCB 16 digit	37.7564211643173024	-122.405107288884309
4016	2019-10-16 13:13:55	2019-10-16	Talmadge Lang	talmadge.lang@geemail.com	New York	New York	4533308774355005	b14629409440e94e5eb377b805e6e87e	VISA 16 digit	40.7384017302878192	-73.9800586674723775
4017	2019-10-16 13:33:49	2019-10-16	Geovanni VonRueden	geovanni.vonrueden@woohoo.com	Columbus	Ohio	589349559256729	ce22f3e078059fc4e2af3d6310a631bf	VISA 16 digit	39.8852553566031176	-82.8977217387642753
4018	2019-10-16 14:26:00	2019-10-16	Budd Berge	budd.berge@woohoo.com	Winston–Salem	North Carolina	4977315034837139	0fb033901f0fa25f8e546bd6d1fb528b	Discover	36.1956271955974387	-80.2872383846100348
4019	2019-10-16 15:13:19	2019-10-16	Icy Stamm	icy.stamm@geemail.com	Tyler	Texas	3020458730566106	f9f9c9563849058b3afd706137e4154f	Mastercard	32.3508263008717449	-95.3125755440086095
4020	2019-10-16 16:26:58	2019-10-16	Lera Kemmer	lera.kemmer@warmmail.com	Berkeley	California	3158873888095304806	e2287bb9faf1cacd22eb16cd7b99c76a	VISA 13 digit	37.8833880896818442	-122.28998610476377
4021	2019-10-16 16:54:19	2019-10-16	Torrance Casper	torrance.casper@geemail.com	San Francisco	California	3057591325997808	b702fba4a83fd4b5bb522ff4e41ba1aa	Diners Club / Carte Blanche	37.7721046473263229	-122.430165938949969
4022	2019-10-16 18:52:24	2019-10-16	Mahala Bauch MD	mahala.bauch.md@woohoo.com	New York	New York	180087287351109821	fc6049623d2669843deecb35b6186301	VISA 13 digit	40.633508769258853	-73.9746875799622359
4023	2019-10-16 19:14:07	2019-10-16	Verona Feeney	verona.feeney@geemail.com	Baton Rouge	Louisiana	869935090144451812	03ace755b75a83847a4ef0aa4fd0eef6	VISA 13 digit	30.3681467832744119	-91.0995896376777381
4024	2019-10-16 19:15:18	2019-10-16	Dr. Orange Hyatt	dr.orange.hyatt@geemail.com	Columbus	Ohio	54419697779927860	4de697924c97496c4fcecd3641997c20	VISA 13 digit	39.907166868964957	-83.0617641133025302
4025	2019-10-16 20:05:53	2019-10-16	Pattie Bailey-Stiedemann	pattie.bailey.stiedemann@geemail.com	San Francisco	California	3021205477579902	412f49400c03c8055369dc000bdad929	VISA 13 digit	37.7790586675163809	-122.426556848741129
4026	2019-10-16 20:21:25	2019-10-16	Lavonda Wolf	lavonda.wolf@geemail.com	Los Angeles	California	561215134935368	54ab2d2b26695d9c69b704735aabf3bd	VISA 16 digit	33.9526370981574033	-118.431654671113193
4027	2019-10-16 21:05:47	2019-10-16	Madeline Pollich PhD	madeline.pollich.phd@warmmail.com	San Francisco	California	6011837158975937496	b24d48b002551aebba92a781f5f570a2	Voyager	37.7093199623544706	-122.42016872344557
4028	2019-10-16 21:10:03	2019-10-16	Mr. Levar Weber	mr.levar.weber@geemail.com	San Francisco	California	3528425522863180212	5257ead02ffc7ab6a168a9cd6ae83777	Discover	37.754548071712378	-122.457141774801016
4029	2019-10-16 21:34:39	2019-10-16	Godfrey Nolan	godfrey.nolan@geemail.com	Chicago	Illinois	4488849970009545	8af7325cf13dd3e650731cdabb088036	Discover	41.8973104591783141	-87.74207205381542
4030	2019-10-16 21:42:04	2019-10-16	Lemuel Cummerata-Dickens	lemuel.cummerata.dickens@warmmail.com	Louisville	Kentucky	6011093010867311471	9436db2b4bf3fc961700ffc4dc61304b	JCB 16 digit	38.1199819953549621	-85.7104017348099489
4031	2019-10-16 23:31:49	2019-10-16	Jamari Little	jamari.little@geemail.com	San Francisco	California	561265870468207	75ef651d3e2282724f16bd54868f4079	VISA 16 digit	37.7951040655585331	-122.411974014614501
4032	2019-10-16 23:49:58	2019-10-16	Mr. Murdock Ryan	mr.murdock.ryan@woohoo.com	Oceanside	California	6011867320757448810	64f8e8eaccd23adb868e38849667a41d	VISA 13 digit	33.1772782098390167	-117.249052116422732
4033	2019-10-17 00:13:47	2019-10-17	Welton Tremblay-Gislason	welton.tremblay.gislason@geemail.com	Berkeley	California	3337905405402908898	e457a11d05dea9b7d405787836a2cb71	VISA 13 digit	37.8640097727420724	-122.263483144563978
4034	2019-10-17 01:37:54	2019-10-17	Venus Tillman	venus.tillman@warmmail.com	San Francisco	California	4268150881616	faf129e05397086f072b78c09f63f135	Voyager	37.7658371475369066	-122.436603465686076
4035	2019-10-17 01:57:21	2019-10-17	Trudie Barton	trudie.barton@geemail.com	Denver	Colorado	502099283577551	ae561de5e2ddb01df6d75e6864733634	Diners Club / Carte Blanche	39.7188588104262905	-104.862861770788584
4036	2019-10-17 02:07:13	2019-10-17	Cornelious Eichmann	cornelious.eichmann@woohoo.com	New York	New York	3401972377932446	d5b0798b1e26f1575d645f5d6c592004	VISA 16 digit	40.5908360498715197	-73.8664670329902293
4037	2019-10-17 02:54:26	2019-10-17	Leah Predovic	leah.predovic@warmmail.com	Stamford	Connecticut	4503655591300630	8ae30e523af3b3592e2dff474b0aa2fe	Voyager	41.168044155405461	-73.4652705913446908
4038	2019-10-17 03:02:06	2019-10-17	Brooks Dicki	brooks.dicki@warmmail.com	Berkeley	California	6011210194553057586	c0cc7eb98ac3ff559c22153a34b85b19	Discover	37.8735048991248178	-122.276228514837015
4039	2019-10-17 03:02:49	2019-10-17	Izora Davis	izora.davis@geemail.com	Berkeley	California	503810942277731	62c35fb77b27f8718af65d0c00383649	JCB 16 digit	37.8553916969132587	-122.276771148695559
4040	2019-10-17 03:21:15	2019-10-17	Ardell Hand	ardell.hand@warmmail.com	Berkeley	California	3337436422959964198	82db1f27032c61201ed382ebd385b6f8	JCB 15 digit	37.8703902870963987	-122.243213318141798
4041	2019-10-17 05:10:35	2019-10-17	Deron Mayer	deron.mayer@woohoo.com	San Francisco	California	4142344589256602	e20189270ff4f0aae3b751b7bae975f6	American Express	37.7506354614738626	-122.442493974305606
4042	2019-10-17 05:48:23	2019-10-17	Orval Kertzmann	orval.kertzmann@geemail.com	San Francisco	California	561274354164597	9d5e59409d6ff4555e82f75969a1bbbc	Mastercard	37.7998301694566123	-122.421160040604818
4043	2019-10-17 06:15:16	2019-10-17	Mr. Dewayne Jerde	mr.dewayne.jerde@warmmail.com	Anchorage	Alaska	4668961290610	98014f7c33c2c4fc4d8f66d83be4a93d	Mastercard	61.1831710442185397	-149.351639406441905
4044	2019-10-17 06:49:31	2019-10-17	Ocie Marquardt	ocie.marquardt@warmmail.com	Chicago	Illinois	3495377039135338	0f0c90f259fa2edd7c322629c749f740	Mastercard	41.9090803791604927	-87.7576960061706615
4045	2019-10-17 06:56:46	2019-10-17	Mr. Lindy Bins II	mr.lindy.bins.ii@woohoo.com	New York	New York	869947782114883216	00efc2327d68fbfaeb4a37785985cee4	VISA 16 digit	40.6186983529236159	-73.9285948581889301
4046	2019-10-17 07:32:52	2019-10-17	Angella Wilkinson	angella.wilkinson@warmmail.com	Rochester	New York	3021540301162388	b331daa552177ee1dfab8aa1dece97a0	Diners Club / Carte Blanche	43.0889151160117194	-77.6635647820081516
4047	2019-10-17 08:48:56	2019-10-17	Vella Bernhard	vella.bernhard@warmmail.com	St. Petersburg	Florida	869901315406475229	cda1adccc80a73dea14cc95b748b190a	American Express	27.7483669792655867	-82.6379615416176563
4048	2019-10-17 09:22:59	2019-10-17	Janette Durgan MD	janette.durgan.md@geemail.com	San Francisco	California	4769261748211736	75c8090e7b27f38e6374bd7ae8909bec	Voyager	37.7510066571517839	-122.430026606912705
4049	2019-10-17 10:23:42	2019-10-17	Earlean Zulauf DDS	earlean.zulauf.dds@warmmail.com	San Francisco	California	210036884258974422	c63b1dff6749cc3d9d7dacd5b3cce984	VISA 13 digit	37.7815679474673232	-122.439686223958844
4050	2019-10-17 12:09:15	2019-10-17	Raekwon Labadie	raekwon.labadie@geemail.com	San Francisco	California	4663417971933845	323ca15b6c8985bf7f22a6284fff1641	VISA 13 digit	37.7385584375006076	-122.42347870650012
4051	2019-10-17 12:35:27	2019-10-17	Sherrill Blick	sherrill.blick@geemail.com	San Francisco	California	4471415140306184	da86678cbb43147515cddb678109db13	VISA 13 digit	37.7929972952622677	-122.423598964565869
4052	2019-10-17 14:07:17	2019-10-17	Hillery Hyatt	hillery.hyatt@warmmail.com	Toledo	Ohio	4279596069379916	821b1f9747456bf837235c94b4ca38a5	American Express	41.754897005407507	-83.6419568383000893
4053	2019-10-17 14:39:40	2019-10-17	Duke Hane	duke.hane@geemail.com	Berkeley	California	55942505169385662	7139c7a196505a8251db4415212c87fb	JCB 16 digit	37.8676067033756354	-122.264318491825136
4054	2019-10-17 14:58:48	2019-10-17	Versie Johns MD	versie.johns.md@geemail.com	San Francisco	California	180093718683145382	4d3a51dd4b1510eb66e67ee2ccbaed48	American Express	37.7845476437739265	-122.436684882897964
4055	2019-10-17 15:06:01	2019-10-17	Socorro Barrows	socorro.barrows@geemail.com	Los Angeles	California	55806440795826092	45b2cab0e4bf7f96814b14a2fe45c090	VISA 13 digit	34.019625631846111	-118.36886977627799
4056	2019-10-17 15:10:27	2019-10-17	Brian Leannon	brian.leannon@woohoo.com	Columbia	South Carolina	52879993806759795	63e52524c1e287166dbba0ad274f635c	Mastercard	33.9527823565326656	-80.9253464773781559
4057	2019-10-17 16:04:45	2019-10-17	Mr. Ova Kling	mr.ova.kling@geemail.com	McKinney	Texas	3528865349998316264	cbddeecac17fbe4697127ea4b57cc01d	VISA 16 digit	33.1479052021298557	-96.6025371147152043
4058	2019-10-17 16:29:20	2019-10-17	Carlie Roberts	carlie.roberts@warmmail.com	West Valley City	Utah	210087455315391583	1452051bb0501c1bc6fb5e4ede4c2f55	VISA 13 digit	40.5963288190998099	-111.918677485755822
4059	2019-10-17 18:15:09	2019-10-17	Dr. Jacoby White DDS	dr.jacoby.white.dds@geemail.com	Cedar Rapids	Iowa	210074154636125326	a6a9dcead6362987bd3746ae0842299b	Mastercard	41.877717896930875	-91.7083720529053465
4060	2019-10-17 18:39:16	2019-10-17	Tobe Boehm III	tobe.boehm.iii@geemail.com	Plano	Texas	52375115509160688	38d5ac97bd5b2d362946a389364e4ef6	JCB 15 digit	33.012384177287295	-96.6840557982396405
4061	2019-10-17 18:41:16	2019-10-17	Laverne Friesen Sr.	laverne.friesen.sr.@geemail.com	Saint Paul	Minnesota	3088385010758890093	9c985fc939b812f5595b1455ddb894fb	VISA 16 digit	44.9446124839536836	-93.1118724545262779
4062	2019-10-17 19:00:54	2019-10-17	Harlen Romaguera	harlen.romaguera@geemail.com	San Francisco	California	3791626992366684	3f373098727b3ab5c1a1f44c51f30379	VISA 16 digit	37.8083449134596208	-122.44451778252359
4063	2019-10-17 21:08:45	2019-10-17	Miss Gisele Pfeffer	miss.gisele.pfeffer@geemail.com	Oakland	California	3088085823957059986	c6c0c2c30945e8da5c013c0bf177a44d	JCB 15 digit	37.8115100502024504	-122.27997323391395
4064	2019-10-17 21:23:47	2019-10-17	Kiyoshi Hauck	kiyoshi.hauck@geemail.com	Cape Coral	Florida	4618727069264598	f59b0660f72dd15027a0f0dd84c15b29	VISA 13 digit	26.7068867942754196	-81.9949959499832204
4065	2019-10-17 22:33:07	2019-10-17	Arlyne Ullrich	arlyne.ullrich@geemail.com	Berkeley	California	3158635301538235271	e401be10db510c4808bbea6132c8b370	Mastercard	37.8997438762372667	-122.277559553449947
4066	2019-10-17 23:02:45	2019-10-17	Breann Keeling-Bernhard	breann.keeling.bernhard@geemail.com	El Monte	California	180052822202550897	c7fb51b2389c02fb56b131068261b305	Discover	34.1110475315902377	-118.055185501862695
4067	2019-10-17 23:22:32	2019-10-17	Mr. Glendon Skiles	mr.glendon.skiles@warmmail.com	Round Rock	Texas	3445551751645952	b2bf111492c34a6cbed6ac12802c2ab0	Voyager	30.5059083571795391	-97.7279084863923515
4068	2019-10-18 00:23:56	2019-10-18	Caron Nitzsche	caron.nitzsche@geemail.com	San Francisco	California	4862769330351435	810bc56531c71bd177db18a80cfebc84	JCB 15 digit	37.7557395003318419	-122.459824002004737
4069	2019-10-18 01:13:48	2019-10-18	Davy Fay	davy.fay@woohoo.com	Philadelphia	Pennsylvania	3024181735621140	6860b0b507864eece515bdfda712ae2d	VISA 13 digit	40.0184296939946691	-75.0547575428050067
4070	2019-10-18 01:15:26	2019-10-18	Alec Gerhold	alec.gerhold@geemail.com	Virginia Beach	Virginia	3096704391325758078	521f8703bdba2dd5858059ff4785fbc2	Mastercard	36.8776214201189561	-75.9318798347979822
4071	2019-10-18 01:19:45	2019-10-18	Olin Goyette	olin.goyette@woohoo.com	Berkeley	California	3424091006104906	826a433d161f92827d3744d22055890b	Diners Club / Carte Blanche	37.9193341952175444	-122.266260212719189
4072	2019-10-18 01:37:19	2019-10-18	Delaney McGlynn	delaney.mcglynn@geemail.com	Oakland	California	4948581495876	64ef42fdee174b2a8967834c6263df45	Diners Club / Carte Blanche	37.7948312575737972	-122.263490357859297
4073	2019-10-18 01:40:29	2019-10-18	Dr. Brant Jacobi	dr.brant.jacobi@geemail.com	Los Angeles	California	4090017655300106	c8de4ae54af122d253463c397579cb3b	Diners Club / Carte Blanche	33.9542027647938554	-118.499301374237234
4074	2019-10-18 02:27:31	2019-10-18	Sybilla Pouros	sybilla.pouros@geemail.com	San Antonio	Texas	4261296410353393	75d822c66fcd7fa9ee2f5b29e1750ed5	JCB 15 digit	29.5672135979007926	-98.6087015753913647
4075	2019-10-18 03:22:05	2019-10-18	Mrs. Lindsey Huel PhD	mrs.lindsey.huel.phd@woohoo.com	Oakland	California	52499281991297593	075eb59c4c9c773eeca773aba6e27c6a	Discover	37.7934160324744752	-122.275686460856875
4076	2019-10-18 04:08:04	2019-10-18	Madora Jacobs	madora.jacobs@geemail.com	Jersey City	New Jersey	180099745082003296	175fc9cdb7cb9236aa61fab82f1636e6	Discover	40.7257880617804773	-74.0672947021156602
4077	2019-10-18 04:16:49	2019-10-18	Andreas Feil	andreas.feil@geemail.com	Miami	Florida	869984216691294558	6027b8d9eff4da95ceded40d71ae1bcf	VISA 13 digit	25.8334892088685208	-80.1998021885626002
4078	2019-10-18 04:37:02	2019-10-18	Irva Smith	irva.smith@geemail.com	Virginia Beach	Virginia	210028755309638309	1be904f63b86f98b79553a6b3abb66d2	JCB 15 digit	36.7941728502232621	-75.9622895147323618
4079	2019-10-18 05:20:40	2019-10-18	Curley Wolff	curley.wolff@geemail.com	Tampa	Florida	210078094394142194	5f674e0440e6d0ebb5b9ec403616cb06	JCB 15 digit	27.9282979552749531	-82.4264635212466032
4080	2019-10-18 05:43:45	2019-10-18	Rubin Krajcik	rubin.krajcik@geemail.com	Houston	Texas	4464727576861642	b67ee66dde3949d3401b96307da39040	JCB 15 digit	29.8814884720448397	-95.4475064369399178
4081	2019-10-18 06:13:45	2019-10-18	Trinity Murazik	trinity.murazik@warmmail.com	Oakland	California	4580718301893058	94b8bc2a59048d9cae0ce53776d7788c	Voyager	37.8080301273558845	-122.290169175564088
4082	2019-10-18 08:12:03	2019-10-18	Dr. Irvine Kertzmann Sr.	dr.irvine.kertzmann.sr.@geemail.com	Oakland	California	869994072891559045	85925d74998e00ca9cec3ac84f5c306b	VISA 16 digit	37.7942951772711027	-122.300608466512841
4083	2019-10-18 08:23:12	2019-10-18	Jaymes Hermann	jaymes.hermann@geemail.com	San Francisco	California	869986364904092704	98d1749fc00ba81bc05eee4b7e042851	Diners Club / Carte Blanche	37.770912094464542	-122.456257508827065
4084	2019-10-18 09:35:06	2019-10-18	Mr. Alden Littel IV	mr.alden.littel.iv@geemail.com	Los Angeles	California	6011520469635830266	d224190304e2c5d76fa507b5a44b68c5	Diners Club / Carte Blanche	34.078727606344593	-118.381650168867026
4085	2019-10-18 10:01:47	2019-10-18	Germaine Bosco	germaine.bosco@geemail.com	Washington	District of Columbia	6011064031165409010	a022177b897a2f13364e185cd72ca016	JCB 16 digit	38.8194016522992413	-77.0021279209040159
4086	2019-10-18 10:21:08	2019-10-18	Verle Kling	verle.kling@woohoo.com	Phoenix	Arizona	4445024829521338	6a632f9eec28f6543638d09f79038f68	American Express	33.6462169725380846	-112.165408350846178
4087	2019-10-18 10:45:46	2019-10-18	Fronnie Johnston	fronnie.johnston@geemail.com	San Francisco	California	869945377644291436	a4a09bbfacf02c5ab1c39ae9b2f68ff8	JCB 16 digit	37.7691046345508212	-122.455519190602317
4088	2019-10-18 11:21:18	2019-10-18	Fabian Hand	fabian.hand@geemail.com	Fresno	California	53683044283896035	7c4f3a29c93ce64ca33c62e241b7678f	Maestro	36.8815436609894007	-119.832044031900921
4089	2019-10-18 11:35:00	2019-10-18	Aylin Kohler	aylin.kohler@geemail.com	San Francisco	California	53472793388980715	2647677379f182c9df3ff4b804ad3f28	VISA 16 digit	37.7616051566488693	-122.455863488048351
4090	2019-10-18 12:04:35	2019-10-18	Bynum Witting	bynum.witting@geemail.com	San Francisco	California	4746868985167	8915f5f4f3fa1b556f50f414e747e606	JCB 16 digit	37.7456706030725542	-122.43685390509512
4091	2019-10-18 12:32:18	2019-10-18	Irine Nader	irine.nader@geemail.com	Oakland	California	3780251069547059	ff05f38e4352ec6a26abed48ffa8172c	VISA 13 digit	37.8335726707177642	-122.206019766696741
4092	2019-10-18 13:05:30	2019-10-18	Rella Lehner	rella.lehner@warmmail.com	San Francisco	California	52783527011039646	2105de291b15541e93ee9ed57571681c	VISA 16 digit	37.7654746902145888	-122.409323354137001
4093	2019-10-18 13:14:59	2019-10-18	Miss Nikia Macejkovic	miss.nikia.macejkovic@warmmail.com	Palm Bay	Florida	6011676677180358275	dc7d4a07ee475db19ec37a112b205930	Diners Club / Carte Blanche	27.9143731442600505	-80.6537640276666679
4094	2019-10-18 15:21:27	2019-10-18	Alijah Kuphal MD	alijah.kuphal.md@geemail.com	San Francisco	California	3014681031918223	6534d2456432f4dda7ae5afa6b801185	JCB 16 digit	37.7512440419977864	-122.425888974185426
4095	2019-10-18 15:31:32	2019-10-18	Natalia Ziemann	natalia.ziemann@woohoo.com	New Orleans	Louisiana	3112171044225338053	3d8e35d3047aa78d4dd216c9043b7d25	VISA 16 digit	30.0015168691068901	-89.8843410360422013
4096	2019-10-18 15:48:29	2019-10-18	Melonie VonRueden	melonie.vonrueden@geemail.com	San Francisco	California	55340844245142922	e9511d42f35bbf3b6103b65dc64564b1	VISA 13 digit	37.7983514031936068	-122.426382205663813
4097	2019-10-18 16:21:08	2019-10-18	Ballard Hilpert	ballard.hilpert@geemail.com	Berkeley	California	180095014046994452	436cdb28f710eac967a9e18c2b1c938a	JCB 15 digit	37.8622821772229443	-122.267975305723198
4098	2019-10-18 16:31:54	2019-10-18	Vera Carroll	vera.carroll@geemail.com	Santa Clara	California	51801075121979697	da0a8b72ab22ed00aa96eb8f07b86747	VISA 16 digit	37.4573670744247735	-122.039535035006324
4099	2019-10-18 17:16:57	2019-10-18	Yamilex Harvey	yamilex.harvey@geemail.com	Berkeley	California	4865316963365006	c0fdf94e8c6e87a2f782e83a3b7fdbfb	Discover	37.8361552641514223	-122.275534758738416
4100	2019-10-18 19:01:46	2019-10-18	Isaias Lowe	isaias.lowe@geemail.com	Tampa	Florida	4442718603412	ee9acc92c28818dde8377609590a0365	Voyager	27.8903454055193798	-82.4415913963436964
4101	2019-10-18 19:28:50	2019-10-18	Dolores Kilback	dolores.kilback@warmmail.com	San Francisco	California	630459654835921	62796b0fe0de3c584e65623ec1d432d1	VISA 16 digit	37.7793285223100952	-122.439297643427977
4102	2019-10-18 19:30:52	2019-10-18	Werner Stanton	werner.stanton@geemail.com	San Francisco	California	4208782780653	15acc73187155b47993fbe5a25fb4deb	VISA 16 digit	37.7624033537958965	-122.419344021219231
4103	2019-10-18 20:17:01	2019-10-18	Jessie Davis Sr.	jessie.davis.sr.@geemail.com	San Francisco	California	3712420501916130	b8f78a578a339eae47e1f108a7cb107d	Maestro	37.7743615407679698	-122.460833077507587
4104	2019-10-18 21:15:37	2019-10-18	Aaron Weissnat	aaron.weissnat@geemail.com	Milwaukee	Wisconsin	3528720073617488826	ac24817e8c1e43ab12ed637d85e9051c	Maestro	42.9832379772879136	-87.9655529209047558
4105	2019-10-18 22:16:40	2019-10-18	Sonia Spencer	sonia.spencer@geemail.com	Costa Mesa	California	4637255236332	a66e0c31330916b968f45edc5b7cccfa	American Express	33.6095221731826683	-117.886496173530077
4106	2019-10-18 22:34:01	2019-10-18	Alto Mohr	alto.mohr@geemail.com	Berkeley	California	4821634295112943	c20511b5d7e7702e606541a714c823be	JCB 15 digit	37.8672530714779896	-122.25239977259254
4107	2019-10-18 23:03:34	2019-10-18	Geri Leffler PhD	geri.leffler.phd@geemail.com	Amarillo	Texas	676154802307972	ae3c3878ef5fe92b67cea74d310cdb20	VISA 13 digit	35.1337416871614749	-101.859351188256227
4108	2019-10-18 23:10:32	2019-10-18	Myrna Moen	myrna.moen@geemail.com	Evansville	Indiana	3096661368543365267	f59b11f89696766e68471583a83cc22d	VISA 16 digit	38.0490050056155766	-87.5905355315122733
4109	2019-10-18 23:15:48	2019-10-18	Burr Hodkiewicz	burr.hodkiewicz@woohoo.com	San Francisco	California	869912582452835690	cd62a670858e8ea61c109e97546e0a0d	JCB 15 digit	37.7900340768395182	-122.435065011550208
4110	2019-10-19 00:01:37	2019-10-19	Janet Hand	janet.hand@geemail.com	Newport News	Virginia	3528062876905586283	f04689ac593e483d6a1ce70ecc4d6cb9	JCB 15 digit	37.1715445685561718	-76.4761347285732711
4111	2019-10-19 01:05:38	2019-10-19	Alpha Kris	alpha.kris@geemail.com	Providence	Rhode Island	4662498120148445	a97cddd4fba06802513df77544fc6200	VISA 16 digit	41.8726807831175591	-71.5093494380742385
4112	2019-10-19 01:27:22	2019-10-19	Sabina Heaney MD	sabina.heaney.md@woohoo.com	San Francisco	California	4183592917849767	6386d3cd23379073c076dbbd04ea36a1	VISA 16 digit	37.7999210241647319	-122.392641152382609
4113	2019-10-19 02:09:51	2019-10-19	Gayle Hermann	gayle.hermann@warmmail.com	Sparks	Nevada	3042519272910644	5a7464ea3f2862d4b8c4df89fb44b95f	VISA 16 digit	39.4865061338298062	-119.789469764879357
4114	2019-10-19 02:17:12	2019-10-19	Verdell Corkery DVM	verdell.corkery.dvm@geemail.com	New York	New York	630411373799607	a38d5cad79943004d57ce39e04c0aafb	VISA 13 digit	40.6689547522682702	-73.8754194453254343
4115	2019-10-19 02:36:54	2019-10-19	Harmon Jacobi DDS	harmon.jacobi.dds@geemail.com	Oakland	California	630469082428678	2d8d1af3839034459d6e6cd30bef3f27	VISA 13 digit	37.8105911820080181	-122.289209216625466
4116	2019-10-19 03:10:52	2019-10-19	Mrs. Dalia Fahey	mrs.dalia.fahey@geemail.com	San Diego	California	3040738603937637	24149f80325b78068a9784b6f9459d4c	VISA 13 digit	32.9067576512761448	-117.200791145572438
4117	2019-10-19 04:39:47	2019-10-19	Columbia Turner	columbia.turner@geemail.com	Phoenix	Arizona	3337843465348969904	fed4ad1a311ea68423ed544cd446fe33	VISA 16 digit	33.5598645316835515	-111.991751709154258
4118	2019-10-19 04:59:33	2019-10-19	Bob Konopelski	bob.konopelski@geemail.com	High Point	North Carolina	3438786377360227	33d7c9b9c9744adecb8ea5952995a489	Voyager	36.0287638472486336	-79.9473245980888549
4119	2019-10-19 05:03:16	2019-10-19	Ms. Terrie Jacobi PhD	ms.terrie.jacobi.phd@warmmail.com	Austin	Texas	869953223173612932	6d536f74b61bf996feeff5b70e8ad839	VISA 16 digit	30.3005218908783043	-97.7086116195429213
4120	2019-10-19 05:50:18	2019-10-19	Rodolfo Brown	rodolfo.brown@geemail.com	San Francisco	California	869981685564623874	c1f899b36ca0c4c32387e41bb1c39a4f	Voyager	37.8007516869572697	-122.440127664409744
4121	2019-10-19 06:06:46	2019-10-19	Mrs. Gidget Kunde DVM	mrs.gidget.kunde.dvm@warmmail.com	San Francisco	California	54692287496360203	ff1cc34b08d90f3436aecd9893e07580	Diners Club / Carte Blanche	37.7705692075285597	-122.462069394077915
4122	2019-10-19 06:30:41	2019-10-19	Colon Kreiger-Brown	colon.kreiger.brown@geemail.com	San Francisco	California	869933505970869235	91215fb145c62c18170ca2c13e4246d4	JCB 16 digit	37.80687673310576	-122.438975046737966
4123	2019-10-19 07:01:13	2019-10-19	Annalise Adams	annalise.adams@geemail.com	San Francisco	California	6011429015375317469	5848c4f8675e64432e1bc04690e1ebd4	JCB 16 digit	37.7501552077226563	-122.430403642657467
4124	2019-10-19 08:43:08	2019-10-19	Dr. Rafael Rogahn DDS	dr.rafael.rogahn.dds@warmmail.com	Salinas	California	4423352611756754	3df604ae170aac7e921108de2807b2a4	VISA 16 digit	36.6302227489881176	-121.676324016152705
4125	2019-10-19 09:49:29	2019-10-19	Dr. Omer Morissette	dr.omer.morissette@geemail.com	Rancho Cucamonga	California	4985609914101149	b7ca258f5f26d363d84671a13e3ed745	VISA 13 digit	34.0995413334567132	-117.623342509289088
4126	2019-10-19 09:56:06	2019-10-19	Elenor Oberbrunner	elenor.oberbrunner@geemail.com	San Francisco	California	4741552958670725	d97f0eed68f16e789b3d4aaddba6c85c	JCB 16 digit	37.7579327273038601	-122.410277445494273
4127	2019-10-19 09:58:30	2019-10-19	Muriel Macejkovic	muriel.macejkovic@geemail.com	Las Vegas	Nevada	6011290053177034046	da7852e1459e5271aee2ed3487e78f65	Discover	36.2147187379289406	-115.279794539951155
4128	2019-10-19 10:47:08	2019-10-19	Signe Stehr MD	signe.stehr.md@geemail.com	New York	New York	502040453424307	f3310753594d81e5dedf9577f896bb49	Maestro	40.6365163683649158	-73.9099088519241576
4129	2019-10-19 11:01:50	2019-10-19	Orville Pouros	orville.pouros@woohoo.com	Indianapolis	Indiana	180037204564148646	aafad6f0c1a9b9e3a66e3b95b9439d3b	Voyager	39.7838187946945396	-86.1937976636659329
4130	2019-10-19 11:27:23	2019-10-19	Mr. Kelsey Bashirian	mr.kelsey.bashirian@geemail.com	Berkeley	California	53910445933893717	2dfb52a7993f0277c67cf1e8df5abb3f	Maestro	37.858676895202592	-122.274733132270399
4131	2019-10-19 13:23:49	2019-10-19	Renada Luettgen-Nikolaus	renada.luettgen.nikolaus@woohoo.com	Lincoln	Nebraska	6011058214818362244	efbb5ad12290880a31c19f68e72da844	Discover	40.8805246626976881	-96.6267485455770014
4132	2019-10-19 13:37:47	2019-10-19	Lilliana Wehner DDS	lilliana.wehner.dds@geemail.com	Berkeley	California	4304749152730094	50c2bf6da4568a8e3f936c31359c2aa5	Mastercard	37.8622345246679615	-122.286572243606344
4133	2019-10-19 15:24:38	2019-10-19	Clemmie Carroll	clemmie.carroll@woohoo.com	Phoenix	Arizona	6011001555417253244	565317c5aa450c8461029d9f849a3245	Discover	33.6449638261392749	-112.116665297134233
4134	2019-10-19 15:58:04	2019-10-19	Melville Ebert	melville.ebert@woohoo.com	San Francisco	California	3755515739242825	b0d26e34695bc6c72192d002a7d7918c	VISA 13 digit	37.772101180827292	-122.429170951621856
4135	2019-10-19 16:58:18	2019-10-19	Dr. Rae Lemke Jr.	dr.rae.lemke.jr.@geemail.com	San Francisco	California	6011483121055428486	3f4b57cf347726f75882ecb6b39e258a	Maestro	37.7430899605403454	-122.45505929306681
4136	2019-10-19 17:18:15	2019-10-19	Chloie Crona-Koss	chloie.crona.koss@geemail.com	San Francisco	California	4656627623539555	d1e6212b41b22bef617cf50872992d1f	Maestro	37.7486037673855535	-122.418523002986277
4137	2019-10-19 17:31:29	2019-10-19	Annabel Torp DDS	annabel.torp.dds@geemail.com	Oakland	California	3489046042474038	370ea50afd3354952a0cf4946e98af2f	Voyager	37.7907395935789054	-122.258499415317459
4138	2019-10-19 17:38:46	2019-10-19	Delos Corwin-Reichel	delos.corwin.reichel@geemail.com	Oakland	California	3040191247490441	ef59ffdb09ebc08d7cd3417470cc18d1	JCB 15 digit	37.8053108464271261	-122.262553712203385
4139	2019-10-19 17:49:46	2019-10-19	Mr. Casimiro Kessler Sr.	mr.casimiro.kessler.sr.@geemail.com	Oakland	California	4993261708402232	50c0a9294c8c99123e439a63b479bc9b	VISA 13 digit	37.7966952948349828	-122.311160195770086
4140	2019-10-19 17:59:03	2019-10-19	Bonny Mante	bonny.mante@warmmail.com	Escondido	California	676195277899175	d7297f0de084ddb233979468eefe308a	Voyager	33.0855741108063626	-117.078867883305989
4141	2019-10-19 18:01:10	2019-10-19	Barnie Senger	barnie.senger@geemail.com	Arvada	Colorado	52959612596229370	8689c1fd3bb2fed4034fde4c038aa03b	Maestro	39.8314758143562813	-105.082099573777242
4142	2019-10-19 19:09:28	2019-10-19	Noma Lakin	noma.lakin@geemail.com	Chicago	Illinois	676369727368438	a75e6f2250ef36bf5e9901c4106bf87b	American Express	41.9324105066549038	-87.655857470262049
4143	2019-10-19 19:40:59	2019-10-19	Curtis Pollich	curtis.pollich@geemail.com	Oxnard	California	4474879268239518	9bb3547a8c2f40bd5dba4e1a08410fc6	VISA 13 digit	34.2148411809422086	-119.187705994388466
4144	2019-10-19 21:11:59	2019-10-19	Erna Ziemann MD	erna.ziemann.md@geemail.com	San Francisco	California	3768653240468160	e31c30c1f3e153e9cf5ddede32d4c101	VISA 16 digit	37.7509452257499944	-122.41737360942642
4145	2019-10-19 21:48:43	2019-10-19	Mrs. Cathleen McKenzie	mrs.cathleen.mckenzie@geemail.com	San Francisco	California	3721866333118817	fc405d313ef0b42a184b8f8e376e9ac3	Discover	37.7933412998690557	-122.458334357832456
4146	2019-10-19 22:09:29	2019-10-19	Domenico Greenfelder	domenico.greenfelder@geemail.com	San Francisco	California	3112875736072076988	42644adaa2bcdff6ebbe3efab7932e7f	Discover	37.7787004560497124	-122.390714179403986
4147	2019-10-19 23:16:41	2019-10-19	Mr. Asbury Farrell	mr.asbury.farrell@warmmail.com	Oakland	California	3528852205122650850	e339c5c5b1867d535a45336d9d920181	Maestro	37.7896154567538929	-122.276794899330611
4148	2019-10-19 23:31:46	2019-10-19	Mr. Deangelo Wisozk PhD	mr.deangelo.wisozk.phd@woohoo.com	Long Beach	California	210018795868589784	1ff745c2c0f6c9116ad6fbd83f10ab73	Voyager	33.8423737843807757	-118.189837837421521
4149	2019-10-20 00:58:47	2019-10-20	Lissette Simonis-Roob	lissette.simonis.roob@warmmail.com	Tulsa	Oklahoma	060432527160173	e90bc4fe082b213a1d39f9175b91bc98	JCB 16 digit	36.1730561721973061	-95.8531828685618876
4150	2019-10-20 01:07:50	2019-10-20	Exie Olson	exie.olson@geemail.com	Overland Park	Kansas	3088915186901346081	5c587ca628bbb55df175880be56eb637	JCB 15 digit	38.8398449706248954	-94.7542949177831417
4151	2019-10-20 01:40:43	2019-10-20	Albertha Bradtke MD	albertha.bradtke.md@geemail.com	Sandy Springs	Georgia	3799315395503315	fa9f6d34f49f6d5b6075ad411602d58e	Voyager	34.0215762673001763	-84.3197149227921017
4152	2019-10-20 01:49:36	2019-10-20	Fredie Littel	fredie.littel@woohoo.com	Overland Park	Kansas	3735086832158198	10070ed1033f7fbe67fae01f57dfd7b7	Voyager	38.8390513991806685	-94.610804949006436
4153	2019-10-20 01:52:10	2019-10-20	Barnard Anderson Sr.	barnard.anderson.sr.@woohoo.com	Scottsdale	Arizona	4749734897086203	4ce0845f84bb576fc46b735810123ef2	Discover	33.6816754314705733	-111.798620747166126
4154	2019-10-20 02:37:51	2019-10-20	Maebell Reinger	maebell.reinger@warmmail.com	Houston	Texas	561200492738943	41a838a2be32ffe228c3f12853b6c605	JCB 16 digit	29.8394056536801173	-95.4483288152623999
4155	2019-10-20 03:32:36	2019-10-20	Thorwald Mitchell	thorwald.mitchell@geemail.com	San Francisco	California	676123139363743	0b6559ede756c1cbd8078965a533ff45	Maestro	37.7579100270506842	-122.466452879398801
4156	2019-10-20 03:42:05	2019-10-20	Giovanny Jast	giovanny.jast@geemail.com	San Francisco	California	3096958481038608455	6db66b9ae17b24cd6d72d3097a6a032d	Mastercard	37.7608246143158368	-122.438561423153729
4157	2019-10-20 03:48:12	2019-10-20	Dr. Cash Lowe PhD	dr.cash.lowe.phd@geemail.com	San Francisco	California	3019508513264492	351f39d81ab0ffdbdd30696b9fcb87e7	VISA 16 digit	37.7755411357716895	-122.42212212481752
4158	2019-10-20 04:19:23	2019-10-20	Tessa Ziemann DDS	tessa.ziemann.dds@geemail.com	McKinney	Texas	869975790921109878	ba0b5b511242aa9b0267138450d0f6ba	JCB 15 digit	33.1828893391545918	-96.6439166337549693
4159	2019-10-20 04:37:29	2019-10-20	Agnes Barton	agnes.barton@geemail.com	Lewisville	Texas	3088745815638234915	de6ee739adabf92c3e32bb6329df62aa	Discover	33.0664198657482871	-97.029253257301832
4160	2019-10-20 04:48:07	2019-10-20	Margery Robel	margery.robel@warmmail.com	Ontario	California	4937690704707971	b75c6b3936e26086b927a14f0137ad04	VISA 16 digit	34.111814835961539	-117.534871133659792
4161	2019-10-20 05:03:55	2019-10-20	Lawton Macejkovic	lawton.macejkovic@geemail.com	San Francisco	California	55450591518185668	3ec79012a258051172242708922b2c58	American Express	37.7903996884807043	-122.44468566504068
4162	2019-10-20 08:42:26	2019-10-20	Braden Mann-Swift	braden.mann.swift@geemail.com	San Francisco	California	6011867177257600849	57ebfa0e0761087ff4a4c2437a28b802	JCB 16 digit	37.8133058766131853	-122.438883194369012
4163	2019-10-20 09:53:12	2019-10-20	Cailyn Heidenreich	cailyn.heidenreich@geemail.com	Elgin	Illinois	6011751225334917469	cee58b6c11d0b60e1c6028dba4c71096	JCB 16 digit	42.0288635338008376	-88.2674910390570773
4164	2019-10-20 09:54:49	2019-10-20	Jodi Volkman	jodi.volkman@geemail.com	Oakland	California	4660296993364	9b6aa3e7829f1b6a7ada0157dba3bc86	JCB 16 digit	37.7751445582751586	-122.278621318572959
4165	2019-10-20 10:36:04	2019-10-20	Dallin Gaylord	dallin.gaylord@warmmail.com	Davenport	Iowa	4602819374441	c4771ac8a1599cc8d393fe0bb61181a6	Diners Club / Carte Blanche	41.6099845968451305	-90.6382094876803421
4166	2019-10-20 11:03:30	2019-10-20	Telly Sporer	telly.sporer@geemail.com	San Francisco	California	4225242295890	7d01ef18bf79370d3d6d9d75497269ac	Diners Club / Carte Blanche	37.756165634010749	-122.449135553476978
4167	2019-10-20 11:14:30	2019-10-20	Miss Cherelle Kilback DDS	miss.cherelle.kilback.dds@geemail.com	San Francisco	California	589312291139082	d86574b16d1dd15a43e1022c5b68814d	VISA 16 digit	37.7803998479395418	-122.437443137164635
4168	2019-10-20 12:02:30	2019-10-20	Sheryll Block	sheryll.block@woohoo.com	San Francisco	California	869991851820569156	9462e94265e7167b7421abe186cadbe2	American Express	37.7829897669931327	-122.389024197876751
4169	2019-10-20 13:35:39	2019-10-20	Hughie Ritchie	hughie.ritchie@geemail.com	Phoenix	Arizona	3337507638788793441	41a3cdc1485c86b6764bf6bc7514ce13	VISA 16 digit	33.5549870774548538	-112.034156147243834
4170	2019-10-20 13:59:15	2019-10-20	Mr. Tyreek Hackett I	mr.tyreek.hackett.i@geemail.com	Berkeley	California	180060128882038348	ecce37ee6e40a989e42dd184312cb135	Discover	37.8802707866558919	-122.281352429739613
4171	2019-10-20 14:02:44	2019-10-20	Georgina Marquardt DVM	georgina.marquardt.dvm@geemail.com	Colorado Springs	Colorado	3729578155407622	d44c749eba9f21243866c59ed07db120	Maestro	38.919181861360741	-104.821591433712101
4172	2019-10-20 14:08:05	2019-10-20	Nathanael Hansen	nathanael.hansen@geemail.com	San Francisco	California	3528520786286453019	2c751453bc83a3fde2a56c70f782af3d	JCB 16 digit	37.7592818968170718	-122.435904636855568
4173	2019-10-20 14:36:35	2019-10-20	Elsworth Lowe	elsworth.lowe@geemail.com	West Valley City	Utah	6011903049066702718	6a2932156b339a9536ee7c4208a98be8	VISA 16 digit	40.7058665317241051	-111.959562952325854
4174	2019-10-20 15:01:28	2019-10-20	Mr. Jerry Kohler	mr.jerry.kohler@woohoo.com	Houston	Texas	210042418574442921	140fbdfcaaf17aa12803466b3d5326a7	Diners Club / Carte Blanche	29.7101015314072363	-95.3134593502633294
4175	2019-10-20 15:07:51	2019-10-20	Cayden Zemlak	cayden.zemlak@woohoo.com	San Francisco	California	4617686088917571	e4c7f8b6f7c75767166e1fe725a8ab5f	Discover	37.7752413947260948	-122.421971340804205
4176	2019-10-20 18:12:09	2019-10-20	Mr. Gilmer Ritchie	mr.gilmer.ritchie@warmmail.com	Los Angeles	California	210078590517369580	c3bc2afa56b49ad0f652ad871709f7d2	Voyager	33.9431311503849926	-118.444679185141993
4177	2019-10-20 18:45:19	2019-10-20	Trevion Wolff	trevion.wolff@warmmail.com	San Francisco	California	3726358943352692	a04eb3baa3627cd6b181038c259655c5	Diners Club / Carte Blanche	37.7783538309034199	-122.439219182592296
4178	2019-10-20 19:12:15	2019-10-20	Emmons West	emmons.west@geemail.com	Des Moines	Iowa	3337111586261800217	7075160ef0cfe55e4fd3212e06ca134f	Diners Club / Carte Blanche	41.6277724173128618	-93.6093522856988045
4179	2019-10-20 19:23:21	2019-10-20	Othel Wolff	othel.wolff@geemail.com	Berkeley	California	869949411381614801	f020e30b312d690f576fa386f46770ad	American Express	37.8835220455080659	-122.340316123811874
4180	2019-10-20 19:52:22	2019-10-20	Ashlyn Quigley	ashlyn.quigley@woohoo.com	Berkeley	California	3158975689278550828	89aaa2c78ea322eb943ede79b06667e9	VISA 13 digit	37.9005733444414403	-122.283745950249042
4181	2019-10-20 20:19:47	2019-10-20	Mr. Rhoda Bergnaum PhD	mr.rhoda.bergnaum.phd@woohoo.com	Chicago	Illinois	4493488067100710	bffd97a8e6dfc38e02a01ac11e1610a6	JCB 16 digit	41.8029189660981331	-87.6275769681699472
4182	2019-10-20 20:26:05	2019-10-20	Edmonia Steuber	edmonia.steuber@woohoo.com	Spokane	Washington	3158435375946434538	d801fe3ba074891519adfd9b36f12131	VISA 16 digit	47.6058447558205557	-117.430278848055011
4183	2019-10-20 21:25:43	2019-10-20	Mrs. Evelin Bode PhD	mrs.evelin.bode.phd@geemail.com	Worcester	Massachusetts	4952098846910	226fe06ad6fa28a499f2de46e31226b7	JCB 16 digit	42.3587804937437156	-71.8198921405963659
4184	2019-10-20 21:41:12	2019-10-20	Wilda Price	wilda.price@geemail.com	San Francisco	California	4972981549003064	2a95d9430a12230f0a8ad27b7b6824d4	Diners Club / Carte Blanche	37.7806399056645859	-122.445013596904147
4185	2019-10-20 21:56:17	2019-10-20	Karyn Fay	karyn.fay@geemail.com	Chicago	Illinois	6011119584037987261	83d4bc4fd390dffe2c90656729316a78	VISA 16 digit	41.9237398190725585	-87.7332416977297527
4186	2019-10-20 22:16:39	2019-10-20	Leola Dietrich	leola.dietrich@warmmail.com	Dallas	Texas	6011969163135559834	36f2ecea47dc74af44fd5b050baae0bd	Mastercard	32.792648643422126	-96.6958420979287467
4187	2019-10-20 22:29:09	2019-10-20	Tamekia Tillman	tamekia.tillman@warmmail.com	Beaumont	Texas	3112399161696157709	c1cc2db7cfeeab063d9165789b27376c	VISA 16 digit	30.0318085285905774	-94.1352942771066097
4188	2019-10-20 23:46:19	2019-10-20	Jett Shields	jett.shields@geemail.com	Atlanta	Georgia	630436196245736	b0362f57faa24c6a819d43866bf90100	Mastercard	33.7079560885481584	-84.4368448002308725
4189	2019-10-20 23:49:56	2019-10-20	Leila Block	leila.block@geemail.com	Chicago	Illinois	210081009905611193	b9084e00c53e5dd8af976e03ed3242df	Diners Club / Carte Blanche	41.884157728061453	-87.5910215197160795
4190	2019-10-21 00:21:11	2019-10-21	Davina Koch	davina.koch@warmmail.com	Buffalo	New York	630435196975292	2a76e3566c645dba026d82287422b746	Voyager	42.8563488338794514	-78.9155244084008132
4191	2019-10-21 01:17:19	2019-10-21	Friend Kessler Sr.	friend.kessler.sr.@geemail.com	San Francisco	California	3717023502169496	33624707a350e8b4c4719442bf28878e	Discover	37.8097842530465869	-122.427015132210414
4192	2019-10-21 01:54:16	2019-10-21	Augustine Cronin	augustine.cronin@geemail.com	Pembroke Pines	Florida	3337359444900117448	1c046a4df4f28ec57ba8d5dc48698a48	American Express	25.9575665949881085	-80.4014114309471069
4193	2019-10-21 01:59:26	2019-10-21	Fitzhugh Rath	fitzhugh.rath@geemail.com	San Francisco	California	52580797052569885	2646c3a54c1ae2c9006b6bb84e609790	JCB 15 digit	37.7843830329725279	-122.417521289953285
4194	2019-10-21 03:11:57	2019-10-21	Joan Dicki	joan.dicki@geemail.com	San Francisco	California	4882356014168	5303ba6d0cac529a724cd7d2fa8b0164	VISA 16 digit	37.7834112528409349	-122.397827755907514
4195	2019-10-21 03:23:49	2019-10-21	Jay Kub-Littel	jay.kub.littel@geemail.com	Berkeley	California	4904927741949367	9a4188a90bc94398019f20684ae6803b	Mastercard	37.8805346065462771	-122.266703698147481
4196	2019-10-21 03:57:08	2019-10-21	Olof Rolfson PhD	olof.rolfson.phd@geemail.com	Las Vegas	Nevada	4281594724661188	d41fb89fc82af33e7bec80350129bf43	JCB 16 digit	36.2110853974342319	-115.20375319153294
4197	2019-10-21 06:13:54	2019-10-21	Allene Kohler DVM	allene.kohler.dvm@geemail.com	San Francisco	California	6011135504731687090	117631310b4f266a1667ab050b1aeaf3	JCB 15 digit	37.7429697404995963	-122.412345032281394
4198	2019-10-21 06:33:02	2019-10-21	Laquan Bailey MD	laquan.bailey.md@geemail.com	San Francisco	California	3112506315744482960	93c9c09b330772a921153c219f549ac6	JCB 16 digit	37.8144934755934514	-122.388782129589288
4199	2019-10-21 08:08:28	2019-10-21	Nonie Conroy DDS	nonie.conroy.dds@geemail.com	Madison	Wisconsin	4996297963915135	3c790789974900ad0962a8bf7f5c1168	Diners Club / Carte Blanche	43.0423531221199767	-89.4415129402071329
4200	2019-10-21 08:37:13	2019-10-21	Dr. Chauncy Rempel MD	dr.chauncy.rempel.md@geemail.com	Phoenix	Arizona	3528861493771967432	92e0f32fde33b797b6cb760799df7723	Mastercard	33.4896971999600552	-112.137782039486254
4201	2019-10-21 08:46:02	2019-10-21	Miranda Rosenbaum	miranda.rosenbaum@geemail.com	Beaumont	Texas	3337783475496668416	fb2985627cb1c5a331340260d811079d	VISA 16 digit	30.0052407786786581	-94.1819551050450769
4202	2019-10-21 08:51:19	2019-10-21	Gustavus Quigley	gustavus.quigley@geemail.com	Oakland	California	869947213565853169	39f957218f20b3b1b49061e8a2cc5b4a	Discover	37.8450508986823806	-122.270248879976492
4203	2019-10-21 09:31:05	2019-10-21	Shaun Durgan	shaun.durgan@woohoo.com	Oakland	California	675927923173556	f05916391285bcacc4d07d25ae6f8dfa	Discover	37.8057327996880161	-122.247101598128708
4204	2019-10-21 09:58:46	2019-10-21	Alexis Willms DDS	alexis.willms.dds@warmmail.com	New York	New York	6011609496401259838	94f06b7e05c8c916c3d14f2168d21cc1	VISA 16 digit	40.6587866638079305	-73.9125554777577491
4205	2019-10-21 10:01:18	2019-10-21	Madilyn Grant-Champlin	madilyn.grant.champlin@geemail.com	Seattle	Washington	561299537296347	1aa516c8371722ce781fd19914361d18	JCB 15 digit	47.6089026026353253	-122.36420972388386
4206	2019-10-21 10:07:28	2019-10-21	Bettyjane Dickens-Weimann	bettyjane.dickens.weimann@geemail.com	San Francisco	California	210008391596743448	31a9e95d440b24b7f289515f859882a9	Voyager	37.7906575017807427	-122.439026627514863
4207	2019-10-21 10:24:51	2019-10-21	Lenna Willms	lenna.willms@warmmail.com	San Francisco	California	4558559562927393	0a557b21d7c6632bcc1514e7c6bf9caa	American Express	37.8120001052473143	-122.415107795133082
4208	2019-10-21 10:27:57	2019-10-21	Wanita Turner-Rempel	wanita.turner.rempel@geemail.com	San Francisco	California	4301947038822332	c31bcda5c6743868097be364bb802da7	VISA 16 digit	37.7816134988603665	-122.446550525978836
4209	2019-10-21 10:36:43	2019-10-21	Clemmie Block-Bahringer	clemmie.block.bahringer@geemail.com	San Francisco	California	4201636273378669	278c1b6f38651ad5cdba2a967e493b72	VISA 16 digit	37.7858139151010235	-122.428925471522035
4210	2019-10-21 10:41:39	2019-10-21	Osborn Buckridge-Wisozk	osborn.buckridge.wisozk@geemail.com	Houston	Texas	4743991614202	236eaa250505e54811f0548066d9a11e	JCB 15 digit	29.8017333617046489	-95.3396122019287162
4211	2019-10-21 11:33:48	2019-10-21	Mr. Fidel Collins	mr.fidel.collins@geemail.com	Fontana	California	3005138118546095	036b39969da5160c6ed01077c8a1c573	Mastercard	34.0814059185478868	-117.533673625280713
4252	2019-10-22 17:43:41	2019-10-22	Isabel Wilderman	isabel.wilderman@geemail.com	Oakland	California	3433278213982666	0b4d7e11b4e4ef1d63cc09df8af378c3	VISA 16 digit	37.8282740215576965	-122.260981813523912
4212	2019-10-21 11:34:03	2019-10-21	Miss Tanika Cronin DDS	miss.tanika.cronin.dds@geemail.com	Seattle	Washington	869982538117318410	c3351a288a231e210e4817e88f10f937	Voyager	47.7082718673553288	-122.437790275916086
4213	2019-10-21 11:53:46	2019-10-21	Winnifred Walsh	winnifred.walsh@geemail.com	San Francisco	California	210078828676651665	ce896e4cf8002b165c6bc5a75e455af9	JCB 16 digit	37.7541263124468429	-122.405574664963765
4214	2019-10-21 14:00:56	2019-10-21	Adolphus Thiel III	adolphus.thiel.iii@geemail.com	Boston	Massachusetts	3088854962055049090	a008164770e95a31f951070dcfd62b1a	VISA 16 digit	42.4271020644977668	-70.9665306949939634
4215	2019-10-21 14:03:42	2019-10-21	Brendon Walter	brendon.walter@geemail.com	Milwaukee	Wisconsin	210089180297548483	eba867faabf4d38c9ace23fd57a820f0	JCB 15 digit	43.124600030769777	-87.961026337520039
4216	2019-10-21 14:09:15	2019-10-21	Celie Erdman	celie.erdman@geemail.com	San Francisco	California	3033424887129624	42c44164a0018a6228dd38b33af35f81	JCB 16 digit	37.7759714226486665	-122.413462884553041
4217	2019-10-21 14:48:02	2019-10-21	Berton Gleason	berton.gleason@geemail.com	Philadelphia	Pennsylvania	3158558651891009975	fe47e6236552b98f2d7c684e7d39da93	VISA 16 digit	39.9337464942555869	-75.0849877290792875
4218	2019-10-21 15:26:49	2019-10-21	Rylan Nikolaus-Bechtelar	rylan.nikolaus.bechtelar@woohoo.com	San Francisco	California	869900052015787907	58fe9c4db2d638636fb1cf4a6731aeb4	American Express	37.8188524174392882	-122.456528519218338
4219	2019-10-21 17:29:50	2019-10-21	Tamela Grant DDS	tamela.grant.dds@geemail.com	New York	New York	52533717564957335	bc1538836ad10ac51a228a0d1a3cf3fa	JCB 16 digit	40.7285435444433261	-73.9559957695089309
4220	2019-10-21 20:30:04	2019-10-21	Darren Considine	darren.considine@geemail.com	Killeen	Texas	55466368169700059	dc4b6a13ea620d1000f1732382ca09bd	JCB 16 digit	31.1611646057337524	-97.7085151247382129
4221	2019-10-21 21:25:18	2019-10-21	Noah Shields	noah.shields@woohoo.com	San Francisco	California	869940293639138505	3f118402a627719d78243a519a6c3077	American Express	37.7932910174426979	-122.431138725959372
4222	2019-10-21 22:05:58	2019-10-21	Dr. Ama Daugherty DVM	dr.ama.daugherty.dvm@geemail.com	Seattle	Washington	6011825619494582588	79c5e61a370d9687268bb8a340afe5e0	Maestro	47.5354320699274524	-122.295669418518983
4223	2019-10-21 23:29:31	2019-10-21	Fitzgerald Buckridge-Bradtke	fitzgerald.buckridge.bradtke@geemail.com	Oakland	California	4781853017976371	91c2a4267364b3aade5f4b19b760097d	Voyager	37.7729818176142587	-122.281435906201992
4224	2019-10-22 00:43:03	2019-10-22	Kristen Brekke III	kristen.brekke.iii@geemail.com	Oakland	California	4077809374691089	d257260790c4953d0d7af3fbea6bdfc3	Diners Club / Carte Blanche	37.7676282730300912	-122.275281040844376
4225	2019-10-22 01:24:40	2019-10-22	Mr. Newton Anderson Sr.	mr.newton.anderson.sr.@geemail.com	Indianapolis	Indiana	4899186290578	30b9ac521f3f0266e0585679e3cb69cb	Discover	39.7527837983805696	-86.2146019604258242
4226	2019-10-22 01:33:45	2019-10-22	Miss Jamie Thompson	miss.jamie.thompson@geemail.com	San Francisco	California	4685723696215	df8586699b6c1aa80e35af30ee6e3f88	VISA 16 digit	37.8148660311631986	-122.433448267576907
4227	2019-10-22 01:53:37	2019-10-22	Tamara Dach MD	tamara.dach.md@geemail.com	Elizabeth	New Jersey	3112783150170501213	aaefc689bf2a98a63656853d58432878	JCB 16 digit	40.5676967135757209	-74.2054717274326805
4228	2019-10-22 02:02:59	2019-10-22	Randell Ruecker-Nolan	randell.ruecker.nolan@geemail.com	Temecula	California	210076193585419122	a75d98df140895fc7b28bae38d932a56	Diners Club / Carte Blanche	33.5792881258897467	-117.042871156726775
4229	2019-10-22 02:57:33	2019-10-22	Bruno Turner-Ernser	bruno.turner.ernser@geemail.com	Chicago	Illinois	55428829472272588	7869640d8c5e65b7fadd9f312099c75d	VISA 16 digit	41.9030357646126319	-87.6133694747958316
4230	2019-10-22 03:24:33	2019-10-22	Jacalyn Gleason	jacalyn.gleason@geemail.com	Rancho Cucamonga	California	869913023239557579	3fa89f110cf741f5fb96774657d8b776	Maestro	34.0343642775893187	-117.550966823893418
4231	2019-10-22 04:12:35	2019-10-22	Dr. Damien Olson	dr.damien.olson@geemail.com	Amarillo	Texas	3528347246992598236	eb0f429a4d68c8c30efe211d8651ecd9	Mastercard	35.1371177486307928	-101.903332585361611
4232	2019-10-22 06:41:05	2019-10-22	Valentine Graham	valentine.graham@geemail.com	New York	New York	561204398189607	c81521ca9db2999ac97c65b557aabec7	Discover	40.7066243551895042	-73.9389577597740981
4233	2019-10-22 07:17:30	2019-10-22	Madison Fahey	madison.fahey@geemail.com	Fremont	California	4605116711710	07dd2b82b2b7f22447a92443083cd157	Diners Club / Carte Blanche	37.4160503262355917	-121.995399275281272
4234	2019-10-22 07:35:21	2019-10-22	Terance McCullough	terance.mccullough@geemail.com	Jurupa Valley	California	4688380931172	226ca4f7c5e1a86dfcc8ee4d802f9090	JCB 15 digit	33.9789999955728632	-117.414033370932941
4235	2019-10-22 07:56:28	2019-10-22	Kenyatta Crist	kenyatta.crist@geemail.com	Oakland	California	4629918596608	4c405386a1885bdd147c6d25331ef575	JCB 16 digit	37.8308777131380296	-122.262768417410967
4236	2019-10-22 08:26:27	2019-10-22	Sheila O'Conner	sheila.o'conner@geemail.com	Memphis	Tennessee	4186388394923	a99589db9a7542977e747cb30b391038	Mastercard	35.1974528009604697	-90.0440497274301919
4237	2019-10-22 08:49:42	2019-10-22	Coley Kuhic	coley.kuhic@geemail.com	Washington	District of Columbia	3112232081061004362	2d7bf2a678a905b15cf8f9d98979a1e4	VISA 13 digit	38.8631673322323721	-76.9566604446832088
4238	2019-10-22 08:50:29	2019-10-22	Landon Blanda-Rolfson	landon.blanda.rolfson@geemail.com	San Francisco	California	869966428306529359	116f446fd9f7219dffef1d6faef1de0d	Maestro	37.7942092312927613	-122.425702767361855
4239	2019-10-22 09:01:01	2019-10-22	Dr. Gussie Kuvalis IV	dr.gussie.kuvalis.iv@geemail.com	Cincinnati	Ohio	4163983937760585	96ea59299e5389021f8bd119b847fead	Mastercard	39.2283278613116622	-84.5991989082463078
4240	2019-10-22 09:16:14	2019-10-22	Mrs. Estefania Pfannerstill MD	mrs.estefania.pfannerstill.md@warmmail.com	Spokane	Washington	4485143332178534	b11439bfb0571b2039d7d09cedce0219	VISA 16 digit	47.738874331839007	-117.513526471787316
4241	2019-10-22 10:09:12	2019-10-22	Helma Weber	helma.weber@geemail.com	New York	New York	51939146312727818	ffde5211beff81725b94f8cf41ee1a9a	American Express	40.638727234605696	-73.9659317330352906
4242	2019-10-22 10:21:13	2019-10-22	Deane Casper	deane.casper@warmmail.com	San Francisco	California	4299168853573041	e296f49a72672bae1020b48cba8acbce	Maestro	37.7942562237260589	-122.407104990302798
4243	2019-10-22 10:35:20	2019-10-22	Mr. Kipp Hessel MD	mr.kipp.hessel.md@geemail.com	New York	New York	51942188376104455	c297439d6207418fc46771fb87a00d9c	JCB 16 digit	40.6161009567547566	-73.880295653630796
4244	2019-10-22 11:05:58	2019-10-22	Genevieve Lakin	genevieve.lakin@geemail.com	San Francisco	California	6011919886564977264	194d3b6443cc6b84a7680fd21e8d07b6	Diners Club / Carte Blanche	37.7812461643955189	-122.430647797273849
4245	2019-10-22 11:25:01	2019-10-22	Dr. Isreal Donnelly	dr.isreal.donnelly@warmmail.com	San Francisco	California	53943292019114431	308ef8d90e978c961ee6238d2e5cd76a	Diners Club / Carte Blanche	37.7928578706564551	-122.432717963493218
4246	2019-10-22 11:31:28	2019-10-22	Cheryle Glover MD	cheryle.glover.md@geemail.com	San Francisco	California	4373275901248	f10fff482a9f8a2bd77c41bad4fb9c0d	Voyager	37.7685065680661154	-122.419878819770659
4247	2019-10-22 12:11:30	2019-10-22	Landon Baumbach-Gerhold	landon.baumbach.gerhold@geemail.com	Honolulu	Hawaii	210053290322334718	a96b775115853434281ab498d717a8a7	Maestro	21.3148509359203295	-157.828392088992899
4248	2019-10-22 16:26:39	2019-10-22	Jahir Flatley-Spencer	jahir.flatley.spencer@geemail.com	Berkeley	California	4474218348240545	9df57e84ca0c391c188d9117e44c2821	Voyager	37.8640874702328034	-122.297253054882049
4249	2019-10-22 16:33:52	2019-10-22	Kenya Cremin	kenya.cremin@warmmail.com	Palmdale	California	4616844782870478	dc29f8ba24f3128b4adc20ab6a4979ba	JCB 15 digit	34.6312987551409748	-118.041918225679183
4250	2019-10-22 17:03:29	2019-10-22	Delma Smitham	delma.smitham@geemail.com	San Francisco	California	3789877112948455	74b5321fc72a333d8d3b356299265107	Voyager	37.7850304933650207	-122.439367384201759
4251	2019-10-22 17:36:31	2019-10-22	Mayme Boyer	mayme.boyer@woohoo.com	San Antonio	Texas	3042745778085595	7b6a3b7c0a7ac7d9781fe640b6fa589a	JCB 16 digit	29.5117459958955664	-98.4769699192907666
4253	2019-10-22 17:48:44	2019-10-22	Wes Schiller	wes.schiller@woohoo.com	San Francisco	California	869986929538757185	f2d1bc140bfa64cfeaa0d4a292910e74	Voyager	37.7734019224967525	-122.427047059303007
4254	2019-10-22 19:06:15	2019-10-22	Dorthea Terry-Corwin	dorthea.terry.corwin@geemail.com	Baton Rouge	Louisiana	3033295772743863	f78f616e66a943bef8327d25b5f697aa	Diners Club / Carte Blanche	30.4609480967026194	-91.1782661056253971
4255	2019-10-22 19:08:45	2019-10-22	Corene Howell	corene.howell@woohoo.com	Los Angeles	California	6011514597798502385	e9d3f70d4dad510aea814dc06a194f05	JCB 15 digit	34.0683003552123864	-118.447914816484968
4256	2019-10-22 19:49:48	2019-10-22	Gaynell Ledner	gaynell.ledner@warmmail.com	Berkeley	California	180006543268605279	605ca31f7ea32077dc4a5d06cd850df3	American Express	37.8763959607436078	-122.263072380946738
4257	2019-10-22 20:16:36	2019-10-22	Dayami Lueilwitz MD	dayami.lueilwitz.md@geemail.com	San Francisco	California	869970860591522208	8c5cc5a1e6e140031c35f904e5e8f051	JCB 15 digit	37.7733464033556103	-122.472765934440801
4258	2019-10-22 20:52:52	2019-10-22	Mildred Roberts	mildred.roberts@warmmail.com	Providence	Rhode Island	3096001570820495191	017e9f3d8c33a31b6ed2d0018f56a4fb	Diners Club / Carte Blanche	41.7267437446717153	-71.3247258333873049
4259	2019-10-22 21:33:52	2019-10-22	Ms. Venice Hilll PhD	ms.venice.hilll.phd@geemail.com	Houston	Texas	180009724755131808	7a6c28819967cb36d729e169690af85c	VISA 13 digit	29.8048298965752139	-95.3489969465430818
4260	2019-10-22 23:02:22	2019-10-22	Maddox Morissette	maddox.morissette@warmmail.com	San Francisco	California	4932345098200	04a4bb0d6aae0e964c9151321333f88e	VISA 16 digit	37.7235258969343192	-122.457110714700178
4261	2019-10-22 23:04:26	2019-10-22	Joanna Emard	joanna.emard@geemail.com	San Francisco	California	3337193119939407172	a482c7418338d4fdd4b2642317accdaa	Maestro	37.7938907102263002	-122.451532627061468
4262	2019-10-22 23:34:40	2019-10-22	Dr. Ralph Wunsch	dr.ralph.wunsch@woohoo.com	Omaha	Nebraska	639057425352614	95feef277802c558814f0ad16b7ee835	JCB 15 digit	41.2428318028949192	-96.0872224017627588
4263	2019-10-22 23:40:54	2019-10-22	Kassidy Bashirian	kassidy.bashirian@geemail.com	Lincoln	Nebraska	4403897172964027	ecb8d1a751dd19ccccc2a00437c037b6	JCB 16 digit	40.8494545889571299	-96.780045720205834
4264	2019-10-23 00:25:49	2019-10-23	Dr. Illya Dooley	dr.illya.dooley@woohoo.com	Anchorage	Alaska	639066322200628	881a8f3793ae331d076e6bcb8f7a5f22	JCB 16 digit	61.1629610803660029	-149.192916753947003
4265	2019-10-23 00:53:12	2019-10-23	Nyah McClure PhD	nyah.mcclure.phd@geemail.com	Lubbock	Texas	53004047955734311	5653ee8b7e72e69778bb7bd2da152c37	Mastercard	33.6380447340704549	-101.919507706622412
4266	2019-10-23 00:59:21	2019-10-23	Kaylee Considine	kaylee.considine@geemail.com	San Francisco	California	4679662061294416	9be44ea81e1d483c28f419895eca65e3	VISA 13 digit	37.7775351980577625	-122.444624125890726
4267	2019-10-23 02:31:23	2019-10-23	Dr. Kolby Langosh V	dr.kolby.langosh.v@geemail.com	San Francisco	California	3158096000036156623	b9b0bf6b1d5d83d78ec888727cb58944	Discover	37.7410689621386553	-122.411452243499312
4268	2019-10-23 02:47:34	2019-10-23	Melony Wiegand DDS	melony.wiegand.dds@geemail.com	Berkeley	California	3012713106518299	9a7832f587f9cd6c5447fd45df55305d	VISA 13 digit	37.8611782906620888	-122.287438731644272
4269	2019-10-23 03:01:43	2019-10-23	Berta Jenkins	berta.jenkins@geemail.com	Fullerton	California	3764257770329489	d731795fcd53a775b36d23b03b4eee13	JCB 15 digit	33.9809593724708989	-117.837542298503223
4270	2019-10-23 03:58:25	2019-10-23	Sherwood Goodwin	sherwood.goodwin@geemail.com	San Francisco	California	3042218514930235	4fff2f45549a4208b635e45816372057	Diners Club / Carte Blanche	37.7940340641542036	-122.421690841358611
4271	2019-10-23 04:21:40	2019-10-23	Marva Brekke	marva.brekke@geemail.com	Long Beach	California	869926077778389427	f236993b332b442e482c0e8164d4f0f6	Discover	33.8945790730703607	-118.059017746539041
4272	2019-10-23 07:46:04	2019-10-23	Ailene Collier	ailene.collier@warmmail.com	Long Beach	California	3044082707508432	96e39a615dca42964be996daed2a0307	JCB 16 digit	33.7247294959433361	-118.06337838593609
4273	2019-10-23 08:35:05	2019-10-23	Dorris Schiller-Hickle	dorris.schiller.hickle@warmmail.com	San Francisco	California	210034530252915745	7f211a296f97c2cf06825bde1ab428fd	Maestro	37.7670502033809399	-122.435935044953666
4274	2019-10-23 09:03:38	2019-10-23	Devon Heller	devon.heller@geemail.com	Berkeley	California	6011593461759901678	3dd63e1b057d67b487230f9f4f76fe84	JCB 16 digit	37.8785861622880802	-122.288228545619702
4275	2019-10-23 09:18:08	2019-10-23	Jaycee McClure	jaycee.mcclure@geemail.com	Oakland	California	55781364179050815	7c67d38e0dddd4bba1b73bb978be4ddf	VISA 16 digit	37.8365081662085032	-122.295922829111532
4276	2019-10-23 09:21:48	2019-10-23	Wilbur Lehner	wilbur.lehner@warmmail.com	San Francisco	California	3411417385060515	eb24308b2e03717aa7565458e42eb815	JCB 15 digit	37.7658662000537788	-122.411314355307198
4277	2019-10-23 10:15:22	2019-10-23	Coraima Considine	coraima.considine@geemail.com	New York	New York	53149046207901369	ff7e69649a073125cdea3d8f0398f5ad	VISA 16 digit	40.5801086016222854	-73.871928819118807
4278	2019-10-23 11:47:02	2019-10-23	Devon Mann	devon.mann@geemail.com	Bellevue	Washington	4579130798229	998e668e27e411a5e571731c151eb034	American Express	47.5229127812381833	-122.143446582142261
4279	2019-10-23 11:56:37	2019-10-23	Max Hilpert	max.hilpert@woohoo.com	San Francisco	California	210082181586915596	23fb46e508a6c0e5e477ef95506a35b9	JCB 16 digit	37.7760709577738041	-122.415984438860988
4280	2019-10-23 12:10:14	2019-10-23	Carie Carroll	carie.carroll@geemail.com	Charleston	South Carolina	869949085196656015	7666dd804dcb482ff5cc601d31dc253d	Discover	32.8314614100843656	-79.9317939097676486
4281	2019-10-23 12:27:26	2019-10-23	Cornelious Raynor	cornelious.raynor@geemail.com	Milwaukee	Wisconsin	4507514576530057	2fdf2428c0f379f6d18b2ceab5ee91fa	VISA 16 digit	42.9957870609212662	-88.0418441463828145
4282	2019-10-23 12:45:52	2019-10-23	Luciano Renner	luciano.renner@warmmail.com	Rochester	New York	180005838427521917	f4afa5fd1fee6eccf73d802fa94e45f0	American Express	43.0785089766584335	-77.6299795154720584
4283	2019-10-23 13:40:38	2019-10-23	Hudson Quigley	hudson.quigley@geemail.com	Amarillo	Texas	210092598847657824	0f34f86df9cbd3d7406419c91827d0a0	VISA 16 digit	35.2984728684347147	-101.817028817054634
4284	2019-10-23 13:43:07	2019-10-23	Dr. Melvina Langosh	dr.melvina.langosh@geemail.com	Sugar Land	Texas	54096000001846539	dc724b6dd76c75f44af60ac5ba0950e9	VISA 16 digit	29.5614412108022719	-95.556202106737345
4285	2019-10-23 15:12:04	2019-10-23	Colon Beier	colon.beier@geemail.com	Berkeley	California	869905193443038623	7ec6e18e656110ac93ee3e4574221218	JCB 16 digit	37.8598898226401062	-122.293561198144104
4286	2019-10-23 15:32:20	2019-10-23	Miss Nealie Barton DDS	miss.nealie.barton.dds@geemail.com	Washington	District of Columbia	4074170163617	f684ed29f562d782c64ab01a2ede25ee	VISA 16 digit	38.8355780085813223	-77.0112709475427835
4287	2019-10-23 16:22:08	2019-10-23	Salvador Witting-Trantow	salvador.witting.trantow@woohoo.com	Austin	Texas	869985344688719657	251dcc81341ab9d5a4bf0064b1854111	Diners Club / Carte Blanche	30.3976260488048169	-97.7238865845609439
4288	2019-10-23 16:42:07	2019-10-23	Rosemary Ebert	rosemary.ebert@geemail.com	Costa Mesa	California	6011087666542418409	a7b01c3affa5b72dc066740256deb6d3	VISA 16 digit	33.5797655703514835	-117.855330981020998
4289	2019-10-23 17:57:41	2019-10-23	Mrs. Myla Rempel DDS	mrs.myla.rempel.dds@geemail.com	Springfield	Massachusetts	52319020991884465	358ed1159123931f78fc7c2096daef80	JCB 15 digit	42.0594924303907902	-72.4721650851052317
4290	2019-10-23 17:59:06	2019-10-23	Dr. Viva Predovic	dr.viva.predovic@geemail.com	New York	New York	3337949649310690621	55e865a47b7f7cbe65c703b310516f0b	VISA 13 digit	40.6099679309166959	-73.918901468663293
4291	2019-10-23 18:41:54	2019-10-23	Rosaria Swaniawski	rosaria.swaniawski@geemail.com	Oakland	California	869997951557099049	a49a11dcdb0cf66de5436f2ff3d8442d	VISA 13 digit	37.814255084564067	-122.296541233775244
4292	2019-10-23 18:44:58	2019-10-23	Miss Ayesha Mills DVM	miss.ayesha.mills.dvm@geemail.com	Berkeley	California	3112139824382750005	31b6e003c5d5504ee91b5fc2801e8bef	JCB 16 digit	37.827837882258784	-122.253543333181682
4293	2019-10-23 18:50:06	2019-10-23	Miss Bree Larson PhD	miss.bree.larson.phd@geemail.com	Memphis	Tennessee	869906041583227911	7503de2ab3e7e247ec25fe95d1e04aa0	JCB 15 digit	35.1519251808591235	-89.9199081726629288
4294	2019-10-23 19:06:09	2019-10-23	Geraldo Langosh DDS	geraldo.langosh.dds@geemail.com	Columbus	Ohio	4744298532013183	aca0b38f6e609acd2e438c4ca4f6c907	Discover	39.9144777964379642	-83.021277109603588
4295	2019-10-23 21:29:15	2019-10-23	Tomika Botsford	tomika.botsford@woohoo.com	San Francisco	California	3004183469381305	0b7dcf0a5856b40ff7bad3e18108c3a3	Mastercard	37.7811696041963501	-122.372012291662287
4296	2019-10-23 21:37:07	2019-10-23	Princess Wolff	princess.wolff@woohoo.com	Berkeley	California	4081830331740	8c4af0598a49bda9127e8b8edfc3a49b	American Express	37.8975753692400872	-122.282161225022961
4297	2019-10-23 21:51:43	2019-10-23	Othel Wolf	othel.wolf@geemail.com	Raleigh	North Carolina	51301221882603069	308b101456b4409abadd7810099a7dee	Diners Club / Carte Blanche	35.879390512233968	-78.6960500904295657
4298	2019-10-23 22:21:01	2019-10-23	Clara Kassulke	clara.kassulke@warmmail.com	Irving	Texas	675962492537170	161a0dde8750b762e6afe1dfb838bc04	Mastercard	32.9073156345587208	-97.046711059920483
4299	2019-10-23 22:21:28	2019-10-23	Male Wuckert	male.wuckert@warmmail.com	Fresno	California	4525065013496327	4f0c92e3f1e382e85252476609c427fc	Maestro	36.8378016541119635	-119.798269191674521
4300	2019-10-23 23:19:50	2019-10-23	Mr. Justice Williamson III	mr.justice.williamson.iii@warmmail.com	Berkeley	California	869955813256357112	3473705354c8b0cacf2737469983d8f2	VISA 16 digit	37.8677055667294269	-122.284578931522248
4301	2019-10-24 00:05:47	2019-10-24	Elinore Morar-Feest	elinore.morar.feest@woohoo.com	Chicago	Illinois	4722596741976207	c0ff73acf5a8f3156c64b06853d8374b	Maestro	41.7942421282477667	-87.7767396706186247
4302	2019-10-24 00:37:45	2019-10-24	Mr. Emry Hintz Sr.	mr.emry.hintz.sr.@geemail.com	Louisville	Kentucky	54702739829651763	64bf13fb29709f9fd613c940f39b90ce	JCB 16 digit	38.2601597545571579	-85.6553023155383784
4303	2019-10-24 00:58:40	2019-10-24	Mr. Antony Howell DDS	mr.antony.howell.dds@geemail.com	Berkeley	California	4904336732554949	5ac2b997b9ee91df6d0b1a5546ea482f	VISA 13 digit	37.8884886770708107	-122.259984382794102
4304	2019-10-24 01:25:17	2019-10-24	Texie Braun	texie.braun@geemail.com	San Francisco	California	55685400609604560	1219b4cc6a39e76c4bd20d512078dcd0	American Express	37.7836475502056928	-122.388775764892344
4305	2019-10-24 01:44:36	2019-10-24	Amparo Feest MD	amparo.feest.md@woohoo.com	New York	New York	210014738378337058	d361dcbfa3856a8ececab52042b38b70	Maestro	40.747754189720375	-73.8860176008555953
4306	2019-10-24 01:59:37	2019-10-24	Falon Halvorson	falon.halvorson@warmmail.com	New Orleans	Louisiana	4881541811785986	7316acdd8a9d3463f72b9d81c7816a71	Discover	30.1173749625232077	-89.8611053215134916
4307	2019-10-24 03:36:09	2019-10-24	Stone Rice	stone.rice@woohoo.com	Buffalo	New York	4192882632160775	4cf6c9fcdb9a5f7ec77dc2befc567d20	Diners Club / Carte Blanche	42.8671195111889389	-78.7702250465218015
4308	2019-10-24 04:11:15	2019-10-24	Ottie Greenfelder	ottie.greenfelder@geemail.com	Las Vegas	Nevada	4123569129380503	4a3e6c4c40e03cdfa5ab6b64e3b78a98	JCB 15 digit	36.2598199854705499	-115.297119724119455
4309	2019-10-24 05:22:29	2019-10-24	Lemmie Schmidt	lemmie.schmidt@warmmail.com	San Francisco	California	3058739277742404	5e3726277ada695e321d409be0fb0d6d	VISA 16 digit	37.7647966622349571	-122.436859157218208
4310	2019-10-24 05:45:41	2019-10-24	Tommy Quigley-Frami	tommy.quigley.frami@geemail.com	Santa Ana	California	3725439061550647	8c829946baa86d70b800ae5d6c91569c	Discover	33.7056825141526772	-117.819017222190269
4311	2019-10-24 06:48:00	2019-10-24	Esau Yost	esau.yost@geemail.com	Richmond	Virginia	3784013159245671	de1d3dc73aabfb40a898bbb7c772b71d	Voyager	37.556161791108174	-77.4991382325757314
4312	2019-10-24 08:04:58	2019-10-24	Dayne Cole	dayne.cole@geemail.com	Oakland	California	3054714397146269	88b1878f54c654e877ccc5670f5b2a6e	VISA 13 digit	37.8231282078434674	-122.253792261702941
4313	2019-10-24 08:17:20	2019-10-24	Manson Morar	manson.morar@geemail.com	Laredo	Texas	6011277724901565672	fdd8edf97592dc215aba5e78bfba598c	American Express	27.6218734801929457	-99.4783662319656372
4314	2019-10-24 09:11:09	2019-10-24	Watson Goyette-Walsh	watson.goyette.walsh@geemail.com	Brownsville	Texas	3112198658619125146	2a7c0672457812d738fc86f23db5d02e	Discover	26.0754729944825172	-97.5086113922484259
4315	2019-10-24 10:35:02	2019-10-24	Moriah Konopelski	moriah.konopelski@geemail.com	Oakland	California	6011732179636118900	48ec4c76b5298cd92e9dfbc7a2dbbef8	American Express	37.8220049886651921	-122.269068032159666
4316	2019-10-24 11:06:39	2019-10-24	Mr. Harmon Morar	mr.harmon.morar@geemail.com	San Francisco	California	53656456454557035	cb6f76baf6adef9ad1c8ae5338f66327	VISA 16 digit	37.7991008117049176	-122.430972888185721
4317	2019-10-24 11:18:16	2019-10-24	Jacki Carter	jacki.carter@geemail.com	Baltimore	Maryland	3011508026366402	728ccb28829ccf4f92a2e385bc7f776a	JCB 16 digit	39.3636609417386296	-76.696559611383833
4318	2019-10-24 11:22:53	2019-10-24	Kwame Jerde	kwame.jerde@geemail.com	Lexington	Kentucky	3756347902015310	4dadc38145fa02df86ae7c3aead7c649	VISA 16 digit	37.9496252581819888	-84.4775768366541655
4319	2019-10-24 11:49:24	2019-10-24	Dr. Therman Jaskolski	dr.therman.jaskolski@geemail.com	Oakland	California	6011762266079247537	a0bd2034e9a945f2695427cc28f0e1ed	American Express	37.8073159742270732	-122.266911598599123
4320	2019-10-24 12:39:38	2019-10-24	Herma Krajcik	herma.krajcik@geemail.com	Dallas	Texas	4997448619383793	0c2823ec1a4a8321041d9b85f03c08b0	JCB 16 digit	32.8691073174394717	-96.7467328042220203
4321	2019-10-24 13:22:34	2019-10-24	Don Sanford	don.sanford@geemail.com	Pearland	Texas	4988153095279835	f924663b7a14d1f73c4a1ef77368c0bd	Mastercard	29.6124669398918776	-95.341905602146312
4322	2019-10-24 15:10:56	2019-10-24	Dr. Dewey Hilpert	dr.dewey.hilpert@geemail.com	San Francisco	California	676172117654003	db729f1fa4d0866ad46c97a601cc2dda	VISA 13 digit	37.7687237886566933	-122.436383358868525
4323	2019-10-24 15:16:39	2019-10-24	Laurene Champlin	laurene.champlin@warmmail.com	Berkeley	California	3112351380952150291	d1d71c7e45c887af71c20d6fe8d840aa	Discover	37.8626712575347071	-122.280629240218971
4324	2019-10-24 15:41:28	2019-10-24	Davon Berge-Murphy	davon.berge.murphy@geemail.com	Philadelphia	Pennsylvania	4408653279930	58c7a4e724c22182f89750ca07cc8155	Voyager	39.9839401093736271	-75.1140657422497924
4325	2019-10-24 16:41:33	2019-10-24	Ms. Deann Kilback PhD	ms.deann.kilback.phd@geemail.com	Portland	Oregon	676352501508999	18401b5539736c5dc43b7086c4966ee7	JCB 15 digit	45.556030199013648	-122.614482391905042
4326	2019-10-24 16:57:45	2019-10-24	Milburn Ferry	milburn.ferry@geemail.com	San Francisco	California	6011811824450983871	12203e0643a478d9ffe1e9632ee63b0a	Discover	37.7846873302226172	-122.402592152896077
4327	2019-10-24 18:08:27	2019-10-24	Chet Lakin DVM	chet.lakin.dvm@geemail.com	Berkeley	California	676207191669147	5c36d854101a5b89dbe41e7aad76100f	Discover	37.8820136248576489	-122.281940866945192
4328	2019-10-24 18:18:25	2019-10-24	Mrs. Dorothy Reilly DVM	mrs.dorothy.reilly.dvm@geemail.com	Bakersfield	California	6011594700626931437	e99bed081e702a8ab4b81faf290daa85	American Express	35.3425760853745032	-119.035454866177588
4329	2019-10-24 18:27:38	2019-10-24	Clem Kerluke	clem.kerluke@geemail.com	Oakland	California	3727693230894835	34ffe8ea6da3f25f1e6287b1773b7411	Maestro	37.7878180644427317	-122.268187168178642
4330	2019-10-24 18:28:18	2019-10-24	Hugh Dickinson	hugh.dickinson@geemail.com	San Francisco	California	3745998012924751	f85419ff55a893d868d0a648037d5192	VISA 16 digit	37.7393338266182852	-122.434327427303785
4331	2019-10-24 20:59:00	2019-10-24	Mr. Westin Schimmel	mr.westin.schimmel@geemail.com	Winston–Salem	North Carolina	6011991680851227702	5286d4e18029edd4148d3c3641e4699e	VISA 13 digit	36.1704390057593557	-80.1674549969509229
4332	2019-10-24 21:22:36	2019-10-24	Latrice Welch	latrice.welch@geemail.com	San Francisco	California	3400606622812448	d7cf6ea95540dafb5f2a2edda180e20e	JCB 16 digit	37.730787419105468	-122.427867169759651
4333	2019-10-24 22:25:22	2019-10-24	Minda Aufderhar	minda.aufderhar@warmmail.com	Rochester	New York	4931067956563095	cdbd8cd0fb0a99bb13cfb8e1cea73844	Diners Club / Carte Blanche	43.1751398269530355	-77.522396872495861
4334	2019-10-24 22:30:23	2019-10-24	Cherie Bechtelar	cherie.bechtelar@geemail.com	San Francisco	California	4076941967390	ad12627a92b9c19fba8e49ab374b046c	JCB 16 digit	37.7809149749774775	-122.43351238928085
4335	2019-10-24 22:32:03	2019-10-24	Allena Nikolaus PhD	allena.nikolaus.phd@geemail.com	San Francisco	California	4856067383625732	a78d3ca8091bb66df1c2d197dee8536e	Maestro	37.7798833324329024	-122.414190491851357
4336	2019-10-25 00:25:24	2019-10-25	Osborn Fisher-Prohaska	osborn.fisher.prohaska@geemail.com	San Francisco	California	3400838736758890	11831b32cbb6841159b764e65a757cab	JCB 16 digit	37.7573739352181335	-122.455362117080938
4337	2019-10-25 00:26:31	2019-10-25	Mrs. Bridgett Oberbrunner DDS	mrs.bridgett.oberbrunner.dds@geemail.com	San Francisco	California	3710249665453107	6f9418b459efa7e64ee5cc0bc691bb72	Voyager	37.8058802094135729	-122.407863227380659
4338	2019-10-25 00:36:38	2019-10-25	Dr. Larry Gerhold III	dr.larry.gerhold.iii@geemail.com	Anaheim	California	180046921007465928	3fb85ae54949e39f9bddd8893b632639	VISA 16 digit	33.7677190011665189	-117.684519443588698
4339	2019-10-25 01:20:49	2019-10-25	Leander Schaden-Maggio	leander.schaden.maggio@geemail.com	Escondido	California	3528375785316367096	898e8d2310b25a8b7b7f58b127357cd1	Mastercard	33.0801112246926863	-117.007597832499073
4340	2019-10-25 01:50:57	2019-10-25	Dr. Geraldo Oberbrunner	dr.geraldo.oberbrunner@geemail.com	Oakland	California	869906413024148065	bd37f6db735126e6310026e44705b2aa	VISA 16 digit	37.7956924923116091	-122.339789091238657
4341	2019-10-25 03:03:45	2019-10-25	Dannielle Kutch	dannielle.kutch@geemail.com	San Francisco	California	869936287418851961	8280128a89f226213d54de7a3a5236ac	Voyager	37.8025686033148602	-122.436450379767621
4342	2019-10-25 03:49:33	2019-10-25	Ilene Hoppe	ilene.hoppe@geemail.com	San Francisco	California	060478059738787	f60ad3ac797a31c25e0ebe3927568a01	VISA 13 digit	37.7490269104947842	-122.446653480967939
4343	2019-10-25 05:08:19	2019-10-25	Mistie Mertz	mistie.mertz@geemail.com	Philadelphia	Pennsylvania	180058333871229569	ecb4e9c433b4e9bbc6759e321462ebf8	Maestro	40.0984597840771073	-75.0829737804263857
4344	2019-10-25 05:27:22	2019-10-25	Mauricio Harvey	mauricio.harvey@geemail.com	Denver	Colorado	6011453991750624399	09fbe181719d926e80cd649b1866286c	JCB 16 digit	39.7336358776368144	-104.909871874634547
4345	2019-10-25 05:36:06	2019-10-25	Williams Erdman-Rohan	williams.erdman.rohan@geemail.com	Dallas	Texas	3112852381962406271	eb718f3113305029baecb96da7fbbe96	Maestro	32.70272191700451	-96.7150457205679146
4346	2019-10-25 05:53:14	2019-10-25	Mr. Tre Schultz	mr.tre.schultz@woohoo.com	Vista	California	4317330092918282	e83be59a92ec0edf36bafa169e85fe9c	Diners Club / Carte Blanche	33.1260196448285171	-117.212128074007481
4347	2019-10-25 06:07:31	2019-10-25	Mr. Gustavo Kunze	mr.gustavo.kunze@woohoo.com	Louisville	Kentucky	3158270244703657004	ad6884a761ba9f251a857a6c06527285	JCB 15 digit	38.1338097628574815	-85.6856355254143551
4348	2019-10-25 06:46:11	2019-10-25	Caden Hoppe	caden.hoppe@geemail.com	San Francisco	California	4499847785802515	d0774cf2654e8508de7dfbb2b3dfc522	Mastercard	37.7784463510680837	-122.416750965798897
4349	2019-10-25 06:52:12	2019-10-25	Carrol Gutmann-Hegmann	carrol.gutmann.hegmann@geemail.com	Honolulu	Hawaii	3158851006289130533	be4a3d8868095d8948ab920d8978e2c7	JCB 15 digit	21.2745528862096371	-157.936024591487268
4350	2019-10-25 06:58:38	2019-10-25	Auston Willms DVM	auston.willms.dvm@geemail.com	Oakland	California	3703919763452198	4cfd3a4176dbee4182b193c3ac5c17c4	JCB 16 digit	37.7860540437410108	-122.246245383002986
4351	2019-10-25 09:31:17	2019-10-25	Madalyn Dare	madalyn.dare@geemail.com	San Francisco	California	869919627829208148	37d6c40795df2da1d3c66be9b5a897d5	VISA 16 digit	37.7663969520794538	-122.44927361667753
4352	2019-10-25 09:44:21	2019-10-25	Anibal Stroman-Hodkiewicz	anibal.stroman.hodkiewicz@geemail.com	San Francisco	California	3494804598898080	ddd85eeb5ecb5d39a33f77dc27faf662	VISA 13 digit	37.7738528405129017	-122.432777752601226
4353	2019-10-25 10:06:16	2019-10-25	Hayden Hermiston	hayden.hermiston@warmmail.com	San Francisco	California	4950698849397089	8de09feccd4375f261ec44ee8f6c0cbd	JCB 16 digit	37.7765294380202477	-122.443825550856246
4354	2019-10-25 10:16:49	2019-10-25	Mr. Jamel Kilback V	mr.jamel.kilback.v@geemail.com	Bellevue	Washington	4225912416437130	4ac5aaff0dbbe210555b042d85baa04b	Mastercard	47.5042041929155587	-122.246076194807884
4355	2019-10-25 10:30:00	2019-10-25	Khloe Lesch	khloe.lesch@geemail.com	Cary	North Carolina	6011444937165774255	9ba1b50d8aedcf448c784435669a94d0	JCB 16 digit	35.8556749151196357	-78.8781528862278947
4356	2019-10-25 10:38:20	2019-10-25	Reynaldo Jerde	reynaldo.jerde@geemail.com	Berkeley	California	3112900407467813547	35f6cd1a8ddcda3887039dc4955c5c8a	Diners Club / Carte Blanche	37.864270564354868	-122.277750157981174
4357	2019-10-25 11:01:53	2019-10-25	Coleman Morar-Jones	coleman.morar.jones@geemail.com	Fort Wayne	Indiana	4806510706322850	bf4959f18673036152b2cded8dc40856	JCB 16 digit	40.9917548778250804	-85.1854446215774885
4358	2019-10-25 11:02:56	2019-10-25	Kaela Gusikowski	kaela.gusikowski@geemail.com	Brownsville	Texas	3052823541579861	9d494239c58fa45be9c529f0b62daa9c	American Express	26.0701019689053268	-97.5502744131442086
4359	2019-10-25 11:19:00	2019-10-25	Masao McKenzie	masao.mckenzie@geemail.com	New York	New York	4284689180966	f1616eb0dc7c52b557b6c1577da6c797	Voyager	40.6048257623557021	-73.9033480767056261
4360	2019-10-25 11:35:48	2019-10-25	Stephania Bruen DVM	stephania.bruen.dvm@geemail.com	Washington	District of Columbia	4566259099491209	236df57b0ab4cb80060b9df8d0f7e165	Diners Club / Carte Blanche	38.8940067832157013	-77.075090882948416
4361	2019-10-25 14:04:29	2019-10-25	Dr. Ott Kovacek	dr.ott.kovacek@geemail.com	San Francisco	California	4439307982353336	2ed5d1d5081154299d574c90f7f1a04d	American Express	37.7943094997189206	-122.442713928941515
4362	2019-10-25 14:21:21	2019-10-25	Darian Gerlach	darian.gerlach@warmmail.com	Waco	Texas	502084416160491	83d575aab94f267ba96083013e1f6222	Voyager	31.6306134302377693	-97.1633597763385666
4363	2019-10-25 14:37:57	2019-10-25	Robert O'Kon DVM	robert.o'kon.dvm@geemail.com	Berkeley	California	869931349067580112	036046b7f4bf698ac4fae96022856c73	Maestro	37.8654769301194705	-122.233155857525446
4364	2019-10-25 14:46:40	2019-10-25	Tanner Terry	tanner.terry@geemail.com	Boise	Idaho	51099382690817196	0da28aadeaf77c70625cd3e7fa2e3b58	Mastercard	43.6001091804027539	-116.313374528634185
4365	2019-10-25 15:51:57	2019-10-25	Natalie Ward	natalie.ward@geemail.com	San Francisco	California	3002476192511137	b765e1a2155455ec549a0b473d805b0f	Maestro	37.7575494207953994	-122.443144904083169
4366	2019-10-25 15:54:36	2019-10-25	Branden Yost DVM	branden.yost.dvm@geemail.com	Nashville	Tennessee	3476547437706699	5a654b34aa116aacbc6a4a4135dee1d6	Discover	36.1874054735649366	-86.7111202847585076
4367	2019-10-25 17:14:22	2019-10-25	Adron King MD	adron.king.md@geemail.com	San Francisco	California	869978476124098335	0ab61d9207c0278eadca71373b2820ea	Voyager	37.7958625195120987	-122.453016593599557
4368	2019-10-25 17:45:55	2019-10-25	Dr. Page Kling Sr.	dr.page.kling.sr.@woohoo.com	San Francisco	California	3035401536431013	17da893c1f4f6e9668f5b8814fd31f70	Diners Club / Carte Blanche	37.7681849096482196	-122.445854430256119
4369	2019-10-25 17:52:29	2019-10-25	Mr. Denny Stokes	mr.denny.stokes@warmmail.com	Portland	Oregon	210090786294226100	1ee382b759eb9a0f15664778996f6544	VISA 16 digit	45.6075187623854745	-122.550547687662771
4370	2019-10-25 18:13:30	2019-10-25	Adaline Heidenreich	adaline.heidenreich@geemail.com	Berkeley	California	3528909341665879516	3a2dabf73c29ecc2fba1e6b6cd754cfe	Discover	37.8639753523814733	-122.256161873241467
4371	2019-10-25 19:10:28	2019-10-25	Emory Schmeler	emory.schmeler@geemail.com	Phoenix	Arizona	3528426030996788546	a215609664f9484ea342d8693980ea76	JCB 16 digit	33.5983615158524387	-112.182206552748013
4372	2019-10-25 20:24:34	2019-10-25	Miguel Prohaska	miguel.prohaska@geemail.com	Berkeley	California	869909659105094365	1fbd6c06bea1f0e532e89ae98bf7cbe6	Mastercard	37.9049729722128887	-122.221887050325648
4373	2019-10-25 20:35:55	2019-10-25	Mrs. Jaycee Yundt PhD	mrs.jaycee.yundt.phd@warmmail.com	Orlando	Florida	060474158384573	b719fa6793cf96d340e095712fd7b487	JCB 15 digit	28.3377867133155448	-81.2087538955699699
4374	2019-10-25 21:41:45	2019-10-25	Mr. Domingo McLaughlin Jr.	mr.domingo.mclaughlin.jr.@geemail.com	West Valley City	Utah	210064174306641016	18ce122b832da1fa31c30f80df17b7b7	VISA 16 digit	40.7813566107060765	-111.932214177840564
4375	2019-10-25 22:03:16	2019-10-25	Mr. Felipe Lowe Sr.	mr.felipe.lowe.sr.@geemail.com	Tacoma	Washington	4858186866227366	968d7a6a0737ebb9257287cd5e559b06	JCB 16 digit	47.3415190093338509	-122.366611846140771
4376	2019-10-25 23:03:16	2019-10-25	Korbin Corwin	korbin.corwin@geemail.com	San Antonio	Texas	6011575684541654352	41f174d055e63761260c8f079c2dd248	JCB 15 digit	29.5520410813462	-98.5638091319076608
4377	2019-10-26 01:15:14	2019-10-26	Ms. Astrid Spinka	ms.astrid.spinka@woohoo.com	Inglewood	California	3112183558818367332	071b5ed9707f5a736ca6595a114ed2b0	VISA 16 digit	34.0310885862227508	-118.309546012248106
4378	2019-10-26 01:23:21	2019-10-26	Inell Klein-Wiza	inell.klein.wiza@geemail.com	Los Angeles	California	180002433545843154	2fbe51292546c381c5caca53f45d2678	Diners Club / Carte Blanche	34.0859822548791769	-118.439957003434372
4379	2019-10-26 01:24:36	2019-10-26	Ema Emard DVM	ema.emard.dvm@geemail.com	New York	New York	51806039562859599	641fdf92146e829f1313b3c005d1908e	JCB 16 digit	40.7288838739264776	-73.908638723975784
4380	2019-10-26 01:28:29	2019-10-26	Arnav Bednar	arnav.bednar@geemail.com	Henderson	Nevada	676309106713291	4145669010589a51ad1a5390b52d61b1	JCB 15 digit	35.9351781440366054	-115.128309802354138
4381	2019-10-26 01:54:27	2019-10-26	Mrs. Marylee Zemlak	mrs.marylee.zemlak@woohoo.com	Brownsville	Texas	4854912145083	ce7964ce4666ac3f5e58a35a4737220a	VISA 16 digit	26.0367580491196335	-97.4420267252903471
4382	2019-10-26 03:02:15	2019-10-26	Orrie Hane-Spencer	orrie.hane.spencer@woohoo.com	San Francisco	California	3096291278394514285	7ef2cd06cd244b710e3bd0863cbbec7c	VISA 16 digit	37.7671806913178187	-122.433909621830423
4383	2019-10-26 03:02:15	2019-10-26	Isham Kiehn-Olson	isham.kiehn.olson@geemail.com	Seattle	Washington	6011525706820592028	dae3c61ef3c67fa79cafa01477b4f211	JCB 15 digit	47.6456258438453091	-122.266958550402521
4384	2019-10-26 03:26:54	2019-10-26	Pearley Murazik II	pearley.murazik.ii@geemail.com	San Francisco	California	180012715672686705	d56d0006d5807a0081b2bbac9396583d	Maestro	37.763803812352549	-122.426327181662415
4385	2019-10-26 03:39:27	2019-10-26	Alexus Kuphal	alexus.kuphal@woohoo.com	Houston	Texas	676244796872024	281a8bf32bf0c0b210d57da3b6060afc	Mastercard	29.7680327390398816	-95.3091756769470919
4386	2019-10-26 04:30:39	2019-10-26	Summer Lebsack	summer.lebsack@geemail.com	New York	New York	4383718969262645	abf25f2526b5a5abcdfe4056144857a3	VISA 16 digit	40.6422305227480791	-74.037161108049375
4387	2019-10-26 05:54:23	2019-10-26	Dr. Eliseo Rau V	dr.eliseo.rau.v@geemail.com	San Francisco	California	4457417811929995	7d88160f7ccdfc5ddc7b0ce08bc19240	American Express	37.7816359950391529	-122.430186655815461
4388	2019-10-26 06:26:19	2019-10-26	Armando Hand	armando.hand@woohoo.com	Charlotte	North Carolina	53105835867788971	8b40cc5f62d975ed9602f267456bb578	VISA 13 digit	35.2511328036218856	-80.9148234880939157
4389	2019-10-26 07:08:04	2019-10-26	Fate Cummerata	fate.cummerata@geemail.com	Phoenix	Arizona	3705362100309284	856c3990938a40a4b9df9b01c26e8ab8	Maestro	33.6587409844089294	-112.029751588350535
4390	2019-10-26 07:34:53	2019-10-26	Burrel Connelly	burrel.connelly@geemail.com	Daly City	California	4875373612759806	8b275415d6746b55bd302e546bf285c5	VISA 16 digit	37.6955542158722849	-122.386407003188509
4391	2019-10-26 07:49:24	2019-10-26	Quinn Lubowitz	quinn.lubowitz@geemail.com	Indianapolis	Indiana	210079205698732956	8956bdcb95edbd4cb84c845ef837f04b	JCB 16 digit	39.713411962241679	-86.1533507802724756
4392	2019-10-26 08:27:27	2019-10-26	Helene McKenzie-Kerluke	helene.mckenzie.kerluke@warmmail.com	San Francisco	California	3037083945992781	1fd15d8a0268ffe16182ac609d916afe	VISA 13 digit	37.7698666726815233	-122.409779466880735
4393	2019-10-26 08:30:05	2019-10-26	Mrs. Joselin West	mrs.joselin.west@geemail.com	San Francisco	California	4800195365641	76190f029fe3835332d30e4dec1e6811	Maestro	37.7804707488150555	-122.404931959062154
4394	2019-10-26 08:38:00	2019-10-26	Breonna Yundt-Price	breonna.yundt.price@geemail.com	Pompano Beach	Florida	3096988922168745330	cd620fddb6f2d36c5cd781ea78085174	American Express	26.2551168678127205	-80.1563875316955148
4395	2019-10-26 08:53:38	2019-10-26	Mr. Keagan Kunze	mr.keagan.kunze@geemail.com	San Francisco	California	3728002704174048	f28ba1fe43ded5a804dc1aa28ccec0be	VISA 13 digit	37.7621707030693941	-122.431796753501402
4396	2019-10-26 08:57:13	2019-10-26	Ms. Treena Hickle	ms.treena.hickle@geemail.com	Chandler	Arizona	676167514881928	f711dba783b6a0c20a3c45c9f7632f35	Discover	33.1892305426854648	-111.766864566679672
4397	2019-10-26 09:08:15	2019-10-26	Dr. Hughey Marks Jr.	dr.hughey.marks.jr.@geemail.com	San Francisco	California	4906011763546720	e6f39a80974fb6596c3d8d8d89820a84	VISA 13 digit	37.7920309987390723	-122.406316099117888
4398	2019-10-26 09:31:45	2019-10-26	Malissie Kutch	malissie.kutch@geemail.com	Jersey City	New Jersey	630437037295310	5ca8b70d7811c99ad91584ab604d8afa	JCB 15 digit	40.6876242344208023	-74.1056426506444836
4399	2019-10-26 11:52:56	2019-10-26	Keeley Leuschke	keeley.leuschke@geemail.com	Santa Ana	California	3764696455003374	f64a156182e0a7fc562e1c695a5bd0f8	VISA 16 digit	33.659626005693525	-117.974690207319327
4400	2019-10-26 11:57:55	2019-10-26	Ruie Stehr	ruie.stehr@geemail.com	San Francisco	California	4401616187692619	846ce1165f55fd31ed01d57ba9d0b93f	Diners Club / Carte Blanche	37.7686745424237387	-122.373738552359342
4401	2019-10-26 12:34:20	2019-10-26	Mrs. Classie Lynch	mrs.classie.lynch@geemail.com	San Francisco	California	3528954769234948467	5ce32d5e282331c37e0537592475b3c9	Discover	37.7781237356946136	-122.432440096827932
4402	2019-10-26 13:03:33	2019-10-26	Mr. Asberry Daugherty	mr.asberry.daugherty@geemail.com	Oakland	California	869995311995185870	38397c0b15493a38b7e5c4f627b3385e	JCB 16 digit	37.8125877417784366	-122.27665335435286
4403	2019-10-26 13:05:55	2019-10-26	Dr. Anibal Grady V	dr.anibal.grady.v@geemail.com	Fresno	California	4704893404787	9653b6a602331de4fcf88b3e2277256d	Discover	36.702678102754426	-119.803887399110579
4404	2019-10-26 14:12:10	2019-10-26	Ms. Bertina Batz MD	ms.bertina.batz.md@geemail.com	Bridgeport	Connecticut	6011758150826833284	c4a69f187924c831937dc418a6ad3410	Voyager	41.0900089831255357	-73.1325156660650038
4405	2019-10-26 14:51:54	2019-10-26	Mrs. Norene Quitzon DVM	mrs.norene.quitzon.dvm@woohoo.com	Denver	Colorado	3467909558221877	32a90fe9bef65568dba2650502e51711	Maestro	39.6975296961195738	-104.806868815074125
4406	2019-10-26 15:01:20	2019-10-26	Kingston Marvin IV	kingston.marvin.iv@geemail.com	Chicago	Illinois	52650707593136222	1ace8319a8f816f2f112dfdef7a75330	Voyager	41.8071310691371565	-87.6628361415613426
4407	2019-10-26 15:05:44	2019-10-26	Dr. Lulla Bins	dr.lulla.bins@geemail.com	Denver	Colorado	4541284429514	e94ea0a865b4a4a6a97440ac811dad02	Mastercard	39.8451641098182634	-104.951412503818432
4408	2019-10-26 15:22:49	2019-10-26	Akeelah Schmitt	akeelah.schmitt@geemail.com	San Francisco	California	3017357165512937	a7fa4c47f14b40a7b7ad998c6ce2864a	Voyager	37.7967702718509102	-122.428152597652655
4409	2019-10-26 15:28:03	2019-10-26	Mr. Nakia West	mr.nakia.west@geemail.com	San Francisco	California	55226835805743041	8cc7fa0982510b9c5d12c2ce4ab0a90f	Voyager	37.7660410410110998	-122.423144648002776
4410	2019-10-26 15:44:02	2019-10-26	Hale Nikolaus	hale.nikolaus@geemail.com	Oakland	California	869914434213746451	f03820c91af3721e04d9245e9975a27b	Maestro	37.8281602985508343	-122.280727352878358
4411	2019-10-26 16:35:09	2019-10-26	Rupert Deckow	rupert.deckow@geemail.com	Berkeley	California	53202790559414471	f18ccf8c3d0672a08b4d02af461a76d1	JCB 15 digit	37.8611088293430598	-122.244080196414615
4412	2019-10-26 18:23:00	2019-10-26	Ernestina Jenkins DDS	ernestina.jenkins.dds@geemail.com	Fort Lauderdale	Florida	869977279230948596	a10ca18a30f5cba213c280423e83146a	Diners Club / Carte Blanche	26.1989609766740372	-80.0671522112384366
4413	2019-10-26 18:31:47	2019-10-26	Benjaman Schinner	benjaman.schinner@geemail.com	Santa Rosa	California	503891187997969	9d55873d2c04f1fe7435ec50884f37bd	VISA 16 digit	38.4768408426206605	-122.797579501500735
4414	2019-10-26 18:36:22	2019-10-26	Kori Stiedemann	kori.stiedemann@geemail.com	San Francisco	California	6011453089938733578	60934ebdc1648fbd04eb4f0c2c7877ec	VISA 16 digit	37.7585841316989814	-122.417745589781248
4415	2019-10-26 18:47:52	2019-10-26	Mrs. Kia Kovacek	mrs.kia.kovacek@geemail.com	Oakland	California	6011618009829087340	ae76c034473f1147efa1d3c22698e071	Discover	37.8056988205227498	-122.244873744037008
4416	2019-10-26 19:00:33	2019-10-26	Dr. Jerimy Harvey	dr.jerimy.harvey@geemail.com	Oakland	California	501839462756956	cdcde83988644368d393654cb36b2928	JCB 15 digit	37.797492832747082	-122.217521195508908
4417	2019-10-26 19:37:45	2019-10-26	Keeley Nienow	keeley.nienow@geemail.com	Washington	District of Columbia	55404206748672339	4f413eac585df6378117b643954b43f1	Voyager	38.9282709175985318	-76.960277970994639
4418	2019-10-26 19:59:58	2019-10-26	Roby Spinka	roby.spinka@geemail.com	San Jose	California	4853811423157369	0d174561f23e8efdbba0b326a6e3947c	Diners Club / Carte Blanche	37.3572089420452755	-121.916117007447028
4419	2019-10-26 20:15:38	2019-10-26	Desirae Corkery	desirae.corkery@geemail.com	Richmond	Virginia	210057328056425470	cfff7257e19229c7b10315002bed06fc	VISA 16 digit	37.4991920851390788	-77.5352296110931718
4420	2019-10-26 21:18:42	2019-10-26	Arielle Swift MD	arielle.swift.md@geemail.com	Berkeley	California	3473677644959998	7845dceb38c7ed4dc663b176a2fa1517	JCB 16 digit	37.8639474249549863	-122.285190733248697
4421	2019-10-26 21:36:19	2019-10-26	Sage Doyle	sage.doyle@geemail.com	Eugene	Oregon	869921821139710994	e59b35334e11df760930c7023f38d55d	VISA 13 digit	43.9659416422907228	-123.11571292909683
4422	2019-10-26 21:58:50	2019-10-26	Mr. Ethen Daugherty Sr.	mr.ethen.daugherty.sr.@geemail.com	Austin	Texas	4302718225502949	b4aee3328fd38096e6618667fbdb7423	Voyager	30.3006980729881654	-97.8126089257426656
4423	2019-10-26 22:03:17	2019-10-26	Gaetano Wilkinson	gaetano.wilkinson@woohoo.com	San Francisco	California	55303661253811791	c05c411856d62c52986fec87d0557728	Diners Club / Carte Blanche	37.7710572968864469	-122.417344539556197
4424	2019-10-26 22:15:08	2019-10-26	Ervin Lehner	ervin.lehner@woohoo.com	Clovis	California	3422615612010628	707905f25f27d7b95bb46a84c5022523	Diners Club / Carte Blanche	36.8716656657278534	-119.585330453475564
4425	2019-10-26 22:33:01	2019-10-26	Miss Chasity Wolf DVM	miss.chasity.wolf.dvm@geemail.com	Montgomery	Alabama	3088218968570856811	8ebae27af1621081fc87e1c5ebda6860	JCB 16 digit	32.3948301108952634	-86.3114777143265997
4426	2019-10-26 22:53:32	2019-10-26	Nayeli Kohler	nayeli.kohler@geemail.com	Tulsa	Oklahoma	4309818034699184	c4befed9f6bced30b053337dcea69708	American Express	36.101702058212453	-95.8712974194858134
4427	2019-10-26 23:32:19	2019-10-26	Lylah Yundt	lylah.yundt@geemail.com	San Diego	California	676117712508385	57d4649edfbeda3575dc97ea761b94eb	American Express	32.8995174394056207	-117.054838526239621
4428	2019-10-27 01:11:54	2019-10-27	Dr. Eunice Heathcote MD	dr.eunice.heathcote.md@geemail.com	San Francisco	California	060449122615559	912c9542381c30107a74019201554915	JCB 15 digit	37.7611804331986392	-122.413120131031121
4429	2019-10-27 01:59:15	2019-10-27	Dr. Talmage Kub DVM	dr.talmage.kub.dvm@geemail.com	Tucson	Arizona	4971500514246994	c576aa65fc99ea54f118cc1bce9979d8	American Express	32.2021696324501221	-110.828220331039645
4430	2019-10-27 04:38:30	2019-10-27	Nery Baumbach-Bruen	nery.baumbach.bruen@woohoo.com	San Francisco	California	869966850862147047	5f84b14ed082df723580b7cca375f661	JCB 15 digit	37.7956200690945323	-122.403515758429833
4431	2019-10-27 04:55:45	2019-10-27	Jaycee Carter	jaycee.carter@geemail.com	San Francisco	California	3025584964857286	ae6dcdeaa4170d58bfa3d1582f00da33	JCB 15 digit	37.7450876766031556	-122.423850655351117
4432	2019-10-27 05:06:59	2019-10-27	Leisha Cronin	leisha.cronin@warmmail.com	Carlsbad	California	54268304945878257	bc1f38b17fc583a5aead0906e32350a0	Diners Club / Carte Blanche	33.0382815344199514	-117.196123500799004
4433	2019-10-27 05:41:18	2019-10-27	Vinie Kihn	vinie.kihn@warmmail.com	Indianapolis	Indiana	180005108167900642	51a2a40fcee3fec1e08182bd3aa3d0a6	Diners Club / Carte Blanche	39.6898426573265297	-86.2149456171054425
4434	2019-10-27 05:58:56	2019-10-27	Exie Bruen-Romaguera	exie.bruen.romaguera@geemail.com	Memphis	Tennessee	53173530005910192	13e62809427c82af2fe569736d2562b6	Maestro	35.1583376873351625	-89.8818959235005082
4435	2019-10-27 06:04:44	2019-10-27	Mr. Stanton Treutel	mr.stanton.treutel@geemail.com	San Francisco	California	3158796016758582526	3711d4c3fe963174d610f8f712bfc974	Diners Club / Carte Blanche	37.7629469021281707	-122.478883013511478
4436	2019-10-27 06:16:26	2019-10-27	Dr. Afton Daugherty	dr.afton.daugherty@geemail.com	Berkeley	California	180077892465315255	8e31b6de6bff9885c1abf40c13d550aa	Voyager	37.8464878090731602	-122.268511809427864
4437	2019-10-27 07:02:34	2019-10-27	Lady Mertz	lady.mertz@woohoo.com	Cary	North Carolina	52050271230135630	ebbff5c66796f254af67aff664e605c9	VISA 16 digit	35.8194696013923775	-78.8347706541970297
4438	2019-10-27 07:06:02	2019-10-27	Lonzo Zemlak	lonzo.zemlak@geemail.com	Tucson	Arizona	3158581798843429651	398f2a7862597e9a571d3ad2d7861b73	JCB 15 digit	32.2304356556892415	-110.867402991628637
4439	2019-10-27 07:32:40	2019-10-27	Fritz Bins	fritz.bins@geemail.com	Washington	District of Columbia	869956270467226850	19633b8b967285c6ef04a6af252b8616	American Express	38.8569232454787965	-77.098390243316814
4440	2019-10-27 08:18:01	2019-10-27	Mrs. Audriana Kling	mrs.audriana.kling@geemail.com	San Francisco	California	51329286916585556	f4542e06ca0ab6f4acb4ec792f27cd99	VISA 16 digit	37.7861784139775096	-122.41421684543009
4441	2019-10-27 10:50:49	2019-10-27	Turner Donnelly	turner.donnelly@geemail.com	San Francisco	California	4755395313977747	cf0a0b28bf8e74d402db5d3b4acc3ccd	VISA 16 digit	37.7832612388005629	-122.417589987108471
4442	2019-10-27 10:51:05	2019-10-27	Dr. Elmyra Ryan DVM	dr.elmyra.ryan.dvm@geemail.com	Henderson	Nevada	4636750860547	3873f83967e2a2c3283af209e8df1482	Discover	35.9510179508876107	-115.033669480836764
4443	2019-10-27 11:08:22	2019-10-27	Dakoda Barrows DVM	dakoda.barrows.dvm@geemail.com	San Francisco	California	4889772467536355	fea3fed981ad8cb8435391bfa0bf7d28	JCB 16 digit	37.7870254881924765	-122.462267164446502
4444	2019-10-27 11:42:34	2019-10-27	Maverick Jerde-Skiles	maverick.jerde.skiles@warmmail.com	San Francisco	California	6011944883224776250	26d464c15f985048292890df3a794e44	Voyager	37.7939593127458409	-122.415578348638377
4445	2019-10-27 12:04:34	2019-10-27	Dr. Urijah Pagac	dr.urijah.pagac@geemail.com	Berkeley	California	3759689175718113	e3a6f88a56c820d1aa6da1871a8ee56d	JCB 16 digit	37.9007784484300245	-122.254218993078283
4446	2019-10-27 12:49:05	2019-10-27	Adela Heathcote	adela.heathcote@woohoo.com	Pittsburgh	Pennsylvania	3337168230455057803	62a22c9e1a3d91c0aca9b16e4c73dcc4	JCB 16 digit	40.435945609160882	-80.047682827076315
4447	2019-10-27 13:23:58	2019-10-27	Andria O'Conner	andria.o'conner@warmmail.com	Chicago	Illinois	561279988085068	efb5e98284354a7fb36211169ddc2b3e	VISA 16 digit	41.8558134193833951	-87.7769644379179823
4448	2019-10-27 13:38:02	2019-10-27	Amie Heathcote MD	amie.heathcote.md@geemail.com	San Francisco	California	3057233465992501	8684c824c111b19ac16965fde59afa7a	Voyager	37.8261291405816209	-122.418004515759506
4449	2019-10-27 14:05:12	2019-10-27	Kristoffer Hilpert Sr.	kristoffer.hilpert.sr.@geemail.com	San Francisco	California	060460910204571	19a9ab7d4535dedfa6a7c75914c7a02b	JCB 15 digit	37.707727763213839	-122.414404464623843
4450	2019-10-27 14:12:21	2019-10-27	Andrae Wilderman	andrae.wilderman@woohoo.com	New York	New York	180005900887935795	74890cfb696a9207744cc2576ea8a649	JCB 16 digit	40.692238694870845	-73.8543647110823542
4451	2019-10-27 14:22:18	2019-10-27	Olie Kuhlman	olie.kuhlman@geemail.com	San Francisco	California	3776599779937424	d19d3dcff0239d1908ae11cd8ba50b04	JCB 16 digit	37.788881831697644	-122.448503485077396
4452	2019-10-27 14:34:09	2019-10-27	Dario Schoen	dario.schoen@geemail.com	Los Angeles	California	502055158174585	5fc780d83a9021873ba48f4d52950133	Voyager	33.9621662400528734	-118.421747958892212
4453	2019-10-27 15:39:22	2019-10-27	Loyd Dibbert	loyd.dibbert@woohoo.com	San Francisco	California	4871938444917899	b9a4508aaeae3a6518bff48a01d35127	JCB 16 digit	37.82020064552799	-122.433076081009489
4454	2019-10-27 16:07:48	2019-10-27	Joy Ziemann	joy.ziemann@geemail.com	New York	New York	869922176880156924	e5de248605c178d3e842d5d6ec14032f	VISA 16 digit	40.7149311666600369	-73.9488444189902339
4455	2019-10-27 17:09:56	2019-10-27	Tia Bednar	tia.bednar@geemail.com	Chicago	Illinois	3456074237748775	dcd1211aac82a37a4c3904ac64698463	JCB 15 digit	41.9211282180458298	-87.7517768444057538
4456	2019-10-27 18:42:27	2019-10-27	Arnold Hahn	arnold.hahn@geemail.com	Los Angeles	California	3096901906407586054	cbb1d3944f902be2aa6ec446293ca298	JCB 16 digit	33.9337940503243303	-118.352632198249168
4457	2019-10-27 19:23:21	2019-10-27	Bennie Gutkowski DVM	bennie.gutkowski.dvm@geemail.com	Detroit	Michigan	52095973430991665	7449a124d2eac39ddf098891d18c145c	JCB 16 digit	42.4102578252013771	-83.0867890962053082
4458	2019-10-27 19:31:36	2019-10-27	Dr. Nila Schaefer	dr.nila.schaefer@geemail.com	San Francisco	California	4006508068799416	f8a63876d7bf094959c0c0ddadc20444	American Express	37.7739703305611769	-122.432505589700952
4459	2019-10-27 19:51:29	2019-10-27	Ragna Kertzmann	ragna.kertzmann@geemail.com	Detroit	Michigan	6011162678478119057	3303ed693a117d223d1c5f97e760c5b6	American Express	42.2917856345344347	-83.0894079935856098
4460	2019-10-27 20:16:33	2019-10-27	Jaimie Boyle	jaimie.boyle@geemail.com	Chesapeake	Virginia	3337213763659788877	1e33da195efe9e76a3609ad3a9a19c06	JCB 15 digit	36.6463211736414607	-76.3905443749234081
4461	2019-10-27 20:21:03	2019-10-27	Gregory Walsh IV	gregory.walsh.iv@geemail.com	Berkeley	California	639004921570331	fd83036478b200fc8e0a7a14fa428255	JCB 15 digit	37.8573473421544549	-122.257803163411282
4462	2019-10-27 20:25:20	2019-10-27	Davion Kreiger	davion.kreiger@geemail.com	San Francisco	California	4822437548492610	f6da2ee1a12d38b15b52f0eeca316442	Diners Club / Carte Blanche	37.7501647373081184	-122.416768982676601
4463	2019-10-27 20:43:17	2019-10-27	Anahi Rodriguez	anahi.rodriguez@woohoo.com	San Francisco	California	3777348065671852	54e72eff54794a504b3c5e5af767070c	Diners Club / Carte Blanche	37.7958623657984134	-122.452232444489596
4464	2019-10-27 20:49:12	2019-10-27	Sydnee Rosenbaum-Schamberger	sydnee.rosenbaum.schamberger@warmmail.com	Des Moines	Iowa	4806663376217858	528bbc49e5898f8f511f6c22fa4da633	Mastercard	41.6152628893241285	-93.5794893027327959
4465	2019-10-27 20:50:27	2019-10-27	Lee Fritsch	lee.fritsch@geemail.com	San Francisco	California	51550884832606694	645caaff3a9bc364d4220853a23c46f3	JCB 15 digit	37.7882675459639685	-122.439910453684689
4466	2019-10-27 23:01:44	2019-10-27	Elon Rolfson	elon.rolfson@woohoo.com	Chicago	Illinois	869900859440474293	d11a53eac27996f0f43d1822539727f9	VISA 16 digit	41.8711133508313438	-87.6902128465969071
4467	2019-10-27 23:16:22	2019-10-27	Carla Lindgren MD	carla.lindgren.md@warmmail.com	San Francisco	California	6011456442442573781	428be151d6fb8dc245a2ce5d9b0c0128	Voyager	37.7993498274163215	-122.440250844918737
4468	2019-10-28 00:17:55	2019-10-28	Johnpaul Grady	johnpaul.grady@geemail.com	Orange	California	676198702845086	e6ba7befe346757c7c9259bad9e28ce7	American Express	33.6977781459111725	-117.921071308163178
4469	2019-10-28 00:50:25	2019-10-28	Levar Wolff	levar.wolff@geemail.com	Oceanside	California	869905769620508098	1dd48ad1c6cb523eff995483e7045b6e	JCB 16 digit	33.1251955494172847	-117.31236241823882
4470	2019-10-28 00:52:51	2019-10-28	Ms. Ara Berge	ms.ara.berge@geemail.com	Berkeley	California	180068203044136256	f449059a644afaf8943ee7e4fbf9b29d	Mastercard	37.8818765831953854	-122.283329864618381
4471	2019-10-28 01:46:52	2019-10-28	Mabell Will	mabell.will@geemail.com	Baton Rouge	Louisiana	4603867512094957	eb2477aa357b1ceb21ce082f961dc8c5	JCB 16 digit	30.5314687615938496	-91.1784840974599149
4472	2019-10-28 02:03:14	2019-10-28	Lyda Carter	lyda.carter@geemail.com	Davie	Florida	3158867609481159754	f92b3fe7503583fd85e8fa446d56631d	JCB 16 digit	25.9833837458197046	-80.2285860468074645
4473	2019-10-28 03:07:32	2019-10-28	Miss Stephany Gerhold	miss.stephany.gerhold@geemail.com	Knoxville	Tennessee	3799005325023217	fff31687394568278270c5eef0e89009	Diners Club / Carte Blanche	35.9666278669673929	-83.8648076554045048
4474	2019-10-28 04:08:00	2019-10-28	Lizabeth Hilll-Bashirian	lizabeth.hilll.bashirian@geemail.com	Detroit	Michigan	3791536263252424	f88883242e52577f8ba43ae34df22893	JCB 15 digit	42.3351257748361718	-83.1355170769270444
4475	2019-10-28 05:02:04	2019-10-28	Lockie Watsica	lockie.watsica@warmmail.com	San Diego	California	3732799957091753	b03c0ccba19d62dd7b3783a6bb84fbb6	VISA 16 digit	32.8895359822150297	-117.113094114270069
4476	2019-10-28 05:22:26	2019-10-28	Dusty Fahey	dusty.fahey@warmmail.com	Santa Clara	California	51977414412028450	03676861c09e4037e78ea8a1f3cec1b9	Mastercard	37.3436443197358443	-121.955231284396348
4477	2019-10-28 05:50:22	2019-10-28	Dr. Randolph Schmitt	dr.randolph.schmitt@geemail.com	Berkeley	California	4042899938759	c43e82bcb2f14b475c2d1e663640384c	JCB 16 digit	37.8287189407505551	-122.26938682343085
4478	2019-10-28 06:22:00	2019-10-28	Opha Purdy	opha.purdy@geemail.com	Dallas	Texas	6011129764956342981	3f139f527bf76c36f3c2c15b7e223019	American Express	32.7885723324764555	-96.8041553419977419
4479	2019-10-28 06:41:33	2019-10-28	Jarod Yost-Balistreri	jarod.yost.balistreri@geemail.com	San Francisco	California	3112428321378251502	e83cd69ee1ba8b58bb5cd75bf349f7f0	JCB 16 digit	37.7831587584611128	-122.430670104789229
4480	2019-10-28 07:01:03	2019-10-28	Fredy Gutkowski	fredy.gutkowski@geemail.com	Oakland	California	4383679589086766	9def826f7e99cb26884a308a1824275f	VISA 16 digit	37.7865938711682645	-122.261376878046519
4481	2019-10-28 08:43:57	2019-10-28	Everet Gibson Jr.	everet.gibson.jr.@woohoo.com	Paterson	New Jersey	210064504829089139	11add39f11516b9749a471f471ec2ff4	JCB 16 digit	40.9487341279584882	-74.1548801958534938
4482	2019-10-28 09:02:44	2019-10-28	Mr. Rigoberto Hammes DVM	mr.rigoberto.hammes.dvm@geemail.com	Orange	California	3096827518759589262	cf70c43606e12e956a811c3f4316eafd	American Express	33.8804875036124145	-117.767864521929255
4483	2019-10-28 09:11:12	2019-10-28	Stacy Bahringer	stacy.bahringer@geemail.com	Surprise	Arizona	180063902759329932	859a71c5d7f0f82b0c26f3d930600331	American Express	33.68528077949248	-112.40791217170171
4484	2019-10-28 09:52:33	2019-10-28	Ronny Von	ronny.von@geemail.com	San Francisco	California	4042188353462	60885e3c5c29086f1bc2f963cafe9d28	JCB 15 digit	37.7766898943607927	-122.423841042900733
4485	2019-10-28 10:07:15	2019-10-28	Dr. Acy Gibson V	dr.acy.gibson.v@geemail.com	San Bernardino	California	210031761098649890	99d5c69d284b42958c331fa92d43e147	Discover	34.135133118814224	-117.372104481818525
4486	2019-10-28 11:09:55	2019-10-28	Dr. Brantley Schulist Sr.	dr.brantley.schulist.sr.@geemail.com	Berkeley	California	4464885219699	c0d484e9d796d0af439ddb83faf81dd9	VISA 13 digit	37.8934200036589672	-122.263769041566391
4487	2019-10-28 11:33:34	2019-10-28	Bettie Bradtke	bettie.bradtke@geemail.com	Baton Rouge	Louisiana	6011045942074131442	b32aa651b3b538b7c1c846822d235c01	American Express	30.4736956435468045	-91.0380361180394857
4488	2019-10-28 11:54:55	2019-10-28	Efrain Prohaska-Feeney	efrain.prohaska.feeney@geemail.com	San Francisco	California	4614293364070424	b08d6ed019fd159c5fef1d342c19d895	Mastercard	37.8077179223028494	-122.421735549337683
4489	2019-10-28 12:31:50	2019-10-28	Harl Ward-Gleason	harl.ward.gleason@geemail.com	Phoenix	Arizona	3158165736962598215	8fbaf4bee073854b9d58ddc3956d08e6	Mastercard	33.5318668541431464	-112.159506203506524
4490	2019-10-28 17:17:30	2019-10-28	Alana Kiehn	alana.kiehn@geemail.com	Omaha	Nebraska	3742118548770965	3ddcc21ea0b17d70be3fe3c18ee25a66	VISA 16 digit	41.1675759757548576	-96.0306925918091139
4491	2019-10-28 17:58:41	2019-10-28	Hardin Goyette	hardin.goyette@woohoo.com	San Francisco	California	4760386532730085	ed380717103b81ca24390bfd13f7e54b	VISA 16 digit	37.7804678464465766	-122.414535734296777
4492	2019-10-28 18:21:47	2019-10-28	Savon McClure-Nikolaus	savon.mcclure.nikolaus@woohoo.com	Chicago	Illinois	675962882567159	c3f0d8d71e58e158213be1aee0105e11	JCB 16 digit	41.9226602082908144	-87.5968833101011768
4493	2019-10-28 18:22:59	2019-10-28	Tavion Lowe	tavion.lowe@geemail.com	Sacramento	California	3031743089184646	68d6c887a365bed2625587a2154c28c2	VISA 16 digit	38.6025701702371222	-121.49243591318502
4494	2019-10-28 18:39:20	2019-10-28	Dorene Lang MD	dorene.lang.md@woohoo.com	San Francisco	California	3041464613575767	dfbd7bdef52d020fdf2d3d057fd2b3a7	Discover	37.7810157465321339	-122.417543641082972
4495	2019-10-28 18:42:25	2019-10-28	Brian Feeney IV	brian.feeney.iv@geemail.com	Frisco	Texas	3158611727282474492	9628660c6f55426016b58900cf1646bc	Voyager	33.1439854035615937	-96.847963403884691
4496	2019-10-28 19:05:26	2019-10-28	Eddie Cremin-Kuvalis	eddie.cremin.kuvalis@warmmail.com	San Francisco	California	639027605695769	3f8adbfe11f0c6571df1a26b4d53c3d1	JCB 15 digit	37.794984456129697	-122.444884699533461
4497	2019-10-28 19:17:05	2019-10-28	Elsie Torp	elsie.torp@geemail.com	San Francisco	California	54377044403218392	54045d267677b89ad16132636982b04a	Diners Club / Carte Blanche	37.7751823233397204	-122.422909031383966
4498	2019-10-28 19:31:36	2019-10-28	Launa Schuppe	launa.schuppe@geemail.com	Los Angeles	California	4662687463967300	603a9318b010efdaa1260fc45fc510b2	JCB 16 digit	33.9979378345753958	-118.493606825591243
4499	2019-10-28 19:33:30	2019-10-28	Anabella Conn-Schamberger	anabella.conn.schamberger@geemail.com	Bakersfield	California	060484062197003	a54cccc598d90f7c87799a47dfd06626	Voyager	35.3194532018329923	-118.945178552185368
4500	2019-10-28 20:04:20	2019-10-28	Cora Hauck	cora.hauck@geemail.com	Berkeley	California	869963795291576410	ccf756ed66e39271f2ab6d570fc33fb2	Maestro	37.870595609044301	-122.272349285901257
4501	2019-10-28 20:51:11	2019-10-28	Trystan White	trystan.white@warmmail.com	Berkeley	California	869968392388833006	88f51450392405ee292ebdc79937d0fe	Mastercard	37.863917980847809	-122.275051798449624
4502	2019-10-28 20:53:41	2019-10-28	Rondal Herzog	rondal.herzog@geemail.com	San Francisco	California	676396022338139	1d044065773d3d2cb9e7fc64f36f6b8a	Discover	37.713481839678721	-122.464608333553642
4503	2019-10-28 21:40:43	2019-10-28	Nathan Brown	nathan.brown@warmmail.com	New York	New York	676168325885421	1a44bf3a4bb78a7927d7f2dd61c07dc9	American Express	40.5976490992344878	-73.8408164835430654
4504	2019-10-28 22:17:35	2019-10-28	Deon Marquardt Sr.	deon.marquardt.sr.@geemail.com	San Francisco	California	3733881067136527	b9f10e9bbfee77f6e3c9df0f34b12a49	Diners Club / Carte Blanche	37.7539366006543773	-122.394372564115713
4505	2019-10-28 22:41:45	2019-10-28	Simmie Berge	simmie.berge@geemail.com	Oklahoma City	Oklahoma	4478068539129	45de7a142d8fa31f6842d315d5a03fa3	VISA 13 digit	35.3912759605240126	-97.5270225519675762
4506	2019-10-28 22:46:44	2019-10-28	Tameka Lynch	tameka.lynch@geemail.com	Oakland	California	4779636852476	610eebd191c2fa5bfd62c784a9b21df3	VISA 16 digit	37.7821629608752261	-122.318460654056125
4507	2019-10-28 23:12:09	2019-10-28	Mrs. Caddie Stark	mrs.caddie.stark@geemail.com	New York	New York	869960725533258272	f00dafe12725d45512ccac13296cc446	Voyager	40.667247053164985	-73.9781011644180779
4508	2019-10-28 23:13:30	2019-10-28	Ms. Gerry Ledner PhD	ms.gerry.ledner.phd@warmmail.com	Columbus	Ohio	54806416971564368	8261ee80a921f24e7074004c922557d0	VISA 13 digit	40.0295550404626894	-82.8871924985434987
4509	2019-10-28 23:52:21	2019-10-28	Jermey Waters	jermey.waters@geemail.com	Jacksonville	Florida	3765663432535810	0515af4d409cb06067100337753655f2	VISA 16 digit	30.3195483594719306	-81.6544884267341473
4510	2019-10-29 00:08:18	2019-10-29	Dr. Corliss Rempel PhD	dr.corliss.rempel.phd@geemail.com	Houston	Texas	3013496239117200	610ebfbc25dd6f2a92f0cc5e5bff8cd8	VISA 13 digit	29.8618373095601797	-95.2955893242280894
4511	2019-10-29 00:57:20	2019-10-29	Miss Leonore Macejkovic	miss.leonore.macejkovic@geemail.com	Boston	Massachusetts	3705943451393140	b2f318bbda61c08baea032af4a007b4c	JCB 16 digit	42.2449600777756444	-71.0489885118275879
4512	2019-10-29 01:44:53	2019-10-29	Roderick Crist	roderick.crist@geemail.com	Oakland	California	869973513360191708	55ecede0dbf4766192a549cf92f55b6a	JCB 16 digit	37.7847698278660928	-122.305470088234671
4513	2019-10-29 02:21:36	2019-10-29	Manly Simonis	manly.simonis@geemail.com	San Francisco	California	3056475240349223	5e3274ec61d12c11a7aeb780e21c0459	Maestro	37.7779557651473468	-122.423539441049044
4514	2019-10-29 02:36:51	2019-10-29	Krysta Stroman	krysta.stroman@woohoo.com	Austin	Texas	3033567320685352	35d5c7921b704a51547faa888e6f57f5	American Express	30.3750714262608419	-97.7201577765639939
4515	2019-10-29 02:50:45	2019-10-29	Cortney Koch I	cortney.koch.i@geemail.com	Berkeley	California	4456392749412912	a86b63326dd3093a1bf2ccb11109484e	JCB 16 digit	37.87540495143935	-122.28822318688772
4516	2019-10-29 03:09:04	2019-10-29	Bryson Gottlieb	bryson.gottlieb@geemail.com	San Francisco	California	869996156783827962	4836862734e0b4b9d722682ec3c60131	Discover	37.7363875689328836	-122.377973293633204
4517	2019-10-29 03:22:54	2019-10-29	Anjanette Reichert	anjanette.reichert@warmmail.com	Hartford	Connecticut	3027630623814024	cf033f37e91b6e80c21708d9e9aaece4	American Express	41.7193125597216223	-72.6753223667278974
4518	2019-10-29 04:00:07	2019-10-29	Luka Monahan	luka.monahan@geemail.com	Philadelphia	Pennsylvania	180020613678852936	85ae2cac698b8b5a63ab9f9f27a363c6	Diners Club / Carte Blanche	40.1061982564587112	-75.1434875984575683
4519	2019-10-29 04:00:23	2019-10-29	Devan Harber	devan.harber@geemail.com	Garland	Texas	3158177378177072631	f610c2fff7c6c1da59529e46ce9b3685	American Express	32.8939649123933151	-96.6073694665610816
4520	2019-10-29 04:00:52	2019-10-29	Dr. Manuel Turner	dr.manuel.turner@woohoo.com	St. Petersburg	Florida	630456987711266	840c82a52656ee169dc85faa4cfe763d	JCB 16 digit	27.8239662025477728	-82.5787676152199452
4521	2019-10-29 04:28:28	2019-10-29	Harold Shanahan	harold.shanahan@warmmail.com	New York	New York	869958468889827184	54fc71211904a891d42288c14d637ddf	Voyager	40.6738019492700715	-73.9246737829770808
4522	2019-10-29 05:33:02	2019-10-29	Sallie Graham MD	sallie.graham.md@geemail.com	Rochester	New York	675934853116951	0492cf769aef67dd9a638b5f45c26cb9	Diners Club / Carte Blanche	43.0715586782876372	-77.5796393185161008
4523	2019-10-29 05:38:47	2019-10-29	Amalie Pollich	amalie.pollich@geemail.com	Oklahoma City	Oklahoma	503896941085464	b85bac699382bf4ce11065dc776bd011	JCB 15 digit	35.5061790633857299	-97.5068349584367127
4524	2019-10-29 05:51:39	2019-10-29	Rashida Mueller-Gleichner	rashida.mueller.gleichner@warmmail.com	Berkeley	California	3158746240290586404	4e3feb8dabe935c513b84b6a3587acc6	JCB 16 digit	37.856944829579227	-122.271542988608644
4525	2019-10-29 05:58:12	2019-10-29	Carmine Hackett	carmine.hackett@geemail.com	Oakland	California	4088680423998	d65d8084e2a725ceefc4d9cfb1588758	JCB 16 digit	37.8082981261442939	-122.286974049902327
4526	2019-10-29 06:11:23	2019-10-29	Elizebeth O'Keefe	elizebeth.o'keefe@warmmail.com	Oakland	California	180016069325215710	b9dd3b69f77a3b7c8829e5f5263a8981	VISA 16 digit	37.7995161503542221	-122.282878177062827
4527	2019-10-29 06:24:21	2019-10-29	Ciara Christiansen	ciara.christiansen@woohoo.com	Edison	New Jersey	3088487036620571345	09568f7937ad005b084d89f33fb86bbc	JCB 16 digit	40.4587236550133653	-74.2963049651641398
4528	2019-10-29 06:25:43	2019-10-29	Mr. Erasmus Weissnat	mr.erasmus.weissnat@geemail.com	El Paso	Texas	502044938153648	11355844b538113dbbf74b3c4f0eef9a	American Express	31.8321799486704187	-106.49159205397406
4529	2019-10-29 06:50:55	2019-10-29	Mrs. Meda Corkery	mrs.meda.corkery@geemail.com	Berkeley	California	3048614214703621	98baa60a6c9c808ac0147a46dfa897a0	VISA 16 digit	37.8643727664279197	-122.281117965786066
4530	2019-10-29 08:34:57	2019-10-29	Mordechai Langosh	mordechai.langosh@warmmail.com	Baltimore	Maryland	6011596790979693021	a7eaeda7fd4b870375338eac08e8255e	Mastercard	39.2329868672415571	-76.6618114368543075
4531	2019-10-29 10:28:20	2019-10-29	Mr. Winton Aufderhar III	mr.winton.aufderhar.iii@geemail.com	San Francisco	California	4567160736904	08a593af1e30959a49514ef2433f57ef	VISA 13 digit	37.7733172151558776	-122.446378639387589
4532	2019-10-29 11:36:46	2019-10-29	Mrs. Magnolia Schroeder	mrs.magnolia.schroeder@warmmail.com	Arlington	Texas	3337679789982108860	056a47ba77d948a94e3604798319c949	American Express	32.702806542419637	-97.0674945154253379
4533	2019-10-29 12:42:33	2019-10-29	Dr. Gustavus Treutel	dr.gustavus.treutel@geemail.com	San Francisco	California	3528920288142382843	76790d44567803f3485d7277220f744f	JCB 16 digit	37.759604857167254	-122.43386291004667
4534	2019-10-29 13:37:46	2019-10-29	Dr. Dot Jast	dr.dot.jast@geemail.com	Grand Rapids	Michigan	3112857230911496948	ce3d665351e869d87886a78ea3ccddd0	Mastercard	42.9209076863050427	-85.7287689214240771
4535	2019-10-29 13:48:45	2019-10-29	Ozzie Schaden	ozzie.schaden@geemail.com	Kansas City	Missouri	210029908364375874	23ac169df1e5357302fcef6693936b4b	Diners Club / Carte Blanche	39.0704431504778569	-94.6125575648844261
4536	2019-10-29 15:32:08	2019-10-29	Mr. Ellison Kilback IV	mr.ellison.kilback.iv@geemail.com	San Francisco	California	3528265548916668369	28d5a86f0d3e1ebe5f448e347b7758b3	Diners Club / Carte Blanche	37.7873932154335606	-122.415495031239843
4537	2019-10-29 16:46:24	2019-10-29	Nolie Nitzsche PhD	nolie.nitzsche.phd@woohoo.com	San Francisco	California	3498192138718471	9a1a33083d2a9ee5a770697b4b003040	JCB 15 digit	37.7496904968304818	-122.413630909010308
4538	2019-10-29 16:46:46	2019-10-29	Mrs. Love Bahringer MD	mrs.love.bahringer.md@geemail.com	San Francisco	California	4422207457076140	3830c379880ec57649ed24833f606bf3	VISA 13 digit	37.7794425476911542	-122.435004778994852
4539	2019-10-29 17:16:13	2019-10-29	Dr. Reason Bashirian V	dr.reason.bashirian.v@geemail.com	Memphis	Tennessee	3528317158786961205	0d50df30430615a56873c60fdc0a6d55	American Express	35.0619695973649641	-89.9246438245080384
4540	2019-10-29 20:47:32	2019-10-29	Dr. Lyn Veum	dr.lyn.veum@geemail.com	San Francisco	California	210036492040872597	c26cd5cff1fbce7d171151b08b7723f5	Diners Club / Carte Blanche	37.7743100753914121	-122.436994050779049
4541	2019-10-29 20:50:47	2019-10-29	Willodean O'Keefe	willodean.o'keefe@geemail.com	San Francisco	California	210075438794475485	c03311e8a4932436e7fe1958928b8898	Voyager	37.7835784349492627	-122.444317301159558
4542	2019-10-29 20:53:30	2019-10-29	Leaner Weber	leaner.weber@geemail.com	Henderson	Nevada	4071508653640	4b52fe14cc303c813e440fda901d6da0	Maestro	36.096120797370375	-115.069848216992625
4543	2019-10-29 21:17:21	2019-10-29	Stephanie Grant	stephanie.grant@geemail.com	New York	New York	180035070529833693	d09511a376fb2b048cd83856134c5689	Voyager	40.6531505695302045	-74.0006188407435985
4544	2019-10-29 21:51:33	2019-10-29	Sabina Nitzsche	sabina.nitzsche@geemail.com	Berkeley	California	4983955421208	16e42ec06de6f1d6b4ddc32eca47a478	JCB 15 digit	37.896426552501012	-122.246739062460406
4545	2019-10-29 22:41:29	2019-10-29	Mr. Burl Carroll DVM	mr.burl.carroll.dvm@geemail.com	Worcester	Massachusetts	561256767025952	fdf8ca16d1217a9a5fe6006ecf14709f	VISA 16 digit	42.2164817499164471	-71.7692231624640584
4546	2019-10-30 00:25:04	2019-10-30	Maddux Sanford	maddux.sanford@geemail.com	San Francisco	California	3456557054205275	ff027f334134c684299299201cacb00e	JCB 15 digit	37.7820448520009791	-122.430164716827264
4547	2019-10-30 00:52:25	2019-10-30	Christi Wilderman MD	christi.wilderman.md@geemail.com	Los Angeles	California	676291452954620	9081fbff0f2334818c0a893f811b173f	JCB 15 digit	33.9344510115083295	-118.450168347870175
4548	2019-10-30 01:06:24	2019-10-30	Reed Gutmann-Boyer	reed.gutmann.boyer@geemail.com	Milwaukee	Wisconsin	3037041139385733	a976f8eaa38bdd0b856f86affabdbf86	Voyager	43.0517912128094551	-87.8794341468818487
4549	2019-10-30 01:21:55	2019-10-30	Miss Corene Morar PhD	miss.corene.morar.phd@warmmail.com	New Haven	Connecticut	4687203817717	2674d1598a6af16c64bec2e87906298f	Maestro	41.2509058481540549	-72.8388863471802352
4550	2019-10-30 01:41:04	2019-10-30	Watt Rath	watt.rath@geemail.com	San Francisco	California	4062388669454450	4f4afb1e77240e9820fa2bc53b891eae	VISA 16 digit	37.7612851501605817	-122.428119730065632
4551	2019-10-30 01:43:07	2019-10-30	Kathi Renner	kathi.renner@warmmail.com	San Francisco	California	4085643647220511	5cccc7defbab4928d2063e36f9960364	Discover	37.7507615759765187	-122.402637506132152
4552	2019-10-30 02:59:28	2019-10-30	Ms. Alberta Padberg	ms.alberta.padberg@geemail.com	Berkeley	California	54995449747964399	11daa78f8b1130ba094901d3bd5376a2	JCB 16 digit	37.8850111328585086	-122.273864128027114
4553	2019-10-30 03:03:33	2019-10-30	Kaydence Monahan PhD	kaydence.monahan.phd@geemail.com	New Haven	Connecticut	4811173019421076	c6b3f25ab01a38a7b0120fdc6a886b03	JCB 15 digit	41.3142353186376425	-72.9818834985140654
4554	2019-10-30 03:36:00	2019-10-30	Angella Walker	angella.walker@geemail.com	Des Moines	Iowa	3158289952020800268	91dbe99826a6ee9969aeeb99dfbf78fc	JCB 15 digit	41.6272463236678405	-93.7087088110435786
4555	2019-10-30 04:28:26	2019-10-30	Davie Mante V	davie.mante.v@geemail.com	Chula Vista	California	210007176598690775	d7b7a81b15be8888ce3040d5a77f15f0	JCB 15 digit	32.603385296393931	-117.029556699166818
4556	2019-10-30 04:36:00	2019-10-30	Oswald Torphy I	oswald.torphy.i@geemail.com	Newark	New Jersey	676349594176379	4095342d7baba71b2bcb9b56b5c3a34b	Mastercard	40.7379447061948525	-74.1497402787417172
4557	2019-10-30 05:26:22	2019-10-30	Ms. Georgiana Schimmel PhD	ms.georgiana.schimmel.phd@geemail.com	Lincoln	Nebraska	4739619021631234	57a995a4193bc7366ae6fea64afa7c70	VISA 16 digit	40.8648262344319377	-96.6529128879934518
4558	2019-10-30 05:32:54	2019-10-30	Ms. Leatrice Schultz	ms.leatrice.schultz@geemail.com	Houston	Texas	4890318826942	6ff65ad9b6a37738b64d09a49d0cf873	Diners Club / Carte Blanche	29.8593887704968459	-95.3380391384489911
4559	2019-10-30 07:44:00	2019-10-30	Dr. Garnet Schultz II	dr.garnet.schultz.ii@geemail.com	Dallas	Texas	54164986081875140	d047f9db8755f927f36b5ad07773de25	American Express	32.7764319928169243	-96.6668514065872841
4560	2019-10-30 08:05:18	2019-10-30	Babyboy Kilback	babyboy.kilback@geemail.com	Philadelphia	Pennsylvania	180076446243921388	889cf03b7a199c3ff6d6c8769e7bfe56	VISA 16 digit	40.0712534025736176	-75.1998287381038182
4561	2019-10-30 08:20:43	2019-10-30	Deegan Wolff	deegan.wolff@geemail.com	Austin	Texas	3337896290651293106	f04b9e8f62c87adfa60f395624a0e289	Maestro	30.3205061786469052	-97.7622046001959575
4562	2019-10-30 08:55:38	2019-10-30	Conor Keebler	conor.keebler@geemail.com	San Francisco	California	4822827147155	67468f84d7a0be1991b0edb00a60f68e	Discover	37.7734196704995	-122.430452668818219
4563	2019-10-30 10:15:39	2019-10-30	Delmus Lakin	delmus.lakin@geemail.com	Lewisville	Texas	6011458339847468377	0ebdc02da9f0b1eaa0556ce97cca0a31	VISA 16 digit	33.0047271048635196	-97.0774409579608601
4564	2019-10-30 11:18:51	2019-10-30	Miss Audriana Kessler	miss.audriana.kessler@geemail.com	Jacksonville	Florida	561258953908280	6682b542ae89d904f586f29a9673fdca	VISA 16 digit	30.3589313199330135	-81.6385619359169254
4565	2019-10-30 11:52:29	2019-10-30	Reino Bode DVM	reino.bode.dvm@geemail.com	Houston	Texas	6011388262439507862	f510c5df69fcce22b69116e70f7afcd9	Discover	29.7963833973355605	-95.4584208323169463
4566	2019-10-30 11:55:14	2019-10-30	Savanna Marvin-Grimes	savanna.marvin.grimes@warmmail.com	San Francisco	California	6011524118699964166	c2fc93a686ed0d5b433f515ac07836ae	Mastercard	37.7540429559702275	-122.465696834939834
4567	2019-10-30 12:22:57	2019-10-30	Dr. Zackery Ritchie III	dr.zackery.ritchie.iii@warmmail.com	Philadelphia	Pennsylvania	869987910444930966	d6a2d3bd4372b2d37fa6563289e0b684	VISA 16 digit	39.9121359742671231	-75.0919487918160939
4568	2019-10-30 12:26:33	2019-10-30	Nada Cummerata PhD	nada.cummerata.phd@woohoo.com	San Francisco	California	4098293324509	f554480c434b718a286423a4f73c6d24	VISA 16 digit	37.7656648515702571	-122.453207409774308
4569	2019-10-30 12:31:23	2019-10-30	Isa Emard	isa.emard@geemail.com	Oakland	California	3088025322206603598	dab7b9a67259b542c60033ad63bbcc7d	VISA 16 digit	37.7954452832432395	-122.306558326114882
4570	2019-10-30 12:37:28	2019-10-30	Daria Bosco-VonRueden	daria.bosco.vonrueden@geemail.com	New York	New York	52332002139235068	6dd5840ca1f39b4eb0a3b3e31dac0d6e	Diners Club / Carte Blanche	40.5930400194358043	-74.0321974216856091
4571	2019-10-30 13:19:49	2019-10-30	Mart Stiedemann	mart.stiedemann@geemail.com	San Francisco	California	561253146995039	e03387c5fb923cfebc1f2f95b79518c0	Mastercard	37.7122845532707203	-122.431205198428771
4572	2019-10-30 13:38:32	2019-10-30	Mr. Spencer Keeling Sr.	mr.spencer.keeling.sr.@geemail.com	Portland	Oregon	3096569207119996217	28d05d6ed06559401ebbf2644f957d50	Mastercard	45.5935217937808446	-122.601911056786776
4573	2019-10-30 14:19:15	2019-10-30	Zadie Anderson	zadie.anderson@geemail.com	Jurupa Valley	California	4505434622294	89568e7bdb3a3cbe01aa3fe265692cf0	Diners Club / Carte Blanche	34.100523115966844	-117.540404241254933
4574	2019-10-30 14:22:49	2019-10-30	Merlyn Ferry	merlyn.ferry@geemail.com	Corpus Christi	Texas	52073657798936554	cf0146cb314dc8c5e75412f2552608de	Diners Club / Carte Blanche	27.796901301614195	-97.0915964591145553
4575	2019-10-30 14:27:30	2019-10-30	Dr. Ellis Walker I	dr.ellis.walker.i@geemail.com	Cincinnati	Ohio	3112082167153578867	cc28398c633c25e66f788b80fa7be683	VISA 13 digit	39.1331528326261804	-84.4511654441051149
4576	2019-10-30 14:32:05	2019-10-30	Isiah Lubowitz	isiah.lubowitz@geemail.com	New York	New York	4084156112039267	976e9412c9a7c77271b023b2a27daf80	Discover	40.6874323413930838	-73.9161598458781839
4577	2019-10-30 15:05:55	2019-10-30	Shaylee Swaniawski	shaylee.swaniawski@geemail.com	San Francisco	California	3088835396886875114	441ecae4ac21ca709d47b3b677b6117d	Diners Club / Carte Blanche	37.7921901123143229	-122.395571491335346
4578	2019-10-30 15:42:59	2019-10-30	Alto Collins-Schuster	alto.collins.schuster@geemail.com	San Francisco	California	869937124298973376	6e84aeda8321dc1e6209f78e027804b5	VISA 16 digit	37.7870069303748934	-122.440658222379767
4579	2019-10-30 16:28:32	2019-10-30	Alston Haag-Jast	alston.haag.jast@geemail.com	San Francisco	California	3736908007178397	51ef5b49264c93fa63b3e6e9313554c7	Diners Club / Carte Blanche	37.746215365771512	-122.425462531528751
4580	2019-10-30 16:51:30	2019-10-30	Mr. Deondre Cummings DDS	mr.deondre.cummings.dds@geemail.com	Philadelphia	Pennsylvania	3088770938374829272	01736e775bfeb507c2f46b024575c17b	Discover	40.0687992534559214	-75.0833163014046931
4581	2019-10-30 17:28:49	2019-10-30	Miss Hayden Jones	miss.hayden.jones@warmmail.com	Lexington	Kentucky	4044057717269094	c2f84c4a6478e9c0a0268b97b66646e3	VISA 16 digit	38.089872641662879	-84.3848497153159229
4582	2019-10-30 17:35:34	2019-10-30	Louisa Grimes	louisa.grimes@geemail.com	Rockford	Illinois	3337319313232015282	9d740024fe6791c1a1b5e93e07a711ac	Diners Club / Carte Blanche	42.1782524148013422	-88.9899793832845916
4583	2019-10-30 21:01:49	2019-10-30	Sherron Anderson-Wolf	sherron.anderson.wolf@woohoo.com	San Francisco	California	4943156281818872	5b1e8d2321f19aba54c3c9aceb1bf2ea	JCB 16 digit	37.7914970733326712	-122.441029895259248
4584	2019-10-30 21:04:12	2019-10-30	Arminta Schimmel	arminta.schimmel@geemail.com	New York	New York	676127487850672	4eb3c58306bb7246fe714a79fd84f596	Discover	40.6508883559834189	-73.9350869813363971
4585	2019-10-30 21:45:50	2019-10-30	Arther Gibson Jr.	arther.gibson.jr.@geemail.com	Oakland	California	55471977936897767	9185a0b4da8516fe7802b698053ed30a	Discover	37.8038657228663766	-122.301620355177391
4586	2019-10-30 21:53:18	2019-10-30	Anjali McClure	anjali.mcclure@woohoo.com	Raleigh	North Carolina	869902596380279294	c46a7b5ecb61bee259c3b3683752dff9	JCB 16 digit	35.9176146039873316	-78.5706434431422593
4587	2019-10-30 22:03:35	2019-10-30	Mr. Charlie Bogisich	mr.charlie.bogisich@geemail.com	Cambridge	Massachusetts	869920276819656747	adf443ef45c97f2f96caba22d3f904d1	VISA 16 digit	42.4466818969920254	-71.164355906107275
4588	2019-10-30 22:04:35	2019-10-30	Darleen O'Connell-Pouros	darleen.o'connell.pouros@woohoo.com	Allentown	Pennsylvania	3088541898532784744	644e2ea6232c4bcc171c106b89375713	Voyager	40.5425841317757971	-75.5703473253656171
4589	2019-10-30 22:10:27	2019-10-30	Effie Larkin	effie.larkin@geemail.com	Pittsburgh	Pennsylvania	3431863302232883	16c8f4c7e987d7633f3e461b8e69772a	JCB 15 digit	40.4841628456909177	-80.0274772265631782
4590	2019-10-30 22:18:09	2019-10-30	Kathryn Block DDS	kathryn.block.dds@geemail.com	San Francisco	California	869978983124872759	12088b58c30d843d58c7e825463f1f6d	Diners Club / Carte Blanche	37.7503345493078513	-122.420869481127824
4591	2019-10-30 22:31:01	2019-10-30	Charisse Kilback-Shanahan	charisse.kilback.shanahan@geemail.com	Fort Worth	Texas	55298547730448173	937bf6c04bb499b0893ed85dd19fac6c	VISA 13 digit	32.7228970666937542	-97.2810174128327532
4592	2019-10-30 23:21:06	2019-10-30	Ms. Elizebeth Heller MD	ms.elizebeth.heller.md@geemail.com	Gainesville	Florida	4262722486479902	96605592ece3665dfa8ff3b127ae9540	Discover	29.6129607502661649	-82.4015496666882257
4593	2019-10-31 00:15:24	2019-10-31	Leopoldo McGlynn	leopoldo.mcglynn@geemail.com	Des Moines	Iowa	3037064792968603	f584a56586ca10a9a2103ed477c53eb0	Voyager	41.6692969871893553	-93.5840237773533943
4594	2019-10-31 00:39:11	2019-10-31	Dr. Larissa Schimmel PhD	dr.larissa.schimmel.phd@geemail.com	New York	New York	6011360115915212401	a8d6661d19d70991061b6dc778c6702f	JCB 16 digit	40.5957743379045297	-73.8969412210293086
4595	2019-10-31 01:14:41	2019-10-31	Merle Kreiger	merle.kreiger@geemail.com	San Francisco	California	3740814520107273	99acfbce242efd6468eac233b80c3f8d	Mastercard	37.7646008767660035	-122.424029648567057
4596	2019-10-31 01:15:54	2019-10-31	Lylah Olson	lylah.olson@geemail.com	San Francisco	California	6011490209277282855	33e8fa146a19bd98e4ba35ba36117b5d	JCB 15 digit	37.8096915212704943	-122.416632983605609
4597	2019-10-31 03:03:33	2019-10-31	Hildred Rempel DVM	hildred.rempel.dvm@warmmail.com	Berkeley	California	3487890218607844	658b8f69f4fd8b32b82e4fdd1aba91f3	Voyager	37.8660404248637263	-122.265252545618409
4598	2019-10-31 03:26:59	2019-10-31	Amerigo Waters	amerigo.waters@geemail.com	Honolulu	Hawaii	51128878658498395	150c5909b205bc426554768495bad572	Voyager	21.3239665942016998	-157.860239119243261
4599	2019-10-31 03:43:25	2019-10-31	Mrs. Yazmin Mitchell	mrs.yazmin.mitchell@geemail.com	Glendale	Arizona	589309927558198	c1b3a0bd56b2c5c5dad0ad5ea4a0545b	JCB 16 digit	33.6207617583911826	-112.153484266509849
4600	2019-10-31 03:45:18	2019-10-31	Jerri Huels	jerri.huels@warmmail.com	San Francisco	California	4499045501891	5455e426f12849d0e41750af29e80287	VISA 13 digit	37.7976696238854473	-122.447604792839883
4601	2019-10-31 03:46:26	2019-10-31	Dr. Alpheus Hackett IV	dr.alpheus.hackett.iv@geemail.com	San Diego	California	3777147414075017	f04966523f7bdfef237bbe348ff3c108	Discover	32.864780326846244	-117.064660314414652
4602	2019-10-31 04:13:48	2019-10-31	Mrs. Shanda Schneider	mrs.shanda.schneider@geemail.com	Philadelphia	Pennsylvania	6011909103820170847	931cf27bbdf21e867b680858f47dce0c	JCB 16 digit	40.1047843283001342	-75.2039806150265093
4603	2019-10-31 05:00:28	2019-10-31	Gaylen DuBuque	gaylen.dubuque@warmmail.com	Ontario	California	869992822238399725	1cfa7d9085811867bc86d1b5879770d1	Voyager	33.9401127143442665	-117.658582041795185
4604	2019-10-31 05:20:28	2019-10-31	Dino Cole MD	dino.cole.md@geemail.com	Pittsburgh	Pennsylvania	4915294829256372	dc826aaf9d08e9fdab4f93ba259d7d67	Discover	40.3800482952456932	-80.0259101845495451
4605	2019-10-31 06:53:57	2019-10-31	Dr. Chas Jacobs	dr.chas.jacobs@geemail.com	Houston	Texas	3749796755410863	836c78aa2c131d058c03b93b3608ae99	JCB 16 digit	29.859581441766025	-95.3178731904845762
4606	2019-10-31 07:18:44	2019-10-31	Mr. Gunner Wehner	mr.gunner.wehner@geemail.com	Honolulu	Hawaii	4963120981508139	6d19152621d071b01946ec10108805c5	JCB 15 digit	21.2869196834258751	-157.791270631526032
4607	2019-10-31 07:20:40	2019-10-31	Angelique Ward	angelique.ward@geemail.com	San Francisco	California	4260643879175000	d7461e44c71dbae106a8220454a96051	American Express	37.8133566943984292	-122.430752529513725
4608	2019-10-31 07:31:10	2019-10-31	Sydney Gerlach	sydney.gerlach@geemail.com	New Haven	Connecticut	869906072640021260	672b243a4542c7479abd04180612a909	JCB 15 digit	41.2468266129951928	-72.9236508968286188
4609	2019-10-31 08:04:47	2019-10-31	Jewell Kreiger-Auer	jewell.kreiger.auer@geemail.com	San Francisco	California	6011323962005630638	74f01a7991a126facc9c4958da82c451	JCB 15 digit	37.7532675436326812	-122.42972003046232
4610	2019-10-31 08:49:57	2019-10-31	Miss Hattie Rowe PhD	miss.hattie.rowe.phd@geemail.com	Fort Collins	Colorado	53818378473062513	9feb0bf2b0248a1a8971b3c59004ce76	Diners Club / Carte Blanche	40.627396703201164	-104.970245905448877
4611	2019-10-31 09:02:11	2019-10-31	Mr. Brock Kihn MD	mr.brock.kihn.md@geemail.com	San Francisco	California	3456939688397613	0dce224fa6368d2fc4ab231749164ce4	JCB 15 digit	37.7769990221940901	-122.368478236228938
4612	2019-10-31 10:09:54	2019-10-31	Rosalyn Reynolds	rosalyn.reynolds@woohoo.com	Portland	Oregon	3096799298559690339	82d36eadbbcea0ee4b9ae36e361990c5	Diners Club / Carte Blanche	45.5912359730694448	-122.66330277826637
4613	2019-10-31 10:12:49	2019-10-31	Dejuan Pfeffer	dejuan.pfeffer@geemail.com	San Francisco	California	869901586600615790	ddd30ccc9438518b9c07a4f14c807cf3	Mastercard	37.7772483192214494	-122.426067574191009
4614	2019-10-31 10:35:33	2019-10-31	Mrs. Jimena Jakubowski PhD	mrs.jimena.jakubowski.phd@warmmail.com	Rockford	Illinois	55809699951228495	fd6d737a961033455d65306a6257249b	Diners Club / Carte Blanche	42.2178921532828397	-89.1583003639526623
4615	2019-10-31 12:03:32	2019-10-31	Verda Greenfelder	verda.greenfelder@geemail.com	Oakland	California	4903512156897664	9c67ee0271fda67dd385cf76d2fe7d85	American Express	37.8313073750260713	-122.236999697055381
4616	2019-10-31 12:09:27	2019-10-31	Kristian Kutch-Kirlin	kristian.kutch.kirlin@woohoo.com	Gilbert	Arizona	53384679025383297	1579b23ad9cd20a9e2befd0031094175	Diners Club / Carte Blanche	33.3644467771865436	-111.763456599707155
4617	2019-10-31 13:09:24	2019-10-31	Jaylon Schneider	jaylon.schneider@geemail.com	San Francisco	California	4166718193216980	e43cfe155d0d4bced65f87b83c279827	Diners Club / Carte Blanche	37.7537721539288	-122.40143089151826
4618	2019-10-31 13:14:13	2019-10-31	Clide Sawayn-Lynch	clide.sawayn.lynch@geemail.com	Mesquite	Texas	4099355949027	32249169505916186ad5a37467548fa7	JCB 16 digit	32.7354483439397086	-96.6864601942908024
4619	2019-10-31 14:03:45	2019-10-31	Eric Nienow	eric.nienow@woohoo.com	Dallas	Texas	180020085072582791	3c03bddf7e93f453fefbc565f3c80c41	JCB 16 digit	32.7993309331398493	-96.6900310374293355
4620	2019-10-31 14:31:14	2019-10-31	Patrick Lehner	patrick.lehner@geemail.com	Lakewood	Colorado	6011950858781303095	d4ce5a1425ab7ae39ebd24961db5d2e5	Mastercard	39.6783226355850687	-105.06097663743644
4621	2019-10-31 15:48:32	2019-10-31	Christina Reynolds	christina.reynolds@geemail.com	Huntington Beach	California	4025868617009	c5ad1b1ae30ec9b0744e8015e65a57a6	Voyager	33.6865831730462659	-118.035787988326689
4622	2019-10-31 15:56:59	2019-10-31	Mrs. Francine Zulauf PhD	mrs.francine.zulauf.phd@geemail.com	New York	New York	3426962033854333	26b898a2079d29bb8eaf08e5aaec6312	Diners Club / Carte Blanche	40.5764735125228739	-73.9780144172616332
4623	2019-10-31 16:03:32	2019-10-31	Ollie Pouros-Anderson	ollie.pouros.anderson@geemail.com	Berkeley	California	3088608163135230078	eda8134399871ccaaae78e51dccf13c8	VISA 13 digit	37.8186002257050333	-122.29164648146714
4624	2019-10-31 16:08:12	2019-10-31	Mr. Alfie Collins V	mr.alfie.collins.v@geemail.com	San Francisco	California	3037763224260022	4e45f61f0c0c311386852c85ee716105	American Express	37.7894878202601205	-122.417182699958133
4625	2019-10-31 16:37:20	2019-10-31	Waino Brown	waino.brown@woohoo.com	Jurupa Valley	California	503823494918131	d15262be0a980111f59f819163739737	American Express	33.9462073364689942	-117.488388575662299
4626	2019-10-31 17:27:32	2019-10-31	Jazmine Mohr-Beer	jazmine.mohr.beer@woohoo.com	Berkeley	California	4332705710793	740ab7c23b317cfb5e6eb349e3f4d800	VISA 13 digit	37.8484993190539427	-122.275751734250619
4627	2019-10-31 17:30:28	2019-10-31	Dr. Roosevelt Pagac Jr.	dr.roosevelt.pagac.jr.@geemail.com	Cary	North Carolina	676182680024682	c2b051242c491c6b26f345e098b2045a	VISA 13 digit	35.7956580986376878	-78.8323525880549028
4628	2019-10-31 17:34:56	2019-10-31	Patrick Nienow	patrick.nienow@woohoo.com	Oakland	California	503895217832203	6c9f8c697c8356fd2194e484684154bb	VISA 13 digit	37.798343804990381	-122.246393122886829
4629	2019-10-31 18:15:13	2019-10-31	Duard Heaney	duard.heaney@warmmail.com	Oakland	California	55166937222933346	a9d9d2803232599acad5895388c4b7e8	Diners Club / Carte Blanche	37.8172083997744579	-122.267478438394434
4630	2019-10-31 18:38:54	2019-10-31	Carla Corkery	carla.corkery@geemail.com	Cape Coral	Florida	869940571396382436	84f75cc3808c5ec53dd6a156a2f6babb	VISA 16 digit	26.6623318118944752	-82.030823381811004
4631	2019-10-31 18:45:13	2019-10-31	Sharonda Kemmer	sharonda.kemmer@geemail.com	New York	New York	3088288536776967107	bcc83825a8ac82c8d5f1baf55e04da95	JCB 16 digit	40.6357905734088263	-73.9857369059126739
4632	2019-10-31 18:51:20	2019-10-31	Lorenz Schinner	lorenz.schinner@warmmail.com	Raleigh	North Carolina	6011510663475754790	e1c3a5712b177acddf3bca6fea6d0f82	Voyager	35.8574706530798224	-78.5531234499935067
4633	2019-10-31 19:17:37	2019-10-31	Arturo Toy-Lynch	arturo.toy.lynch@woohoo.com	New York	New York	503803639543416	1ca5a19201b62195c46f02a48dbe6b77	VISA 16 digit	40.573216760832814	-73.8916571381863179
4634	2019-10-31 20:37:40	2019-10-31	Ms. Betsy Collins DDS	ms.betsy.collins.dds@geemail.com	San Francisco	California	4688405927851477	879d2fd2bf2f5a434e17eb805aa5970b	VISA 16 digit	37.8054925615727768	-122.415556168395852
4635	2019-10-31 21:05:32	2019-10-31	Raheem Marks-Schumm	raheem.marks.schumm@woohoo.com	Berkeley	California	869975492203650865	acca653f7aa32fc57575e53e98bc50e8	VISA 16 digit	37.8914787016344476	-122.294237179752088
4636	2019-10-31 21:55:42	2019-10-31	Miss Lorean Crooks	miss.lorean.crooks@geemail.com	San Francisco	California	4516500218511	aa6b837befa7989a238c454b35bd3033	Maestro	37.7977678096050127	-122.392474236159259
4637	2019-10-31 23:03:55	2019-10-31	Alexandre Bayer	alexandre.bayer@woohoo.com	San Francisco	California	3337205383531645599	2869b0aa07ae87a0c14a25172dd2a7c6	VISA 16 digit	37.7996411195883653	-122.45542372667208
4638	2019-11-01 00:45:27	2019-11-01	Fannie Beier	fannie.beier@geemail.com	Lubbock	Texas	3112049050242842530	3b5264d502e51e2de0355519fb2cbafa	American Express	33.4817169451661414	-101.857401383613052
4639	2019-11-01 02:43:19	2019-11-01	Son Deckow PhD	son.deckow.phd@geemail.com	Los Angeles	California	210008200304813155	3e107645e54ca9b4b0305248c8844edd	JCB 16 digit	33.9243561409745311	-118.445458430656416
4640	2019-11-01 02:59:53	2019-11-01	Starr Waelchi	starr.waelchi@geemail.com	San Francisco	California	4338290504262031	982f4a65c253a135e87200b78ab7c30f	JCB 16 digit	37.7646702656011115	-122.409974042023961
4641	2019-11-01 03:11:53	2019-11-01	Candido Lehner	candido.lehner@geemail.com	San Francisco	California	4937035366533499	b93c7427fdf5c99dab5b2fa95349a55a	Maestro	37.7718052914780742	-122.406738239272102
4642	2019-11-01 03:14:44	2019-11-01	Krista Flatley	krista.flatley@geemail.com	San Francisco	California	3462017876509778	2f160b40f6d7d0c48d492f6f532902ed	JCB 16 digit	37.8043677841433592	-122.411378334099396
4643	2019-11-01 03:37:46	2019-11-01	Cortez Leffler	cortez.leffler@geemail.com	San Francisco	California	3030548426535496	b8fc204e1807b7dbabd42b3231d210b9	JCB 15 digit	37.7844665717781325	-122.411290205128481
4644	2019-11-01 04:00:23	2019-11-01	Kamryn Cartwright	kamryn.cartwright@woohoo.com	San Francisco	California	210045636963033889	4b4bc95d1ef53f97e235684be8d8f443	Maestro	37.7633764917584998	-122.456552427600144
4645	2019-11-01 04:09:35	2019-11-01	Edrie King	edrie.king@woohoo.com	San Francisco	California	060490540848810	63cb310f539d98fce788a37f40c092e0	JCB 16 digit	37.7721212070745764	-122.453618218328259
4646	2019-11-01 05:04:11	2019-11-01	Shanon Wolf	shanon.wolf@geemail.com	Kansas City	Missouri	3096326782411668973	81d493611e389f74437ab10f337696c7	VISA 16 digit	39.2073973938658895	-94.5293624342642715
4647	2019-11-01 05:07:18	2019-11-01	Nicolle Treutel	nicolle.treutel@warmmail.com	Oakland	California	3528489052361604813	f8df25588e128472b9ac577302c144ac	JCB 15 digit	37.8306865126094394	-122.303431033863546
4648	2019-11-01 05:08:58	2019-11-01	Shemar Beatty	shemar.beatty@woohoo.com	San Francisco	California	4472459268134712	8b18667a94c6e78839ad50a6d879012b	JCB 16 digit	37.7623260585065452	-122.439057160648716
4649	2019-11-01 05:37:20	2019-11-01	Delmer Mohr	delmer.mohr@geemail.com	Philadelphia	Pennsylvania	869982595196218564	c87ad3c4375c4cdbcb110072beab6f54	Voyager	40.0968449687078561	-75.1426978220597022
4650	2019-11-01 07:32:45	2019-11-01	Marni Schoen	marni.schoen@woohoo.com	Oakland	California	639053496458562	969cc5c10a61240bc15b792993292224	JCB 16 digit	37.8387112655294686	-122.282722276721657
4651	2019-11-01 08:43:53	2019-11-01	Mr. Carrol Huels	mr.carrol.huels@geemail.com	San Francisco	California	3002279005946502	cdf5afe76925a922a4f65f673060ba81	Mastercard	37.7421660485533508	-122.423542599790864
4652	2019-11-01 08:55:37	2019-11-01	Chrystal Block MD	chrystal.block.md@geemail.com	San Francisco	California	675905554320662	8f530f022239d99ac3daef717ac7e19f	JCB 16 digit	37.7804847438791001	-122.451769434930796
4653	2019-11-01 10:01:14	2019-11-01	Beverley Hodkiewicz DDS	beverley.hodkiewicz.dds@geemail.com	Clovis	California	3528808293067386271	43dbe20cd9de5e9de04265f17677bd7f	VISA 13 digit	36.7831428392201687	-119.719674488443502
4654	2019-11-01 10:04:40	2019-11-01	Gavin Doyle	gavin.doyle@geemail.com	San Francisco	California	6011825106224419992	17f1c941aa5af0cca3847ed5458e27a8	VISA 16 digit	37.775666338866408	-122.399878055095201
4655	2019-11-01 10:19:27	2019-11-01	Rhett Hand-Jast	rhett.hand.jast@geemail.com	Phoenix	Arizona	6011108929340909333	4f2c27ee47c9492bad95dce7acb7505a	Diners Club / Carte Blanche	33.6211215373992971	-112.104701487433545
4656	2019-11-01 10:35:23	2019-11-01	Haylie Collier	haylie.collier@geemail.com	Oakland	California	3088662337532166704	7dca1b00ba2845a9ac855ecb1cbfe6e6	Maestro	37.7784980244394788	-122.305855242630827
4657	2019-11-01 11:22:22	2019-11-01	Angeles Schneider MD	angeles.schneider.md@geemail.com	St. Petersburg	Florida	210094755229414921	0b724a40489e66cf36548f530c371d6e	JCB 16 digit	27.8583245586026464	-82.6266799357611603
4658	2019-11-01 12:20:16	2019-11-01	Mr. Alden Hessel PhD	mr.alden.hessel.phd@woohoo.com	San Francisco	California	869968567729146792	c4913b5916d333773e96a52a541a4e48	Diners Club / Carte Blanche	37.7712196482568672	-122.431431294308979
4659	2019-11-01 12:55:40	2019-11-01	Mrs. Lular King	mrs.lular.king@geemail.com	San Francisco	California	6011231232901030122	2b149bd5e2b91c7a1c39d7d566263275	Diners Club / Carte Blanche	37.7881170845895369	-122.432118277671066
4660	2019-11-01 13:57:02	2019-11-01	Camille Leuschke-Jenkins	camille.leuschke.jenkins@geemail.com	Thousand Oaks	California	210052796496146333	c45a3233e90f4ac062e6422871196818	VISA 16 digit	34.1939140880286701	-118.847213950744646
4661	2019-11-01 14:28:01	2019-11-01	Ruffus Lynch-Corkery	ruffus.lynch.corkery@woohoo.com	San Francisco	California	55403321644631353	be2b4dba653407472fc315812dcfc144	Maestro	37.7489294962338775	-122.453408658366868
4662	2019-11-01 15:40:53	2019-11-01	Zillah Hickle	zillah.hickle@warmmail.com	Los Angeles	California	4846698936519452	17841595f21368ba6a0356c3f97acfd3	Maestro	34.026742550344764	-118.48417576742284
4663	2019-11-01 16:47:23	2019-11-01	Miss Anya Skiles	miss.anya.skiles@geemail.com	Davie	Florida	4085442268350289	5158c7fe6184ef0a843513ea714c5291	VISA 13 digit	26.134809471600132	-80.316605933606624
4664	2019-11-01 17:11:05	2019-11-01	Chas Dare	chas.dare@warmmail.com	Memphis	Tennessee	3088070281748183606	548140c71a64c6cb0102c47a90e09b45	VISA 13 digit	35.0826813189379862	-89.9398438454862656
4665	2019-11-01 17:49:08	2019-11-01	Ona Weissnat	ona.weissnat@geemail.com	New Orleans	Louisiana	210093203058254192	523632c8d060d14eb53b6b32803872b3	Discover	29.9869591835435472	-89.8406645288951751
4666	2019-11-01 19:02:00	2019-11-01	Elmo Barton	elmo.barton@geemail.com	Palmdale	California	4654997727564136	8bca5c19d8f40edd51bbf76860551d0f	JCB 16 digit	34.6403350912351158	-118.110832045320052
4667	2019-11-01 19:11:18	2019-11-01	Kordell Beier	kordell.beier@warmmail.com	San Francisco	California	675925127617857	0b1425dd3cf55e4a26fd20fc3ccc3c00	Maestro	37.7646824255264093	-122.436943260117559
4668	2019-11-01 19:21:19	2019-11-01	Red Walker IV	red.walker.iv@geemail.com	Seattle	Washington	3728085186406889	b8f5c1dc438a583409cfb09141ba805d	JCB 16 digit	47.6298078976962742	-122.354395384799318
4669	2019-11-01 21:18:15	2019-11-01	Carlyn Smitham	carlyn.smitham@warmmail.com	Thousand Oaks	California	3112297589660909072	c1cc7718f2dd50a43b1b3a1c49507def	JCB 15 digit	34.1852866083655513	-118.839037774354964
4670	2019-11-01 21:55:48	2019-11-01	Birtha Koch	birtha.koch@woohoo.com	Mesa	Arizona	3112500706778260692	9c67d705f293b51bb6af61c52819cdda	VISA 16 digit	33.3962758007604634	-111.733980262221394
4671	2019-11-01 22:05:20	2019-11-01	Dr. Jerrica Lubowitz MD	dr.jerrica.lubowitz.md@geemail.com	Chicago	Illinois	4399354420853327	148637981ba175b77104ae4886ce7cbc	Diners Club / Carte Blanche	41.8300839872401227	-87.6826322570938572
4672	2019-11-01 23:35:22	2019-11-01	Kamya Howell	kamya.howell@geemail.com	San Francisco	California	3337915708472784596	7eb8fc9ea2e61e65b4449bff23ec2aca	Discover	37.7897172628572022	-122.442773432591153
4673	2019-11-02 00:35:11	2019-11-02	Tori Bogisich	tori.bogisich@warmmail.com	San Francisco	California	676224986363117	1d1ff34d5c53d359e8a33524b628b1a1	JCB 15 digit	37.7110564184859669	-122.443563474030469
4674	2019-11-02 00:40:05	2019-11-02	Brant Nader-Runolfsdottir	brant.nader.runolfsdottir@warmmail.com	Providence	Rhode Island	180022216161213190	77cfa75bcaece5dd4d34df5315212518	VISA 13 digit	41.8813195735070849	-71.4018803495831804
4675	2019-11-02 00:51:09	2019-11-02	Miss Felicitas Herman	miss.felicitas.herman@geemail.com	Macon	Georgia	3468917407582802	daf0d840dc5473992bb951834f8ac98b	Discover	32.7630499863076921	-83.6098095863785602
4676	2019-11-02 01:26:33	2019-11-02	Loran Ratke Sr.	loran.ratke.sr.@geemail.com	Meridian	Idaho	4930665919673546	e5d587b475974931242c4b2bad7350c8	Mastercard	43.6243195674389597	-116.472131971450153
4677	2019-11-02 01:54:54	2019-11-02	Mattye Hahn	mattye.hahn@woohoo.com	Boston	Massachusetts	869992910387652844	b6422fb8e51801ec140aead5d8fe4104	JCB 16 digit	42.2645241848826387	-70.9823113537810713
4678	2019-11-02 02:18:21	2019-11-02	Dr. Gale Nader V	dr.gale.nader.v@geemail.com	Oakland	California	3441874167834877	1f2b58702633e819adde47263d9d19e5	Maestro	37.8261349266884395	-122.279735228907882
4679	2019-11-02 03:05:09	2019-11-02	Alcide Buckridge	alcide.buckridge@geemail.com	Oakland	California	4732526796969003	e7608ccff6df79d9fdd1a036cf16487e	Maestro	37.8109435268442553	-122.270441954135663
4680	2019-11-02 03:29:45	2019-11-02	Dr. Debi Donnelly DDS	dr.debi.donnelly.dds@geemail.com	Jacksonville	Florida	3053721358190641	340b1aaac18ea723d35a9c0f34f45137	American Express	30.3532192901760354	-81.7028998663727322
4681	2019-11-02 03:40:48	2019-11-02	Troy Mohr-Ziemann	troy.mohr.ziemann@geemail.com	Oakland	California	210021488455673238	38cb2257b35d1fc584aa23ac538a257d	JCB 15 digit	37.7973041267343319	-122.251282401600918
4682	2019-11-02 04:17:16	2019-11-02	General Sawayn	general.sawayn@warmmail.com	Oakland	California	4747856485911211	4a89975ca147bd27f18db25df9ba7d67	Voyager	37.7780627385196937	-122.274350862966713
4683	2019-11-02 04:22:14	2019-11-02	Venessa O'Kon	venessa.o'kon@geemail.com	North Las Vegas	Nevada	3717404702306809	8623725a1a3bf5d99c2e7c531ef3b27e	VISA 13 digit	36.3489867552340016	-115.057104148132353
4684	2019-11-02 04:57:24	2019-11-02	Miss Rosetta Emmerich DDS	miss.rosetta.emmerich.dds@geemail.com	Oakland	California	55319836454127989	36949a037a87d0155fd4f4bdf2922eb2	Discover	37.7707278385421432	-122.274958229435285
4685	2019-11-02 05:47:57	2019-11-02	Theodora Collier	theodora.collier@woohoo.com	San Francisco	California	675928553019358	b15531154b4f63f9b0c9e13d3f3d4b5d	Discover	37.7790737945827999	-122.40694407414172
4686	2019-11-02 06:05:25	2019-11-02	Williemae Weimann	williemae.weimann@geemail.com	Berkeley	California	3088605126901171514	eb51c771b836404aace26058f08ece9f	Diners Club / Carte Blanche	37.8329470854278114	-122.234411838120337
4687	2019-11-02 06:57:26	2019-11-02	Osbaldo Feest-Johnston	osbaldo.feest.johnston@geemail.com	Gilbert	Arizona	869934414108694129	4698e9eff987eeed6b2948c0b681e32b	JCB 15 digit	33.2397481938239139	-111.750962641755493
4688	2019-11-02 07:06:55	2019-11-02	Marguerite Schuster	marguerite.schuster@warmmail.com	San Francisco	California	3158026800352366267	d032db367df726b1dddbf9abb350f662	VISA 16 digit	37.79989788671638	-122.421194732681315
4689	2019-11-02 07:17:33	2019-11-02	Rachelle Heathcote	rachelle.heathcote@geemail.com	Austin	Texas	3158000353338414090	2d8c3a206c97484533b5a0bf1559ecf0	JCB 15 digit	30.2627625446427615	-97.7736940928973297
4690	2019-11-02 07:36:03	2019-11-02	Benjaman Ebert	benjaman.ebert@geemail.com	San Francisco	California	4546680259670	9cac06c4c4c1e5c9b06e510051190eb3	VISA 16 digit	37.7566593700307749	-122.44231044067871
4691	2019-11-02 07:42:19	2019-11-02	Valery Macejkovic	valery.macejkovic@woohoo.com	New York	New York	869954037325202312	c00d01fd2abf57bff6a57f425dd0a178	American Express	40.6337801139559573	-73.9303117339860592
4692	2019-11-02 07:42:54	2019-11-02	Harding Nienow	harding.nienow@geemail.com	Los Angeles	California	4370336892162637	513a503d224684e2bd28458130d81cb5	Maestro	34.0596589095290696	-118.345065838889397
4693	2019-11-02 08:17:50	2019-11-02	Laurel Christiansen	laurel.christiansen@woohoo.com	Berkeley	California	3022135652288533	2f8af463fbacfab6d3c7829d7e686eed	Diners Club / Carte Blanche	37.8995281318240416	-122.291281284770989
4694	2019-11-02 08:37:35	2019-11-02	Tempie Trantow	tempie.trantow@geemail.com	Lexington	Kentucky	3036239356892776	0aa2959bdfa39fca8c0a07b9f70cef5f	Discover	38.0315611333928985	-84.5244524024326296
4695	2019-11-02 09:16:33	2019-11-02	Rachael D'Amore DVM	rachael.d'amore.dvm@geemail.com	San Francisco	California	4543995005010736	62d1a7eb55549ded5df890a4e4637477	Voyager	37.7734535276279217	-122.429093142242664
4696	2019-11-02 09:25:19	2019-11-02	Ms. Nataly Barrows PhD	ms.nataly.barrows.phd@geemail.com	Chicago	Illinois	6011736563888073952	3930402728df44a32e54286d46a26418	Voyager	41.8145171664025668	-87.6456418523594749
4697	2019-11-02 10:09:53	2019-11-02	Miss Minervia Waters DVM	miss.minervia.waters.dvm@geemail.com	Austin	Texas	3528145829778016483	23fbf8102ffdb1f110675585bd2e6be7	American Express	30.3316978844940657	-97.6622385686501957
4698	2019-11-02 10:36:32	2019-11-02	Dallas Bailey-Berge	dallas.bailey.berge@geemail.com	Chattanooga	Tennessee	4950430754784	a17f7e1ad9d3ad36f7d05105da199bb7	JCB 16 digit	35.056315121132883	-85.1953297866337067
4699	2019-11-02 11:07:51	2019-11-02	Encarnacion Rice	encarnacion.rice@geemail.com	Indianapolis	Indiana	3051122865465570	bbec20eb135726fc426ec400b2f363cc	JCB 16 digit	39.8206347805920942	-86.0939325203388961
4700	2019-11-02 11:11:49	2019-11-02	Adella Rippin	adella.rippin@geemail.com	San Francisco	California	3096557059586618327	b10032f66a99645021213fe5b36ba6bf	Mastercard	37.754710457328585	-122.413267210859047
4701	2019-11-02 11:24:43	2019-11-02	Ms. Freddie Murazik MD	ms.freddie.murazik.md@warmmail.com	Reno	Nevada	3112946901946016991	65bec5d2170178f5303568c6ea591770	Maestro	39.4659515929020941	-119.941324360498797
4702	2019-11-02 11:38:27	2019-11-02	Mr. Luciano Kirlin	mr.luciano.kirlin@warmmail.com	Salinas	California	3462954386953346	d3058d4cb57b0e4e8f8bacb097c606ff	JCB 16 digit	36.7056276081826525	-121.710820690979062
4703	2019-11-02 12:42:05	2019-11-02	Tessie Dickens DDS	tessie.dickens.dds@geemail.com	Irvine	California	3485282731835742	8177cf470d41025534ad35e2e3efff83	Mastercard	33.6777054240476375	-117.787405610132211
4704	2019-11-02 15:35:57	2019-11-02	Marylyn Corwin DVM	marylyn.corwin.dvm@warmmail.com	Elizabeth	New Jersey	6011582041843255183	627de4ef574a774814fda7aa7160d660	JCB 16 digit	40.6733081695284753	-74.2256139778010606
4705	2019-11-02 15:39:30	2019-11-02	Nanci Stracke	nanci.stracke@woohoo.com	San Francisco	California	4652984561116	a0bf90799f9a65c16ae3818dec03bf92	Voyager	37.7665949281752162	-122.426358582090657
4706	2019-11-02 16:20:27	2019-11-02	Carley Cole	carley.cole@geemail.com	Richmond	Virginia	4969016567485	6b3f1c11b31d9299c4339e896ba3790f	VISA 13 digit	37.4542548126760835	-77.551924720335748
4707	2019-11-02 17:19:50	2019-11-02	Reece Jacobi	reece.jacobi@warmmail.com	Tucson	Arizona	869994987473376239	8e4a7bc5a64fed77d578d6213db1f777	JCB 16 digit	32.1419683903031057	-110.842058570798855
4708	2019-11-02 17:30:15	2019-11-02	Rillie Daugherty	rillie.daugherty@geemail.com	Buffalo	New York	3528469509011304874	9e888b16a6559f1c0879873845dd7418	JCB 15 digit	42.8362467496376453	-78.8720012869618898
4709	2019-11-02 17:48:51	2019-11-02	Miss Yahaira Ondricka MD	miss.yahaira.ondricka.md@geemail.com	Lincoln	Nebraska	869949666438134836	bb4f16ec0e00b9cc65a26be8c1e02758	VISA 16 digit	40.7777407995909442	-96.7263308635607331
4710	2019-11-02 18:14:26	2019-11-02	Leeann Walker-Deckow	leeann.walker.deckow@geemail.com	San Francisco	California	6011331655759936173	3e1d2808a9a3f247d48abc4101348d65	VISA 16 digit	37.7636782964539108	-122.446468648316085
4711	2019-11-02 18:56:50	2019-11-02	Jacque Hane	jacque.hane@geemail.com	San Francisco	California	060466685309776	20e5ae9791aa61b2ff44232a6de8a46f	VISA 16 digit	37.7650317698258036	-122.459432631244709
4712	2019-11-02 19:52:43	2019-11-02	Ervin Nader	ervin.nader@woohoo.com	Las Vegas	Nevada	869946686609023686	2815d131b99f524c50110df1d49dc0d8	American Express	36.1643621691603201	-115.254353794103849
4713	2019-11-02 19:53:51	2019-11-02	Mrs. Kelsey Langosh	mrs.kelsey.langosh@geemail.com	Dallas	Texas	4621384578541	3777e8b47a5bc368cd2e6cd45a2ca999	VISA 13 digit	32.7240435685768745	-96.7115907961931072
4714	2019-11-02 19:56:11	2019-11-02	Elana Lebsack MD	elana.lebsack.md@warmmail.com	Berkeley	California	3528418338347105892	3186b7f3eda8e2b7ccc516255842eb70	JCB 15 digit	37.8999143114901216	-122.27343266321914
4715	2019-11-02 21:16:29	2019-11-02	Felipe Murray II	felipe.murray.ii@geemail.com	Berkeley	California	4260374013712	e15c6dca76740161a30b264049d1124d	Mastercard	37.8822529025600545	-122.305132859041052
4716	2019-11-02 21:42:20	2019-11-02	Dr. Monte Dicki Sr.	dr.monte.dicki.sr.@warmmail.com	Los Angeles	California	52074579744835137	d1e73afe451fb0eb74c7926b8b77a6e3	JCB 16 digit	34.0233095437619824	-118.484045212016625
4717	2019-11-02 22:29:18	2019-11-02	Albertina Gusikowski	albertina.gusikowski@warmmail.com	San Francisco	California	4012765701875449	464bff71c1ea3f9b1bb29fd15272be8c	Discover	37.7314718188804932	-122.386661705587073
4718	2019-11-02 22:47:40	2019-11-02	Adamaris Goodwin	adamaris.goodwin@geemail.com	Jurupa Valley	California	6011690372943933729	76e1d2730da155a6b56b9ddbcfb6dd11	JCB 16 digit	34.0579857798688153	-117.51276671602615
4719	2019-11-02 23:45:56	2019-11-02	Vlasta Kulas	vlasta.kulas@geemail.com	Columbus	Georgia	869985731069498614	9c3f78feec942da25398c58cfd21f833	Maestro	32.5428169161125993	-84.8275950472965832
4720	2019-11-03 00:27:41	2019-11-03	Verla Hills DDS	verla.hills.dds@woohoo.com	San Francisco	California	3024979627101059	c4170e740620593536a34ee56f753d54	Maestro	37.7473721962918987	-122.430834191365662
4721	2019-11-03 00:31:56	2019-11-03	Mrs. Teressa Kemmer MD	mrs.teressa.kemmer.md@geemail.com	San Francisco	California	3029464499852134	cc7b99ee54d6e276f257ef77adf13ad5	Voyager	37.8047197380001165	-122.413653845584619
4722	2019-11-03 00:35:53	2019-11-03	Miss Aubree Schaden	miss.aubree.schaden@geemail.com	Oakland	California	4149032701936010	395d1deeacd7491ded4c198286aea078	Voyager	37.7888209062206144	-122.325779403573932
4723	2019-11-03 00:49:41	2019-11-03	Mr. Zion Runolfsson	mr.zion.runolfsson@woohoo.com	Lincoln	Nebraska	4140215723529728	4c399397ac5e8718bfba6643c620f07a	Voyager	40.8220025262814019	-96.6528096794311011
4724	2019-11-03 01:03:59	2019-11-03	Robbin Schaden	robbin.schaden@woohoo.com	San Francisco	California	4888077374503535	019fcd10e6e72475b776c86a7bb4164d	VISA 16 digit	37.7665327525517611	-122.40904492691628
4725	2019-11-03 01:07:20	2019-11-03	Miss Almeta Schumm	miss.almeta.schumm@woohoo.com	San Jose	California	502030698820310	7a7135d751b9aebc5cc50065a1a0a1b6	Diners Club / Carte Blanche	37.2351021149948238	-121.917212764987354
4726	2019-11-03 01:08:53	2019-11-03	Elgie Kovacek	elgie.kovacek@woohoo.com	Oakland	California	3096461461972932343	1439684b4432c568f089730aea2d7ad8	Discover	37.7816612096417259	-122.286028387508622
4727	2019-11-03 01:13:02	2019-11-03	Dr. Fed Huels III	dr.fed.huels.iii@geemail.com	Murrieta	California	180072425794808289	59a0de70fd83f997158555bd66a32fe6	Maestro	33.4743752283141021	-117.253679602257534
4728	2019-11-03 02:01:06	2019-11-03	Liller Hamill PhD	liller.hamill.phd@geemail.com	San Jose	California	3088043161407037265	f2022f45cc1f39735e190f7263fa98b1	JCB 16 digit	37.2049828363403705	-121.911051077184823
4729	2019-11-03 02:38:21	2019-11-03	Jamiya Daniel DDS	jamiya.daniel.dds@geemail.com	Miami	Florida	675991748541579	be81b1e9bfb2f7eff215c11dc0cbde8c	Mastercard	25.699223907165976	-80.256657139804588
4730	2019-11-03 04:06:42	2019-11-03	Orilla Purdy MD	orilla.purdy.md@woohoo.com	Kansas City	Missouri	3777518644456450	8d129b3c147b3d0537f9fbbd84103a48	VISA 16 digit	39.2071251922588857	-94.4530055344794022
4731	2019-11-03 04:22:17	2019-11-03	Tanner Kshlerin	tanner.kshlerin@geemail.com	San Francisco	California	4410127983660247	3e2d79b193e8455dd86db4e6fc0e259f	JCB 15 digit	37.7859596349261651	-122.430561081201901
4732	2019-11-03 04:22:27	2019-11-03	Timmy Labadie IV	timmy.labadie.iv@warmmail.com	Port St. Lucie	Florida	502053218049459	2439cfd71c8ab86e3c8387e366e3769e	VISA 16 digit	27.3759020184300823	-80.3280464254871021
4733	2019-11-03 04:52:32	2019-11-03	Mr. Luciano Aufderhar	mr.luciano.aufderhar@warmmail.com	Jacksonville	Florida	3112258285859471233	235322e440713e43e46d60c178dc84cb	Mastercard	30.3694422054622315	-81.6626631476994618
4734	2019-11-03 05:06:37	2019-11-03	Maxwell Marvin	maxwell.marvin@warmmail.com	San Francisco	California	4446045126641171	0f0eb5c31ecfaad772b0fee6068b0693	Diners Club / Carte Blanche	37.822584394721062	-122.461737217636568
4735	2019-11-03 05:10:42	2019-11-03	Ms. Chloe Berge DVM	ms.chloe.berge.dvm@geemail.com	Berkeley	California	3755876072812388	86d39827a7b1cd628858397e421439f9	Discover	37.8746024712330467	-122.256468584867577
4736	2019-11-03 05:34:08	2019-11-03	Jaime Konopelski	jaime.konopelski@geemail.com	San Diego	California	3721918046453880	e09742234d73ea955cf10f929cbbc2f5	VISA 13 digit	32.8174501124370863	-117.209634049134337
4737	2019-11-03 05:37:16	2019-11-03	Dr. Tamica Reynolds	dr.tamica.reynolds@warmmail.com	Knoxville	Tennessee	676229177900692	5d34be5c53546411b02ca53d20c5948f	Mastercard	35.8957292342621841	-83.8922693838115663
4738	2019-11-03 05:57:39	2019-11-03	Miss Marissa Gislason DVM	miss.marissa.gislason.dvm@geemail.com	Chicago	Illinois	639090143292192	5ac89d8778a7a4bc4ddf8e041e463436	VISA 16 digit	41.887495659321921	-87.620584128101541
4739	2019-11-03 06:14:57	2019-11-03	Meggan Hauck-Macejkovic	meggan.hauck.macejkovic@geemail.com	Baton Rouge	Louisiana	4308505753408977	dad4ca6eade00ae3d5528bf7b2b12810	Maestro	30.5356841380454611	-91.0475721917223098
4740	2019-11-03 06:35:41	2019-11-03	Kylan Greenfelder	kylan.greenfelder@geemail.com	San Francisco	California	6011876713254123838	bffbfd2dc94d6edb080264e2739016b2	Discover	37.7687258595134594	-122.418363920927973
4741	2019-11-03 06:36:00	2019-11-03	Dr. Aiyanna Schoen	dr.aiyanna.schoen@geemail.com	Detroit	Michigan	869946550396343477	fdb5a4a807306d4fdbfc756f6ad6053b	JCB 15 digit	42.4465486490558845	-83.1285504694215973
4742	2019-11-03 06:58:27	2019-11-03	Carsen Huel-Swaniawski	carsen.huel.swaniawski@geemail.com	Oklahoma City	Oklahoma	4042482841113	880600d85cf4838ec0926876f2d6bb37	Mastercard	35.4587460813488846	-97.5813903612911702
4743	2019-11-03 07:32:39	2019-11-03	Jeremy Hoppe-Eichmann	jeremy.hoppe.eichmann@warmmail.com	Des Moines	Iowa	210056863268274408	1980647f248e69ce11c72b0b210c9c1e	Discover	41.5252237242855173	-93.6070948981724769
4744	2019-11-03 07:59:51	2019-11-03	Glinda Gleichner	glinda.gleichner@warmmail.com	Vacaville	California	210053728642321097	e0bb4286c8a54197ca97a4ed101ebac1	VISA 16 digit	38.3148401408117323	-121.896268298790986
4745	2019-11-03 08:18:34	2019-11-03	Hurbert Champlin-Schultz	hurbert.champlin.schultz@warmmail.com	Santa Clarita	California	869934003352071058	b3a0166c1660f0a26c9396e534f909a1	JCB 16 digit	34.4440048713907601	-118.47290765918865
4746	2019-11-03 08:42:07	2019-11-03	Mr. Hobart Durgan	mr.hobart.durgan@geemail.com	Chula Vista	California	53333135365347733	1a2b3d6a4a60c92e3e6026d74650e88f	Mastercard	32.6011338026493789	-116.997875838517018
4747	2019-11-03 09:01:48	2019-11-03	Virgle Bechtelar	virgle.bechtelar@geemail.com	San Francisco	California	869995467894199881	2570c9829a3ee9acd605cfd9bf2c58ae	JCB 15 digit	37.7974342741474274	-122.44962522006837
4748	2019-11-03 09:28:33	2019-11-03	Johny Schmeler	johny.schmeler@geemail.com	Cleveland	Ohio	4867699511504376	26c0216dbf2361fe8f96e5267ba1c894	VISA 16 digit	41.5665052775144517	-81.6630555706337162
4749	2019-11-03 09:31:14	2019-11-03	Philomene Ullrich	philomene.ullrich@geemail.com	San Diego	California	4438141491185	bda5c6a03c5256815d528687f02b2d62	VISA 16 digit	32.7717843820873682	-117.203357837665834
4750	2019-11-03 09:39:18	2019-11-03	Tavaris Nienow DVM	tavaris.nienow.dvm@geemail.com	San Francisco	California	54572971090726381	33dcbd854d0621e26219129dfb72dcac	VISA 16 digit	37.7849242402500352	-122.442263954777957
4751	2019-11-03 10:16:14	2019-11-03	Dona Beier-Doyle	dona.beier.doyle@geemail.com	San Francisco	California	3112544953838126947	79143dad0ad78f235858a01c37f32d4d	Maestro	37.764885255637509	-122.433925859940942
4752	2019-11-03 10:40:50	2019-11-03	Loris Dickinson	loris.dickinson@geemail.com	San Francisco	California	060412539754064	ac54a7d3791c1aa0793e1f8bf727c4ca	Discover	37.7610346428090864	-122.42840335077274
4753	2019-11-03 11:07:48	2019-11-03	Alphonse Rice	alphonse.rice@geemail.com	San Francisco	California	6011134621901152738	4aa65cb12f7709e4b4e64493e823c5ca	Voyager	37.8079909346880427	-122.420684187362511
4754	2019-11-03 11:08:56	2019-11-03	Mr. Abdul Mueller	mr.abdul.mueller@warmmail.com	Montgomery	Alabama	4411612405604864	672a9fbb7aec5915350d8e1c2bba5816	Mastercard	32.4042165949407988	-86.2503519482131935
4755	2019-11-03 11:12:34	2019-11-03	Dr. Carroll Rogahn	dr.carroll.rogahn@geemail.com	Milwaukee	Wisconsin	6011129317828142285	8027e5bd1eee89874f1471b1fd6b37e2	Discover	43.0673081729646725	-87.9469777130156842
4756	2019-11-03 12:21:59	2019-11-03	Jule Grant IV	jule.grant.iv@warmmail.com	Jacksonville	Florida	3088816188938586119	6a65845177fd1f5d357f2a684c62aa39	JCB 15 digit	30.322874517185241	-81.7603118983175676
4757	2019-11-03 12:34:57	2019-11-03	Hunter Schamberger II	hunter.schamberger.ii@geemail.com	Dallas	Texas	6011017743708083965	29b7775ad587a78de0e18b1559dee177	Voyager	32.6943170987341603	-96.7505194424614245
4758	2019-11-03 12:57:02	2019-11-03	Clabe Denesik Sr.	clabe.denesik.sr.@woohoo.com	San Francisco	California	869944643441770471	3c7a50e0aa078984231515c269b73951	Maestro	37.7544672289963614	-122.431332019041577
4759	2019-11-03 13:12:43	2019-11-03	Gearldine Weber-Carter	gearldine.weber.carter@geemail.com	Gainesville	Florida	3096566370739213737	ac87ac2ad745c50e0156df34289dac75	Discover	29.7370949628122148	-82.3246681610461337
4760	2019-11-03 14:48:15	2019-11-03	Denver Heathcote	denver.heathcote@geemail.com	Berkeley	California	4771486445864661	e71a9e3403034a49664d2043767b9f1a	Diners Club / Carte Blanche	37.8772501332101541	-122.277315900594061
4761	2019-11-03 14:59:28	2019-11-03	Renata Aufderhar MD	renata.aufderhar.md@geemail.com	Honolulu	Hawaii	4581228545971461	a95319e5a26140dea64a01af61bf0f07	Diners Club / Carte Blanche	21.4183421582199642	-157.759580348499497
4762	2019-11-03 15:32:42	2019-11-03	Guilford Frami	guilford.frami@geemail.com	San Francisco	California	3007457346420180	abd7cd6045507c7f19a56a4e33e8b75a	Discover	37.7618203427701147	-122.436456965927491
4763	2019-11-03 16:22:50	2019-11-03	Annemarie Harber	annemarie.harber@geemail.com	Lubbock	Texas	4813223441746901	921048bbf72cf70a3cfefd367c727186	VISA 16 digit	33.6254106919322169	-101.824122731565311
4764	2019-11-03 16:32:06	2019-11-03	Sylvania Lehner	sylvania.lehner@woohoo.com	Long Beach	California	4735663089465	6e9aaf87da048da7efc6d404e59d4d64	Maestro	33.9018399210002244	-118.146752960995954
4765	2019-11-03 20:23:36	2019-11-03	Lenny Emmerich-Streich	lenny.emmerich.streich@geemail.com	Oakland	California	3528270327169695426	a30ad8c1ec8c41185a41313918963544	JCB 16 digit	37.8353727011661363	-122.247179513972043
4766	2019-11-03 20:25:41	2019-11-03	Katerina Lehner-Hegmann	katerina.lehner.hegmann@woohoo.com	Lewisville	Texas	676174984375290	5aaed5d2404eeb9c9aff7ad4950b3fc4	Maestro	33.0293063257805954	-97.066717620662601
4767	2019-11-03 21:16:40	2019-11-03	Otis Sanford	otis.sanford@woohoo.com	Oakland	California	6011680343878468629	5d8712bb5abb597ca8a18ed9434a0c8c	Voyager	37.7911660420604889	-122.259614722409893
4768	2019-11-03 21:16:43	2019-11-03	Deonta Crist	deonta.crist@geemail.com	Henderson	Nevada	4447486394938	a1f2080588417d7248b778498f141871	JCB 15 digit	35.9193989631187165	-115.029066331839942
4769	2019-11-03 21:20:46	2019-11-03	Stefanie Von	stefanie.von@geemail.com	Denver	Colorado	180061459466445594	2082a2f1a966ffb3e20a9ca480073269	JCB 16 digit	39.8596171489037516	-104.853091704450918
4770	2019-11-03 21:38:35	2019-11-03	Ms. Katharine Streich DVM	ms.katharine.streich.dvm@woohoo.com	San Francisco	California	060450405402715	6c0ac4dbdc1f1a381d6e31dd18460364	JCB 16 digit	37.7970078852355158	-122.461806376021215
4771	2019-11-03 23:12:50	2019-11-03	Braeden Ebert	braeden.ebert@geemail.com	Oakland	California	51304292750280303	3c2dffc7dc3387bf11e53aff0ea419ab	VISA 16 digit	37.8286710996326647	-122.22445679312446
4772	2019-11-03 23:25:51	2019-11-03	Darcy Spencer	darcy.spencer@woohoo.com	Pompano Beach	Florida	6011386199249235882	0ce79154ce256c0f8ef6de15a468ac35	Diners Club / Carte Blanche	26.1832866811923672	-80.0588104066751924
4773	2019-11-03 23:27:29	2019-11-03	Georganna Gulgowski	georganna.gulgowski@geemail.com	Abilene	Texas	52116610231787158	41d24096acebdf98756cdac202d7071b	Voyager	32.4493851929511905	-99.6467562530137627
4774	2019-11-04 00:30:15	2019-11-04	Mr. Dereck Fisher DVM	mr.dereck.fisher.dvm@geemail.com	Washington	District of Columbia	6011849820697822092	e60a0c95a78626299adc1c0a3c57f02c	JCB 15 digit	38.9800242384694542	-76.9686281589072223
4775	2019-11-04 00:34:49	2019-11-04	Rob Rosenbaum	rob.rosenbaum@geemail.com	Fort Worth	Texas	3486369828425989	c166673a7f412e16253857e459a10952	JCB 16 digit	32.7233681492097688	-97.4421671579878819
4776	2019-11-04 02:44:27	2019-11-04	Marlo Koss-Effertz	marlo.koss.effertz@geemail.com	Plano	Texas	180010655496305615	8789c2e474463841af8cac36aa9bbff2	VISA 13 digit	32.9764433116737763	-96.7776210610006018
4777	2019-11-04 03:26:49	2019-11-04	Lisandro Leuschke	lisandro.leuschke@warmmail.com	Los Angeles	California	630439542902398	236084b780fc4695f1b17e65039dc0d0	JCB 16 digit	33.9994674642901842	-118.351393437990168
4778	2019-11-04 03:57:50	2019-11-04	Kristina Ryan PhD	kristina.ryan.phd@geemail.com	Los Angeles	California	4399468538182278	08312123aa6680829f7ab2845e945449	JCB 16 digit	34.0964185873843704	-118.368168926610792
4779	2019-11-04 04:14:49	2019-11-04	Keanna Wiza	keanna.wiza@woohoo.com	Thornton	Colorado	4476917699252904	b5075c0838b1e284c74f94d92e5c8b67	VISA 16 digit	39.9290472763456421	-104.966881382807344
4780	2019-11-04 04:53:30	2019-11-04	Nelly Prohaska	nelly.prohaska@geemail.com	San Francisco	California	4922496311674738	43c9d0a11b4e962265ed1d82786d3938	Diners Club / Carte Blanche	37.7543536267291557	-122.459414780605016
4781	2019-11-04 06:33:49	2019-11-04	Adela Toy DDS	adela.toy.dds@warmmail.com	Lafayette	Louisiana	53978564514465643	641b8101c8d262d7ec1c9cd424119139	American Express	30.2372988543450845	-92.0195510334186224
4782	2019-11-04 06:36:57	2019-11-04	Trenten Price	trenten.price@woohoo.com	San Francisco	California	4275017141065450	75d5558798781f5cae707d410ca494e4	JCB 15 digit	37.7659804528851737	-122.444419950776521
4783	2019-11-04 06:56:11	2019-11-04	Nichol Cormier	nichol.cormier@warmmail.com	San Francisco	California	52165794246148307	f3a28a9fda49115c893d71600e2d6d71	Diners Club / Carte Blanche	37.796479721141516	-122.454120438073161
4784	2019-11-04 07:02:04	2019-11-04	Dustan Nitzsche	dustan.nitzsche@geemail.com	Shreveport	Louisiana	210037770436893346	251fd4ac8350609e90dd3f8006cfbd76	American Express	32.5144842786021542	-93.7732271881055084
4785	2019-11-04 07:25:54	2019-11-04	Ezequiel Schroeder	ezequiel.schroeder@geemail.com	Columbus	Ohio	51001942219761261	21bf0a4b1c404034c69de77994cb4cfe	VISA 13 digit	39.9686273010958004	-82.9716987198453495
4786	2019-11-04 07:42:47	2019-11-04	Herb Feest-Collins	herb.feest.collins@geemail.com	Chattanooga	Tennessee	676198501892198	a03e2a725af732fc394b735cc910e469	JCB 16 digit	35.1022212784588348	-85.1799549192484449
4787	2019-11-04 08:11:06	2019-11-04	Kirk Kihn	kirk.kihn@geemail.com	San Francisco	California	6011919249994774431	3d5d7687715a236d138da50f7b9b9e3b	Maestro	37.8093656599920109	-122.406079432906864
4788	2019-11-04 08:22:20	2019-11-04	Dr. Joseline Daniel MD	dr.joseline.daniel.md@geemail.com	Los Angeles	California	869912774492794975	55e4318b14d2c7c12e6930d70dbdd7a5	Discover	33.9817905728105458	-118.413755252071837
4789	2019-11-04 09:22:17	2019-11-04	Dr. Malaki Dibbert	dr.malaki.dibbert@woohoo.com	Berkeley	California	589358589446929	2543747f47dd0138f84e27d5f2deed92	Mastercard	37.8793705673169185	-122.307631405781521
4790	2019-11-04 09:59:24	2019-11-04	Bryanna Prosacco	bryanna.prosacco@woohoo.com	San Francisco	California	3490326079787768	2f167f89453310d7cd03f791a85cdaa8	Maestro	37.7504785567901209	-122.391203696255587
4791	2019-11-04 10:38:57	2019-11-04	Kazuko Jaskolski-Lowe	kazuko.jaskolski.lowe@geemail.com	Davenport	Iowa	6011997894314766826	c3e458a32d3557af467e59ec5cfe618b	JCB 16 digit	41.5489372953105729	-90.6764218401126527
4792	2019-11-04 10:43:12	2019-11-04	Graves Skiles	graves.skiles@geemail.com	Las Vegas	Nevada	53229677017959669	e6c39cf6a5d8520bd91642899673dfd8	Discover	36.2287422414038289	-115.265686333991951
4793	2019-11-04 10:55:42	2019-11-04	Randy Abbott	randy.abbott@warmmail.com	San Francisco	California	3015738256319575	42138da053fc20e750eea9a44b89f8ac	Diners Club / Carte Blanche	37.7664292022153418	-122.422490918359983
4794	2019-11-04 11:44:05	2019-11-04	Mr. Ayden Spinka II	mr.ayden.spinka.ii@woohoo.com	Corpus Christi	Texas	3337691492817740460	b365547339db80c63dccb29e573fa992	VISA 13 digit	27.6733767989028259	-97.1696670732289505
4795	2019-11-04 11:46:27	2019-11-04	Mrs. Esperanza Rau	mrs.esperanza.rau@warmmail.com	Portland	Oregon	3400498918534294	999dda972516b506d1e6628b68d20d54	American Express	45.6211129356529526	-122.727801288012415
4796	2019-11-04 11:53:38	2019-11-04	Miss Dannielle Stehr	miss.dannielle.stehr@geemail.com	San Diego	California	4439001428609415	42925e96b0c1cc9d13babad1df9e9f4a	American Express	32.8415949874158954	-117.114175747279077
4797	2019-11-04 13:00:07	2019-11-04	Kelby Kuvalis-Hansen	kelby.kuvalis.hansen@geemail.com	Pompano Beach	Florida	210014466109580347	2c224474c24b0bb6abed2e39ef3f1264	JCB 15 digit	26.276747929331286	-80.1300029036901833
4798	2019-11-04 13:10:13	2019-11-04	Davin Feest-Kunze	davin.feest.kunze@warmmail.com	San Francisco	California	3780156752997463	47b5338ae71c64e61a2df92b9b93bc6d	VISA 16 digit	37.7322892768767701	-122.447632117147137
4799	2019-11-04 13:19:05	2019-11-04	Octa Konopelski	octa.konopelski@warmmail.com	Macon	Georgia	589326513966551	68f02ed9abc8820b7f4c5b85852ac254	Discover	32.8505200431227635	-83.7754421039212502
4800	2019-11-04 13:26:23	2019-11-04	Kenji Sauer	kenji.sauer@warmmail.com	Oakland	California	4628572133009159	a6a546d449edfc1ef558c1005ad88c9f	VISA 16 digit	37.8129838319792313	-122.275798541149129
4801	2019-11-04 13:58:33	2019-11-04	Alannah Volkman	alannah.volkman@geemail.com	Berkeley	California	3528103802825168938	3bd6b2eb4a49b02c352de38e052cab95	Voyager	37.8430043239765794	-122.296848878494302
4802	2019-11-04 14:02:40	2019-11-04	Jaycie Parker DDS	jaycie.parker.dds@geemail.com	New York	New York	6011061466596750371	5855e12b31c375d5c239d1b440731cb1	JCB 15 digit	40.7602695627361555	-73.8885824602924259
4803	2019-11-04 14:03:12	2019-11-04	Dr. Florian Gottlieb	dr.florian.gottlieb@geemail.com	Philadelphia	Pennsylvania	3096367681679759351	e9e53805ef33607d636c4bc0f15d89c0	Mastercard	40.0576361656147952	-75.1473906246844763
4804	2019-11-04 14:40:57	2019-11-04	Anabelle Haag	anabelle.haag@geemail.com	San Francisco	California	869996639141251868	2e75b5dcb3c8424e8b0d524273cffd77	VISA 13 digit	37.7568585154733185	-122.430492104531965
4805	2019-11-04 17:00:35	2019-11-04	Michaele Dickinson	michaele.dickinson@woohoo.com	Durham	North Carolina	6011838002806217216	933c73af69f9ecac098e49c2e4894a7a	Voyager	35.9516088462214896	-79.0011795450370755
4806	2019-11-04 17:28:49	2019-11-04	Mrs. Magen Eichmann	mrs.magen.eichmann@geemail.com	Killeen	Texas	3709997861239158	835026d3537a0864be778fc316502d83	Discover	31.0261301241580405	-97.636731556819754
4807	2019-11-04 17:31:05	2019-11-04	Janiah Nader DVM	janiah.nader.dvm@geemail.com	Hayward	California	869957244364287173	62084df6b8d06a10081e6fa36cfdd414	Discover	37.7052806343406459	-122.12413632001504
4808	2019-11-04 18:10:00	2019-11-04	Dr. Leda Corkery	dr.leda.corkery@warmmail.com	Toledo	Ohio	869968996634053126	02836dbfd37adcfa7c113cf108edfa38	JCB 16 digit	41.7350625046700188	-83.4917269772250279
4809	2019-11-04 19:00:18	2019-11-04	Jadyn Hegmann	jadyn.hegmann@warmmail.com	Hillsboro	Oregon	3045418450629240	131c0c637f396a2a51ddd9058f3fc65b	Mastercard	45.5180579386390747	-122.982633995280409
4810	2019-11-04 19:43:56	2019-11-04	Dr. Josh Lemke	dr.josh.lemke@geemail.com	San Francisco	California	53444687697744868	22c09bac14e1e1c539ac5c659fb56ec2	Voyager	37.7620829144244041	-122.429980020679039
4811	2019-11-04 19:46:39	2019-11-04	French Batz	french.batz@geemail.com	West Palm Beach	Florida	4796863417214896	d87a5e578fd7b95362cee0fd70e58bcb	Mastercard	26.8098619935881359	-80.0793814364656811
4812	2019-11-04 20:11:20	2019-11-04	Dina Ruecker	dina.ruecker@geemail.com	San Francisco	California	3043084589603084	1f4fbec963a061556972cf03f0f2ed77	Mastercard	37.7755760399084579	-122.45284651271632
4813	2019-11-04 20:27:39	2019-11-04	Mariyah Will	mariyah.will@geemail.com	San Francisco	California	6011739386305821606	b5f05ff482b7f2e136b094cf032a1831	Mastercard	37.7951504873640474	-122.416360420958185
4814	2019-11-04 20:31:41	2019-11-04	Bluford Christiansen	bluford.christiansen@geemail.com	Cedar Rapids	Iowa	180009371080974252	88ba9d7c4f8e6e69430059963ca0caf7	VISA 13 digit	41.883462991852312	-91.5813143991932321
4815	2019-11-04 20:32:17	2019-11-04	Matt Wisozk	matt.wisozk@woohoo.com	New York	New York	3088938984383769652	ccfaf346f9fb700ee2fc6ada52c6a351	Voyager	40.7185956885330356	-73.9652523588750483
4816	2019-11-04 20:33:32	2019-11-04	Rhoda Dickens-Pfeffer	rhoda.dickens.pfeffer@geemail.com	Berkeley	California	3758468113442875	c3e13c8a0f333b2a120051f396993409	VISA 16 digit	37.8994910672797403	-122.274980157507002
4817	2019-11-04 22:31:16	2019-11-04	Dr. Dangelo Parker	dr.dangelo.parker@woohoo.com	Oakland	California	4226564525658186	4e8ba0e47cba24707e3d9130594bf573	Diners Club / Carte Blanche	37.8215026177023717	-122.285496528433939
4818	2019-11-04 23:03:10	2019-11-04	Beckett Moore	beckett.moore@woohoo.com	Richmond	Virginia	3025261058258594	df8edd07d86531f76d4d3cd0bdd5ccb6	JCB 16 digit	37.4897069536369258	-77.4095741894785334
4819	2019-11-04 23:49:57	2019-11-04	Kristin Durgan	kristin.durgan@warmmail.com	El Monte	California	501879060266578	54c30f1581463dd7fc6a9e2846f476da	Mastercard	33.9925373664315771	-118.028925841886917
4820	2019-11-05 00:39:58	2019-11-05	Heriberto Walker MD	heriberto.walker.md@warmmail.com	Mesa	Arizona	6011709742648286251	5dd1ea563b58489600322d9c8aed14d8	JCB 16 digit	33.4906948227580585	-111.632054640946535
4821	2019-11-05 00:58:59	2019-11-05	Elmyra Kihn	elmyra.kihn@geemail.com	Naperville	Illinois	180021552046812579	5e54697e4cfc1ae8a8690acbc4d9cd4c	Discover	41.8340280325066303	-88.1196863528229386
4822	2019-11-05 02:00:18	2019-11-05	Dr. Shaquille Kassulke	dr.shaquille.kassulke@geemail.com	Grand Rapids	Michigan	4914267719868598	e29f7ba1a21e9e5f35dff8a76be5dd0c	VISA 16 digit	42.9619784027140597	-85.677761304298798
4823	2019-11-05 02:08:23	2019-11-05	Merlyn Watsica	merlyn.watsica@geemail.com	San Francisco	California	6011322876666606730	dbd74be51fa229be0ede3ec8cff80cdf	Maestro	37.7706648482923768	-122.42490606923414
4824	2019-11-05 02:23:54	2019-11-05	Lucina Block-Willms	lucina.block.willms@geemail.com	Houston	Texas	3029785528355958	45ecba58314bf6050ecc1cdde3477872	JCB 16 digit	29.7825921289701014	-95.3556549990099001
4825	2019-11-05 02:40:26	2019-11-05	Janyce Pfannerstill-Smitham	janyce.pfannerstill.smitham@geemail.com	Oakland	California	4951432203328756	99438fd3b2ffc1196222a31bb9bed8df	Maestro	37.8130708685594641	-122.24548643470078
4826	2019-11-05 04:06:30	2019-11-05	Jaycob Tromp	jaycob.tromp@woohoo.com	Albuquerque	New Mexico	180090700284070907	2e5c526ec9fbe5bae9dc13ca45fe1948	Discover	35.1930344406649525	-106.566826242494955
4827	2019-11-05 04:17:47	2019-11-05	Regan Mante	regan.mante@warmmail.com	San Francisco	California	6011726047632831834	90411f52692cecc2c28f34f47ad54770	Voyager	37.7656364730903746	-122.478628289569272
4828	2019-11-05 05:26:15	2019-11-05	Camilla Orn	camilla.orn@geemail.com	Thornton	Colorado	4801218078243101	ddc9bffef837fc331de5f713fa9bbc05	VISA 16 digit	39.8841321663331243	-105.020137964344769
4829	2019-11-05 05:56:57	2019-11-05	Britt Wilkinson	britt.wilkinson@geemail.com	Albuquerque	New Mexico	3028188135111719	34e3bb9cd75924872880bd5c1c0219d7	Maestro	35.20318232920431	-106.556093706057965
4830	2019-11-05 05:57:14	2019-11-05	Sussie Gusikowski	sussie.gusikowski@geemail.com	Pomona	California	4359250545738	77069c7708edbd3e35e492711b52f529	Voyager	34.0695383930616131	-117.708886713903766
4831	2019-11-05 06:40:48	2019-11-05	Mack Blick-O'Reilly	mack.blick.o'reilly@woohoo.com	Bridgeport	Connecticut	3088748586318301756	4c99ce248f036e55998d8cdcbc4f4e23	JCB 15 digit	41.172708735677972	-73.2061806573431966
4832	2019-11-05 07:36:09	2019-11-05	Davonte Macejkovic	davonte.macejkovic@geemail.com	El Paso	Texas	210059779257811744	77ecba4118bf4ad31a5fe810b160b61a	Diners Club / Carte Blanche	31.8530162186656156	-106.47585108456947
4833	2019-11-05 07:40:45	2019-11-05	Helene O'Reilly	helene.o'reilly@geemail.com	Berkeley	California	3158489544800691260	e2d2893f8acb74bdf9f5dda2ca942a24	Diners Club / Carte Blanche	37.8568566027412743	-122.301665837126862
4834	2019-11-05 08:14:26	2019-11-05	Penni Welch	penni.welch@woohoo.com	San Francisco	California	3528372807549313326	973e89f21b1ded059e95dbc490a4ffd1	VISA 13 digit	37.7604455123984124	-122.447921272075519
4835	2019-11-05 08:14:52	2019-11-05	Ms. Nadine Beier	ms.nadine.beier@geemail.com	Ontario	California	180006503007248930	fb03fe82f9863149b01acce84a70f924	Discover	34.1230595015134668	-117.544328493728116
4836	2019-11-05 08:16:32	2019-11-05	Kacy Cartwright	kacy.cartwright@geemail.com	Odessa	Texas	3528853426089973528	8704bff78d37366bec25dfadbce3e970	VISA 13 digit	31.9023251671355226	-102.289931454711038
4837	2019-11-05 09:11:33	2019-11-05	Filomena Feest DDS	filomena.feest.dds@geemail.com	New York	New York	53202769587122322	e88144c776e872cd3812de4f01f76418	Discover	40.6244782964456803	-73.924784951506922
4838	2019-11-05 10:10:35	2019-11-05	Joan Gislason	joan.gislason@geemail.com	Berkeley	California	639084368265645	29997136a8be1b768249afb0e7740522	JCB 16 digit	37.8467635800213884	-122.242356900618972
4839	2019-11-05 10:51:18	2019-11-05	Deonte Morissette	deonte.morissette@geemail.com	Round Rock	Texas	180057267232281201	e5e2385014878af2a75388384dce2106	JCB 16 digit	30.5552970183219763	-97.5728023830186544
4840	2019-11-05 11:09:38	2019-11-05	Mateo O'Keefe	mateo.o'keefe@geemail.com	Oakland	California	4844773176434274	84291f9ca0f9d421714afce303365dcc	JCB 16 digit	37.7899642316650386	-122.301309360078264
4841	2019-11-05 11:35:53	2019-11-05	Antwon Hilll V	antwon.hilll.v@geemail.com	Berkeley	California	675943571633353	f41298d0e38843111e3573dd7ee60dac	Maestro	37.8883681504009857	-122.254927962931532
4842	2019-11-05 13:30:17	2019-11-05	Zain Gutkowski	zain.gutkowski@geemail.com	Sacramento	California	869989401232696801	f2e13524e880d0e1c652d769f8a3eeb2	Discover	38.5862104962844441	-121.374090256100885
4843	2019-11-05 14:06:31	2019-11-05	Aydin Blanda-Schulist	aydin.blanda.schulist@geemail.com	Oakland	California	4962182918169923	7ce23aa6c56b4e9ee87abd1e4c82f0ad	JCB 16 digit	37.789446607619773	-122.285180150107678
4844	2019-11-05 15:06:28	2019-11-05	Dr. Terry Osinski	dr.terry.osinski@warmmail.com	Washington	District of Columbia	3088087557461197605	c01eaa3ffc2a4a233984be10177950d5	Voyager	38.8641372551940378	-76.9700715785592848
4845	2019-11-05 15:07:58	2019-11-05	Miss Kelley Kohler	miss.kelley.kohler@geemail.com	Durham	North Carolina	3096234467665113170	ff7503de511473edb0ba7268265f9861	American Express	35.9550314279519014	-78.9346349053453622
4846	2019-11-05 15:22:36	2019-11-05	Ira Spencer	ira.spencer@warmmail.com	San Francisco	California	6011922945478947972	f523fb204dc66e99ad44c3e63bd69b9f	JCB 16 digit	37.7673417874199089	-122.455627235452653
4847	2019-11-05 15:29:43	2019-11-05	Burrel Bailey	burrel.bailey@woohoo.com	Berkeley	California	3032233068094130	84a56c899710e9e321c9f9c714bca028	VISA 13 digit	37.8667823987754701	-122.249175787496
4848	2019-11-05 16:07:25	2019-11-05	Gearld Pagac	gearld.pagac@geemail.com	Houston	Texas	3002248530043168	db1e2e9f811ceec648b48bf9b4398f4f	VISA 13 digit	29.8724198841102435	-95.3606587287984837
4849	2019-11-05 17:44:10	2019-11-05	Dr. Arnie Stamm	dr.arnie.stamm@geemail.com	Plano	Texas	3528948123946185225	1d9254ae5544e3391a605a34b33dd770	JCB 16 digit	33.0692457303490528	-96.6988966610930873
4850	2019-11-05 18:46:24	2019-11-05	Coy Maggio-Schimmel	coy.maggio.schimmel@geemail.com	San Francisco	California	210031099188865948	358bf9137b63fb068e7a52af7b954fc1	Discover	37.7874756089951447	-122.442502684129991
4851	2019-11-05 18:47:37	2019-11-05	Andy Lind	andy.lind@woohoo.com	Edison	New Jersey	4417069821258136	b0fb41a3ad224bde6d7c60252b9fe996	VISA 16 digit	40.501866326756776	-74.3750746422499418
4852	2019-11-05 19:34:30	2019-11-05	Raven Brekke	raven.brekke@geemail.com	San Francisco	California	6011350725743087932	669bab2b3363fb2c20522c44667fae33	JCB 15 digit	37.7865645866072484	-122.45796741724412
4853	2019-11-05 20:14:56	2019-11-05	Cesar Kshlerin	cesar.kshlerin@geemail.com	San Jose	California	180061739234913951	f95a3d1c60c799847aaf6db2283d7574	Maestro	37.2986781364593654	-121.808176187028735
4854	2019-11-05 20:34:52	2019-11-05	Clarance Rath	clarance.rath@geemail.com	San Francisco	California	4710988925176593	a09a4ccfa19353f939abd3dab1e34fba	Maestro	37.8015111083972926	-122.4337987674555
4855	2019-11-05 20:39:19	2019-11-05	Dr. Shaquan Wilkinson	dr.shaquan.wilkinson@geemail.com	Los Angeles	California	502080769282916	3a5d80070f0d0b04bc8eeab648f6008e	VISA 16 digit	34.0396922355383609	-118.45197136998101
4856	2019-11-05 20:41:44	2019-11-05	Tobin Bernier I	tobin.bernier.i@geemail.com	San Francisco	California	6011406191202087208	a2de136bcfba14eb3e5de92d5ef11f90	JCB 15 digit	37.7511603374658691	-122.418601828920046
4857	2019-11-05 20:56:48	2019-11-05	Emmaline Grady	emmaline.grady@geemail.com	Miramar	Florida	51213935951441039	4ec050ab53714083a7adbb1b318c9739	Mastercard	25.9331616399325426	-80.4258282884947988
4858	2019-11-05 21:29:10	2019-11-05	Abraham Heller	abraham.heller@geemail.com	San Francisco	California	3417627305553910	3c34316fba9eabb75683575705c74e37	VISA 16 digit	37.7660520974773206	-122.433000002558728
4859	2019-11-05 22:49:02	2019-11-05	Shelbie Braun	shelbie.braun@geemail.com	Anchorage	Alaska	3088565051305097867	ea0db3cb40b76de46b0c32ef3a4a29d9	VISA 16 digit	61.1297011458996735	-149.247788620333381
4860	2019-11-05 23:43:28	2019-11-05	Eliana Ledner	eliana.ledner@geemail.com	Reno	Nevada	3112760152143922663	555d1287c2ba883b3a5f4efd3c3ab1d7	VISA 13 digit	39.4545740254767239	-119.899005988675739
4861	2019-11-05 23:55:56	2019-11-05	Lupe O'Hara-Boyer	lupe.o'hara.boyer@geemail.com	Denver	Colorado	3400653428922906	5d957eb2fb87724c94a2ff1135b35200	American Express	39.7825175438594059	-104.972921771394468
4862	2019-11-06 00:03:25	2019-11-06	Clarence Gorczany	clarence.gorczany@geemail.com	San Francisco	California	4563508352086491	625c3482454e60371fd13b5d43b803c8	Voyager	37.7739237030695705	-122.437173294502145
4863	2019-11-06 01:00:22	2019-11-06	Mr. Alexzander Pouros MD	mr.alexzander.pouros.md@geemail.com	San Francisco	California	3407928314383840	529265f71bdcbfd56d91476a2820cfe7	American Express	37.7676227011413914	-122.451553032536978
4864	2019-11-06 01:32:47	2019-11-06	Lemuel Satterfield	lemuel.satterfield@geemail.com	San Francisco	California	210001338873067980	d9c9ba91a694e0de0c4294f870a7661f	Mastercard	37.7704872622947008	-122.471607959266862
4865	2019-11-06 01:50:44	2019-11-06	Boss Dach	boss.dach@geemail.com	San Francisco	California	6011462898308927050	78015a517318fff949b3962375c7178d	VISA 16 digit	37.7504962682421947	-122.431103237586896
4866	2019-11-06 02:31:40	2019-11-06	Gustie Connelly	gustie.connelly@geemail.com	Arlington	Texas	4418406647655	eb6f35c0ac073e676c02e531ccf163c5	Voyager	32.6074241379059799	-97.128131646758689
4867	2019-11-06 02:46:11	2019-11-06	Orra Schuster-Ziemann	orra.schuster.ziemann@geemail.com	San Francisco	California	180049592393181341	24535c3b41f1342c4ab22e151f457cdd	VISA 13 digit	37.7784807644823601	-122.433987053803023
4868	2019-11-06 04:15:46	2019-11-06	Toccara Jacobs	toccara.jacobs@woohoo.com	Dallas	Texas	55357849281762715	273a83116d782cec8400a0ac9ef4f851	JCB 16 digit	32.8152476412050476	-96.7801188785079773
4869	2019-11-06 04:20:56	2019-11-06	Dequan Bernier MD	dequan.bernier.md@geemail.com	Berkeley	California	869919639058426408	41a9fc43e641902af033d9a98bd944a3	JCB 15 digit	37.8659126554977021	-122.250051081518791
4870	2019-11-06 04:36:44	2019-11-06	Dr. Zariah Ratke	dr.zariah.ratke@geemail.com	Berkeley	California	3018020110188463	b7bc4c6c8c1a9eb646882c4eafe2d68e	JCB 16 digit	37.8617603837572219	-122.286833563642674
4871	2019-11-06 05:32:07	2019-11-06	Ms. Amelia Lind	ms.amelia.lind@warmmail.com	Des Moines	Iowa	3412637871457318	e099228eb416fdfc70635fc2bb42d68c	Diners Club / Carte Blanche	41.6348001399751766	-93.560931605710465
4872	2019-11-06 06:07:04	2019-11-06	Dozier Collier II	dozier.collier.ii@warmmail.com	San Francisco	California	4141317904369632	166f4c9c6628ec96c387ca5c187732e3	JCB 16 digit	37.7711874960254619	-122.425307531816301
4873	2019-11-06 06:42:04	2019-11-06	Loren Murray III	loren.murray.iii@geemail.com	San Diego	California	180057378084328238	f8eb44b33e03dae548b3f6baa7534006	Discover	32.8589023519840069	-117.174036337193101
4874	2019-11-06 06:54:52	2019-11-06	Dr. Damarion Skiles	dr.damarion.skiles@geemail.com	Berkeley	California	6011957574927777760	c022b75ded7c937f8136d00e0883f7b7	JCB 16 digit	37.8443902808355688	-122.272194688451592
4875	2019-11-06 07:02:11	2019-11-06	Ward Dach	ward.dach@geemail.com	Meridian	Idaho	4252260002644156	f32d2174bca08dac4ca8c731d7b41126	VISA 16 digit	43.5801283587709065	-116.385754784144083
4876	2019-11-06 08:14:41	2019-11-06	Gregorio Feil	gregorio.feil@geemail.com	Hialeah	Florida	3029697423513237	537992338e8214250d4931e9b1e52d1c	JCB 16 digit	25.9651236524317426	-80.257913001570472
4877	2019-11-06 09:10:35	2019-11-06	Mrs. Janette Friesen MD	mrs.janette.friesen.md@geemail.com	Oakland	California	060472763384665	3580fd3b0fded2ae65bfb7ecc204a370	Diners Club / Carte Blanche	37.8018384626413066	-122.283528934512034
4878	2019-11-06 11:23:45	2019-11-06	Duke Larson-Turcotte	duke.larson.turcotte@geemail.com	St. Petersburg	Florida	589321409107071	99c28e8b60e3ceba9d3a0c3511511076	Mastercard	27.6874004974849512	-82.5980275783579714
4879	2019-11-06 11:48:09	2019-11-06	Mikala Mohr	mikala.mohr@geemail.com	Providence	Rhode Island	180069128080960054	d2f8c9110b2ec7230cf5d55f9aeb7119	VISA 13 digit	41.8169927242532324	-71.3511550565168307
4880	2019-11-06 11:55:15	2019-11-06	Karlene Gutmann	karlene.gutmann@woohoo.com	Pittsburgh	Pennsylvania	4468940784829	31fcd44f2ae5944af97ac480df774638	JCB 16 digit	40.360962368590009	-80.0272305381655684
4881	2019-11-06 12:34:44	2019-11-06	Elvie Eichmann-Howell	elvie.eichmann.howell@geemail.com	Tallahassee	Florida	4721393140166	92f8c78f0b9118a76fcccc9dac8c4c9a	Discover	30.4040632322452993	-84.3522779552280895
4882	2019-11-06 12:45:29	2019-11-06	Fran Larson	fran.larson@warmmail.com	Syracuse	New York	3043383120921298	2697ab89bb6d6c1b654e8d09484d6884	Diners Club / Carte Blanche	43.1292551630027532	-76.2307439772658171
4883	2019-11-06 12:55:10	2019-11-06	Phyliss Connelly	phyliss.connelly@geemail.com	Los Angeles	California	4878920814816052	cf37ed8a8a57ca4611b8898fec9389c6	American Express	34.0559053432062271	-118.39692811793573
4884	2019-11-06 13:26:10	2019-11-06	Scarlett Huels	scarlett.huels@warmmail.com	Berkeley	California	4322678865908705	eacd6d3f7c06a167ccaded3036391cc2	Diners Club / Carte Blanche	37.8631136236348027	-122.279252609840626
4885	2019-11-06 13:48:00	2019-11-06	Roy Will-Weissnat	roy.will.weissnat@geemail.com	Wichita	Kansas	3055746426071158	fe36ab13feee113acb160dcd1e5641d1	Discover	37.6090800582773994	-97.3285429215725486
4886	2019-11-06 13:52:04	2019-11-06	Chantelle Abernathy	chantelle.abernathy@geemail.com	San Francisco	California	6011167770275625090	c4f6d9074a0316ffebd1d0a01d828316	Voyager	37.7500359844768454	-122.421842592892787
4887	2019-11-06 14:05:54	2019-11-06	Carl Lehner	carl.lehner@geemail.com	Houston	Texas	3528682785139284476	3f525399c4ac5a062963d3320f991da3	VISA 16 digit	29.7308253992427147	-95.3366202100195039
4888	2019-11-06 14:28:55	2019-11-06	Shiloh Walker	shiloh.walker@geemail.com	Grand Rapids	Michigan	6011201498560465125	6cbbfbb37e287a84de0850a6cad0612e	American Express	42.8802874896943536	-85.7393136034853853
4889	2019-11-06 14:34:02	2019-11-06	Elvira Schaefer	elvira.schaefer@geemail.com	San Francisco	California	3049439448985250	f25eb612ebef5422d8de7f9816973de2	American Express	37.8076251337767104	-122.459701957438398
4890	2019-11-06 15:08:12	2019-11-06	Texanna Stiedemann	texanna.stiedemann@warmmail.com	Omaha	Nebraska	4491018360540213	dda5bf6ac5793e8f243b21e47ebadd49	Discover	41.1948760195780537	-96.0292406419407598
4891	2019-11-06 15:46:01	2019-11-06	Dr. Jaycee Schulist	dr.jaycee.schulist@geemail.com	San Francisco	California	52127186282654123	933cdb810f8078b31b754f71ba4f80a6	VISA 16 digit	37.7681311105321456	-122.458666406834382
4892	2019-11-06 16:15:10	2019-11-06	Lamont Heidenreich	lamont.heidenreich@geemail.com	Temecula	California	53753710167888364	d45eff0c7b4da75d62b268aaa107f196	VISA 13 digit	33.4167753803212193	-117.072921765242512
4893	2019-11-06 16:37:34	2019-11-06	Gage Strosin	gage.strosin@geemail.com	Huntington Beach	California	3528108437260080770	54055be13b14cd14a1e74fcf3f0447b4	Diners Club / Carte Blanche	33.7612017738673842	-117.945011954766883
4894	2019-11-06 17:31:15	2019-11-06	Rex Erdman-Hahn	rex.erdman.hahn@geemail.com	Lakewood	Colorado	210084117091944570	cef672e9a1af784f522ad1b9b2d758ea	American Express	39.6010268149372209	-105.027529641243063
4895	2019-11-06 18:25:33	2019-11-06	Yaretzi Kshlerin-Marvin	yaretzi.kshlerin.marvin@woohoo.com	West Covina	California	210047391562037877	9aa27d366161ea0c858844f4e5dbb58e	VISA 16 digit	34.0493173766057922	-117.870811233350622
4896	2019-11-06 19:10:07	2019-11-06	Teagan Lockman	teagan.lockman@geemail.com	Durham	North Carolina	4116166298546953	977a9544b9d54e03dcc511fb63ef0a19	JCB 15 digit	35.9598689416203641	-78.9349550245698595
4897	2019-11-06 19:42:04	2019-11-06	Tobias Turcotte-Hayes	tobias.turcotte.hayes@warmmail.com	Reno	Nevada	6011791722912147735	38cfe20c6ab5f15129ad55b433783329	Mastercard	39.5321951963085709	-119.815621450187265
4898	2019-11-06 19:44:49	2019-11-06	Kayleen Von	kayleen.von@geemail.com	Las Vegas	Nevada	4974014068323321	c7eddf8851d6b7a94e514ca19aecb038	American Express	36.1982290425438435	-115.316741560140997
4899	2019-11-06 20:32:02	2019-11-06	Tarik Simonis	tarik.simonis@geemail.com	New York	New York	210002006465142334	e2724190830a47de83440fa76ae62602	VISA 16 digit	40.6917074056100105	-73.9656160483963703
4900	2019-11-06 21:18:01	2019-11-06	Marian Bednar	marian.bednar@woohoo.com	Birmingham	Alabama	4855011780902	131d1996b59281d67a1ca25acbfb9a63	JCB 15 digit	33.452984428152071	-86.8457086026910758
4901	2019-11-06 21:41:21	2019-11-06	Ms. Sharonda Mayert DDS	ms.sharonda.mayert.dds@geemail.com	San Francisco	California	3046746352585097	54bb0ad2daa8585c9160e1d944746e2b	JCB 16 digit	37.7746724808161076	-122.416643385975362
4902	2019-11-06 22:00:14	2019-11-06	Kendall Dibbert	kendall.dibbert@geemail.com	San Antonio	Texas	869900589532372473	de392316586063537adec15bd3944300	VISA 16 digit	29.4691599883209925	-98.5487994122155015
4903	2019-11-06 22:24:48	2019-11-06	Gerri Little	gerri.little@geemail.com	Santa Rosa	California	869918530675129684	b5f14c7236feff3a09706fc6938a4a2d	VISA 16 digit	38.4251095903694662	-122.729575484969104
4904	2019-11-06 22:32:55	2019-11-06	Waldemar Beier IV	waldemar.beier.iv@geemail.com	Berkeley	California	869962777875588368	f41564b55e433de669ff5b14af5b885e	VISA 16 digit	37.8818539695955963	-122.275219096213277
4905	2019-11-06 22:34:10	2019-11-06	Caesar Dietrich II	caesar.dietrich.ii@woohoo.com	Tampa	Florida	4177583703885	92aea8f6eecaa336e7b0d20ef1d02c6d	American Express	28.0024350780643516	-82.529340545248985
4906	2019-11-06 22:38:41	2019-11-06	Syreeta Bergnaum	syreeta.bergnaum@geemail.com	Berkeley	California	503813124273965	9fa2a2d4b614e9feaa237a6a90f347d0	JCB 15 digit	37.8766020188185877	-122.2812612082801
4907	2019-11-06 23:07:42	2019-11-06	Mathews O'Conner	mathews.o'conner@geemail.com	Nashville	Tennessee	4685925894105428	dfc8f0816418b7e9aab54f8cf124b665	Discover	36.2022741448257079	-86.7255340533703531
4908	2019-11-06 23:53:49	2019-11-06	Rosie Tremblay	rosie.tremblay@geemail.com	San Diego	California	869900096909404152	ccfe5193343b651ce3a63dd0894ea02a	JCB 16 digit	32.8495196554411208	-117.187375879231851
4909	2019-11-07 00:37:48	2019-11-07	Brendan Reichel	brendan.reichel@geemail.com	Oklahoma City	Oklahoma	55702304762320809	00ad351fc6a18670c855114ccc653402	Diners Club / Carte Blanche	35.4057886531021495	-97.5784468594834209
4910	2019-11-07 00:43:36	2019-11-07	Assunta Turcotte	assunta.turcotte@geemail.com	Philadelphia	Pennsylvania	210022274598360308	7916d9afae40a6be1187c640a3406e9c	VISA 16 digit	40.0882576014805565	-75.0817955572988893
4911	2019-11-07 01:05:37	2019-11-07	Ms. Vennie Swift DDS	ms.vennie.swift.dds@geemail.com	Austin	Texas	180032840970715810	b30b7567c5e12d98a6573fa52c995b02	JCB 16 digit	30.2689368479546133	-97.7900606988236376
4912	2019-11-07 01:20:05	2019-11-07	Baxter Homenick	baxter.homenick@warmmail.com	Corpus Christi	Texas	869943657593156652	d757c7699c93782f218908e5e39587b2	Diners Club / Carte Blanche	27.8373318895168609	-97.0966166395056973
4913	2019-11-07 01:27:11	2019-11-07	Selma Turner	selma.turner@geemail.com	Memphis	Tennessee	3008423945032353	6aed33cb44bb0419b360a546484c20c4	VISA 13 digit	35.1978974163133671	-89.9496719856537936
4914	2019-11-07 01:32:22	2019-11-07	Rupert Farrell	rupert.farrell@geemail.com	San Francisco	California	3158434891126008802	ea5296411dbb9a549f3b4e97985a5257	Discover	37.780347332236687	-122.3880201198386
4915	2019-11-07 01:47:05	2019-11-07	Dr. Aretha Lynch MD	dr.aretha.lynch.md@woohoo.com	Albuquerque	New Mexico	4545880487438217	c24c8d9db7902c7121ca1424657ff1f1	Voyager	35.0332512781623748	-106.724253745337577
4916	2019-11-07 02:27:42	2019-11-07	Jodie Barton-Balistreri	jodie.barton.balistreri@geemail.com	San Francisco	California	3096355931980725375	04e630f6c0c47805de935a7cd12f3094	Voyager	37.7536688088885271	-122.430601767831575
4917	2019-11-07 02:29:56	2019-11-07	Mrs. Caddie Farrell MD	mrs.caddie.farrell.md@geemail.com	Reno	Nevada	3096523925651444776	035db77ea97d599c97fea0410e969da3	JCB 16 digit	39.6408952703312067	-119.938814575893431
4918	2019-11-07 02:50:15	2019-11-07	Pat Hettinger	pat.hettinger@woohoo.com	Berkeley	California	869938524860460067	47c6c9a2225ac763d9328dd5cc5c47c8	Voyager	37.8348867555601132	-122.294022835307743
4919	2019-11-07 03:33:14	2019-11-07	Holly Hettinger	holly.hettinger@geemail.com	Kansas City	Missouri	4951917170795540	c7df19ae04f0692c6b1c49f4d18e525f	JCB 15 digit	39.1330652681481155	-94.6225030786581414
4920	2019-11-07 03:50:46	2019-11-07	Purl Gulgowski	purl.gulgowski@geemail.com	San Francisco	California	4007908728931665	fe42227eb4016bfe839ba69d0aa78c54	Maestro	37.7667007218645878	-122.42880919984232
4921	2019-11-07 03:58:57	2019-11-07	Mandie Gibson	mandie.gibson@geemail.com	San Francisco	California	3462988739324565	db8bd1fec9c20a1f6ce4af56fc4e6da9	Voyager	37.785762163816706	-122.461781374931462
4922	2019-11-07 04:45:48	2019-11-07	Susan McDermott-Harber	susan.mcdermott.harber@geemail.com	San Francisco	California	53096717458563396	721d7e189cde0583d1e2f47f31cd2907	Maestro	37.7777464216328696	-122.460091723440627
4923	2019-11-07 04:56:51	2019-11-07	Yoshio Simonis-Cummings	yoshio.simonis.cummings@geemail.com	Dallas	Texas	3017995292708298	6afb569fcb53c9447345834984950e8c	VISA 13 digit	32.8207523455184003	-96.7878532183319322
4924	2019-11-07 04:58:13	2019-11-07	Skylar Bergnaum	skylar.bergnaum@geemail.com	Oklahoma City	Oklahoma	4107202753117443	9e98691d01c4eb87795ecd95217b0d2b	JCB 15 digit	35.4278711004093338	-97.565756247275317
4925	2019-11-07 05:07:54	2019-11-07	Dr. Rhys Schimmel	dr.rhys.schimmel@geemail.com	Long Beach	California	6011409532677866591	c41e7763954a9748264b7a9048687e8b	VISA 13 digit	33.8528646142508833	-118.206644813359901
4926	2019-11-07 05:52:22	2019-11-07	Coralie Langosh-Langosh	coralie.langosh.langosh@warmmail.com	Fort Lauderdale	Florida	3528922138731326586	7264321790e2a171a376d388960acbef	Mastercard	26.1684028055507696	-80.0591385214410707
4927	2019-11-07 05:53:48	2019-11-07	Dr. Davis Veum Sr.	dr.davis.veum.sr.@geemail.com	Philadelphia	Pennsylvania	4892782357017569	d2443aad2a1092d5d93b25d6c2133e36	VISA 13 digit	40.0913893864449093	-75.0854358142606912
4928	2019-11-07 06:52:26	2019-11-07	Pollie Pollich	pollie.pollich@geemail.com	New York	New York	869997260703277263	2bd22397555d3994b5cd868103169fa4	JCB 16 digit	40.5957121991775907	-73.9965984046820466
4929	2019-11-07 07:06:18	2019-11-07	Claudette Hirthe	claudette.hirthe@geemail.com	San Francisco	California	55415816557798160	091f7cc6eebff34e3ffc58ec6297bc08	Mastercard	37.7381543278960905	-122.384689159467527
4930	2019-11-07 07:20:19	2019-11-07	Mr. Maceo Feil	mr.maceo.feil@geemail.com	Beaumont	Texas	3088173894870762777	5733f6bfbe40ee74a94002d538691d09	VISA 16 digit	30.1666278813105073	-94.2324110286563723
4931	2019-11-07 07:50:10	2019-11-07	Mrs. Antonia Cassin	mrs.antonia.cassin@woohoo.com	Miami	Florida	3528879644182752207	79b656a40ce10c2ea2f0b0e65abec451	Maestro	25.7236803686384121	-80.1522285204254104
4932	2019-11-07 08:02:05	2019-11-07	Alecia Marquardt-Abshire	alecia.marquardt.abshire@geemail.com	Philadelphia	Pennsylvania	3112240345086153052	0bc02896c2ede78b441846bf602661fa	VISA 16 digit	39.9342896955046811	-75.1053619483850952
4933	2019-11-07 08:13:40	2019-11-07	Kellen Mante-Ondricka	kellen.mante.ondricka@geemail.com	San Francisco	California	3096622592471970628	697221b611e092aa39d36180485c14f3	Discover	37.7934240271879389	-122.421783886405734
4934	2019-11-07 08:20:40	2019-11-07	Vernell Hartmann	vernell.hartmann@geemail.com	Hillsboro	Oregon	869999527300878679	e75dc8e390b2dd7a50ab431b6de48e20	JCB 15 digit	45.5906756023149953	-122.882393372633302
4935	2019-11-07 09:23:38	2019-11-07	Neoma Wilderman	neoma.wilderman@geemail.com	Woodbridge	New Jersey	55324247327216897	9521c5dce0647cb59e1ba9f40bb73b2a	JCB 15 digit	40.4780701211810054	-74.2422691061019862
4936	2019-11-07 09:53:21	2019-11-07	Ms. Essa Schamberger DDS	ms.essa.schamberger.dds@geemail.com	Phoenix	Arizona	51220709242860070	7027f311b57dd39151de19b28ecb7f07	VISA 16 digit	33.6309328995112367	-112.186112949850411
4937	2019-11-07 10:32:16	2019-11-07	Erich Rath	erich.rath@geemail.com	Berkeley	California	210010193952286665	ce6704d4d4f7303185febab54668bdb6	Discover	37.8706923170481744	-122.27678279827515
4938	2019-11-07 10:40:30	2019-11-07	Theodora Lowe MD	theodora.lowe.md@geemail.com	Long Beach	California	3112823657779476425	44169da23f460e7f93ae89ecd1333385	Voyager	33.9071719892144188	-118.219852376559004
4939	2019-11-07 11:16:01	2019-11-07	Nena Weber	nena.weber@warmmail.com	Murrieta	California	52113106448744457	1e0fcad8d0d80ba5681eb3e821221742	Discover	33.5848994780428711	-117.10459584727846
4940	2019-11-07 11:40:56	2019-11-07	Dr. Prudie Schoen	dr.prudie.schoen@geemail.com	Oakland	California	54974789856663281	5e45cbc0e64f8f05e4280b0bfa085c10	JCB 15 digit	37.7498797830867616	-122.274647136500874
4941	2019-11-07 12:32:45	2019-11-07	Orra Bauch	orra.bauch@geemail.com	Davenport	Iowa	6011696128552645085	f535160d412358c2bec3cfab05d0b241	Discover	41.4928719902675596	-90.6239161561206004
4942	2019-11-07 14:07:33	2019-11-07	Penni Fahey	penni.fahey@geemail.com	San Francisco	California	4334821902413851	05c7d1a7ce035fb43e1231d55481840a	VISA 13 digit	37.7730823424316213	-122.435885163624192
4943	2019-11-07 14:09:16	2019-11-07	Essie Green	essie.green@geemail.com	San Francisco	California	3096684320417408817	9781b7a37a18349ad0216f467e2f8c9b	VISA 16 digit	37.7863213200002761	-122.476010892849587
4944	2019-11-07 14:34:22	2019-11-07	Minna Vandervort	minna.vandervort@geemail.com	Laredo	Texas	3769404879286070	6e2f9e0ffaf2737210cb552d893bbec4	Diners Club / Carte Blanche	27.5519683712344623	-99.5673578233465548
4945	2019-11-07 14:48:55	2019-11-07	Ines Spinka	ines.spinka@geemail.com	New York	New York	4176229860666158	95826ffe7885ee20b43ebf64f80efa2f	VISA 13 digit	40.6445669071041067	-73.9833322621777683
4946	2019-11-07 15:29:40	2019-11-07	Lavonda Carter	lavonda.carter@warmmail.com	Henderson	Nevada	3096139781994067162	0e595e0708c95aadf36758df39b11bae	Mastercard	35.9282188605450088	-115.016587368507686
4947	2019-11-07 16:07:26	2019-11-07	Dr. Mace Cartwright	dr.mace.cartwright@geemail.com	San Antonio	Texas	3528187213805141235	f5d09dac7447ae170ff95054306a0846	Mastercard	29.5231694455329325	-98.4908025386579311
4948	2019-11-07 16:12:44	2019-11-07	Dr. Bettyjane Crist	dr.bettyjane.crist@geemail.com	New York	New York	675972181520965	8f964837daf77506f133260985cd823a	JCB 16 digit	40.6790617440585009	-73.8387470279250238
4949	2019-11-07 16:21:49	2019-11-07	Ms. Breann Parker	ms.breann.parker@geemail.com	New York	New York	4882462054637	afd21d39d8593761c6605c3d30e83f6f	Diners Club / Carte Blanche	40.6861442170795016	-73.9566427011869791
4950	2019-11-07 16:57:42	2019-11-07	Abbey Paucek	abbey.paucek@geemail.com	San Francisco	California	676209377758066	5c0b141b6388fd40e676f02c1d63a7eb	VISA 16 digit	37.8004223426180204	-122.464320758270631
4951	2019-11-07 20:03:06	2019-11-07	Justus Spinka	justus.spinka@warmmail.com	Fort Worth	Texas	210037286072994223	496f866c56678e2ba7673939ef1f5c6c	American Express	32.8629003533683743	-97.2671356873873663
4952	2019-11-07 20:54:47	2019-11-07	Knox Huels	knox.huels@geemail.com	Los Angeles	California	4040758414779350	245f6d5232e80fb87eaa9dd34b2b746f	Diners Club / Carte Blanche	34.0282162779342343	-118.336185764753438
4953	2019-11-07 21:10:45	2019-11-07	Jeb Hane DVM	jeb.hane.dvm@warmmail.com	Los Angeles	California	4393677102573649	b87b92c5182739329142097d58f458ee	Maestro	34.0233514112751934	-118.497738588321198
4954	2019-11-07 21:46:32	2019-11-07	Dr. Boston Ferry	dr.boston.ferry@geemail.com	San Francisco	California	3002564224291107	77ef4847caa367432566a451b67779ec	Discover	37.7388537920568226	-122.432106797315399
4955	2019-11-07 22:31:09	2019-11-07	Kimberli Buckridge	kimberli.buckridge@geemail.com	San Francisco	California	4131961020539958	00fd91bc7914d820db84dffe444aeb0a	VISA 16 digit	37.7406268580927886	-122.430741278598305
4956	2019-11-07 23:46:56	2019-11-07	Myrtis Gutkowski	myrtis.gutkowski@geemail.com	San Francisco	California	3158986209903295611	f8c99582fb2cebc1f52eef2709fd63cc	Discover	37.8145715523089052	-122.404325172522107
4957	2019-11-08 00:47:34	2019-11-08	Ms. Jordin Turcotte	ms.jordin.turcotte@geemail.com	Oakland	California	3096158127383842227	b04f47be6f03a5f0aef8ee3473beaf61	American Express	37.834206572690384	-122.274104109675719
4958	2019-11-08 01:07:20	2019-11-08	Ever Steuber	ever.steuber@geemail.com	Fort Wayne	Indiana	869936099437618325	1233940f6aa59b588f7462d32d281ea0	VISA 16 digit	41.1780032009135937	-85.0555017158608848
4959	2019-11-08 01:09:53	2019-11-08	Mr. Hudson Crooks	mr.hudson.crooks@geemail.com	San Francisco	California	4211158319367950	672ca407280734997eb050397cfd1691	VISA 13 digit	37.7667448037503632	-122.455890290318962
4960	2019-11-08 01:23:34	2019-11-08	Markita Nader-Walker	markita.nader.walker@geemail.com	San Francisco	California	639018603850001	5f8659ce26d6f39cef6311879e5b2886	VISA 13 digit	37.7706540758508069	-122.460442185545844
4961	2019-11-08 01:25:07	2019-11-08	Miss Ottilie Abshire MD	miss.ottilie.abshire.md@geemail.com	Warren	Michigan	54522835692080888	c83bae3b45726f27803bd051e2b77c0c	Voyager	42.4464481956787409	-82.999550606822595
4962	2019-11-08 02:07:06	2019-11-08	Mr. Merton Boyle I	mr.merton.boyle.i@geemail.com	Cleveland	Ohio	6011868719525106775	ddbab4f10ccdb3349a3e29f128d9a97d	JCB 16 digit	41.4396922026611847	-81.6240694520302128
4963	2019-11-08 02:23:30	2019-11-08	Stephaine Ferry-Runte	stephaine.ferry.runte@warmmail.com	San Francisco	California	6011807601414892745	145ded99ba7f653b041fac2964262da9	VISA 16 digit	37.7733035326775592	-122.455920797554299
4964	2019-11-08 03:32:59	2019-11-08	Hertha Blanda	hertha.blanda@woohoo.com	Broken Arrow	Oklahoma	3742283640085165	d8a2f73ab8eda20b05977cbbf54eaee0	American Express	36.129143926851448	-95.8552313297465446
4965	2019-11-08 03:58:50	2019-11-08	Ovid Wilkinson-Rowe	ovid.wilkinson.rowe@geemail.com	Oklahoma City	Oklahoma	869995894753687872	18688d258d73bea66a4b7204619ac936	JCB 16 digit	35.3708701642140753	-97.4200621064182428
4966	2019-11-08 04:29:38	2019-11-08	Junie Huel	junie.huel@geemail.com	Baton Rouge	Louisiana	4584190803067	9b873e16f7ebc48e9ced2fb2f1cd2f2b	VISA 16 digit	30.348003808523341	-91.1633902533087905
4967	2019-11-08 04:48:46	2019-11-08	Franz Russel II	franz.russel.ii@geemail.com	San Francisco	California	869949448769345574	1283777f6d801797480c9db5469c2c2e	JCB 16 digit	37.797490972923363	-122.464274574426071
4968	2019-11-08 04:48:49	2019-11-08	Lise Zulauf	lise.zulauf@geemail.com	Los Angeles	California	210029314562064388	3eeaab7ac5b0e8b5df39c5f54ef55961	JCB 16 digit	33.9844178862735617	-118.344967325077576
4969	2019-11-08 05:17:28	2019-11-08	Mrs. Delphia Hamill	mrs.delphia.hamill@geemail.com	Chesapeake	Virginia	180043769298824995	0b02b4e44c2de31f9fb79ef01ededeab	VISA 16 digit	36.5814311160944428	-76.3771908899147007
4970	2019-11-08 05:34:45	2019-11-08	Mrs. Sommer Stroman	mrs.sommer.stroman@geemail.com	Cleveland	Ohio	210016871606920292	b328e1291dc6af7861704b97a5cff526	VISA 16 digit	41.5645318957362306	-81.7142456051200696
4971	2019-11-08 05:44:12	2019-11-08	Johathan Hessel	johathan.hessel@geemail.com	Fort Worth	Texas	4008467746388126	06e0bad333f5f62e7492977e87afa2db	JCB 16 digit	32.6837236337419625	-97.2763876270789609
4972	2019-11-08 06:03:52	2019-11-08	Jeptha Kreiger	jeptha.kreiger@warmmail.com	San Francisco	California	3096499903608898550	2a894c6e21e8134eb79dff2535bab0fe	Voyager	37.8053362695184134	-122.414366050671404
4973	2019-11-08 06:05:17	2019-11-08	Mr. Arther Botsford MD	mr.arther.botsford.md@geemail.com	Oakland	California	869950223028296421	e91c30225794e17ca83811f363fb9307	Diners Club / Carte Blanche	37.8071705804154519	-122.27850634925251
4974	2019-11-08 07:32:57	2019-11-08	Spencer Bogan-Kunze	spencer.bogan.kunze@geemail.com	Springfield	Missouri	3419597276917550	0c2f2d059f74578a880942c98d3a3853	JCB 15 digit	37.2253731904745138	-93.2068475765466786
4975	2019-11-08 08:04:27	2019-11-08	Percival Hand	percival.hand@woohoo.com	Palm Bay	Florida	6011464014681252441	ba8abbf695774d9819ecfe5c312c4967	American Express	28.0209595648892247	-80.7520885850604628
4976	2019-11-08 08:07:33	2019-11-08	Lala Emmerich-Ward	lala.emmerich.ward@warmmail.com	Oakland	California	180096377942983070	97f2af6e83ea8ce097a6b22101bc9149	Discover	37.7902696174020534	-122.261686591851003
4977	2019-11-08 08:11:31	2019-11-08	Maeve Runolfsson DDS	maeve.runolfsson.dds@geemail.com	San Francisco	California	210025994917957487	978618fc1a8f66b41b8bb70857a125c7	Discover	37.7754191830846437	-122.427734442430364
4978	2019-11-08 08:33:23	2019-11-08	Mr. Dimitri Schumm	mr.dimitri.schumm@geemail.com	San Diego	California	52103450002318379	8429ab041ba58b54a99ebe619bda189a	Voyager	32.8746329449649934	-117.095806174948819
4979	2019-11-08 09:33:04	2019-11-08	Cicely Hoeger	cicely.hoeger@geemail.com	Wichita	Kansas	6011285198376488316	c075906bfa08572559a42b7f57d06910	Maestro	37.7025275427725148	-97.3530425917092685
4980	2019-11-08 09:59:09	2019-11-08	Ramon Sanford	ramon.sanford@warmmail.com	Riverside	California	503894508517888	4ec455cde27c765e2123e292b882c95f	Maestro	33.9163435619272278	-117.322104367657374
4981	2019-11-08 10:15:22	2019-11-08	Meda Terry	meda.terry@warmmail.com	San Francisco	California	3001831630379854	cdda239176a351e7c85bd259398de7d1	VISA 16 digit	37.7709671942062499	-122.460565834599677
4982	2019-11-08 10:36:08	2019-11-08	Mr. Ali Rice	mr.ali.rice@woohoo.com	Laredo	Texas	4595842396240182	c6303b8c12d9fe3505ae0d30d835a143	Diners Club / Carte Blanche	27.4629501216296106	-99.547274978506195
4983	2019-11-08 10:47:42	2019-11-08	Mr. Prosper Boyle III	mr.prosper.boyle.iii@geemail.com	New York	New York	503877440451258	cdabe68128dab71602e55a3771e137b0	Maestro	40.7309935126677161	-73.8548437008529817
4984	2019-11-08 11:07:43	2019-11-08	Alani Lockman	alani.lockman@geemail.com	San Francisco	California	3743660397574211	363e0a0ddf24b33fd9e89124c89538af	Mastercard	37.7761729775507291	-122.432028334254071
4985	2019-11-08 11:21:20	2019-11-08	Dr. Conner Mueller	dr.conner.mueller@geemail.com	Berkeley	California	3021487604510261	979158f84b9b5fe65a5276902be57571	VISA 16 digit	37.8708946561270139	-122.274811616909759
4986	2019-11-08 11:35:56	2019-11-08	Derrell Gottlieb	derrell.gottlieb@geemail.com	San Francisco	California	502019435645809	e37ec19047d1d060ac526523d91439ae	JCB 16 digit	37.7927409899893547	-122.434046895733601
4987	2019-11-08 12:30:33	2019-11-08	Admiral Kuhlman	admiral.kuhlman@warmmail.com	San Francisco	California	54704444959021469	b13701c68aa1af0804a811ba73002259	Voyager	37.8340561283914809	-122.425949800190281
4988	2019-11-08 12:37:55	2019-11-08	Giovanna Brakus-Bruen	giovanna.brakus.bruen@geemail.com	San Francisco	California	3044710695588681	186592eef11d6bdc3d283c61cef81b58	Maestro	37.7849014333776267	-122.422832979731965
4989	2019-11-08 13:23:42	2019-11-08	Elana Hodkiewicz	elana.hodkiewicz@warmmail.com	Albuquerque	New Mexico	3112407603778464578	0ce4dbae00dc1c169ce3f2a407dbc43d	American Express	35.1870626778010305	-106.572930613260354
4990	2019-11-08 15:04:30	2019-11-08	Elgie Morar PhD	elgie.morar.phd@geemail.com	Reno	Nevada	3017460952874286	8989aaa104910e912257b8e0b9d6a63f	Maestro	39.5382856436617729	-119.836341786307841
4991	2019-11-08 15:53:06	2019-11-08	Georgeann Kertzmann	georgeann.kertzmann@geemail.com	West Covina	California	210038954432231409	c22fd33fb9b0c36104fe7e996886ae4e	Maestro	34.0747603389076872	-117.989579937800386
4992	2019-11-08 16:51:15	2019-11-08	Miss Shara Anderson MD	miss.shara.anderson.md@geemail.com	San Francisco	California	869900993575280595	9cf35d43dcdf8df69c1766acfba55d60	JCB 16 digit	37.7909465072027331	-122.425167156521226
4993	2019-11-08 17:09:27	2019-11-08	Ms. Ricki Quitzon MD	ms.ricki.quitzon.md@geemail.com	San Francisco	California	4493570720821194	2ad48f97a9a44e44b4e6dcadd88c3b86	VISA 16 digit	37.8043171191801193	-122.406086277145704
4994	2019-11-08 18:05:37	2019-11-08	Bernadette Mayer	bernadette.mayer@geemail.com	Tacoma	Washington	51736033063997557	1f95bf0d6f09b063b86e8db55a4b947d	Discover	47.2042892623346333	-122.383363339421521
4995	2019-11-08 18:56:58	2019-11-08	Kimberly Cremin	kimberly.cremin@geemail.com	San Francisco	California	210079497966403242	3a111c897d2e7e52931f8525ff93dfb5	American Express	37.7749963432431528	-122.43037520058391
4996	2019-11-08 19:43:00	2019-11-08	Tonja Tromp	tonja.tromp@geemail.com	Berkeley	California	6011608675746835953	ae771ede7590c109dd096a85599efce2	VISA 16 digit	37.8396488231731922	-122.32602603258816
4997	2019-11-08 19:43:20	2019-11-08	Frances Kautzer	frances.kautzer@geemail.com	San Francisco	California	3112771761862390162	eb7ffa889ac2a5e121318738da114c18	Voyager	37.7660617004320684	-122.426318141583891
4998	2019-11-08 20:03:37	2019-11-08	Mikeal Williamson	mikeal.williamson@warmmail.com	San Francisco	California	4308710667772	a19a97a54932f9e2de826a577f74a422	Mastercard	37.7710186931969076	-122.429072964791246
4999	2019-11-08 20:11:29	2019-11-08	Mrs. Dena Thompson	mrs.dena.thompson@geemail.com	Odessa	Texas	6011571908920681833	8e245e049b01b2e1ff1ad295c8d1b268	JCB 16 digit	31.942678850145267	-102.431761256946615
5000	2019-11-08 20:13:28	2019-11-08	Beaulah Streich MD	beaulah.streich.md@warmmail.com	Anchorage	Alaska	4543395131659227	4de2153ac73582001bf9513f858df01e	VISA 16 digit	61.0798446489248477	-149.301450742327802
5001	2019-11-08 20:35:47	2019-11-08	Ari Ernser	ari.ernser@warmmail.com	Thornton	Colorado	6011408691258600372	2e500d363cc22ab7f2e094227eac9913	JCB 15 digit	39.8765950537618252	-105.034665885676816
5002	2019-11-08 20:58:39	2019-11-08	Arden Ryan-Heller	arden.ryan.heller@geemail.com	Cleveland	Ohio	180037965264291288	98315f9bdea6122bcacf27301e45a411	Voyager	41.4837486793603745	-81.7732134185504123
5003	2019-11-08 21:22:32	2019-11-08	Einar Huel	einar.huel@geemail.com	Wichita	Kansas	675908532546119	d4fcf21434c3e501f87afa4cbc5849cd	American Express	37.6040562560193266	-97.3880570346690746
5004	2019-11-08 21:38:06	2019-11-08	Lakeisha Botsford	lakeisha.botsford@warmmail.com	Chesapeake	Virginia	210036582549248370	aca2288369aee249c71f8aa43eb806f6	Maestro	36.7208081660565	-76.3809080196388095
5005	2019-11-08 21:39:14	2019-11-08	Geoffrey Daniel	geoffrey.daniel@woohoo.com	Peoria	Illinois	53416265051821673	d2731d83d501f2afde1189fa0392afdf	VISA 16 digit	40.8080623358823331	-89.6008484642837288
5006	2019-11-08 23:02:43	2019-11-08	Mckinley Reichel	mckinley.reichel@woohoo.com	Lakewood	New Jersey	501825386974650	41eae3810e25883066b144c6873f7c0b	VISA 13 digit	40.1145458210077166	-74.1341691858876572
5007	2019-11-09 00:40:09	2019-11-09	Enrique Ziemann II	enrique.ziemann.ii@warmmail.com	Manchester	New Hampshire	4435690962754241	d719ea8f9e45ce699f9ad8d2cd64e6d8	Mastercard	42.9620153471898334	-71.4409312490731594
5008	2019-11-09 01:24:38	2019-11-09	Tyriq Bins	tyriq.bins@geemail.com	Oklahoma City	Oklahoma	4546711039926749	a655b8a0add81eca3771450936f3f949	American Express	35.482931135353077	-97.4968965572666377
5009	2019-11-09 02:00:17	2019-11-09	Arletta Von	arletta.von@geemail.com	San Francisco	California	3436133584424482	12151f521adbbf12c7e7d855823a9fe2	JCB 16 digit	37.7881341806158133	-122.41227834170347
5010	2019-11-09 02:31:55	2019-11-09	Ms. Lota Ferry DDS	ms.lota.ferry.dds@geemail.com	New York	New York	6011911889418028068	f21e81b23c1a239d8cb5c44a93525766	JCB 15 digit	40.7614227459523804	-73.8516915227182125
5011	2019-11-09 02:57:16	2019-11-09	Ms. Elna McClure	ms.elna.mcclure@geemail.com	San Francisco	California	4040952376438	4689ea7761cc5bc4c3fa71fa750f59c1	VISA 16 digit	37.7723952055377978	-122.495985928881183
5012	2019-11-09 03:06:21	2019-11-09	Alec Krajcik	alec.krajcik@woohoo.com	San Francisco	California	502099392865863	ff03acbd0d9b2302b3ce4542ba032e5d	VISA 13 digit	37.7905519924637971	-122.438844425989487
5013	2019-11-09 03:13:39	2019-11-09	Davey Bradtke	davey.bradtke@geemail.com	Baton Rouge	Louisiana	676195869906206	a9394d9b1e4e09882d8e40e55e2c7ca3	Discover	30.5300977423533801	-91.0576210578545897
5014	2019-11-09 04:29:59	2019-11-09	Ireland Hammes	ireland.hammes@warmmail.com	San Francisco	California	4025057288651616	89aa63dc2e08f9f4f032000767257f66	Discover	37.7546642015614964	-122.424134805515664
5015	2019-11-09 04:35:09	2019-11-09	Case Howell	case.howell@woohoo.com	San Francisco	California	3096822367091191600	0433fcac8d2c2a4f41d69f50a24fc245	JCB 16 digit	37.753249044980798	-122.447188830077295
5016	2019-11-09 04:44:37	2019-11-09	Lupe Fahey	lupe.fahey@geemail.com	Baltimore	Maryland	4884227426993	34078c381bca5f96c5524016352226af	VISA 13 digit	39.2980761139187962	-76.5278377726227035
5017	2019-11-09 04:45:46	2019-11-09	Erlene Sauer	erlene.sauer@geemail.com	Arlington	Texas	210090026534591413	644404250f78f46da5daa43a03f2fb46	Voyager	32.6463830650567957	-97.0708923055816513
5018	2019-11-09 05:22:01	2019-11-09	Kiyoshi Batz	kiyoshi.batz@geemail.com	Centennial	Colorado	3461704374433368	edbfb0d68f99a23bf11c956e0835b2e3	Maestro	39.5853033899370601	-104.886166806321967
5019	2019-11-09 05:22:57	2019-11-09	Maddison Bauch	maddison.bauch@geemail.com	San Francisco	California	51785001850307470	f924facfe440fb064321d33f07a73bb3	JCB 16 digit	37.7619586541253369	-122.420654942706932
5020	2019-11-09 05:30:43	2019-11-09	Jahiem Kunze PhD	jahiem.kunze.phd@geemail.com	Louisville	Kentucky	3001519880467194	6dac0a624aba50360450949031223fdf	Diners Club / Carte Blanche	38.1440139851901634	-85.6887467237725957
5021	2019-11-09 05:57:21	2019-11-09	Dr. Herman Schaden Jr.	dr.herman.schaden.jr.@geemail.com	Stockton	California	4575377361373480	1ee15c4bc7e41f33dc40b4c77cb49a2d	Maestro	37.9436022423405248	-121.243906581084431
5022	2019-11-09 06:57:03	2019-11-09	Clifton Moen	clifton.moen@geemail.com	Virginia Beach	Virginia	6011305377591811645	be252181d441d6c300a2c237b6c0a5c4	VISA 16 digit	36.7914838132169137	-76.0959695346325589
5023	2019-11-09 07:02:39	2019-11-09	Orvel Gaylord	orvel.gaylord@geemail.com	Atlanta	Georgia	52851587655943815	cc85df83938885c696d18b1acea1172b	Maestro	33.7984474932119241	-84.4501548008106653
5024	2019-11-09 07:09:51	2019-11-09	Aedan Abernathy	aedan.abernathy@geemail.com	Burbank	California	3404047000776309	4e9c405a422d7488c3cb672241260bf0	Diners Club / Carte Blanche	34.2740501987677106	-118.269586593661089
5025	2019-11-09 07:11:27	2019-11-09	Emilio Pfannerstill	emilio.pfannerstill@geemail.com	Amarillo	Texas	3528356165376126166	3cd59738ce3736b6f8c768048693f0c9	VISA 16 digit	35.2627280000761161	-101.752613729969411
5026	2019-11-09 07:20:17	2019-11-09	Cloe Osinski	cloe.osinski@warmmail.com	Oakland	California	3741915882995509	13dea93f6c6d0c9797d088519bc6f3b0	VISA 13 digit	37.8286056281521468	-122.268261610836518
5027	2019-11-09 07:24:24	2019-11-09	Eduardo Nader	eduardo.nader@warmmail.com	San Francisco	California	3528688704464463724	8355f1cf13a7f1f4f5c9d178f803e9b3	Discover	37.7947512925715898	-122.400070020843017
5028	2019-11-09 08:12:08	2019-11-09	Rillie Stoltenberg	rillie.stoltenberg@geemail.com	Clinton	Michigan	53435045446474827	a9475931bcef75b68c64483ab429eb0b	JCB 16 digit	42.6347889396894715	-82.8680852369014218
5029	2019-11-09 08:26:50	2019-11-09	Miss Ether Bayer	miss.ether.bayer@geemail.com	Allen	Texas	4857869510032370	56c0f7d8becf3f364ea968c72a3839d9	JCB 16 digit	33.0149078068815172	-96.5861544078163803
5030	2019-11-09 08:36:56	2019-11-09	Khadijah Swaniawski	khadijah.swaniawski@geemail.com	Anaheim	California	4758542626487172	8090e2fa8780e0cf3aebdb7970287153	Maestro	33.8690229065082988	-117.67120704168677
5031	2019-11-09 08:41:49	2019-11-09	Amil Ledner	amil.ledner@geemail.com	Tallahassee	Florida	3709204769033076	7f8e926d608e601cf8b4c8b6c89e21d9	Voyager	30.4316041006263376	-84.3361414733357719
5032	2019-11-09 08:45:47	2019-11-09	Audra Stracke-Wolff	audra.stracke.wolff@geemail.com	Carlsbad	California	4791079354174242	a0b9e21995b66003b709fcdf38dc80fc	VISA 13 digit	33.1706990940436697	-117.249216567843405
5033	2019-11-09 09:44:10	2019-11-09	Ashleigh Harvey	ashleigh.harvey@geemail.com	San Francisco	California	4708105769622	93262a44c4d4890eab9c1539bfa4d1ea	Maestro	37.8033059428773086	-122.436785316925693
5034	2019-11-09 10:48:18	2019-11-09	Jory Armstrong	jory.armstrong@geemail.com	Miami Gardens	Florida	54604422809710623	d817f15d0cef07929e9640893de13475	American Express	25.9597558794949173	-80.1891284015741235
5035	2019-11-09 12:20:57	2019-11-09	Allen Ortiz	allen.ortiz@geemail.com	San Francisco	California	4182732365750197	a00508c6594f921db7f74e525c7bf55e	JCB 16 digit	37.7618036022760748	-122.408811246694441
5036	2019-11-09 13:15:21	2019-11-09	Robby Beatty-Fritsch	robby.beatty.fritsch@geemail.com	San Francisco	California	869982884224921864	2974bc38cf7deb06964b3e1b52eed54e	Maestro	37.8103491258407871	-122.445984638412867
5037	2019-11-09 13:29:32	2019-11-09	Federico Bahringer	federico.bahringer@geemail.com	Surprise	Arizona	869905084366113370	a3e24e2b6e5a90a38dc45e5f0b31652e	JCB 16 digit	33.7548313309665744	-112.522123650111993
5038	2019-11-09 13:53:45	2019-11-09	Laney Mante	laney.mante@geemail.com	San Francisco	California	675913082519573	abe452327541430a8e6dd25f45fcdbc7	Voyager	37.7711106417556337	-122.422551170150598
5039	2019-11-09 14:08:02	2019-11-09	Wilfrid Kuhic-Braun	wilfrid.kuhic.braun@geemail.com	San Francisco	California	3528304771883756552	adeafd1c4a0f916e97aea98ae3b39dec	American Express	37.7828203120495303	-122.420668555766085
5040	2019-11-09 14:33:45	2019-11-09	Fleet Wolff IV	fleet.wolff.iv@geemail.com	San Mateo	California	4254696002325650	42c809f1155bc7d1571fe683983cb873	JCB 16 digit	37.5672490653928364	-122.269839718597382
5041	2019-11-09 14:55:43	2019-11-09	Katlin Murray	katlin.murray@woohoo.com	San Francisco	California	4408747919301	c404a2e239d672aaa41a8d6a54bb8228	Discover	37.7503812898254978	-122.434296060330553
5042	2019-11-09 14:56:14	2019-11-09	Cam Hyatt	cam.hyatt@woohoo.com	Vancouver	Washington	3037449548933516	2bf1dec545734cec0f2fe1b2c191b4fa	JCB 15 digit	45.5712579038996282	-122.52299861214756
5043	2019-11-09 15:20:03	2019-11-09	Dr. Rosia Cormier	dr.rosia.cormier@geemail.com	Dallas	Texas	4749162098729746	6f73718d6a7f314209c638f86618e587	Discover	32.6952536541309229	-96.8197724238466435
5044	2019-11-09 15:40:29	2019-11-09	Buster Schoen-Sauer	buster.schoen.sauer@geemail.com	New York	New York	3407353073696466	a27e6d1519f8f1dcbc820f479f498223	VISA 16 digit	40.7018643118198966	-74.0010324060812508
5045	2019-11-09 15:49:35	2019-11-09	Amey Treutel	amey.treutel@geemail.com	San Antonio	Texas	180078422578589205	ee4f4f008b8d5ea9dee583d9c36436d8	VISA 16 digit	29.4194784111879777	-98.4737438150051929
5046	2019-11-09 15:50:29	2019-11-09	Foch Hartmann-Leffler	foch.hartmann.leffler@geemail.com	Torrance	California	3722817213832067	f3770bcf01e99074afa409ef4c7b0542	JCB 15 digit	33.7731288035772721	-118.329494821153204
5047	2019-11-09 16:37:34	2019-11-09	Dawna Cassin PhD	dawna.cassin.phd@warmmail.com	San Francisco	California	4125021705651335	f550b61e51e7026265b4601c9e02e9ae	VISA 16 digit	37.7692618727270428	-122.456558498080852
5048	2019-11-09 17:00:24	2019-11-09	Dr. Waverly Bartell I	dr.waverly.bartell.i@geemail.com	San Francisco	California	3528580241423885225	aa76efe8d34dc11c58b0e36108d6fbaf	VISA 16 digit	37.7645713279879871	-122.421824052645917
5049	2019-11-09 17:43:25	2019-11-09	Alverta Sanford	alverta.sanford@geemail.com	San Francisco	California	4764659274177558	e3587f61702472cfa9f0d8b4f8d74daa	Discover	37.7772483557223993	-122.435422117065684
5050	2019-11-09 19:39:33	2019-11-09	Launa Borer	launa.borer@woohoo.com	San Francisco	California	869951067747277835	584d3b14457c17d8305f3d4da659018f	VISA 13 digit	37.7619996572865873	-122.425051113156528
5051	2019-11-09 20:11:27	2019-11-09	Miss Sarrah Romaguera	miss.sarrah.romaguera@woohoo.com	San Francisco	California	3787723834942875	69bfb1096b4d3aa8271a47a0b998a5d5	Discover	37.7487917509363484	-122.414513507441583
5052	2019-11-09 21:14:25	2019-11-09	Hortencia Tillman	hortencia.tillman@geemail.com	Berkeley	California	180007847151599492	16ddf0ff00b6babe9ca44b38eef416c6	VISA 16 digit	37.8857469746581614	-122.284814990085465
5053	2019-11-09 22:26:31	2019-11-09	Worth Simonis	worth.simonis@geemail.com	Broken Arrow	Oklahoma	4706314923371340	10d31898ab54813403eba32901d67c84	JCB 16 digit	36.0687828441858258	-95.8650794703923168
5054	2019-11-09 22:27:54	2019-11-09	Inell Blanda	inell.blanda@warmmail.com	Pomona	California	3785312425124770	2a5a52641732e43c3499486a7f7f9dbd	American Express	34.1434181280471378	-117.709979306530585
5055	2019-11-09 22:38:04	2019-11-09	Mr. Zain Lockman III	mr.zain.lockman.iii@geemail.com	Clovis	California	180037858440033403	ec75309966e9324eb71f32758bfca272	Diners Club / Carte Blanche	36.8137797940865212	-119.720889216808231
5056	2019-11-09 22:55:34	2019-11-09	Dr. Federico Champlin DDS	dr.federico.champlin.dds@geemail.com	Seattle	Washington	3491952786208373	79d4da7e82cd1e65b89a534232adf607	JCB 16 digit	47.6861769965775295	-122.302393763737371
5057	2019-11-09 23:16:14	2019-11-09	Kanye Ritchie-Kirlin	kanye.ritchie.kirlin@geemail.com	Chicago	Illinois	3088382705574136414	c17557e5db0fbd7d5a87c582508472c5	JCB 16 digit	41.8791856286883402	-87.6909778179164903
5058	2019-11-09 23:38:04	2019-11-09	Othel Langworth	othel.langworth@geemail.com	Houston	Texas	4407006549035216	1a5cfb27886045b07bdb4c6a3be6f2c7	American Express	29.7812011494845166	-95.4813098417609893
5059	2019-11-09 23:51:20	2019-11-09	Vince Collins	vince.collins@warmmail.com	Boston	Massachusetts	676125732296758	6b5c441123cc6f8ed6064f08b78cbca4	Diners Club / Carte Blanche	42.3534826125651591	-70.9789500326801175
5060	2019-11-10 00:03:37	2019-11-10	Broderick Bailey	broderick.bailey@woohoo.com	San Francisco	California	4464125409761	e908fb3b01b367f994e247b3580505f6	Mastercard	37.7766903291073817	-122.410380684901099
5061	2019-11-10 00:30:44	2019-11-10	Waldo Jacobson-Mayer	waldo.jacobson.mayer@geemail.com	Cincinnati	Ohio	3112651335598716050	3c37e56354a350963f4b67cba5247aec	Maestro	39.1478841209083797	-84.4516921518176673
5062	2019-11-10 01:42:18	2019-11-10	Chrissie Bauch	chrissie.bauch@geemail.com	Chicago	Illinois	869996870131754898	8a57c5d761af7f50a712c647bb9ba5af	American Express	41.8467225482057827	-87.6321536893520516
5063	2019-11-10 01:45:27	2019-11-10	Dabney Buckridge	dabney.buckridge@geemail.com	San Francisco	California	869981929006052601	1b0060c2e0e5a4092d27f123c8cae63a	American Express	37.7928203985947349	-122.425805684761514
5064	2019-11-10 01:50:36	2019-11-10	Suzette Haag	suzette.haag@geemail.com	San Francisco	California	3044833016955965	4e73ddbd0f7794c7ad62076d24e5f8a2	VISA 16 digit	37.7858492746225565	-122.402849511997132
5065	2019-11-10 02:37:05	2019-11-10	Mrs. Mellissa Breitenberg	mrs.mellissa.breitenberg@geemail.com	Beaumont	Texas	4778515966365691	44838af66d5bf9419cefb137057de12d	JCB 16 digit	30.0956563234865691	-94.1064000631935897
5066	2019-11-10 03:24:44	2019-11-10	Michelina Eichmann	michelina.eichmann@geemail.com	Downey	California	3112240492965664450	a3ac8fc0c722be9b477df365b1cf0dbe	Maestro	33.8459499846927869	-118.112872431018943
5067	2019-11-10 03:53:22	2019-11-10	Lida Friesen	lida.friesen@geemail.com	Washington	District of Columbia	6011435668155124992	ac73ab752c306e86573f97089e8b73a9	Discover	38.9632657888609941	-77.0388101375408496
5068	2019-11-10 03:58:58	2019-11-10	Exie Blanda MD	exie.blanda.md@geemail.com	San Francisco	California	6011398830543228340	7ec73e0681add097439ed352190d66b6	Discover	37.7825041604077256	-122.446215092262833
5069	2019-11-10 04:02:13	2019-11-10	Mr. Matias Durgan	mr.matias.durgan@geemail.com	Portland	Oregon	210071500095930502	c026af07220f47c991136aeb43474b98	Mastercard	45.5509112332835784	-122.710727417608723
5070	2019-11-10 04:10:41	2019-11-10	Jessy Abshire	jessy.abshire@geemail.com	San Francisco	California	676192317847363	73b04c495777484c6a4518f77158a609	JCB 16 digit	37.7427968361368187	-122.414786301077712
5071	2019-11-10 05:12:25	2019-11-10	Vernelle Hilll	vernelle.hilll@geemail.com	Dallas	Texas	676353291499399	52b01bfe48de566d8310066febc27c7e	VISA 16 digit	32.759731854618714	-96.7092635396830644
5072	2019-11-10 05:13:41	2019-11-10	Carlota Glover	carlota.glover@geemail.com	San Francisco	California	869994187453522676	0327c94d0906f50f938b6a049af405c0	Voyager	37.7837200204167516	-122.448217255419721
5073	2019-11-10 07:17:14	2019-11-10	Dr. Najee Hagenes I	dr.najee.hagenes.i@woohoo.com	Wilmington	North Carolina	3337053836978879107	91a499e32df5df089e2593bf1a873c64	Maestro	34.3084631602566716	-77.8211732758667409
5074	2019-11-10 07:25:30	2019-11-10	Smith Quigley	smith.quigley@woohoo.com	Greensboro	North Carolina	4223128984907485	b9fc8924cdf8b210e8534a7477fcd29b	Diners Club / Carte Blanche	36.0687878929659718	-79.9045652292650175
5075	2019-11-10 07:54:16	2019-11-10	Freeman Stoltenberg DDS	freeman.stoltenberg.dds@geemail.com	San Francisco	California	060475523867747	de3b6e4360465a015927f594cdd82e2b	JCB 16 digit	37.7836628692657897	-122.436181368051166
5076	2019-11-10 08:40:31	2019-11-10	Rocco Toy	rocco.toy@geemail.com	Bakersfield	California	53439080124513964	d9828fb826bed06be8824678d151f014	JCB 15 digit	35.4073985881812874	-118.973073447336631
5077	2019-11-10 09:40:58	2019-11-10	Dr. Zigmund Moore	dr.zigmund.moore@warmmail.com	Providence	Rhode Island	4103986292147630	dfa95ae697403cdd67e64631d88f7211	American Express	41.8101510850567308	-71.4823328655131149
5078	2019-11-10 09:51:20	2019-11-10	Venessa Emmerich	venessa.emmerich@geemail.com	Jacksonville	Florida	3012280915753848	dd27b909f1173e0d915e8761854a6c6a	JCB 16 digit	30.3688179472513511	-81.6333019238509365
5079	2019-11-10 10:27:44	2019-11-10	Mr. Alcide Yundt PhD	mr.alcide.yundt.phd@geemail.com	Dallas	Texas	4007245166546071	ba879a27a1f10378b947e51b76dd3d21	Maestro	32.797883538137377	-96.7089558370374078
5080	2019-11-10 10:54:28	2019-11-10	Royal Nikolaus	royal.nikolaus@geemail.com	San Francisco	California	869981022217064944	f5ab89eb52742dfab084fffb60b1459d	VISA 13 digit	37.7551597487689534	-122.470656371439816
5081	2019-11-10 12:38:47	2019-11-10	Patty Bergstrom	patty.bergstrom@warmmail.com	Houston	Texas	6011617048362855920	c6289e9a6a49fed47b150d4261b9dc64	VISA 16 digit	29.8438292661294327	-95.4204040642842699
5082	2019-11-10 13:35:09	2019-11-10	Ednah Dach	ednah.dach@geemail.com	Oakland	California	52101625973157961	0c3c1b38bee81cca3ddf3dbaba25fd0f	JCB 16 digit	37.8112918445856891	-122.302894968749712
5083	2019-11-10 14:30:12	2019-11-10	Budd Crooks	budd.crooks@geemail.com	Garland	Texas	3337033126134938400	b097a7b6daf63ce2d3f2254566a5e08c	Voyager	32.8109795467697083	-96.5887265317302308
5084	2019-11-10 14:53:27	2019-11-10	Beula Carroll	beula.carroll@geemail.com	Louisville	Kentucky	3096305184181695929	86252b904d41c243f67130155efdb675	Maestro	38.26102691580504	-85.6484190363507736
5085	2019-11-10 16:09:38	2019-11-10	Francis Turcotte	francis.turcotte@warmmail.com	Phoenix	Arizona	6011620145930456903	adfc13723c63a769dbd4e13f14a6683b	Mastercard	33.5183257274262658	-112.128220242860181
5086	2019-11-10 16:38:38	2019-11-10	Abbey McCullough	abbey.mccullough@geemail.com	Omaha	Nebraska	6011105325784656139	124587b7301b2d3b9e24e6f517f4a9e5	Discover	41.3024608850158756	-95.9837518992018062
5087	2019-11-10 16:40:45	2019-11-10	Izetta Hauck	izetta.hauck@geemail.com	Daly City	California	6011666810857951013	26704afe8267b0441088dea42e5014ef	Discover	37.6930040036715539	-122.507371140280739
5088	2019-11-10 16:55:39	2019-11-10	Memphis Effertz II	memphis.effertz.ii@woohoo.com	San Diego	California	3796136646310158	3edc9d71ee1c5dea15e19da56b3ff1ad	VISA 16 digit	32.8744622272972009	-117.170908709885552
5089	2019-11-10 17:25:05	2019-11-10	Mr. Alphonse Leffler	mr.alphonse.leffler@geemail.com	Dallas	Texas	3019087163216029	cde8ca0d75c15a303dd6d148df8139cc	Maestro	32.7295622707616545	-96.7824979355987125
5090	2019-11-10 17:52:15	2019-11-10	Arman Kshlerin	arman.kshlerin@warmmail.com	San Francisco	California	3028618274536995	f616854b89fa6676526f692fcf435d1d	Maestro	37.7941037087572624	-122.433857338652814
5091	2019-11-10 17:57:20	2019-11-10	Alyse Heathcote-Bergnaum	alyse.heathcote.bergnaum@geemail.com	Jacksonville	Florida	210078880218389502	fb825bcef9dbcb6e4a27904c3113c2b0	VISA 16 digit	30.2948437445849166	-81.6469566395584536
5092	2019-11-10 18:26:00	2019-11-10	Kathlene Wisoky-Hahn	kathlene.wisoky.hahn@geemail.com	San Francisco	California	180083105425539613	9aa5147d9060f75f1847fa66612306a0	VISA 13 digit	37.7769070964458962	-122.432350944337486
5093	2019-11-10 19:25:47	2019-11-10	Broderick Witting	broderick.witting@geemail.com	Clarksville	Tennessee	3049823355705951	2dd4a0d1c235c31d65674de7cbdbc1e8	Diners Club / Carte Blanche	36.564809621370955	-87.3517828774124467
5094	2019-11-10 19:46:14	2019-11-10	Niki Simonis	niki.simonis@geemail.com	San Francisco	California	180025857074458393	1b5703446d0f4d643b8569cdb65b1ab7	Discover	37.7637741691318141	-122.387941130018916
5095	2019-11-10 19:56:01	2019-11-10	Mr. Andreas Muller	mr.andreas.muller@geemail.com	Los Angeles	California	3016721718775146	b9f24c7c1e6284808db9c80b821feff4	Mastercard	34.0680719959415441	-118.334018514537433
5096	2019-11-10 20:28:44	2019-11-10	Trevin Bergnaum-Strosin	trevin.bergnaum.strosin@geemail.com	Los Angeles	California	869979406266483366	71593f2739fcd6960713f76ea43dec70	Discover	34.0952489455096384	-118.403248388691992
5097	2019-11-10 20:47:49	2019-11-10	Bobbye Connelly MD	bobbye.connelly.md@warmmail.com	San Diego	California	3037259343381898	d44616208e83d3ee35e4a5ef7e07bc3b	Voyager	32.8086409282006315	-117.125610646456479
5098	2019-11-10 21:03:32	2019-11-10	Jonathan Keebler	jonathan.keebler@geemail.com	Pasadena	Texas	6011695200578515963	e3810260bb3da32f9aaa836f501b80bb	JCB 16 digit	29.6349329720590262	-95.0919673105183989
5099	2019-11-10 21:18:57	2019-11-10	Jaiden Huel	jaiden.huel@warmmail.com	San Francisco	California	180033959518283534	bc13e1d03fd29a5fa354ecab42dc88a6	American Express	37.7917742057103965	-122.43125190515309
5100	2019-11-10 21:36:33	2019-11-10	Shannen Kessler	shannen.kessler@geemail.com	San Francisco	California	4383127778515385	e85578e9311c22c4485810ea2acf2ff1	VISA 16 digit	37.7772954349009282	-122.387219013380118
5101	2019-11-10 22:02:30	2019-11-10	Maribeth Auer-Schoen	maribeth.auer.schoen@geemail.com	Ontario	California	51347906967328238	9d23d59a12b8bcf8fcdc21a7fc3336e1	VISA 16 digit	34.0031501398101454	-117.621156743970516
5102	2019-11-10 22:09:30	2019-11-10	Arnold Casper	arnold.casper@geemail.com	San Francisco	California	53446894537188821	69d35da60ca70dd06430a249d3351dd5	Diners Club / Carte Blanche	37.7414285197995696	-122.432152184458658
5103	2019-11-10 22:12:38	2019-11-10	Esley Williamson	esley.williamson@woohoo.com	Oakland	California	3050971254788450	12847c84ef6070d422366fc868f85250	VISA 16 digit	37.8204732886105006	-122.301584690994147
5104	2019-11-10 22:30:26	2019-11-10	Mr. Adams Nicolas Sr.	mr.adams.nicolas.sr.@geemail.com	Davenport	Iowa	869922160235919863	face0f82c106ff3e89560d551950df0b	Mastercard	41.5321556749552485	-90.6610544514339409
5105	2019-11-10 22:35:36	2019-11-10	Demetra Schneider	demetra.schneider@geemail.com	Chicago	Illinois	54457627534350911	cf75935cb918ebe4e5c0a99f49a11f60	JCB 16 digit	41.8006589738953878	-87.6911275026418195
5106	2019-11-10 22:36:23	2019-11-10	Dr. Reyes Kessler	dr.reyes.kessler@geemail.com	Austin	Texas	55942604343690947	bf3b506b08e180b7eb6318c588adf223	Maestro	30.2279411431062961	-97.8219280683673986
5107	2019-11-10 23:02:41	2019-11-10	Jens Reinger	jens.reinger@geemail.com	San Francisco	California	4388575122717	83a4edfa711efc9efe506a0d6314f030	American Express	37.7870071248588886	-122.419213547278773
5108	2019-11-10 23:10:56	2019-11-10	Ammon Beer	ammon.beer@geemail.com	Oakland	California	210042414196065695	33d838cd773800cd59ef8ff8e0b94eb1	JCB 16 digit	37.7835488072220755	-122.280744844922637
5109	2019-11-10 23:15:09	2019-11-10	Ms. Delaney Labadie	ms.delaney.labadie@geemail.com	Santa Ana	California	6011460270446670889	6f2701cab52f91ff34a9cceec095c3ee	Mastercard	33.7274317171063274	-117.86586625868641
5110	2019-11-10 23:18:49	2019-11-10	Cyril Schmitt	cyril.schmitt@geemail.com	Los Angeles	California	52086590266449799	7ce7efaaed5dfe47db14162ef16c6f78	Discover	34.05754377267845	-118.441231632231919
5111	2019-11-10 23:25:09	2019-11-10	Jordi Orn	jordi.orn@geemail.com	New Orleans	Louisiana	3448344513367090	5e8cbc1218ef86efc6b9377574da8610	JCB 15 digit	29.9700729818098246	-89.8634618683978914
5112	2019-11-10 23:30:48	2019-11-10	Kimberely Christiansen-Hansen	kimberely.christiansen.hansen@geemail.com	Berkeley	California	3043337803116022	9bef95fe32cb9cf58f5de7a819b9bce3	VISA 13 digit	37.8789517972404681	-122.281962943099259
5113	2019-11-11 00:16:37	2019-11-11	Micky Dickinson-Volkman	micky.dickinson.volkman@geemail.com	Detroit	Michigan	3528316135348651236	3ee078d97b7b4f52f712fa2245c23e79	American Express	42.3737611463218968	-83.1956055250603725
5114	2019-11-11 00:38:06	2019-11-11	Baron Waelchi	baron.waelchi@warmmail.com	San Francisco	California	53549733770346876	9c98627c9b87529d0f70eaa08601a54f	VISA 16 digit	37.7405864872076506	-122.46505006026112
5115	2019-11-11 00:53:24	2019-11-11	Dakota Kovacek Jr.	dakota.kovacek.jr.@woohoo.com	Boston	Massachusetts	3088039399934766347	b9d0ada08aa8f4dc42ebc58d7b51397f	American Express	42.2640928625762484	-70.9477142161175607
5116	2019-11-11 01:04:16	2019-11-11	Dr. Marc Lueilwitz Sr.	dr.marc.lueilwitz.sr.@warmmail.com	San Francisco	California	869928152983214120	cbad5612b5b9434f5501ee7f2f98488f	VISA 13 digit	37.8014965270251579	-122.47997382576925
5117	2019-11-11 01:44:42	2019-11-11	Mrs. Camila Franecki	mrs.camila.franecki@geemail.com	Chesapeake	Virginia	210093436731857656	5a45d139f09da30d73752dd774053e60	Voyager	36.5806603826820833	-76.2237755680300353
5118	2019-11-11 02:03:02	2019-11-11	Bell Davis	bell.davis@geemail.com	San Francisco	California	180026285801349496	57b86d978c70f6edc092a539307a518f	Voyager	37.7826122679885259	-122.417121564794215
5119	2019-11-11 03:09:50	2019-11-11	Paris West	paris.west@geemail.com	San Francisco	California	3096788815121755499	03a2a728af9d617616ecfe90c2be9d82	VISA 16 digit	37.7675149915483033	-122.448422927672766
5120	2019-11-11 03:32:04	2019-11-11	Justus Stark	justus.stark@geemail.com	New York	New York	180016718711319862	89d073c8b385763bc2e9cbeda60bd21e	JCB 16 digit	40.6405040137227616	-73.9146191860444759
5121	2019-11-11 03:34:51	2019-11-11	Sasha Howell	sasha.howell@warmmail.com	Peoria	Illinois	503896535410961	a0471983246a93f3aceae437c4100a7a	Mastercard	40.7684101841282072	-89.6258567419719014
5122	2019-11-11 03:44:16	2019-11-11	Kaliyah Batz	kaliyah.batz@geemail.com	Lancaster	California	3528601675858692991	98d92b2df72bd2a349b5cb3080f045a7	VISA 16 digit	34.7352855786461419	-118.157743462358781
5123	2019-11-11 03:55:22	2019-11-11	Jacques Watsica III	jacques.watsica.iii@geemail.com	Boston	Massachusetts	4898333821841830	d6f4a7122b7c6f4a915321bd33c6d674	Diners Club / Carte Blanche	42.2461568643040977	-71.0010409363962793
5124	2019-11-11 04:27:14	2019-11-11	Norene Thompson	norene.thompson@geemail.com	Birmingham	Alabama	6011162488528203327	68e04cf24897bde821b3175bea518583	JCB 15 digit	33.5739746121946752	-86.8313777379468092
5125	2019-11-11 04:28:25	2019-11-11	Mr. Cedric Hickle Sr.	mr.cedric.hickle.sr.@woohoo.com	San Francisco	California	210051796831701041	95b4c2893bf3990f6790641f80720d7c	Voyager	37.7728753428046033	-122.423901069222453
5126	2019-11-11 04:37:46	2019-11-11	Dr. Dereon McLaughlin	dr.dereon.mclaughlin@geemail.com	Austin	Texas	3726793327151916	f232cc5880bca31a64ad03de95481886	American Express	30.3094254457518453	-97.6976252278085866
5127	2019-11-11 06:13:02	2019-11-11	Burleigh Welch	burleigh.welch@geemail.com	San Francisco	California	180093554083161574	be00755314d5c0ffbb69b65b15fb0567	JCB 15 digit	37.7722426370708888	-122.441806626448241
5128	2019-11-11 07:03:52	2019-11-11	Kadeem Stoltenberg	kadeem.stoltenberg@geemail.com	San Francisco	California	869903396844108992	5d890b0155f987f9a17ee450ce8ef7d8	Maestro	37.7966886105376503	-122.438595631134689
5129	2019-11-11 07:30:16	2019-11-11	Zora Ankunding-Gutmann	zora.ankunding.gutmann@woohoo.com	Rockford	Illinois	3479236842709061	46ee008b9dc610a77a626183f47cb3d6	VISA 16 digit	42.2411247848544278	-88.9770979310203387
5130	2019-11-11 07:49:23	2019-11-11	Cleda Huels	cleda.huels@warmmail.com	New York	New York	6011256222410667050	5175d1c1abfb5777c1c48d504bf81a73	Diners Club / Carte Blanche	40.7587486435882767	-73.8488009963545977
5131	2019-11-11 07:50:09	2019-11-11	Shirlie Murazik	shirlie.murazik@warmmail.com	San Francisco	California	54179199004288176	196c11449e48d4d7af2c81b9d22d7f6e	Voyager	37.7568513308805436	-122.465737422663196
5132	2019-11-11 09:58:00	2019-11-11	Lyndia Olson	lyndia.olson@geemail.com	Mesa	Arizona	6011722234534290749	6f8eb8f98a2ef800a3772fe1624ae77a	American Express	33.4513416305795275	-111.684701453463731
5133	2019-11-11 10:40:24	2019-11-11	Raul Reichert	raul.reichert@woohoo.com	San Francisco	California	53857994250907027	81862dcffa8d05348751ec27ab771be7	JCB 16 digit	37.8057194930485352	-122.422598621531947
5134	2019-11-11 10:53:17	2019-11-11	Ms. Makenzie Shields DDS	ms.makenzie.shields.dds@geemail.com	San Francisco	California	639032109492390	3e7cd46c1b5611d7ce7b77236df2dc20	VISA 16 digit	37.7601079130856903	-122.426384172137432
5135	2019-11-11 11:18:54	2019-11-11	Ms. Tess Lowe DVM	ms.tess.lowe.dvm@geemail.com	Philadelphia	Pennsylvania	51998447953109763	c15013d9a8040c4ab6110465b1003bd4	Voyager	40.0609173197723933	-75.169299388061475
5136	2019-11-11 11:25:51	2019-11-11	Jolene Osinski	jolene.osinski@geemail.com	Tampa	Florida	55106598159564646	9f79c37cc5d2b76169b7c90406117029	VISA 16 digit	27.8908482643425444	-82.5033332116182834
5137	2019-11-11 11:45:37	2019-11-11	Sabina Ward-Rolfson	sabina.ward.rolfson@geemail.com	Detroit	Michigan	4461608023765151	3ea625d66206b769aeda43e80f4c43d6	VISA 13 digit	42.3850888953469749	-83.1294482588887149
5138	2019-11-11 12:03:12	2019-11-11	Odin Larkin	odin.larkin@geemail.com	Berkeley	California	210003638128472614	5e7c2ef0b223f4c4bc0514f4411e9421	VISA 16 digit	37.8733726201653482	-122.297292450056972
5139	2019-11-11 12:21:07	2019-11-11	Antonina Collins	antonina.collins@geemail.com	San Francisco	California	3112305190874168637	7b664cc4e79bcca9ae96187860b70ac8	VISA 13 digit	37.7797282884332049	-122.464318132913675
5140	2019-11-11 12:43:41	2019-11-11	Seymour Bartell	seymour.bartell@geemail.com	Minneapolis	Minnesota	4324613949551484	48c58d65dc78f2e0d558f10c91a86933	Diners Club / Carte Blanche	45.0476018171377461	-93.3664625236105081
5141	2019-11-11 12:53:30	2019-11-11	Vella Homenick	vella.homenick@geemail.com	San Francisco	California	6011913669704214368	a1f94a397d0162d30ae69ba9709dd048	VISA 16 digit	37.8188820494893108	-122.455953903194739
5142	2019-11-11 14:46:30	2019-11-11	Miss Liza Schaden MD	miss.liza.schaden.md@geemail.com	Billings	Montana	3014681496481204	f6d0c70721fb31939e4425ffde594158	JCB 16 digit	45.7509065968673667	-108.605122352826967
5143	2019-11-11 14:54:42	2019-11-11	Ms. Brittany Cummings	ms.brittany.cummings@geemail.com	Oakland	California	210099200286808157	4942a2e55abef5a231fa1c019d845e63	VISA 16 digit	37.8334186975757092	-122.278712203616095
5144	2019-11-11 15:27:57	2019-11-11	Mrs. Texanna Wehner DVM	mrs.texanna.wehner.dvm@geemail.com	San Francisco	California	502081394452239	e347748391f86bc93bd146ae896b0430	Voyager	37.7856038814277824	-122.41969905432795
5145	2019-11-11 15:29:20	2019-11-11	Creola McGlynn-Hagenes	creola.mcglynn.hagenes@geemail.com	New York	New York	4335793178057861	ef2000becab2ea9de3d7bc8f56c69ca5	Maestro	40.7118893864788092	-73.9105703333288346
5146	2019-11-11 16:50:14	2019-11-11	Stephen Adams IV	stephen.adams.iv@warmmail.com	Detroit	Michigan	6011560772330380540	626264be382a71a918d40842eb5f9871	American Express	42.3442058118917046	-83.0074663075737647
5147	2019-11-11 18:01:40	2019-11-11	Kayley Walsh-Bergstrom	kayley.walsh.bergstrom@warmmail.com	Salt Lake City	Utah	3112196832037894425	c923991692a0c9ec497a0c5359a378f3	Maestro	40.7981154711130998	-112.01237659397907
5148	2019-11-11 18:24:20	2019-11-11	Dr. Dondre Lockman I	dr.dondre.lockman.i@geemail.com	New York	New York	4762612268326444	da01481bd216f02cddae84e1b31c3a3a	Diners Club / Carte Blanche	40.723420413652434	-73.8421439514391125
5149	2019-11-11 18:42:37	2019-11-11	Laraine Jakubowski	laraine.jakubowski@geemail.com	San Francisco	California	3704882953872212	1e5d5073427ab27de00c01355501212e	Voyager	37.8285245201300881	-122.473275017684813
5150	2019-11-11 19:34:17	2019-11-11	Mr. Samson Nienow	mr.samson.nienow@geemail.com	Santa Clarita	California	3721721222043511	730a5e3296bc0c868c74874cfb0ef797	JCB 15 digit	34.4800884119905504	-118.561570268926019
5151	2019-11-11 19:38:21	2019-11-11	Mr. Kevin Reynolds MD	mr.kevin.reynolds.md@geemail.com	Fort Worth	Texas	4890789945833	d62fc1a45881e87f075a4d9c5c9fdb60	JCB 16 digit	32.8107939844541292	-97.3505101927842986
5152	2019-11-11 20:21:29	2019-11-11	Enola Ledner DDS	enola.ledner.dds@geemail.com	San Antonio	Texas	3798538510912597	5325f47df8f17e42e15ec6b4a58778ec	Discover	29.4657632331900317	-98.6201476615689643
5153	2019-11-11 20:37:39	2019-11-11	Dr. Lex Kub	dr.lex.kub@geemail.com	Los Angeles	California	639065745361959	b2f7edb3c249e37845aff5ff3ddffc1e	VISA 13 digit	34.0631591194640819	-118.390284864836559
5154	2019-11-11 20:46:38	2019-11-11	Jaylin Windler	jaylin.windler@warmmail.com	Berkeley	California	3088202753776071086	f2f53f822c4255ddd3a9caea094ff05b	JCB 16 digit	37.8264457724170242	-122.284951111382867
5155	2019-11-11 20:56:11	2019-11-11	Emilee Marquardt	emilee.marquardt@warmmail.com	Lexington	Kentucky	3096047159520181677	721802fbf5e5a03c544714a6a33cee0a	VISA 16 digit	38.1245859240524467	-84.4863780829954862
5156	2019-11-11 21:52:23	2019-11-11	Dr. Oscar Cassin IV	dr.oscar.cassin.iv@geemail.com	Greeley	Colorado	6011057302588343998	7826b7e62872edf00c8964c4d387b543	VISA 16 digit	40.4635676051557098	-104.714644796944043
5157	2019-11-11 21:58:56	2019-11-11	Virgia O'Kon	virgia.o'kon@geemail.com	Clarksville	Tennessee	6011836303849895725	388728c8a576a8929c5314b01cf63f91	VISA 16 digit	36.5377336594402777	-87.3942479424595859
5158	2019-11-11 23:12:53	2019-11-11	Barton Quigley	barton.quigley@geemail.com	Vallejo	California	3790603793821929	3b7f99bf21614346bf9e1a3039c4076c	JCB 16 digit	38.130697758458183	-122.190370844291522
5159	2019-11-12 01:40:53	2019-11-12	Zed Schmidt	zed.schmidt@geemail.com	College Station	Texas	869964363355699799	e79f618d40cfbab96b67d610565d4398	Voyager	30.5618542251687515	-96.3399283034108578
5160	2019-11-12 02:16:38	2019-11-12	Tiney Dickinson	tiney.dickinson@woohoo.com	San Francisco	California	4748804645194	ebafb0e709bf8952f9a5b20a2597d5f3	JCB 16 digit	37.7851274045591907	-122.472048424700944
5161	2019-11-12 05:04:17	2019-11-12	Verne Mueller	verne.mueller@geemail.com	Boston	Massachusetts	3158596087942670362	d3017388510121fcec95e2fbf89f96e8	Voyager	42.3971103776413969	-70.9789848649360238
5162	2019-11-12 05:38:59	2019-11-12	Versa Mayer	versa.mayer@geemail.com	San Francisco	California	3044417741776019	84d5d5cc3c2c8788feb7eaa87cd7c27c	VISA 16 digit	37.7659851964260511	-122.410271583722007
5163	2019-11-12 05:54:44	2019-11-12	Dr. Jenniffer Wiegand PhD	dr.jenniffer.wiegand.phd@geemail.com	San Francisco	California	4509644215762130	bdda94b5b1a273910c9fab6c7ce53020	Maestro	37.7938402107395319	-122.481499696703438
5164	2019-11-12 06:17:51	2019-11-12	Laurence Spencer III	laurence.spencer.iii@geemail.com	San Francisco	California	4121619433057503	26a98256320b4a48e816129b2c878bda	JCB 16 digit	37.792691717133188	-122.433377870457051
5165	2019-11-12 06:40:38	2019-11-12	Camilla Fadel-Jones	camilla.fadel.jones@warmmail.com	Hollywood	Florida	4225132738170596	82f86c17d8395d72a4dcb4cecc326d9e	VISA 13 digit	25.9481020682435464	-80.1010962537772855
5166	2019-11-12 06:43:22	2019-11-12	Verle Weissnat	verle.weissnat@geemail.com	San Francisco	California	51966269013235802	85f04bba5e02ed8b39691f33f99717de	Mastercard	37.809161981920532	-122.403194190801443
5167	2019-11-12 07:02:56	2019-11-12	Kortney Larson DDS	kortney.larson.dds@geemail.com	Oakland	California	4446237382555027	6bfd184268e893a0263549cacfbff404	VISA 16 digit	37.7851928654987006	-122.239263696239533
5168	2019-11-12 07:34:04	2019-11-12	Uriah Dare	uriah.dare@geemail.com	Louisville	Kentucky	4242269519467087	6075ede8fa307e78697d1e6dd2ff9fb2	Maestro	38.0865153999436643	-85.7278255895316619
5169	2019-11-12 07:41:52	2019-11-12	Dr. Jaxton Hahn V	dr.jaxton.hahn.v@geemail.com	San Francisco	California	3797867686887304	bedca78234c5446a667ba35c5f1c8ec4	VISA 16 digit	37.7894916934096088	-122.437553181682333
5170	2019-11-12 08:02:36	2019-11-12	Hampton Ledner	hampton.ledner@geemail.com	New York	New York	4661827974906832	5e4f9e2200ccb3482ed532879cb265c7	VISA 16 digit	40.5675250199381239	-74.0179093985248358
5171	2019-11-12 08:17:37	2019-11-12	Merlene Waters	merlene.waters@warmmail.com	Visalia	California	3714614742848692	6715993d172e05e1464fc2aa4aadc7f0	JCB 16 digit	36.3068617163181315	-119.407353817637642
5172	2019-11-12 08:40:11	2019-11-12	Jewell D'Amore-Crooks	jewell.d'amore.crooks@geemail.com	Oakland	California	3112983498287739186	5b42d31e2651d17b419002112acb0389	Voyager	37.7945468193861558	-122.292328091401629
5173	2019-11-12 08:45:49	2019-11-12	Ota McLaughlin DDS	ota.mclaughlin.dds@geemail.com	San Francisco	California	4108234891381	cc8129397cf1835b71428d15c02a2379	VISA 16 digit	37.7527098910771599	-122.442455807174611
5174	2019-11-12 09:09:20	2019-11-12	Dominique Emmerich	dominique.emmerich@geemail.com	Memphis	Tennessee	4339085291684606	2b1b20d239b67a7084997394ef59a9e5	VISA 16 digit	35.0788369272902614	-90.0305495765317261
5175	2019-11-12 10:19:06	2019-11-12	Alivia Abshire-Rohan	alivia.abshire.rohan@geemail.com	Berkeley	California	6011415982445924887	ce3464f9704afd1fff572232d064102f	American Express	37.8555227148986972	-122.244629230889743
5176	2019-11-12 10:46:47	2019-11-12	Bryson Kunde	bryson.kunde@geemail.com	St. Louis	Missouri	4960937690721056	aa147482705ef38d5f7e00d084efd8fa	VISA 16 digit	38.6430494993150262	-90.1760625447150375
5177	2019-11-12 11:07:47	2019-11-12	Stephanie Renner	stephanie.renner@warmmail.com	Salem	Oregon	4509749715882203	68a066260c351c6046ea60967cfdb25a	VISA 13 digit	44.9687661168433692	-122.972964517368752
5178	2019-11-12 11:25:36	2019-11-12	Leslee Yost	leslee.yost@geemail.com	Houston	Texas	3015530808949565	5ed7fcb84310b21b84032596abc15fbf	Maestro	29.772277768709138	-95.3589658916477134
5179	2019-11-12 11:33:43	2019-11-12	Macey Glover-Ryan	macey.glover.ryan@geemail.com	Athens	Georgia	3112302896881377226	ec933697f27188f131809d977ed5ff45	VISA 16 digit	34.0464666309490767	-83.4073337382286724
5180	2019-11-12 11:34:40	2019-11-12	Mr. Delbert Hoppe DDS	mr.delbert.hoppe.dds@woohoo.com	San Francisco	California	4271920030005731	0153ab6f76711922f227862351c8ccf6	Diners Club / Carte Blanche	37.7783684623863678	-122.4394516271133
5181	2019-11-12 12:42:22	2019-11-12	Gertha Corkery	gertha.corkery@woohoo.com	West Jordan	Utah	4080463483871995	08dadf464430f8c06883a594d414cced	Maestro	40.5043133535213826	-111.998460586377604
5182	2019-11-12 12:56:25	2019-11-12	Horace Brekke	horace.brekke@geemail.com	Austin	Texas	54108506051124466	1998d697d516d31e59d909743e81214c	JCB 16 digit	30.2072261961769293	-97.8146667990606318
5183	2019-11-12 13:03:02	2019-11-12	Hayleigh Kerluke-Reynolds	hayleigh.kerluke.reynolds@geemail.com	Sacramento	California	3727229991573191	06c0cbaff7d2deff8021b88d02b5a215	JCB 16 digit	38.6261628708600995	-121.455927902065582
5184	2019-11-12 13:11:35	2019-11-12	Mindi Christiansen	mindi.christiansen@geemail.com	Norfolk	Virginia	869971209791085286	6768c76984727bb2a53da3d33f7d98d5	Maestro	36.9475777226984547	-76.270909709018099
5185	2019-11-12 13:23:57	2019-11-12	Augustina Mueller-Becker	augustina.mueller.becker@geemail.com	Los Angeles	California	6011644837496300051	0747509ef2982d74f0b23ccd20e65365	JCB 16 digit	33.9507989869318862	-118.344630098947505
5186	2019-11-12 13:51:32	2019-11-12	Mr. Levi Crist	mr.levi.crist@geemail.com	Yonkers	New York	3096478010356531261	77382c46babe9876464c507a820e2ae8	Mastercard	40.913316113056247	-73.8266267788015398
5187	2019-11-12 14:14:06	2019-11-12	Hazen Emard	hazen.emard@geemail.com	Mobile	Alabama	3006808673362166	8a0d8f9435096248442218176ca5679a	Discover	30.6781856276668599	-88.0215693990372188
5188	2019-11-12 14:56:30	2019-11-12	Errol Huels	errol.huels@geemail.com	New York	New York	869997005348120448	6ff306cefdb4fca0410c13c11791ef10	Maestro	40.7605587246585657	-74.0022526446159929
5189	2019-11-12 16:47:07	2019-11-12	Dr. Matt Towne	dr.matt.towne@geemail.com	Oakland	California	3158624590155480391	df743c453605ff226780cba16816f82f	Discover	37.8388488268500254	-122.258410205344532
5190	2019-11-12 17:24:15	2019-11-12	Mr. Carlo Torphy IV	mr.carlo.torphy.iv@woohoo.com	San Jose	California	3405195015513867	c8d9873bbff4dcde8a128d23d184a9f0	JCB 16 digit	37.3143102804020046	-121.804438679175078
5191	2019-11-12 17:37:49	2019-11-12	Jeanmarie Hackett	jeanmarie.hackett@geemail.com	Atlanta	Georgia	4353847794016	6f2c02f46fa6926b1cd383a11b082bc3	VISA 16 digit	33.7824884673390571	-84.3865070092070937
5192	2019-11-12 18:39:42	2019-11-12	Ryley Weissnat-Smith	ryley.weissnat.smith@geemail.com	Frisco	Texas	4503107696380	09f2fb53d4ad7582f6c199e6317eec58	VISA 13 digit	33.2470154343634832	-96.7796995427202376
5193	2019-11-12 18:48:23	2019-11-12	Dr. Adelard Klein DDS	dr.adelard.klein.dds@geemail.com	Los Angeles	California	6011306001016644170	7b2e953eaa3f8f0782564b4b36f76389	Voyager	34.0180215421464283	-118.412549305659894
5194	2019-11-12 18:57:44	2019-11-12	Dania Oberbrunner	dania.oberbrunner@geemail.com	San Francisco	California	3426778558964798	2308119392b702617f870f755d98ae7b	American Express	37.7537732527289691	-122.410274957550456
5195	2019-11-12 19:25:17	2019-11-12	Judd Ortiz I	judd.ortiz.i@geemail.com	San Diego	California	6011096992768624374	98e3d7deaaa72a114df2dd3ccc43de7b	Discover	32.7719854536067672	-117.203459650222214
5196	2019-11-12 19:34:09	2019-11-12	Karyl Hand	karyl.hand@geemail.com	San Francisco	California	3112298199379990345	6ca7c6a78a024bf08253fc49119ea2a4	Diners Club / Carte Blanche	37.8009169029936984	-122.4445148600756
5197	2019-11-12 19:46:57	2019-11-12	Mr. Donte Murray PhD	mr.donte.murray.phd@woohoo.com	Odessa	Texas	4779005398592798	894f661c37e5804ba08c93b148c3e3d4	American Express	31.8196806651085637	-102.264661931774015
5198	2019-11-12 19:47:33	2019-11-12	Burnell Brekke	burnell.brekke@woohoo.com	San Francisco	California	4591197152514104	7d7a032d3ce79c5ae0acfc897a22ea73	American Express	37.8020825510189979	-122.439301142009015
5199	2019-11-12 19:57:28	2019-11-12	Maia Yost	maia.yost@geemail.com	Nashville	Tennessee	4513310963031755	b449dcd01928652e0f8a40c16b1cc483	Discover	36.1963046984404286	-86.7091743856109645
5200	2019-11-12 20:22:00	2019-11-12	Ruthanne Morissette	ruthanne.morissette@geemail.com	San Diego	California	639084843201439	c4e11c1d8199a4357d5d5f3d2a667094	JCB 15 digit	32.8437340772312112	-117.040571258533745
5201	2019-11-12 20:28:02	2019-11-12	Ephram Kub-Vandervort	ephram.kub.vandervort@geemail.com	San Francisco	California	4928611290786	f4a9cfcd2482ce2e1523412b73ce27e4	Maestro	37.7694904288403919	-122.436564445306061
5202	2019-11-12 20:37:07	2019-11-12	Duane Rohan	duane.rohan@geemail.com	Bridgeport	Connecticut	630451322178941	a8b5879aa59c068a737657c1bf310dbf	VISA 13 digit	41.2565170278936577	-73.1025264901939806
5203	2019-11-12 20:39:23	2019-11-12	Ellamae VonRueden	ellamae.vonrueden@geemail.com	Oakland	California	3421977067749410	5c8d9d05a4c424b44bcfe1a255db2bef	JCB 16 digit	37.7559776561072624	-122.229603666058054
5204	2019-11-12 21:16:00	2019-11-12	Canyon Jast V	canyon.jast.v@warmmail.com	Worcester	Massachusetts	3447766272698169	1c9eeedf20fb2b5c93303b83ead0e75c	Discover	42.2874168726783282	-71.8828290119554794
5205	2019-11-12 21:28:02	2019-11-12	Mac Rodriguez	mac.rodriguez@woohoo.com	Los Angeles	California	4639509625657977	f408e43ce844955e77e6a6a5c95ff457	VISA 16 digit	34.0539681197941277	-118.479952486138046
5206	2019-11-12 22:33:50	2019-11-12	Ms. Elgie Dibbert PhD	ms.elgie.dibbert.phd@geemail.com	Vancouver	Washington	6011997149959350281	3461c20e838682e5fee262304c5fcba8	JCB 15 digit	45.60105595277399	-122.670317472942912
5207	2019-11-12 23:33:50	2019-11-12	Siddie Runolfsdottir	siddie.runolfsdottir@geemail.com	Denver	Colorado	3010181609909534	aef9459c2417037436ec8e5ed0d59149	American Express	39.7193863732326733	-104.950072830893475
5208	2019-11-12 23:54:30	2019-11-12	Montana Schneider	montana.schneider@geemail.com	Houston	Texas	3017110449525112	c8fd21f67a1584f0a6bebcb468e4a2b2	JCB 16 digit	29.7051486772563322	-95.3471878501601537
5209	2019-11-12 23:58:57	2019-11-12	Roderick Kuhn	roderick.kuhn@geemail.com	New York	New York	3112625505166049117	66edc183a0127921463d7dfd10341c3a	VISA 16 digit	40.631472235335039	-73.8676687854703431
5210	2019-11-13 00:14:41	2019-11-13	Delisa Hauck	delisa.hauck@woohoo.com	Lancaster	California	6011851284687445858	474a3afae309fc5506244b346e7c56f3	VISA 16 digit	34.7006681562181569	-118.146186458503081
5211	2019-11-13 00:18:15	2019-11-13	Mr. Enrique Murazik Sr.	mr.enrique.murazik.sr.@geemail.com	Rochester	Minnesota	4780020461643	761944616d0a408ffcb37715dce0f4f2	Diners Club / Carte Blanche	44.0873651220366369	-92.4665281671218509
5212	2019-11-13 01:04:12	2019-11-13	Jamal Wisoky-Ledner	jamal.wisoky.ledner@geemail.com	Birmingham	Alabama	4375526242569201	cc507694b04404d7f0e8fd3092df417d	VISA 13 digit	33.4850931559480713	-86.8329173473883458
5213	2019-11-13 01:04:34	2019-11-13	Mr. Hunt Stanton IV	mr.hunt.stanton.iv@geemail.com	Colorado Springs	Colorado	4895874169496	d6dc22d4ea240542ab53b9b7bd9dba42	American Express	38.7929014986895027	-104.829836188132688
5214	2019-11-13 01:42:53	2019-11-13	Layla Heidenreich-Quigley	layla.heidenreich.quigley@woohoo.com	Long Beach	California	3009229193345317	970a01fd296a372dea2eb3f9ca47c209	Mastercard	33.8947255369562654	-118.146265695539483
5215	2019-11-13 01:53:52	2019-11-13	Mr. Cain Wehner	mr.cain.wehner@geemail.com	Oakland	California	210059427067139886	a9bccd9f545759080b4f5f41bab18374	VISA 16 digit	37.8376255024236343	-122.258717812575895
5216	2019-11-13 02:14:29	2019-11-13	Darrion Ruecker I	darrion.ruecker.i@geemail.com	Charlotte	North Carolina	3158891545395327147	b25dc13b522f782e11aec7ed722bc8c3	VISA 16 digit	35.1095478482797745	-80.7726174032725481
5217	2019-11-13 02:43:41	2019-11-13	Lavelle Schroeder	lavelle.schroeder@geemail.com	San Diego	California	6011546168695937355	1b294daef245459960b7591e6a6a4a17	Discover	32.758031687566266	-117.078022343143829
5218	2019-11-13 03:21:29	2019-11-13	Con Bailey	con.bailey@warmmail.com	San Francisco	California	4839100876465555	5bbb0f52a20d84907df7d81907d0392c	Discover	37.8037917300374531	-122.422478898959994
5219	2019-11-13 04:29:09	2019-11-13	Dr. Buddy Lubowitz	dr.buddy.lubowitz@geemail.com	San Francisco	California	869980437103854169	b772a06ac228ec2b08c8471ad5256080	Discover	37.8053932615169543	-122.430970459699822
5220	2019-11-13 04:38:02	2019-11-13	Mrs. Whitney Hane DVM	mrs.whitney.hane.dvm@warmmail.com	Garden Grove	California	3112880709383141505	c22fe5626a5317743d357c08a2b1dafa	VISA 16 digit	33.8705874176055133	-118.054691566854714
5221	2019-11-13 05:23:29	2019-11-13	Ms. Ressie Kuhn	ms.ressie.kuhn@geemail.com	Los Angeles	California	675914620714841	e4a58bea9d5db76bb0a9d8a2dd6af725	VISA 16 digit	34.0568202911276359	-118.456126831424598
5222	2019-11-13 06:20:50	2019-11-13	Whit Lakin	whit.lakin@geemail.com	Los Angeles	California	4607671335116138	6d2c6f8638d31b983609e3a42ab318f4	VISA 13 digit	34.0083417045284051	-118.510563065064318
5223	2019-11-13 06:33:11	2019-11-13	Destany Littel	destany.littel@geemail.com	San Francisco	California	503836506376809	fc7fd2cda19d0b710e07bcc5216254ab	VISA 13 digit	37.7803450620822971	-122.414904920520186
5224	2019-11-13 06:53:48	2019-11-13	Erland Wolff	erland.wolff@geemail.com	San Francisco	California	4365808840693175	b8d19e84909288281d921c83d95b04a9	VISA 13 digit	37.746802993806007	-122.447537236852924
5225	2019-11-13 07:13:08	2019-11-13	Tina Bashirian DVM	tina.bashirian.dvm@geemail.com	Philadelphia	Pennsylvania	676375644567523	fdcb4070e26b71693d3acca70db25d73	JCB 15 digit	39.9664575757883469	-75.1235947677299407
5226	2019-11-13 08:11:11	2019-11-13	Fisher Beahan	fisher.beahan@woohoo.com	Houston	Texas	6011645046101164220	ae54abbba586ba11a033b34cf6de877b	Maestro	29.7183595857195542	-95.4162167102578991
5227	2019-11-13 08:35:15	2019-11-13	Polk Weissnat	polk.weissnat@geemail.com	Cary	North Carolina	3096755386142750447	0859d20d7e80eeacfbb522f10c4c8961	JCB 15 digit	35.7482233718611297	-78.7223831588487997
5228	2019-11-13 09:15:11	2019-11-13	Sophia Daugherty MD	sophia.daugherty.md@geemail.com	Berkeley	California	4220431755472272	76a7cc7a0927b38aed50053e802e9228	VISA 16 digit	37.8474869673415242	-122.281732705564664
5229	2019-11-13 10:04:19	2019-11-13	Danelle Roberts-Dach	danelle.roberts.dach@geemail.com	Nashville	Tennessee	4733685652423049	fef55d2e4e2dd7dda3cdad2dc95530a0	American Express	36.1051480644971079	-86.8146638654079226
5230	2019-11-13 10:34:14	2019-11-13	Dr. Judie Kertzmann DVM	dr.judie.kertzmann.dvm@woohoo.com	Los Angeles	California	676140538486933	fd9bd1d83c47e1b3c6a0cfe4a8f1bad6	JCB 15 digit	33.9293074486643036	-118.352817748579383
5231	2019-11-13 11:37:32	2019-11-13	Lyric Kemmer	lyric.kemmer@warmmail.com	Portland	Oregon	4296906135540	daccb0a6380b3eaf2fd8764a0d3605d5	Maestro	45.5473285692632217	-122.634949734760454
5232	2019-11-13 12:45:15	2019-11-13	Domenick Kling	domenick.kling@woohoo.com	Berkeley	California	3039426953432323	36343d24b144d8c04ad4d0b56a0c8ef6	Voyager	37.8656528449901231	-122.25289170884642
5233	2019-11-13 12:56:31	2019-11-13	Orra Lemke	orra.lemke@geemail.com	Plano	Texas	4207739152859	65af6c5a5d25db5e25b2cfa9a9970060	Mastercard	32.9969782176978939	-96.6578978941958411
5234	2019-11-13 12:57:29	2019-11-13	Loree Daugherty PhD	loree.daugherty.phd@geemail.com	San Francisco	California	210032483062045364	45b18ff9b03345bfb133132afe388d25	Maestro	37.7992558524016644	-122.423927412862341
5235	2019-11-13 14:19:10	2019-11-13	Mr. Dejuan Champlin V	mr.dejuan.champlin.v@geemail.com	New York	New York	4157032095344333	a7b023ae500701a853219be16610c68c	JCB 16 digit	40.64743896073103	-74.0281654407631606
5236	2019-11-13 14:29:37	2019-11-13	Krish Sawayn	krish.sawayn@geemail.com	Pompano Beach	Florida	3023092217982218	1b3fe038e64f504efa58773aaddc379e	JCB 16 digit	26.2439350795265263	-80.1570496370863168
5237	2019-11-13 14:59:00	2019-11-13	Miss Unknown Lehner	miss.unknown.lehner@geemail.com	San Francisco	California	3158728112056416112	49bc34f818471d52bc16461c9851f59c	JCB 16 digit	37.7839986092853977	-122.421197715225162
5238	2019-11-13 15:33:15	2019-11-13	Irine Nitzsche DDS	irine.nitzsche.dds@geemail.com	Oakland	California	3028359342240712	10b7e6b3efd48f345fe83f24a8b313e3	VISA 16 digit	37.8057384535387015	-122.273105742203839
5239	2019-11-13 15:46:17	2019-11-13	Vallie Huel	vallie.huel@woohoo.com	Dallas	Texas	3454136764448517	a2fdeeec1f2ecc9604004d5f78da635c	American Express	32.7037481758549831	-96.8635746674109157
5240	2019-11-13 16:04:37	2019-11-13	Denzell Roberts	denzell.roberts@geemail.com	San Francisco	California	869924673655102107	076899f11208ed6365439df5373c4e4e	JCB 15 digit	37.770764075041626	-122.402758947776661
5241	2019-11-13 16:06:18	2019-11-13	Jimena Stehr	jimena.stehr@geemail.com	Oakland	California	3337337327361259998	070994e8aced9d2d7b8791769a46e95a	Diners Club / Carte Blanche	37.8022283857155657	-122.293735393967182
5242	2019-11-13 16:41:21	2019-11-13	Junior Leuschke	junior.leuschke@woohoo.com	San Francisco	California	3528781233034364259	1e0a1043bfff536aa83687e328f7c2e7	Mastercard	37.7977085272603333	-122.482525080492294
5243	2019-11-13 17:32:32	2019-11-13	Marshal Little	marshal.little@woohoo.com	Berkeley	California	4094808051773664	d83d93e8f5959fcc945f0a8a4e5ada45	American Express	37.85116421196674	-122.249603462862339
5244	2019-11-13 18:37:14	2019-11-13	Monna Will	monna.will@geemail.com	New York	New York	4140891024899	3878c52487e0a7ab839e772fc615d50f	American Express	40.6098900477159788	-73.9643043310277193
5245	2019-11-13 19:13:34	2019-11-13	Miss Kira Hahn	miss.kira.hahn@geemail.com	Hollywood	Florida	4741445280745	521ba170638469f07fdc078275935780	VISA 16 digit	26.0011693783048514	-80.1504343999367137
5246	2019-11-13 19:17:20	2019-11-13	Gannon Smith	gannon.smith@geemail.com	Berkeley	California	6011028978773100412	e07d90173c2b7e76938ce1e0126ad1e3	JCB 16 digit	37.8813292320042976	-122.27974790513214
5247	2019-11-13 20:32:10	2019-11-13	Jerrad Ernser	jerrad.ernser@geemail.com	Los Angeles	California	6011771945082852164	368b72cca08c5257d7259f9d70fa84f1	VISA 16 digit	34.0553672806691381	-118.495236715906486
5248	2019-11-13 21:05:51	2019-11-13	Loma DuBuque	loma.dubuque@geemail.com	San Francisco	California	55428805611961687	26daca2787f25e530455f8617474a6ab	Diners Club / Carte Blanche	37.7848408017768946	-122.406912534708496
5249	2019-11-13 21:07:51	2019-11-13	Deondre Corwin	deondre.corwin@woohoo.com	Portland	Oregon	4041586219929	c004d8c1cfe2102d889ea20c5357abc0	Mastercard	45.5588428593594585	-122.633152963547047
5250	2019-11-13 21:48:41	2019-11-13	Gussie Wisoky-Christiansen	gussie.wisoky.christiansen@geemail.com	Newark	New Jersey	4104212382311492	0f64293ad9245cb3d34967c2dd46f998	JCB 16 digit	40.6503512666940736	-74.2156650989059443
5251	2019-11-13 21:52:10	2019-11-13	Dereck McKenzie DVM	dereck.mckenzie.dvm@geemail.com	Indianapolis	Indiana	4452381396772	90fd1bbd4ba271a8209ed296a55ee9c3	VISA 16 digit	39.7035871060106871	-86.1247940856233214
5252	2019-11-13 22:30:12	2019-11-13	Dr. Ayaan McClure PhD	dr.ayaan.mcclure.phd@geemail.com	San Francisco	California	3050671353211194	372b7bf451f8409ab837032b8b9d3110	JCB 16 digit	37.7891113237770213	-122.404446256584336
5253	2019-11-14 00:20:29	2019-11-14	Alecia Breitenberg PhD	alecia.breitenberg.phd@geemail.com	San Francisco	California	3528115795692154674	2f89e3a843a9664e56da65794bc4a36a	Mastercard	37.7460024082648431	-122.462074790685648
5254	2019-11-14 00:47:37	2019-11-14	Demetric Veum	demetric.veum@geemail.com	San Antonio	Texas	676150639222012	b6dc82d41a125af7f5f3d966d9a55ec9	JCB 16 digit	29.4229550962872821	-98.5869796945083863
5255	2019-11-14 01:20:34	2019-11-14	Brian Conroy DDS	brian.conroy.dds@geemail.com	San Francisco	California	4203431624626	62578e21746242b239417099cefb3226	JCB 16 digit	37.7886010062913016	-122.454500193585446
5256	2019-11-14 01:31:39	2019-11-14	Desiree Towne	desiree.towne@warmmail.com	San Francisco	California	4298806564239706	570d32a8ef8e20d8ed1ab0d386f5127e	JCB 16 digit	37.7542858548438147	-122.431074969324783
5257	2019-11-14 01:39:19	2019-11-14	Johnie Gutkowski	johnie.gutkowski@geemail.com	San Francisco	California	501888622810047	bdee27e4e07b9c81782a137f4bce41f4	Maestro	37.7749273362096645	-122.434726151538072
5258	2019-11-14 02:17:14	2019-11-14	Elbert Moen-Mraz	elbert.moen.mraz@woohoo.com	Jacksonville	Florida	3054157748347212	103c52466532f8999e6e1efb31e9cf69	JCB 16 digit	30.4084084528550491	-81.7604640523515656
5259	2019-11-14 02:26:35	2019-11-14	Jensen Pfannerstill	jensen.pfannerstill@geemail.com	Berkeley	California	51515205309823220	ef73f606ef46fb319ce63905d86fca50	JCB 16 digit	37.8687011636564037	-122.239779906293421
5260	2019-11-14 02:58:30	2019-11-14	Keith O'Kon	keith.o'kon@woohoo.com	San Francisco	California	6011297920898959243	6a11b8426a11df3503ae679f5e0c419a	JCB 16 digit	37.7576156894486274	-122.423967153941234
5261	2019-11-14 03:06:59	2019-11-14	Steward Walker	steward.walker@warmmail.com	Detroit	Michigan	3042492369339095	cb9a45b3d26b6d0a68720c2de9f06e0b	Mastercard	42.4664497733507318	-83.0851526351299157
5262	2019-11-14 03:43:37	2019-11-14	Clovis Bernhard	clovis.bernhard@geemail.com	Kansas City	Missouri	3112849284169607988	6ae6414b30a7d380df484ea30308bee6	VISA 16 digit	39.1312066234484348	-94.5143030688855816
5263	2019-11-14 03:48:11	2019-11-14	Regan Hayes	regan.hayes@geemail.com	Stockton	California	869986926039481299	4d4e8f1d7b158627019f2d980d5ae937	Diners Club / Carte Blanche	37.8804382129304145	-121.233337891389795
5264	2019-11-14 06:05:40	2019-11-14	Dr. Dorman Homenick DVM	dr.dorman.homenick.dvm@geemail.com	San Jose	California	4108673511864246	1a3904f350ef9ba0b85786ce968d3684	JCB 16 digit	37.2387689714606864	-121.802479823886969
5265	2019-11-14 06:20:41	2019-11-14	Denton Schiller	denton.schiller@geemail.com	Ontario	California	3058992823309489	0defb71ceee60dd76358244bdd7c01cb	JCB 15 digit	34.0288392689690014	-117.699111780301493
5266	2019-11-14 06:23:10	2019-11-14	Suzette Greenholt	suzette.greenholt@woohoo.com	Memphis	Tennessee	180016047550086501	adb77f2365c602d8e17173a9b7aeb083	VISA 16 digit	35.1461493106160319	-90.033988266696781
5267	2019-11-14 06:40:13	2019-11-14	Sharleen McGlynn-Harvey	sharleen.mcglynn.harvey@woohoo.com	San Francisco	California	3528318135140606493	acd4c0296adbe3e9437133a442c20e6d	JCB 16 digit	37.7978898662158898	-122.433762510448062
5268	2019-11-14 07:30:01	2019-11-14	Tinie Baumbach-Labadie	tinie.baumbach.labadie@geemail.com	New York	New York	4238233130786	137d1b0044438c0e2abf4e08d269ff42	VISA 16 digit	40.6707749137412762	-73.9930273751158296
5269	2019-11-14 07:55:29	2019-11-14	Aime Ferry	aime.ferry@geemail.com	Phoenix	Arizona	3088468038907761972	616a9e8d025bcbd9abee2befe2a8edcc	VISA 16 digit	33.5377214979313365	-112.136826703085006
5270	2019-11-14 08:23:19	2019-11-14	Chandra Howell	chandra.howell@geemail.com	Mobile	Alabama	3112171345900654908	033abeaa5cf4140d10bdf25e28f56ffe	JCB 16 digit	30.7580896478719978	-88.1120153940420607
5271	2019-11-14 09:37:20	2019-11-14	Mr. Laurence VonRueden Sr.	mr.laurence.vonrueden.sr.@geemail.com	Hillsboro	Oregon	869929209722339136	81f2430b43b6499e621bc6b164935736	Mastercard	45.492717857865614	-122.957639859911794
5272	2019-11-14 10:45:02	2019-11-14	Henry Conroy	henry.conroy@geemail.com	Glendale	California	502031849797035	f793cff267c00bf9757b354a7c7877f0	Diners Club / Carte Blanche	34.2450389387771423	-118.207532013151052
5273	2019-11-14 11:10:30	2019-11-14	Jo O'Reilly	jo.o'reilly@warmmail.com	New York	New York	3088055971959190790	508017c0e891105fd32e766fbc98dabe	Maestro	40.7631264127548789	-73.9797986180882816
5274	2019-11-14 11:12:37	2019-11-14	Ms. Mittie Runolfsdottir PhD	ms.mittie.runolfsdottir.phd@geemail.com	Boise	Idaho	3015498499358688	17e5043b3f9ed69afd216be2d4b2b1f8	Discover	43.6771410255365069	-116.274042491308236
5275	2019-11-14 11:46:02	2019-11-14	Torrance Koch	torrance.koch@geemail.com	Oakland	California	4589661368270573	b59259f8764259728e071f998edf568a	JCB 15 digit	37.80798708734185	-122.304825777321696
5276	2019-11-14 12:20:37	2019-11-14	Yessenia Collins	yessenia.collins@warmmail.com	Los Angeles	California	3777528701959353	33f826e2efd472e23fb9a0126dc9ee36	VISA 13 digit	34.0150875590607527	-118.347175037720419
5277	2019-11-14 12:39:17	2019-11-14	Cornelious Davis	cornelious.davis@geemail.com	Berkeley	California	869990785137042435	48e3d3b468f9bf8f0c42955b2b206fd8	Maestro	37.8599916350098411	-122.265473190341282
5278	2019-11-14 13:00:55	2019-11-14	Mrs. Danna Rosenbaum DDS	mrs.danna.rosenbaum.dds@geemail.com	Sacramento	California	6011178112531933975	7866fbf0906b434bf8770ccbae9a539a	JCB 16 digit	38.6103899409327695	-121.490729733860491
5279	2019-11-14 13:03:53	2019-11-14	Dr. Nico Wisoky MD	dr.nico.wisoky.md@woohoo.com	San Francisco	California	3476142402142011	1d346e7d73573410b97e9bfdf150d0e9	JCB 15 digit	37.7681759462299453	-122.408709786082341
5280	2019-11-14 13:08:31	2019-11-14	Dr. Laila Bins DDS	dr.laila.bins.dds@geemail.com	Odessa	Texas	4191862773379583	19c4cde23e2e9c8de557d5e2bcc69d9d	Diners Club / Carte Blanche	31.9129635149158553	-102.431163832607112
5281	2019-11-14 14:04:45	2019-11-14	Lyla Hansen-Breitenberg	lyla.hansen.breitenberg@geemail.com	Berkeley	California	6011990691052611900	802f9613e3dfd77f79835830ead58de0	VISA 16 digit	37.8756208726112575	-122.296516694418742
5282	2019-11-14 14:10:01	2019-11-14	Mr. Devyn Monahan	mr.devyn.monahan@geemail.com	San Francisco	California	54598277861476861	4548ad7824e24e6bf25ee6870bab3f65	Voyager	37.775244106219013	-122.440130341768707
5283	2019-11-14 14:12:45	2019-11-14	Mr. Denis Anderson	mr.denis.anderson@geemail.com	San Francisco	California	54719439370156483	723db38321626dff09dc3bde222b872f	VISA 16 digit	37.7456157177926173	-122.407962057610504
5284	2019-11-14 14:22:47	2019-11-14	Almus Sipes	almus.sipes@geemail.com	McKinney	Texas	52124091031696115	abfe94a50b6af72aca4a2ec143dc1817	American Express	33.1256457882132409	-96.5758781394287951
5285	2019-11-14 14:29:04	2019-11-14	Valinda McKenzie	valinda.mckenzie@geemail.com	Indianapolis	Indiana	3088961188010180859	f2f53f82abdb35638e78ee0e5d2ece74	VISA 13 digit	39.8630674501422746	-86.0720897895019448
5286	2019-11-14 14:32:50	2019-11-14	Meggan Abbott	meggan.abbott@geemail.com	San Francisco	California	869922037638816617	440457d7a32cb5de5314c91978a84f8b	Maestro	37.7512282745018126	-122.431738650442455
5287	2019-11-14 16:15:47	2019-11-14	Vicente White	vicente.white@geemail.com	San Jose	California	4863660431820445	737d8f7a700447b8e9c052ab273b5265	JCB 15 digit	37.3690698491696267	-121.891518247475474
5288	2019-11-14 16:48:58	2019-11-14	Salma Legros-Barrows	salma.legros.barrows@geemail.com	New York	New York	4065299680218	d9544580d73c8a37f2e5782e93d5caea	VISA 16 digit	40.5885320550054303	-73.9477674593113363
5289	2019-11-14 18:13:12	2019-11-14	Iona Veum-Gibson	iona.veum.gibson@geemail.com	Bridgeport	Connecticut	3731052824642510	2b92f37282ef3b6dccb2fa1ba5989394	VISA 16 digit	41.1281293869648081	-73.1307753851070999
5290	2019-11-14 18:16:52	2019-11-14	Mr. Mateo Connelly DVM	mr.mateo.connelly.dvm@geemail.com	San Francisco	California	3012935196826247	88b321a862fef02af4dbe12644ffcfd8	Mastercard	37.7668031844629937	-122.432892627004506
5291	2019-11-14 18:51:39	2019-11-14	Eusebio Schroeder	eusebio.schroeder@geemail.com	Tacoma	Washington	4603481896597120	34123ec458614ab6fa70911f22f9e977	Diners Club / Carte Blanche	47.3053755441334118	-122.382821495481949
5292	2019-11-14 19:28:48	2019-11-14	Marvin Pacocha	marvin.pacocha@woohoo.com	San Francisco	California	4085200410141141	38272de672b4f72c4080220b4c6caaed	JCB 16 digit	37.8178637799080377	-122.444793839496811
5293	2019-11-14 21:07:07	2019-11-14	Gillie Padberg	gillie.padberg@woohoo.com	San Francisco	California	3528705141723611695	73c4da8d3901886d9d3bd5398892543f	Mastercard	37.7760456768212762	-122.442083143856166
5294	2019-11-14 21:42:15	2019-11-14	Ms. Michal Stanton DDS	ms.michal.stanton.dds@geemail.com	Houston	Texas	869997419428680272	179b7708f6c7ea43558b0fe0f3058de8	Maestro	29.8083518717050566	-95.4177701523542368
5295	2019-11-14 22:31:55	2019-11-14	Obed Reichel	obed.reichel@geemail.com	Escondido	California	869932619546264457	28eb28c8ac6a82708daecaada772feed	Discover	33.1544353393599351	-117.126039472805331
5296	2019-11-14 22:35:27	2019-11-14	Jane Haley	jane.haley@geemail.com	Topeka	Kansas	3725353439277744	35170550a33f748d5d8aa1e14afa74fd	JCB 16 digit	39.0843846388559797	-95.7683003216691304
5297	2019-11-14 22:35:42	2019-11-14	Wm Beatty	wm.beatty@geemail.com	New York	New York	3726791754169385	4405fb3f3bf9b5d3b7ef06a1e30d6b33	Diners Club / Carte Blanche	40.5679483466539494	-73.9343605183426291
5298	2019-11-14 22:59:26	2019-11-14	Miss Lonna Mohr	miss.lonna.mohr@woohoo.com	Tacoma	Washington	180046177401458593	ebeb01a835fd7b10c8c64f7cd8996b49	Maestro	47.2470809159453964	-122.543405537749834
5299	2019-11-14 23:34:40	2019-11-14	Shana Ryan	shana.ryan@geemail.com	San Francisco	California	3048608046235299	1180b79a0c5ae5f2e6845a6447f6faa5	VISA 16 digit	37.7943410875309169	-122.470534796978754
5300	2019-11-15 00:35:34	2019-11-15	Londyn Hermann	londyn.hermann@warmmail.com	San Francisco	California	6011189436123603580	dceb5b13b3314187a338a6fe5dc2fba5	Discover	37.7610137583856371	-122.427053723840416
5301	2019-11-15 01:22:05	2019-11-15	Gaye Marquardt	gaye.marquardt@woohoo.com	Oakland	California	3447122438123017	a8d8b38fc1ecca77e91144ebd91940dd	Diners Club / Carte Blanche	37.8014699640287688	-122.313956694877916
5302	2019-11-15 01:46:17	2019-11-15	Alto Orn	alto.orn@warmmail.com	San Francisco	California	3007133308617283	c8caf699ac4f7b21a15d96c8349e833e	VISA 16 digit	37.784852786655847	-122.45146845034175
5303	2019-11-15 01:48:55	2019-11-15	Goebel Rath	goebel.rath@geemail.com	San Francisco	California	4184349325802097	3264c1d77d8c38d7fb611e68f8a3c9df	American Express	37.7720284822390298	-122.401857040873011
5304	2019-11-15 02:06:48	2019-11-15	Manilla Kling MD	manilla.kling.md@warmmail.com	Winston–Salem	North Carolina	3485462572670149	a591d59c37024eb3af57a98521c47af1	Diners Club / Carte Blanche	36.1181079771134961	-80.2854351453147785
5305	2019-11-15 02:28:20	2019-11-15	Nunzio Ledner	nunzio.ledner@geemail.com	Austin	Texas	180059419375492073	3ddb6b018fd6981df8e25edd7d539841	JCB 15 digit	30.2138975104443723	-97.7260313382145114
5306	2019-11-15 03:03:00	2019-11-15	Levin Parisian IV	levin.parisian.iv@geemail.com	Berkeley	California	3474942598056442	2e7c2f97342b53bde646d6ab67379fe7	VISA 13 digit	37.8390825066924066	-122.255852898136226
5307	2019-11-15 03:18:38	2019-11-15	Mr. Melton West I	mr.melton.west.i@geemail.com	San Francisco	California	3096876762976384392	14bcd97d3ca6f28e19bc00463c156536	JCB 15 digit	37.7857701824690935	-122.466504169202352
5308	2019-11-15 03:31:55	2019-11-15	Noel Weissnat-Jacobi	noel.weissnat.jacobi@woohoo.com	San Francisco	California	869986810317759610	b70ea50bac8736a1f956d6bfbb3c1728	JCB 16 digit	37.794606846037162	-122.427250396256071
5309	2019-11-15 03:33:16	2019-11-15	Conrad Parisian	conrad.parisian@geemail.com	New York	New York	3022650274217744	6202b8782a65bdfe6aa01338beabf83f	Diners Club / Carte Blanche	40.5912900426182901	-74.0355080716673228
5310	2019-11-15 03:56:55	2019-11-15	Le Conn	le.conn@woohoo.com	Berkeley	California	4887821745478	8f1855cb6072bffb147ec3c35e69af3a	VISA 16 digit	37.8948566438394749	-122.265663471928917
5311	2019-11-15 04:17:02	2019-11-15	Essex Koss-Eichmann	essex.koss.eichmann@geemail.com	San Francisco	California	3528980662536733323	cdf0dd2d50bb08074e2da43f17559a4b	VISA 13 digit	37.7905932203768273	-122.422341065301993
5312	2019-11-15 04:30:39	2019-11-15	Dwane Goodwin	dwane.goodwin@woohoo.com	El Paso	Texas	869925996389331208	d543403a9f367dd7a613dc774a3d6039	JCB 16 digit	31.7772445663638443	-106.342473732212568
5313	2019-11-15 05:41:06	2019-11-15	Shiloh Denesik	shiloh.denesik@geemail.com	Oakland	California	4648588094237957	96d2b23b1b507528dfdf513f5bf641aa	VISA 13 digit	37.7840716406792367	-122.282033537433279
5314	2019-11-15 07:16:02	2019-11-15	Braedon Bednar	braedon.bednar@geemail.com	San Francisco	California	3088964614427017720	2cf528c8cf915b0a0dbe9865f6d103e8	JCB 15 digit	37.8008942485584498	-122.419455410225524
5315	2019-11-15 07:18:54	2019-11-15	Bryton Casper	bryton.casper@woohoo.com	Riverside	California	4512872440049	67e34cb34c382ac59271c628bbbe18b8	JCB 16 digit	33.8895295694883885	-117.378160021357971
5316	2019-11-15 07:34:17	2019-11-15	Dr. Brianna Cruickshank MD	dr.brianna.cruickshank.md@geemail.com	Dallas	Texas	060495094983608	5d845057914d4175f97a3199d0eec8e3	Discover	32.8810883811947008	-96.7957868415824976
5317	2019-11-15 07:38:53	2019-11-15	Tory Kuhlman	tory.kuhlman@woohoo.com	Midland	Texas	53841405248033403	b6b2cdbaebed8da842a4537786f9c20d	JCB 15 digit	32.0048740910556191	-102.052140339346607
5318	2019-11-15 07:54:05	2019-11-15	Bernadine Kulas	bernadine.kulas@geemail.com	San Francisco	California	869995966114449760	b5c8bc60b805ae9cfee4b43b18835560	American Express	37.7573056720527376	-122.454060784446298
5319	2019-11-15 08:03:08	2019-11-15	Juliette Gorczany	juliette.gorczany@geemail.com	Lexington	Kentucky	4866212983386222	6ea7b051b3b96595135e7da736fb64c0	JCB 16 digit	38.0744378044147069	-84.4218290569625793
5320	2019-11-15 08:12:31	2019-11-15	Ms. Alyvia Crona DVM	ms.alyvia.crona.dvm@warmmail.com	San Jose	California	210041663179788860	28b142f25eb3613af91e9fd1d3af35c2	Mastercard	37.2274615472003845	-121.840842678093907
5321	2019-11-15 08:18:36	2019-11-15	Darcy Mante	darcy.mante@geemail.com	Norfolk	Virginia	4915857889927700	8dd3a9a97cc0dc2169fbdcfff7a12b7d	Discover	36.9541669818125698	-76.3021405335985179
5322	2019-11-15 09:48:56	2019-11-15	Dr. Weston Labadie IV	dr.weston.labadie.iv@geemail.com	Nashville	Tennessee	6011479481327394635	f0c98a52c873b4d2d6e4af3cc1c96566	Discover	36.0765663441859132	-86.707888887440788
5323	2019-11-15 10:06:43	2019-11-15	Deryl Hand	deryl.hand@geemail.com	Gilbert	Arizona	4949414087924541	349b2aeaf5c27de5c18e3ced4eaea353	American Express	33.2289384756583672	-111.657910000732542
5324	2019-11-15 10:20:55	2019-11-15	Lovey Kassulke	lovey.kassulke@warmmail.com	New York	New York	675948528796161	54ff3874cab841e12058aeeefe313d46	Maestro	40.7056579073648876	-73.914769196267045
5325	2019-11-15 10:47:07	2019-11-15	Mr. Hall Corwin II	mr.hall.corwin.ii@warmmail.com	Santa Rosa	California	561267449633733	ed8607414c1a03801a105fa040971730	American Express	38.4701980895485747	-122.611372278143094
5326	2019-11-15 10:57:15	2019-11-15	Jaquan Waters	jaquan.waters@geemail.com	San Francisco	California	6011953197725000526	6f1ee8c42f300a21270e593fd07ec6b6	JCB 16 digit	37.7548439869203989	-122.438000086097148
5327	2019-11-15 10:58:22	2019-11-15	Tinie Feest	tinie.feest@geemail.com	Atlanta	Georgia	3434334597366700	89c2bcd1a7a6aba1ab4370d2167dd18f	VISA 16 digit	33.6647539158627396	-84.4485701586164623
5328	2019-11-15 11:06:19	2019-11-15	Tad Brakus	tad.brakus@woohoo.com	Akron	Ohio	51887745623735832	b3f03fc48ed2263696513ff80c752de0	JCB 16 digit	41.0990436434578186	-81.6208054313283355
5329	2019-11-15 11:42:12	2019-11-15	Burl Bashirian	burl.bashirian@warmmail.com	Charlotte	North Carolina	639001065862037	4aa32a32fc36a93bd60f4829160921d1	Mastercard	35.134954333796351	-80.8529617082737389
5330	2019-11-15 11:46:08	2019-11-15	Tate Fritsch	tate.fritsch@geemail.com	San Francisco	California	4479463006202438	22cb316247ef11625ad1f3c328f53e58	VISA 16 digit	37.789226403909062	-122.44871836653158
5331	2019-11-15 12:43:37	2019-11-15	Cherish Kozey	cherish.kozey@geemail.com	Anaheim	California	4927136258955	1ffcc2f7f404777feb464bad238e3766	Voyager	33.8047835823446476	-117.758563551420707
5332	2019-11-15 13:22:49	2019-11-15	Coley Osinski-Lemke	coley.osinski.lemke@woohoo.com	San Francisco	California	3011335824029614	c5acdaf2fb1affc2bcd48d9135d372e7	VISA 13 digit	37.7594831294920823	-122.421757556107039
5333	2019-11-15 13:37:25	2019-11-15	Reagan Schaden I	reagan.schaden.i@warmmail.com	New York	New York	180048978068400572	c823bc6b69a868a7edfbad528d37df43	American Express	40.6017880663033566	-73.9392660381168128
5334	2019-11-15 13:49:03	2019-11-15	Arley Klein	arley.klein@geemail.com	San Francisco	California	6011694534098679821	b33a86911e15387445e7dcfa44d9ba20	JCB 16 digit	37.8010087322647266	-122.427434876373425
5335	2019-11-15 14:06:35	2019-11-15	Mrs. Cleda Konopelski DDS	mrs.cleda.konopelski.dds@geemail.com	San Diego	California	4828820679904	2234dc9f997f43508474f85ed4e96504	JCB 15 digit	32.8545902896739577	-117.060255630956974
5336	2019-11-15 14:09:06	2019-11-15	Mr. Darnell Dibbert IV	mr.darnell.dibbert.iv@geemail.com	San Francisco	California	4306581430726	04feb7b24f962b74e7e61b298c00bc72	Mastercard	37.796799940537305	-122.427092699809265
5337	2019-11-15 15:53:54	2019-11-15	Gerry Monahan	gerry.monahan@geemail.com	Sandy Springs	Georgia	4140882417920	3cefb2164af6dbd43d618e5acb77e158	VISA 13 digit	34.0278371062185627	-84.4205487900495513
5338	2019-11-15 16:01:07	2019-11-15	Hubbard Harvey Sr.	hubbard.harvey.sr.@geemail.com	Oakland	California	4250807885430	363dcf65a06eb72a65646b65ee8efd26	JCB 16 digit	37.8006998919769401	-122.273430322550311
5339	2019-11-15 16:02:46	2019-11-15	Dr. Clovis Kutch	dr.clovis.kutch@geemail.com	Los Angeles	California	869934374959306704	5610b20c07bf04068a1caad07d97a1da	JCB 16 digit	34.0763138411432465	-118.329223817772416
5340	2019-11-15 16:26:14	2019-11-15	Leslie Tillman DVM	leslie.tillman.dvm@geemail.com	Philadelphia	Pennsylvania	3474677362867786	b3a01116b216fda217742edb40969015	Voyager	39.9511988746426994	-75.0685683672681563
5341	2019-11-15 16:28:36	2019-11-15	Ariel Rolfson	ariel.rolfson@geemail.com	Albuquerque	New Mexico	676354934932275	3e4fc10646a5e5391dd391f5e116eba8	VISA 16 digit	35.1093775132805135	-106.588542320912339
5342	2019-11-15 16:30:52	2019-11-15	Marchello Doyle	marchello.doyle@geemail.com	Irvine	California	3528819772030762095	23cfbb4a9290a72eb00711feb962ac20	Diners Club / Carte Blanche	33.7567499139826808	-117.771763443342593
5343	2019-11-15 16:44:33	2019-11-15	Luka Cummerata	luka.cummerata@geemail.com	Berkeley	California	4567376555940	2a4200577319921b08018357ca212afa	Voyager	37.841202113699687	-122.263827934718691
5344	2019-11-15 16:59:09	2019-11-15	Grayling White	grayling.white@woohoo.com	Yonkers	New York	3096007489158441368	19b55b515bbba3f29bc48882d2c61364	Diners Club / Carte Blanche	41.0007389072064328	-73.8930342035718297
5345	2019-11-15 18:25:51	2019-11-15	Eric Marquardt IV	eric.marquardt.iv@geemail.com	Dallas	Texas	3026426801312944	0f746e5562f5890db60d4630b0271e08	Maestro	32.8885569188550164	-96.6702313081324007
5346	2019-11-15 18:31:39	2019-11-15	Ariana Beier	ariana.beier@woohoo.com	Charlotte	North Carolina	4103891286714082	11e343b30f86fe2e3cf884c4aa302c25	VISA 13 digit	35.2262225163888161	-80.8546180152744114
5347	2019-11-15 20:33:19	2019-11-15	Atlas McCullough Jr.	atlas.mccullough.jr.@woohoo.com	Anchorage	Alaska	869921626703535804	949e32b17e2e3e924b9061f24b1d9936	Voyager	61.2235895889095971	-149.317307300132882
5348	2019-11-15 20:51:44	2019-11-15	Kindra O'Kon	kindra.o'kon@warmmail.com	Colorado Springs	Colorado	589335461737658	c9e5419816eb32d9a7eb265b140d3fef	VISA 13 digit	38.9394713341772558	-104.793839407495042
5349	2019-11-15 21:18:21	2019-11-15	Loni Rogahn-Hamill	loni.rogahn.hamill@warmmail.com	Winston–Salem	North Carolina	869911415352693854	cb2e33dfe0f5ea3a1820db32edc5327c	JCB 15 digit	36.1309574510201799	-80.2709561620037988
5350	2019-11-15 21:27:02	2019-11-15	Leon Veum-Morar	leon.veum.morar@geemail.com	Berkeley	California	3112548762440010670	50ce1fc305a5ec208a4c8dd93e423704	Diners Club / Carte Blanche	37.8642881553550055	-122.252103880964569
5351	2019-11-15 21:32:13	2019-11-15	Dr. Neveah Wisozk PhD	dr.neveah.wisozk.phd@geemail.com	Los Angeles	California	676151600691797	085cb3fa4b20ca80533d510e5a99f18a	VISA 16 digit	34.0107533692713773	-118.446387387345723
5352	2019-11-15 21:53:25	2019-11-15	Jasper Mayert	jasper.mayert@warmmail.com	Overland Park	Kansas	3088360456064527599	e9a27870d36c3e735a0df70793daaf0a	American Express	38.9591152703724859	-94.7219600553665373
5353	2019-11-15 21:56:07	2019-11-15	Marlon Kohler	marlon.kohler@geemail.com	Providence	Rhode Island	4899881237585	841dbe31fed8fbe59d5e0804dbb2fd4f	Voyager	41.725602199122676	-71.3456096057698232
5354	2019-11-15 22:50:15	2019-11-15	Donte Pollich-Erdman	donte.pollich.erdman@geemail.com	Berkeley	California	51059771771663636	5267ab8a505f439cce9eb5036db4386e	VISA 16 digit	37.8210282968859772	-122.24948530046963
5355	2019-11-15 23:37:53	2019-11-15	Kelton Gleason III	kelton.gleason.iii@warmmail.com	Oakland	California	4997464940522827	fc2aa52735d287c6cf9e8a63235d0b43	Mastercard	37.7975077439961424	-122.253448602706868
5356	2019-11-16 00:45:22	2019-11-16	Mr. Arthor Langosh	mr.arthor.langosh@geemail.com	San Mateo	California	589313093091356	8b1478e1fce1ed7523a4ae67d024fa1d	American Express	37.6365549401726582	-122.315818384834003
5357	2019-11-16 01:11:11	2019-11-16	Mr. Demarcus Lind	mr.demarcus.lind@geemail.com	West Valley City	Utah	060478675251900	a5d7601177faa3bbfe7d4cfb3f543a2e	Mastercard	40.6692356373872599	-112.089750231777501
5358	2019-11-16 02:46:00	2019-11-16	Hayden Mraz	hayden.mraz@geemail.com	Rockford	Illinois	3112728628742106080	d16f31fb6ad1da4c4e7f98f8bdbfd7ba	JCB 16 digit	42.2460354334220298	-89.0101808427184835
5359	2019-11-16 03:15:58	2019-11-16	Irven Kulas	irven.kulas@geemail.com	Columbus	Ohio	3052854464820446	a1196511ffad41733468ba617b089f54	Discover	40.0558808748189321	-82.9071204233683687
5360	2019-11-16 03:17:17	2019-11-16	Anson Dicki-Erdman	anson.dicki.erdman@warmmail.com	El Paso	Texas	3158635279263707385	7ffd18b34959b7a55dc736e9c6f401ba	American Express	31.8774309346281015	-106.350705563042325
5361	2019-11-16 04:07:11	2019-11-16	Chet Schaefer DDS	chet.schaefer.dds@geemail.com	San Francisco	California	3011108632259073	9373314bf644ee64db780b7726d224f4	VISA 16 digit	37.7617091841871542	-122.425316578385818
5362	2019-11-16 04:58:59	2019-11-16	Hal Smitham-Reichert	hal.smitham.reichert@geemail.com	Lincoln	Nebraska	060427940847398	c01bd8c20abe44ca0092cc8e7559f3b9	VISA 16 digit	40.8430039314571758	-96.7021471886124431
5363	2019-11-16 05:24:11	2019-11-16	Jasen Aufderhar	jasen.aufderhar@woohoo.com	Kansas City	Kansas	4397219049673	1dafbd90faa24ca5282d4eb2e9658567	VISA 16 digit	39.0802554469462535	-94.7183731969848282
5364	2019-11-16 05:27:42	2019-11-16	Mandi Reinger	mandi.reinger@geemail.com	San Francisco	California	3158110463772610686	c6d08a9d79585b2f7d26efa157a79429	Voyager	37.7814899996600602	-122.407393486004523
5365	2019-11-16 05:52:24	2019-11-16	Elizah Aufderhar Jr.	elizah.aufderhar.jr.@geemail.com	Kansas City	Missouri	3158228666264109699	23ecead2f466f7780ffbcd418190efe9	JCB 16 digit	39.1301586651079418	-94.6251312921512948
5366	2019-11-16 06:26:48	2019-11-16	Madison Funk	madison.funk@woohoo.com	Ventura	California	6011564201565036649	8abcd0d26d03320c8dfec6fe2d6e49bb	JCB 16 digit	34.232900449416789	-119.238233510740841
5367	2019-11-16 06:50:42	2019-11-16	Dow Huel-Bernhard	dow.huel.bernhard@geemail.com	San Francisco	California	3019117924023487	b87505f879f8f97a880835808dfc1ce2	Mastercard	37.7707604683178317	-122.453501755966258
5368	2019-11-16 06:59:49	2019-11-16	Darry Volkman	darry.volkman@geemail.com	Detroit	Michigan	6011947166559776666	6387327ba4455392dd58402bf3d77d76	American Express	42.3077507638763635	-83.1832491599608232
5369	2019-11-16 07:58:59	2019-11-16	Dr. Verle Hills Sr.	dr.verle.hills.sr.@warmmail.com	Berkeley	California	6011628435842023129	9916e8bed85bea79f84f6f075aa104dd	JCB 15 digit	37.8812450810038541	-122.260851378606105
5370	2019-11-16 08:22:45	2019-11-16	Myron Blanda-Lebsack	myron.blanda.lebsack@warmmail.com	San Francisco	California	4880373380672796	18fced0d6681ad3ec4be1f8b960ec07e	JCB 16 digit	37.753668071247958	-122.435411061787903
5371	2019-11-16 08:50:12	2019-11-16	Iris Green	iris.green@geemail.com	Lafayette	Louisiana	4871718446523	bc6cc6b0880385a5d1b942826880810c	JCB 15 digit	30.1136330985441809	-92.0085617169123111
5372	2019-11-16 08:50:57	2019-11-16	Geoff Ernser I	geoff.ernser.i@warmmail.com	San Francisco	California	4896599764124	b946b4fc9479fdfc2b111def68f336df	JCB 16 digit	37.7472147616418781	-122.418867120978945
5373	2019-11-16 09:22:10	2019-11-16	Winnifred Schuppe	winnifred.schuppe@geemail.com	San Francisco	California	3402963683711904	849fe3b7504035c0dd64c7a41cd70e7c	Discover	37.7986974558231026	-122.431923290384674
5374	2019-11-16 10:10:14	2019-11-16	Liston Lubowitz	liston.lubowitz@geemail.com	San Francisco	California	3528653413973146553	c8e20c337aa8f5883e384e331b7e0c81	VISA 16 digit	37.7859488669924772	-122.399528447123174
5375	2019-11-16 10:23:06	2019-11-16	Mr. Tavion Welch DVM	mr.tavion.welch.dvm@woohoo.com	Rochester	New York	3457817421436055	b83b95d2648a2206159184659741c1ce	JCB 15 digit	43.0826201857045277	-77.5227631258085381
5376	2019-11-16 10:30:25	2019-11-16	Dejon Klein-O'Connell	dejon.klein.o'connell@woohoo.com	Aurora	Illinois	6011175397531361185	a91da3d3d48029d1e8d1e51e6078a796	VISA 16 digit	41.6997753921654066	-88.2234960448391661
5377	2019-11-16 10:48:02	2019-11-16	Katharine Rau	katharine.rau@warmmail.com	San Francisco	California	3528753804349227029	c5153e9e5a0169ae0df6245aa81c9224	Maestro	37.8016719803513794	-122.406548036661334
5378	2019-11-16 11:18:10	2019-11-16	Lyn Kunze	lyn.kunze@geemail.com	Berkeley	California	3528622648464606338	766decb80232c0d927c7aba753f3d3d1	VISA 16 digit	37.8844310267032114	-122.31363851942335
5379	2019-11-16 11:24:16	2019-11-16	Tracey Runolfsdottir	tracey.runolfsdottir@geemail.com	Amarillo	Texas	210075881819290639	9b881e11a689741e26fac05716c9d2dc	Maestro	35.2109954689327651	-101.732595748859282
5380	2019-11-16 11:41:57	2019-11-16	Jaidyn McCullough	jaidyn.mccullough@woohoo.com	Irvine	California	4306684247220595	8f47a86ea0c1ffc4220cef5ee112cf4f	American Express	33.6683549667723483	-117.692212636024877
5381	2019-11-16 12:01:45	2019-11-16	Celie Pfeffer	celie.pfeffer@geemail.com	New York	New York	3048245111764240	7129fe2d5496260764943c8731a79a1e	Maestro	40.5915609874520413	-74.0229561296653031
5382	2019-11-16 12:20:35	2019-11-16	Sandra Orn	sandra.orn@geemail.com	Phoenix	Arizona	3337942773344432094	4eb3c152251390f06167dc92bf8614e0	Diners Club / Carte Blanche	33.5489557779792733	-112.029302891383324
5383	2019-11-16 12:20:54	2019-11-16	Kaylah Stroman-Crona	kaylah.stroman.crona@geemail.com	Oakland	California	6011049701388057354	a4c23c961972f8285f94eaa74df39cfc	VISA 13 digit	37.84293753737348	-122.250840979378708
5384	2019-11-16 12:21:40	2019-11-16	Audrey Marquardt	audrey.marquardt@geemail.com	San Francisco	California	3088129199575107509	1b689ae78ac7857a3dbd6a3cea6fc305	Maestro	37.7880183793025353	-122.405773063797554
5385	2019-11-16 12:50:55	2019-11-16	Evonne Davis	evonne.davis@woohoo.com	Amarillo	Texas	4417727983625	f3dedd945adc666ebe1340b305b7dcff	Discover	35.2454010939389448	-101.87281021418498
5386	2019-11-16 12:51:26	2019-11-16	Blanchard Oberbrunner	blanchard.oberbrunner@geemail.com	San Francisco	California	3747920257562128	c9c92bcb79f4c96e374c212355886799	Maestro	37.7698025912740079	-122.437792444035495
5387	2019-11-16 12:56:31	2019-11-16	Abigail Crona	abigail.crona@geemail.com	San Francisco	California	3056159971076946	b8eefd4fc35ca933557481bde00a3aba	Maestro	37.7862579561432312	-122.419632424259007
5388	2019-11-16 13:08:06	2019-11-16	Constantine Little DVM	constantine.little.dvm@geemail.com	Escondido	California	6011394307312659595	6b79c4e9c5c2751c859c76b036d43a9f	Mastercard	33.1032142029836791	-117.148009009683506
5389	2019-11-16 13:17:43	2019-11-16	Nicola Kunze	nicola.kunze@geemail.com	Kansas City	Missouri	4489213718559	60d63a7aca7ff8fb238864af65010308	Discover	39.0730787446092833	-94.5174208914618958
5390	2019-11-16 13:22:36	2019-11-16	Zander Morissette	zander.morissette@woohoo.com	San Francisco	California	180091259304753827	0a22e7b82daf8ae77e46daf46fafb9dd	Mastercard	37.7810440118035444	-122.414682901914787
5391	2019-11-16 13:26:48	2019-11-16	Thurlow Adams	thurlow.adams@geemail.com	New York	New York	3158360987234242511	2b107a1f88b8c0a6bb81cff5ba3b2fae	VISA 16 digit	40.6930179435051969	-73.8801173468947354
5392	2019-11-16 13:28:29	2019-11-16	Ms. Azaria Kutch MD	ms.azaria.kutch.md@warmmail.com	San Francisco	California	3528239686161914956	b102cdfd425e5207ce4558f4f7134cff	Maestro	37.7862385174065096	-122.462434784478518
5393	2019-11-16 14:00:31	2019-11-16	Clovis Wilderman	clovis.wilderman@geemail.com	Omaha	Nebraska	3158973236352989456	c501139e7880af33e9ec1ef039843cf5	Mastercard	41.172502284371852	-96.0814805464468975
5394	2019-11-16 14:38:52	2019-11-16	Lolla Bartoletti	lolla.bartoletti@geemail.com	Elizabeth	New Jersey	4569052881825685	905b47610c3a87cf5730c7eb3082f68f	Discover	40.663982541545856	-74.1354706246349906
5395	2019-11-16 15:00:03	2019-11-16	Germaine Price	germaine.price@geemail.com	San Francisco	California	869915925094617207	1692b5019b7ac380fe337b84c8cb3c56	VISA 16 digit	37.7721990973966015	-122.44415015372951
5396	2019-11-16 15:15:44	2019-11-16	Lem Crist	lem.crist@warmmail.com	New York	New York	210022967739899403	9a8e540237815b10529dde1ef2b963fb	JCB 16 digit	40.7223987630326292	-74.0082320661179693
5397	2019-11-16 16:13:23	2019-11-16	Hayden Labadie-Hammes	hayden.labadie.hammes@woohoo.com	New York	New York	3528904557734159912	932e1f6c14c4f51bbaf8fb560209bdbb	Voyager	40.6610521676708032	-73.9869203152962029
5398	2019-11-16 16:22:00	2019-11-16	Huy Connelly-Kertzmann	huy.connelly.kertzmann@geemail.com	Chicago	Illinois	4413861385294463	f20fc2b03e4848be703456dac390b93f	VISA 16 digit	41.8926633494742262	-87.7125873752433733
5399	2019-11-16 16:42:20	2019-11-16	Zavier Wilkinson II	zavier.wilkinson.ii@warmmail.com	Henderson	Nevada	501822704623655	0a6125d731dff2294e8032b53820b1fd	Maestro	36.0959833507359065	-115.079809950494024
5400	2019-11-16 16:59:21	2019-11-16	Gail Schowalter	gail.schowalter@geemail.com	San Francisco	California	4809747151449955	6bbb0d689f0ed1798fe5623773716e3d	Maestro	37.7888540170806948	-122.420221728926876
5401	2019-11-16 19:03:41	2019-11-16	Miss Karley Funk	miss.karley.funk@warmmail.com	Vancouver	Washington	6011532820886345907	825f0eb5e374a4c9ab8aa37a92195a89	Discover	45.6586055507022905	-122.606803796493253
5402	2019-11-16 19:07:43	2019-11-16	Dr. Kiara Emmerich	dr.kiara.emmerich@geemail.com	Berkeley	California	589343903633261	930474bbf3ccfe986b0801770a4ef184	Discover	37.9033940021119946	-122.270885846458569
5403	2019-11-16 19:35:06	2019-11-16	Kimball Walsh	kimball.walsh@geemail.com	Jacksonville	Florida	4744172693692	3c4f7bbf5aa6df8f78ee3a818c651039	JCB 16 digit	30.2978605805948362	-81.7368338809892663
5404	2019-11-16 20:18:43	2019-11-16	Alex Ortiz	alex.ortiz@geemail.com	Oakland	California	53560143348597576	eae3240887a2beda2d4f463843d095ea	VISA 16 digit	37.8396938086830446	-122.274838252381969
5405	2019-11-16 20:38:49	2019-11-16	Miss Edris Morissette MD	miss.edris.morissette.md@geemail.com	St. Petersburg	Florida	52043976310198254	55f275740876064db67991a817a6e434	JCB 16 digit	27.7280402778070432	-82.7092483836583767
5406	2019-11-16 21:10:10	2019-11-16	Marco Zieme-Spencer	marco.zieme.spencer@geemail.com	San Francisco	California	3096069981338054181	7b0ff9dbedd78c2a2fd33c08fb6c4f93	VISA 16 digit	37.7986802762662606	-122.409403373974015
5407	2019-11-16 22:27:01	2019-11-16	Damon Swaniawski III	damon.swaniawski.iii@woohoo.com	Philadelphia	Pennsylvania	180075224736010808	b251baa52dadf564c05929f005af0a42	Discover	39.9136586346156861	-75.0485307985816235
5408	2019-11-16 22:33:01	2019-11-16	Clarence McKenzie	clarence.mckenzie@geemail.com	Pittsburgh	Pennsylvania	3040207302703872	e30d72c0755f8e6454a6707393a17bf7	VISA 16 digit	40.4288277812723038	-80.0556950628463255
5409	2019-11-16 22:47:31	2019-11-16	Jaime Bernhard	jaime.bernhard@geemail.com	San Francisco	California	3465142058316763	c4e8e969a237bf59520dd5f8ba006c66	Maestro	37.7868171804694128	-122.465953272540219
5410	2019-11-16 22:49:13	2019-11-16	Sherrill Bashirian-Mann	sherrill.bashirian.mann@geemail.com	Oakland	California	6011275541746693713	f3a1ad267db881e510d6680bca141032	Discover	37.8220748014617953	-122.251176003148515
5411	2019-11-16 23:18:43	2019-11-16	Terese Hahn	terese.hahn@warmmail.com	Springfield	Missouri	180004403054970746	97ab69eaef27a904526787309170a29f	JCB 16 digit	37.1024947626709931	-93.3892567775502869
5412	2019-11-16 23:36:10	2019-11-16	Octave McCullough	octave.mccullough@woohoo.com	Charlotte	North Carolina	3015157944158545	745404eac6471f46ae639392e6a456c2	JCB 15 digit	35.3050809134982515	-80.8654562869984659
5413	2019-11-17 00:08:51	2019-11-17	Adelle Quitzon	adelle.quitzon@geemail.com	San Francisco	California	3006037270300078	1f55ae88bc96d10c3720eb9e7fb27232	Diners Club / Carte Blanche	37.7627495941803488	-122.422188180510034
5414	2019-11-17 00:38:40	2019-11-17	Wilber McKenzie	wilber.mckenzie@geemail.com	Hialeah	Florida	3528733774895935280	a88883b403f179cedb4b96dcf85e552b	Diners Club / Carte Blanche	25.774672361833602	-80.2882406279813381
5415	2019-11-17 00:39:35	2019-11-17	Christian Weissnat	christian.weissnat@warmmail.com	Los Angeles	California	4621898050591292	69baee7b32f370804188be050a5094e8	VISA 16 digit	34.0168205394741108	-118.329150289808581
5416	2019-11-17 00:56:32	2019-11-17	Miss Lavinia Goodwin	miss.lavinia.goodwin@geemail.com	San Francisco	California	6011462189064258181	ddf5b8f9a8c7f5b037dbf40da783ecf9	Maestro	37.7876807095938574	-122.464118367542227
5417	2019-11-17 01:20:09	2019-11-17	Alcee Bernier	alcee.bernier@geemail.com	San Francisco	California	4122920809742002	19dce1db6eb0759a78c018a4e372ea94	JCB 15 digit	37.770716393901651	-122.395534160750145
5418	2019-11-17 02:53:12	2019-11-17	Javonte Hilll	javonte.hilll@warmmail.com	Virginia Beach	Virginia	3158933864280728560	94e401545c6a88d984a53cc4b94f291b	American Express	36.70156284619123	-76.0270399797379923
5419	2019-11-17 02:53:45	2019-11-17	Iridian Schoen	iridian.schoen@woohoo.com	Berkeley	California	869986401244000151	02f443dab16ae601ffb2ea05c785909d	JCB 16 digit	37.8919926577056785	-122.258066531636601
5420	2019-11-17 03:16:22	2019-11-17	Mr. Carl Bergnaum V	mr.carl.bergnaum.v@warmmail.com	Inglewood	California	3096698433780317970	383a01d97554188810302fd1c679ea80	VISA 16 digit	33.9273010280229173	-118.250085962799574
5421	2019-11-17 03:26:48	2019-11-17	Janelle Flatley DVM	janelle.flatley.dvm@woohoo.com	San Francisco	California	53966959990570110	6112a65f277d51b9154bedf51b85f075	JCB 15 digit	37.767319360075561	-122.432437291634201
5422	2019-11-17 04:02:19	2019-11-17	Ralph McDermott	ralph.mcdermott@warmmail.com	Chesapeake	Virginia	503816620417234	2b7477b40e1a83e2b4dfa1576fa9c49a	VISA 16 digit	36.7519633840076665	-76.376581428743151
5423	2019-11-17 04:09:02	2019-11-17	Dr. Frank Denesik	dr.frank.denesik@geemail.com	Wichita	Kansas	3056964205999825	e7071c86cc51aab91b5fbfd376df85bc	Discover	37.7055253567516786	-97.2838492159467165
5424	2019-11-17 04:13:44	2019-11-17	Mrs. Genoveva D'Amore DDS	mrs.genoveva.d'amore.dds@geemail.com	Houston	Texas	4338364880157	0b6d81fa79780e8b1f2ec6338598c08b	VISA 13 digit	29.8595999883100376	-95.4265850475538571
5425	2019-11-17 05:05:09	2019-11-17	Nilda Sipes-Zulauf	nilda.sipes.zulauf@geemail.com	Oklahoma City	Oklahoma	3528336429288559426	776eebd6bb69dd0629bc93316a10f1c5	VISA 16 digit	35.465622847890856	-97.4394096043322264
5426	2019-11-17 05:05:43	2019-11-17	Miss Osa Walter DVM	miss.osa.walter.dvm@geemail.com	Berkeley	California	3002936239037792	1ff50acb01ca88679065daef47376646	Voyager	37.8754653197298623	-122.294032203407724
5427	2019-11-17 05:15:13	2019-11-17	Arnav Funk	arnav.funk@geemail.com	San Francisco	California	869954206591310873	963664f61102fd7f906d8d3c32886d49	Diners Club / Carte Blanche	37.7731775953809503	-122.426521438659094
5428	2019-11-17 05:17:53	2019-11-17	Oran Langosh	oran.langosh@geemail.com	Phoenix	Arizona	210025262652191112	d616650b9b455815e9f55ee5ed45340f	JCB 15 digit	33.4881659628756339	-112.122587295335165
5429	2019-11-17 06:23:30	2019-11-17	Maritza Reichel	maritza.reichel@geemail.com	San Francisco	California	4292117050415354	e3aad6e9bb3e64dbbb9cd2f3854fd028	Diners Club / Carte Blanche	37.7985961040733613	-122.439247582452296
5430	2019-11-17 06:38:41	2019-11-17	Mr. Adams Spencer MD	mr.adams.spencer.md@geemail.com	Berkeley	California	869932369174679317	0049ae1e1f5866085e984672eb885641	JCB 16 digit	37.8445757588570473	-122.255126886425145
5431	2019-11-17 07:19:48	2019-11-17	Jarred Russel	jarred.russel@geemail.com	Philadelphia	Pennsylvania	3036649559922321	9e79a766e424b03b2411d65002f7cb40	VISA 16 digit	40.0244793738197515	-75.1945850087229246
5432	2019-11-17 07:37:02	2019-11-17	Meggan Leffler	meggan.leffler@geemail.com	Oklahoma City	Oklahoma	180089150169334601	92ae66aec395c2636d7bf2f871e9e37c	American Express	35.520346235614646	-97.4528360206529527
5433	2019-11-17 08:45:07	2019-11-17	Louvenia Kuhn-Swift	louvenia.kuhn.swift@geemail.com	Lancaster	California	6011744296729731021	ad930f8c63eb982a66e4fbd99f5faef8	VISA 16 digit	34.6181160058140804	-118.129899239351218
5434	2019-11-17 10:06:15	2019-11-17	Mrs. Leyla Tremblay PhD	mrs.leyla.tremblay.phd@geemail.com	Chandler	Arizona	3088255799522705168	acbe412cea0801ea0865b8d3b7211c67	VISA 16 digit	33.2442018260803067	-111.910557180678097
5435	2019-11-17 10:25:36	2019-11-17	Mr. Kristin Cummerata II	mr.kristin.cummerata.ii@geemail.com	Norwalk	California	55422053232891035	6b5c06978adb62eeb95d978bf9263633	JCB 16 digit	33.9681512912385202	-118.016432111062116
5436	2019-11-17 10:35:56	2019-11-17	Lavern Botsford	lavern.botsford@geemail.com	Meridian	Idaho	3452435336247437	c7c8167fbd23955d535ba5852ec5e511	JCB 16 digit	43.7058443739552018	-116.383032203040642
5437	2019-11-17 10:45:48	2019-11-17	Jenifer Corwin	jenifer.corwin@geemail.com	Manchester	New Hampshire	4061645839018379	1d006efd62cce16c4a773aba2a20bb56	VISA 16 digit	43.0415438884474355	-71.3981938378311725
5438	2019-11-17 10:57:16	2019-11-17	Jeremie Larson	jeremie.larson@woohoo.com	Berkeley	California	4092252232548	487f876d8143527e22c05d429c710639	JCB 16 digit	37.8471456308826149	-122.311482365633083
5439	2019-11-17 11:00:58	2019-11-17	Brandee Gusikowski	brandee.gusikowski@geemail.com	San Francisco	California	55155474533639076	f7df21fb8f004b133d83ced40d0c7ba3	VISA 13 digit	37.7845988078444748	-122.451318767724629
5440	2019-11-17 11:31:18	2019-11-17	Katheryn Konopelski	katheryn.konopelski@geemail.com	San Francisco	California	3425900631066232	ced6b1217ada95fefbd4aece10c20b74	American Express	37.7906270258438752	-122.425592374749542
5441	2019-11-17 11:42:02	2019-11-17	Xiomara Rosenbaum	xiomara.rosenbaum@woohoo.com	Fort Worth	Texas	3528641378488537775	196cda4302940e03090d45de8a1c42df	Mastercard	32.7380460458397877	-97.3129211996503187
5442	2019-11-17 11:59:00	2019-11-17	Carroll Smitham	carroll.smitham@geemail.com	Rockford	Illinois	4126688200803691	db31a2ac897dbe38b9faa7aee95ff152	JCB 16 digit	42.3087701620079599	-89.0231995865985795
5443	2019-11-17 12:55:12	2019-11-17	Edsel Emmerich II	edsel.emmerich.ii@geemail.com	Kansas City	Missouri	6011016939585721054	7c100672b66206317dc931fd46dd4b9e	JCB 16 digit	39.1793132820934105	-94.5553844903353564
5444	2019-11-17 13:08:21	2019-11-17	Mrs. Elma Mitchell MD	mrs.elma.mitchell.md@geemail.com	San Francisco	California	501841252099738	9aac98a6745a9923a93a08508d47075e	Maestro	37.7955846041456525	-122.404923342392451
5445	2019-11-17 13:34:34	2019-11-17	Jovanni Koch	jovanni.koch@woohoo.com	Laredo	Texas	54181474620198687	aaf6569697087c828293a98f40084f16	VISA 16 digit	27.6419544821321992	-99.4676836037550061
5446	2019-11-17 14:51:23	2019-11-17	Celia Turcotte	celia.turcotte@geemail.com	Omaha	Nebraska	180097424702187804	56f5b41f748c1269c0b4fd298e908d70	Maestro	41.2665822073962545	-96.1428572320494794
5447	2019-11-17 15:57:42	2019-11-17	Ms. Heather Jenkins	ms.heather.jenkins@geemail.com	San Francisco	California	210098406273677049	78ae5e239f37369aedde4102806dea31	Mastercard	37.7962566479966711	-122.404454688158637
5448	2019-11-17 16:15:40	2019-11-17	Ronaldo Botsford	ronaldo.botsford@warmmail.com	Minneapolis	Minnesota	53259687287412748	a811356e38fa43ed69ec2e91d1ccc49a	VISA 16 digit	44.9338264525488	-93.2734540427841239
5449	2019-11-17 17:25:08	2019-11-17	Mrs. Aylin Willms PhD	mrs.aylin.willms.phd@woohoo.com	San Francisco	California	676266604462037	7a38559a557172cf60d6a556e5866eac	VISA 13 digit	37.7814494291489211	-122.438585107940128
5450	2019-11-17 17:38:48	2019-11-17	Mr. Agustin Stanton	mr.agustin.stanton@geemail.com	Durham	North Carolina	180044527761953595	89f74e10470d36f3a47abc93f012fbe3	Voyager	35.8844240833785335	-78.9186845534384247
5451	2019-11-17 18:31:56	2019-11-17	Calvin Renner	calvin.renner@geemail.com	New York	New York	869903678310564075	a04b077e61483f0cec7f2eb6a9201b03	JCB 16 digit	40.7415459390487484	-73.9166242611490105
5452	2019-11-17 18:34:04	2019-11-17	Mrs. Vernelle Turner MD	mrs.vernelle.turner.md@geemail.com	San Francisco	California	4061646798703803	013301546028a6e0191a66196f01594a	Discover	37.7762445659303552	-122.476061512451111
5453	2019-11-17 18:36:16	2019-11-17	Primus McGlynn	primus.mcglynn@woohoo.com	Sterling Heights	Michigan	4983680078141	8160d6716edb88356ae4f01a984e2ba0	Maestro	42.6379427658475976	-83.0484145680136976
5454	2019-11-17 18:40:02	2019-11-17	Mrs. Esmeralda Heidenreich	mrs.esmeralda.heidenreich@geemail.com	Dallas	Texas	3451112352111125	ead88b176716918fcacc165842fa18ff	JCB 16 digit	32.7363359747260816	-96.7471588310748274
5455	2019-11-17 18:48:31	2019-11-17	Boss Macejkovic-Blick	boss.macejkovic.blick@woohoo.com	Moreno Valley	California	4179056565064	b44497bd6dac7769c3568bdcf800ef0b	JCB 15 digit	33.8943545693989847	-117.222392594625049
5456	2019-11-17 18:49:29	2019-11-17	Ovid Krajcik	ovid.krajcik@geemail.com	Washington	District of Columbia	180064703461770051	2f93cee55e273abbbda44063ea953c9b	JCB 15 digit	38.8209896103277785	-77.0422823949929381
5457	2019-11-17 19:26:23	2019-11-17	Mr. Darion Hand	mr.darion.hand@woohoo.com	San Francisco	California	4174795113235	8ac7d43de2bc0aa5ff7fe145fd273414	Diners Club / Carte Blanche	37.7703138681075927	-122.450559821890991
5458	2019-11-17 19:37:55	2019-11-17	Kameron Davis	kameron.davis@geemail.com	San Francisco	California	3528673446168677459	8f2b260d468468a3f81922428c7aca74	American Express	37.7632982537970463	-122.457757009610674
5459	2019-11-17 19:39:24	2019-11-17	Ms. Genesis Hand	ms.genesis.hand@warmmail.com	Portland	Oregon	3415710338624924	8582d057239c0d2b2e678fc7aa1ecb4b	Voyager	45.4448736911993478	-122.738095416035506
5460	2019-11-17 19:43:56	2019-11-17	Cass Torphy	cass.torphy@geemail.com	San Francisco	California	55688674689410232	604ca562e176e9d21aec26a03a9c6e3d	JCB 15 digit	37.7841981656388981	-122.394902489865032
5461	2019-11-17 19:48:52	2019-11-17	Ms. Jadyn Luettgen DDS	ms.jadyn.luettgen.dds@geemail.com	Oakland	California	3048284283162297	0ad0d9db97fcc2e5caa8d59945718189	Diners Club / Carte Blanche	37.8042267625114974	-122.272328944925775
5462	2019-11-17 19:58:51	2019-11-17	Dr. Thora Cummings	dr.thora.cummings@geemail.com	Stamford	Connecticut	4305257163052572	37224811aadc0af7315456fca427841b	Diners Club / Carte Blanche	41.0838247210603242	-73.477034271093089
5463	2019-11-17 20:33:52	2019-11-17	Miss Hattie Lehner DVM	miss.hattie.lehner.dvm@geemail.com	Denver	Colorado	6011876893261304462	14b4236d70f33ab1285a1acc45f51a45	Maestro	39.8564138946641222	-104.957796498552341
5464	2019-11-17 22:55:24	2019-11-17	Redmond Bartell	redmond.bartell@geemail.com	Detroit	Michigan	3037979930067184	99e016ccc6b659539a93127e0d10fd70	VISA 16 digit	42.435846636530016	-83.1308205099429927
5465	2019-11-17 22:55:56	2019-11-17	Beverlee Sanford DDS	beverlee.sanford.dds@geemail.com	San Francisco	California	4512569877476106	409db93d399cf30d070745ffe44112f7	Voyager	37.7573624413453359	-122.454974556264204
5466	2019-11-18 00:27:20	2019-11-18	Jerald Cummerata	jerald.cummerata@geemail.com	San Francisco	California	869977386379031876	25c72c7e5aeef4b5b90ac1672dde011c	Voyager	37.8172112527124469	-122.432101776831644
5467	2019-11-18 01:22:44	2019-11-18	Makai Lesch	makai.lesch@geemail.com	Houston	Texas	3013433489283473	9a8a1f8ff9aaac2c0dfef27106a0a070	American Express	29.7885809314049794	-95.4353803559687037
5468	2019-11-18 01:37:30	2019-11-18	Vessie Dooley	vessie.dooley@geemail.com	Miami Gardens	Florida	3032317271309219	2b72c644210a352e74f634ebd394683d	Maestro	25.9181766802851108	-80.2615512364789794
5469	2019-11-18 01:41:58	2019-11-18	Ms. Salma McClure DVM	ms.salma.mcclure.dvm@geemail.com	Winston–Salem	North Carolina	3714511655554525	5d52bae7a8a58cafd32a89546d9a83ad	American Express	36.1632337985791281	-80.1833810035735297
5470	2019-11-18 02:58:13	2019-11-18	Osborn Kiehn	osborn.kiehn@geemail.com	Elizabeth	New Jersey	3017156855205434	d62b2887694307811472f490b8f4fcbe	JCB 16 digit	40.6647943498227775	-74.2111799958106104
5471	2019-11-18 03:09:12	2019-11-18	Joselyn Sipes	joselyn.sipes@geemail.com	San Francisco	California	060490688849349	28c5dcb3490fc89d14302c68f36b477a	Mastercard	37.7142074399821396	-122.433947597177891
5472	2019-11-18 03:33:36	2019-11-18	Dr. Clemence Koch Jr.	dr.clemence.koch.jr.@warmmail.com	New York	New York	53700905330407449	91bfcc45b37356bc9286d5ca1ae9fd18	Voyager	40.6059156800843795	-73.9412358389131725
5473	2019-11-18 05:48:06	2019-11-18	Mrs. Bertie Dietrich	mrs.bertie.dietrich@woohoo.com	San Francisco	California	210005086495069852	25f6b7b75b7e05fa2524a05bb5c2bc04	Voyager	37.7817653645070308	-122.430224377659712
5474	2019-11-18 06:13:37	2019-11-18	Dr. Wong Zieme Jr.	dr.wong.zieme.jr.@woohoo.com	San Francisco	California	6011002050027024242	d13827c8348cef9e6ae1b82f52d0693c	American Express	37.7572227120006616	-122.415676954123484
5475	2019-11-18 06:58:42	2019-11-18	Millard Schuppe	millard.schuppe@geemail.com	New York	New York	3028903389752764	c57b00cf418c8757a3e2a2a7aefa51b3	JCB 16 digit	40.726597798824308	-74.0281543856848003
5476	2019-11-18 07:10:24	2019-11-18	Dr. Alvera Johns MD	dr.alvera.johns.md@woohoo.com	Philadelphia	Pennsylvania	51767633327804325	4ca89291b4b28702f382b39838dea815	Discover	39.9667004227597289	-75.1158576665345663
5477	2019-11-18 07:32:18	2019-11-18	Rustin Schaefer	rustin.schaefer@woohoo.com	Fort Wayne	Indiana	3158327340458088966	fc68fc17fdfc911b5e0ce8b80efa2920	Maestro	41.1390390340954042	-85.2079072232577914
5478	2019-11-18 08:51:26	2019-11-18	Birdie Lockman DVM	birdie.lockman.dvm@geemail.com	San Francisco	California	4883074748275275	c963e8b50365586095b38ef84802f74b	American Express	37.7849145823047508	-122.475213145193138
5479	2019-11-18 09:11:29	2019-11-18	Mrs. Abby Ferry DVM	mrs.abby.ferry.dvm@woohoo.com	Salem	Oregon	4955860735112	ba51d92b6942eb2528e6663511fec37e	JCB 15 digit	44.9456632118008983	-123.066768682251507
5480	2019-11-18 09:41:39	2019-11-18	Zeb Crist	zeb.crist@geemail.com	Rochester	Minnesota	4091134753746814	7d003e461641f74c84bffbc0008ae403	JCB 15 digit	44.1107406447544719	-92.4442540085993727
5481	2019-11-18 10:56:20	2019-11-18	Malia Ruecker DVM	malia.ruecker.dvm@geemail.com	San Jose	California	6011874023994770548	afcbe4a36e86de78752802c4880490bb	Discover	37.3301797064773737	-121.790535846421122
5482	2019-11-18 11:24:45	2019-11-18	Susannah Huel	susannah.huel@geemail.com	Oceanside	California	869931381013555799	e0b22f49f6a89ebbe2c0829ec81eeeeb	VISA 16 digit	33.2858496251869909	-117.292757248560719
5483	2019-11-18 12:00:41	2019-11-18	Dorinda Lebsack	dorinda.lebsack@geemail.com	San Francisco	California	6011268962364526655	d428dab12f90c3b62116895aa210ab40	Diners Club / Carte Blanche	37.7966229140353889	-122.434274327823701
5484	2019-11-18 12:05:25	2019-11-18	Benjman Schaden	benjman.schaden@geemail.com	Los Angeles	California	3337417173430051575	7b99f45028d6320c20253a501b0177c6	Discover	34.0065112929657047	-118.47300868122764
5485	2019-11-18 12:47:09	2019-11-18	Ms. Zilpah Schuppe	ms.zilpah.schuppe@geemail.com	Wichita	Kansas	3035686521713348	68a572605ccb7f90a4e43d6ac240a3ba	VISA 16 digit	37.7867133787244569	-97.3345350907385409
5486	2019-11-18 13:06:36	2019-11-18	Lucy Nienow	lucy.nienow@geemail.com	New York	New York	676268094499347	db93dd21c7d3125dfdbba2d74781d1b2	Maestro	40.7357436067648209	-73.9515653164487361
5487	2019-11-18 13:16:31	2019-11-18	Georgette Marquardt	georgette.marquardt@warmmail.com	Jackson	Mississippi	501821580229496	22e6d11f0c053603c75c143a6bf17be0	JCB 15 digit	32.384563836240396	-90.1589962029803615
5488	2019-11-18 13:57:45	2019-11-18	Issac Lynch Jr.	issac.lynch.jr.@geemail.com	New York	New York	3442642060608790	1df0e817f4b73297e41595f18a85d081	Mastercard	40.6304946605339623	-73.8994734493445549
5489	2019-11-18 14:11:04	2019-11-18	Yusuf Olson DDS	yusuf.olson.dds@warmmail.com	Augusta	Georgia	6011957981396232799	9617d2bc7af24dcf33c9bb2e6947c6a1	Mastercard	33.462856989467511	-82.0353841150473926
5490	2019-11-18 14:52:35	2019-11-18	Spurgeon D'Amore	spurgeon.d'amore@geemail.com	Los Angeles	California	4821985613625713	94b22610791737d3ec6f347a1e4b591c	American Express	33.9877710158336868	-118.404898442327223
5491	2019-11-18 15:00:46	2019-11-18	Erving Grant	erving.grant@geemail.com	Berkeley	California	3088496475768319308	c430f978655a502f169e06f4528e96c5	VISA 16 digit	37.8762008057274002	-122.281023929860652
5492	2019-11-18 15:29:24	2019-11-18	Dyllan Ortiz	dyllan.ortiz@woohoo.com	Des Moines	Iowa	3486479655820143	10ee8da02eda3f6355f06a3dc747dd5f	JCB 16 digit	41.5412048532836167	-93.6126352817796175
5493	2019-11-18 16:18:26	2019-11-18	Leatrice Funk	leatrice.funk@warmmail.com	New York	New York	6011537848362807350	f00d9c18b7745962ae1d85abc3f5002c	Maestro	40.6252400647606677	-73.916786937684563
5494	2019-11-18 16:20:45	2019-11-18	Carleton Williamson	carleton.williamson@geemail.com	Los Angeles	California	3451378649423827	44e81c4a7b65f2cceee8d9e76f88ead7	VISA 16 digit	34.1024965177156005	-118.431943736923103
5495	2019-11-18 16:22:41	2019-11-18	Mario Bins V	mario.bins.v@warmmail.com	San Francisco	California	3432815702940738	da38994c452363c343c9dc1286937cc0	VISA 16 digit	37.7404527758942265	-122.409415664882317
5496	2019-11-18 16:36:43	2019-11-18	Mr. Mathews Torp MD	mr.mathews.torp.md@warmmail.com	Las Vegas	Nevada	3019296406023775	5fb2b5e284d57444044d1928ea600480	Maestro	36.1545031784202919	-115.280668430004638
5497	2019-11-18 16:59:09	2019-11-18	Mal Johnson PhD	mal.johnson.phd@woohoo.com	Long Beach	California	4914359779231575	d2ad947acce3a71cdcfd2e9f3968e61e	Discover	33.9058209074947925	-118.221073779992011
5498	2019-11-18 17:22:27	2019-11-18	Areli Hermann	areli.hermann@geemail.com	Berkeley	California	180040267893040896	83b29b0986ddcb3cd9306d47335157ba	JCB 15 digit	37.8396658244743662	-122.256956876104411
5499	2019-11-18 18:04:57	2019-11-18	Ms. Marinda Kihn MD	ms.marinda.kihn.md@warmmail.com	Berkeley	California	52565393825835396	4ab5a1b3e754b23a91e1aa533a76dc96	VISA 13 digit	37.838828097033641	-122.250853541222909
5500	2019-11-18 18:36:44	2019-11-18	Devante Morissette	devante.morissette@geemail.com	Tallahassee	Florida	4500363834499573	d17fababa4d6efecb8590ad1c935f21f	VISA 16 digit	30.3751892481952908	-84.227448108281564
5501	2019-11-18 19:21:18	2019-11-18	Maryann Johnston	maryann.johnston@geemail.com	Berkeley	California	4140337006266305	b897678ef41abc2a1045d779a76f8f2a	VISA 16 digit	37.8645363464081441	-122.259676063071581
5502	2019-11-18 19:24:34	2019-11-18	Lilyanna Heidenreich	lilyanna.heidenreich@woohoo.com	Cincinnati	Ohio	55518043940758548	b24890df4fa4dd0d494334c6720aa95e	VISA 13 digit	39.1220956856150153	-84.5792662790782686
5503	2019-11-18 20:18:57	2019-11-18	Roxie Boyer MD	roxie.boyer.md@geemail.com	San Francisco	California	3096145705471030775	2fcf8f8737b7f292db87813b6da55452	American Express	37.7679528013301322	-122.432481138953094
5504	2019-11-18 22:14:37	2019-11-18	Harvey Weissnat III	harvey.weissnat.iii@woohoo.com	Dayton	Ohio	676194503972997	cba8d70184b43c2fe6a83fee914d3da7	Diners Club / Carte Blanche	39.7687089009467485	-84.2103080204878012
5505	2019-11-18 22:25:06	2019-11-18	Rozanne Pagac-Bosco	rozanne.pagac.bosco@geemail.com	New York	New York	180039816474361619	472ea9414a650537b0ba88b87d9932ef	JCB 16 digit	40.6149083411078919	-73.9378818676237017
5506	2019-11-18 22:28:05	2019-11-18	Baker Schmitt-Schaden	baker.schmitt.schaden@geemail.com	Oakland	California	4698163141582679	e14a0fa6a4a25fec2e55a4e5876c7ae0	JCB 16 digit	37.8455486130083543	-122.284647237946103
5507	2019-11-18 23:11:13	2019-11-18	Byrd Feeney	byrd.feeney@geemail.com	San Francisco	California	53961401564946108	ed27d59bf92406f44eddd8500d0dbdfc	Mastercard	37.7758586841373827	-122.422028347820174
5508	2019-11-18 23:34:39	2019-11-18	Brennon Berge	brennon.berge@geemail.com	San Francisco	California	6011823820601177286	8e683536b329d5bcebf2b62d7fb8ec12	VISA 16 digit	37.7828614392114375	-122.4368398663416
5509	2019-11-19 00:19:36	2019-11-19	Mrs. Veta Oberbrunner DVM	mrs.veta.oberbrunner.dvm@geemail.com	Elk Grove	California	6011419161458050221	f3d8c7bd939ce69098cd7495fa537eb8	JCB 16 digit	38.3822430759485798	-121.386965206768366
5510	2019-11-19 01:02:48	2019-11-19	Weston Mosciski IV	weston.mosciski.iv@warmmail.com	High Point	North Carolina	3158840075565903537	3937594ab8400b9880f4f3e1a2d70052	VISA 13 digit	36.0082407151442041	-80.0031061631832188
5511	2019-11-19 01:42:15	2019-11-19	David Schinner	david.schinner@warmmail.com	Oceanside	California	53752489069645575	b6a427aba22a68527ed25f9e68b43983	American Express	33.3209254719670867	-117.321331508605553
5512	2019-11-19 01:55:03	2019-11-19	Cornie Mitchell	cornie.mitchell@geemail.com	Phoenix	Arizona	3158195341157320717	f59119ce380873ea0eda4cae6aa5ea8b	JCB 16 digit	33.5813188503895006	-112.147893317781765
5513	2019-11-19 02:01:29	2019-11-19	Mr. Olen Reynolds Jr.	mr.olen.reynolds.jr.@woohoo.com	Los Angeles	California	4381638608054827	3a0d6d731d76c3aba68f2473570f05f0	VISA 13 digit	33.9804141743440127	-118.453581827598811
5514	2019-11-19 03:31:49	2019-11-19	Mariano Murphy	mariano.murphy@warmmail.com	Berkeley	California	3088910959159979349	7628055998c4c4f9c4ce6301292704ba	Voyager	37.8716463173780653	-122.248504523420934
5515	2019-11-19 03:45:45	2019-11-19	Berlin Barrows	berlin.barrows@warmmail.com	Richmond	Virginia	3088761321658236095	af1816fed3b4ba039977e928d78d0939	VISA 16 digit	37.4734360830146827	-77.3782240670863501
5516	2019-11-19 04:41:12	2019-11-19	Tilda Bashirian	tilda.bashirian@geemail.com	Berkeley	California	55556967958696823	e9c29c731f85193a9f70f0328bddb37a	JCB 16 digit	37.8827866167090477	-122.244857781701924
5517	2019-11-19 05:44:59	2019-11-19	Hanson Witting	hanson.witting@geemail.com	San Francisco	California	4594808338661	af78f4c0c0f7715f3ff996d4c3fe1a4a	JCB 16 digit	37.7556853291972985	-122.459676032367327
5518	2019-11-19 06:15:57	2019-11-19	Ms. Paityn Brakus DDS	ms.paityn.brakus.dds@warmmail.com	Los Angeles	California	4915484512412	5823696ec13daf4be401c13cf4a260fb	Discover	33.9659443333610866	-118.490587964047862
5519	2019-11-19 06:28:01	2019-11-19	Demarcus Corwin	demarcus.corwin@geemail.com	Berkeley	California	210058998170408542	bb964e94a2e48c2c4e5e3fd18ef97662	VISA 13 digit	37.8910772021276046	-122.263197954780054
5520	2019-11-19 06:55:48	2019-11-19	Domenick Crist-Gulgowski	domenick.crist.gulgowski@geemail.com	San Francisco	California	3735533563071264	2adae61f8391c870d9a577e99e8f7f74	Discover	37.7675136300723224	-122.429885448756565
5521	2019-11-19 06:56:35	2019-11-19	Sie Herman	sie.herman@warmmail.com	Austin	Texas	6011884977674980966	9b9e8864ca1625aacd1f78a163adb2a1	Maestro	30.2304167174860829	-97.7637232100363889
5522	2019-11-19 07:12:30	2019-11-19	Prince O'Reilly	prince.o'reilly@geemail.com	New York	New York	3096275493135488752	2ae6c54389b3763918cc4dfa2671a790	VISA 13 digit	40.6363176236618315	-73.8815638262674241
5523	2019-11-19 07:12:40	2019-11-19	Otha Herzog	otha.herzog@geemail.com	Irving	Texas	3035268351485642	e5cbe6088fa7575aec736bcb3a5255b4	JCB 15 digit	32.7905007958363726	-96.9438213490229117
5524	2019-11-19 08:40:04	2019-11-19	Myles Mueller Jr.	myles.mueller.jr.@geemail.com	New York	New York	3528272059933067289	0430c2e38a38c4d351b074df64e09e76	JCB 16 digit	40.5762705486025652	-73.865139330074939
5525	2019-11-19 09:30:54	2019-11-19	Phylis Morar-Gerlach	phylis.morar.gerlach@geemail.com	Philadelphia	Pennsylvania	4756206163579559	f70514b5a87165f927930ded19d73209	JCB 16 digit	40.0789310781244197	-75.1336134542610523
5526	2019-11-19 09:37:20	2019-11-19	Trudy Johnson	trudy.johnson@geemail.com	San Francisco	California	630418130998166	0e8ccfd25e02c8687f1433ca33e4ec0c	VISA 16 digit	37.755373198300255	-122.426430866816389
5527	2019-11-19 09:51:41	2019-11-19	Felipe Mosciski	felipe.mosciski@geemail.com	San Antonio	Texas	676231408174543	dbc6a252234b966cdd53977e5e5b49bf	JCB 15 digit	29.4819240766648214	-98.578837156419084
5528	2019-11-19 10:06:04	2019-11-19	Sheryl Powlowski	sheryl.powlowski@woohoo.com	San Francisco	California	3158020654999712052	bcb6a502d17e0cc3771797c3ff60f3b2	Voyager	37.7571320669366415	-122.454593091739625
5529	2019-11-19 10:36:14	2019-11-19	Zander Watsica	zander.watsica@woohoo.com	New York	New York	4637446580225585	d3eda97f1c53e39ec71f509de8bff0b3	American Express	40.5636351748593142	-73.9294314929179848
5530	2019-11-19 10:49:01	2019-11-19	Angie Stiedemann-Wisoky	angie.stiedemann.wisoky@geemail.com	San Francisco	California	180009364019884627	82119c9b508c6067f6bfc54579552321	Maestro	37.7445596574225206	-122.440695715513712
5531	2019-11-19 10:51:12	2019-11-19	Blair Bechtelar	blair.bechtelar@geemail.com	Round Rock	Texas	210051164208717290	afd8eb42a1acb442ffce97b209744889	Diners Club / Carte Blanche	30.4763179602704959	-97.6802425354104429
5532	2019-11-19 11:03:38	2019-11-19	Ainsley Hackett	ainsley.hackett@geemail.com	Fresno	California	3057906319673548	cea91b636631623ea4435ceabe854fb3	Diners Club / Carte Blanche	36.7055411066267609	-119.702177695987373
5533	2019-11-19 11:31:58	2019-11-19	Elmira Powlowski PhD	elmira.powlowski.phd@geemail.com	Chicago	Illinois	3053814254171557	cf28ece67681170f907cbe259fd1356e	Diners Club / Carte Blanche	41.768847493904083	-87.7171907363954944
5534	2019-11-19 11:59:03	2019-11-19	Berneice D'Amore	berneice.d'amore@geemail.com	San Francisco	California	6011685268232587944	d180032012f440b49f4457b4e6c4a658	VISA 16 digit	37.7614497994780223	-122.45337167365372
5535	2019-11-19 12:24:31	2019-11-19	Cristofer Stoltenberg	cristofer.stoltenberg@geemail.com	Norfolk	Virginia	3014657169799114	9a4745f9c2ae2805c17cae5df0eafa65	Maestro	36.8795862718969616	-76.2664102827668273
5536	2019-11-19 12:49:46	2019-11-19	Jeffery Parisian	jeffery.parisian@geemail.com	San Francisco	California	3337153223517525245	9e8f7243f56326eeb0c9c49980e72f3c	JCB 15 digit	37.7715863120667663	-122.423855334608405
5537	2019-11-19 12:57:32	2019-11-19	Maye Smitham	maye.smitham@warmmail.com	Las Cruces	New Mexico	6011979251238045856	25272e7ef573202ee462a4d9599b31f6	JCB 15 digit	32.2949691407415997	-106.778132312244551
5538	2019-11-19 14:42:45	2019-11-19	Kenji Pollich-Walsh	kenji.pollich.walsh@geemail.com	Oakland	California	210040223178106423	e34fbc1655b97d534c24354d99b2032a	JCB 15 digit	37.7733694041848693	-122.2830982901081
5539	2019-11-19 15:20:03	2019-11-19	Dr. Vanesa Abshire DDS	dr.vanesa.abshire.dds@geemail.com	San Francisco	California	210052433826336026	3474fbffc4edc0ffb7ee5873a6ad10ea	VISA 13 digit	37.8053360770427105	-122.406569803990365
5540	2019-11-19 15:23:58	2019-11-19	Jarad Emard	jarad.emard@woohoo.com	Omaha	Nebraska	4771329874479	857efdda5a3a4c5fe5c495fdef1c5a69	Diners Club / Carte Blanche	41.226609206167609	-96.1068099629715107
5541	2019-11-19 15:48:13	2019-11-19	Dr. Anfernee Torphy IV	dr.anfernee.torphy.iv@geemail.com	Corona	California	3112038787160681654	414076bb708be76dae995580de6c9517	Voyager	33.8063395220674607	-117.476874175921083
5542	2019-11-19 16:06:12	2019-11-19	Bilal Skiles	bilal.skiles@geemail.com	Los Angeles	California	4339588281446	897f405ec4bba7509b30ec1226c7e862	Diners Club / Carte Blanche	34.0640878422982993	-118.345529709988455
5543	2019-11-19 16:22:21	2019-11-19	Mirna Kiehn DDS	mirna.kiehn.dds@geemail.com	San Francisco	California	3004504860124111	4ffabda2e0e586fc79a55a16563217b4	Mastercard	37.7613052424937408	-122.419738872681435
5544	2019-11-19 16:30:09	2019-11-19	Mr. Deshawn Schmidt II	mr.deshawn.schmidt.ii@geemail.com	San Francisco	California	180061388924410405	85e788d6456cacdbad67a4888217d36d	JCB 16 digit	37.7520379719913137	-122.415216381995933
5545	2019-11-19 16:49:25	2019-11-19	Jenifer Kub-Mraz	jenifer.kub.mraz@geemail.com	Arlington	Texas	55957385099761437	e1760358b2a7a3b82aa729c837d08a31	American Express	32.7583451838016515	-97.0456102876950126
5546	2019-11-19 17:07:15	2019-11-19	Mr. Jair Flatley	mr.jair.flatley@geemail.com	Syracuse	New York	52818072454606824	830f70b6b6c9aeb1594b79c70a1dc23d	Voyager	43.1392766678091135	-76.0642398318056081
5547	2019-11-19 19:01:56	2019-11-19	Benedict Mraz	benedict.mraz@geemail.com	Detroit	Michigan	210078155986730678	f0d7528e56d156429ff784604d4784e9	JCB 16 digit	42.3287163050305111	-83.0389526356596406
5548	2019-11-19 19:32:37	2019-11-19	Lum Hilll III	lum.hilll.iii@geemail.com	San Francisco	California	503827084745200	91a39da1308c55e21534be94bfa8cb11	VISA 13 digit	37.7860737483635418	-122.402975177390175
5549	2019-11-19 19:47:58	2019-11-19	Viola Padberg	viola.padberg@woohoo.com	Austin	Texas	3158384736315930094	e56794419f425e7086cb36468ba6adad	American Express	30.2393888044763344	-97.661533154757322
5550	2019-11-19 19:57:10	2019-11-19	Raymond Raynor	raymond.raynor@geemail.com	New Orleans	Louisiana	6011566589528969486	6991b1a9c7c8bc42a62a9d12b574b00e	Mastercard	29.9690521714758127	-89.911540332229805
5551	2019-11-19 20:06:24	2019-11-19	Mrs. Lilyan Crona	mrs.lilyan.crona@geemail.com	San Francisco	California	3112743911183816826	d761b4aefe6773a2befd279399fd5322	Voyager	37.7782457896366637	-122.416010443120229
5552	2019-11-19 20:08:21	2019-11-19	Alcie Mills	alcie.mills@geemail.com	Colorado Springs	Colorado	3112266741672201967	75afe9ee2c06f0c2c2c8b686511ededc	Mastercard	38.8523803165696577	-104.791011924777919
5553	2019-11-19 21:11:58	2019-11-19	Mr. Melvin Kreiger	mr.melvin.kreiger@geemail.com	San Francisco	California	52018645104615481	10697c4f9ccd0a9f7310eabf6e6232a9	Discover	37.7694700801237673	-122.457104173513528
5554	2019-11-19 21:43:51	2019-11-19	Chet Rolfson	chet.rolfson@geemail.com	San Antonio	Texas	4023713961122539	60cc675b7cd505fe9d81b2df69f40c7e	VISA 16 digit	29.4652216008003798	-98.5481619051028019
5555	2019-11-19 21:51:55	2019-11-19	Casper Wiza	casper.wiza@geemail.com	San Francisco	California	561296270528779	d5d4077d301e47a78e73573e01c26e2b	VISA 16 digit	37.7810225102392465	-122.390208888140307
5556	2019-11-19 21:59:04	2019-11-19	Ms. Orra Johnson	ms.orra.johnson@woohoo.com	Washington	District of Columbia	4458982725297457	3f2c3f1732095dc6196c0b84176086e3	Voyager	38.8749376923110361	-76.9304625765167174
5557	2019-11-20 00:07:48	2019-11-20	Griffith Kozey	griffith.kozey@geemail.com	Berkeley	California	55201051429505209	dbe65029de20dd542e047b663f40286f	VISA 16 digit	37.9036551650756053	-122.285054383956137
5558	2019-11-20 00:13:40	2019-11-20	Zeb Hane	zeb.hane@geemail.com	Huntsville	Alabama	676282262847104	d2753eb355a76d09230df96b129c055a	VISA 16 digit	34.7678409266062047	-86.6874918598700361
5559	2019-11-20 00:41:44	2019-11-20	Chaney Grady	chaney.grady@geemail.com	Berkeley	California	4431614813720	0d7042b08c1a2d63b3ed68f656787375	Maestro	37.8629618611969221	-122.269098018657075
5560	2019-11-20 00:59:29	2019-11-20	Sharon Hills	sharon.hills@geemail.com	Berkeley	California	4050226446106833	f6821eac634e4a689f4ebe08ea4e623e	JCB 16 digit	37.8808427478541603	-122.276726572858081
5561	2019-11-20 01:18:53	2019-11-20	Estefania Gorczany-Abernathy	estefania.gorczany.abernathy@geemail.com	Gilbert	Arizona	3528327344676346784	4c1098ef893bc164b1cc6a988ea48ef2	JCB 16 digit	33.3626647832684213	-111.677887975531064
5562	2019-11-20 01:37:52	2019-11-20	Tandy Koss	tandy.koss@geemail.com	Sacramento	California	4316802397362029	3f70fba5ff1e0f70ae8ed9fb8218dbfd	Maestro	38.6166449677929293	-121.469514913648737
5563	2019-11-20 01:50:36	2019-11-20	Latricia Langworth-VonRueden	latricia.langworth.vonrueden@geemail.com	Berkeley	California	3088931101943209973	c47fafce657a7189a5c66343d06619be	Discover	37.8817357556742778	-122.256232267146387
5564	2019-11-20 02:06:40	2019-11-20	Jaydan Kuphal	jaydan.kuphal@woohoo.com	Victorville	California	869963240966299857	770d6b72cd70e4142c30bb744105cbc4	VISA 16 digit	34.6096065910764068	-117.405472785761958
5565	2019-11-20 02:35:11	2019-11-20	Dr. Earle Christiansen	dr.earle.christiansen@geemail.com	Nashville	Tennessee	3528686264407324741	601bf27de3586ae60276c10aafc8664b	Discover	36.161289927934483	-86.7180574707128073
5566	2019-11-20 03:25:12	2019-11-20	Blair Reinger	blair.reinger@geemail.com	San Francisco	California	4746696369865559	68d263f273eba92e00ac4699ce6bed88	Voyager	37.7823857729840498	-122.414485337248749
5567	2019-11-20 04:27:41	2019-11-20	Elick Stamm-Hegmann	elick.stamm.hegmann@woohoo.com	Huntsville	Alabama	869977604452787358	39bd63af3858f2ff581c3d5931b52e9d	JCB 16 digit	34.621264223778617	-86.5904100920558051
5568	2019-11-20 04:57:45	2019-11-20	Johana Mayert	johana.mayert@geemail.com	San Jose	California	676240006681833	82d6550cbd9ab2a85de19f8323bc382e	VISA 13 digit	37.2362701121073201	-121.883941866991663
5569	2019-11-20 05:02:55	2019-11-20	Shannen Cremin	shannen.cremin@geemail.com	Albuquerque	New Mexico	3096845472130977077	dcef2fb57c779af7b3a8d5a0be66f9b1	Voyager	35.0733703660912823	-106.652032883938034
5570	2019-11-20 05:37:18	2019-11-20	Mr. Marshal Beatty	mr.marshal.beatty@geemail.com	El Paso	Texas	3528439034951954064	b93d81ff028460e7565eec4dee5d5bee	JCB 16 digit	31.8164328433401913	-106.494148619424564
5571	2019-11-20 05:55:00	2019-11-20	Mr. Boone Leannon	mr.boone.leannon@warmmail.com	Jacksonville	Florida	4643656694898638	9240e1a74c3c1239013570c56d03adcc	JCB 15 digit	30.3530668062675737	-81.641870650796605
5572	2019-11-20 06:50:10	2019-11-20	Shedrick Kiehn-Yost	shedrick.kiehn.yost@geemail.com	Warren	Michigan	869945576693938058	0a5e6377ae00a60bdd97ed25b3fd855f	JCB 16 digit	42.5727877631779776	-82.9605251276399969
5573	2019-11-20 07:40:26	2019-11-20	Steward Kshlerin	steward.kshlerin@geemail.com	Clarksville	Tennessee	4279709621543412	a47408e131cebcb0c721c3a4b6c8ddb2	VISA 16 digit	36.6477918626401618	-87.3866239075034912
5574	2019-11-20 07:47:07	2019-11-20	Besse Dare	besse.dare@geemail.com	Elizabeth	New Jersey	869963823555446557	efd642a08b697e781ce2a4247a0d6cd0	American Express	40.7306917842604221	-74.2615612871423423
5575	2019-11-20 07:54:59	2019-11-20	Felipe McGlynn	felipe.mcglynn@woohoo.com	McKinney	Texas	53996473161383331	d7757622adeeb2272d4134bc45caba01	VISA 13 digit	33.2621351872701254	-96.6050660293381753
5576	2019-11-20 08:17:48	2019-11-20	Ms. Dena Wilkinson	ms.dena.wilkinson@geemail.com	Tampa	Florida	869962574939904719	ddbbdc4e557f2b8d3a21e6fd7d319093	VISA 16 digit	28.0631109784472734	-82.3901577440768449
5577	2019-11-20 09:06:11	2019-11-20	Jean Schuster	jean.schuster@geemail.com	Berkeley	California	4036590120909021	8a7001764868c97a770bff3a66bc6cae	Maestro	37.8540182772964116	-122.272292626440574
5578	2019-11-20 09:36:37	2019-11-20	Jaylyn Pacocha	jaylyn.pacocha@geemail.com	Midland	Texas	52905723571849465	35f0a25766286ada701c0d40d9826c28	VISA 13 digit	32.0651584429390724	-102.085707558387895
5579	2019-11-20 09:47:27	2019-11-20	Dr. Dakotah Halvorson	dr.dakotah.halvorson@geemail.com	Detroit	Michigan	4847864865574905	8ff8bf4f9be2427c373674409e0ecefd	Voyager	42.440762355962768	-83.1348630726922266
5580	2019-11-20 10:43:14	2019-11-20	Stanley Corwin DDS	stanley.corwin.dds@geemail.com	Fayetteville	North Carolina	3054488626316205	9acb94af7619a21ead12d91edf8217cd	VISA 13 digit	35.1682916219133901	-78.9623953309040587
5581	2019-11-20 11:16:19	2019-11-20	Dr. Kanesha Toy	dr.kanesha.toy@geemail.com	San Francisco	California	675903441217795	9ba173d3cec8563fc6140efd331ec9d5	Voyager	37.7819143929204486	-122.451829383432823
5582	2019-11-20 11:29:51	2019-11-20	Dr. Shelby Parker MD	dr.shelby.parker.md@geemail.com	Dallas	Texas	4291097654094	f7936c1a8085e2b65f16dc969d4d045e	Maestro	32.697784568582847	-96.8200620145965303
5583	2019-11-20 12:03:35	2019-11-20	Andrea Muller	andrea.muller@geemail.com	Miami	Florida	3158648970732915782	00538c7fb9750c63ca1b971b9ab7a7c3	Maestro	25.7833488106399784	-80.2246730259493006
5584	2019-11-20 12:08:49	2019-11-20	Yasmin Lind PhD	yasmin.lind.phd@geemail.com	Syracuse	New York	3032935043467088	19979c1846369e25a1f0c7a66edc1796	JCB 16 digit	43.0659334452673761	-76.117324629404024
5585	2019-11-20 12:48:36	2019-11-20	Kalen Wunsch	kalen.wunsch@warmmail.com	Sacramento	California	4768904841246	a9c766df1c906652d8d3f398942f9e35	Diners Club / Carte Blanche	38.5577361686419735	-121.401369313501192
5586	2019-11-20 13:13:44	2019-11-20	Miss Lauretta Kshlerin PhD	miss.lauretta.kshlerin.phd@warmmail.com	San Francisco	California	3112044132454270249	df97f483a094a866e84b029fc97a6ee1	Discover	37.8054068203918945	-122.413854066367207
5587	2019-11-20 13:27:34	2019-11-20	Ms. Azariah Zulauf	ms.azariah.zulauf@geemail.com	Oakland	California	869951448489591288	7a0a77c4fdc4537d3cd5228568707ee5	JCB 16 digit	37.8012297798138661	-122.276808141176758
5588	2019-11-20 15:22:32	2019-11-20	Dominga Davis	dominga.davis@geemail.com	Oakland	California	4235037247378	978eb9753922a14d2657acdbd14f0b31	American Express	37.8241212242123552	-122.267817728874277
5589	2019-11-20 15:30:58	2019-11-20	Omer Torphy Sr.	omer.torphy.sr.@geemail.com	Aurora	Colorado	3016818220484595	91f33a3486017d7ab48bdcc41da1a04a	VISA 16 digit	39.762130924418571	-104.724319553340607
5590	2019-11-20 15:52:32	2019-11-20	Holmes Smith	holmes.smith@warmmail.com	Jacksonville	Florida	3031627921299136	ca30a0eecdee196b9ef60600e0ef6495	JCB 16 digit	30.4013776526838555	-81.7324148422651007
5591	2019-11-20 16:14:10	2019-11-20	Ms. Sybilla Kreiger	ms.sybilla.kreiger@geemail.com	New York	New York	3337080155437729416	088503546c267ceda14ac12d938281a3	VISA 16 digit	40.5823237096648626	-73.9714763862442197
5592	2019-11-20 17:00:02	2019-11-20	Concetta Erdman	concetta.erdman@geemail.com	Los Angeles	California	6011597132689861417	d2be096a7783f3018a2eb08c021c713b	VISA 16 digit	33.9612930905405435	-118.369754516286022
5593	2019-11-20 17:26:48	2019-11-20	Patrica Bashirian-Wisozk	patrica.bashirian.wisozk@geemail.com	Pittsburgh	Pennsylvania	676392177372015	30770626f7f2086ac33c0d715f1c8774	VISA 16 digit	40.4385758895382281	-79.9349314986433939
5594	2019-11-20 18:09:59	2019-11-20	Fitzgerald Leffler	fitzgerald.leffler@warmmail.com	Chicago	Illinois	52287524375718908	6b68df86630ca53bf9e2f5938f53b9ec	Mastercard	41.9212134591139858	-87.6940749757021649
5595	2019-11-20 19:54:21	2019-11-20	Mr. Derick Reilly MD	mr.derick.reilly.md@geemail.com	San Francisco	California	3726200361200427	512f159c1e20c8f9f4b2cd265e2d09b7	VISA 13 digit	37.7927416228933382	-122.427125717738278
5596	2019-11-20 20:04:23	2019-11-20	Hillery Haag DDS	hillery.haag.dds@geemail.com	Brownsville	Texas	3528570934116442880	c73809f2c10250f9d32eff84f5f02e6a	American Express	25.9555106782898299	-97.5294627995882166
5597	2019-11-20 20:30:27	2019-11-20	Reagan Boyle	reagan.boyle@warmmail.com	Omaha	Nebraska	3410685915370361	e51e103c3144b94329a227fa36694c2d	Diners Club / Carte Blanche	41.2311180558666592	-96.1047299200318861
5598	2019-11-20 20:52:44	2019-11-20	Bethzy Bartell	bethzy.bartell@geemail.com	Oakland	California	51948265907651255	b93900e8bfef6b4eb7da276b637422a0	JCB 16 digit	37.802910271383638	-122.259592109600376
5599	2019-11-20 21:06:29	2019-11-20	Miss Birdie Quigley DVM	miss.birdie.quigley.dvm@woohoo.com	League City	Texas	3096717041306244508	ed87af2bff986e0b3cbd9456318a4490	Voyager	29.5054966752346637	-95.0627293266806674
5600	2019-11-20 21:35:25	2019-11-20	Salina Grimes DVM	salina.grimes.dvm@geemail.com	Oakland	California	4525887196893	c98278d57b4dde9d246407a3ca824992	Discover	37.784201834326737	-122.25848745459939
5601	2019-11-20 22:05:40	2019-11-20	Elda Gislason	elda.gislason@geemail.com	Oakland	California	4561790828249	945e3e0a78f7cf9538b4368e92287d05	American Express	37.8304496437818401	-122.241247499941352
5602	2019-11-20 22:19:46	2019-11-20	Sena Simonis	sena.simonis@geemail.com	Kent	Washington	6011808242474069624	1f9ca1cfcddcb540e3cc37140969e70e	Maestro	47.4176941487584216	-122.205276154321425
5603	2019-11-20 22:21:47	2019-11-20	Mr. Alcee Hirthe	mr.alcee.hirthe@geemail.com	San Jose	California	210020002350615516	6480447fe566f58f5d3e593f75496c29	Voyager	37.2019691044285921	-121.901635184114426
5604	2019-11-20 22:35:16	2019-11-20	Nicholaus Hilpert	nicholaus.hilpert@geemail.com	San Francisco	California	4178231144245872	19dbdb023a62b578df6b3fc80f5c3012	Maestro	37.7797367864596367	-122.438915763173398
5605	2019-11-20 22:40:12	2019-11-20	Elwin Watsica	elwin.watsica@geemail.com	San Francisco	California	6011074977440983302	7f5cf0ee44cc4c75e8a83f73ca119684	Discover	37.7331023669346877	-122.440757001079319
5606	2019-11-20 22:44:48	2019-11-20	Delora Leuschke	delora.leuschke@geemail.com	Coral Springs	Florida	3096751036966878873	e8ac4807a8782e245aac94627a923eba	American Express	26.176749998337403	-80.2081636589143443
5607	2019-11-20 22:46:08	2019-11-20	Emogene Bogisich	emogene.bogisich@geemail.com	Philadelphia	Pennsylvania	502002885972139	c8fffc8327469bf197dfbb79576aa541	Maestro	39.9196047029882664	-75.1685340791840133
5608	2019-11-20 23:30:46	2019-11-20	Bryn Kilback	bryn.kilback@woohoo.com	Berkeley	California	6011926917585866870	40117f7c5bb28f1b37dd84d0df1b6d05	VISA 16 digit	37.8411509590948896	-122.257461575765291
5609	2019-11-20 23:51:09	2019-11-20	Dorla Conn MD	dorla.conn.md@geemail.com	Portland	Oregon	52495028153729721	da4406c44f273c36b890280b8c69a846	American Express	45.4909335967507218	-122.590716027142491
5610	2019-11-21 00:24:25	2019-11-21	Fitzhugh Beier	fitzhugh.beier@geemail.com	Clinton	Michigan	3112803688374903822	a53c50a3c3120c0ef0d9fd8eb55f717e	Voyager	42.6719704652272185	-82.9612069867625905
5611	2019-11-21 00:26:21	2019-11-21	Ms. Chastity Ortiz	ms.chastity.ortiz@geemail.com	San Francisco	California	869912985036684585	58a77e5aa32f79961aac7ed0ff6dce32	Mastercard	37.8068584378440633	-122.4536592799289
5612	2019-11-21 00:43:52	2019-11-21	Roddy Oberbrunner III	roddy.oberbrunner.iii@geemail.com	Atlanta	Georgia	3528036228660122537	093c727c4f2ad464f1b7e5abec418205	Mastercard	33.7124009906124371	-84.3278878170576007
5613	2019-11-21 00:52:20	2019-11-21	Dr. Spencer Wolff DVM	dr.spencer.wolff.dvm@geemail.com	Boulder	Colorado	6011491894186781003	c5648b631aaa351921459f0a0f977a5d	Mastercard	39.987030820127579	-105.167496983907753
5614	2019-11-21 01:31:26	2019-11-21	Kyler Hilpert	kyler.hilpert@geemail.com	San Francisco	California	180007136807201988	20cef7f83a687486ffbf97788400e744	Diners Club / Carte Blanche	37.7771336207538511	-122.430451943284609
5615	2019-11-21 01:43:12	2019-11-21	Yasmeen Lang	yasmeen.lang@geemail.com	Santa Clara	California	53371681993370939	e212740b0fbd48464da722972b75edef	American Express	37.2782045038700147	-121.979756267740953
5616	2019-11-21 02:17:40	2019-11-21	Donald Harber	donald.harber@geemail.com	Berkeley	California	676193614490162	8a2df9768dedee9683bdb1cb11b0d87e	Diners Club / Carte Blanche	37.8638195027207018	-122.295492648362611
5617	2019-11-21 02:20:52	2019-11-21	Montrell Hartmann	montrell.hartmann@geemail.com	San Francisco	California	4941363985016	801f2358fcc9df530858cf392e17b47b	Maestro	37.7822769114838479	-122.432858883234758
5618	2019-11-21 03:23:53	2019-11-21	Dale Wilkinson	dale.wilkinson@woohoo.com	Cary	North Carolina	180015858270766615	8f579779683cd029382dbed25d5716d6	VISA 16 digit	35.8610909342408206	-78.7854524243708738
5619	2019-11-21 04:47:24	2019-11-21	Caddie Funk DVM	caddie.funk.dvm@warmmail.com	Arlington	Texas	54056349872967082	04fd84b9d74092d83c94b582598a66d4	JCB 15 digit	32.6845137615937702	-97.2162469040162875
5620	2019-11-21 04:53:16	2019-11-21	Kellan Willms	kellan.willms@geemail.com	New York	New York	676378969263066	e8ad1e96cac9effc179cec75c9693165	Diners Club / Carte Blanche	40.5672751959171123	-74.0075163054641365
5621	2019-11-21 05:05:06	2019-11-21	Tavaris Leuschke	tavaris.leuschke@geemail.com	Chicago	Illinois	54778694769233123	173b94f442587d9acf2b91776ff83611	JCB 16 digit	41.9056223821196738	-87.6246730445448208
5622	2019-11-21 05:11:31	2019-11-21	Mr. Jalen Flatley	mr.jalen.flatley@geemail.com	Buffalo	New York	6011688199187284285	39d6117725f1cfbae35aeacf04859e9d	JCB 16 digit	42.9696571036893857	-78.7603492260843581
5623	2019-11-21 05:11:54	2019-11-21	Cora Koch DVM	cora.koch.dvm@warmmail.com	San Francisco	California	3495687924333008	a93f11949a6e5ab92f037cb6093e8927	JCB 16 digit	37.7695596888182905	-122.427202964553388
5624	2019-11-21 05:23:33	2019-11-21	Trinidad Bashirian	trinidad.bashirian@geemail.com	Oakland	California	6011298860433597042	0823ae5e71c7fe33f9342affc4c0f303	JCB 16 digit	37.8375693413990888	-122.265198588967706
5625	2019-11-21 05:28:31	2019-11-21	Alexandra Hickle	alexandra.hickle@geemail.com	Plano	Texas	3026826043653999	784c5c7f42f37df1850c9a6a108dd5d6	American Express	33.0263413720849925	-96.8255635733898714
5626	2019-11-21 05:29:30	2019-11-21	Mr. Treyvon Zboncak Sr.	mr.treyvon.zboncak.sr.@geemail.com	Grand Prairie	Texas	3528715076386631317	6e6fd9d5954d9c9403d83290b9b49ab1	JCB 16 digit	32.6305805927660302	-96.9771622337274266
5627	2019-11-21 05:34:04	2019-11-21	Dr. Sigurd Fisher	dr.sigurd.fisher@geemail.com	Bridgeport	Connecticut	3484695191480454	09d5d468d3677d9d1efb95a12116fe95	VISA 13 digit	41.1078332205466879	-73.1609416475884728
5628	2019-11-21 05:39:10	2019-11-21	Doshia Gutmann	doshia.gutmann@geemail.com	New York	New York	4398384804893483	5e0d3cd7e98ca394454f432aeff59342	Mastercard	40.5662216760907341	-73.9338796464622021
5629	2019-11-21 06:25:29	2019-11-21	Barton DuBuque	barton.dubuque@woohoo.com	St. Petersburg	Florida	4447748461375029	f2af9dda794f308d36e992b362552492	VISA 13 digit	27.7787218336835515	-82.7392093122362979
5630	2019-11-21 06:39:42	2019-11-21	Ana Shanahan DVM	ana.shanahan.dvm@geemail.com	Norfolk	Virginia	4576280030106399	b93a1e31bff034630e4674e1f63f3842	JCB 16 digit	36.853606806417929	-76.2864650519568528
5631	2019-11-21 07:23:37	2019-11-21	Mr. Ottis Konopelski	mr.ottis.konopelski@geemail.com	Durham	North Carolina	869921995479527422	c1edc5f7ab2412edd9bdc14ade235b13	Maestro	36.0568315718103207	-78.8597972922861601
5632	2019-11-21 07:50:27	2019-11-21	Assunta Heathcote	assunta.heathcote@geemail.com	Indianapolis	Indiana	210084971235645034	a191bec06efaeb0702b16eba515f13fd	Voyager	39.7782635622665239	-86.065690741894386
5633	2019-11-21 07:57:07	2019-11-21	Mrs. Audriana Lockman	mrs.audriana.lockman@geemail.com	Houston	Texas	54585480369877177	b0f4fdbf0cddee8d59ca797462f4368c	JCB 16 digit	29.8439276780080043	-95.4461270897664207
5634	2019-11-21 07:58:58	2019-11-21	Lindsay VonRueden	lindsay.vonrueden@geemail.com	Durham	North Carolina	3038837523658240	b00b7947d4748cc491ca8609e180601c	VISA 16 digit	36.0158131173592011	-78.9219520610660368
5635	2019-11-21 08:29:11	2019-11-21	Terra Cole	terra.cole@woohoo.com	New York	New York	6011682652078018044	cacc1c2638ce46c02afec07036fee1a2	Mastercard	40.7154668464548877	-74.0245924861531677
5636	2019-11-21 09:08:06	2019-11-21	Lorayne Lang DVM	lorayne.lang.dvm@geemail.com	San Antonio	Texas	3707173275391108	b4cdcd302f4b393d60f19e024b01e777	Voyager	29.4146563973348592	-98.438579941943658
5637	2019-11-21 09:51:30	2019-11-21	Dr. Charmaine Bogan	dr.charmaine.bogan@geemail.com	San Francisco	California	4560214853443868	aa55902dbd2c4465de22c568826a6cc5	Diners Club / Carte Blanche	37.7577558580492578	-122.454126619434277
5638	2019-11-21 09:59:35	2019-11-21	Carnell Wilderman	carnell.wilderman@warmmail.com	New York	New York	3719998790180248	a3e30eacaf4af1414d411e36026fe83e	Mastercard	40.6457435441426895	-73.8957640431251406
5639	2019-11-21 10:04:39	2019-11-21	Lauretta Hahn MD	lauretta.hahn.md@geemail.com	Oakland	California	869950462039477105	0f9974b1d4f3da0e1d4100e5aa5ace1d	JCB 16 digit	37.7585811782239347	-122.272989485963961
5640	2019-11-21 10:50:33	2019-11-21	Dr. Dotty Morar MD	dr.dotty.morar.md@geemail.com	Durham	North Carolina	4637298208390089	d426bc7ae1292bc6e66a46b89c5a42d4	VISA 16 digit	36.05758132704198	-78.9131425679564558
5641	2019-11-21 11:48:40	2019-11-21	Rollo Dooley I	rollo.dooley.i@geemail.com	Bakersfield	California	4984896733939509	09d77d32382c906657a5e7e75b454299	American Express	35.3020321073651289	-118.985043079945441
5642	2019-11-21 12:04:28	2019-11-21	Lavern Grimes	lavern.grimes@geemail.com	Oakland	California	6011468634588784588	0c902710bd2588eb1a094a29090cb055	American Express	37.8059257555929662	-122.239102837026309
5643	2019-11-21 12:35:28	2019-11-21	Arlene Oberbrunner	arlene.oberbrunner@geemail.com	Berkeley	California	4052844019544400	2eaea57bb0018eeccb85aa95c7df6192	VISA 13 digit	37.8479819027633582	-122.28027204962909
5644	2019-11-21 13:04:15	2019-11-21	Diane Bednar	diane.bednar@geemail.com	Dallas	Texas	4086015098173227	10aea6576463d536fbf69e85b8774d7a	VISA 16 digit	32.8851023031670593	-96.8384467247836227
5645	2019-11-21 13:21:57	2019-11-21	Tomie Barrows	tomie.barrows@woohoo.com	Vallejo	California	4697364932003138	549b30c20d89d54844d1af4b5efa39f4	Maestro	38.1400749832946815	-122.177751409295936
5646	2019-11-21 13:29:33	2019-11-21	Jalissa Hilpert	jalissa.hilpert@woohoo.com	Baltimore	Maryland	51131605675251019	2c8941d165bb8998ff4982be34891506	Diners Club / Carte Blanche	39.256856120470907	-76.6552597718332009
5647	2019-11-21 15:09:36	2019-11-21	Von Lubowitz	von.lubowitz@geemail.com	Chicago	Illinois	869953174139468036	6d8262042dc7b14905f946945643bfdb	Mastercard	41.8840094362687339	-87.6004359341256276
5648	2019-11-21 15:16:08	2019-11-21	Mrs. Mariah Ondricka DVM	mrs.mariah.ondricka.dvm@woohoo.com	San Francisco	California	589315935573210	90c67fdcf63ca18dfa2b7fc312f87fed	Maestro	37.7751290941936375	-122.448391551480228
5649	2019-11-21 15:19:28	2019-11-21	Mrs. Dominique Kassulke	mrs.dominique.kassulke@geemail.com	Las Vegas	Nevada	4837663681667576	f9e37b37ab5b3cc832d22e4f306a8c4d	JCB 16 digit	36.300143842642008	-115.175432698589191
5650	2019-11-21 15:31:27	2019-11-21	Lesli Cremin	lesli.cremin@geemail.com	Berkeley	California	4316347869316343	d620e3b46f84ee2b9e0e0eb4433da15e	JCB 15 digit	37.9012897375538458	-122.267394104570485
5651	2019-11-21 15:36:54	2019-11-21	Marianne Yundt	marianne.yundt@woohoo.com	Plano	Texas	210048449214618509	1cb81a7d6dc650a199cb9a5b7f3d64da	Diners Club / Carte Blanche	33.049076365082712	-96.7341584966700481
5652	2019-11-21 15:37:14	2019-11-21	Idamae Bernier	idamae.bernier@geemail.com	San Francisco	California	4975103642327947	6bea142e8930a43ab998120057aad30e	JCB 15 digit	37.7904123932291256	-122.418430130917756
5653	2019-11-21 15:40:35	2019-11-21	Rachael Grimes	rachael.grimes@geemail.com	New York	New York	4191985444550	75d95661b6b4ebe26c97c644265dd0b4	Diners Club / Carte Blanche	40.6652990548629276	-73.922588025674969
5654	2019-11-21 16:21:30	2019-11-21	Marcela Gleason	marcela.gleason@woohoo.com	Palmdale	California	4992590397871	40e04089a00855b3a135e44ca5f39479	JCB 15 digit	34.6549017316978407	-118.149841647222274
5655	2019-11-21 17:52:21	2019-11-21	Nallely Reichert	nallely.reichert@geemail.com	Shreveport	Louisiana	4168122784540221	1ed6eb7c67bf55b299771dd2d25a403f	Mastercard	32.5365628763340453	-93.882556256719667
5656	2019-11-21 17:53:40	2019-11-21	Dr. Brook Kreiger	dr.brook.kreiger@woohoo.com	Atlanta	Georgia	3088604888717034738	850d20c8dc826fd95900c33a3c8ae1db	VISA 16 digit	33.7583350720625361	-84.4960484540134757
5657	2019-11-21 17:54:40	2019-11-21	George Jakubowski	george.jakubowski@warmmail.com	Sterling Heights	Michigan	3009434848126761	cdf1c30e8546c94e13d69cc6dff8392a	American Express	42.5043655314564717	-82.9756186119440855
5658	2019-11-21 17:55:03	2019-11-21	Dr. Gust Satterfield Jr.	dr.gust.satterfield.jr.@geemail.com	Scottsdale	Arizona	51073646219236637	d137f2dffc932ce2008db070eee30f88	American Express	33.6213727805420746	-111.918440381341043
5659	2019-11-21 17:57:23	2019-11-21	Chelsie Lebsack	chelsie.lebsack@geemail.com	Oakland	California	3760685903387350	a32b622581eaa25a72b9014670dc9235	JCB 15 digit	37.8221854132424582	-122.28643538848128
5660	2019-11-21 18:35:18	2019-11-21	Desirae Kunde-Kunze	desirae.kunde.kunze@woohoo.com	San Francisco	California	589307913613688	0c16d42e0e6c9821f730e5698277d43c	JCB 15 digit	37.7591708425881478	-122.407693716440065
5661	2019-11-21 18:47:46	2019-11-21	Watson Lemke I	watson.lemke.i@warmmail.com	New York	New York	4681792995808209	2dea44a0e6ea284b2c0a4c113c52f5d1	Diners Club / Carte Blanche	40.731286256549879	-73.8473602611001496
5662	2019-11-21 21:06:02	2019-11-21	Hartley Lowe V	hartley.lowe.v@geemail.com	Springfield	Missouri	3158514596965689991	73b373ac4d4523270b9178d8e0a9b56f	Mastercard	37.19690784692839	-93.2152296523388486
5663	2019-11-21 21:28:40	2019-11-21	Abb Kuhlman	abb.kuhlman@geemail.com	Wilmington	North Carolina	4896044642555564	14be8de92623175e60b0e14610acc0a8	Discover	34.1968298455987139	-77.817085994220534
5664	2019-11-21 23:21:43	2019-11-21	Ms. Ossie Lynch PhD	ms.ossie.lynch.phd@woohoo.com	Ann Arbor	Michigan	4868236800066152	9356cd56851112ee2eac8a30ff832931	Diners Club / Carte Blanche	42.2001952639374878	-83.6868855319559657
5665	2019-11-21 23:27:53	2019-11-21	Sasha Wilkinson-Lang	sasha.wilkinson.lang@woohoo.com	Oakland	California	3096256069339475630	afc6332ec41701f8c17fb6ae72495d1f	JCB 16 digit	37.8068280671619306	-122.273394872777885
5666	2019-11-21 23:30:11	2019-11-21	Angelita Macejkovic	angelita.macejkovic@geemail.com	Los Angeles	California	4652314866911312	6d360470a2c141804db01104c5962ca4	Voyager	34.0540098492387671	-118.389637000997737
5667	2019-11-21 23:54:39	2019-11-21	Laurence Nolan	laurence.nolan@woohoo.com	Eugene	Oregon	4561114247242209	fbeae796d83e0178e373614651542fd6	Voyager	43.9921343667160727	-123.189682954083011
5668	2019-11-22 00:22:41	2019-11-22	Cheyenne Kertzmann PhD	cheyenne.kertzmann.phd@warmmail.com	Berkeley	California	3112401615230841165	234796bdd294ab9c7b53b5e0a288933f	VISA 13 digit	37.8570250234993395	-122.269011094816648
5669	2019-11-22 00:45:23	2019-11-22	Aline Altenwerth	aline.altenwerth@woohoo.com	Kent	Washington	869909255117388026	beb514f8e281d4cc126afe23ef25d44f	VISA 16 digit	47.3922519743554247	-122.295617639520017
5670	2019-11-22 01:14:41	2019-11-22	Ms. Serenity Yost MD	ms.serenity.yost.md@geemail.com	New York	New York	3022495097474258	2f349004e391aff655aa46048dd4b85a	VISA 16 digit	40.653156408457086	-73.8736550048354985
5671	2019-11-22 01:32:28	2019-11-22	Adaline Nikolaus-Denesik	adaline.nikolaus.denesik@geemail.com	Phoenix	Arizona	3088458916255797247	54647c9942ef0bf326b51e475e298135	JCB 16 digit	33.5619136352025009	-112.12311406651736
5672	2019-11-22 01:40:43	2019-11-22	Kirby Bailey	kirby.bailey@geemail.com	San Francisco	California	55396211833966042	ed08d5c29729d6c79f3c6f282bf1abe5	Discover	37.7519744642530526	-122.447804553076139
5673	2019-11-22 01:42:13	2019-11-22	Mr. Hattie Kling II	mr.hattie.kling.ii@geemail.com	San Francisco	California	3439346111392249	34cb19f8672d90e8f956d4f84b1fedb4	JCB 16 digit	37.7570336551387697	-122.438304228296204
5756	2019-11-23 11:31:19	2019-11-23	Miss Melonie Wolf	miss.melonie.wolf@woohoo.com	San Francisco	California	4561234452390	5aa281305219df774eff3e5b018f623d	Discover	37.7582267279155559	-122.409290609900395
5674	2019-11-22 02:25:48	2019-11-22	William Heidenreich	william.heidenreich@warmmail.com	Santa Clarita	California	4766672276017	7e7ff05fb24d1bce96a17b48b70af52d	Diners Club / Carte Blanche	34.4517856958992752	-118.447618496148664
5675	2019-11-22 02:37:18	2019-11-22	Miss Madaline Berge DVM	miss.madaline.berge.dvm@geemail.com	Denver	Colorado	4598889322435185	79e3c4c70f05e11f840a51cdcf95c3b7	VISA 16 digit	39.7000537141278329	-104.909271300236142
5676	2019-11-22 03:31:20	2019-11-22	Dejuan Okuneva	dejuan.okuneva@geemail.com	Sacramento	California	3744447801842460	7ee9d140139c0342869c1a338e76b3ca	American Express	38.4920898765124377	-121.483383463580523
5677	2019-11-22 03:52:27	2019-11-22	Zed Schamberger Jr.	zed.schamberger.jr.@geemail.com	Victorville	California	3035905701153418	70df4ebf3067a08dba9594c4b1df4250	American Express	34.4285319740649314	-117.36857957482934
5678	2019-11-22 04:19:41	2019-11-22	Graham Bergnaum	graham.bergnaum@geemail.com	Jacksonville	Florida	3528583476113361957	035b7dda523897150ef6d3afd5bdf0ed	JCB 16 digit	30.3002594278246171	-81.6872098584737643
5679	2019-11-22 04:20:51	2019-11-22	Mr. Kasen Langworth IV	mr.kasen.langworth.iv@geemail.com	Berkeley	California	52242481022131478	221bd192443cdac930d91c737e1e9010	American Express	37.8399064489058716	-122.262487515433406
5680	2019-11-22 04:58:39	2019-11-22	Ira Gottlieb-Lebsack	ira.gottlieb.lebsack@woohoo.com	Bakersfield	California	3707393967879406	c1351191f92b1347c452ecd74e41b668	VISA 16 digit	35.2317537169147244	-119.054237147261574
5681	2019-11-22 05:09:48	2019-11-22	Geraldo Jacobs	geraldo.jacobs@geemail.com	Tucson	Arizona	4984608828213207	568017cae4bb2ddb4f14f55a3b8c861b	American Express	32.1174860728479956	-110.968603299487754
5682	2019-11-22 05:25:41	2019-11-22	Wynona Macejkovic PhD	wynona.macejkovic.phd@woohoo.com	Dayton	Ohio	180027971809503148	d2d5ee0119ebffbdc8003f350e9ff75e	JCB 16 digit	39.7582724196162047	-84.1934529218547141
5683	2019-11-22 06:23:31	2019-11-22	Giana Ankunding	giana.ankunding@geemail.com	San Francisco	California	180042445791945246	a413b40dc0b58a7dd466c7ab768378d5	Voyager	37.777498220168269	-122.429037171004296
5684	2019-11-22 06:30:46	2019-11-22	Elba Sporer	elba.sporer@geemail.com	San Antonio	Texas	210048770709521167	cfd6b6f1d615c32b4892e266e57aff90	American Express	29.5409069930274057	-98.5119286030832626
5685	2019-11-22 06:42:34	2019-11-22	Vincenza Lemke	vincenza.lemke@geemail.com	Irving	Texas	3405099407217055	3fb1fc91c55804704331130f7f63aefc	VISA 13 digit	32.9256968130774794	-96.9779730487894227
5686	2019-11-22 08:33:33	2019-11-22	Harlie O'Conner	harlie.o'conner@woohoo.com	Fullerton	California	55263046043007207	8a85195b313bce84e2b702feb94604a0	VISA 13 digit	33.9521144634269163	-117.924681952802459
5687	2019-11-22 08:59:06	2019-11-22	Lilyanna Kautzer MD	lilyanna.kautzer.md@warmmail.com	San Francisco	California	4002139284097031	56335af5d33476adf99d9ac05d7295bc	American Express	37.7765326827354215	-122.44310738077067
5688	2019-11-22 09:03:00	2019-11-22	Dr. Shay Turcotte DDS	dr.shay.turcotte.dds@geemail.com	San Francisco	California	3736254848843489	27d8542c9087e06d2f022caefbeb5a97	Discover	37.7177074757343149	-122.405117247064211
5689	2019-11-22 10:06:31	2019-11-22	Candi Schumm	candi.schumm@geemail.com	Detroit	Michigan	3407533585881058	23f3a8cf316bb8feb12628a286cad824	Diners Club / Carte Blanche	42.4746822967585231	-83.0342629275403823
5690	2019-11-22 10:28:26	2019-11-22	Kenya Quitzon	kenya.quitzon@geemail.com	Los Angeles	California	3012672438670964	a261df0fb0d5050bd17ac95495b79924	Voyager	34.0494897973589588	-118.447230111760263
5691	2019-11-22 10:31:38	2019-11-22	Dr. Pryor Heaney	dr.pryor.heaney@warmmail.com	Burbank	California	51820118608554638	4b23c07bfce61de8e7f944a5c0f8f7d9	Mastercard	34.2523692789416785	-118.295075814243035
5692	2019-11-22 11:04:44	2019-11-22	Fronia Gaylord DVM	fronia.gaylord.dvm@geemail.com	San Francisco	California	3158426695296054110	ae1725886ae2f78b093708d5f51f23ef	Voyager	37.7734477700225	-122.421249242505596
5693	2019-11-22 11:26:15	2019-11-22	Mohammad Ortiz-Blick	mohammad.ortiz.blick@geemail.com	Sacramento	California	4813667715474	b734c14f097981863f257266f2a2412d	VISA 16 digit	38.5281658664610234	-121.560368048424266
5694	2019-11-22 11:49:58	2019-11-22	Price Ritchie	price.ritchie@geemail.com	San Francisco	California	3445450355786058	dd0f6ea0e607bb809fa6da0a31b8cfd0	Voyager	37.7870850640635823	-122.481403236778633
5695	2019-11-22 11:59:38	2019-11-22	Leilani Roob	leilani.roob@geemail.com	Springfield	Massachusetts	4476722128319369	e72e11d9abbaab0e0a528cee2b9ae87b	VISA 13 digit	42.0624180810265216	-72.4550977781042462
5696	2019-11-22 12:17:50	2019-11-22	Dr. Keandre Grady	dr.keandre.grady@geemail.com	Philadelphia	Pennsylvania	4404129302966998	0c843b1f1276b71f1561b3d9948b6dbe	VISA 16 digit	39.9783244911074647	-75.0860916337829138
5697	2019-11-22 14:34:14	2019-11-22	Gearld Schultz	gearld.schultz@geemail.com	Berkeley	California	4655878385245	5f7103e88f658b88ffc728e3f13ec1d3	Maestro	37.8479077656142593	-122.249209131808186
5698	2019-11-22 15:48:20	2019-11-22	Corrine Boyer	corrine.boyer@geemail.com	Elk Grove	California	630457188222822	5700d0cb71c101f77012366ec08db010	American Express	38.3542740433760017	-121.438520796867095
5699	2019-11-22 15:51:17	2019-11-22	Timmy Kris	timmy.kris@geemail.com	New York	New York	4159815641125	033ac6a749c5ab6ab203dd789f54eb1a	VISA 16 digit	40.6590688268411924	-73.9969343312446028
5700	2019-11-22 16:06:39	2019-11-22	Mr. Corwin Ernser	mr.corwin.ernser@warmmail.com	Greensboro	North Carolina	4924859450801461	4a171f2af0092108e6438ff08192e5ab	American Express	36.0065364599809072	-79.7638501367047468
5701	2019-11-22 16:17:49	2019-11-22	Pryor Lehner	pryor.lehner@geemail.com	Oakland	California	55680397322927457	0720f6fb0547018701945304071a6218	JCB 16 digit	37.7949018321291419	-122.28999148994906
5702	2019-11-22 16:47:14	2019-11-22	Buena Stracke	buena.stracke@geemail.com	San Francisco	California	4318854685376557	26536fa7ac74476971af77b9c31b4330	Mastercard	37.7566975361255217	-122.45016955177212
5703	2019-11-22 17:16:49	2019-11-22	Candace Muller-Rosenbaum	candace.muller.rosenbaum@warmmail.com	Washington	District of Columbia	869981774960538819	f92b8bf5f55e223f6e4ce3dfa1c5c2b5	JCB 16 digit	38.9210946430716689	-77.0339078736238179
5704	2019-11-22 17:31:54	2019-11-22	Antonio Kuhn	antonio.kuhn@woohoo.com	New York	New York	3528141502479353869	cdfe28d997f0afe515bfd1d6779086f8	JCB 15 digit	40.6197617746181763	-73.8898737225577236
5705	2019-11-22 17:32:34	2019-11-22	Dosha Nader PhD	dosha.nader.phd@woohoo.com	Aurora	Illinois	3046590107593562	d95f00e296c59a308197efcae47059ee	JCB 16 digit	41.8325999270882463	-88.3201485838204547
5706	2019-11-22 17:37:29	2019-11-22	Mr. Amil Waelchi	mr.amil.waelchi@geemail.com	Green Bay	Wisconsin	3158121459272814171	011aa903b3c877ae6121ffda89308355	JCB 15 digit	44.4790815074525767	-88.0748241156626506
5707	2019-11-22 17:44:50	2019-11-22	Jax Considine	jax.considine@woohoo.com	Allen	Texas	869993002501146264	eae7facf286cea8318e813521a81b0ae	VISA 16 digit	33.0187147501416476	-96.6231896976888152
5708	2019-11-22 18:03:11	2019-11-22	Miss Meggan Nicolas DVM	miss.meggan.nicolas.dvm@woohoo.com	New York	New York	869948779387888244	0ff0d89a3c102ed3ed595a24b9e02086	Maestro	40.6818241877239188	-73.999855812069768
5709	2019-11-22 18:20:53	2019-11-22	Della Nitzsche	della.nitzsche@warmmail.com	Berkeley	California	3773505797818671	d74c66135604cdfccf0b76e786a6c985	Maestro	37.8913308532291495	-122.280639031979462
5710	2019-11-22 18:38:17	2019-11-22	Dr. Howell Koss	dr.howell.koss@geemail.com	Topeka	Kansas	4596717342414587	bfd7b8ca3774f710850684ebc1a36b2a	VISA 13 digit	39.0779713354006404	-95.6015671421948809
5711	2019-11-22 19:01:12	2019-11-22	Shayna Bradtke	shayna.bradtke@geemail.com	Oakland	California	4398493936753448	173afce442cb010cf377f664346352ce	American Express	37.7979055331513578	-122.270181512064426
5712	2019-11-22 19:16:37	2019-11-22	Bobby Nikolaus	bobby.nikolaus@geemail.com	San Francisco	California	4012650159785607	6f2a78f9d052b11f39298b112060ca7b	Voyager	37.7547856665395756	-122.460470279929709
5713	2019-11-22 19:23:24	2019-11-22	Frances Funk	frances.funk@geemail.com	Chicago	Illinois	869982705306201315	00cf8a1ce18b9be933308adbcd180813	VISA 13 digit	41.76882434914112	-87.7600159439753753
5714	2019-11-22 19:23:41	2019-11-22	Thyra Mayer	thyra.mayer@geemail.com	Washington	District of Columbia	3490856153355348	61c0465aaf4f57c7854a25300643882b	JCB 15 digit	38.8210516587629897	-77.101525162554168
5715	2019-11-22 19:47:07	2019-11-22	Delma Bergstrom-Luettgen	delma.bergstrom.luettgen@warmmail.com	New York	New York	4543233946499	576933e8d9447b209b81b0ec829d2fa5	Mastercard	40.6724693112298823	-74.01710895797126
5716	2019-11-22 20:04:43	2019-11-22	Dr. Tanya Farrell PhD	dr.tanya.farrell.phd@geemail.com	Berkeley	California	4181646032900731	99a3c4f7236ed9c906d00955d6406e3b	Maestro	37.8895213334866057	-122.256696511016173
5717	2019-11-22 20:48:19	2019-11-22	Joanna Wyman	joanna.wyman@geemail.com	Los Angeles	California	4974178056064187	87e90db5dbb6f046b35acd040afcc314	Mastercard	33.9280343961302151	-118.406394193087891
5718	2019-11-22 21:23:53	2019-11-22	Marlee Cartwright	marlee.cartwright@geemail.com	New York	New York	4952728117604714	ff0a4a8370426f12aabb9b0b590e38b8	JCB 15 digit	40.5873712061196557	-73.9756431317318146
5719	2019-11-22 21:45:17	2019-11-22	Robyn Bartell	robyn.bartell@geemail.com	Durham	North Carolina	180079970624127700	bc4ce3276dca6019a8f11e4cbcbf0480	Mastercard	36.0400234987273791	-78.9421874763347233
5720	2019-11-22 22:02:26	2019-11-22	Dawna Price	dawna.price@geemail.com	New York	New York	6011809979835171131	70582475ff74bf1d58dc2244f0d64a6b	JCB 16 digit	40.5790373109038924	-73.8806932065997302
5721	2019-11-22 22:22:30	2019-11-22	Sunday Walter	sunday.walter@geemail.com	San Francisco	California	4429721081231	f5755ec19127901730ea223537bffed9	JCB 15 digit	37.7696085178315712	-122.413254034952942
5722	2019-11-22 22:35:21	2019-11-22	Kailee Carroll	kailee.carroll@geemail.com	San Francisco	California	210028647508413057	0d09ab312b0a0b4b4a70e80546f63572	American Express	37.7992660190931602	-122.456171906653609
5723	2019-11-22 22:52:49	2019-11-22	Irven Hauck Jr.	irven.hauck.jr.@woohoo.com	San Francisco	California	4373993008388725	d6589be4c7bbdaae99e04389e3c6a913	Mastercard	37.7433228060845849	-122.432571550428278
5724	2019-11-22 23:02:56	2019-11-22	Gustie Jast DDS	gustie.jast.dds@geemail.com	Los Angeles	California	3423855317538403	0bcbf3eb97bed8177e28bf7217dc966b	Discover	34.0615968398615721	-118.42306738416589
5725	2019-11-23 00:06:05	2019-11-23	Maxine Pacocha	maxine.pacocha@geemail.com	Houston	Texas	4963602143563946	9f1d10699122214f5e92b533fcf9a539	VISA 13 digit	29.7454083975017056	-95.3525176121868157
5726	2019-11-23 00:21:03	2019-11-23	Eugenia Block-O'Conner	eugenia.block.o'conner@geemail.com	Spokane	Washington	4915723366012012	e5c4ba6744a4328a052497ca520a366a	JCB 16 digit	47.7296435412257907	-117.354403436965498
5727	2019-11-23 01:21:30	2019-11-23	Lidia West	lidia.west@woohoo.com	Fairfield	California	4375555212053037	b35ca7987560baabf69b0e75d8f090ad	JCB 15 digit	38.1943042014848473	-122.110451816860959
5728	2019-11-23 01:22:24	2019-11-23	Claudius Tromp	claudius.tromp@warmmail.com	Oakland	California	676272876095182	7943c804edeb6bd70e63cdb100ea12eb	VISA 16 digit	37.7997063250988461	-122.254673690261583
5729	2019-11-23 01:27:13	2019-11-23	Ciara Hilpert	ciara.hilpert@geemail.com	San Francisco	California	3112715201370361404	ff53c750932c8eb81a88e9609f074abf	Discover	37.7790296440777453	-122.442684994093469
5730	2019-11-23 01:40:01	2019-11-23	Bentley Oberbrunner	bentley.oberbrunner@warmmail.com	Salinas	California	3337530156068339273	de584c5272b6d46e2760299aacb50b59	VISA 16 digit	36.7137164159443188	-121.666122260334717
5731	2019-11-23 01:57:47	2019-11-23	Glendora Rath	glendora.rath@warmmail.com	Oxnard	California	52476335650613552	1f996deee809b0b1269ab3ee64c64504	American Express	34.1703216358508897	-119.238634552285447
5732	2019-11-23 02:10:48	2019-11-23	Ferd Swaniawski	ferd.swaniawski@woohoo.com	San Francisco	California	3096317829947044996	e246c6a315794c86eb63c62d887b0fc4	Mastercard	37.7801316182405387	-122.451444464706086
5733	2019-11-23 02:25:50	2019-11-23	Miss Arabella Kihn	miss.arabella.kihn@geemail.com	Oakland	California	3014251187927475	929b2c1845f9ff89e7abea705aa7c43e	Mastercard	37.7709040542273513	-122.307089313791678
5734	2019-11-23 02:42:02	2019-11-23	Anwar Murazik	anwar.murazik@geemail.com	North Las Vegas	Nevada	52422456105812360	c715becd76b2af81191d2818698d6996	Diners Club / Carte Blanche	36.3384284242212772	-115.039239487586173
5735	2019-11-23 03:14:05	2019-11-23	Areli Beer DDS	areli.beer.dds@geemail.com	Portland	Oregon	4501109362076	cbedba4b40e57105463f0e90e754ce2d	VISA 13 digit	45.4579310872480278	-122.646887606522071
5736	2019-11-23 03:23:19	2019-11-23	Earline Wiegand-Wolff	earline.wiegand.wolff@warmmail.com	San Francisco	California	210092406547900892	681bb58cded0eef83b80a27417659f80	VISA 16 digit	37.7834398601019075	-122.425484538822971
5737	2019-11-23 03:39:32	2019-11-23	Marcella King	marcella.king@warmmail.com	Salt Lake City	Utah	675944164860668	2096b01f8f9645aace4c7641776c73af	Diners Club / Carte Blanche	40.7365065744757615	-111.946389817534012
5738	2019-11-23 04:51:02	2019-11-23	Marcell Bogisich	marcell.bogisich@geemail.com	San Francisco	California	180047081975707956	119a5f7088ab14c57d4dee5fc3822b4d	JCB 16 digit	37.7799354835913164	-122.42661395596042
5739	2019-11-23 05:06:53	2019-11-23	Doloris Wisoky	doloris.wisoky@woohoo.com	Denver	Colorado	3726714898340332	f432ba006a5243606b19b92c74153fc8	Diners Club / Carte Blanche	39.7994999962910967	-104.93207256875597
5740	2019-11-23 06:22:27	2019-11-23	Mr. Ebb Torphy IV	mr.ebb.torphy.iv@geemail.com	Houston	Texas	676118235985399	0b3f0c172327240e9dcb1deb7d555288	JCB 15 digit	29.8402025166511535	-95.402715452063461
5741	2019-11-23 06:34:16	2019-11-23	Syble Stroman	syble.stroman@geemail.com	Plano	Texas	3059421328625099	2b8fb0d60a893bbbcad3cf6d90a9fe91	JCB 15 digit	33.0478889776013816	-96.6634861222650841
5742	2019-11-23 06:45:06	2019-11-23	Alto Streich-Kreiger	alto.streich.kreiger@warmmail.com	Denver	Colorado	869965105561913657	5317b1a7fb377190930d47070fcb34a2	Voyager	39.7078635180886792	-104.854435767490799
5743	2019-11-23 06:58:46	2019-11-23	Mrs. Destiney Emmerich DVM	mrs.destiney.emmerich.dvm@woohoo.com	Waterbury	Connecticut	3158189665102856328	29ecc2dc9a179e4e0bbe4a5deb8f22c8	VISA 16 digit	41.5325774071775413	-73.0434083074711253
5744	2019-11-23 07:01:52	2019-11-23	Aubra Huel	aubra.huel@geemail.com	Spokane	Washington	3528181350532433679	06fa7d9386a3eb91a2105a1bbca75583	American Express	47.7661314090486613	-117.342917855399847
5745	2019-11-23 07:24:57	2019-11-23	Harrold Dickens	harrold.dickens@woohoo.com	San Francisco	California	4100001327798	d1bd7f4b1860355bff29effc960266f4	VISA 16 digit	37.7941895521992777	-122.420861150879944
5746	2019-11-23 07:39:07	2019-11-23	Kesha Bernier	kesha.bernier@geemail.com	Clarksville	Tennessee	4700402018498	5f4ceff5b441f718f782142fb1ddca51	VISA 16 digit	36.5776091801129297	-87.4210476428222023
5747	2019-11-23 07:54:08	2019-11-23	Kenji Romaguera	kenji.romaguera@geemail.com	Toledo	Ohio	53081071344356947	98992719442576f57fcc31279eeac232	VISA 13 digit	41.7311852396171545	-83.5779228453856007
5748	2019-11-23 07:59:34	2019-11-23	Malakai Christiansen II	malakai.christiansen.ii@geemail.com	San Francisco	California	3096734666316420828	6aad200d8b00328beda739ce75d769a0	Mastercard	37.8067821806020348	-122.390621289017858
5749	2019-11-23 08:07:12	2019-11-23	Theda Rodriguez MD	theda.rodriguez.md@geemail.com	Los Angeles	California	4814003797934288	2ee4e29e56d757d2520f73e44bd943c7	JCB 15 digit	34.1024591744743262	-118.342518285474924
5750	2019-11-23 09:09:11	2019-11-23	Coretta Rempel	coretta.rempel@geemail.com	New York	New York	4209750564497831	22609a5d9416b94e4c8814faf74df329	JCB 15 digit	40.5700239511895902	-73.9044569963950693
5751	2019-11-23 09:40:45	2019-11-23	Donal Simonis	donal.simonis@geemail.com	Boise	Idaho	3112609571428701945	227772236c1929b8f9cbf2acfff0389b	American Express	43.6001907223973433	-116.259251507251335
5752	2019-11-23 09:41:07	2019-11-23	Halie Weimann-Emmerich	halie.weimann.emmerich@woohoo.com	New York	New York	4078585009432466	9d61ce63723e0f41ad4017b87075214a	Discover	40.5929757492374605	-73.9736043866619468
5753	2019-11-23 10:51:48	2019-11-23	Raiden Feeney-Rowe	raiden.feeney.rowe@geemail.com	Oakland	California	6011165525634969346	06608a93e6c2131e9f2876c97a1fb0a9	VISA 13 digit	37.8253348814664108	-122.246550055885649
5754	2019-11-23 11:06:21	2019-11-23	Rico Klein	rico.klein@warmmail.com	Minneapolis	Minnesota	3001992014023276	fda8a32f09c6b0007954d2cc627b586f	American Express	45.0607730407819105	-93.1818584564413896
5755	2019-11-23 11:26:12	2019-11-23	Stonewall Welch DVM	stonewall.welch.dvm@geemail.com	Garland	Texas	3528741002353215445	96c5d38a17811caad2d67c26ee74800b	Mastercard	32.844507362297918	-96.7104342774648273
5757	2019-11-23 12:00:53	2019-11-23	Dudley Lehner	dudley.lehner@geemail.com	Toledo	Ohio	3528601898117951210	0ec3a21d39e2e696377a3cdd803927a3	Discover	41.591002374671767	-83.5299825459584611
5758	2019-11-23 12:28:34	2019-11-23	Dr. Burr Mante	dr.burr.mante@geemail.com	San Francisco	California	6011567393407229511	d65ee238746b09521197f4f7601d6d2f	Diners Club / Carte Blanche	37.7772276033996803	-122.490749483525533
5759	2019-11-23 12:47:26	2019-11-23	Sonja Nader	sonja.nader@geemail.com	Colorado Springs	Colorado	3528769040773157646	1a794b7545688ece67a5b02b55b5ef8d	VISA 16 digit	38.8313591935254649	-104.756351683630427
5760	2019-11-23 13:24:40	2019-11-23	Dr. Monte Swaniawski IV	dr.monte.swaniawski.iv@geemail.com	San Francisco	California	4136804684631700	8755e1c77227d9025f541225fa79562c	Voyager	37.7861260090716442	-122.477914057795118
5761	2019-11-23 13:37:44	2019-11-23	Amelie Murazik	amelie.murazik@geemail.com	San Francisco	California	4682743716443841	b89e2d4c0878d5b31385f5e654ecebc2	VISA 13 digit	37.758063609273357	-122.426512010645453
5762	2019-11-23 13:52:42	2019-11-23	Theodosia Stracke-Marks	theodosia.stracke.marks@geemail.com	New York	New York	6011136850144700387	4380e79d739ceee08ddb28161b5e9f17	VISA 16 digit	40.5915024456791542	-73.9218057402305249
5763	2019-11-23 14:13:30	2019-11-23	Dr. Tressie Schaden	dr.tressie.schaden@geemail.com	Lubbock	Texas	869994273815569264	00df78228b9e724c5b2b19a72fca46af	Discover	33.5607284619979609	-101.96410803421476
5764	2019-11-23 14:33:26	2019-11-23	Kirby Nolan	kirby.nolan@geemail.com	San Francisco	California	6011219472978762829	2726464035b0002b7677eae0172e9b71	Diners Club / Carte Blanche	37.7511409289352073	-122.445930320450145
5765	2019-11-23 14:48:14	2019-11-23	Arlyn Volkman-Altenwerth	arlyn.volkman.altenwerth@warmmail.com	San Francisco	California	4099009303985	c09b39c98c057cc121dd5263e16bdd6f	American Express	37.7741602475379423	-122.404533760792987
5766	2019-11-23 15:00:14	2019-11-23	Marla Bogisich	marla.bogisich@geemail.com	Laredo	Texas	869992463841839425	5ae0a5334b8bc87f6bf7e48e2d89a1c4	Diners Club / Carte Blanche	27.4736013169582947	-99.3895454454708869
5767	2019-11-23 15:37:43	2019-11-23	Diana Herzog DVM	diana.herzog.dvm@geemail.com	Fresno	California	6011025393975066036	3b0fc1e9db018075490efe96c61a3ff8	VISA 13 digit	36.7187682130247381	-119.701819766835868
5768	2019-11-23 16:00:41	2019-11-23	Tena Bergstrom	tena.bergstrom@geemail.com	Frisco	Texas	4091632759600	2ff1944a60dc25502a5ce5baeb4ffab3	Diners Club / Carte Blanche	33.2291472989596457	-96.7759809819724381
5769	2019-11-23 16:01:25	2019-11-23	Dr. Vinie Collier	dr.vinie.collier@geemail.com	Louisville	Kentucky	3337368371484388492	8c0a905fc019f435892bfb18df5a662e	JCB 16 digit	38.1793480336569218	-85.6541169414833234
5770	2019-11-23 16:12:06	2019-11-23	Beryl Frami	beryl.frami@woohoo.com	San Francisco	California	180012338880077276	bbed5e5c4066ab8cc3b15760a1d837ea	American Express	37.7826111000506515	-122.426269517767338
5771	2019-11-23 16:30:47	2019-11-23	Rollie Heaney	rollie.heaney@warmmail.com	New Orleans	Louisiana	3158294396590692965	54d815fdcea700390efcad3a45594c4a	Voyager	30.1234706486590191	-89.9238781001213994
5772	2019-11-23 16:47:12	2019-11-23	Perla Schowalter	perla.schowalter@woohoo.com	Albuquerque	New Mexico	180024230407310817	3c38803c5804b88bb222c55d4b22a7a5	VISA 13 digit	35.0462045114155885	-106.689872041957088
5773	2019-11-23 16:47:47	2019-11-23	Elliana Bailey	elliana.bailey@geemail.com	Rialto	California	3020456411109188	cb0ea8829ae066d6e1f3f67dc53b1edd	Diners Club / Carte Blanche	34.2040153781633833	-117.362048415522281
5774	2019-11-23 16:56:03	2019-11-23	Rena Zulauf	rena.zulauf@geemail.com	Miami	Florida	4297516660554	e1dfc828a516a0de268f2e513c06f4cc	Diners Club / Carte Blanche	25.8506625341854992	-80.2782494875941524
5775	2019-11-23 16:58:24	2019-11-23	Jody Koelpin	jody.koelpin@woohoo.com	Mesa	Arizona	3452295746197964	80bf3166f89c9e94edd4eb5f842dfe58	VISA 16 digit	33.4440871799509978	-111.681013529037685
5776	2019-11-23 17:21:58	2019-11-23	Amparo Lockman	amparo.lockman@geemail.com	New York	New York	3729046792319022	c678990a10fa0801ac21009d3b67577c	Maestro	40.59355881127901	-73.9996453785233115
5777	2019-11-23 17:49:49	2019-11-23	Florida Kessler	florida.kessler@geemail.com	San Diego	California	3006331840176625	382a64f7b14162a4c962888dbf44f341	Diners Club / Carte Blanche	32.8008349448975167	-117.184669800885032
5778	2019-11-23 17:56:48	2019-11-23	Danika Jacobson DVM	danika.jacobson.dvm@geemail.com	Lexington	Kentucky	4250026426973543	9b1e0a44be3a9f61a94439b9937c263d	VISA 16 digit	37.9733884872745762	-84.3811203773032759
5779	2019-11-23 17:58:03	2019-11-23	Catherine Schaden DVM	catherine.schaden.dvm@geemail.com	San Francisco	California	4365045559291251	4eddc6d1addf434ad60e40fe1a626130	VISA 16 digit	37.7717561912860376	-122.400586722632923
5780	2019-11-23 18:03:35	2019-11-23	Vernia Hackett	vernia.hackett@geemail.com	San Francisco	California	180027719074217047	5d3624611452f2c46423e0d8ca0938f7	Mastercard	37.7218600420569601	-122.439793826997047
5781	2019-11-23 18:09:46	2019-11-23	Sheryll Jaskolski	sheryll.jaskolski@geemail.com	Baton Rouge	Louisiana	4807988527006	8d01e63318034823b1993fd84541e07e	JCB 15 digit	30.4050085367381584	-91.2002530424032329
5782	2019-11-23 18:32:21	2019-11-23	Metta Reichel	metta.reichel@woohoo.com	Berkeley	California	869961649725433973	b9a9783bc6ca74ca92d799fb69ca846d	VISA 13 digit	37.8764933989724284	-122.26033955063707
5783	2019-11-23 19:09:33	2019-11-23	Cierra Lind DDS	cierra.lind.dds@geemail.com	San Francisco	California	3022621980925516	32a0c6e9b8817b37eaaedc0fae0eac2c	JCB 16 digit	37.78490785896701	-122.43217061253192
5784	2019-11-23 19:38:43	2019-11-23	Moshe Padberg	moshe.padberg@geemail.com	San Francisco	California	210053787675193716	63e2a4e9761d02dc2c6cd781c13c2c2b	JCB 16 digit	37.7591774621338701	-122.396207131412098
5785	2019-11-23 20:37:41	2019-11-23	Exa Abernathy MD	exa.abernathy.md@geemail.com	Hollywood	Florida	4864578049601347	f4632e0cffdd1a80339f0ceb718c7e27	JCB 15 digit	26.1241705256458374	-80.1793900896146852
5786	2019-11-23 20:54:40	2019-11-23	Ariana Grimes	ariana.grimes@geemail.com	Newark	New Jersey	869984990900016933	cf47aea39715532e7eca49d6ffdc818d	JCB 16 digit	40.6785281198944944	-74.1540116471447135
5787	2019-11-23 21:19:53	2019-11-23	Cory Wehner	cory.wehner@warmmail.com	Mobile	Alabama	3018067820944743	ca281ce52fb074e7157bfd467b0adb58	JCB 16 digit	30.5805808830182997	-88.0717207459870792
5788	2019-11-23 21:46:41	2019-11-23	Dr. Benny Deckow	dr.benny.deckow@geemail.com	Kansas City	Missouri	180009518174967275	4cab3ad0791a4b40d23d4439d438ef65	VISA 16 digit	39.0362187976785009	-94.6161509995572345
5789	2019-11-23 22:04:34	2019-11-23	Penny Cartwright	penny.cartwright@geemail.com	Palmdale	California	4260482138920553	40bf40f66030a0be70bb327161fcff38	VISA 16 digit	34.5549737201388965	-118.138581632310149
5790	2019-11-23 22:14:35	2019-11-23	Georgiann Mills	georgiann.mills@geemail.com	San Francisco	California	503802441997513	821c9fc6a0467c35fe904a952fdfbe6b	JCB 16 digit	37.7965030683635135	-122.436084184299744
5791	2019-11-23 22:31:58	2019-11-23	Cornelius Anderson	cornelius.anderson@woohoo.com	Phoenix	Arizona	4221085443234	4b88a362bf3d6569375d682fd0d2b917	JCB 16 digit	33.5917080835837893	-112.002966749661056
5792	2019-11-23 22:50:27	2019-11-23	Achsah Runte	achsah.runte@geemail.com	New York	New York	4102703904395	f2bc8a4cf1805a66f177024596c101d9	JCB 15 digit	40.731384328076615	-74.0134048772871438
5793	2019-11-23 22:50:32	2019-11-23	Alphonsus Sporer-Stroman	alphonsus.sporer.stroman@geemail.com	Rochester	New York	4008825937678	3c9ce97747a24cf2fc49f5563437e85e	American Express	43.2329615948699413	-77.5430725642252696
5794	2019-11-23 23:14:04	2019-11-23	Mrs. Winnifred Bartell	mrs.winnifred.bartell@geemail.com	Rochester	Minnesota	3528482539176705238	631b6e11115fc6d9ae531cdd3f83a5f3	Diners Club / Carte Blanche	44.1101423049714398	-92.4845040261399021
5795	2019-11-23 23:21:57	2019-11-23	Dr. Savon Kub	dr.savon.kub@geemail.com	San Francisco	California	3112864130295591275	9810b13546239d24050ddfe579851cc7	Maestro	37.7863107580717283	-122.441205446963039
5796	2019-11-23 23:32:23	2019-11-23	Domenic Rau	domenic.rau@geemail.com	Wilmington	North Carolina	180033967894066118	ad54a552689da8ac9cc64745216ade31	VISA 16 digit	34.1356338850043741	-77.9091560528606237
5797	2019-11-24 01:23:04	2019-11-24	Tisa Morissette	tisa.morissette@geemail.com	Chicago	Illinois	869953349572381041	261c6f584f6a8cc2d244aebd2c12cea3	JCB 15 digit	41.9140303430914898	-87.7159917162295386
5798	2019-11-24 02:10:10	2019-11-24	Faustino Cassin	faustino.cassin@geemail.com	San Francisco	California	4653751146608060	665bfc65b084886af0115461f5aec437	VISA 16 digit	37.7995775541814965	-122.441851109120762
5799	2019-11-24 02:18:51	2019-11-24	Nancy Willms	nancy.willms@warmmail.com	San Francisco	California	4890346155132	1dc970a03405c2156cfa3b4b09415c76	American Express	37.7537435516269255	-122.42642162427191
5800	2019-11-24 02:34:47	2019-11-24	Keesha Goodwin	keesha.goodwin@geemail.com	Detroit	Michigan	869977366866511184	2395fc99efd5650d523c7d18e9c4bc07	VISA 16 digit	42.3817021019216682	-83.0185657007738911
5801	2019-11-24 02:45:57	2019-11-24	Beckett Ziemann	beckett.ziemann@woohoo.com	Sacramento	California	55312217615681338	e51ccafa31b0923d02e4961bc2304ee3	VISA 13 digit	38.5515328073207328	-121.407334952034418
5802	2019-11-24 02:47:52	2019-11-24	Juelz Lueilwitz Jr.	juelz.lueilwitz.jr.@geemail.com	San Francisco	California	53525198844938843	7dbfd6141c4bac7d59d1c8107acba2ac	Maestro	37.7907151693202508	-122.428382135089649
5803	2019-11-24 03:09:57	2019-11-24	Lonzo Considine	lonzo.considine@geemail.com	Tempe	Arizona	3793060728277130	05ec0f5733ea5e2f60d6c12ac1f9847e	JCB 16 digit	33.374692757466434	-111.874606047992771
5804	2019-11-24 03:48:21	2019-11-24	Dr. Trayvon Satterfield	dr.trayvon.satterfield@geemail.com	Chula Vista	California	869967031974016102	1d2780b3ec0f4755362b243e19a9bbbb	JCB 16 digit	32.6488191141046542	-116.971099547645821
5805	2019-11-24 03:59:30	2019-11-24	Ms. Taylor Greenfelder DDS	ms.taylor.greenfelder.dds@geemail.com	Evansville	Indiana	54918560403407400	67db63b9123022b40531a6cbcb94ead1	VISA 13 digit	38.0290032932206969	-87.5629660329714454
5806	2019-11-24 04:10:49	2019-11-24	Dr. Beau Leannon Jr.	dr.beau.leannon.jr.@geemail.com	San Diego	California	501888802670542	37a37ab615b3e5e550fcde5b29c79efb	VISA 16 digit	32.7899923088561778	-117.136903355307879
5807	2019-11-24 05:33:03	2019-11-24	Malvina Rohan	malvina.rohan@warmmail.com	Oakland	California	6011071324470021328	4ce7414d5f92cef2238bbbb290bf0bd3	VISA 16 digit	37.798746813404243	-122.276077754826119
5808	2019-11-24 05:44:33	2019-11-24	Luvinia Nikolaus	luvinia.nikolaus@geemail.com	San Francisco	California	3088519995228992603	5862f6a7bcfe2fa2b1d607d8010abf66	JCB 16 digit	37.740090225960607	-122.424497616861743
5809	2019-11-24 06:04:21	2019-11-24	Bunk Cassin	bunk.cassin@geemail.com	Santa Rosa	California	180029198836695634	8d1797ee6774408e5959fb5b34eee939	Maestro	38.4765440707683624	-122.734252294829489
5810	2019-11-24 06:20:08	2019-11-24	Dr. Burgess Ratke MD	dr.burgess.ratke.md@geemail.com	Arlington	Texas	6011535189299813480	d7bd55340438f574031787a40a70374e	JCB 16 digit	32.6223434275265731	-97.1881529111906985
5811	2019-11-24 06:50:31	2019-11-24	Mrs. Tamisha Rosenbaum DVM	mrs.tamisha.rosenbaum.dvm@geemail.com	San Francisco	California	869964404105858036	cde12b6e9367d245315b0eb80044cd0c	Discover	37.7836160158848884	-122.458345483459851
5812	2019-11-24 06:55:24	2019-11-24	Dr. Colvin Konopelski	dr.colvin.konopelski@woohoo.com	San Francisco	California	3158777961892283551	bfba68b7e24b956a52f8d0385778cc5c	American Express	37.7982231085873721	-122.461627476946816
5813	2019-11-24 06:56:48	2019-11-24	Madilyn Kuhlman	madilyn.kuhlman@warmmail.com	Oakland	California	060477811801321	4deab3acf4c385604b89ec3d75249ef7	VISA 16 digit	37.7720106192627583	-122.268273467965471
5814	2019-11-24 07:39:01	2019-11-24	Mr. Deric Lesch DDS	mr.deric.lesch.dds@geemail.com	Chicago	Illinois	6011678925234246667	a6dc0f0ffdbc1dc14d29d6782a23cdf7	VISA 16 digit	41.8729102139197309	-87.6971591360896809
5815	2019-11-24 08:17:02	2019-11-24	Madison Blanda DDS	madison.blanda.dds@geemail.com	Visalia	California	180097609451549325	c6945816b992e2d63822eb623c438fbd	Mastercard	36.3516956372607538	-119.259992289648949
5816	2019-11-24 08:21:05	2019-11-24	Makai Jerde-Schiller	makai.jerde.schiller@woohoo.com	Berkeley	California	4107292104653	3edcc90993286301196abedf39257183	VISA 16 digit	37.8629850448519534	-122.303580531213484
5817	2019-11-24 08:45:30	2019-11-24	Orma Hamill	orma.hamill@woohoo.com	Houston	Texas	210060036816848445	58ba47537473d567cb25565b023e07a9	JCB 16 digit	29.796835472628846	-95.3057198180366356
5818	2019-11-24 08:56:29	2019-11-24	Ozell Considine-Schuppe	ozell.considine.schuppe@woohoo.com	Memphis	Tennessee	869938786445327240	9871695f4edecc540c05c21d3cf253a1	JCB 16 digit	35.164790529531615	-90.018298812422529
5819	2019-11-24 08:58:35	2019-11-24	Jann Eichmann	jann.eichmann@woohoo.com	Independence	Missouri	3700667777250206	1d6951f6b4c25626e67475ce07588e6a	Maestro	39.0185690487287999	-94.3019286750167538
5820	2019-11-24 10:47:19	2019-11-24	Thad Boyer	thad.boyer@geemail.com	San Francisco	California	3492680032469817	8e755540e8febc4439d10141d6a1fdf4	JCB 16 digit	37.7783813073209274	-122.449334970734114
5821	2019-11-24 11:16:53	2019-11-24	Bliss Kshlerin	bliss.kshlerin@geemail.com	Thousand Oaks	California	501854210483951	4c59a07158c932ebe9b630b5a7c761a4	JCB 15 digit	34.2700140028998277	-118.807034560796623
5822	2019-11-24 11:49:19	2019-11-24	Lynn Nicolas MD	lynn.nicolas.md@geemail.com	New York	New York	4990530862921	d79da30100ca610dbc0765b33187dbf4	Diners Club / Carte Blanche	40.6710613053515573	-74.0126533764310182
5823	2019-11-24 11:49:36	2019-11-24	Ainsley Quigley	ainsley.quigley@geemail.com	Raleigh	North Carolina	4810346806153	4dae117688ec265ffb16f622fb34d828	JCB 15 digit	35.7818270703911736	-78.6877842177107993
5824	2019-11-24 12:17:37	2019-11-24	Miss Alana Wilkinson	miss.alana.wilkinson@geemail.com	San Francisco	California	3055562022798072	bb6b3b6b740013141ea269ca764d475e	JCB 15 digit	37.7574273647982679	-122.40871252800018
5825	2019-11-24 12:26:30	2019-11-24	Jarrod Bashirian	jarrod.bashirian@geemail.com	Berkeley	California	52933708389006420	ff5fe6649241ecca45c764e7269cf3fb	VISA 16 digit	37.8695374347045259	-122.239898477564466
5826	2019-11-24 12:26:36	2019-11-24	Tremaine Adams	tremaine.adams@woohoo.com	Berkeley	California	869951507457924126	e503bed74e16e79d622949a3fd938118	JCB 16 digit	37.829916383975835	-122.282704273626607
5827	2019-11-24 12:31:54	2019-11-24	Robt Wehner Jr.	robt.wehner.jr.@geemail.com	Long Beach	California	3460465766072823	36804a67dc6eddad96ae851ddeac2593	VISA 16 digit	33.7287455181878002	-118.055678156965598
5828	2019-11-24 12:54:07	2019-11-24	Sandi O'Reilly	sandi.o'reilly@woohoo.com	San Francisco	California	4961370046440388	3a4c66284c8e9a6ccf747a03d4cf7a42	Voyager	37.7767216914852426	-122.442913408685698
5829	2019-11-24 12:55:23	2019-11-24	Tyrell Jones	tyrell.jones@woohoo.com	Oakland	California	869986615533125771	a9e130115333c4e955d6e14e963107c6	Maestro	37.8535268877323148	-122.264429144569149
5830	2019-11-24 13:44:05	2019-11-24	Zara Hoeger	zara.hoeger@woohoo.com	Tempe	Arizona	869921508484356156	391ae6f26cc158b9c957fb02c8b6fc47	Mastercard	33.4100777668800148	-111.892871712383993
5831	2019-11-24 13:48:09	2019-11-24	Chancey Shanahan PhD	chancey.shanahan.phd@warmmail.com	Renton	Washington	4499616184795277	9d4b967fe4f66437401cb6c3c4329ee4	JCB 15 digit	47.3872792689189311	-122.209539251083498
5832	2019-11-24 14:01:01	2019-11-24	Oleta Klocko	oleta.klocko@woohoo.com	San Francisco	California	3787675607786352	033d7cb9f6b68c5137a1bbd9570c5d75	Diners Club / Carte Blanche	37.7777172102167356	-122.464827667448489
5833	2019-11-24 14:05:43	2019-11-24	Elizbeth Koch-Blanda	elizbeth.koch.blanda@geemail.com	St. Petersburg	Florida	180059598182836059	a449e19e2165452fb85925295f53b0af	VISA 16 digit	27.7743379801400003	-82.5833216987442142
5834	2019-11-24 14:08:31	2019-11-24	Reyna Anderson PhD	reyna.anderson.phd@woohoo.com	Los Angeles	California	3112085046599780187	bc1bfec2fca8157eec2c3629afb0c3cc	Maestro	33.9646290804125357	-118.467579010407619
5835	2019-11-24 14:22:30	2019-11-24	Cristofer Kuvalis	cristofer.kuvalis@geemail.com	Salem	Oregon	4558233293876515	37157292be942f7ac0e8bc7c02c9e384	JCB 16 digit	44.9799201848253603	-122.981080803802982
5836	2019-11-24 15:05:23	2019-11-24	Clementina Gorczany-Goodwin	clementina.gorczany.goodwin@geemail.com	San Francisco	California	4387757816582579	8853a41a5dc8e1b83ea716ef4ef974a3	Maestro	37.7635056331996992	-122.422308071266784
5837	2019-11-24 15:09:33	2019-11-24	Ms. Stephany Reynolds	ms.stephany.reynolds@woohoo.com	Los Angeles	California	4140576480748433	768f3d861a883535a0b5f19453384b42	Mastercard	34.0824857583135312	-118.386157283651826
5838	2019-11-24 16:38:54	2019-11-24	Mr. Randel Wintheiser	mr.randel.wintheiser@geemail.com	Inglewood	California	54204744597969564	06eb7b4e0dc9685bd4dee6b5b44aa1f6	JCB 16 digit	34.0538405840996674	-118.410123794575412
5839	2019-11-24 16:50:48	2019-11-24	Dr. Erich Kerluke PhD	dr.erich.kerluke.phd@geemail.com	San Francisco	California	3337731103100787025	0c76efc34a1ad7c4964a05cade0e77ad	Mastercard	37.7037749966447819	-122.407726723941579
5840	2019-11-24 18:13:32	2019-11-24	Dr. Connie Quigley	dr.connie.quigley@geemail.com	New York	New York	3158643168883144105	4e3afc501999bf400846eee7e3ecf9f4	Diners Club / Carte Blanche	40.5650847101341938	-73.9868333536095832
5841	2019-11-24 18:36:00	2019-11-24	Carlisle Hagenes IV	carlisle.hagenes.iv@woohoo.com	Anchorage	Alaska	676238584394175	a5b15eaff96facedfae7d8f04e3bcc78	Discover	61.1634243938822308	-149.255353712628789
5842	2019-11-24 18:36:39	2019-11-24	Rayan Weimann	rayan.weimann@geemail.com	Los Angeles	California	3337010037982974461	a90bf232fff4e97a919d03c7e65abea9	American Express	34.1166423854283991	-118.332160444603488
5843	2019-11-24 18:45:50	2019-11-24	Tess Moen	tess.moen@warmmail.com	Pearland	Texas	869973466967355657	1bbc72b07bf69f5612b6b76b6e42f0c0	VISA 13 digit	29.6207920220952481	-95.2746775075647889
5844	2019-11-24 18:53:00	2019-11-24	Emery Breitenberg	emery.breitenberg@warmmail.com	Chicago	Illinois	3158064255870100172	dfcd3a65f84f44d0d12b6bd15ab87306	Mastercard	41.9304688185289507	-87.7186639112450166
5845	2019-11-24 18:58:21	2019-11-24	Olen Harris I	olen.harris.i@geemail.com	New York	New York	53797867245861181	6fd65d5237e7c70e98ebab65f330b42c	JCB 16 digit	40.5779837929867213	-73.9664642414439442
5846	2019-11-24 19:30:07	2019-11-24	Ms. Hali Botsford	ms.hali.botsford@geemail.com	New York	New York	52219876521162024	643c174ef9c7d7c46555008d730c91f7	Discover	40.5779007656257562	-73.9366599484242499
5847	2019-11-24 19:59:49	2019-11-24	Emerson O'Keefe	emerson.o'keefe@geemail.com	Oklahoma City	Oklahoma	4557882520562669	36a4285323f63a58dff216493847c914	VISA 13 digit	35.526083008423825	-97.5835895229492394
5848	2019-11-24 20:00:19	2019-11-24	Mr. Babe Dibbert	mr.babe.dibbert@warmmail.com	Los Angeles	California	3713232344153998	150a4eb0af89b5c1c3a3ca1e8d1891b6	JCB 16 digit	34.0842367022164154	-118.335640435944498
5849	2019-11-24 20:33:43	2019-11-24	Mac Kling	mac.kling@geemail.com	San Francisco	California	3112878885091545411	412292b6980c273922066a9b3714b9b1	Discover	37.7867943818633236	-122.42375111580813
5850	2019-11-24 20:36:17	2019-11-24	Ruben Vandervort Sr.	ruben.vandervort.sr.@geemail.com	Tulsa	Oklahoma	869977423180592760	3b6062c4dd34a5363cb7c53b2f4dccee	JCB 16 digit	36.1556934244368193	-95.8629966623570766
5851	2019-11-24 20:46:43	2019-11-24	Dr. Alberta Jast	dr.alberta.jast@woohoo.com	Santa Rosa	California	210097280315568214	dfde4968f1c7a49260fc700a4bd13db9	Voyager	38.5342701742548499	-122.75579780724496
5852	2019-11-24 20:48:41	2019-11-24	Mr. Kirk Swaniawski	mr.kirk.swaniawski@geemail.com	San Francisco	California	3040617670011916	c0a8d2d607124438fcebccc4fa403b30	VISA 16 digit	37.7757959440562558	-122.432382817536251
5853	2019-11-24 22:04:49	2019-11-24	Ruthe Harvey	ruthe.harvey@geemail.com	Berkeley	California	55521898007026773	5690ae71eebee595f5629ff40d3d2cc9	JCB 16 digit	37.8941623834709844	-122.259479717578898
5854	2019-11-24 22:20:11	2019-11-24	Mr. Kiyoshi Streich	mr.kiyoshi.streich@warmmail.com	Nashville	Tennessee	3057129445828205	e5f290bd21386edcc21d9fd8f24d919a	American Express	36.2451611881732916	-86.7009362985752432
5855	2019-11-24 23:57:31	2019-11-24	Carlene Harber	carlene.harber@geemail.com	Charlotte	North Carolina	3721806616219510	e2ebd23cf7e03e3964f14bf7ccaad164	JCB 15 digit	35.1771610494490687	-80.8360747050903825
5856	2019-11-24 23:57:42	2019-11-24	Emerson Wilderman	emerson.wilderman@warmmail.com	Berkeley	California	4516607063532088	ffe47099eaa04278819310b14279f7f1	Discover	37.8387298166361248	-122.283803500257051
5857	2019-11-25 00:34:36	2019-11-25	Augustine Ankunding	augustine.ankunding@geemail.com	San Francisco	California	4342924355627	91efe64f0b03838da74ac008e6264dd9	JCB 15 digit	37.7616784842117568	-122.426282360749312
5858	2019-11-25 00:34:39	2019-11-25	Dr. Risa Nikolaus MD	dr.risa.nikolaus.md@geemail.com	San Francisco	California	4113700643937179	d6336a0969370c496ae464dec228a7bd	American Express	37.7588049387460742	-122.455483473843017
5859	2019-11-25 01:33:22	2019-11-25	Miss Madison Wolff DDS	miss.madison.wolff.dds@geemail.com	San Francisco	California	3112578827292601398	ceb974c097cd997a0548b6d06bfd9991	American Express	37.7628522570171157	-122.447332743750309
5860	2019-11-25 01:37:42	2019-11-25	Dr. Ali Stroman	dr.ali.stroman@woohoo.com	Daly City	California	869943629541596610	9f1ac9ecf19e3ed02bd90b185ad41e46	Maestro	37.6139745514761614	-122.391356818061325
5861	2019-11-25 02:06:02	2019-11-25	Audra Monahan	audra.monahan@geemail.com	New York	New York	4392142744169	ece0a606d895618cbe2dcb2f871acbeb	Mastercard	40.6828154229316823	-73.8651405502472045
5862	2019-11-25 02:53:59	2019-11-25	Chauncey Kuphal II	chauncey.kuphal.ii@geemail.com	San Francisco	California	869952587468867091	b035bcd27eff5268595038ded93b6814	VISA 16 digit	37.795410220754583	-122.486752588217158
5863	2019-11-25 02:54:13	2019-11-25	Dr. Darryl Bergstrom	dr.darryl.bergstrom@warmmail.com	New York	New York	53926660488886567	7179239912304bb633910b7090ff54d7	JCB 16 digit	40.7253208303581928	-73.9536635276757153
5864	2019-11-25 03:17:52	2019-11-25	Lucien Bins PhD	lucien.bins.phd@geemail.com	Coral Springs	Florida	3088829162469303082	2a41c6c840acb7dc45be324bb0af459e	VISA 13 digit	26.3193134762875758	-80.216972221213581
5865	2019-11-25 04:23:23	2019-11-25	Luanne Rempel	luanne.rempel@geemail.com	Santa Rosa	California	869973880955809717	9b4b188817c6f931d4c12dbe24e393d4	VISA 16 digit	38.5360001186497527	-122.707454798860851
5866	2019-11-25 04:33:29	2019-11-25	Emile Schneider-Farrell	emile.schneider.farrell@geemail.com	San Francisco	California	3041532555937078	f1f3a29fa5a035c52ae0d6eaf4058f7b	JCB 16 digit	37.7974623192744517	-122.448372340012867
5867	2019-11-25 04:46:38	2019-11-25	Kenton Reichel-Romaguera	kenton.reichel.romaguera@geemail.com	Wichita Falls	Texas	4446741625728770	7f413405dd9d89dc4d6385366928655e	Voyager	33.8371354284889989	-98.5373767454564558
5868	2019-11-25 04:46:56	2019-11-25	Euna Thompson	euna.thompson@warmmail.com	Fresno	California	869940824682781732	3a2e40eed1c9f45327a01e55ca6d40d1	Maestro	36.8577549795959172	-119.748776659007746
5869	2019-11-25 05:30:57	2019-11-25	Clevie Spencer-Zemlak	clevie.spencer.zemlak@geemail.com	San Francisco	California	3112787387663273779	113508da0a6446175468a014d2ca3854	VISA 16 digit	37.7518899325217916	-122.418460822655362
5870	2019-11-25 05:51:53	2019-11-25	Anastacia Toy	anastacia.toy@geemail.com	Oakland	California	4585676243520	a81eca2f46a8e2810ec56ccaa2a6d77a	VISA 13 digit	37.8494630675226489	-122.290947975069983
5871	2019-11-25 06:35:53	2019-11-25	Zayne Balistreri	zayne.balistreri@geemail.com	Fullerton	California	3007216933420387	6fe1a9c7e291551aa5d4f56415615010	Discover	33.9825538715038462	-117.935126753684131
5872	2019-11-25 07:08:04	2019-11-25	Morgan Altenwerth	morgan.altenwerth@geemail.com	Madison	Wisconsin	4631081438709	b613ab72dfab98cbb16657cd127f9b71	Mastercard	42.9903011617224706	-89.3341465515900381
5873	2019-11-25 08:19:50	2019-11-25	Cheri Koepp	cheri.koepp@woohoo.com	St. Petersburg	Florida	51266306209531318	38ab6451c8c3d7ce2dac3d9771f93be6	VISA 16 digit	27.8277143422402453	-82.5724540985081319
5874	2019-11-25 08:39:59	2019-11-25	Dr. Grove Zieme IV	dr.grove.zieme.iv@geemail.com	Atlanta	Georgia	3112252705376749965	669687b64eec3b9f832d2e8be28dfa25	VISA 16 digit	33.8071947475705343	-84.3667356557723167
5875	2019-11-25 10:00:40	2019-11-25	Luz Cummerata MD	luz.cummerata.md@warmmail.com	San Francisco	California	676213795049405	d20a8e967dde043b34135ceec2ab0257	VISA 13 digit	37.7876162680553094	-122.426220171424177
5876	2019-11-25 10:03:56	2019-11-25	Lavera Breitenberg	lavera.breitenberg@geemail.com	Savannah	Georgia	3057081587902464	2c9f676346aab859b418691c27a5278e	Diners Club / Carte Blanche	31.9053467302676275	-81.0601999801736355
5877	2019-11-25 10:52:36	2019-11-25	Ernst Stroman Sr.	ernst.stroman.sr.@geemail.com	Arlington	Texas	6011539780077264221	0422d2b149761940f91f2505f57779a7	VISA 13 digit	32.6211506212379732	-97.0529107070088486
5878	2019-11-25 12:04:25	2019-11-25	Keegan Kerluke IV	keegan.kerluke.iv@woohoo.com	Plano	Texas	869912523367831044	6c6b2e3a995990792364400f596ff610	Diners Club / Carte Blanche	33.0608001757498826	-96.7655112349145128
5879	2019-11-25 13:01:33	2019-11-25	Kimberely Corkery-Macejkovic	kimberely.corkery.macejkovic@geemail.com	San Francisco	California	4431302224029875	81f910ef9974d6535e06111dc2c758d3	JCB 15 digit	37.7595694425468196	-122.447615340346346
5880	2019-11-25 13:10:48	2019-11-25	Dr. Ted Yundt Sr.	dr.ted.yundt.sr.@warmmail.com	San Antonio	Texas	6011739469941817749	4ad7c8d854b7a3db9299ea2e83c14370	JCB 16 digit	29.5617744609318684	-98.4827054351869862
5881	2019-11-25 13:35:29	2019-11-25	Yee Bauch	yee.bauch@geemail.com	San Francisco	California	51388337968599959	150653d2142a26abb68ab8c51cdc2acb	Diners Club / Carte Blanche	37.7610216110493155	-122.415430193068474
5882	2019-11-25 13:45:40	2019-11-25	Alfred Waters	alfred.waters@warmmail.com	New York	New York	3768239662897084	538165a76f2c132a58f3b6ca18183275	JCB 16 digit	40.6216133003812274	-73.9556302124064331
5883	2019-11-25 13:53:32	2019-11-25	Frida Doyle	frida.doyle@warmmail.com	Los Angeles	California	3096232450624370265	f01ffa215e8ebe96b167e13a440e6ae4	VISA 16 digit	33.9345854513213041	-118.320947378407411
5884	2019-11-25 14:31:00	2019-11-25	Christophe Leuschke	christophe.leuschke@woohoo.com	Los Angeles	California	869987885308172949	d6ecc135246fc44cf0cedb6b52308ec1	JCB 16 digit	33.9253340090025191	-118.345922566623614
5885	2019-11-25 15:13:17	2019-11-25	Mrs. Carlotta Schmitt MD	mrs.carlotta.schmitt.md@geemail.com	Santa Ana	California	180056049406210278	3d95e1521d600598e0bb1662147d5556	American Express	33.7790336049266173	-117.83738583120703
5886	2019-11-25 15:15:57	2019-11-25	Kamron Lind	kamron.lind@geemail.com	Hialeah	Florida	3088680543774011163	86927881ca2d2f1bfad1a2e70f985c78	JCB 15 digit	25.9643315374363226	-80.3239498191881864
5887	2019-11-25 15:19:48	2019-11-25	Jace Zulauf	jace.zulauf@geemail.com	Oakland	California	180028976617775605	cfa8e8a021471e6dec48ba7c6e2f645e	VISA 13 digit	37.7650306655306451	-122.276833349893266
5888	2019-11-25 16:07:41	2019-11-25	Dereck Morissette	dereck.morissette@geemail.com	Lowell	Massachusetts	180013368254703222	baf81b3eb89bf406c2750dfa27504a9a	Maestro	42.7180549326688066	-71.2373754882127059
5889	2019-11-25 16:26:40	2019-11-25	Vernetta Kunde	vernetta.kunde@woohoo.com	New York	New York	3096944967874468381	d145e771cfea49a5d7b4df4794afa28c	Maestro	40.714431801972907	-73.9935459988553106
5890	2019-11-25 16:36:41	2019-11-25	Leonie Fahey	leonie.fahey@geemail.com	San Francisco	California	6011049092860272889	e78b8a07b70ea9656d712ad075b0af37	VISA 16 digit	37.7688218924311698	-122.4331198858238
5891	2019-11-25 16:52:45	2019-11-25	Grover Daniel	grover.daniel@geemail.com	Davenport	Iowa	3015066644487510	184c997ef6c0f0cc80aee3ac4a74c869	VISA 16 digit	41.542380219119039	-90.5701384467035524
5892	2019-11-25 16:53:05	2019-11-25	Dr. Myles Upton PhD	dr.myles.upton.phd@warmmail.com	Columbus	Ohio	55797888403692812	c9d244e2300bc2e0897e55d8353d4a3d	Mastercard	40.0126976436048736	-83.075490536145125
5893	2019-11-25 17:21:53	2019-11-25	Simeon Pollich	simeon.pollich@woohoo.com	San Francisco	California	6011413048360077846	31c142ec84e9fd8ec6573cbd4ff74842	Diners Club / Carte Blanche	37.7848797894710131	-122.402787370321079
5894	2019-11-25 17:29:23	2019-11-25	Mathilde Rutherford	mathilde.rutherford@geemail.com	Birmingham	Alabama	3015553050609497	aaa41787624e66e5366ead7d22de3262	Mastercard	33.5489801410377027	-86.897036829847849
5895	2019-11-25 17:30:13	2019-11-25	Willis Lemke	willis.lemke@warmmail.com	San Francisco	California	52894824851879439	8c41d3ac67099d2fc09c20819ab0ec94	VISA 16 digit	37.7818832966381137	-122.421323210219526
5896	2019-11-25 17:53:53	2019-11-25	Ms. Alison Homenick	ms.alison.homenick@geemail.com	San Francisco	California	180008066263366471	a4966b08a9f62999c99aefee1806ef20	JCB 15 digit	37.7471393661656123	-122.427491845048138
5897	2019-11-25 18:13:32	2019-11-25	Collier Rowe	collier.rowe@geemail.com	New York	New York	6011840143742244934	8bfdce28ad920f75516b9cf44c2d0937	JCB 16 digit	40.6148540409039711	-73.9622015971120419
5898	2019-11-25 18:37:14	2019-11-25	Elayne Effertz	elayne.effertz@warmmail.com	Birmingham	Alabama	3096922997296129770	a1a3e641e0a69d3dd58c4ed07e87d288	JCB 16 digit	33.5780216022651672	-86.7475141423065281
5899	2019-11-25 19:34:42	2019-11-25	Dr. Manerva Hodkiewicz PhD	dr.manerva.hodkiewicz.phd@woohoo.com	San Francisco	California	3772032329273292	f1e41b143addc9bc527c94e542d2d450	Maestro	37.7710851091824367	-122.44239937118661
5900	2019-11-25 19:52:04	2019-11-25	Kendall Abernathy-Hills	kendall.abernathy.hills@geemail.com	Kansas City	Kansas	869952430092858725	16461bc512182e86e9409315d126b3f5	Discover	39.2163861490227319	-94.8268707384757619
5901	2019-11-25 20:08:22	2019-11-25	Hali Hyatt	hali.hyatt@geemail.com	San Francisco	California	3096656215969422774	d3dee979577bdd276fd2df2da467c88d	American Express	37.7709736586882485	-122.416383934337588
5902	2019-11-25 21:03:37	2019-11-25	Lenna Hayes	lenna.hayes@geemail.com	Mesa	Arizona	4013621141954	3163e92771530044746876246a0caeef	VISA 13 digit	33.344337301902101	-111.656355639768393
5903	2019-11-25 21:15:49	2019-11-25	Benjaman Anderson	benjaman.anderson@geemail.com	Simi Valley	California	3096979228903019929	6268763bd9ad82859ee92945e6252c23	VISA 16 digit	34.3416859247494486	-118.748661158991979
5904	2019-11-25 21:21:15	2019-11-25	Ms. Denese Gusikowski PhD	ms.denese.gusikowski.phd@geemail.com	Austin	Texas	4410862649857320	af784deb3ac534cea84a0c1bb06cb945	Maestro	30.376472145937008	-97.7990081377565872
5905	2019-11-25 22:00:50	2019-11-25	Demetrios Schneider-Cronin	demetrios.schneider.cronin@warmmail.com	New York	New York	630401876264159	930294232481c43668a78dbe06df0b32	VISA 16 digit	40.7232277317661797	-73.9128239503957332
5906	2019-11-25 22:45:38	2019-11-25	Tara Beatty	tara.beatty@geemail.com	Las Vegas	Nevada	869919127735547986	445b1d7989ce447fd93b75b0823ae22d	American Express	36.2614297885082664	-115.271453053525079
5907	2019-11-25 23:06:36	2019-11-25	Tyreese Keeling	tyreese.keeling@warmmail.com	Berkeley	California	589379121420149	f8b72607b65ccd64c3ddb895e27eb962	JCB 15 digit	37.8513789361732975	-122.278525204398363
5908	2019-11-25 23:13:16	2019-11-25	Dr. Kade Marvin Sr.	dr.kade.marvin.sr.@warmmail.com	Aurora	Colorado	3479931090789993	d509c757d51b6d017f862e9c2015e1b1	Voyager	39.6943613231759542	-104.604246847762539
5909	2019-11-25 23:34:39	2019-11-25	Modena Hyatt	modena.hyatt@geemail.com	San Antonio	Texas	3088988903925466576	d054a4f085247a46f489edb97f3c4155	VISA 16 digit	29.4230069855298844	-98.4410527290612407
5910	2019-11-25 23:57:04	2019-11-25	Jed Terry-Roob	jed.terry.roob@geemail.com	Pembroke Pines	Florida	3337862047459991756	30ed1b08bac718bcddef6ceffadc2729	JCB 16 digit	26.0747511203438052	-80.2832001663647645
5911	2019-11-26 00:00:09	2019-11-26	Evita Hilpert	evita.hilpert@geemail.com	New York	New York	4229674044957303	f2c9775bd8ad0d645e61e291353d63ef	VISA 13 digit	40.5689219972342272	-73.8611814793560626
5912	2019-11-26 00:03:55	2019-11-26	Artelia Stanton	artelia.stanton@warmmail.com	San Diego	California	4491531310227087	0f6ac43ed39288718c54ad01c99864ef	Diners Club / Carte Blanche	32.8632893600102491	-117.178618628988048
5913	2019-11-26 01:18:12	2019-11-26	Weldon Crist	weldon.crist@geemail.com	San Francisco	California	4230902076945	7d4dd07c3c9ced964b8b27a1e87d9b90	Voyager	37.7662755668560735	-122.414037272823435
5914	2019-11-26 01:36:23	2019-11-26	Deward Doyle	deward.doyle@warmmail.com	Frisco	Texas	180094400826019589	30f38dc65f5f005c29701a299b08d1ff	JCB 16 digit	33.2441756638694557	-96.9124202988319041
5915	2019-11-26 02:34:20	2019-11-26	Cody Muller	cody.muller@geemail.com	Little Rock	Arkansas	3470485160619498	ab6b984a1ec22e01c20485192b94388d	VISA 13 digit	34.808354333396629	-92.3205157490320403
5916	2019-11-26 03:07:43	2019-11-26	Mr. Murdock Kuhlman	mr.murdock.kuhlman@warmmail.com	New York	New York	3480759942328216	de30d9b906906a3d30d2288d810ffb57	Voyager	40.754649109462278	-74.0119787830289368
5917	2019-11-26 03:28:59	2019-11-26	Mrs. Pennie Langworth	mrs.pennie.langworth@geemail.com	San Francisco	California	210076140337907524	565ef5b445327699a1163a82e0888639	Mastercard	37.7575650933969698	-122.398818451387683
5918	2019-11-26 03:46:39	2019-11-26	Paralee Swift	paralee.swift@warmmail.com	Jacksonville	Florida	3096391679164441477	5ca99d367e8884852114b89d5202d120	JCB 16 digit	30.3359529561880983	-81.6452086712777714
5919	2019-11-26 04:25:29	2019-11-26	Nathen Schaefer MD	nathen.schaefer.md@woohoo.com	Westminster	Colorado	675937232204745	6368358288cc378bf5e289758b5e53a2	JCB 16 digit	39.9237034456644153	-105.085162517210108
5920	2019-11-26 05:02:17	2019-11-26	Hennie Kuvalis	hennie.kuvalis@geemail.com	Fresno	California	3096791726613857518	be68471784eda9114a365803645a0dee	VISA 16 digit	36.8702940605454117	-119.785161807212617
5921	2019-11-26 05:53:56	2019-11-26	Glynis Weissnat	glynis.weissnat@warmmail.com	Raleigh	North Carolina	3059246771940426	94590d5cd9c2b21cb00aeb66223c6675	JCB 15 digit	35.7716712434444517	-78.589961218641335
5922	2019-11-26 06:02:19	2019-11-26	Dr. Bama Schimmel	dr.bama.schimmel@warmmail.com	San Francisco	California	4556513886367721	b0ffc0accda6a4c2a6631e980e27f6fa	Maestro	37.7865327789617709	-122.445574072661771
5923	2019-11-26 06:29:59	2019-11-26	Evan Reichert	evan.reichert@warmmail.com	Oxnard	California	6011578303664711173	387795b907c6889beaf17f5a850099ff	VISA 16 digit	34.219868177869543	-119.143267592406275
5924	2019-11-26 07:16:40	2019-11-26	Helene Brown	helene.brown@geemail.com	New York	New York	210000632663058998	66f72da597a840933371c11f4fcf38d1	Voyager	40.6389673691932103	-73.9507894194580615
5925	2019-11-26 07:24:04	2019-11-26	Werner Okuneva	werner.okuneva@geemail.com	Hillsboro	Oregon	4350760670801	462db85d830f479b891b0d8695a3bb65	American Express	45.4652469708789155	-122.908935809942705
5926	2019-11-26 09:02:31	2019-11-26	Sigurd Rodriguez	sigurd.rodriguez@woohoo.com	San Francisco	California	3088568644393489264	6077272c50828082a4157c3ec6d1160a	Mastercard	37.7975088665737573	-122.410461108803418
5927	2019-11-26 09:22:13	2019-11-26	Lavon Crooks	lavon.crooks@warmmail.com	Chicago	Illinois	4668950311026255	f6909134fb194c93ed8d69148b3980f7	Maestro	41.7391035587362964	-87.7180212549894947
5928	2019-11-26 09:50:01	2019-11-26	Rigoberto Harris	rigoberto.harris@geemail.com	Renton	Washington	4517368274795787	b7a2c352ac6752eb91ae0b18bd5b83d2	JCB 15 digit	47.379549180861936	-122.15585368686169
5929	2019-11-26 09:55:30	2019-11-26	Debbi Emard	debbi.emard@geemail.com	Houston	Texas	3779137892858214	da7b8a3427ade609ed63af3737494f0d	JCB 16 digit	29.8352998823471367	-95.4602542279768755
5930	2019-11-26 10:30:14	2019-11-26	Aydin Mayer III	aydin.mayer.iii@warmmail.com	Los Angeles	California	502053639698967	b30ccd716dddc60088af9b0e13b2b156	Mastercard	33.9583316160231803	-118.378077232930053
5931	2019-11-26 10:37:05	2019-11-26	Eddie Kertzmann	eddie.kertzmann@geemail.com	Norwalk	California	639023884120728	5c40c9337f900b061443c6d75f093a03	VISA 16 digit	33.8291749702416382	-118.094369059152896
5932	2019-11-26 11:11:02	2019-11-26	Dr. Carlisle Bayer	dr.carlisle.bayer@warmmail.com	New York	New York	4048817053324	575f657ec264c2afb630bb23c3f17b4c	VISA 13 digit	40.683102083368226	-73.8921423272125395
5933	2019-11-26 11:17:45	2019-11-26	Osborn Quigley	osborn.quigley@geemail.com	San Francisco	California	4126867345969852	5eeec2e2aff7087d23b9c21747424884	Discover	37.7745320815565293	-122.438815242310838
5934	2019-11-26 11:33:54	2019-11-26	Gilda Reichel DDS	gilda.reichel.dds@geemail.com	Baltimore	Maryland	869985122294859533	a43f4a589a6fd6f6800991c5a02150de	JCB 15 digit	39.331313815386963	-76.694357972593977
5935	2019-11-26 11:38:47	2019-11-26	Hunter Wilkinson	hunter.wilkinson@geemail.com	Vancouver	Washington	3096674967929778129	2f9545d74ba79c1ac6f76979ab169dc7	Diners Club / Carte Blanche	45.7226601793967191	-122.586488366505876
5936	2019-11-26 11:50:30	2019-11-26	Echo Goodwin	echo.goodwin@woohoo.com	New York	New York	4001240608651	897cf3863c1b17332e2fd1120239566d	VISA 13 digit	40.6809229573458424	-73.9304433640919569
5937	2019-11-26 12:09:56	2019-11-26	Marcella Monahan	marcella.monahan@geemail.com	San Francisco	California	4828589769354491	c88be8fc05037adbc1968cc7b52aeee7	Diners Club / Carte Blanche	37.7747615234395013	-122.46207221675968
5938	2019-11-26 12:43:27	2019-11-26	Mr. Deon Leannon	mr.deon.leannon@geemail.com	Louisville	Kentucky	676111585316711	de6ed4d5080d2069d7e7a0f6935fe20f	JCB 16 digit	38.2370547773685274	-85.6058365600720066
5939	2019-11-26 13:09:21	2019-11-26	Dr. Mikhail Runolfsdottir I	dr.mikhail.runolfsdottir.i@geemail.com	San Francisco	California	180070217317876576	9e7530109fef6cf5982d001d85e64b33	Voyager	37.7931235758467281	-122.456408064515458
5940	2019-11-26 14:21:18	2019-11-26	Hazle Ondricka DDS	hazle.ondricka.dds@geemail.com	Gilbert	Arizona	3448824209719662	a400d06b50ac75467ef6a8d0febc1a10	Mastercard	33.3729413473859395	-111.656975960046424
5941	2019-11-26 14:47:12	2019-11-26	Cinnamon Wiegand	cinnamon.wiegand@warmmail.com	Berkeley	California	4278538645377163	250957f34ab9eee8de92c9c5f252c62e	Mastercard	37.8574250441835574	-122.298741355602871
5942	2019-11-26 14:49:26	2019-11-26	Alexzander Runte	alexzander.runte@woohoo.com	Los Angeles	California	6011049019961898452	8d7adb846138c3a380b65ce52aae88ff	VISA 16 digit	34.1044342944730019	-118.403496863459424
5943	2019-11-26 14:52:40	2019-11-26	Dr. Mathilde Runolfsdottir DDS	dr.mathilde.runolfsdottir.dds@geemail.com	Berkeley	California	4933780752311174	391a67995b67b09eade5aedcaad684e9	JCB 15 digit	37.8593844972566131	-122.273422873890439
5944	2019-11-26 14:56:22	2019-11-26	Gottlieb Steuber PhD	gottlieb.steuber.phd@woohoo.com	Fort Worth	Texas	51425575005020928	b7135944d14bc083994ec37912f2b969	Voyager	32.7153485290762021	-97.433679067884384
5945	2019-11-26 16:19:21	2019-11-26	Miss Carolina Dare	miss.carolina.dare@geemail.com	San Francisco	California	3112987600782227874	19f918934e8d493ff8ba7ecf89a2d4e3	JCB 16 digit	37.7613783625735664	-122.444716669370877
5946	2019-11-26 17:12:50	2019-11-26	Ms. Maureen Collins PhD	ms.maureen.collins.phd@geemail.com	Pasadena	Texas	3777591993054077	fd9cdbc1f31e73b365a47a34b3d0f86b	JCB 16 digit	29.5697269752960636	-95.1480381709937006
5947	2019-11-26 17:48:27	2019-11-26	Lonzo Bahringer-Volkman	lonzo.bahringer.volkman@geemail.com	San Francisco	California	54294683081001081	d8093416726cdc8ad85e8f426cc00495	Voyager	37.7140581923233356	-122.450061868603484
5948	2019-11-26 18:30:34	2019-11-26	Jacquline Farrell-Terry	jacquline.farrell.terry@geemail.com	Des Moines	Iowa	3112768994784205334	3679e904c360c918327ce68cfc9ea65f	Discover	41.6045774705916642	-93.5918985815763591
5949	2019-11-26 18:35:03	2019-11-26	Deja Larkin-Thiel	deja.larkin.thiel@geemail.com	El Paso	Texas	6011260446217265164	a0ae4d0c7d7aacaeef0a9118cc0a707c	JCB 16 digit	31.8467205706812457	-106.408354167684919
5950	2019-11-26 18:58:34	2019-11-26	Schuyler DuBuque-Thompson	schuyler.dubuque.thompson@geemail.com	Wichita	Kansas	51586767033660149	898a4cf7154de94f7ac6b349edf2605b	American Express	37.7675578323069985	-97.4319510228667411
5951	2019-11-26 19:12:26	2019-11-26	Claud Monahan V	claud.monahan.v@geemail.com	St. Louis	Missouri	3528739578637558639	d2b3fe1fd8910279206b26ccc57c0a77	Discover	38.5927848246105043	-90.2723628204785342
5952	2019-11-26 19:50:13	2019-11-26	Prudence Kuhlman-Mayert	prudence.kuhlman.mayert@geemail.com	Washington	District of Columbia	869932802393858726	3a8863949bf7a41dd202feb23af51f22	American Express	38.9588284698579486	-77.0538040201392107
5953	2019-11-26 19:52:03	2019-11-26	Arlington Kessler	arlington.kessler@geemail.com	Los Angeles	California	180046794554692156	dbc12582dfb7cf3f0a508d01d1b8efcc	JCB 15 digit	34.0638969602394823	-118.317552753723405
5954	2019-11-26 20:29:45	2019-11-26	Jerrell Reilly	jerrell.reilly@geemail.com	Odessa	Texas	3024092063202314	f060778c1e24af7745d849298d789902	JCB 16 digit	31.9539711555011579	-102.270333860503882
5955	2019-11-26 20:56:29	2019-11-26	Anabella Dach	anabella.dach@geemail.com	Cincinnati	Ohio	3468673896217737	325eea811e8508d1e4c74d5ac0019583	Maestro	39.1674951794788271	-84.4484747214980302
5956	2019-11-26 21:11:26	2019-11-26	Therese Cole-Lang	therese.cole.lang@geemail.com	San Francisco	California	4283838108521346	4a280662546566beb061f5f3d5b7133d	JCB 15 digit	37.7821681053144189	-122.463782300165036
5957	2019-11-26 21:40:44	2019-11-26	Angele Stehr	angele.stehr@geemail.com	Chicago	Illinois	180071478611675713	326624cb9ba33bae371c4f114baee1e7	VISA 13 digit	41.840191183921327	-87.7367706673249614
5958	2019-11-26 21:44:29	2019-11-26	Ena Lindgren	ena.lindgren@geemail.com	San Francisco	California	4907671602194328	d5ae84258c35a2844b719040a8b7a5fa	Maestro	37.7766199917645693	-122.426144952931978
5959	2019-11-26 21:53:25	2019-11-26	Dr. Isreal Stamm V	dr.isreal.stamm.v@geemail.com	Berkeley	California	210055289447794473	ae2d55b01203429198bfed924f1b9a7f	JCB 15 digit	37.8538064316655252	-122.219462564887223
5960	2019-11-26 22:07:27	2019-11-26	Mrs. Stacey Casper	mrs.stacey.casper@geemail.com	Burbank	California	4376981939445968	377cfcc5b21e43cd96fb2eee7ff09b1d	Mastercard	34.2609872607909125	-118.260619646733261
5961	2019-11-26 22:44:56	2019-11-26	Lonnie Volkman DVM	lonnie.volkman.dvm@warmmail.com	San Francisco	California	4583959929657361	138182eb14451e97d1c59235614d62dc	Diners Club / Carte Blanche	37.7537081304902316	-122.411033656929376
5962	2019-11-26 23:15:26	2019-11-26	Austen Harber	austen.harber@warmmail.com	San Francisco	California	4845500070635899	f5ef4c88a7ade8782d52c9d39a3a843f	JCB 15 digit	37.7784781829223846	-122.410438151828401
5963	2019-11-26 23:16:06	2019-11-26	Lafe Okuneva	lafe.okuneva@warmmail.com	Berkeley	California	3112082424551565990	f2546f9679905d3a13dbf83eda0b01ce	Maestro	37.9112031758331582	-122.282468337707996
5964	2019-11-26 23:26:22	2019-11-26	Tristin Boyle	tristin.boyle@warmmail.com	Simi Valley	California	4882016342173	fdbf188774038406e88c1ecc38cff62f	Mastercard	34.3276342124450977	-118.764004306834195
5965	2019-11-26 23:54:49	2019-11-26	Dandre Zboncak	dandre.zboncak@geemail.com	Berkeley	California	6011334136194308317	f58e43ac0012fbcdf6177d5da64ca5c1	Mastercard	37.8532863238263388	-122.272311620340574
5966	2019-11-27 00:01:47	2019-11-27	Loula Stark-Mante	loula.stark.mante@geemail.com	San Francisco	California	869984385736531660	21c4fb3eba1112f096e9074433e4a309	Mastercard	37.7730611683839825	-122.385562112473266
5967	2019-11-27 00:31:04	2019-11-27	Blossom Crooks	blossom.crooks@woohoo.com	Los Angeles	California	4737615964988948	a3d7e452ce181e53698a83cb91066528	JCB 16 digit	33.9920591672748316	-118.327579069928447
5968	2019-11-27 00:50:23	2019-11-27	Arvel Bruen	arvel.bruen@warmmail.com	El Paso	Texas	869946264094532999	f26a535a1f8dd901aa67a1b87a2c22fd	Diners Club / Carte Blanche	31.9416071779854605	-106.340351627811799
5969	2019-11-27 01:44:58	2019-11-27	Delpha Berge	delpha.berge@warmmail.com	Norfolk	Virginia	4447948353641658	7c46019efc5cb3102de6a959e9912e60	Discover	36.867198121177033	-76.3173465984877311
5970	2019-11-27 01:51:16	2019-11-27	Dr. Enrico Johnston DVM	dr.enrico.johnston.dvm@geemail.com	San Francisco	California	869965750774450003	e30db761908aa8cae9c10da72eefb6a5	VISA 16 digit	37.7720623414504644	-122.451936869665573
5971	2019-11-27 04:09:51	2019-11-27	Augustin Torp	augustin.torp@geemail.com	Berkeley	California	4361205628817	2df2ec2e6572511d30b8ac5a85d7c5ca	JCB 15 digit	37.8599691530770599	-122.269701648117305
5972	2019-11-27 04:43:14	2019-11-27	Devaughn Kuhlman-Cassin	devaughn.kuhlman.cassin@geemail.com	San Francisco	California	4162230658831	c93407dd7bad999f0a59673b8273f0f6	VISA 13 digit	37.7921856438262864	-122.419495197988937
5973	2019-11-27 04:46:26	2019-11-27	Lindsey King	lindsey.king@warmmail.com	Los Angeles	California	4100139637266	78ab1fcb0acb6d8561065d25ef426b65	VISA 13 digit	34.09003320633024	-118.315225231786442
5974	2019-11-27 04:55:45	2019-11-27	Maryjo Walsh	maryjo.walsh@woohoo.com	Syracuse	New York	3041008379424510	cad79e18a6255c3194f773f96d0e3c77	VISA 13 digit	43.0512466227952331	-76.2132603112854099
5975	2019-11-27 05:09:28	2019-11-27	Sanai Dickinson	sanai.dickinson@warmmail.com	High Point	North Carolina	6011357733072393072	90bc5db52b486285c42180a9cb035386	VISA 16 digit	35.9301916744653127	-79.896174913758415
5976	2019-11-27 06:18:17	2019-11-27	Sherree Wolff	sherree.wolff@geemail.com	Tampa	Florida	4996093325652130	f98ad0a4a61cc19fb74b56fdd2e24508	Maestro	28.0053354555856409	-82.3818371808368681
5977	2019-11-27 06:38:44	2019-11-27	Ted Hermiston	ted.hermiston@geemail.com	Minneapolis	Minnesota	55148498864104913	e0b9c4a34d9fef3449c4d46ec210c397	Voyager	44.8691457491453676	-93.1946564013410352
5978	2019-11-27 06:52:55	2019-11-27	Georgianna Medhurst	georgianna.medhurst@geemail.com	Detroit	Michigan	869993922689812132	ae0f698b99bcc566029a4dce2e1d6436	American Express	42.4259896418005269	-83.0306605179447672
5979	2019-11-27 07:27:08	2019-11-27	Mercer Wilderman II	mercer.wilderman.ii@geemail.com	New York	New York	4469689062252	46d137a5e8a433dc2838bae43a06945a	Voyager	40.7543937726635477	-73.9381287530425908
5980	2019-11-27 08:09:15	2019-11-27	Annalise Pollich MD	annalise.pollich.md@geemail.com	Fort Worth	Texas	639097385796087	2afe7daafe0c3b4a318b3bfd938d811a	JCB 16 digit	32.8038881263285873	-97.2627503950901371
5981	2019-11-27 08:21:20	2019-11-27	Shelvia Paucek	shelvia.paucek@warmmail.com	San Francisco	California	3337425066904811294	e5d73f5c7febd8f50091e2407c32a9c0	JCB 16 digit	37.7686278650114104	-122.437284936340362
5982	2019-11-27 08:29:39	2019-11-27	Drusilla Schamberger	drusilla.schamberger@warmmail.com	Boulder	Colorado	3112012508875675736	4c7c23eb7e853d4688520b88dfc50133	VISA 16 digit	40.0253007743954683	-105.337475774684549
5983	2019-11-27 08:44:24	2019-11-27	Jakob Halvorson PhD	jakob.halvorson.phd@geemail.com	Louisville	Kentucky	4157698386875	edb16fb044c922196da83aace7420b24	Mastercard	38.1789350889991965	-85.6694175475813466
5984	2019-11-27 08:45:07	2019-11-27	Christel McCullough	christel.mccullough@geemail.com	Cleveland	Ohio	869989345333626060	376e6adcedf78115a5de6796b881a406	Voyager	41.459812465155494	-81.5987502953276049
5985	2019-11-27 08:48:29	2019-11-27	Averie Jaskolski	averie.jaskolski@warmmail.com	Detroit	Michigan	4535073972501960	ea4b1448df9eb9a3cb43765e7a58699b	Diners Club / Carte Blanche	42.460685515163469	-83.0497472859106978
5986	2019-11-27 09:37:57	2019-11-27	Addyson Herman	addyson.herman@warmmail.com	Atlanta	Georgia	4111688521863736	170c8127ac2d690fbe5b301af1e664ec	Maestro	33.8445447689197962	-84.4751360734038172
5987	2019-11-27 09:41:27	2019-11-27	Jeb Blanda Sr.	jeb.blanda.sr.@geemail.com	San Francisco	California	3027270809842463	5f9da53eecf98992b022980712986201	American Express	37.7767269894551632	-122.4416216359798
5988	2019-11-27 10:35:25	2019-11-27	Kadijah Herzog	kadijah.herzog@geemail.com	Oakland	California	4955149330980962	bf0c7f7ac81d83596ef17c3975eb5d73	VISA 16 digit	37.8295718077901455	-122.253747359121292
5989	2019-11-27 10:39:38	2019-11-27	Fitzgerald Yost	fitzgerald.yost@warmmail.com	Chicago	Illinois	4903242203615	bd866bdb747fc9c8d57d3410e1057997	American Express	41.9075587278999393	-87.6661102862127137
5990	2019-11-27 10:46:28	2019-11-27	Gillie Hand	gillie.hand@warmmail.com	San Francisco	California	4992638311121419	f74fe356484e9ef3396992c310793ddf	Maestro	37.7864453086829784	-122.475751216387224
5991	2019-11-27 10:52:19	2019-11-27	Callie Fritsch	callie.fritsch@geemail.com	Huntsville	Alabama	869977884768498458	d27583bac727c0c315a04125ac79d1a2	Maestro	34.7348595729339849	-86.7382740364428599
5992	2019-11-27 11:04:54	2019-11-27	Erby Armstrong-Erdman	erby.armstrong.erdman@woohoo.com	Clearwater	Florida	4191583266717606	42e93327005c8470b1812b88d5e4a92c	VISA 16 digit	28.0399216584056603	-82.7739102117516126
5993	2019-11-27 11:24:54	2019-11-27	Raul Huels-Mann	raul.huels.mann@warmmail.com	Long Beach	California	869945482993664744	db57a635e88bb028c83405e269c2d25c	VISA 13 digit	33.8323324120424687	-118.137518381902197
5994	2019-11-27 13:06:02	2019-11-27	Geraldo Larson	geraldo.larson@geemail.com	North Las Vegas	Nevada	55714311861647632	c5128cff211521efe55e465f7e578995	VISA 16 digit	36.2357731743872122	-115.164490461976825
5995	2019-11-27 13:08:29	2019-11-27	Aarav Hintz-Bednar	aarav.hintz.bednar@geemail.com	San Francisco	California	6011852184450712287	bf68ba3cc1b300d22a8a533e68ac68ba	Discover	37.761469294845412	-122.470912950640525
5996	2019-11-27 13:19:14	2019-11-27	Ruffus Bechtelar	ruffus.bechtelar@warmmail.com	San Francisco	California	3015969613541102	b48084c92b51b389f6b461534567f5e8	Discover	37.7763230260049312	-122.425727525693731
5997	2019-11-27 13:42:48	2019-11-27	Katerina Brakus	katerina.brakus@geemail.com	Hartford	Connecticut	54628139962460794	b2290ad582e3aa65b6e8dc5358a28517	VISA 13 digit	41.8130014242619268	-72.5914109227605167
5998	2019-11-27 13:56:18	2019-11-27	Mr. Burnice Donnelly	mr.burnice.donnelly@warmmail.com	New York	New York	3042143725536870	a67aacddcb208561d6c07d686b5df13e	American Express	40.7358679626360498	-74.0116318627622007
5999	2019-11-27 14:03:21	2019-11-27	Mr. Braedon Gaylord	mr.braedon.gaylord@geemail.com	San Diego	California	4644549207796382	55ae16a15874742f280156a1bbe601a7	JCB 16 digit	32.8982756943043313	-117.195616829339414
6000	2019-11-27 14:09:07	2019-11-27	Reubin Altenwerth	reubin.altenwerth@warmmail.com	New York	New York	3088183212741719108	2367581c7ca6d14542bc72f2e8caee01	Diners Club / Carte Blanche	40.6916094671227029	-73.8594502189558
6001	2019-11-27 14:42:03	2019-11-27	Grecia Schuppe	grecia.schuppe@geemail.com	Chicago	Illinois	4069923813667723	9e7fbf954b8b6aca424f4cc30be29f65	VISA 16 digit	41.9346699596684473	-87.6135106302361919
6002	2019-11-27 15:22:00	2019-11-27	Ivey Bode-Goyette	ivey.bode.goyette@geemail.com	Oakland	California	4631213069264907	311e7ab2c086941d2b6680f04e4f6fbb	Voyager	37.7959808853927015	-122.279565982903648
6003	2019-11-27 15:34:15	2019-11-27	Lota Simonis	lota.simonis@geemail.com	Berkeley	California	6011045656451647487	07cf32187b572d3e32f0fc4a0c169e8a	VISA 13 digit	37.9053177225149724	-122.298585627027137
6004	2019-11-27 15:39:31	2019-11-27	Dr. Ryne Gusikowski	dr.ryne.gusikowski@geemail.com	Berkeley	California	3456173286910136	fac4345647bf3a0db11cd73440eb2a0c	JCB 16 digit	37.817153900154743	-122.264468859978535
6005	2019-11-27 17:35:03	2019-11-27	Shaun Bauch-Jones	shaun.bauch.jones@geemail.com	Frisco	Texas	4104161339569	67753a9f4d7bbc0b7fef07d1310ca2c7	JCB 16 digit	33.1233763463791462	-96.7380418935533584
6006	2019-11-27 17:41:52	2019-11-27	Hasan Kertzmann	hasan.kertzmann@woohoo.com	El Paso	Texas	3048771181666973	42b861c3b79a235f05a790b10ad699f9	JCB 16 digit	31.8337716034907849	-106.486819629974676
6007	2019-11-27 18:46:31	2019-11-27	Alpha Ferry	alpha.ferry@woohoo.com	San Diego	California	676165031990289	093c69dda4204b92b83809867ef6a1e1	Voyager	32.8674023410372413	-117.167500761048871
6008	2019-11-27 18:49:42	2019-11-27	Myrtice Waelchi	myrtice.waelchi@geemail.com	Orlando	Florida	6011745306615919504	e40b6426abc39229e7f9a7df00250911	Mastercard	28.3549556733373542	-81.2583317294217693
6009	2019-11-27 19:09:38	2019-11-27	Denis Mayert	denis.mayert@geemail.com	San Francisco	California	6011945751784228773	b90cea5a48aeba342eca49bbc4ec95bb	Discover	37.7388308156571171	-122.41143478378072
6010	2019-11-27 19:10:33	2019-11-27	Dr. Hayward Strosin	dr.hayward.strosin@geemail.com	San Diego	California	4365428767841366	cc3f737bb0bff35b22b8e2c5c5c3c391	American Express	32.7179075553614638	-117.121714162118735
6011	2019-11-27 19:31:33	2019-11-27	Pranav Waelchi	pranav.waelchi@geemail.com	San Francisco	California	3785291139422433	80c9bdf0553e813f05ebb04658ea763b	VISA 13 digit	37.7905834855667138	-122.485110886161749
6012	2019-11-27 20:08:38	2019-11-27	Marla Kiehn	marla.kiehn@woohoo.com	South Bend	Indiana	4027707572353372	79813a095584cafb17303f0493c2084b	Mastercard	41.7263977391324943	-86.2608077244888989
6013	2019-11-27 21:26:46	2019-11-27	Mrs. Baylie Keebler PhD	mrs.baylie.keebler.phd@woohoo.com	Phoenix	Arizona	4377875907178719	7fd9ae11a40a1f1fa063156be02d6c61	JCB 15 digit	33.5966036628399038	-112.181436930636323
6014	2019-11-27 21:40:11	2019-11-27	Mr. Tab Adams	mr.tab.adams@geemail.com	San Francisco	California	589376907530893	de1b26089e4295b49cf091777538d2b1	JCB 15 digit	37.7719464974634889	-122.432770071969728
6015	2019-11-27 21:43:14	2019-11-27	Mauro Green	mauro.green@woohoo.com	Renton	Washington	3714345522438996	13ad869b4b1ae6334a673cf064a6f95b	JCB 16 digit	47.5333378354147129	-122.268663644146173
6016	2019-11-27 23:06:29	2019-11-27	Dr. Mckayla Willms	dr.mckayla.willms@warmmail.com	San Francisco	California	6011653168849848168	163ec4253694f722fa7283a34a1b87f3	Mastercard	37.7951264526981277	-122.432984288645486
6017	2019-11-27 23:07:24	2019-11-27	Ms. Ebba Ledner DDS	ms.ebba.ledner.dds@geemail.com	Phoenix	Arizona	3019244557587206	2e7379bdb91120dea6c095d8ee788ee7	VISA 13 digit	33.5955410636428766	-112.164927826255933
6018	2019-11-27 23:59:05	2019-11-27	Franklyn Murazik	franklyn.murazik@geemail.com	San Francisco	California	4022651124300769	555eb55ab0cb6154b3e8cd623a24e332	Maestro	37.7665506836817642	-122.424243208704311
6019	2019-11-28 00:08:36	2019-11-28	Dorthy Dibbert	dorthy.dibbert@geemail.com	New York	New York	6011472078994949639	93e35b3b708aa2086a4090b92bb635a5	JCB 16 digit	40.6801400280315448	-73.9230202874530136
6020	2019-11-28 01:06:39	2019-11-28	Manly Beatty	manly.beatty@geemail.com	Oakland	California	4472773410064	2e4cac15d528f485666699a42cff6932	VISA 16 digit	37.8375955359493048	-122.288859888787144
6021	2019-11-28 01:28:05	2019-11-28	Joel Stark	joel.stark@geemail.com	Baltimore	Maryland	869989609187695517	7724c4a53878fc6b5b318c13f359bec6	JCB 16 digit	39.3263916375581175	-76.5517359842564957
6022	2019-11-28 01:35:27	2019-11-28	Mr. Floyd Welch	mr.floyd.welch@geemail.com	Knoxville	Tennessee	060466867711229	9571e6b7f5d01620b00a5f290a857207	American Express	35.9985637321665877	-84.0084419172938794
6023	2019-11-28 01:50:24	2019-11-28	Jared Kohler-Bauch	jared.kohler.bauch@woohoo.com	New York	New York	869901513257254095	d8cc074ae3036eb07d8f2ce49d79abc3	American Express	40.6924741742890319	-74.0269676107343315
6024	2019-11-28 02:07:55	2019-11-28	Miss Amberly Schneider	miss.amberly.schneider@geemail.com	Independence	Missouri	4203395654320	4f311d884fa3f85f0c7961fadd79002d	VISA 16 digit	39.1446205205302746	-94.4261371646359464
6025	2019-11-28 02:28:04	2019-11-28	Kent Lemke Sr.	kent.lemke.sr.@geemail.com	Richmond	Virginia	4638317288394	da3c52fb0917312a2e03d04b97d9a145	JCB 16 digit	37.5599705860704134	-77.4981507359761679
6026	2019-11-28 02:30:06	2019-11-28	Nim Cole	nim.cole@woohoo.com	Fresno	California	4981448630995813	504756b042c183e5809b9b7443b4588c	American Express	36.7225047112315863	-119.864105338427805
6027	2019-11-28 03:12:08	2019-11-28	Salena Treutel	salena.treutel@geemail.com	Eugene	Oregon	502090530350520	ced0335c1e7683eaf7cbb266b5254e6c	Voyager	43.9569260065171861	-123.195957170612004
6028	2019-11-28 03:31:18	2019-11-28	Tressa Wiza	tressa.wiza@geemail.com	South Bend	Indiana	3007246078555689	08f3ff515919203f34033397c00df2b7	VISA 16 digit	41.7675526115257298	-86.1857095235548911
6029	2019-11-28 03:42:58	2019-11-28	Hadley Renner DVM	hadley.renner.dvm@geemail.com	Colorado Springs	Colorado	869905601090968256	b1f1ba86e09bef054fc25b2b5afe25fd	JCB 16 digit	38.941274840110168	-104.747317740243673
6030	2019-11-28 03:53:17	2019-11-28	Nickolas Homenick	nickolas.homenick@woohoo.com	Greensboro	North Carolina	3721738576306187	15294141defe7967018a6bb18d109649	Discover	36.0694931663688294	-79.7903290758356434
6031	2019-11-28 04:23:22	2019-11-28	Miss Ardella Bergnaum	miss.ardella.bergnaum@geemail.com	McKinney	Texas	6011329169025739878	fbc55c9928a2585ee2805c585cc06a7d	Diners Club / Carte Blanche	33.136797895994043	-96.6278983387462915
6032	2019-11-28 04:23:47	2019-11-28	Maybelle Stark	maybelle.stark@geemail.com	Columbus	Ohio	4392173758928379	da5ea0483aee8755fc68fac5c91ccb1c	VISA 16 digit	39.985305066644024	-83.0052716870095679
6033	2019-11-28 04:46:44	2019-11-28	Dr. Kole Stracke I	dr.kole.stracke.i@woohoo.com	San Francisco	California	54797512458807493	7cd6c9c5803f3750f2bfabad082208a6	JCB 16 digit	37.7548556155268642	-122.419260213462053
6034	2019-11-28 05:21:27	2019-11-28	Cristi Tillman	cristi.tillman@geemail.com	Atlanta	Georgia	3771317694034887	f9c0a7b4a39e83569983942a853420cc	JCB 16 digit	33.7087609945606488	-84.4832469680856946
6035	2019-11-28 05:22:22	2019-11-28	Justus Wiegand	justus.wiegand@geemail.com	San Francisco	California	869964515321346470	85ebd8448ea3ad3f99a4e13407ea6165	Mastercard	37.793909394341263	-122.432754350169674
6036	2019-11-28 05:37:21	2019-11-28	Mayme Hegmann	mayme.hegmann@geemail.com	Chicago	Illinois	869966035444593450	ad1484066704a02ce48a84373da1d54f	JCB 16 digit	41.9362396652180749	-87.5917126505199803
6037	2019-11-28 06:07:03	2019-11-28	Sarahi Reinger	sarahi.reinger@geemail.com	San Francisco	California	4101254437821	e8311cbe50a115ab6cb29afb89ada7fd	Discover	37.742205739817642	-122.428686051681893
6038	2019-11-28 07:16:17	2019-11-28	Loula Stiedemann-Runte	loula.stiedemann.runte@geemail.com	San Francisco	California	4668423283464003	f00737773980cd5bd3f0ce251dcf09fa	VISA 16 digit	37.7757293746476179	-122.450888630813822
6039	2019-11-28 07:16:50	2019-11-28	Mr. Levie Lang PhD	mr.levie.lang.phd@geemail.com	San Francisco	California	4829188221183470	8f93078ea4ceeb7aa06f9fc889c8154d	VISA 16 digit	37.8044655536009415	-122.39814441553375
6040	2019-11-28 07:25:33	2019-11-28	Rylee Bogan-Jacobs	rylee.bogan.jacobs@woohoo.com	San Francisco	California	4227534846190	39b219c8f0a6db31f83b04d9d533219d	JCB 16 digit	37.7585085825865931	-122.377896795438588
6041	2019-11-28 08:17:54	2019-11-28	Atha Gislason	atha.gislason@geemail.com	Westminster	Colorado	3021692890679197	a4c59e43f981ceaccfbc257029481e89	JCB 16 digit	39.786574663857742	-105.095775029403725
6042	2019-11-28 09:13:43	2019-11-28	Dr. Murray Langworth DVM	dr.murray.langworth.dvm@geemail.com	Kansas City	Missouri	3528947279551356955	a463209d6a800736c34f2720a291ba33	JCB 16 digit	39.085284499341995	-94.5865326515622513
6043	2019-11-28 09:15:23	2019-11-28	Maverick Lynch	maverick.lynch@warmmail.com	Berkeley	California	54561276307926631	b5e3516898da1561d49cef90a0a165a6	VISA 16 digit	37.892903439759074	-122.277385926974361
6044	2019-11-28 10:55:22	2019-11-28	Mr. Diallo Schaefer	mr.diallo.schaefer@geemail.com	San Diego	California	869910761097935170	07c004a7b53bcc93f6327136053f1afd	JCB 16 digit	32.7571935614172389	-117.052374418815603
6045	2019-11-28 11:31:43	2019-11-28	Danelle Donnelly-Schiller	danelle.donnelly.schiller@warmmail.com	Santa Ana	California	55602445783759789	fc9d1a560ba7db211760a7664436d924	Diners Club / Carte Blanche	33.774178669193013	-117.883910114450373
6046	2019-11-28 11:54:20	2019-11-28	Leighton Green-Bednar	leighton.green.bednar@geemail.com	San Francisco	California	3112467247756755610	bceaba1c473a5728d4eb897f39417369	Diners Club / Carte Blanche	37.8185543463717977	-122.439552145504649
6047	2019-11-28 12:54:42	2019-11-28	Ms. Sharde Luettgen MD	ms.sharde.luettgen.md@geemail.com	Oxnard	California	3048178083432902	cd3f2e3d922309a131238ece9dc57930	Mastercard	34.2160522567529242	-119.178659700500219
6048	2019-11-28 12:55:49	2019-11-28	Abel Ritchie	abel.ritchie@warmmail.com	Oakland	California	53729396343131480	8f60662fd200db6a8af500206a509cae	VISA 13 digit	37.7866710881733283	-122.276581743633244
6049	2019-11-28 13:07:04	2019-11-28	Tobi Quitzon-Emard	tobi.quitzon.emard@warmmail.com	San Francisco	California	4839719146317351	3ef8b380ffe4975371cdcaa746445f33	Maestro	37.7589193451316376	-122.401714031556295
6050	2019-11-28 13:13:43	2019-11-28	Kurtis Turner	kurtis.turner@geemail.com	San Francisco	California	54315904595178560	22ff1485467cf753026135257cdc9a4d	Mastercard	37.7893695587656779	-122.40921064437957
6051	2019-11-28 13:21:36	2019-11-28	Ms. Madeline Hoppe	ms.madeline.hoppe@geemail.com	Lakeland	Florida	869952162248082948	9c90f5469cb460850d86adfe1ec4c3a4	Diners Club / Carte Blanche	28.0249803974591174	-82.02284812376611
6052	2019-11-28 13:42:04	2019-11-28	Betsey Deckow-Skiles	betsey.deckow.skiles@geemail.com	Denver	Colorado	3765652845129576	d540f03032df41041663ca94c80bdf0b	VISA 16 digit	39.8109606935229152	-104.923866631348062
6053	2019-11-28 14:27:22	2019-11-28	Linn Kerluke	linn.kerluke@geemail.com	New York	New York	3112213585149641154	dd9f7631953a2056d1784c05b20cc0d8	Diners Club / Carte Blanche	40.7247687380984402	-73.9687818691030117
6054	2019-11-28 14:27:33	2019-11-28	Ollie Herzog	ollie.herzog@geemail.com	Miramar	Florida	4808608166829	a1c91186023b993b1417539cd9ff3996	VISA 16 digit	25.8868379640374329	-80.3524824029758662
6055	2019-11-28 14:37:01	2019-11-28	Ms. Deirdre Bergnaum	ms.deirdre.bergnaum@warmmail.com	San Jose	California	3045062322440699	d93dcbae73bf58da1d8653cb9fb17e04	VISA 13 digit	37.3697023617390585	-121.78009334343821
6056	2019-11-28 14:38:18	2019-11-28	Ishmael Cartwright-Heaney	ishmael.cartwright.heaney@geemail.com	Peoria	Arizona	4605414970394823	c6190e85a363d1ea6edb457c2f80d1d2	JCB 16 digit	33.7079807081528031	-112.22624434734881
6057	2019-11-28 14:55:47	2019-11-28	Matthew Spencer I	matthew.spencer.i@geemail.com	El Paso	Texas	3772092862173549	b10d3a0e0cafb5f2cbb03ac625e53644	JCB 16 digit	31.8301293188534693	-106.51320768375696
6058	2019-11-28 15:31:02	2019-11-28	Kylene Orn	kylene.orn@woohoo.com	Aurora	Illinois	3718742951665881	8edc43ab6bbeb5089512e8cf48face05	Maestro	41.6957956163436165	-88.3831507642682652
6059	2019-11-28 16:22:40	2019-11-28	Adyson Miller	adyson.miller@geemail.com	Carlsbad	California	869933954889886130	c381fdd154d78af791741b83b0443035	VISA 16 digit	33.1175720018275044	-117.288154833928857
6060	2019-11-28 17:09:41	2019-11-28	Avah Huels	avah.huels@geemail.com	San Antonio	Texas	3096231391663900508	8ab60a04d178b171f1c906c18d173f79	JCB 16 digit	29.5693999074935903	-98.6051733461510338
6061	2019-11-28 17:58:29	2019-11-28	Kizzy Boyle	kizzy.boyle@geemail.com	Oakland	California	4841660653112890	451b6e5e59866c6601ec428b1590b7ee	JCB 16 digit	37.8063275884720511	-122.273051494894162
6062	2019-11-28 18:22:14	2019-11-28	Alex Hegmann DDS	alex.hegmann.dds@warmmail.com	San Francisco	California	51861485542394425	c0aeba9eaf0bac2c27f956c85d75ba2b	Mastercard	37.7572418136238852	-122.451266953090666
6063	2019-11-28 18:24:31	2019-11-28	Mr. Mckinley Blanda II	mr.mckinley.blanda.ii@geemail.com	San Francisco	California	3337181770828951318	7700c9f92d056716962373ea8653a0ba	VISA 13 digit	37.7785608207891102	-122.421110850388686
6064	2019-11-28 18:33:08	2019-11-28	Lakeisha Gutkowski	lakeisha.gutkowski@warmmail.com	Oakland	California	4594159894842174	eb91046dddfffcabb3293b8b6f1f3d57	VISA 16 digit	37.8231079799749139	-122.235796041756402
6065	2019-11-28 18:36:00	2019-11-28	Mr. Timmothy Pouros PhD	mr.timmothy.pouros.phd@geemail.com	New York	New York	4367175729270253	89136c151cb6ce7a61036b6695c977ae	VISA 16 digit	40.6987127003017832	-73.9891172464366917
6066	2019-11-28 19:06:40	2019-11-28	Joeseph Feil	joeseph.feil@geemail.com	Peoria	Arizona	869913608939684275	1e3476bedab845063e5767e187939689	Diners Club / Carte Blanche	33.6921020476415762	-112.359497027976445
6067	2019-11-28 20:14:59	2019-11-28	Nayeli Kunze	nayeli.kunze@woohoo.com	San Francisco	California	54519356538384017	c1615ce2f623622e4d27624d971a466c	Maestro	37.7477858474523558	-122.394243301698793
6068	2019-11-28 21:04:29	2019-11-28	Mia Smitham PhD	mia.smitham.phd@geemail.com	Houston	Texas	3761550016514788	cbfd13351ec9a70d5bc128904cc9f0e0	VISA 16 digit	29.7229818949088447	-95.3911227944787612
6069	2019-11-28 21:27:45	2019-11-28	Diamond Baumbach PhD	diamond.baumbach.phd@geemail.com	Greensboro	North Carolina	3702463900122076	ab412831ee996322ef1d82de352e186a	American Express	36.0740975588209949	-79.9193074029385997
6070	2019-11-28 22:01:51	2019-11-28	Archie Dickens	archie.dickens@woohoo.com	San Francisco	California	6011059829911274308	e8b87dff57457c158a88d797c20d7be0	Maestro	37.7848795464192193	-122.439355714339627
6071	2019-11-28 22:16:09	2019-11-28	Dr. Sam Wyman	dr.sam.wyman@geemail.com	Los Angeles	California	6011621543905621270	06e6fc68410124e29688031e00affbf4	VISA 13 digit	33.9694449113082086	-118.379518664254988
6072	2019-11-28 22:34:04	2019-11-28	Clifford Zieme	clifford.zieme@geemail.com	Tampa	Florida	3112641389990797435	7a4592ad77ff024b735a3f39ea8d71b5	JCB 16 digit	27.8987708733066917	-82.4046480859842063
6073	2019-11-28 22:38:06	2019-11-28	Colon Schultz	colon.schultz@geemail.com	Saint Paul	Minnesota	3528671852262183140	950e9d6a9edc1e7c733cb71af4b85e9f	JCB 16 digit	44.9643310722369733	-93.0729073714729367
6074	2019-11-28 23:31:35	2019-11-28	Audley Johnson	audley.johnson@geemail.com	Oakland	California	3337112558102658269	136872b76648f879397fe509cbbd715f	JCB 16 digit	37.7878868876861844	-122.244166170817039
6075	2019-11-28 23:45:35	2019-11-28	Mr. Garry O'Keefe	mr.garry.o'keefe@warmmail.com	Everett	Washington	4875116817349240	2fda9abad6dcb54213ebb39b76805b98	VISA 16 digit	48.0043583879139319	-122.223558489245917
6076	2019-11-29 00:24:14	2019-11-29	Desiree West-Hettinger	desiree.west.hettinger@warmmail.com	Joliet	Illinois	180001658292316068	08e2d05e197e198c5f1c8549d58488a6	Maestro	41.5535074431773239	-88.2132508771132677
6077	2019-11-29 00:29:03	2019-11-29	Jovanny Hahn-Lehner	jovanny.hahn.lehner@geemail.com	Tucson	Arizona	676281086201563	4851e59fe277955182ebe6176bdf964f	Mastercard	32.1543645752634859	-110.875703908246379
6078	2019-11-29 01:15:09	2019-11-29	Joey Von	joey.von@woohoo.com	New York	New York	4137823917851	2872ac579aaa64fdf62746469c494370	Voyager	40.6844685981739289	-73.8889358797937632
6079	2019-11-29 01:23:53	2019-11-29	Mr. Geoffrey Kulas	mr.geoffrey.kulas@geemail.com	Pembroke Pines	Florida	6011889929808615849	137940def8913bba96ef14ddb398d26b	Maestro	26.0542918021827958	-80.3179864856783325
6080	2019-11-29 01:47:00	2019-11-29	Dr. Randal Willms	dr.randal.willms@woohoo.com	Huntsville	Alabama	6011256675158252221	746ca662dc15e67af45d81ca79957277	Maestro	34.7207331831343424	-86.7724582563638762
6081	2019-11-29 01:52:05	2019-11-29	Pearlie McGlynn	pearlie.mcglynn@geemail.com	San Francisco	California	3013009867834895	ccde3627349e6e3bc1d0fe15c4965314	American Express	37.7332966442085578	-122.424460757196783
6082	2019-11-29 02:18:35	2019-11-29	Delmer Jast-Ritchie	delmer.jast.ritchie@woohoo.com	Athens	Georgia	3096164029775081004	f9ea6c24218c12bf6e73bee8a4af479b	JCB 16 digit	33.8899218996711014	-83.4273985240723874
6083	2019-11-29 02:49:21	2019-11-29	Oliver Schiller	oliver.schiller@geemail.com	San Francisco	California	4438896591433183	d5d27eae4643fc90898ebe94319fd54f	JCB 15 digit	37.7604982177552202	-122.422664384771323
6084	2019-11-29 03:07:52	2019-11-29	Effie Crona	effie.crona@geemail.com	Newark	New Jersey	4307702343037017	f80e384b108b3a6eade767d67b3730f8	JCB 15 digit	40.7802394580476033	-74.2300679048731951
6085	2019-11-29 03:47:12	2019-11-29	Karyl Reichert	karyl.reichert@warmmail.com	Minneapolis	Minnesota	210092518012710406	f5a7fea1fe179b9b41eeee754124e760	VISA 16 digit	45.0223350426267785	-93.2989386001873697
6086	2019-11-29 03:59:11	2019-11-29	Imani Langosh	imani.langosh@geemail.com	Raleigh	North Carolina	6011465067289733435	7a7f5bd533cc4ce33fa2783d880bd2ea	VISA 13 digit	35.7815726855438143	-78.7305650928460068
6087	2019-11-29 04:26:04	2019-11-29	Memphis Adams	memphis.adams@geemail.com	Irvine	California	3112130833228371487	e0e624a32952ee444306afbcc64db7fe	American Express	33.6409216859858518	-117.788433781826114
6088	2019-11-29 05:23:17	2019-11-29	Nicola Ebert	nicola.ebert@geemail.com	New York	New York	3707984181271071	8c844639426e44e904649f0e60843274	Diners Club / Carte Blanche	40.7514590235184855	-73.8743161784846336
6089	2019-11-29 06:10:23	2019-11-29	Neveah Christiansen	neveah.christiansen@geemail.com	San Francisco	California	4625535556496	ad49733b040f1e3579087bb842d71a0f	VISA 16 digit	37.787466971700681	-122.428096828864383
6090	2019-11-29 06:21:12	2019-11-29	Mr. Eddie Walter	mr.eddie.walter@geemail.com	San Francisco	California	180067309867482148	f93277a97d04128e3794fde511cbad49	Voyager	37.771213333097144	-122.421775993551805
6091	2019-11-29 06:56:35	2019-11-29	Ms. Metha Gaylord DVM	ms.metha.gaylord.dvm@geemail.com	San Francisco	California	3528060042968940105	24b9da1b3d07e008e00e01d6ba625fbb	JCB 16 digit	37.7707315664379308	-122.414585534187339
6092	2019-11-29 06:56:45	2019-11-29	Mr. Levon Nitzsche I	mr.levon.nitzsche.i@geemail.com	San Francisco	California	869993896446085358	bec45292c87a1d27c65e6c45b0fc6517	American Express	37.7536162297357265	-122.421446353534648
6093	2019-11-29 07:33:16	2019-11-29	Mamie Von	mamie.von@geemail.com	San Francisco	California	4860528327270	3c09548fc7d831765b84e4e6a669da3c	Voyager	37.7629102931921494	-122.442586642631213
6094	2019-11-29 08:24:45	2019-11-29	Riya Nikolaus	riya.nikolaus@geemail.com	Tucson	Arizona	3412047299518065	9e6e507bac4be03e70be36a00e43c58b	JCB 16 digit	32.2094917791005244	-110.927516720652946
6095	2019-11-29 09:14:16	2019-11-29	Reynolds Rowe	reynolds.rowe@geemail.com	Fort Wayne	Indiana	3039608591565073	c9358e5139bac48444ed4509ff57d3af	JCB 15 digit	41.0335481820877632	-85.228456420054286
6096	2019-11-29 09:16:36	2019-11-29	Mr. Alejandro Marvin	mr.alejandro.marvin@geemail.com	New York	New York	51648098009686934	74a0c398616aaf5bbc1d2884dfb6ca3c	JCB 16 digit	40.6634090000521411	-73.9951176612067911
6097	2019-11-29 09:32:54	2019-11-29	Dorathy Erdman	dorathy.erdman@geemail.com	San Francisco	California	210000990333892240	7a7668137d45819ac54d13d59af058c7	JCB 16 digit	37.7321044051779282	-122.42774982408524
6098	2019-11-29 09:33:22	2019-11-29	Mr. Coby Casper MD	mr.coby.casper.md@woohoo.com	Frisco	Texas	4797964476154483	756ae3107b142ae1410b8a12630af3ba	Mastercard	33.1247747800309185	-96.7441142233297171
6099	2019-11-29 09:53:56	2019-11-29	Leonia Kub-Willms	leonia.kub.willms@geemail.com	Miami	Florida	6011136551469443237	78dcf6047da426f3518daf0d5e894c55	American Express	25.7917069259237515	-80.3049004037272169
6100	2019-11-29 10:36:01	2019-11-29	Dr. Lavinia Bergnaum	dr.lavinia.bergnaum@geemail.com	San Francisco	California	210069318681402883	4e456373323f1af432b8e9856ad74dfe	JCB 15 digit	37.8029768677393818	-122.406632077647743
6101	2019-11-29 10:41:33	2019-11-29	Georgia Johns DDS	georgia.johns.dds@geemail.com	San Francisco	California	6011446922270045005	6c05de2d5c28fb8daa6bcacbd26faeaf	Voyager	37.7568377559814721	-122.425173756347846
6102	2019-11-29 11:06:14	2019-11-29	Van Cole	van.cole@geemail.com	New York	New York	4077045595830	3a0aec6c126941929d38e2654bea3ee0	Voyager	40.70222126340866	-73.9535121566977267
6103	2019-11-29 11:07:18	2019-11-29	Alijah Kihn	alijah.kihn@geemail.com	San Antonio	Texas	676249890259259	b3a22de900725bb2a0fbb72054c99ca2	JCB 16 digit	29.5268478578027356	-98.5785340629354039
6104	2019-11-29 11:34:24	2019-11-29	Cedric McGlynn	cedric.mcglynn@geemail.com	Denver	Colorado	4175746126899340	081497762b7401c95f394aaf21389127	JCB 16 digit	39.8000855731829972	-104.919907958550752
6105	2019-11-29 11:45:38	2019-11-29	Roscoe Bode	roscoe.bode@warmmail.com	Berkeley	California	4948254276865340	855e5ba22fe108d3d07d78bc1d23ad07	VISA 13 digit	37.8597071620936703	-122.294450528235515
6106	2019-11-29 12:05:11	2019-11-29	Aidan Moen	aidan.moen@geemail.com	Evansville	Indiana	869990120141793403	516deabf30172b6229b781ab299db12d	American Express	38.0787644402727423	-87.4900043417632531
6107	2019-11-29 12:09:19	2019-11-29	Janene Stanton	janene.stanton@geemail.com	Phoenix	Arizona	561218212376265	27b99bf3daf7e06af38108dc5a9a37c4	JCB 16 digit	33.6571849647842356	-112.043140004102526
6108	2019-11-29 13:21:08	2019-11-29	Dr. Connie Klocko Sr.	dr.connie.klocko.sr.@geemail.com	Winston–Salem	North Carolina	4104786299396	224f5e2b924b1f00790e18c5cdfc0c47	American Express	36.060171569441259	-80.3027531560175021
6109	2019-11-29 13:21:40	2019-11-29	Adolfo Gleason	adolfo.gleason@geemail.com	San Francisco	California	4327414123129057	8de93dfcb1f3198ee7beccf04f3fd3ab	JCB 16 digit	37.7569112349701044	-122.440198007542222
6110	2019-11-29 13:31:23	2019-11-29	Mr. Lanny Macejkovic	mr.lanny.macejkovic@geemail.com	San Francisco	California	6011755308718972486	f45c6d1a27ba36beb03192c6b0971d57	Maestro	37.7715756548586583	-122.409731018459311
6111	2019-11-29 13:35:33	2019-11-29	Verl Homenick-Ondricka	verl.homenick.ondricka@woohoo.com	San Francisco	California	561292721046180	0c01dfc8207541d341eb7205046d90f2	VISA 16 digit	37.7764390904826897	-122.414135318385007
6112	2019-11-29 13:37:11	2019-11-29	Cathey Hagenes	cathey.hagenes@geemail.com	San Francisco	California	3042044587071727	53e4529b4f26baa051a297b20653e910	Mastercard	37.7855049356640507	-122.458273512611115
6113	2019-11-29 13:42:31	2019-11-29	Miss Sibyl Huel	miss.sibyl.huel@warmmail.com	Cleveland	Ohio	3112960677280044077	bee9f6a705ac9a04c985223f90ebab34	Diners Club / Carte Blanche	41.412646260004486	-81.7147436412289778
6114	2019-11-29 14:12:50	2019-11-29	Reva Franecki	reva.franecki@warmmail.com	Chesapeake	Virginia	639075972291878	4874420487d3da03feaf5f71fbef0a4a	VISA 16 digit	36.7027325779438058	-76.3242633788224367
6115	2019-11-29 14:19:18	2019-11-29	Miss Isadora Hilpert	miss.isadora.hilpert@geemail.com	Escondido	California	4007503212719427	11af1d8d7705228d5fd831796734d11d	JCB 16 digit	33.1790225764963793	-117.056840897655107
6116	2019-11-29 15:39:54	2019-11-29	Woodroe Crona PhD	woodroe.crona.phd@geemail.com	Jacksonville	Florida	180059078167699301	4cfa8c3e44a492d047b05cb5dad0393d	VISA 16 digit	30.3462370948918156	-81.7020087390750689
6117	2019-11-29 15:53:21	2019-11-29	Opha Schroeder	opha.schroeder@woohoo.com	Indianapolis	Indiana	55136969684591517	18df6d9f5af744a35d065f5f7ce0ba66	JCB 16 digit	39.8628449097748856	-86.1843843715932252
6118	2019-11-29 16:10:23	2019-11-29	Erik Dicki DVM	erik.dicki.dvm@geemail.com	New York	New York	4981615412445726	4c0ee7ad188839a6918802aabf11bb05	VISA 16 digit	40.7206843383833785	-73.9075076811376874
6119	2019-11-29 16:52:15	2019-11-29	Ms. Mellie Gleichner	ms.mellie.gleichner@geemail.com	Joliet	Illinois	3528511178717101683	0bd5e1e6f96312e53e3d245567f4171f	JCB 16 digit	41.5926178482685245	-88.2477081604871785
6120	2019-11-29 18:21:18	2019-11-29	Gwen Emmerich	gwen.emmerich@warmmail.com	San Francisco	California	3112579515962455422	9792eabbc6866e4a47676b4bd3186f0f	Maestro	37.8003819249036539	-122.410165341259088
6121	2019-11-29 19:25:20	2019-11-29	Eldon Dietrich IV	eldon.dietrich.iv@geemail.com	San Francisco	California	4283075197139	6bae6d93f8cc4dbff8fdf89b391b63c0	VISA 16 digit	37.7659278823458209	-122.454403928279888
6122	2019-11-29 19:40:13	2019-11-29	Dr. Eda Haley	dr.eda.haley@geemail.com	Oakland	California	4316390148088	388e7428303ad35b6842704e11968565	Mastercard	37.8184616807543108	-122.298984492712449
6123	2019-11-29 19:46:02	2019-11-29	Wash Wuckert	wash.wuckert@geemail.com	Fort Worth	Texas	869988807456601155	1045cb9ac87b2db3d1f6cb4942928e08	JCB 15 digit	32.8574311357978743	-97.3499891012262566
6124	2019-11-29 19:59:53	2019-11-29	Hildegard Torp MD	hildegard.torp.md@geemail.com	San Jose	California	4560611530281	1357cc252ccf2321e1c5844ef89035a4	Diners Club / Carte Blanche	37.3817292980205309	-121.809695680833983
6125	2019-11-29 20:00:18	2019-11-29	Hebert Schultz	hebert.schultz@warmmail.com	Shreveport	Louisiana	3761224772875672	90dc15cf816d1ff596ccf6b54d7353ac	VISA 13 digit	32.4752788048475978	-93.797124907442182
6126	2019-11-29 21:18:18	2019-11-29	Celesta Thiel-Kessler	celesta.thiel.kessler@geemail.com	Los Angeles	California	3112252341736095053	7d597ec13a4ee62971370493ea60b978	Maestro	34.075301956418528	-118.409873844077055
6127	2019-11-29 21:18:59	2019-11-29	Miss Eulah Gerhold	miss.eulah.gerhold@geemail.com	Dallas	Texas	4887779530910436	4e133710601f0a93b5f8a16ca3017408	American Express	32.7980460410278312	-96.8333434525374201
6128	2019-11-29 21:20:43	2019-11-29	Zoe Walter	zoe.walter@woohoo.com	Cary	North Carolina	3088640661589020598	9fd14da138999e871c3505effe45b25f	VISA 13 digit	35.8059842530746053	-78.8914520255841296
6129	2019-11-29 21:21:34	2019-11-29	Kaylin Buckridge	kaylin.buckridge@geemail.com	El Paso	Texas	869924120526732142	ab513be6629186e9a57692cb5c729e13	JCB 16 digit	31.8012259544633338	-106.356244948364804
6130	2019-11-29 21:30:56	2019-11-29	Zella Wilkinson	zella.wilkinson@geemail.com	Glendale	Arizona	4379080715129	51fdf1e64c1d2d4ccf32a52a7c4a9141	Mastercard	33.5995778871927371	-112.123022882992018
6131	2019-11-29 21:54:25	2019-11-29	Risa Corwin MD	risa.corwin.md@geemail.com	San Diego	California	210080901058397276	3a0260d5466f3a73786081a05a16e2b2	Voyager	32.9015032557837657	-117.214815333755695
6132	2019-11-29 21:58:26	2019-11-29	Arvilla Donnelly-Abernathy	arvilla.donnelly.abernathy@geemail.com	Berkeley	California	6011563922862941543	4a5a5c1dddbba575fdc005e5163196d3	Diners Club / Carte Blanche	37.9014058516408241	-122.277642137870984
6133	2019-11-29 22:05:56	2019-11-29	Neveah Gulgowski	neveah.gulgowski@geemail.com	Washington	District of Columbia	869943998422157085	e56466b3184d3cfd64f8a802d48268f2	JCB 16 digit	38.8475189327061159	-76.951647114821526
6134	2019-11-29 22:10:33	2019-11-29	Dr. Noemi Strosin DDS	dr.noemi.strosin.dds@geemail.com	San Francisco	California	3758155455624620	3e3b3dae5f965d5ca83181476dc0263a	VISA 16 digit	37.7872511976371115	-122.429165106895482
6135	2019-11-29 22:35:11	2019-11-29	Lem Bogan	lem.bogan@warmmail.com	Dallas	Texas	4456700101847	0193d947ee50955d8cca4ae26ef551b0	Mastercard	32.7093447631496943	-96.7672602741476027
6136	2019-11-29 22:35:46	2019-11-29	Arlington Schaden Jr.	arlington.schaden.jr.@geemail.com	Philadelphia	Pennsylvania	3726076499585412	4ea0f1c97a50409049dd039af014c74f	VISA 13 digit	39.9847328105434769	-75.2221699166011177
6137	2019-11-29 22:39:34	2019-11-29	Rosalind Mitchell	rosalind.mitchell@geemail.com	San Francisco	California	210061694194363020	185919a8a4a0b758c0164f5f10ed3390	VISA 16 digit	37.803483260784148	-122.442254832109953
6138	2019-11-29 23:00:35	2019-11-29	Vira Keebler	vira.keebler@woohoo.com	Berkeley	California	3776498137555129	54bf022114a617c55453f4b57172e386	VISA 16 digit	37.9179545269250795	-122.275826935134248
6139	2019-11-29 23:02:13	2019-11-29	Denton Kshlerin	denton.kshlerin@geemail.com	Seattle	Washington	4899074434049	d62931b3f6c8f8fc6bf1b6c4fd883b1a	Mastercard	47.5462849378976955	-122.285881535654511
6140	2019-11-29 23:52:06	2019-11-29	Miss Evia Crona	miss.evia.crona@geemail.com	Boise	Idaho	4597706211989	9be181fbb8b51c18c99d555e24496693	JCB 16 digit	43.5979549182251134	-116.15349736057297
6141	2019-11-29 23:53:30	2019-11-29	Loyce Renner	loyce.renner@geemail.com	San Francisco	California	3016133401340222	d5b8634b933061fd546f20a3406ccf60	JCB 16 digit	37.7676052114539615	-122.451890482507864
6142	2019-11-30 01:41:18	2019-11-30	Bush Howe III	bush.howe.iii@geemail.com	Baltimore	Maryland	3714277035536406	29ab3939cb4ab7b3317441d323f88392	JCB 16 digit	39.3320728035643654	-76.6399340735301422
6143	2019-11-30 01:50:45	2019-11-30	Junious Cummings	junious.cummings@geemail.com	McKinney	Texas	3088093081389138379	e0952d21ffb703d9c9cacf6b433422fa	JCB 15 digit	33.2411077161449953	-96.5946883500386093
6144	2019-11-30 01:53:57	2019-11-30	Elianna Mayert PhD	elianna.mayert.phd@geemail.com	Miami	Florida	3337675178837478054	0ac6fe918260260211cfe2f53efc93ba	VISA 16 digit	25.7495842238560328	-80.2562448590867206
6145	2019-11-30 02:07:10	2019-11-30	Tod Nolan I	tod.nolan.i@woohoo.com	Berkeley	California	4223037511530	cf19b7a46d9f434aae052748c5395452	JCB 16 digit	37.9079223955411422	-122.247715522734822
6146	2019-11-30 02:13:51	2019-11-30	Early Ruecker	early.ruecker@geemail.com	Oklahoma City	Oklahoma	180033084299968425	c21acfa2e0c6e47fa3d703a32dd31107	JCB 16 digit	35.5406025872476405	-97.5650134207110824
6147	2019-11-30 02:57:39	2019-11-30	Ms. Marlena Weimann	ms.marlena.weimann@warmmail.com	Oakland	California	3158364996935628890	4e8702fcaee9360ec360c6d7a01e39c9	VISA 16 digit	37.805510392649829	-122.285964056426067
6148	2019-11-30 02:59:41	2019-11-30	Gretchen Littel	gretchen.littel@geemail.com	Nashville	Tennessee	869980980666194572	5b663aeecad16e5d672c231a7c8ac14a	JCB 16 digit	36.1755465178407718	-86.8406403364520543
6149	2019-11-30 03:03:15	2019-11-30	Mr. Hollis Berge	mr.hollis.berge@geemail.com	Los Angeles	California	4448328533293762	01c509807df08a857ae6d4c395eda579	American Express	33.971043767021591	-118.46261340146809
6150	2019-11-30 03:26:17	2019-11-30	Heath Romaguera MD	heath.romaguera.md@geemail.com	Newport News	Virginia	3722638352602834	4204b8d89dfdf09c516c6005242fca12	American Express	37.153056984803456	-76.553932279048496
6151	2019-11-30 03:40:18	2019-11-30	Annmarie Toy	annmarie.toy@warmmail.com	San Francisco	California	676249781349326	ab05b9b0743b520e9d488129f996b2d8	VISA 16 digit	37.7745927253407743	-122.411901357999298
6152	2019-11-30 03:52:31	2019-11-30	Owen Waters Sr.	owen.waters.sr.@geemail.com	Berkeley	California	3088098911563188631	285ee9a4b64d5a32360430f950cdeaf4	Mastercard	37.8750085537905576	-122.284421048955849
6153	2019-11-30 04:04:27	2019-11-30	Thad Kub	thad.kub@geemail.com	Amarillo	Texas	52077165672926770	112b5932ed2ef54b550efcff465df64f	Diners Club / Carte Blanche	35.2596064184024911	-101.790235335086294
6154	2019-11-30 04:58:17	2019-11-30	Riley Vandervort	riley.vandervort@warmmail.com	Huntsville	Alabama	3043586395574952	282a160e5e1c527e748c093c46a6a363	Voyager	34.7988302506748539	-86.7038055725879957
6155	2019-11-30 05:09:57	2019-11-30	Dr. Kelby Abshire PhD	dr.kelby.abshire.phd@geemail.com	Wichita	Kansas	180048082648945139	4c47a226d90ced293b56659fd29d0240	Discover	37.611888881900164	-97.3816882381882465
6156	2019-11-30 05:21:57	2019-11-30	Shane Stokes	shane.stokes@geemail.com	San Francisco	California	3158543601286904775	0c0bbb0bee0de2c9bdc2ae43f0cacfbb	Maestro	37.7759118553598725	-122.405536549417732
6157	2019-11-30 05:37:08	2019-11-30	Ason Orn PhD	ason.orn.phd@geemail.com	Oakland	California	869950539516603640	cce032215d1930328a6c118bff200df2	VISA 16 digit	37.8046768893852914	-122.269203964526028
6158	2019-11-30 05:52:26	2019-11-30	Nannie Thiel	nannie.thiel@geemail.com	Oakland	California	180065599194075019	459a8cda5a57ab0555c22a9c5d3cdef3	JCB 16 digit	37.811438860667586	-122.27679137178049
6159	2019-11-30 06:09:21	2019-11-30	Ms. Ciarra Okuneva PhD	ms.ciarra.okuneva.phd@woohoo.com	Detroit	Michigan	6011639842696538465	5b439ca1c03c61e574ddd1422f2b710f	JCB 16 digit	42.4194105081185739	-83.1232520059801629
6160	2019-11-30 07:14:16	2019-11-30	Mannie Abbott	mannie.abbott@geemail.com	Philadelphia	Pennsylvania	6011278369716110907	a1e7f74d3750d675e94aebc76c1ad7a5	JCB 16 digit	39.9709647072903778	-75.1849563993413028
6161	2019-11-30 07:29:38	2019-11-30	Woodrow Roberts	woodrow.roberts@geemail.com	Columbus	Ohio	3096737008350160175	84d30747a201b40cd6b6f4cc56371b5b	VISA 16 digit	40.0605983217757213	-83.0322391212687023
6162	2019-11-30 08:10:10	2019-11-30	Emmer McDermott DVM	emmer.mcdermott.dvm@geemail.com	New York	New York	3035198179927477	382fc3a9c26c31f9aecbdd5484cd6a1f	Voyager	40.6780592889748505	-73.8986926199298324
6163	2019-11-30 08:11:26	2019-11-30	Sasha Runolfsson	sasha.runolfsson@geemail.com	San Francisco	California	869917972827526329	83853abd22ae8b1d7df5dacd5583658d	JCB 16 digit	37.8011115230600652	-122.433783467765394
6164	2019-11-30 08:18:45	2019-11-30	Toby O'Keefe	toby.o'keefe@geemail.com	Oakland	California	630428226542190	4442730e0fcd152683baa5492367bd72	Maestro	37.8053263277536118	-122.26564089577883
6165	2019-11-30 08:51:51	2019-11-30	Miss Kristine Gorczany DDS	miss.kristine.gorczany.dds@geemail.com	Worcester	Massachusetts	3009235983730121	f0a551b0263849857e7df8a5532f6926	American Express	42.2551439458206275	-71.8865939398549472
6166	2019-11-30 09:02:42	2019-11-30	Merrilee Dare	merrilee.dare@woohoo.com	Tallahassee	Florida	3030821179741292	1762dcb072d564ab5056464b6419acbf	VISA 16 digit	30.4693169271130131	-84.2252157161958479
6167	2019-11-30 09:39:12	2019-11-30	Lorinda Cummerata	lorinda.cummerata@geemail.com	Cambridge	Massachusetts	3096368230705050895	b95103c22b8c81da2890d1c86dd77245	VISA 13 digit	42.4168961125649489	-71.1058956085320659
6168	2019-11-30 10:59:53	2019-11-30	Yancy Erdman	yancy.erdman@geemail.com	Fresno	California	4467892126466586	a94d6e5bdd398d0d063396c5cb45601d	VISA 16 digit	36.7751215215180096	-119.881294984008747
6169	2019-11-30 11:23:34	2019-11-30	Teri Bogan	teri.bogan@geemail.com	Garland	Texas	3417303093384427	95ecc9e639ea0774bed4b9b2bf3bdea2	Voyager	32.9690948812525662	-96.5817441716484808
6170	2019-11-30 11:33:22	2019-11-30	Shalon Sipes	shalon.sipes@geemail.com	San Diego	California	3096999366084593324	02388d4ff19406224d845dd786f17821	JCB 16 digit	32.9064966011393807	-117.160304752541705
6171	2019-11-30 13:21:53	2019-11-30	Cary Okuneva	cary.okuneva@geemail.com	Boulder	Colorado	869911772809669956	a2d4e2668507624454854e453eff82c0	JCB 16 digit	39.9631296446993929	-105.293358207694823
6172	2019-11-30 13:22:47	2019-11-30	Westin Bogisich	westin.bogisich@warmmail.com	Oakland	California	51241914510126858	a69755461158f17e02e0ee6464e209f1	Mastercard	37.8580489954378052	-122.269264714662199
6173	2019-11-30 13:34:37	2019-11-30	Clyde Jenkins	clyde.jenkins@geemail.com	San Francisco	California	180044659995279776	1288c5db805b8df38c337258d8b9e93e	Mastercard	37.7635491584707879	-122.439795086241844
6174	2019-11-30 15:28:03	2019-11-30	Dr. Alonzo Prohaska Sr.	dr.alonzo.prohaska.sr.@warmmail.com	Memphis	Tennessee	3469266567628420	b945ee26685308ea28da7819606bdc91	VISA 16 digit	35.0046618864938637	-90.0209693427454738
6175	2019-11-30 15:44:50	2019-11-30	Corliss Lowe DVM	corliss.lowe.dvm@geemail.com	Reno	Nevada	3337590693494183807	3a0ac60d5ea118e977419c0c66a61501	VISA 16 digit	39.5848580582611262	-119.788695263925575
6176	2019-11-30 15:55:04	2019-11-30	Vinie Osinski	vinie.osinski@woohoo.com	San Francisco	California	4382568943793988	3445dd2da7692d62b7605a6145bf6ff3	JCB 16 digit	37.7996178764418147	-122.423019840828729
6177	2019-11-30 16:16:38	2019-11-30	Miss Loren Feest DVM	miss.loren.feest.dvm@geemail.com	San Francisco	California	502011187761744	f6e09b5d1b352652884fe28fbd07ca2b	Discover	37.7962354782103134	-122.436048625488979
6178	2019-11-30 16:33:58	2019-11-30	Anabel Ortiz	anabel.ortiz@warmmail.com	Norwalk	California	4072498062271	4d56d62c288d9205a7cf243dd59ba0a9	American Express	33.8123677841037562	-118.124984845196835
6179	2019-11-30 16:35:43	2019-11-30	Wayland Vandervort	wayland.vandervort@woohoo.com	Los Angeles	California	4399103131455975	63c0f38b6da58005e0e782fca5155fb1	JCB 16 digit	34.0365668909024421	-118.45297121717519
6180	2019-11-30 16:56:11	2019-11-30	Andrew Kozey-Mante	andrew.kozey.mante@geemail.com	Sacramento	California	869947057944782460	fa4493577706a6f449091af04e2dfaff	Voyager	38.551330100864547	-121.397091619974375
6181	2019-11-30 17:16:55	2019-11-30	Rhett Rutherford	rhett.rutherford@geemail.com	San Francisco	California	3021891825069710	ac44f81965ad43d901a2b40a4d4b959c	JCB 16 digit	37.764589020041484	-122.438897437613193
6182	2019-11-30 17:31:14	2019-11-30	Dr. Susie Hamill	dr.susie.hamill@geemail.com	San Francisco	California	210042301318555770	7ab32dcf4a92f46e4b6abbcdb9789242	JCB 15 digit	37.7891170710434068	-122.415486582768011
6183	2019-11-30 18:33:30	2019-11-30	Long Mitchell-Ryan	long.mitchell.ryan@woohoo.com	Berkeley	California	180043695568090936	c822210b6939b613f200d176ac4f5a46	Mastercard	37.8607542699591093	-122.269320366263173
6184	2019-11-30 18:50:53	2019-11-30	Adah Murray	adah.murray@geemail.com	San Francisco	California	3337725790887917698	ed38cb263d8a4ab85a06fc5943a8b686	Diners Club / Carte Blanche	37.7968401725899881	-122.426409582645249
6185	2019-11-30 18:53:33	2019-11-30	Cristofer Fadel	cristofer.fadel@geemail.com	Tucson	Arizona	3096026303257936458	5d29379cfd2d45690c14261bf8569bea	Maestro	32.1148088172584778	-110.778776140440627
6186	2019-11-30 19:24:36	2019-11-30	Kurtis Leffler	kurtis.leffler@geemail.com	San Francisco	California	675930661083201	419410c7055d42118bce299b06a09a4f	VISA 13 digit	37.7470620925471607	-122.469602657298466
6187	2019-11-30 20:21:26	2019-11-30	Dr. Wayman Rowe	dr.wayman.rowe@geemail.com	Denton	Texas	4556028413134882	f55c704474c621325b9b57d8f205833e	VISA 16 digit	33.132753706237672	-97.2319346693005429
6188	2019-11-30 21:06:52	2019-11-30	Trilby Dickinson	trilby.dickinson@geemail.com	San Francisco	California	3088289064779197233	1e164190217c2d16c9c18812308c7be6	VISA 16 digit	37.7130055444195591	-122.473331418252144
6189	2019-11-30 21:18:41	2019-11-30	Lorna Pollich	lorna.pollich@geemail.com	Clinton	Michigan	6011916507128929681	f60a1da03c58f1028a29b6627ad95c22	VISA 16 digit	42.5555482272591448	-82.9695395842269079
6190	2019-11-30 21:31:55	2019-11-30	Miss Tiffani McDermott	miss.tiffani.mcdermott@geemail.com	North Las Vegas	Nevada	4417390351286671	a426ba5ee9a17a4f16518e987c15d115	JCB 16 digit	36.2535769735619411	-115.175746215762203
6191	2019-11-30 23:36:00	2019-11-30	Mrs. Melodee Hirthe MD	mrs.melodee.hirthe.md@warmmail.com	San Francisco	California	4613720989367513	148e9b0640ce891c5bffc0da85a75fbf	Maestro	37.7964092609443725	-122.460652034645022
6192	2019-12-01 00:34:19	2019-12-01	Mrs. Ashley Rippin PhD	mrs.ashley.rippin.phd@geemail.com	New York	New York	3780012326214713	ea6e29a8020484263a5fa60774f01239	JCB 16 digit	40.756778485909102	-73.97544498056061
6193	2019-12-01 01:02:25	2019-12-01	Jerrold Kemmer	jerrold.kemmer@warmmail.com	Irvine	California	4417184796270	b98fe14586f1b124914c9426212978e7	VISA 16 digit	33.6304503486041	-117.76989732934274
6194	2019-12-01 01:06:44	2019-12-01	Kayden Halvorson	kayden.halvorson@geemail.com	Winston–Salem	North Carolina	3088062443944052429	cd5b58ea41fe902ced61ea6c0dd3e907	VISA 13 digit	36.0160446651976542	-80.1985086754560399
6195	2019-12-01 02:13:16	2019-12-01	Sim Parker	sim.parker@geemail.com	San Francisco	California	3088203204964396165	09a447bc45a5323464b5726bac1949b7	VISA 16 digit	37.7738967564025998	-122.432319379550492
6196	2019-12-01 02:32:59	2019-12-01	Levy Windler	levy.windler@geemail.com	San Francisco	California	3088244304200876615	460249995a7406d8a947197b6f586888	Maestro	37.7912458650505698	-122.409241303684567
6197	2019-12-01 02:56:28	2019-12-01	Madelene Emmerich	madelene.emmerich@geemail.com	Aurora	Illinois	3337926302506524959	47f87d32783eb5b0d8e6f05d52048ba5	JCB 15 digit	41.6910708457920691	-88.3348699096053736
6198	2019-12-01 02:58:44	2019-12-01	Dr. Lou McKenzie	dr.lou.mckenzie@geemail.com	Omaha	Nebraska	4106204519844782	06bca61577ed7abfe06f1ba17464615b	VISA 13 digit	41.2985896786820135	-96.035249570489313
6199	2019-12-01 03:02:44	2019-12-01	Ms. Izabelle Lowe	ms.izabelle.lowe@geemail.com	San Francisco	California	3788732537737341	c7d398f2a25bc1e8f16b607817f14765	Diners Club / Carte Blanche	37.7841008067236146	-122.456997218643679
6200	2019-12-01 03:18:37	2019-12-01	Adlai Rippin PhD	adlai.rippin.phd@geemail.com	Dallas	Texas	869986818925352082	061baf6b3245da215158bad5241e9bb9	VISA 16 digit	32.8656161006812013	-96.6913771569225844
6201	2019-12-01 04:02:25	2019-12-01	Efrem McClure	efrem.mcclure@geemail.com	Kansas City	Missouri	3047309210734016	707f1fb01e9179a1f630a1540211fc8f	JCB 15 digit	39.1773403696551981	-94.4544138544462584
6202	2019-12-01 04:51:44	2019-12-01	Ima Hahn DVM	ima.hahn.dvm@warmmail.com	Oakland	California	3158517356105967675	92b981ace51edcf525abd57f44cea31f	JCB 16 digit	37.7944377363879624	-122.276174634184912
6203	2019-12-01 05:00:03	2019-12-01	Myrna VonRueden DDS	myrna.vonrueden.dds@geemail.com	Philadelphia	Pennsylvania	869920741967450045	d78e2949258f406adf1a5455880258de	JCB 16 digit	40.0623030166566352	-75.1346397551141791
6204	2019-12-01 05:10:43	2019-12-01	Mabelle Beier	mabelle.beier@warmmail.com	Berkeley	California	561267802355700	44d75acd99357765fa5cd6f348e87396	JCB 16 digit	37.8643526124319578	-122.256968626277995
6205	2019-12-01 05:15:16	2019-12-01	Anona Daugherty	anona.daugherty@geemail.com	Cincinnati	Ohio	4398106387259	d347502339e00750983420ce1704ac25	JCB 15 digit	39.0612780582390755	-84.4629259506046708
6206	2019-12-01 05:19:40	2019-12-01	Gerold Mertz	gerold.mertz@warmmail.com	Virginia Beach	Virginia	869930336607790856	fec9ae54c0d8e8452dc5ec4ea5241ea4	American Express	36.7822986724972765	-76.0461442879538936
6207	2019-12-01 05:23:58	2019-12-01	Mareli Schamberger	mareli.schamberger@geemail.com	Costa Mesa	California	3096870758826146680	2c93d57c406840f4926ec7ea43cb9fc8	JCB 16 digit	33.5859566203799105	-117.976763378302749
6208	2019-12-01 06:19:43	2019-12-01	Claire Becker	claire.becker@geemail.com	Glendale	California	55533279232601811	9ee7c998f52cb91927084a77e7fe86cb	JCB 16 digit	34.1602818591739918	-118.313884289506078
6209	2019-12-01 07:02:49	2019-12-01	Wilma Harris-Abernathy	wilma.harris.abernathy@warmmail.com	Berkeley	California	4369240472472361	67d9843fdb2bd63afe1c4a0418153712	VISA 16 digit	37.8740319498775619	-122.254506385480028
6210	2019-12-01 07:36:29	2019-12-01	Acy Torp	acy.torp@geemail.com	Elk Grove	California	3337385127754759716	57a06b777ee68d2c3ec553e991d43b5c	JCB 16 digit	38.3846979142449811	-121.361723127160232
6211	2019-12-01 07:51:59	2019-12-01	Houston Welch	houston.welch@woohoo.com	Chicago	Illinois	060418548245606	93ce8cb4a5760236e76e40064826ebf6	American Express	41.7838539166677734	-87.6595455922681737
6212	2019-12-01 08:00:02	2019-12-01	Georgianna Kovacek	georgianna.kovacek@warmmail.com	Tempe	Arizona	4342231439982982	8fe6d5c36007c20bbbb6346d4bb34246	Discover	33.34176392545141	-111.946503090861441
6213	2019-12-01 08:03:27	2019-12-01	Derrick Rempel	derrick.rempel@geemail.com	Rochester	New York	3035070151793880	ac88f9f8604ff735270f50f6899c3ed0	American Express	43.1005931007653444	-77.6202764355816015
6214	2019-12-01 08:10:25	2019-12-01	Allyson Shields-Franecki	allyson.shields.franecki@warmmail.com	Houston	Texas	4736244693400694	b16d00eedaf8369f4b5a7ed305790222	American Express	29.7146014998279497	-95.3442083389513186
6215	2019-12-01 08:20:56	2019-12-01	Precious Gutmann	precious.gutmann@warmmail.com	Detroit	Michigan	4981195911127265	3a1e2a2028dabca179d27b697a0a94c0	VISA 16 digit	42.3540002204403336	-83.099150733754783
6216	2019-12-01 08:24:29	2019-12-01	Oliva Frami-Bogan	oliva.frami.bogan@geemail.com	San Francisco	California	4105015967485584	9e97af0bd0303ad97b3d5e3d0a8748e6	VISA 16 digit	37.7770458455224514	-122.426352892959557
6217	2019-12-01 08:48:56	2019-12-01	Kyle Wisoky	kyle.wisoky@geemail.com	New York	New York	3096593592611489468	4255740267c24b9d382612aa65ca70e2	VISA 13 digit	40.5752810604628138	-73.9746249961096822
6218	2019-12-01 08:52:00	2019-12-01	Mr. Tegan Hahn	mr.tegan.hahn@geemail.com	Murrieta	California	3337907675624532613	3dc7b38e8329d82cb585557684bf6475	VISA 13 digit	33.6553328482996648	-117.274414705196023
6219	2019-12-01 08:54:55	2019-12-01	Dr. Buford Hermiston MD	dr.buford.hermiston.md@geemail.com	Toledo	Ohio	3795135938619103	1538a07faf4bc3445c71917a7be6b45b	VISA 16 digit	41.6072842585094236	-83.5732126979954586
6220	2019-12-01 09:03:34	2019-12-01	Guadalupe Schneider	guadalupe.schneider@warmmail.com	San Francisco	California	869974268865372340	c6c0a2fa8c55a3661b1a03bd0f0c7e98	VISA 16 digit	37.7911921574485632	-122.428636781818511
6221	2019-12-01 09:12:02	2019-12-01	Dr. Almond Jacobs	dr.almond.jacobs@geemail.com	Berkeley	California	3096008597641961104	f2205dcdeaa32da49d713ab6ffdb272b	Discover	37.8781412468668535	-122.277959864103238
6222	2019-12-01 09:57:20	2019-12-01	Rochelle Schumm	rochelle.schumm@geemail.com	Salt Lake City	Utah	3112781135826473646	0e3c7382db9238a853f3f26e7bec4573	Diners Club / Carte Blanche	40.8005031080596154	-111.837298125023025
6223	2019-12-01 10:06:31	2019-12-01	Mrs. Tea Kuvalis	mrs.tea.kuvalis@geemail.com	Charlotte	North Carolina	4810168392195090	f60fa9011ef48a35e6f314d187dbd482	Diners Club / Carte Blanche	35.271621246335279	-80.8619470490086911
6224	2019-12-01 10:16:07	2019-12-01	Caryl Pfeffer	caryl.pfeffer@warmmail.com	San Francisco	California	3096383800005600275	f72aa98889d1d2aeec6fa603586ba89b	VISA 16 digit	37.7652032517400968	-122.429718489817347
6225	2019-12-01 11:13:19	2019-12-01	Lisette Kub	lisette.kub@geemail.com	Tulsa	Oklahoma	3528227544946633306	8c0c646efaa6fd1d00a3686ee6e56a4a	Diners Club / Carte Blanche	36.1680678279973549	-95.9257281299170046
6226	2019-12-01 12:24:11	2019-12-01	Mrs. Clarisa Walter	mrs.clarisa.walter@geemail.com	Oakland	California	4631925468513556	bbf32bce76ad64ed230104b472b805e9	VISA 13 digit	37.7829818125807151	-122.269210107175979
6227	2019-12-01 12:44:27	2019-12-01	Parrish Beer	parrish.beer@woohoo.com	Cape Coral	Florida	676382954798698	cbf70858064c38ac52712f21bc6759d4	Maestro	26.6575286566715697	-81.9437983648456623
6228	2019-12-01 13:03:21	2019-12-01	Harriet Carter	harriet.carter@woohoo.com	New York	New York	869911523287942864	7a7b3d91a71d82f812c5389c56e7c82f	Voyager	40.6422562986370153	-73.9951739361871006
6229	2019-12-01 13:27:49	2019-12-01	Mr. Loney Raynor	mr.loney.raynor@woohoo.com	Provo	Utah	6011448275581350392	353bb366ccdc5490e2c586ba90612c9d	JCB 16 digit	40.2851864226881418	-111.562277632593364
6230	2019-12-01 13:42:58	2019-12-01	Joell Zemlak-Shields	joell.zemlak.shields@geemail.com	Austin	Texas	210073202445504032	513976132788d3bd45d893a5a7ef550e	Voyager	30.3541577375620584	-97.6674467704962979
6231	2019-12-01 13:49:56	2019-12-01	Mr. Adolph Grady I	mr.adolph.grady.i@geemail.com	New York	New York	630481149149783	931a065bcfb27a853436e486d2bd972d	JCB 15 digit	40.7523463268987811	-74.0047952322650673
6232	2019-12-01 14:09:04	2019-12-01	Santino Becker	santino.becker@geemail.com	San Francisco	California	869966372285418871	b922bdaa36505c375796075b0540670a	JCB 15 digit	37.7780368978815559	-122.438331140820935
6233	2019-12-01 14:26:31	2019-12-01	Delos Stroman I	delos.stroman.i@geemail.com	Colorado Springs	Colorado	180023602502619238	2baa4d8b5eae859fa1511c3c6b5ab958	Mastercard	38.7766444940168427	-104.774846785903719
6234	2019-12-01 14:32:21	2019-12-01	Chrissy Ferry	chrissy.ferry@geemail.com	Cary	North Carolina	4053542493738	98a19af97df7f49c4d452f10f34019b2	Maestro	35.7607222457524401	-78.8283958277750685
6235	2019-12-01 14:32:45	2019-12-01	Shea Parisian-Langosh	shea.parisian.langosh@geemail.com	San Francisco	California	3112774559150632833	7e8178048526c770c305e122dd13dc99	VISA 16 digit	37.7668434206894332	-122.446285085333244
6236	2019-12-01 14:43:53	2019-12-01	Selmer Cremin	selmer.cremin@geemail.com	San Francisco	California	4461096675582613	422381bba9d80679ad2cbf9c0660f008	American Express	37.8173536121363512	-122.422106662927177
6237	2019-12-01 15:04:05	2019-12-01	Rory Bechtelar	rory.bechtelar@geemail.com	Kansas City	Missouri	55975266813411640	9e35452ffa5faf99975bf1c48a213077	Voyager	39.0300235955346437	-94.5417298408448659
6238	2019-12-01 15:40:59	2019-12-01	Mrs. Bethann Ernser	mrs.bethann.ernser@geemail.com	San Francisco	California	4372045300328023	324947eee72c82d6f5a4998bdd05cfe6	JCB 16 digit	37.7558554891477129	-122.441322085257752
6239	2019-12-01 15:41:29	2019-12-01	Libbie Herman	libbie.herman@geemail.com	Dallas	Texas	3014069168760560	8e7563a63c90134f68767e1b2baeb3d0	JCB 16 digit	32.707397484154626	-96.8033865188676828
6240	2019-12-01 15:42:58	2019-12-01	Shawnna McKenzie	shawnna.mckenzie@geemail.com	Houston	Texas	676204800436687	5905a3052079f352c18511158e556f84	American Express	29.7374052290417268	-95.4218479991905468
6241	2019-12-01 15:51:56	2019-12-01	Abram Schaefer	abram.schaefer@geemail.com	Albuquerque	New Mexico	54139293242138035	eaee4db66961e71f65b5d7236d7d4cba	VISA 13 digit	35.0509033002093489	-106.707565835497903
6242	2019-12-01 16:00:37	2019-12-01	Luciano Tromp Jr.	luciano.tromp.jr.@geemail.com	San Francisco	California	6011973810284539785	aff7922d4d7c3a5aba180b41bdbbc81e	Diners Club / Carte Blanche	37.78102819812284	-122.448632634723253
6243	2019-12-01 16:02:23	2019-12-01	Tilman Homenick	tilman.homenick@woohoo.com	San Francisco	California	210078402415230031	b7980233166c7e8dd772d391562c7175	Mastercard	37.7513702895962027	-122.407474154247197
6244	2019-12-01 17:28:03	2019-12-01	Ally Hintz-Roberts	ally.hintz.roberts@warmmail.com	Chicago	Illinois	51141002031914522	24cbc57948dd563ed5862492f0fd4c34	JCB 16 digit	41.7735995285980408	-87.6109016660630715
6245	2019-12-01 18:16:16	2019-12-01	Shara Borer DDS	shara.borer.dds@geemail.com	San Angelo	Texas	3029710454825410	b4b8dcdbe300579f9b57003c1f45d1b0	JCB 16 digit	31.3961085139460856	-100.408976602798333
6246	2019-12-01 19:26:04	2019-12-01	Aracely Kuhic	aracely.kuhic@geemail.com	San Francisco	California	639010926487298	d1819678074b41ee39b488a650b190a2	American Express	37.7556967791891722	-122.43942929402651
6247	2019-12-01 19:43:03	2019-12-01	Fiona O'Hara	fiona.o'hara@geemail.com	San Francisco	California	210024807327816815	936f9d790adaff3b3af0faa0d0d6cba6	JCB 16 digit	37.7648961038735109	-122.438380914197069
6248	2019-12-01 20:04:36	2019-12-01	Mr. Alessandro O'Hara	mr.alessandro.o'hara@geemail.com	San Francisco	California	3042622846070331	23146ae3ffe0761824e93154001b97eb	VISA 16 digit	37.7673619073088886	-122.415174191988257
6249	2019-12-01 20:09:02	2019-12-01	Spencer Waters	spencer.waters@geemail.com	Lakeland	Florida	3337329649508411269	f144a28ef0765a713aacb319a4fb0265	JCB 16 digit	27.9857506405860157	-81.8873721066746754
6250	2019-12-01 20:20:58	2019-12-01	Becky Howell	becky.howell@woohoo.com	San Francisco	California	869932285093021060	15ca2f6f9366afaaebd8734e7fcb3a76	Discover	37.8099814023515819	-122.430755058088593
6251	2019-12-01 21:24:04	2019-12-01	Cheryll Bechtelar	cheryll.bechtelar@woohoo.com	Dallas	Texas	675963069668174	465d669a71b312014bef5cc4c3a53fb7	Maestro	32.7095040481809534	-96.7083723773211119
6252	2019-12-01 21:40:47	2019-12-01	Roseanna Bode	roseanna.bode@geemail.com	Temecula	California	3006808313574881	f6f8bfd62427dc09a074d5136472c83e	VISA 16 digit	33.5647975039336828	-117.199777634274952
6253	2019-12-01 21:49:09	2019-12-01	Sonia Shields	sonia.shields@warmmail.com	Fremont	California	4398092569955963	98b248fd4a258cc223ce12b906aff422	Diners Club / Carte Blanche	37.5461307835001534	-121.940318653545148
6254	2019-12-01 23:01:35	2019-12-01	Lucian Boehm I	lucian.boehm.i@warmmail.com	Berkeley	California	4774379384463776	665b2e521a874e04b2123070ceab2410	VISA 16 digit	37.860272480317704	-122.226480381202109
6255	2019-12-01 23:02:25	2019-12-01	Carter Schulist	carter.schulist@geemail.com	Centennial	Colorado	3096969707127291879	be15420293567fbfbf24117791e2e203	JCB 15 digit	39.6084710643667748	-104.775538482645899
6256	2019-12-01 23:17:44	2019-12-01	Zollie Lockman	zollie.lockman@geemail.com	Lexington	Kentucky	3760144044701244	232a9bd62c6980509b448faf5600b581	VISA 13 digit	38.0337875004269179	-84.482479144436482
6257	2019-12-01 23:22:47	2019-12-01	Tyrell Mohr	tyrell.mohr@geemail.com	New York	New York	3528435028315444790	3b5d2e372bc81b996474f56398f98ed5	Voyager	40.6480933146774746	-73.9610876228090319
6258	2019-12-02 00:11:35	2019-12-02	Abel Champlin	abel.champlin@woohoo.com	Westminster	Colorado	4963966892900009	87e0f2398922c5e3d347cffba6da8102	VISA 16 digit	39.8354270275056308	-105.010527485344198
6259	2019-12-02 00:21:29	2019-12-02	Jovany Stroman	jovany.stroman@geemail.com	Los Angeles	California	3337595392214731640	9293e41d5b28b2e97281fcd0cc27ec16	VISA 13 digit	33.99000878262855	-118.416838584001354
6260	2019-12-02 00:35:18	2019-12-02	Hazle Kihn	hazle.kihn@woohoo.com	Denver	Colorado	3158983644674228107	e84e886e095c547f9780ea897815c663	JCB 15 digit	39.7011272760625928	-104.884618734220425
6261	2019-12-02 01:15:38	2019-12-02	Tennessee Windler	tennessee.windler@geemail.com	Las Cruces	New Mexico	675995863631073	4fd9829937414bbf2cee9f3588066b5c	VISA 16 digit	32.2967447392210332	-106.693728157284482
6262	2019-12-02 01:34:56	2019-12-02	Suellen Towne	suellen.towne@geemail.com	Coral Springs	Florida	4608898541559137	380913efe0f5406a29b5c29bfb984fa6	Maestro	26.3143145871877699	-80.3034311167087367
6263	2019-12-02 01:44:53	2019-12-02	Dr. Wood Vandervort	dr.wood.vandervort@geemail.com	Vancouver	Washington	3018411731170834	e73328b7f4263814866a46f6364db62b	VISA 13 digit	45.7269067462604539	-122.509446907794839
6264	2019-12-02 02:42:22	2019-12-02	Dario Feest	dario.feest@geemail.com	San Francisco	California	3088733152727375506	fe77b4f79324a71fee3536cc4bf56503	JCB 16 digit	37.7919574152655429	-122.442899803069551
6265	2019-12-02 02:59:55	2019-12-02	Windy Grant	windy.grant@geemail.com	Berkeley	California	3088523201432717793	f8dc9596f7e5cd2da6d923dd029c5130	Voyager	37.8803400822588046	-122.277739849989302
6266	2019-12-02 03:09:52	2019-12-02	Verdie White	verdie.white@geemail.com	Oakland	California	589332987792234	5ee9b3c6b6cf1a17a0df6804bb296495	VISA 16 digit	37.8121532644380878	-122.279790932128023
6267	2019-12-02 03:11:37	2019-12-02	Karim DuBuque	karim.dubuque@geemail.com	Aurora	Colorado	3032530245705680	7e6d96bdb8fe3f9842a0a365e0057751	VISA 16 digit	39.6030277799926722	-104.703061027371135
6268	2019-12-02 03:53:25	2019-12-02	Hailey Gleichner MD	hailey.gleichner.md@woohoo.com	San Francisco	California	180005238473139294	35b9f32c882874a7dae9e4d5d1263ba4	Diners Club / Carte Blanche	37.783693343308201	-122.412889759261418
6269	2019-12-02 04:02:51	2019-12-02	Merrilee Leannon	merrilee.leannon@woohoo.com	San Francisco	California	4506985684670376	e16d9cde24032eaf19b084570e28a7a2	JCB 15 digit	37.7787263983819201	-122.467044303357227
6270	2019-12-02 04:22:48	2019-12-02	Samantha Sanford MD	samantha.sanford.md@geemail.com	San Jose	California	3007606566873128	36039e436b700f868a28b9778e966cc8	Discover	37.2846960830789058	-121.750594546667855
6271	2019-12-02 07:12:45	2019-12-02	Sheldon Gottlieb V	sheldon.gottlieb.v@geemail.com	Jacksonville	Florida	869900982923697436	7dc5dee6de60b1c03df9b211f4178167	JCB 16 digit	30.393318197555466	-81.6590111007060955
6272	2019-12-02 07:22:47	2019-12-02	Dr. Skylar Collins	dr.skylar.collins@warmmail.com	Sugar Land	Texas	3007747744191353	5507d8328b9bb724359b22ce0f2073de	Maestro	29.5141704496514059	-95.6867069181527938
6273	2019-12-02 07:44:34	2019-12-02	Nelly Johnston	nelly.johnston@geemail.com	Ontario	California	3158658445207985799	8066e9632cd810403aa167b0aa092516	Maestro	34.1132654494751222	-117.686175952070215
6274	2019-12-02 08:00:29	2019-12-02	Lissa Simonis DVM	lissa.simonis.dvm@geemail.com	Columbus	Ohio	4353636474184	3b777b7a5e897f5ff4643c83af2c986c	VISA 16 digit	40.0438477933917198	-82.8894206877101283
6275	2019-12-02 08:06:20	2019-12-02	Roman Hyatt Sr.	roman.hyatt.sr.@geemail.com	San Francisco	California	6011249071343620797	9514852b2c74626e4c8ccc572662d2cc	VISA 13 digit	37.7421120313682223	-122.466072374079843
6276	2019-12-02 08:21:18	2019-12-02	Victoriano Schaden	victoriano.schaden@woohoo.com	Los Angeles	California	502042645749930	30b66e16fc880227b1d5c07d30ca51b7	Diners Club / Carte Blanche	33.9644152627192426	-118.390152468112476
6277	2019-12-02 08:50:59	2019-12-02	Sal Cassin	sal.cassin@warmmail.com	San Francisco	California	210020200725323440	b43d10b0f2f06180e0387c34d8326938	VISA 16 digit	37.7658992973159968	-122.419155503533844
6278	2019-12-02 09:57:19	2019-12-02	Ham Nicolas-Wunsch	ham.nicolas.wunsch@warmmail.com	San Francisco	California	3015398084216806	6b9e802c8a3fc80fdb54f3fcd806d001	VISA 16 digit	37.8111409601257478	-122.477049199150585
6279	2019-12-02 09:58:30	2019-12-02	Kristan Simonis	kristan.simonis@geemail.com	San Francisco	California	869932164493742148	8994781dd3d33ff28b4ddca6fc30a104	VISA 16 digit	37.7620314952459637	-122.409221562844607
6280	2019-12-02 09:59:57	2019-12-02	Waldo Bartoletti	waldo.bartoletti@geemail.com	San Francisco	California	4780629519829883	29b45362722ee85c2cb16f5e28d53f50	JCB 16 digit	37.7627663049336491	-122.440363390890639
6281	2019-12-02 10:41:13	2019-12-02	Jerrilyn Pfannerstill	jerrilyn.pfannerstill@geemail.com	Port St. Lucie	Florida	3158001650176339746	2f64395cd8915b2559c5755d9b7970b8	Mastercard	27.3281145313888771	-80.3417984087571568
6282	2019-12-02 10:56:24	2019-12-02	Deon Kirlin	deon.kirlin@warmmail.com	San Francisco	California	869988923126747656	1816b9632a6bfeb163c84b4f62b9b03e	Diners Club / Carte Blanche	37.7704204195625621	-122.423990451732578
6283	2019-12-02 11:25:27	2019-12-02	Jada Kunde MD	jada.kunde.md@woohoo.com	Dallas	Texas	3337507854997608854	4f9e1a4949d35f01d43f4590398c10f6	Diners Club / Carte Blanche	32.7780493002656854	-96.6691493446435715
6284	2019-12-02 14:36:52	2019-12-02	Charolette Mueller-Skiles	charolette.mueller.skiles@woohoo.com	San Francisco	California	210025745285327285	2f7e7d6edd226b0d3850516b59d3b234	JCB 16 digit	37.7680931796697337	-122.413401458403612
6285	2019-12-02 14:48:30	2019-12-02	Mrs. Ragna Rogahn MD	mrs.ragna.rogahn.md@warmmail.com	New York	New York	4700886988321316	93894e18e6715545e001495a75124dc4	JCB 16 digit	40.6549281290955804	-74.0123424362752615
6286	2019-12-02 14:53:28	2019-12-02	Dr. Jarred Wolf II	dr.jarred.wolf.ii@geemail.com	Meridian	Idaho	869936757787067183	84881b22ead8c5d469b3f046c540a409	JCB 15 digit	43.6655914821669455	-116.440996639331431
6287	2019-12-02 14:53:45	2019-12-02	Shannon Schmitt	shannon.schmitt@geemail.com	New York	New York	4662367248420707	facd2f011de576e4ad2017bd5d2b384f	Mastercard	40.5982638742066939	-73.9839071311417911
6288	2019-12-02 15:43:21	2019-12-02	Jonathon Denesik-Abbott	jonathon.denesik.abbott@woohoo.com	El Paso	Texas	6011345857253606039	41f224d732eb9e533aca21d8b8741e80	Discover	31.8364017268937083	-106.371691219320525
6289	2019-12-02 15:52:21	2019-12-02	Emil Ledner	emil.ledner@geemail.com	New York	New York	869958978082827187	81bc1e4fe377b8239daf23d935aed998	American Express	40.7135797282904406	-73.8731658440910195
6290	2019-12-02 16:06:49	2019-12-02	Kameron Schmidt	kameron.schmidt@geemail.com	San Francisco	California	3528423097744569463	7373964731a789e54a25de6eb0edafc5	Mastercard	37.7523020905267401	-122.43334899594285
6291	2019-12-02 16:09:59	2019-12-02	Keisha Daugherty	keisha.daugherty@woohoo.com	San Antonio	Texas	869982970531774045	0f2e2da0ffd5413317ec3037540b0908	VISA 16 digit	29.3875366911828522	-98.6168484397068568
6292	2019-12-02 16:30:56	2019-12-02	Berenice Stanton MD	berenice.stanton.md@geemail.com	San Francisco	California	3799672241870953	dcdcbe9c458fa1566e30134f522497e4	VISA 16 digit	37.7692683027822937	-122.456200020798548
6293	2019-12-02 17:47:11	2019-12-02	Micaela Trantow	micaela.trantow@warmmail.com	Phoenix	Arizona	3528530287071027850	b343dba63cd27e6355cc3325326bb506	JCB 16 digit	33.5548847723685242	-112.123245931037147
6294	2019-12-02 18:06:05	2019-12-02	Dr. Teagan Graham	dr.teagan.graham@geemail.com	Cincinnati	Ohio	589391429539694	302abb44eca9151c89391676aa46a8b4	American Express	39.1034801641710104	-84.5037736400302464
6295	2019-12-02 18:15:36	2019-12-02	Deron Raynor-Kozey	deron.raynor.kozey@woohoo.com	Spokane	Washington	3096765887697169154	a3c85f9a3c8c3ed38a253738026dff15	Discover	47.6126361577078683	-117.402921680816632
6296	2019-12-02 18:20:01	2019-12-02	Alabama Waters	alabama.waters@geemail.com	Fort Worth	Texas	4134057795159341	ac269a199cdbc561ad419544685747cd	VISA 13 digit	32.7651328841280218	-97.3517627758260744
6297	2019-12-02 18:40:17	2019-12-02	Keila Kling	keila.kling@geemail.com	San Francisco	California	3414333178071766	cc52e47c8c244d8fd3980b67aac930b7	JCB 16 digit	37.7512779961305185	-122.445549398289401
6298	2019-12-02 18:45:20	2019-12-02	Mr. Cristian Harvey	mr.cristian.harvey@geemail.com	Ontario	California	869990100533801972	166602a58cfce32bb8de607cbaf80679	Maestro	34.089886362073571	-117.567867809683833
6299	2019-12-02 19:32:22	2019-12-02	Ayleen Swaniawski	ayleen.swaniawski@geemail.com	San Francisco	California	060420665675862	7110667d2e9955bc32b7f21e8a6d4458	Voyager	37.8097030260903111	-122.412432061253014
6300	2019-12-02 19:38:31	2019-12-02	Mrs. Jeanna Blanda	mrs.jeanna.blanda@geemail.com	Cambridge	Massachusetts	54165703769894213	b50b23f4bf803fca812aa2d25733b41d	Diners Club / Carte Blanche	42.4001125439759292	-71.1808880365069996
6301	2019-12-02 19:38:49	2019-12-02	Adelle Connelly	adelle.connelly@geemail.com	San Francisco	California	501883440133359	edbfeb25f0e1b19669e948fd0f8aa573	VISA 16 digit	37.7628302429756886	-122.429879154391941
6302	2019-12-02 19:42:11	2019-12-02	Thompson Labadie-McClure	thompson.labadie.mcclure@warmmail.com	Portland	Oregon	4011270758524546	7603b65f5b8a7cf6e9e932f1fb42b90c	JCB 16 digit	45.4516353650838099	-122.732505701622003
6303	2019-12-02 19:54:39	2019-12-02	Robt Abernathy	robt.abernathy@geemail.com	San Francisco	California	869938062572158232	2a6154675f982612f35a44eb680aadd5	Mastercard	37.7602535959206875	-122.431741172928994
6304	2019-12-02 20:22:37	2019-12-02	Dr. Contina Quigley	dr.contina.quigley@woohoo.com	San Francisco	California	6011689059784092599	8aa3448b42abab6685261e40d4aa4de1	American Express	37.7519893302001037	-122.405717307859831
6305	2019-12-02 20:28:02	2019-12-02	Jasmyn Hane MD	jasmyn.hane.md@woohoo.com	Chula Vista	California	210024573554547271	5eb8faefedaaaf22fcd76f02af69355e	Maestro	32.6595088836967946	-117.068852156237512
6306	2019-12-02 20:28:12	2019-12-02	Nila Zulauf	nila.zulauf@geemail.com	New York	New York	4587300412571726	032d9a41f261ffb44e10367f37d39481	VISA 13 digit	40.7045579514689706	-73.8772415799450073
6307	2019-12-02 21:03:08	2019-12-02	Melanie Hammes	melanie.hammes@geemail.com	Columbus	Ohio	3112766099186373417	cd0b3dc80efc99de157807bf3dea8e9c	Maestro	39.9507554149765483	-82.8987490597881447
6308	2019-12-02 22:44:12	2019-12-02	Annette Marvin	annette.marvin@warmmail.com	Jersey City	New Jersey	869903891635489833	4b57b234228483b63e84a5acc615edcc	Maestro	40.6996484157103993	-74.06797366621457
6309	2019-12-02 23:01:16	2019-12-02	Dayanara Romaguera	dayanara.romaguera@geemail.com	San Antonio	Texas	561273486721506	40fe1777a161d23ffb4fd0ff2b789180	Diners Club / Carte Blanche	29.5702154733311389	-98.5498429129201838
6310	2019-12-02 23:23:09	2019-12-02	Britni Strosin	britni.strosin@woohoo.com	Daly City	California	210073979813850929	9994d294f5568c11a7886d452e327ed7	VISA 13 digit	37.6383532195739434	-122.431621880931786
6311	2019-12-02 23:31:31	2019-12-02	Vicki Murray	vicki.murray@geemail.com	Orlando	Florida	4492546566240	fe8228173713ebd4b753f6f82a7269fb	Diners Club / Carte Blanche	28.456308891836926	-81.346524660006537
6312	2019-12-03 00:25:43	2019-12-03	Johannah Halvorson DVM	johannah.halvorson.dvm@geemail.com	Dallas	Texas	6011304919768180923	129c08c91f534fd4213e619043f25e43	JCB 16 digit	32.8565413122337304	-96.7739388130567875
6313	2019-12-03 01:48:52	2019-12-03	Katia Gislason DDS	katia.gislason.dds@geemail.com	Cary	North Carolina	6011951491165724287	ced2ccabb0d08b2661c71b820d30fcaa	VISA 13 digit	35.7068230403695281	-78.846332302604992
6314	2019-12-03 02:23:21	2019-12-03	June Becker	june.becker@geemail.com	Berkeley	California	675954974825785	26bb4bea4486345718a55c54361de419	JCB 15 digit	37.8803718033466552	-122.306018164499463
6315	2019-12-03 02:31:46	2019-12-03	Kyle Strosin	kyle.strosin@geemail.com	Fort Worth	Texas	4083473373781	e0a3497dbdf6163c7e16ed5bc9ad0ea2	JCB 16 digit	32.7459241782370967	-97.3621928415082323
6316	2019-12-03 02:46:47	2019-12-03	Mrs. Clarice Leuschke PhD	mrs.clarice.leuschke.phd@warmmail.com	Berkeley	California	6011614873851218576	3a66e5aa7720bd562d8317f2a417559a	Mastercard	37.8548667674969153	-122.314550587581891
6317	2019-12-03 03:18:47	2019-12-03	Taliyah Baumbach	taliyah.baumbach@geemail.com	Berkeley	California	4162804998395676	45269e8eb4f208cd66b72875abddeaf7	JCB 16 digit	37.845076687043985	-122.277928829070589
6318	2019-12-03 03:53:14	2019-12-03	Rishi Swaniawski	rishi.swaniawski@geemail.com	Chicago	Illinois	53304103253039874	da0a52e0652d8da9da5ed1b3482e29f1	JCB 15 digit	41.8860329302329575	-87.764863622191541
6319	2019-12-03 04:07:18	2019-12-03	Riley Morar	riley.morar@geemail.com	Denver	Colorado	4774634873037808	3c0b8c8b591ae4f1f8606931aa7b6023	Diners Club / Carte Blanche	39.7135122492030206	-104.802342521889514
6320	2019-12-03 04:28:46	2019-12-03	Maira Klein-Kemmer	maira.klein.kemmer@geemail.com	New York	New York	52425292818234320	60e8e5e36841533560f232784d6c67b7	Diners Club / Carte Blanche	40.754904993366452	-73.9974648667860748
6321	2019-12-03 05:03:57	2019-12-03	Destry Smith-Larkin	destry.smith.larkin@warmmail.com	San Francisco	California	4734625083786118	8bed2652f89f84c6307431538bfcdcae	Diners Club / Carte Blanche	37.7858736798282706	-122.392594383405651
6322	2019-12-03 05:17:45	2019-12-03	Jessye Oberbrunner	jessye.oberbrunner@geemail.com	Louisville	Kentucky	4217876750043	32f786892128ba4d0e68e98a244c2ca3	American Express	38.0953782043322917	-85.6284984152369191
6323	2019-12-03 05:24:25	2019-12-03	Dr. Margot Oberbrunner	dr.margot.oberbrunner@geemail.com	Providence	Rhode Island	3112762027405838328	0c4ac1991e5d7fef68b5e7f537b0474f	VISA 16 digit	41.7765551182761783	-71.4290083003148482
6324	2019-12-03 05:36:38	2019-12-03	Tilla Fahey	tilla.fahey@geemail.com	New York	New York	4298357299702436	313ba929d0966d650f34f9f686e6b93c	JCB 16 digit	40.5974328486006684	-74.0268143205799163
6325	2019-12-03 05:44:22	2019-12-03	Nona Steuber	nona.steuber@woohoo.com	Lansing	Michigan	869929095471310604	48b47a7fc464a725b1c8f1efb1b05b07	JCB 16 digit	42.6528544104035987	-84.6589386202052196
6326	2019-12-03 06:20:43	2019-12-03	Richmond Bauch	richmond.bauch@geemail.com	New York	New York	3056581544182259	21cca134d075f18fee0a308ac416c16b	VISA 16 digit	40.7455857210084815	-73.8404040047328891
6327	2019-12-03 06:41:43	2019-12-03	Adalynn Lebsack	adalynn.lebsack@warmmail.com	Oakland	California	180098912107413758	f10524bf06ec08a777d5649f661fed67	JCB 16 digit	37.835583616985268	-122.232033179234421
6328	2019-12-03 06:44:36	2019-12-03	Marie Stark	marie.stark@geemail.com	Oakland	California	3528653127528333041	631bf35c79ab47e5856a6b7ef465646c	Discover	37.8045657012191114	-122.315231455505469
6329	2019-12-03 06:46:44	2019-12-03	Mr. Hiroshi Powlowski PhD	mr.hiroshi.powlowski.phd@geemail.com	San Francisco	California	3774573601340125	e91f3b92d257269d264c5079668883a9	Diners Club / Carte Blanche	37.8306026430659657	-122.414847947238428
6330	2019-12-03 07:20:54	2019-12-03	Ernst Rohan	ernst.rohan@warmmail.com	Santa Clara	California	869979345854887614	350047cd1a9ed9ac14a86ef8fa418cf1	Maestro	37.3282684362776607	-122.01557341231927
6331	2019-12-03 08:24:11	2019-12-03	Clark Wiegand	clark.wiegand@geemail.com	San Francisco	California	4972099675929596	1c07456446f6e03b2ed1dc3186f215b5	JCB 16 digit	37.7644119060969246	-122.413369803252436
6332	2019-12-03 08:50:18	2019-12-03	Ms. Rinda Weber	ms.rinda.weber@geemail.com	Tucson	Arizona	589308966310073	a57a17ff0d5e48c1acd616ad8769d635	JCB 15 digit	32.1077282974537468	-110.902071492582934
6333	2019-12-03 08:51:44	2019-12-03	Hayley VonRueden MD	hayley.vonrueden.md@woohoo.com	San Francisco	California	3408928605020654	19cabcd3e10cf6f7cb7f21eea789a18f	VISA 16 digit	37.8195259144799039	-122.443310854049557
6334	2019-12-03 09:11:48	2019-12-03	Patricia Bradtke-White	patricia.bradtke.white@geemail.com	North Charleston	South Carolina	55049200010757606	256429ef4a982af10a315f1b7a9b4601	Maestro	32.8643969393961157	-80.018958600014443
6335	2019-12-03 09:24:59	2019-12-03	Mr. Valentine Vandervort	mr.valentine.vandervort@geemail.com	Boston	Massachusetts	869977392888402327	93256b53c8a6c6e0d3d0a6246a79f09b	Mastercard	42.3011460328176625	-70.9953486038789237
6336	2019-12-03 09:43:42	2019-12-03	Sylvia Schulist	sylvia.schulist@warmmail.com	New York	New York	3096663182660034020	ef754103ad0cc7fa5a65f8076e64002d	JCB 16 digit	40.7472978678289763	-73.8769195682264836
6337	2019-12-03 09:54:32	2019-12-03	Dewey Schultz	dewey.schultz@geemail.com	New York	New York	3485972954162333	9ae1146a37aa4823f423df79c44e4068	JCB 15 digit	40.6604668987672753	-73.8477126204769974
6338	2019-12-03 09:55:10	2019-12-03	Randell Bartell	randell.bartell@geemail.com	San Francisco	California	3112428007121656309	d8e5ea25eea25af245118fa351072ffb	JCB 16 digit	37.7949616646874631	-122.438398705213032
6339	2019-12-03 10:35:53	2019-12-03	Cleora Frami-Kuhic	cleora.frami.kuhic@warmmail.com	Atlanta	Georgia	4838450235474611	07a15bbcc7ac81f4065e09f1fe512eb5	Diners Club / Carte Blanche	33.7793534902200108	-84.4757882010236472
6340	2019-12-03 10:49:47	2019-12-03	Nathalie Smith	nathalie.smith@geemail.com	Denver	Colorado	180023715208285466	3ee2dcf6fca59c2c7f320e01188cfba0	Diners Club / Carte Blanche	39.7930939132399857	-104.891112951539839
6341	2019-12-03 11:54:28	2019-12-03	Kennith Ruecker DVM	kennith.ruecker.dvm@geemail.com	Indianapolis	Indiana	52520489798959371	712a14a74d5f594ac62ccf708909c12f	VISA 16 digit	39.737333007157595	-86.1147214885536556
6342	2019-12-03 11:59:11	2019-12-03	Dr. Kyrie Macejkovic	dr.kyrie.macejkovic@geemail.com	Berkeley	California	3776223574620628	519dba623782276b8ddeb5d20393989e	VISA 13 digit	37.8662168292999226	-122.311357544072223
6343	2019-12-03 12:42:50	2019-12-03	Nealy Kessler	nealy.kessler@geemail.com	Cedar Rapids	Iowa	3096595353083791933	71a4f2cc2edcf44895c44e4815e69c5e	VISA 13 digit	42.0559312207233162	-91.598615044129275
6344	2019-12-03 13:23:35	2019-12-03	Miss Charley Rodriguez	miss.charley.rodriguez@geemail.com	Denton	Texas	3039655643583380	96c09f10643d667ed8d7b4c27ebe5ffa	Maestro	33.1446498003587138	-97.1991094837557625
6345	2019-12-03 14:59:04	2019-12-03	Adalberto Heidenreich	adalberto.heidenreich@geemail.com	Montgomery	Alabama	180078137988812357	23377fb88424deaaeb4460bb7499b163	JCB 16 digit	32.4122480242911735	-86.3435710780009629
6346	2019-12-03 15:24:34	2019-12-03	Lula Mraz	lula.mraz@geemail.com	Austin	Texas	52910458972594799	35316a76f264fc75e1960247f6e9f65e	Voyager	30.2085259633731091	-97.8272606593329499
6347	2019-12-03 15:33:50	2019-12-03	Cristi Lesch PhD	cristi.lesch.phd@woohoo.com	Philadelphia	Pennsylvania	210032207782497716	ea5bf9ee3d594e2e7e8d21b2c2bb9b2c	JCB 15 digit	40.0734820986591274	-75.1650740069702294
6348	2019-12-03 15:39:18	2019-12-03	Mr. Davonte Stamm	mr.davonte.stamm@geemail.com	Nashville	Tennessee	3337224437301305417	06234170b17f1d512c7b80f145ff18d0	Maestro	36.2576758959919161	-86.8467144767194981
6349	2019-12-03 15:46:52	2019-12-03	Jazmyne Kutch	jazmyne.kutch@geemail.com	Roseville	California	3021900333527299	a00f716a0daf19374aa2f40abe051819	JCB 15 digit	38.8307558478377715	-121.418599155334377
6350	2019-12-03 15:52:01	2019-12-03	Mr. Rodolfo Hodkiewicz MD	mr.rodolfo.hodkiewicz.md@woohoo.com	Los Angeles	California	3528382846998046209	dbaeaee1f8bdd48bcc1b16798eb6500d	JCB 16 digit	34.0562170341476786	-118.361150056774903
6351	2019-12-03 15:54:04	2019-12-03	Oley Ratke	oley.ratke@warmmail.com	Berkeley	California	4989445478443	cdbca2f950670e4d232f7edef7cc0995	American Express	37.8701061788041002	-122.262495841085141
6352	2019-12-03 16:16:01	2019-12-03	Wenzel Hudson	wenzel.hudson@geemail.com	Wichita	Kansas	4995489339870	b3abd200384c1c1ff03f191c827fa649	JCB 16 digit	37.609301447716355	-97.375506056911874
6353	2019-12-03 16:34:02	2019-12-03	Darrick Witting-Schulist	darrick.witting.schulist@woohoo.com	Naperville	Illinois	3028715117028774	ecc10c5d1c40df4a63989764cf34ee1f	JCB 15 digit	41.6737232754386966	-88.1763809814471813
6354	2019-12-03 16:53:30	2019-12-03	Aidyn Smith	aidyn.smith@geemail.com	Norman	Oklahoma	3762891563274270	ffce5d1241c85dd6aa9cd6cb4428388c	VISA 13 digit	35.1428734814789152	-97.2756386421408479
6355	2019-12-03 17:57:07	2019-12-03	Dr. Carmela Kulas	dr.carmela.kulas@geemail.com	Oakland	California	4799437573014	c1c6613d4f56ee6f92ca25bcc729bfd0	Discover	37.8210354647925726	-122.276959372108408
6356	2019-12-03 18:32:26	2019-12-03	Keon Pollich	keon.pollich@warmmail.com	Tallahassee	Florida	3045562368231662	13964eafadb57d63becf4ff520ececd2	Diners Club / Carte Blanche	30.4250074078816937	-84.2306554073017111
6357	2019-12-03 18:32:32	2019-12-03	Hermina Klein-Gleichner	hermina.klein.gleichner@geemail.com	San Diego	California	3088487071242133679	37399f6673db6e9e03c51bd3d672ce67	VISA 16 digit	32.8744944377403741	-117.166831963174047
6358	2019-12-03 19:06:37	2019-12-03	Adison Breitenberg	adison.breitenberg@geemail.com	Sandy Springs	Georgia	6011313672763455035	1da2c18715a69dbda764f3b45e03b35d	Maestro	33.8671192457489667	-84.2843741335522481
6359	2019-12-03 19:07:06	2019-12-03	Bonnie Gottlieb	bonnie.gottlieb@woohoo.com	San Francisco	California	4541811651648665	6900e749bbc9f19682238398b2f6afc4	Mastercard	37.7713862335605342	-122.448252728136922
6360	2019-12-03 19:16:49	2019-12-03	Mrs. Evelina Prohaska DVM	mrs.evelina.prohaska.dvm@geemail.com	Philadelphia	Pennsylvania	3528132814507394349	43fbf8b2b8b2ad77751e9b2980d35a69	VISA 13 digit	39.9723743039142363	-75.2119450154613816
6361	2019-12-03 19:39:13	2019-12-03	Wenzel McKenzie	wenzel.mckenzie@warmmail.com	New York	New York	3707375291914132	e00e424f1efac3048eb6d6118478d1d4	Diners Club / Carte Blanche	40.6691629752740269	-73.8881040621444498
6362	2019-12-03 19:44:42	2019-12-03	Madlyn Keeling	madlyn.keeling@geemail.com	New York	New York	4307246815000434	4de945cefe31f49c233033449d73ca7d	JCB 15 digit	40.6927872284073402	-73.9632765913277836
6363	2019-12-03 19:55:42	2019-12-03	Fleet Ledner-Daugherty	fleet.ledner.daugherty@woohoo.com	Pasadena	California	4436504262902211	d1c92b2e8a3ad2fec85b54a60953cb12	American Express	34.0727641702018715	-118.167613889957224
6364	2019-12-03 20:07:33	2019-12-03	Miss Diane Kutch	miss.diane.kutch@woohoo.com	San Francisco	California	676173357115119	86eb12bdd084299bb4f8e80119d73226	American Express	37.7631387543693506	-122.473289952160215
6365	2019-12-03 20:17:11	2019-12-03	Isaias Volkman	isaias.volkman@geemail.com	San Francisco	California	6011331058416411344	c20599b6216d0ba98a8298833c29755e	Discover	37.8156040906566062	-122.419707798930233
6366	2019-12-03 21:27:24	2019-12-03	Greene Sipes V	greene.sipes.v@geemail.com	Jacksonville	Florida	6011290458921161039	e2c749338d8c9bf2c2a272edd233256f	VISA 16 digit	30.4331593745440259	-81.5852879964359232
6367	2019-12-03 22:45:38	2019-12-03	Amasa Hintz	amasa.hintz@geemail.com	West Valley City	Utah	3096781523966350130	ebfeedc4ab60e78c4c94f73962ec9f3b	JCB 16 digit	40.6055194657053775	-112.001102327297616
6368	2019-12-03 23:01:14	2019-12-03	Gerry Jenkins-Nader	gerry.jenkins.nader@geemail.com	Oakland	California	4753279451226673	99581365cb4f8efd777c54518b05d1e3	JCB 16 digit	37.784387238720889	-122.278937580272938
6369	2019-12-03 23:20:42	2019-12-03	Cynthia Lang	cynthia.lang@geemail.com	Oakland	California	4736428771216003	62a72b0ab45a80ec27872379a3353fcf	Diners Club / Carte Blanche	37.7956148754698305	-122.276189076172471
6370	2019-12-04 00:12:47	2019-12-04	Mr. Arther Larson IV	mr.arther.larson.iv@geemail.com	Laredo	Texas	4960588855039568	f5db454cc7d1ecc86c1d53c38b1ff827	VISA 16 digit	27.6318030355215072	-99.4572645741056647
6371	2019-12-04 00:26:21	2019-12-04	Mr. Jamie Brekke MD	mr.jamie.brekke.md@geemail.com	San Francisco	California	3096007778923915197	4145441d0ba04f7ac55d3d39a348ff78	Maestro	37.7955546004483338	-122.41424292210742
6372	2019-12-04 00:30:43	2019-12-04	Shelli Kutch	shelli.kutch@geemail.com	San Francisco	California	53036063843152980	9c1125f1911a353ba6e006af51c99fdf	American Express	37.7924633980526892	-122.441064702208195
6373	2019-12-04 01:08:04	2019-12-04	Francina Bahringer	francina.bahringer@geemail.com	Lowell	Massachusetts	3001734305773197	c0e4d1cbd2f553757b21c201bb81b7de	VISA 16 digit	42.5539076549802004	-71.3792453711725727
6374	2019-12-04 01:13:19	2019-12-04	Najee Runolfsdottir MD	najee.runolfsdottir.md@geemail.com	San Francisco	California	869906612112008632	cd563e42c22e80e6ad1d0448e7460a96	JCB 16 digit	37.7409583031553097	-122.424308929813577
6375	2019-12-04 01:34:54	2019-12-04	Milan Kris DVM	milan.kris.dvm@woohoo.com	Los Angeles	California	3483240076559501	b0d97d2f6b32a8f5199da2937fb38f87	Diners Club / Carte Blanche	33.9683226046018305	-118.467943803220237
6376	2019-12-04 02:00:37	2019-12-04	Olie Parker	olie.parker@geemail.com	San Francisco	California	869963005261960531	60144e3f2c991f1b95b9cd45e0219cf9	Mastercard	37.7723665032946272	-122.435606440236342
6377	2019-12-04 02:13:09	2019-12-04	Dr. Jakobe Runolfsson	dr.jakobe.runolfsson@geemail.com	Salem	Oregon	502079607834326	322b16c307eba016a507cb570901b5f6	Diners Club / Carte Blanche	44.998033349941295	-123.010331351465368
6378	2019-12-04 02:23:26	2019-12-04	Mr. Morris Russel	mr.morris.russel@warmmail.com	Columbus	Ohio	4253160201161	18fefbb5a0543d09955c290c166b0a4c	VISA 13 digit	40.0555212128020841	-83.0136525338750459
6379	2019-12-04 02:26:00	2019-12-04	Bambi Sauer	bambi.sauer@woohoo.com	Las Vegas	Nevada	6011123203689438135	20060ce46f6e88ae69d49761aced6b9d	American Express	36.2726241351205871	-115.16817333830744
6380	2019-12-04 02:27:47	2019-12-04	Orlo Stamm-Goodwin	orlo.stamm.goodwin@warmmail.com	West Palm Beach	Florida	3737483795861934	144f4f799ea8f8bdaf58ad01e8e66a09	JCB 16 digit	26.6603076841063817	-80.1023391528822515
6381	2019-12-04 02:46:19	2019-12-04	Kassie Senger PhD	kassie.senger.phd@geemail.com	San Diego	California	869911706799183420	f42663008f4ca5b3734961bc6c9840a9	JCB 15 digit	32.8399785557828849	-117.218000842668118
6382	2019-12-04 02:52:27	2019-12-04	Louise Bailey	louise.bailey@geemail.com	San Jose	California	561214969360446	8d0069532f9062ed0eb67b81a626d88e	Voyager	37.2354748694978639	-121.83490452279672
6383	2019-12-04 03:21:46	2019-12-04	Alyse Stoltenberg	alyse.stoltenberg@geemail.com	Los Angeles	California	6011034174063955929	6021baf9174b27417185decf247ef726	Diners Club / Carte Blanche	34.01849182419069	-118.386403990256781
6384	2019-12-04 03:44:47	2019-12-04	Dorman Kuhic II	dorman.kuhic.ii@geemail.com	El Cajon	California	3025725322308534	87647580e327b4c7cea69ba95e74d5b3	JCB 16 digit	32.7451279076755029	-116.940707472357531
6385	2019-12-04 04:34:29	2019-12-04	Cleta Larson	cleta.larson@geemail.com	Berkeley	California	3054018737927945	27570c97f6d0bb46b09752dffbc0deb8	Maestro	37.8878458013470052	-122.271742639130323
6386	2019-12-04 04:35:00	2019-12-04	Kelsie Dibbert	kelsie.dibbert@geemail.com	Berkeley	California	4035950459749912	80537da0b7ad5b899b92bd9381c44b6a	Discover	37.8753364335050335	-122.299196800778105
6387	2019-12-04 05:20:15	2019-12-04	Ms. Lavonda Jones	ms.lavonda.jones@geemail.com	Tacoma	Washington	3112902218653307949	5a399af64bbb52ed38eeb61f06259ab9	JCB 16 digit	47.1708327516101349	-122.500510829431192
6388	2019-12-04 05:48:18	2019-12-04	Dr. Madalyn Harvey PhD	dr.madalyn.harvey.phd@geemail.com	Cleveland	Ohio	3013369963203795	2ca1b26a4e796c4d908a5c9aa3910ee3	Diners Club / Carte Blanche	41.3793976261131462	-81.7045904534641636
6389	2019-12-04 05:48:50	2019-12-04	Chip Waters	chip.waters@geemail.com	Atlanta	Georgia	4488631162762	5f1755c8fc070707a716594cbc2df1f6	JCB 15 digit	33.8469287642087835	-84.3854517124172361
6390	2019-12-04 06:24:54	2019-12-04	Kay Weimann MD	kay.weimann.md@geemail.com	Phoenix	Arizona	4376236518969	df3696ef2a7cdaa83dc2f06c2b1da23d	Mastercard	33.5877296306125857	-112.009592883235229
6391	2019-12-04 06:35:59	2019-12-04	Arron Sipes-Lesch	arron.sipes.lesch@geemail.com	San Francisco	California	53265792687748113	0e9272191a29f2cb2da7595f82e09762	Discover	37.7464383810351052	-122.429541192142082
6392	2019-12-04 08:11:16	2019-12-04	Giuliana Braun	giuliana.braun@geemail.com	Portland	Oregon	676277343469712	eba3408b7c2a837f40a8d5333d180ba7	Diners Club / Carte Blanche	45.6171588826347119	-122.637209203606474
6393	2019-12-04 08:25:53	2019-12-04	Shanda Berge	shanda.berge@geemail.com	Austin	Texas	4477354180810561	aff1c0e20c17db1d4f8b6682a28e01ac	JCB 16 digit	30.2707149618897589	-97.7983742261078248
6394	2019-12-04 09:19:59	2019-12-04	Jedidiah Sporer	jedidiah.sporer@geemail.com	Berkeley	California	53952783766173578	6282795cd6b8103a2659b170c9521e92	Maestro	37.8645892832190682	-122.2831268428763
6395	2019-12-04 10:17:23	2019-12-04	Ms. Dellie Rutherford MD	ms.dellie.rutherford.md@warmmail.com	Thornton	Colorado	6011818135951790225	bfc30b51385e05d589b8cb576533e938	Voyager	39.9831687415350245	-104.96607725836077
6396	2019-12-04 10:29:13	2019-12-04	Irene Tremblay	irene.tremblay@geemail.com	San Francisco	California	676128871382900	ae854ca59a5325963b4c38504069f149	Diners Club / Carte Blanche	37.7676268355227549	-122.462877255472435
6397	2019-12-04 11:27:06	2019-12-04	Kaylyn Crist-Schmeler	kaylyn.crist.schmeler@geemail.com	Round Rock	Texas	210024342480874435	1c7936572e0220fde356d244ac211c45	Maestro	30.4406032157268385	-97.7593816553559094
6398	2019-12-04 11:49:05	2019-12-04	Ginny Kutch	ginny.kutch@warmmail.com	New York	New York	4645675070702212	6bf106bdb39edf7c5fa76a020f556ba9	VISA 13 digit	40.5835567924417546	-74.0305291482608681
6399	2019-12-04 12:10:29	2019-12-04	Mrs. Alessandra Murphy MD	mrs.alessandra.murphy.md@geemail.com	San Francisco	California	4880812630984980	6db02b8c1cc891ea1a1b3c0c2e7ce3b2	VISA 16 digit	37.7620243378502352	-122.437091241658464
6400	2019-12-04 12:44:11	2019-12-04	Love Rau	love.rau@geemail.com	New York	New York	180018858086862241	60f70e74b607a128c73bc750cab1c0b5	VISA 16 digit	40.7201432049963614	-73.9197944169294061
6401	2019-12-04 13:14:23	2019-12-04	Miss Donnie Kessler MD	miss.donnie.kessler.md@geemail.com	San Francisco	California	501826722567992	dc6fcc0c4b9beaf02529122aa91b52c8	JCB 16 digit	37.7581078397722436	-122.447704793727482
6402	2019-12-04 13:35:40	2019-12-04	Jacquelin Ritchie	jacquelin.ritchie@geemail.com	San Francisco	California	3528110893374290927	aef003a6cd1f161a92c85c142fd44447	Mastercard	37.7685374138198924	-122.44354935722599
6403	2019-12-04 13:58:55	2019-12-04	Marylouise Quigley	marylouise.quigley@warmmail.com	Omaha	Nebraska	4339885448005757	630ba45692ab8bc151fbc0f01c440c14	Discover	41.2336373908124898	-96.1159030273672244
6404	2019-12-04 15:04:22	2019-12-04	Towanda Kris DVM	towanda.kris.dvm@geemail.com	Columbus	Ohio	4557744259630168	b835fc18e9e8c36748f88a7970e44024	Mastercard	39.9797149681530897	-83.0443935848541628
6405	2019-12-04 15:56:05	2019-12-04	Acy Wehner	acy.wehner@geemail.com	San Francisco	California	210078585114032888	3df4f04fe5b50ac4ad846500e435176a	JCB 16 digit	37.7564858173321412	-122.448995201633437
6406	2019-12-04 15:56:22	2019-12-04	Lyndia Paucek	lyndia.paucek@geemail.com	Phoenix	Arizona	6011348684404856074	561ca094fab28a691189e4362f3c085d	Discover	33.5909948989681908	-112.187899035580841
6407	2019-12-04 16:29:04	2019-12-04	Farrah Bednar	farrah.bednar@geemail.com	Philadelphia	Pennsylvania	561262295878482	a8817897841a1cdcc785dcf0fbd2bffb	JCB 15 digit	39.919260975202171	-75.0729004810463749
6408	2019-12-04 16:36:31	2019-12-04	Almus Krajcik-Bartoletti	almus.krajcik.bartoletti@warmmail.com	Berkeley	California	6011501245783848976	17acbfb99db009ffd045bd205fdd58c4	Discover	37.8645110033601071	-122.24402861044743
6409	2019-12-04 17:12:40	2019-12-04	Mason Schmeler	mason.schmeler@geemail.com	El Monte	California	3528609493154434015	63a5e87ea85cba2e876fc7cb7a11c165	Discover	34.1657395740695264	-118.092374805480617
6410	2019-12-04 17:37:37	2019-12-04	Stephani Green	stephani.green@geemail.com	Berkeley	California	180066828428937556	6e02009b20ef1adcc34acec0ae5eb965	JCB 16 digit	37.859095332579912	-122.266714377535166
6411	2019-12-04 17:50:38	2019-12-04	Anabella Carroll	anabella.carroll@geemail.com	Berkeley	California	180020917158989393	f02cb491a6cd83f9b2ffda0cc2b8fe0f	VISA 13 digit	37.8687894453499183	-122.252704049282357
6412	2019-12-04 18:09:17	2019-12-04	Tahj Koelpin	tahj.koelpin@warmmail.com	San Francisco	California	3042119445248897	79f918f9ec9bec16665488c545d184f5	Voyager	37.794053515053001	-122.448203150581065
6413	2019-12-04 19:12:14	2019-12-04	Rey Collins	rey.collins@geemail.com	Visalia	California	561203815565209	0ba614685c2f48b720b830a2dd5a56c9	JCB 16 digit	36.3008009200405368	-119.237722899591176
6414	2019-12-04 20:24:13	2019-12-04	Rudolfo Stracke	rudolfo.stracke@geemail.com	Irvine	California	3437201160342284	9847782a116de4491a27433029967a5d	JCB 16 digit	33.62366673210785	-117.793636224839091
6415	2019-12-04 20:38:57	2019-12-04	Burnell Johnson	burnell.johnson@geemail.com	San Francisco	California	869971073725127113	492438ab76bb3909ab00b6436b077a4c	Maestro	37.7710520221046693	-122.429373713153183
6416	2019-12-04 20:39:49	2019-12-04	Mr. Jagger Kozey	mr.jagger.kozey@woohoo.com	Corona	California	869982838030548352	77abe9ecf24aafc4b432c3c94e100f94	VISA 16 digit	33.7950783710815017	-117.614040055193001
6417	2019-12-04 21:32:07	2019-12-04	Darin McGlynn Jr.	darin.mcglynn.jr.@geemail.com	Tyler	Texas	180040804916911198	1cc2d37ba211b27f6a32b88b762b3c32	Voyager	32.2453917349271535	-95.2839528290197251
6418	2019-12-04 21:47:25	2019-12-04	Jedidiah Treutel-Ullrich	jedidiah.treutel.ullrich@geemail.com	Las Vegas	Nevada	180044849231880988	f91c820a3dd67452178130d74e05e9e3	Diners Club / Carte Blanche	36.2651371084719898	-115.191625611644611
6419	2019-12-04 22:03:44	2019-12-04	Nichol Doyle	nichol.doyle@woohoo.com	Santa Ana	California	4987795424306	f2096d4f3a1ea6deaea4ef99baca05ee	VISA 16 digit	33.6944987409386769	-117.813105155799533
6420	2019-12-04 22:17:53	2019-12-04	Zandra Harvey MD	zandra.harvey.md@geemail.com	Corpus Christi	Texas	52753535294079151	1f4333c065839e46c5fbffc244a5a9dc	VISA 16 digit	27.8069936326175942	-97.1763951622709641
6421	2019-12-04 22:23:01	2019-12-04	Tomas Wuckert	tomas.wuckert@geemail.com	Tampa	Florida	4151295256136	93b3a74ef9f9c1b234f4820768fe61d6	Mastercard	27.920525443984566	-82.4358071889474928
6422	2019-12-04 22:23:34	2019-12-04	Keshawn Bergnaum-Heller	keshawn.bergnaum.heller@warmmail.com	Stockton	California	3718317129090930	c29e4a0e15dd8974247dc1e234da3dce	Maestro	37.9536443384561721	-121.375119409299643
6423	2019-12-04 23:39:15	2019-12-04	Kingston Cormier	kingston.cormier@geemail.com	Atlanta	Georgia	3027425629041213	3a8771d8664df343ced305389a8264ec	VISA 16 digit	33.8268660140965167	-84.3579416934911279
6424	2019-12-05 00:18:37	2019-12-05	Cinda Leannon	cinda.leannon@geemail.com	Atlanta	Georgia	6011099881936707129	41b8326b6d29acfae89920c3598ba14a	VISA 13 digit	33.843881394136325	-84.3731507606383531
6425	2019-12-05 01:13:20	2019-12-05	Dr. Jep Schowalter	dr.jep.schowalter@geemail.com	Oakland	California	3008029296264378	67d62ab573217b8b40f908e223133c28	Mastercard	37.8047769436364547	-122.273572502416428
6426	2019-12-05 02:15:21	2019-12-05	Chanel Hartmann	chanel.hartmann@woohoo.com	Colorado Springs	Colorado	180069985449798560	034debcbd3745364c910c70e4b11bd23	VISA 16 digit	38.9646320336546736	-104.773634428313741
6427	2019-12-05 02:37:30	2019-12-05	Maymie Johnston	maymie.johnston@geemail.com	Detroit	Michigan	4253179022426	ce0f6307e02490a58332621082c134d6	VISA 16 digit	42.379946181869137	-83.0174203586883834
6428	2019-12-05 02:50:47	2019-12-05	Roosevelt Watsica I	roosevelt.watsica.i@geemail.com	San Francisco	California	180062496621197610	6b38e51bdf6ef0c0ccae3237ab430bb3	VISA 16 digit	37.7626363693500409	-122.468915604905135
6429	2019-12-05 02:52:33	2019-12-05	Dr. Burt Christiansen	dr.burt.christiansen@geemail.com	Vallejo	California	3528448737009452159	36dad488895c49eb6b424510f063f655	JCB 15 digit	38.0963301516227446	-122.321104574283581
6430	2019-12-05 03:28:46	2019-12-05	Haiden Volkman V	haiden.volkman.v@geemail.com	Washington	District of Columbia	4966543618666	f8cb409111d574ea56d127fc477e5878	Voyager	38.9434717018421708	-77.0199545435819743
6431	2019-12-05 04:14:15	2019-12-05	Miss Kierra Hahn	miss.kierra.hahn@geemail.com	Plano	Texas	3450609838310479	33f129c19708dd29b662da4fd7e48056	JCB 16 digit	33.1020923808768401	-96.7653426090437989
6432	2019-12-05 04:29:21	2019-12-05	Jimmie Emmerich-Blanda	jimmie.emmerich.blanda@geemail.com	Philadelphia	Pennsylvania	3096254470110474853	d024479c92828b9c5f06b96efd16a46b	Mastercard	40.0694446785334506	-75.0680203816287275
6433	2019-12-05 04:44:45	2019-12-05	Kristen Rodriguez-Macejkovic	kristen.rodriguez.macejkovic@warmmail.com	Overland Park	Kansas	6011446371324790721	bdc0a02dd72f10cf5a656427ca22ab43	Maestro	38.9010509044732942	-94.7425998030271472
6434	2019-12-05 04:57:31	2019-12-05	Jamir Hane	jamir.hane@geemail.com	New York	New York	869964363206527017	61371f1bd34b9b5ecdbbbcfa84ef5386	Voyager	40.7224432090055188	-73.93580933403112
6435	2019-12-05 05:02:42	2019-12-05	Dakotah Klein	dakotah.klein@geemail.com	Killeen	Texas	4506143479230499	586a81a70a4d911c8e28f0e202bb2432	Diners Club / Carte Blanche	31.0686276160411552	-97.7555851402860156
6436	2019-12-05 05:56:23	2019-12-05	Moira Rodriguez	moira.rodriguez@geemail.com	Thousand Oaks	California	4971871753523	5e4ad45b7003a74cb11530bc14fee4ce	Voyager	34.2054004299260654	-118.929974204200136
6437	2019-12-05 06:23:29	2019-12-05	Nile Mante-Heller	nile.mante.heller@warmmail.com	Hampton	Virginia	3015045349680223	7f3c1fece82e0c4298694459bff6d9f4	JCB 15 digit	37.0083722303174483	-76.3095683032277918
6438	2019-12-05 06:25:15	2019-12-05	Dr. Felicie Zulauf	dr.felicie.zulauf@geemail.com	Reno	Nevada	180049339917135886	4531b94d9748cae5021a427896a43ce9	American Express	39.6395157044831663	-119.777591094949841
6439	2019-12-05 06:31:57	2019-12-05	Deante O'Connell	deante.o'connell@warmmail.com	San Francisco	California	210079657117536998	8abdf9bac62167595f5df168ec92560c	JCB 16 digit	37.7225929631693901	-122.403764211758542
6440	2019-12-05 06:39:46	2019-12-05	Heaven Graham DDS	heaven.graham.dds@woohoo.com	San Francisco	California	51766198497354098	7a82426cf50b327c33b0d6a2f114a630	JCB 15 digit	37.7830281545158755	-122.462512220326076
6441	2019-12-05 06:48:08	2019-12-05	Ms. Denine Morar	ms.denine.morar@geemail.com	Albuquerque	New Mexico	675922462954383	4747da84be032775f379f63711b7055e	JCB 16 digit	35.1139713053260039	-106.678896095983319
6442	2019-12-05 07:02:42	2019-12-05	Roswell Purdy	roswell.purdy@warmmail.com	San Francisco	California	3017001895196435	cef1c2b148d4795cb2a8dcf666607979	Mastercard	37.7788172438826564	-122.424934545407154
6443	2019-12-05 07:58:37	2019-12-05	Mr. Ivory Greenfelder	mr.ivory.greenfelder@woohoo.com	New York	New York	6011856939095942862	f9152b271f941bfe96403417a273519f	Discover	40.5727787878122186	-73.9628666030138646
6444	2019-12-05 08:17:38	2019-12-05	Randall Nienow	randall.nienow@geemail.com	Plano	Texas	55628268762961709	57ac43ea9a1b2eba8acc242987f20d2a	Mastercard	33.1067957791585528	-96.670374404331298
6445	2019-12-05 08:18:21	2019-12-05	Coral Collier	coral.collier@geemail.com	Sparks	Nevada	3088660841648834172	90d27dee810881f1c84feaa4ba3fbaf2	VISA 16 digit	39.5837167368974576	-119.689757617781311
6446	2019-12-05 10:17:02	2019-12-05	Susann Schiller	susann.schiller@geemail.com	San Francisco	California	676100785631730	6730a2c8c03c08995fcb0636b0c6b70b	VISA 13 digit	37.7519308937214149	-122.430652037327093
6447	2019-12-05 10:28:26	2019-12-05	Joesph Nolan	joesph.nolan@geemail.com	Warren	Michigan	3752682154679585	73ec0bf96295cac5d6027168113e1f2b	JCB 15 digit	42.5782675032965798	-83.0153897829353866
6448	2019-12-05 10:28:45	2019-12-05	Lucius Kutch	lucius.kutch@geemail.com	Fort Lauderdale	Florida	4551395849423352	aa66c6b59dcac0c8e4008cd640161f77	VISA 16 digit	26.1085097520135356	-80.1734083153128552
6449	2019-12-05 10:33:31	2019-12-05	Alease Schowalter	alease.schowalter@geemail.com	San Diego	California	6011645031748708266	03adab39e2b4887b25ec2bae763ef5f3	Mastercard	32.8459102952919935	-117.042465300057088
6450	2019-12-05 10:53:14	2019-12-05	Tiara Nitzsche DVM	tiara.nitzsche.dvm@warmmail.com	Nashville	Tennessee	4674080979679	70033f95b15aaf5c4eda4f5b764619cf	Discover	36.1514762811019992	-86.780708365924653
6451	2019-12-05 11:11:48	2019-12-05	Corrina Bernhard	corrina.bernhard@geemail.com	San Francisco	California	6011828224880948522	815341d1dc3fc3870e36260351003ffc	JCB 16 digit	37.7847212545080922	-122.430956474989244
6452	2019-12-05 11:17:22	2019-12-05	Tracy Baumbach	tracy.baumbach@warmmail.com	Kansas City	Missouri	3009145777591052	87bcf0fec93c099edf318a880dbbe631	JCB 16 digit	39.1482152779422705	-94.5174478837978143
6453	2019-12-05 11:22:46	2019-12-05	Luetta Casper	luetta.casper@woohoo.com	Lancaster	California	210087939009023271	fe70c3348151b13ecbe1ccb7fafd2eda	VISA 16 digit	34.7905382114242769	-118.201412899091082
6454	2019-12-05 11:42:21	2019-12-05	Connor Ledner	connor.ledner@geemail.com	Virginia Beach	Virginia	6011021507088751929	1e563b1927f4cb287349a18787a6e968	Voyager	36.7397079433500764	-76.0959820401061364
6455	2019-12-05 12:01:09	2019-12-05	Miss Patsy Schowalter PhD	miss.patsy.schowalter.phd@geemail.com	Los Angeles	California	6011521557435790273	eb9b51d10f95f1d52eae7ed8a306efba	American Express	34.1147255260828857	-118.395074134552104
6456	2019-12-05 12:07:51	2019-12-05	Rahsaan Schumm	rahsaan.schumm@geemail.com	Albuquerque	New Mexico	3096558152156928900	9744f65d1704430904c43d2cd34d77d4	JCB 15 digit	35.069773583546656	-106.743943151978414
6457	2019-12-05 12:35:41	2019-12-05	Walt Ullrich	walt.ullrich@woohoo.com	Nashville	Tennessee	51709244108398916	4bb7c65f148c6f9c81ef12626ea1778a	Mastercard	36.2463519369374936	-86.7223726817313576
6458	2019-12-05 12:56:53	2019-12-05	Dejon Heidenreich	dejon.heidenreich@geemail.com	San Francisco	California	4280751890987216	9ead6a1650b34ab702d0fde7ab4c800d	Diners Club / Carte Blanche	37.772709056712813	-122.424061204277464
6459	2019-12-05 13:01:11	2019-12-05	Fenton Skiles-Schoen	fenton.skiles.schoen@geemail.com	New York	New York	4932810837589691	6cc327b5e9b5b78d68754a278ff3d798	Voyager	40.5798958296645438	-73.9884673719655694
6460	2019-12-05 13:22:22	2019-12-05	Kenji Pacocha	kenji.pacocha@geemail.com	Tampa	Florida	676330455304201	35607422ddc92ff1b1c955fecb682c6a	JCB 16 digit	28.051939448725804	-82.4113297877114235
6461	2019-12-05 13:26:28	2019-12-05	Draven Kovacek	draven.kovacek@warmmail.com	Las Vegas	Nevada	3014609770638686	27f97dbf3d5a173766c98bdfad4943ea	JCB 16 digit	36.3277457606147962	-115.311550681965798
6462	2019-12-05 14:29:53	2019-12-05	Tracey Hane	tracey.hane@geemail.com	Toledo	Ohio	3736995256138479	b6049cab48ade36cfd36a6845e330b98	VISA 16 digit	41.6605089658111325	-83.507925298843162
6463	2019-12-05 14:30:24	2019-12-05	Oddie Glover	oddie.glover@geemail.com	Syracuse	New York	3096778374375987483	d38466effdad1f22dc057972a5d56d56	Mastercard	43.0471764668673273	-76.1374865621574344
6464	2019-12-05 14:56:11	2019-12-05	Clemmie Johnson-Kessler	clemmie.johnson.kessler@geemail.com	Columbus	Ohio	869991297909101463	10888db90e74c35e2844939f7efdc882	Voyager	39.9866683306217183	-82.9343777125004777
6465	2019-12-05 15:11:35	2019-12-05	Miss Lesta Haag	miss.lesta.haag@geemail.com	San Francisco	California	180011959016546321	4281d4c75de3c885fcf2367dd15d2aac	Maestro	37.7608125111405784	-122.404985290219486
6466	2019-12-05 16:58:24	2019-12-05	Miracle Crist	miracle.crist@geemail.com	Las Cruces	New Mexico	3096849422826659246	813c0ca6824f4b93b17185768ef13f3f	JCB 16 digit	32.3538411055725064	-106.785831431637334
6467	2019-12-05 17:25:31	2019-12-05	Elza Sawayn	elza.sawayn@geemail.com	Fresno	California	4926903861298	6876ccd30bfe0c1e4b30798dfdcd04b5	Diners Club / Carte Blanche	36.8344727392181781	-119.694058891443163
6468	2019-12-05 17:38:43	2019-12-05	Dr. Alvis Bauch	dr.alvis.bauch@geemail.com	Oakland	California	55586199714206085	97704b5cd2206a534eaa4f1481765c3e	VISA 13 digit	37.8146839876878502	-122.276350602453405
6469	2019-12-05 18:09:22	2019-12-05	Ericka O'Hara-Roob	ericka.o'hara.roob@geemail.com	San Francisco	California	3435648650803062	ba5537b2e22fb7c9c1a10f72b0f14c78	American Express	37.7547521322460042	-122.449053494077944
6470	2019-12-05 19:19:14	2019-12-05	Dr. Quinten Volkman Jr.	dr.quinten.volkman.jr.@geemail.com	Oakland	California	3158278102675983406	a13291e0af407ae8f703056337725c1b	American Express	37.7786191448737512	-122.255097299535919
6471	2019-12-05 19:56:15	2019-12-05	Mrs. Lavinia Hartmann	mrs.lavinia.hartmann@geemail.com	Berkeley	California	55283896796813144	8119b42e8895c7915e1fe6d3f0394559	Maestro	37.8670997398009277	-122.312246415045294
6472	2019-12-05 20:10:12	2019-12-05	Ms. Kathie Wilderman PhD	ms.kathie.wilderman.phd@geemail.com	Philadelphia	Pennsylvania	6011934206452491354	5ff27e46dae261e351d564aa0fd8ff7e	Voyager	39.9773401244036819	-75.2195116516102189
6473	2019-12-05 20:29:21	2019-12-05	Denise Kautzer	denise.kautzer@geemail.com	San Francisco	California	3337433141344547616	63eeda2bbc488350f488989a670478dc	American Express	37.7696022443177881	-122.411838207098654
6474	2019-12-05 20:38:18	2019-12-05	Lonzo Konopelski IV	lonzo.konopelski.iv@geemail.com	Meridian	Idaho	3158919092674368797	da3bb14fccb834e70b9ba752b78fad64	JCB 16 digit	43.6435140339665111	-116.4823215677809
6475	2019-12-05 21:07:42	2019-12-05	Orland Blanda	orland.blanda@geemail.com	Tempe	Arizona	869945958628530368	7559dd8f6c8ba4035cafc10898b78231	Voyager	33.2941462049648109	-111.970805961269136
6476	2019-12-05 21:47:09	2019-12-05	Jemima Wilderman	jemima.wilderman@geemail.com	Anaheim	California	4240729607389602	4700c0102d56977be004e615beff0603	Diners Club / Carte Blanche	33.909330365091563	-117.778738235935933
6477	2019-12-05 21:53:04	2019-12-05	Elfrieda Yost-Stamm	elfrieda.yost.stamm@geemail.com	Los Angeles	California	210064113826021432	0efbd2ebf2b1a6cfc8593bf950e9c623	Discover	34.0050361630372677	-118.316111742005859
6478	2019-12-05 21:54:37	2019-12-05	Daisye Farrell-Koepp	daisye.farrell.koepp@geemail.com	San Francisco	California	3112979600770427833	d163847dc12530a637956a60a68de15b	Maestro	37.8061105454634045	-122.46999727473704
6479	2019-12-05 21:56:17	2019-12-05	Meryl Turner-D'Amore	meryl.turner.d'amore@warmmail.com	San Francisco	California	4462379935481	4a676547df817699a44124d8a8cb5b75	Voyager	37.7484976703117283	-122.431848051872066
6480	2019-12-05 22:48:23	2019-12-05	Hermina Doyle	hermina.doyle@geemail.com	Cleveland	Ohio	6011115245436132453	4396148923eb4ae01180be00f1c50f67	VISA 13 digit	41.4635708148907867	-81.7526467573601821
6481	2019-12-05 22:57:08	2019-12-05	Mistie Hand	mistie.hand@geemail.com	San Francisco	California	6011493511402412779	f6db388b77634481ad753c2cbe64dec8	Mastercard	37.739884498910051	-122.424141692900591
6482	2019-12-06 00:01:48	2019-12-06	Nallely Sipes	nallely.sipes@geemail.com	Pearland	Texas	4958439868469224	401ad3cdaade1062ea3f68bcf485b5a7	Discover	29.6447843724202365	-95.2513672893255858
6483	2019-12-06 00:43:41	2019-12-06	Mr. Champ Hagenes	mr.champ.hagenes@geemail.com	Los Angeles	California	3009761852340676	17dacb7470239a2cd200e938f5212e65	Maestro	34.0626329644449015	-118.444162159179513
6484	2019-12-06 00:54:13	2019-12-06	Enoch Gibson	enoch.gibson@geemail.com	San Francisco	California	3011547771314738	014d22eddc525242b0b93772664fba0a	Maestro	37.7843219327022126	-122.429224188154137
6485	2019-12-06 01:09:18	2019-12-06	Louis Greenholt	louis.greenholt@geemail.com	Sioux Falls	South Dakota	180029201945341692	88cd74b552c3822b28590f168493a53a	Discover	43.6019410308536166	-96.8129618597850197
6486	2019-12-06 01:27:29	2019-12-06	Dr. Caden Hodkiewicz	dr.caden.hodkiewicz@geemail.com	San Francisco	California	3096436758577663294	5e6dfae88a32f061098768d48dd838d2	VISA 16 digit	37.7787528678241031	-122.430860047701984
6487	2019-12-06 01:33:01	2019-12-06	Craig Bergnaum	craig.bergnaum@warmmail.com	San Francisco	California	060469654162762	552d8f9d19358919126c992cfe9ab765	JCB 16 digit	37.7564388936791104	-122.425861050006219
6488	2019-12-06 01:35:16	2019-12-06	Caleb Rempel	caleb.rempel@geemail.com	Washington	District of Columbia	3753027741619745	5e35ca00f849da13b11406169af087da	Mastercard	38.8359001296371247	-77.0150368989657608
6489	2019-12-06 01:54:31	2019-12-06	Rayne Mohr DDS	rayne.mohr.dds@geemail.com	Berkeley	California	869917704469006769	e9170cb930ca1ca2944e6de3c955e906	Maestro	37.8795553528213844	-122.262585375273872
6490	2019-12-06 01:56:29	2019-12-06	Anais Romaguera-Sporer	anais.romaguera.sporer@warmmail.com	San Francisco	California	3023825332914727	ca875292a83ee075926c5742b8eef346	Diners Club / Carte Blanche	37.7643066429049483	-122.43834143917104
6491	2019-12-06 02:42:47	2019-12-06	Milford Weissnat	milford.weissnat@geemail.com	Columbia	South Carolina	4806547078436	2c4b4e1537fd6aca89953c7f6eaa5c7b	VISA 13 digit	33.9694555133845668	-80.9212181259430849
6492	2019-12-06 03:39:09	2019-12-06	Ilda Rolfson DDS	ilda.rolfson.dds@geemail.com	San Francisco	California	3759435025031335	8dabe52ca32e47c1e3502ca96eac97ef	VISA 13 digit	37.7815075092637187	-122.423305367928236
6493	2019-12-06 03:44:27	2019-12-06	Nakia Fritsch	nakia.fritsch@geemail.com	Colorado Springs	Colorado	3011203858162539	ab9998a6d9f3584ee55d9b93ecb91a25	American Express	38.8891474179971937	-104.758024180509892
6494	2019-12-06 04:06:18	2019-12-06	Hyrum Ankunding	hyrum.ankunding@woohoo.com	Philadelphia	Pennsylvania	3096419928041687317	e1accbf1579eee624cafdce9c79d2be3	VISA 16 digit	40.0107268015813062	-75.1383926222465988
6495	2019-12-06 05:09:41	2019-12-06	Sadie Beahan PhD	sadie.beahan.phd@geemail.com	San Francisco	California	869959235092218819	e61de81d991b2d867adc4921a64442d9	Maestro	37.7722707990815465	-122.412308330644152
6496	2019-12-06 05:18:45	2019-12-06	Cassandra Collins	cassandra.collins@woohoo.com	Ventura	California	3158747188727389414	367428eaf6fdceaaacf9c2e89747cebc	JCB 16 digit	34.2227635339528362	-119.247717773598424
6497	2019-12-06 05:27:51	2019-12-06	Lenora Skiles	lenora.skiles@geemail.com	Oakland	California	3045959779550765	d48b32e298a3392941ee0daf0eba1d1a	Discover	37.8163514528062379	-122.279406512941691
6498	2019-12-06 06:21:40	2019-12-06	Ms. Yolonda Feest	ms.yolonda.feest@geemail.com	Baltimore	Maryland	3407281208132695	6de0a8248746a7c6a74a300302a2791d	Voyager	39.2543438564054625	-76.5585122627224735
6499	2019-12-06 06:58:29	2019-12-06	Sabrina Kunze	sabrina.kunze@geemail.com	Glendale	Arizona	3337835639502493469	3f9c0724e31c8cb5a3f4d5d3610ca6bb	Mastercard	33.5701322995353451	-112.179999241957063
6500	2019-12-06 07:11:22	2019-12-06	Heber Donnelly	heber.donnelly@woohoo.com	San Francisco	California	3088070990637619641	c246031794b4b4f891be868e627739e0	VISA 13 digit	37.8003279314320153	-122.402614833792398
6501	2019-12-06 07:23:47	2019-12-06	Farris Rutherford	farris.rutherford@geemail.com	Berkeley	California	4097645890983113	a3bbb9c31d75811a6b0d1378ff81fd87	Maestro	37.904058026405167	-122.290513553994415
6502	2019-12-06 08:10:21	2019-12-06	Kayden Reynolds III	kayden.reynolds.iii@geemail.com	Oakland	California	4789828501891205	9cf4c18a1dd8899ccb7ca0e00021547f	Voyager	37.8251892499262183	-122.259633140559899
6503	2019-12-06 08:56:50	2019-12-06	Peyton Hodkiewicz DVM	peyton.hodkiewicz.dvm@woohoo.com	Cincinnati	Ohio	4161952191222642	6d9c92db1727746e0e1a108cc83c13d8	American Express	39.1377977723021075	-84.5987104599170294
6504	2019-12-06 09:26:57	2019-12-06	Celestino Kohler	celestino.kohler@geemail.com	Baltimore	Maryland	869979717668502409	06262398039480b19943c246e5d99e40	Diners Club / Carte Blanche	39.3802191114053102	-76.5348407765869041
6505	2019-12-06 09:30:40	2019-12-06	Rachelle Wunsch-Kertzmann	rachelle.wunsch.kertzmann@geemail.com	Phoenix	Arizona	675904786129058	2cce91635f22905459bacbe1c4fad807	VISA 16 digit	33.565019891637192	-112.096904626248786
6506	2019-12-06 10:13:22	2019-12-06	Dr. Susie Schiller III	dr.susie.schiller.iii@geemail.com	New York	New York	4092396591265443	58a959684291eb7aeca2f63fabfb43f7	Voyager	40.7555466788578755	-73.9307683921780381
6507	2019-12-06 10:36:51	2019-12-06	Pasquale McClure-Cremin	pasquale.mcclure.cremin@geemail.com	San Francisco	California	3112477041444006488	f51ec73b0112ed0b8106852df1468339	VISA 13 digit	37.7826645040432751	-122.408568749967472
6508	2019-12-06 10:44:00	2019-12-06	Vicki Yost	vicki.yost@geemail.com	Los Angeles	California	6011875436014737538	84115285f87f8380dbd4e803bd12389d	Maestro	34.023640381391715	-118.498283498314393
6509	2019-12-06 10:55:02	2019-12-06	Ms. Reina Prosacco	ms.reina.prosacco@warmmail.com	Los Angeles	California	53553632931841747	b9c91f2fc43c812dbf22b9be64cb37d2	JCB 16 digit	34.0527502004854341	-118.501083418213938
6510	2019-12-06 10:55:44	2019-12-06	Mr. Liam Schroeder	mr.liam.schroeder@geemail.com	Dallas	Texas	210064824083474474	1b0791996ee4027bbede2fe1e95e19a3	VISA 13 digit	32.8747258237835069	-96.7489698681477392
6511	2019-12-06 11:52:27	2019-12-06	Hank Braun-Mraz	hank.braun.mraz@geemail.com	San Francisco	California	3430719087427471	3fb4bf01fc6ecf41a81085f202189869	American Express	37.7658729151655308	-122.42678311182172
6512	2019-12-06 12:01:12	2019-12-06	Vonda Larkin	vonda.larkin@woohoo.com	San Francisco	California	3044216725866550	f17480a88a6655c7edcfb81d6bf742e2	JCB 15 digit	37.7581224342581407	-122.422613383670381
6513	2019-12-06 12:05:55	2019-12-06	Daniela Bailey-Wuckert	daniela.bailey.wuckert@geemail.com	Austin	Texas	3088936078052881609	7be8a1cb041581cd007059a10c68dcc7	Maestro	30.2262303637001644	-97.6740396837942342
6514	2019-12-06 12:10:02	2019-12-06	Nathan Pouros	nathan.pouros@geemail.com	Denver	Colorado	3528175784391076419	629240dc7bba989f75754a7ba9e0dcb5	VISA 13 digit	39.7404056459251791	-104.977675404703618
6515	2019-12-06 12:11:13	2019-12-06	Needham Tremblay	needham.tremblay@woohoo.com	Portland	Oregon	4083666923682049	f4a2fa4c66fde903b6dac226ee9ab192	JCB 16 digit	45.6276394323799721	-122.749162307195377
6516	2019-12-06 13:24:20	2019-12-06	Miss Veola Kling	miss.veola.kling@warmmail.com	Berkeley	California	210037364527954082	6356dd284861a8492062c84e338f216a	Voyager	37.8804043543914943	-122.293974626821907
6517	2019-12-06 13:41:01	2019-12-06	Shirleyann Abbott-O'Reilly	shirleyann.abbott.o'reilly@woohoo.com	Hialeah	Florida	4471989019826	2323648d40772c319b1d5e49a5cb6480	Diners Club / Carte Blanche	25.8763770758152027	-80.3521859375663041
6518	2019-12-06 14:52:38	2019-12-06	Mrs. Bridgett Bode	mrs.bridgett.bode@geemail.com	Los Angeles	California	3003679119525952	0189c70bd106af784ecb69ad8d7672b5	VISA 16 digit	33.9635760507412243	-118.346428435760728
6519	2019-12-06 15:02:59	2019-12-06	Dr. Cherise Erdman PhD	dr.cherise.erdman.phd@geemail.com	Manchester	New Hampshire	3027200810624733	0ba3995e79cf912df4107df847732c5b	American Express	43.0752255203273151	-71.3455047684147985
6520	2019-12-06 15:13:28	2019-12-06	Elaina Klein MD	elaina.klein.md@geemail.com	San Francisco	California	3031864232364347	aa52e6f86c4728f8475f3ff4eec8fb03	Mastercard	37.7993455137832157	-122.404186386452352
6521	2019-12-06 15:20:55	2019-12-06	Moody Welch	moody.welch@woohoo.com	Memphis	Tennessee	4084901511113043	def3bddcc692d33aa59852090b55034d	JCB 15 digit	35.1319762661654522	-89.9502851926047384
6522	2019-12-06 16:00:43	2019-12-06	Mr. Pinkney Ritchie II	mr.pinkney.ritchie.ii@warmmail.com	Kenosha	Wisconsin	3782181322754481	bf35ba75ceb9639ef86054a3db60e03d	Mastercard	42.5822240567605945	-87.8506108979456144
6523	2019-12-06 16:02:36	2019-12-06	Mr. Jesse Rolfson	mr.jesse.rolfson@geemail.com	Oakland	California	52860061060336485	f9600aa686664ab46503e71f28676ba1	VISA 16 digit	37.7790412841182217	-122.279554846891259
6524	2019-12-06 16:11:53	2019-12-06	Ashtyn Ferry	ashtyn.ferry@geemail.com	Fort Wayne	Indiana	675901228724942	c4a0c86605f4acd4116cc4d8bf135b99	VISA 16 digit	41.1220880549650616	-85.2310464515570629
6525	2019-12-06 16:21:15	2019-12-06	Miss Farah Nitzsche	miss.farah.nitzsche@woohoo.com	Houston	Texas	4402801575650192	55689f0d832c1768fc9c9cd72c6390f9	Voyager	29.8696457552801817	-95.3182852203041335
6526	2019-12-06 16:24:55	2019-12-06	Natalee Howell MD	natalee.howell.md@woohoo.com	Los Angeles	California	4404013066752	f132fe601084b363358d8e6e58d369a4	Discover	34.0808796403329808	-118.494277270789439
6527	2019-12-06 16:38:02	2019-12-06	Acey Satterfield	acey.satterfield@geemail.com	Amarillo	Texas	4888085972591307	550cc23b12357edb8b48d5f22bf36d41	JCB 15 digit	35.1273075775872883	-101.906616883803906
6528	2019-12-06 17:06:42	2019-12-06	Germaine Schmidt	germaine.schmidt@geemail.com	Detroit	Michigan	4502771791638926	307646f72053cd2e414490a181d7ca15	Discover	42.3941723256763083	-83.0839853841930562
6529	2019-12-06 17:12:07	2019-12-06	Augustina Kuhic	augustina.kuhic@geemail.com	Phoenix	Arizona	4089222842182	8aee13e9bb811e6acafe2a2931443888	Maestro	33.5388480184067035	-112.03772203344144
6530	2019-12-06 17:35:30	2019-12-06	Donald Rogahn	donald.rogahn@geemail.com	Austin	Texas	4240259550768255	2ef59205a0fbeb73a54b229bc8c6ba0e	VISA 16 digit	30.3518538095183672	-97.8256803491391338
6531	2019-12-06 17:53:21	2019-12-06	Aurthur Koch	aurthur.koch@woohoo.com	North Las Vegas	Nevada	4618767216387785	33b3a054b9e8be1dc7061fe4168a5e38	JCB 16 digit	36.2129171908989562	-115.124035197518396
6532	2019-12-06 17:55:50	2019-12-06	Miss Santana Sporer	miss.santana.sporer@geemail.com	Carlsbad	California	3337667109276878041	73aa3acd34bfabc6138ac2d269250d69	American Express	33.0326711821310184	-117.323321198045463
6533	2019-12-06 18:37:54	2019-12-06	Brooks Okuneva	brooks.okuneva@warmmail.com	San Francisco	California	3779344862259361	1ac6052c5102d22bc19cd0474f206ad3	Mastercard	37.7792665266279784	-122.407820774917155
6534	2019-12-06 19:00:14	2019-12-06	Rowan Wyman	rowan.wyman@warmmail.com	Fontana	California	4201525909754	5d83af2ba2cf1de4be6d6f47ca9cebf6	JCB 16 digit	34.0514899820704002	-117.503693123608457
6535	2019-12-06 19:12:29	2019-12-06	Gauge Doyle	gauge.doyle@woohoo.com	San Francisco	California	3027444541135482	e0d79361ff3caf50b3e35a7fff513108	VISA 16 digit	37.7454422050637888	-122.453121470796233
6536	2019-12-06 19:14:58	2019-12-06	Hazen Emmerich	hazen.emmerich@woohoo.com	Mesa	Arizona	3337634079422397875	8dd7aaa858f97cf74d046559f870f0a9	Mastercard	33.3186869836091972	-111.735905388777695
6537	2019-12-06 19:17:03	2019-12-06	Jared Jakubowski	jared.jakubowski@geemail.com	Indianapolis	Indiana	3337749580633669103	0d9d5308d4ec2d0742e5c923d0ea77d9	VISA 16 digit	39.8534786526121181	-86.0775292717121516
6538	2019-12-06 20:34:30	2019-12-06	Kayden Breitenberg	kayden.breitenberg@geemail.com	Los Angeles	California	210034627992062703	cbf614a51d3d97362d9f73a080ae2bb4	Voyager	34.0873726933129078	-118.493756144772462
6539	2019-12-06 20:38:40	2019-12-06	Ada Wuckert	ada.wuckert@geemail.com	Oakland	California	52010729958466536	efb87d2cd285b3a748d5a18e31554ecd	JCB 16 digit	37.8210863752860504	-122.272664930300522
6540	2019-12-06 20:42:58	2019-12-06	Calista King	calista.king@geemail.com	Chicago	Illinois	3732786953468135	ae4d5f6bbe5cfac4ea9d0a7fb48486ae	JCB 16 digit	41.8620455347768967	-87.6882557582605529
6541	2019-12-06 20:44:57	2019-12-06	Daijah Hand	daijah.hand@woohoo.com	New Orleans	Louisiana	3022268597621292	8cdb2eea83f7c265399bae0a84fc4bc7	JCB 16 digit	30.0825702941525712	-89.9020495470408321
6542	2019-12-06 21:18:05	2019-12-06	Jamir Schumm-Murray	jamir.schumm.murray@geemail.com	Omaha	Nebraska	4881996478747226	3578ede6df74bf32d0fb7ebe6d79739f	Maestro	41.3036274190206072	-96.0872831916086483
6543	2019-12-06 21:33:46	2019-12-06	Mortimer Hartmann	mortimer.hartmann@geemail.com	San Francisco	California	3528261119448375115	1a0c103957e7b0984a74182f3093ed64	JCB 16 digit	37.797545249335478	-122.412392728624951
6544	2019-12-06 21:38:07	2019-12-06	Petra Wyman	petra.wyman@geemail.com	Milwaukee	Wisconsin	3721392748663081	45d41fc88e11eba51d3a89e26b71e9ac	Diners Club / Carte Blanche	42.9641839935064311	-87.919814562854171
6545	2019-12-06 22:37:47	2019-12-06	Beaulah Ondricka	beaulah.ondricka@geemail.com	San Francisco	California	869988835338035441	b1e08f3294c551cb7f5ac807ec14cf45	Voyager	37.7674073868642779	-122.434145795828272
6546	2019-12-06 22:59:46	2019-12-06	Mr. Miner Thompson	mr.miner.thompson@geemail.com	Phoenix	Arizona	4995187441352160	e67dd153b907eb96e2c232c425dad2b6	VISA 16 digit	33.5407113262385153	-112.078344210369892
6547	2019-12-06 23:00:46	2019-12-06	Celena Orn	celena.orn@warmmail.com	Sterling Heights	Michigan	6011154634474071529	174e6e566a5293fad9b2b39d0530d2b8	Voyager	42.6480196482583906	-83.0899564295235962
6548	2019-12-06 23:12:24	2019-12-06	Dewayne Runolfsson	dewayne.runolfsson@warmmail.com	San Francisco	California	3337455087378921933	6b4cf6d2eaff253b310518b9151f0c1a	JCB 16 digit	37.7507775376003636	-122.438836395732793
6549	2019-12-06 23:27:15	2019-12-06	Demarco Sanford	demarco.sanford@geemail.com	Minneapolis	Minnesota	6011396727967353327	f19d4f34340173cf9c906ca8edb6719f	VISA 16 digit	45.063283670050275	-93.2473375621523672
6550	2019-12-07 00:48:07	2019-12-07	Germaine Ruecker	germaine.ruecker@geemail.com	Chandler	Arizona	3112092755544252149	0203d59dff9f8e1777e57dbee538c236	VISA 16 digit	33.3015671886593054	-111.787364298605922
6551	2019-12-07 01:11:33	2019-12-07	Mr. Woodie Lemke I	mr.woodie.lemke.i@geemail.com	San Francisco	California	3433797070165263	06d06f95c099bc91a22f5e0a67fbaaed	VISA 13 digit	37.7700652208807526	-122.434830594834793
6552	2019-12-07 01:36:04	2019-12-07	Ota Bednar	ota.bednar@geemail.com	San Francisco	California	4931709111788501	db6dea2b408be7bd7916a970c7bdcac3	VISA 16 digit	37.7804053209984616	-122.388333217957893
6553	2019-12-07 01:51:45	2019-12-07	Dr. Glenna Gerhold	dr.glenna.gerhold@woohoo.com	New York	New York	4357474206506517	da7437ee55f31375c2f8da411f2e32da	Diners Club / Carte Blanche	40.6017583491038536	-73.9815746369201719
6554	2019-12-07 02:36:47	2019-12-07	Purl Schmidt	purl.schmidt@woohoo.com	Henderson	Nevada	589377585787888	d7036d6205b5cffbde9eb66c823165bc	JCB 16 digit	35.9624713357936585	-115.129536596235639
6555	2019-12-07 02:44:18	2019-12-07	Ruthie Little	ruthie.little@geemail.com	San Francisco	California	676310504462028	e306fd00541deee67d063c5e6f341f0f	Mastercard	37.7623651514953593	-122.416783115330531
6556	2019-12-07 03:24:38	2019-12-07	Belinda Bode-Lubowitz	belinda.bode.lubowitz@geemail.com	Arvada	Colorado	4128377055200728	91d6816b6c166fb6a96d9a19bcc300eb	Mastercard	39.7741007777106006	-105.075375732450937
6557	2019-12-07 03:39:48	2019-12-07	Dr. Roxy Roob	dr.roxy.roob@geemail.com	Vacaville	California	4371183338102051	18d0ff981ee28a9dc837d2a3227b50e6	VISA 16 digit	38.367855655694008	-122.051044911832747
6558	2019-12-07 03:44:59	2019-12-07	Gerry Okuneva-Hermann	gerry.okuneva.hermann@warmmail.com	Chicago	Illinois	210011544824598035	0ff522feaf982da17b998bc45724923b	Discover	41.8520256446510572	-87.7479212115082845
6559	2019-12-07 04:46:03	2019-12-07	Dr. Itzel Ledner	dr.itzel.ledner@geemail.com	Everett	Washington	55048853979448582	a1de9828b86b7a79fe07e55e4cb207c0	Diners Club / Carte Blanche	48.0502393735930369	-122.145662417322029
6560	2019-12-07 04:58:32	2019-12-07	Lyric Corkery Sr.	lyric.corkery.sr.@woohoo.com	San Francisco	California	4267493063115625	5e92c9ee085d8e11ecfb20bfa97a8c74	Maestro	37.771126663514984	-122.403230041436984
6561	2019-12-07 05:27:02	2019-12-07	Dr. Margaretha Baumbach	dr.margaretha.baumbach@geemail.com	Oakland	California	4386732605798349	d07272d334fdcbab9851d89c5538f45a	JCB 15 digit	37.81400859358844	-122.251838624084513
6562	2019-12-07 05:46:27	2019-12-07	Kaylynn Schuster	kaylynn.schuster@geemail.com	San Francisco	California	6011282395017069041	98e65e77787ef234f59b80db232c14c0	Diners Club / Carte Blanche	37.7854684943445989	-122.438748365615851
6563	2019-12-07 07:05:17	2019-12-07	Ms. Lilie Beer	ms.lilie.beer@geemail.com	Stockton	California	4171839478456282	df7df446af558c2ac82b8f6eabe64942	Maestro	37.8928396960917908	-121.241475577986989
6564	2019-12-07 07:17:48	2019-12-07	Immanuel Jones	immanuel.jones@geemail.com	Houston	Texas	54888874658524421	58f387876c929c56f691e20659955097	Mastercard	29.6997075280252858	-95.2926166955862186
6565	2019-12-07 08:49:31	2019-12-07	Merton Bosco I	merton.bosco.i@warmmail.com	San Francisco	California	51774896357626691	a2b1bf69f83694245d6642da69d13d1b	VISA 16 digit	37.7657782655494501	-122.428342704351635
6566	2019-12-07 09:14:30	2019-12-07	Janet Ziemann	janet.ziemann@woohoo.com	Lakewood	Colorado	501810437733024	eed5183c08926dcc2dc5babe9e85badc	JCB 16 digit	39.6667447742015113	-105.102574520746614
6567	2019-12-07 10:08:48	2019-12-07	Cleo Marquardt	cleo.marquardt@geemail.com	San Antonio	Texas	180033341621841203	40656e7926fae2937bb69c6b314e8767	Voyager	29.5277344782907534	-98.4453061276882835
6568	2019-12-07 10:25:21	2019-12-07	Aurelio Sporer-Kub	aurelio.sporer.kub@geemail.com	Las Vegas	Nevada	180039832586888134	cfe6e66255c03dd8553dde1db3deeaee	Maestro	36.1660737369775731	-115.160920361590001
6569	2019-12-07 10:30:50	2019-12-07	Tempie Morissette MD	tempie.morissette.md@woohoo.com	Fort Worth	Texas	3008018666908755	80126e9e074b78d65889440e98c60ee1	VISA 13 digit	32.6914638126790535	-97.3871888864606632
6570	2019-12-07 11:00:41	2019-12-07	Celestino Stanton	celestino.stanton@geemail.com	Baltimore	Maryland	55688302465063146	d442ed5c6614b8ad4981ce2b5fcc6511	Discover	39.2020123681519124	-76.5550332894567447
6571	2019-12-07 11:37:22	2019-12-07	Darrian Thompson	darrian.thompson@woohoo.com	Omaha	Nebraska	210056963309114025	a04fa156cb2e639f9d1eccef327e6a0f	JCB 16 digit	41.1892813868034651	-96.0887491725500666
6572	2019-12-07 12:29:48	2019-12-07	Mrs. Trilby Nitzsche	mrs.trilby.nitzsche@geemail.com	San Francisco	California	3528891693529631123	387b19d5e47ffda9059576aa2a16ab40	Voyager	37.7459231264600845	-122.434500157210437
6573	2019-12-07 12:56:50	2019-12-07	Devin Bergstrom	devin.bergstrom@warmmail.com	San Francisco	California	6011147166862818468	4ac1186b10bcdc2e5adb61f27701b8b4	JCB 16 digit	37.7632358282550911	-122.435015889011154
6574	2019-12-07 13:30:42	2019-12-07	Dr. Tavon Moore I	dr.tavon.moore.i@geemail.com	Thousand Oaks	California	3054892819068822	9ac89e905c496751a02d17878cdecc56	Mastercard	34.2358401905085898	-118.935236655493085
6575	2019-12-07 13:36:39	2019-12-07	Dr. Mack Conn DDS	dr.mack.conn.dds@geemail.com	San Francisco	California	4934203415946020	5ce859885e28264fc47ad16af30a1b57	JCB 16 digit	37.8140565794884083	-122.437525170638338
6576	2019-12-07 13:41:36	2019-12-07	Marcia Heller	marcia.heller@woohoo.com	Columbus	Georgia	3096096197976648245	9dcfa2a8def3dd037d8d79713bbf208b	JCB 16 digit	32.4499302738390867	-84.8438171352889299
6577	2019-12-07 14:03:23	2019-12-07	Mr. Saverio Kohler I	mr.saverio.kohler.i@woohoo.com	Rancho Cucamonga	California	6011850274404702260	560893fb66661988b23adfb5b71b6d31	JCB 16 digit	34.1663344149935995	-117.632007431099936
6578	2019-12-07 14:20:18	2019-12-07	Sylvester Zboncak	sylvester.zboncak@warmmail.com	Renton	Washington	869978833594495922	d276d6b02e37320cac2cfd0e579ec431	Mastercard	47.3793525239046716	-122.285992540799072
6579	2019-12-07 14:50:13	2019-12-07	Chadd Kulas	chadd.kulas@geemail.com	Newark	New Jersey	4103508019739364	524f203fd51de682e2fb9b11a5879f4c	Mastercard	40.7767042443536241	-74.167766389737281
6580	2019-12-07 14:51:29	2019-12-07	Miss Teri Mueller DVM	miss.teri.mueller.dvm@woohoo.com	New York	New York	3112376199486736214	2d0fef1328363d4d72bb2187b1fa5992	VISA 16 digit	40.6483433252424007	-73.9194698857970565
6581	2019-12-07 15:16:58	2019-12-07	Sherree Heathcote	sherree.heathcote@woohoo.com	San Francisco	California	4728650442615	a8bde66632af788d2971f79e7260bbbb	JCB 16 digit	37.7292874097221471	-122.438077122300925
6582	2019-12-07 15:38:40	2019-12-07	Noretta Reynolds	noretta.reynolds@geemail.com	Lakeland	Florida	180047780817927793	f6de701deea3e1079c7c4a6fdb6193d3	VISA 16 digit	28.0372481264937647	-81.8927149985335774
6583	2019-12-07 15:58:41	2019-12-07	Rosemarie Bergnaum	rosemarie.bergnaum@geemail.com	San Francisco	California	869991377149854251	cce665aa0e7404068dbb329adf47d806	Mastercard	37.7467910831964488	-122.445933794794044
6584	2019-12-07 16:32:35	2019-12-07	Keandre Von	keandre.von@geemail.com	Denver	Colorado	869977655461712225	dc51a4d1cbf900a7dd787c17179846ba	VISA 16 digit	39.7025943368259817	-104.804974995904047
6585	2019-12-07 16:40:40	2019-12-07	Ezra Huel	ezra.huel@geemail.com	Scottsdale	Arizona	55376410502694364	1c9d382ad69d9e3c9e805773fbeb068c	VISA 16 digit	33.6450889846432943	-111.909038201855864
6586	2019-12-07 16:43:00	2019-12-07	Tyrin Powlowski	tyrin.powlowski@woohoo.com	Charlotte	North Carolina	210043266903513071	738997096a0971e2b57ed77064246abe	JCB 16 digit	35.188861053695156	-80.7457823323030084
6587	2019-12-07 17:09:54	2019-12-07	Koen Stehr DVM	koen.stehr.dvm@geemail.com	San Francisco	California	4546868277308798	5e23da5114803c1ab4c9dad8e80156de	VISA 13 digit	37.769822646166574	-122.421523502450412
6588	2019-12-07 17:45:09	2019-12-07	Sandie Mohr	sandie.mohr@warmmail.com	Norwalk	California	869950922602594784	28ef29a6b8f89944308108a310cf764c	Voyager	33.9844358599860215	-117.989546160450203
6589	2019-12-07 17:59:50	2019-12-07	Clement Ledner	clement.ledner@geemail.com	San Francisco	California	6011503571772261147	07d7170a45094a8f6de20b058fb57d50	VISA 16 digit	37.789792528416406	-122.452358629056135
6590	2019-12-07 18:21:36	2019-12-07	Delcie Oberbrunner	delcie.oberbrunner@geemail.com	Portland	Oregon	3096880268910889144	fe0630b2ebf964abb7b93f9e07cded90	Mastercard	45.5716021309029315	-122.677064831554901
6591	2019-12-07 18:25:41	2019-12-07	Consuelo Bartell	consuelo.bartell@woohoo.com	San Francisco	California	6011911264360891444	c9213ebfa55a2eb7cfdcf70338f030d5	Discover	37.774559855577472	-122.447384135308198
6592	2019-12-07 18:31:21	2019-12-07	Mr. Lincoln Spencer I	mr.lincoln.spencer.i@geemail.com	Oakland	California	51830659288725525	1351de097a8d117666b17105cd60b2f8	Mastercard	37.8034514038696585	-122.263858368850308
6593	2019-12-07 18:45:03	2019-12-07	Elza Howe	elza.howe@geemail.com	Round Rock	Texas	869983324847567520	aee0f1f2ebd94c3ef36e4a8cd0169a29	Maestro	30.4895485078122483	-97.5756069782506614
6594	2019-12-07 19:08:26	2019-12-07	Lota Kuhlman	lota.kuhlman@geemail.com	Dallas	Texas	869993797846400389	9b705680d32b73b1eae8be4abf89dd06	American Express	32.7660842299733304	-96.7188245749995019
6595	2019-12-07 19:55:55	2019-12-07	Latisha Boehm	latisha.boehm@geemail.com	Topeka	Kansas	3002470092741480	c51debbd2ac545407198ffafce189ab8	Mastercard	39.0649885509096109	-95.6051586471207457
6596	2019-12-07 19:57:12	2019-12-07	Mr. Case Prosacco	mr.case.prosacco@woohoo.com	Portland	Oregon	6011420975949645951	27a4549a3fca94de3d327843d2b1a9fc	JCB 15 digit	45.6083237477000765	-122.570912341447553
6597	2019-12-07 20:16:48	2019-12-07	Bascom Stamm	bascom.stamm@geemail.com	Pasadena	California	6011859436237768872	30dc1ef9b640c5b1b40f56d6cce242dd	VISA 16 digit	34.2206338916759947	-118.134233289286868
6598	2019-12-07 20:35:20	2019-12-07	Kurt Jaskolski	kurt.jaskolski@geemail.com	Philadelphia	Pennsylvania	51257639842609419	21d4e451cdc9d08d1c80b499b5d7c401	VISA 16 digit	39.9287518494255806	-75.223423810060325
6599	2019-12-07 20:46:45	2019-12-07	Dr. Gustav Hane PhD	dr.gustav.hane.phd@geemail.com	New York	New York	3088272344620986748	a1cd89e743c954a02ac81e5f26636d88	Maestro	40.679678036853673	-74.0244791957911019
6600	2019-12-07 20:55:34	2019-12-07	Dr. Devaughn Padberg DVM	dr.devaughn.padberg.dvm@geemail.com	San Francisco	California	53743104466119940	25367828a9b8a0066de61dc0f65ac111	VISA 13 digit	37.7856946361209154	-122.452361352433996
6601	2019-12-07 21:24:34	2019-12-07	Agusta Konopelski	agusta.konopelski@woohoo.com	Baltimore	Maryland	561298713729063	55e0e2850d574049ba5236dcc4fd9bf8	VISA 13 digit	39.3022159998770775	-76.5279746675416845
6602	2019-12-07 21:52:46	2019-12-07	Mrs. Pearle Stroman PhD	mrs.pearle.stroman.phd@geemail.com	Clinton	Michigan	210031489220892374	5f9749126181f010d6adda98b59d4932	Diners Club / Carte Blanche	42.5867242917485527	-82.9262730449046899
6603	2019-12-07 22:07:09	2019-12-07	Lester Connelly	lester.connelly@warmmail.com	New York	New York	3158901682861800436	0031ae3949371989cd9230c8f7ad2723	Diners Club / Carte Blanche	40.6929942463748162	-73.8707597325917362
6604	2019-12-07 22:16:14	2019-12-07	Lahoma Schroeder PhD	lahoma.schroeder.phd@geemail.com	San Antonio	Texas	180040377287410157	02732d1c8ea64fb50c2a3ce5bc08ef8c	Diners Club / Carte Blanche	29.4932127966150652	-98.6202269138138661
6605	2019-12-07 22:18:36	2019-12-07	Ms. Izabelle Bauch MD	ms.izabelle.bauch.md@warmmail.com	Irvine	California	869959443083322695	5e9480187ae526cafd9fadc4bc12c646	Maestro	33.6845306141782572	-117.831373936684059
6606	2019-12-07 22:23:06	2019-12-07	Florine Thompson MD	florine.thompson.md@geemail.com	Louisville	Kentucky	6011174519300371845	59b3d5cb9876d4fc51bf2620a8328b08	Diners Club / Carte Blanche	38.083550834366676	-85.7395229827217804
6607	2019-12-07 22:40:33	2019-12-07	Leonce Klein	leonce.klein@geemail.com	San Francisco	California	4319623290135941	5b3e4d18cc414f5d1f1a39af7d1e1844	VISA 13 digit	37.7808082472252593	-122.48948262072112
6608	2019-12-07 22:49:04	2019-12-07	Carrol Breitenberg	carrol.breitenberg@woohoo.com	San Francisco	California	3025057845603757	d213846590591028a6f00420b683c811	American Express	37.7420583419972573	-122.435704901857534
6609	2019-12-07 23:25:05	2019-12-07	Johnson Nolan	johnson.nolan@geemail.com	San Francisco	California	3426191952381777	403ae694b5dbc1e99791251ac0065829	JCB 16 digit	37.7937929869624583	-122.440389459173304
6610	2019-12-07 23:30:45	2019-12-07	Dr. Kalel Bernier II	dr.kalel.bernier.ii@warmmail.com	Berkeley	California	55505152053166103	fee07f45efe22d9463b13dd85153b9c6	Diners Club / Carte Blanche	37.8751462083400554	-122.270198074974928
6611	2019-12-07 23:56:34	2019-12-07	Lasonya Bergnaum	lasonya.bergnaum@warmmail.com	Des Moines	Iowa	3045669609038796	a534a8f544d5d6b8a9971a929fd37eb5	American Express	41.5909020907454234	-93.6567327030047778
6612	2019-12-07 23:59:20	2019-12-07	Mrs. Ruby Kassulke MD	mrs.ruby.kassulke.md@geemail.com	Denver	Colorado	501817415542061	5088cb8930465255338c7fb2f47150ca	VISA 13 digit	39.8584984870214001	-104.922204284161708
6613	2019-12-08 00:06:59	2019-12-08	Ole Hoeger	ole.hoeger@geemail.com	Winston–Salem	North Carolina	3088236173126277756	04dc21779b45b0af6933473a6eebec50	Mastercard	36.0248731624100316	-80.1915175174027581
6614	2019-12-08 00:10:21	2019-12-08	Charles Rodriguez MD	charles.rodriguez.md@warmmail.com	Broken Arrow	Oklahoma	3112262245714752965	53227a4e298eec5cf1c1746c38479f98	VISA 16 digit	36.0513337217047791	-95.7230455120969594
6615	2019-12-08 01:35:17	2019-12-08	Dr. Mallie Welch DVM	dr.mallie.welch.dvm@geemail.com	Berkeley	California	3750805132223166	24dbf23bf742ca6798905f65e64cf0ec	VISA 16 digit	37.8726042151674491	-122.273437441995881
6616	2019-12-08 01:39:00	2019-12-08	Armani Gibson	armani.gibson@geemail.com	West Covina	California	3158100827828618913	3a8a954b90c0a442c4a56140a2d21c98	Discover	34.1411482383605076	-117.960313031317284
6617	2019-12-08 01:40:48	2019-12-08	Laurel Fritsch	laurel.fritsch@geemail.com	San Francisco	California	180005295675144407	359090c929b2d9e972e9b5a07b7dd5ed	Voyager	37.7638956282868037	-122.417718298206225
6618	2019-12-08 01:41:38	2019-12-08	Verona Haag	verona.haag@geemail.com	Bridgeport	Connecticut	3792706161845244	c5d5bcba44e0779ed08da48524332fec	VISA 13 digit	41.1155453820411054	-73.1160266764361495
6619	2019-12-08 02:58:55	2019-12-08	Mr. Gasper Kassulke	mr.gasper.kassulke@geemail.com	San Diego	California	6011228754993458726	fea84c429ea5245487acb2dc432e1480	American Express	32.7430808817569172	-117.167152288220834
6620	2019-12-08 03:13:50	2019-12-08	Dr. Arther Walker Jr.	dr.arther.walker.jr.@geemail.com	San Francisco	California	869943384102907901	d32c24b758a66e811c7c08cf49f6be99	Maestro	37.8032390231755997	-122.42436668000795
6621	2019-12-08 03:42:55	2019-12-08	Roxane Hettinger	roxane.hettinger@geemail.com	San Francisco	California	869939103685377308	aabbc55859f355c630d894b81730c5a7	VISA 16 digit	37.772696776795236	-122.440906702892292
6622	2019-12-08 04:17:02	2019-12-08	Phebe Walter	phebe.walter@geemail.com	Berkeley	California	180092359642258825	ebcff8fd41a1f75df9db3dbd4a55b7ed	JCB 16 digit	37.8552713241046916	-122.259832332364184
6623	2019-12-08 04:36:03	2019-12-08	Ms. Fannie Friesen DVM	ms.fannie.friesen.dvm@geemail.com	Raleigh	North Carolina	3337579225479808242	7a3791680f3c5e1764aad6f5464d2673	VISA 13 digit	35.8482275982987133	-78.6642022115115083
6624	2019-12-08 05:05:02	2019-12-08	Ann Bergnaum	ann.bergnaum@geemail.com	Chicago	Illinois	4854140535638333	914997ce61cb3a0b7d851046f2024892	JCB 16 digit	41.8039793919142326	-87.7473690314248103
6625	2019-12-08 05:06:19	2019-12-08	Paola Doyle	paola.doyle@warmmail.com	Los Angeles	California	3796560182735454	e8eca4ea19d7f7f73ad7c4e9acf0e390	VISA 13 digit	34.0192053827323022	-118.495075390673421
6626	2019-12-08 05:48:00	2019-12-08	Ms. Retha Wisozk	ms.retha.wisozk@warmmail.com	Frisco	Texas	6011972665708916873	492ae93be6c2b058f68bab74ac403073	VISA 16 digit	33.2522834611587257	-96.8947537793055176
6627	2019-12-08 06:06:57	2019-12-08	Dr. Fate Corkery III	dr.fate.corkery.iii@geemail.com	Pembroke Pines	Florida	3051512109915697	783d83a5326d4df0598b2c36a1d3a08b	VISA 16 digit	26.073282125130298	-80.3366815758772219
6628	2019-12-08 06:50:31	2019-12-08	Eris Skiles	eris.skiles@geemail.com	San Francisco	California	4604938122727	2ba58ca3778e4bed45cb261ec97fe310	Discover	37.7374503663791359	-122.433779289399553
6629	2019-12-08 07:06:12	2019-12-08	Phebe Simonis	phebe.simonis@woohoo.com	Bellevue	Washington	6011450826475998889	4815cca8b9de1dd2393eb5e0835cbee7	JCB 16 digit	47.6510624052207916	-122.252847161941219
6630	2019-12-08 07:45:57	2019-12-08	Venice Kerluke	venice.kerluke@geemail.com	Aurora	Illinois	210031016858990269	a3581ba48f14119c192d164bd82c5f34	JCB 16 digit	41.7640681398790363	-88.3421942140836194
6631	2019-12-08 08:24:10	2019-12-08	Zettie Reichert	zettie.reichert@geemail.com	San Francisco	California	3030455637218401	bbfba4d53b4afd4b760f670f6740e393	Diners Club / Carte Blanche	37.7883554071529062	-122.434504541454174
6632	2019-12-08 08:28:20	2019-12-08	Ossie Kassulke	ossie.kassulke@geemail.com	Mesa	Arizona	6011205837807495146	e72a0c7da41fc2e7a8149f6888cde649	VISA 13 digit	33.3444779487471976	-111.7472790840432
6633	2019-12-08 08:53:52	2019-12-08	Ellery Fay	ellery.fay@woohoo.com	New York	New York	53346756371889023	b9f56758874e67b32adb43414f5e20f9	JCB 15 digit	40.7385899226404717	-73.9607878312829854
6634	2019-12-08 09:01:29	2019-12-08	Jenifer Kozey-Buckridge	jenifer.kozey.buckridge@woohoo.com	San Francisco	California	3088038374972907203	3d246a222e1421870965277ea4caf353	American Express	37.7865247124158046	-122.467028805868665
6635	2019-12-08 09:14:36	2019-12-08	Markel Kertzmann	markel.kertzmann@geemail.com	San Francisco	California	4251201545279093	de0d7ef899168cd8319c6f1b17c4cab0	Discover	37.7976049566637471	-122.445453389710465
6636	2019-12-08 09:38:31	2019-12-08	Miss Mickie Lakin DDS	miss.mickie.lakin.dds@geemail.com	Indianapolis	Indiana	6011055031782266687	49e614cea27bd10e628f283243b19c31	Discover	39.7965189104441563	-86.1308390202667482
6637	2019-12-08 11:35:47	2019-12-08	Louvenia Davis	louvenia.davis@geemail.com	San Francisco	California	6011685530149082537	4bc85c0c63fd52bbdd9263493e37f81c	VISA 16 digit	37.7921874765150037	-122.437860995681362
6638	2019-12-08 12:53:10	2019-12-08	Hayes Sipes MD	hayes.sipes.md@geemail.com	Warren	Michigan	54073159955293036	250ed336f3cfd6a94a203ae4bcabe224	VISA 16 digit	42.4228025177024293	-82.9866104527376649
6639	2019-12-08 13:07:03	2019-12-08	Rene Abernathy	rene.abernathy@geemail.com	San Francisco	California	869957524549513928	9b5293a96819a84f8b561fbcda3f3db1	Discover	37.7577548787808794	-122.429308169862281
6640	2019-12-08 13:46:43	2019-12-08	Vonetta Toy	vonetta.toy@geemail.com	St. Louis	Missouri	676136002588311	e715dc9bb598730d67d56df6fbce61eb	VISA 16 digit	38.6272183670353115	-90.2303517817057781
6641	2019-12-08 14:03:10	2019-12-08	Dr. Isam Davis V	dr.isam.davis.v@geemail.com	San Francisco	California	3096026333934805628	aaffdc731a26906dfcdc620ec73c75f6	JCB 16 digit	37.7439052559663821	-122.469877647078206
6642	2019-12-08 14:46:57	2019-12-08	Esau Kovacek-Sporer	esau.kovacek.sporer@geemail.com	Baltimore	Maryland	4528975030880393	3ab158f332bf8a7374b0a23ecbf7356c	Voyager	39.2313986249733659	-76.5966327694263356
6643	2019-12-08 15:06:35	2019-12-08	Georgiana Considine	georgiana.considine@geemail.com	San Francisco	California	3528369750448454426	1f72f7c22bf8e306118f3693cd4fae54	VISA 16 digit	37.7524977055794224	-122.425304054100991
6644	2019-12-08 15:23:18	2019-12-08	Cornelius Will-Nolan	cornelius.will.nolan@woohoo.com	San Francisco	California	3022659563432450	ec2c5805348ca977fc5dc02f94c8e458	Mastercard	37.7983365057100542	-122.413871724561361
6645	2019-12-08 15:41:55	2019-12-08	Bobbye Runolfsson	bobbye.runolfsson@geemail.com	San Francisco	California	676375220859955	162ba6cbb9d7103ca200e51d77d38c27	Discover	37.7895457762638358	-122.427564266435141
6646	2019-12-08 16:08:42	2019-12-08	Arline Marks	arline.marks@woohoo.com	Lincoln	Nebraska	676348761453785	656d6bcee109447ec99e9fae91b9039d	Mastercard	40.7798065011873803	-96.7350758504282737
6647	2019-12-08 16:11:49	2019-12-08	Elma Dicki	elma.dicki@geemail.com	Oakland	California	3088811034930783129	ad0b72d328c586a9f5fbfaf14cd65fe9	VISA 13 digit	37.8315889672752235	-122.256240548580649
6648	2019-12-08 16:24:08	2019-12-08	Deanne Brown	deanne.brown@woohoo.com	Fort Worth	Texas	4617930696803	c5f460507b3d7578bfe49e20e0388b7e	VISA 16 digit	32.7596966460403038	-97.2869494544163302
6649	2019-12-08 16:30:33	2019-12-08	Joseph Veum	joseph.veum@geemail.com	Kansas City	Missouri	4475804704959	96f8435ba17f768dd1950095f7da17a9	VISA 16 digit	39.1334620766177821	-94.6464077090136726
6650	2019-12-08 16:50:45	2019-12-08	Karley Turcotte-Runolfsson	karley.turcotte.runolfsson@geemail.com	San Francisco	California	3096454787208641418	200bdc68aa0eec370b5e5962a7c0dd38	VISA 16 digit	37.7630834200679217	-122.437285453506163
6651	2019-12-08 17:40:29	2019-12-08	Kameron Nolan	kameron.nolan@woohoo.com	Fayetteville	North Carolina	210071665084152077	dc2860ec557cf0995cd550c9349416bc	VISA 16 digit	35.0204152758020868	-79.0723488969858721
6652	2019-12-08 17:41:43	2019-12-08	Tatianna White	tatianna.white@geemail.com	Overland Park	Kansas	3028849932522602	d8a390309b5ded9970a8c30b16d0f402	JCB 16 digit	38.8475585593245967	-94.7105723944533651
6653	2019-12-08 18:28:56	2019-12-08	Johnie Runolfsson	johnie.runolfsson@geemail.com	Corona	California	4626789954478	7220723d47be69717b1018eca2989f16	VISA 13 digit	33.9452279315218348	-117.488208307392895
6654	2019-12-08 18:30:03	2019-12-08	Solomon Lindgren-Streich	solomon.lindgren.streich@geemail.com	Berkeley	California	6011894013478805825	f380712efa605fb84318983f702603b8	Discover	37.8833238900186942	-122.25109916239056
6655	2019-12-08 18:40:00	2019-12-08	Nakisha Hills	nakisha.hills@geemail.com	Indianapolis	Indiana	6011092239207267082	e91e94935acc5938effc046e26f261f7	Mastercard	39.7677436384379845	-86.1782064387310243
6656	2019-12-08 19:00:01	2019-12-08	Vern Moen	vern.moen@woohoo.com	Milwaukee	Wisconsin	4069588869871428	66350cb8366d2b5a93335a988f7fb0d8	VISA 16 digit	43.0282995511863362	-87.9279573776859849
6657	2019-12-08 19:53:28	2019-12-08	Almyra VonRueden	almyra.vonrueden@geemail.com	Mesquite	Texas	6011174471285346444	add87b87a4813235db3434cbafdf03c3	American Express	32.7417301643449861	-96.636849976909545
6658	2019-12-08 20:05:13	2019-12-08	Pepper Bogisich	pepper.bogisich@geemail.com	Berkeley	California	3431323095769914	983b0e0a8c2222f8ce125cb0bcf86d57	American Express	37.848498912995808	-122.278327779758598
6659	2019-12-08 20:16:43	2019-12-08	Annetta Gutmann-Christiansen	annetta.gutmann.christiansen@woohoo.com	Seattle	Washington	180011871732354007	364b8449d1c1eb83025805707b556111	Discover	47.7040420342627911	-122.335285537961497
6660	2019-12-08 21:33:58	2019-12-08	Verl Marvin	verl.marvin@geemail.com	Columbus	Ohio	4437611764285265	01325c6c52e7fff77bd5b575be405b8a	JCB 16 digit	40.070500945816562	-82.9515366035748372
6661	2019-12-08 21:36:39	2019-12-08	Lelia O'Connell PhD	lelia.o'connell.phd@geemail.com	San Francisco	California	4245061435670093	c809afea20576f120afebc6e38b48865	VISA 13 digit	37.7947755654122801	-122.44268614415553
6662	2019-12-08 21:39:54	2019-12-08	Cris Conn	cris.conn@warmmail.com	San Francisco	California	3112986534843242492	6a99a913e06190ad1c7770c637b98e26	Maestro	37.8055461326067288	-122.462608160874964
6663	2019-12-08 21:53:19	2019-12-08	Dr. Vicky Walter	dr.vicky.walter@geemail.com	Clearwater	Florida	4947744413321	881ae5ad40a68731ed10ef9d4ee5a531	Mastercard	28.0466730295341442	-82.820688819120079
6664	2019-12-08 23:01:29	2019-12-08	Dr. Brent Bode	dr.brent.bode@geemail.com	Shreveport	Louisiana	4500573065584998	c2e8d292711e29e3fd5622014f29a5cc	American Express	32.555903835851332	-93.6983719198711213
6665	2019-12-08 23:20:37	2019-12-08	Phoebe Dach	phoebe.dach@geemail.com	San Francisco	California	3337085112084376855	b78c98e25db24e937dfd2a66fc3503d8	JCB 15 digit	37.7649128010103752	-122.435211094650512
6666	2019-12-08 23:26:59	2019-12-08	Mr. Art Mertz III	mr.art.mertz.iii@geemail.com	San Francisco	California	869937910260888703	40dbcf37daeedd9ce0623e2af92cfdd8	American Express	37.7668701788709598	-122.419376910771462
6667	2019-12-09 00:03:54	2019-12-09	Alfredo Hoppe	alfredo.hoppe@geemail.com	San Francisco	California	3096804189596796507	c64101d8ae2d584e5fded43df07f9815	Voyager	37.756518439352206	-122.412128844784192
6668	2019-12-09 00:15:11	2019-12-09	Cori Kutch	cori.kutch@geemail.com	Little Rock	Arkansas	3717085486564380	075cd7729cbab3335f5570fd765a14fc	JCB 15 digit	34.8143080818742519	-92.2938433727588432
6669	2019-12-09 00:18:43	2019-12-09	Dr. Nilda Schuster MD	dr.nilda.schuster.md@woohoo.com	Pittsburgh	Pennsylvania	3528234185034886322	ca07fa0b6ad1be4d189efa6fdd9b4667	JCB 16 digit	40.3522514942523074	-80.0315111268017461
6670	2019-12-09 00:45:53	2019-12-09	Tresa Howell	tresa.howell@geemail.com	Fresno	California	6011866522935162699	dca86e31aed96956f7fb4c34028938fc	JCB 15 digit	36.7978833815421922	-119.724228151619073
6671	2019-12-09 02:18:05	2019-12-09	Chelsea Harris-Senger	chelsea.harris.senger@warmmail.com	Oakland	California	6011097501865192000	e386bb790e276e5a26eff1294d5460e0	VISA 16 digit	37.785761364032119	-122.291579638554822
6672	2019-12-09 02:31:20	2019-12-09	Tommie Kulas	tommie.kulas@woohoo.com	Oakland	California	3712021497025751	e0f42e0ff128665b4053ca20161cd779	VISA 16 digit	37.7720572549058318	-122.259493288068157
6673	2019-12-09 03:19:02	2019-12-09	Jewel Dooley DDS	jewel.dooley.dds@woohoo.com	San Francisco	California	55279333298827329	2c175c2d0c37de86a4af0ead22fa3749	Discover	37.7700604254125523	-122.40886758559445
6674	2019-12-09 03:20:52	2019-12-09	Corey Nolan	corey.nolan@geemail.com	Tallahassee	Florida	54976029931744535	8a0cf0b464d0ad9eca03bfca947b93e3	VISA 16 digit	30.4182067729089418	-84.3290952017545692
6675	2019-12-09 03:26:07	2019-12-09	Dr. Maud Robel	dr.maud.robel@geemail.com	Charlotte	North Carolina	53045547358608179	8f4c783854a2bf2d36fc959996c466e4	Discover	35.2116218975067099	-80.7758880855459722
6676	2019-12-09 03:34:21	2019-12-09	Dr. Amari Zulauf Sr.	dr.amari.zulauf.sr.@woohoo.com	Miami	Florida	3158622945870447087	eccb4f78fc3f69fe10f3533cbc2e8473	VISA 16 digit	25.7560697820641131	-80.3005977972284057
6677	2019-12-09 04:21:24	2019-12-09	Dr. Osborne Denesik	dr.osborne.denesik@warmmail.com	New York	New York	3407901593801584	2487805d2f9f598619dce2895f08f037	JCB 16 digit	40.6689731761571025	-73.8610230847157538
6678	2019-12-09 04:27:57	2019-12-09	Miss Camryn Runte MD	miss.camryn.runte.md@geemail.com	Austin	Texas	4451350669482492	874b8e3ae28e64c6dda35e5f7d45bd99	JCB 16 digit	30.2062475375957789	-97.6643723144900093
6679	2019-12-09 04:28:06	2019-12-09	January Mohr PhD	january.mohr.phd@woohoo.com	New York	New York	639041263581773	f84dcfd7d8a9a35acf8116876e13266a	VISA 16 digit	40.6482131378017328	-74.0324344162259251
6680	2019-12-09 04:46:18	2019-12-09	Miss Katie Predovic MD	miss.katie.predovic.md@warmmail.com	Oakland	California	4480106953958885	808e6a2e0bcd262205967ccff9b997c2	VISA 16 digit	37.8476332967395521	-122.264375169121038
6681	2019-12-09 04:50:43	2019-12-09	Lise Beer	lise.beer@warmmail.com	New York	New York	869928970858948385	2d150b7e8bf810eae2e4be5b48288d78	VISA 16 digit	40.7524846648555226	-74.0072189236886828
6682	2019-12-09 05:23:00	2019-12-09	Rowland Armstrong	rowland.armstrong@woohoo.com	Springfield	Missouri	4318296035466375	10e58bc04e65515c90f572403e881c70	Maestro	37.1513527559775909	-93.3745170162815725
6683	2019-12-09 05:37:23	2019-12-09	Diego D'Amore	diego.d'amore@geemail.com	New York	New York	3112101385346725644	383ed46ab4745ef48c1934e1110b78a0	VISA 13 digit	40.6655384718663981	-73.954609058600667
6684	2019-12-09 05:41:46	2019-12-09	Lisbeth Heathcote	lisbeth.heathcote@woohoo.com	Seattle	Washington	4056773768538	9df49a3dd49ff81a6a5ffb9ef29a80e8	Discover	47.5723608154728979	-122.329332062081988
6685	2019-12-09 06:00:15	2019-12-09	Jordan Bins	jordan.bins@geemail.com	San Antonio	Texas	4410518357555858	c435913698fb12b6cfde983ebc85c719	Voyager	29.4210922966316346	-98.5187402016319282
6686	2019-12-09 06:06:14	2019-12-09	Dr. Lovett Spencer II	dr.lovett.spencer.ii@geemail.com	Milwaukee	Wisconsin	3528243040949755428	10536c3a2179b9b8b0274eb6f2ce3973	VISA 13 digit	43.0762985067527708	-88.0397793315451622
6687	2019-12-09 06:07:25	2019-12-09	Phoebe Schulist	phoebe.schulist@geemail.com	San Francisco	California	3096450951114345415	4e1390a778286a39b9f751223b1b0d5a	VISA 16 digit	37.8087575201908521	-122.41519743472908
6688	2019-12-09 06:17:58	2019-12-09	Dr. Burnie Padberg	dr.burnie.padberg@geemail.com	San Francisco	California	630406102515738	c203f12cd8139776f0b4944cda16a547	JCB 15 digit	37.7769671711067829	-122.420855911671339
6689	2019-12-09 06:46:30	2019-12-09	Jaelynn Marvin	jaelynn.marvin@geemail.com	San Francisco	California	3468826011754584	02e31acc367964dd47af404513255832	JCB 16 digit	37.7493655703397906	-122.423811214797084
6690	2019-12-09 06:51:38	2019-12-09	Dr. Bridgett Dibbert PhD	dr.bridgett.dibbert.phd@geemail.com	New York	New York	3438777944324770	b5235aa21174fad00f55271d866dd9fc	Voyager	40.6674722691755761	-74.0109344575915458
6691	2019-12-09 07:24:57	2019-12-09	Kathryn D'Amore	kathryn.d'amore@geemail.com	Orlando	Florida	3528093644668485777	38cb721aeda13f02e9941faa65ebfdae	Diners Club / Carte Blanche	28.3928980510015023	-81.282146559186657
6692	2019-12-09 08:04:58	2019-12-09	Roni Trantow	roni.trantow@warmmail.com	San Francisco	California	210084569702443139	e6722adfe3b4dad76fd8d0b4928796ae	VISA 16 digit	37.7593499082998534	-122.410195733159696
6693	2019-12-09 08:05:46	2019-12-09	Ms. Lavina Schmitt	ms.lavina.schmitt@geemail.com	Detroit	Michigan	675943548693795	e4804bfca46ad72d55c12b2d26077007	American Express	42.3545804926585419	-83.1887302314050459
6694	2019-12-09 08:31:06	2019-12-09	Dwain Osinski-Schuster	dwain.osinski.schuster@woohoo.com	New York	New York	869911034236650202	a3553ce6ba43281d62d30d1a09a6e696	VISA 16 digit	40.6661986883487572	-74.0318895288173024
6695	2019-12-09 09:02:04	2019-12-09	Dr. Clemence Ondricka	dr.clemence.ondricka@geemail.com	Chula Vista	California	869909584889658153	a914fd939f2a9f72821a3ea542ab2a00	VISA 13 digit	32.5642639906842248	-116.92259770364015
6696	2019-12-09 09:06:42	2019-12-09	Ms. Averie Smitham	ms.averie.smitham@warmmail.com	Raleigh	North Carolina	869982485666156058	1b020a51afae60f64864aca4c082638f	Voyager	35.7884588215634167	-78.6267921121262106
6697	2019-12-09 09:14:50	2019-12-09	Shaneka Bosco DDS	shaneka.bosco.dds@warmmail.com	San Francisco	California	3054083868443435	1862995851e557723928768970bb4f4a	Maestro	37.7844644192561745	-122.434885105758127
6698	2019-12-09 10:05:32	2019-12-09	Ray Witting	ray.witting@warmmail.com	Dallas	Texas	4068884522981261	83844abe5119ebec638bda7a62348b51	JCB 16 digit	32.8302418302550905	-96.7282328886408322
6699	2019-12-09 10:30:26	2019-12-09	Mrs. Kimberlee Spencer	mrs.kimberlee.spencer@geemail.com	Gainesville	Florida	4456601845054042	0bb0c6e5effd6f7c2b62078874a40b0b	JCB 16 digit	29.7656405368179087	-82.3982022427827161
6700	2019-12-09 10:35:35	2019-12-09	Felipe Bernhard	felipe.bernhard@geemail.com	Gainesville	Florida	3055190441738303	6d86d3563c9cd88c1d72a9e81e79d92e	VISA 13 digit	29.5846205146808181	-82.2721130901355338
6701	2019-12-09 12:15:48	2019-12-09	Miss Rosann Legros	miss.rosann.legros@geemail.com	Los Angeles	California	3112950681992075371	628436a4594c4f9d54e227a62b185511	VISA 16 digit	33.9654611077025521	-118.4017320869483
6702	2019-12-09 12:25:03	2019-12-09	Delwin Rolfson DDS	delwin.rolfson.dds@geemail.com	San Antonio	Texas	6011530278441196152	21f6b9e60a305587613b6ae4a0574961	JCB 16 digit	29.3833298849944029	-98.5880367635585344
6703	2019-12-09 12:50:24	2019-12-09	Ms. Trudie Moen	ms.trudie.moen@woohoo.com	San Francisco	California	4235266566163352	3588c79a51db2f65a95361349f3c81c6	JCB 16 digit	37.7932084952898748	-122.442153312438265
6704	2019-12-09 12:54:35	2019-12-09	Evander Leuschke	evander.leuschke@geemail.com	San Francisco	California	3088617973992162001	d700651a67c2733b5b41d123247ac2a5	VISA 16 digit	37.7684014220506938	-122.446079133638378
6705	2019-12-09 13:03:40	2019-12-09	Fidel Wunsch-Nikolaus	fidel.wunsch.nikolaus@woohoo.com	Broken Arrow	Oklahoma	4411083486494163	ba420828fecbf758d2b938e7bce37c46	Maestro	36.1244190078936498	-95.8017266280893267
6706	2019-12-09 13:19:38	2019-12-09	Ezzard Cormier-Wehner	ezzard.cormier.wehner@warmmail.com	Irving	Texas	3462667268550762	ca4ce32af638258a10682bb419d5f0d6	VISA 16 digit	32.8551318258930038	-96.9698431568033925
6707	2019-12-09 13:20:05	2019-12-09	Birt Yundt	birt.yundt@geemail.com	Denver	Colorado	6011558868979633688	98e7c99b23845836b335927f03d19b5a	Mastercard	39.830143288435039	-104.804749849276988
6708	2019-12-09 14:00:59	2019-12-09	Ms. Maud Ledner DVM	ms.maud.ledner.dvm@geemail.com	Oakland	California	869910749096050349	6ada87c5887dd8f0559c709f811b1daf	VISA 13 digit	37.8011078168753727	-122.25644858570179
6709	2019-12-09 14:27:33	2019-12-09	Mrs. Josefina Beatty	mrs.josefina.beatty@geemail.com	Chicago	Illinois	52018063740177777	593e39aab26c7aeddb6e51d0d50a73a2	Discover	41.8897659318823372	-87.5859329590138032
6710	2019-12-09 15:02:46	2019-12-09	Mrs. Agness Mante PhD	mrs.agness.mante.phd@woohoo.com	Los Angeles	California	54069613790417081	8127d7c5e91b7568e03e9268d7759916	JCB 16 digit	33.9890862949058388	-118.485524778393284
6711	2019-12-09 15:59:41	2019-12-09	Breanne Bradtke	breanne.bradtke@geemail.com	San Francisco	California	869971339979221138	606bc1983202aa02242df54a05605e86	VISA 13 digit	37.7548103473831489	-122.424771819894673
6712	2019-12-09 16:55:14	2019-12-09	Charley Cormier	charley.cormier@geemail.com	San Francisco	California	6011633467889710980	65cf1469617ebc5aeed94a44dbad6c81	American Express	37.732864618923827	-122.395855070235299
6713	2019-12-09 17:03:43	2019-12-09	Mrs. Zelma Feil	mrs.zelma.feil@woohoo.com	Lakewood	Colorado	4591172828524340	a723ed5f66bbd51e22446b6325d6abb8	JCB 16 digit	39.6732350153788929	-105.122189797090741
6714	2019-12-09 17:06:04	2019-12-09	Demetri Beatty	demetri.beatty@woohoo.com	Baltimore	Maryland	51694485877410237	65a202fe611440755834fec702c2b717	Mastercard	39.3215507586020934	-76.6573422545120167
6715	2019-12-09 17:43:11	2019-12-09	Miss Ida Schimmel DVM	miss.ida.schimmel.dvm@geemail.com	San Francisco	California	3096900760712812320	ddf012a811425e8279d30218e64d6159	Discover	37.7542921713888617	-122.420407066856143
6716	2019-12-09 17:52:30	2019-12-09	Ms. Octavie Batz	ms.octavie.batz@geemail.com	Columbus	Ohio	4779284504809	e7b87454db05e8f86ae6ee839a8812ac	Diners Club / Carte Blanche	39.9525433938063657	-82.9321166581708979
6717	2019-12-09 17:58:24	2019-12-09	Ardath Dietrich	ardath.dietrich@geemail.com	Reno	Nevada	869976637137143259	9cfdb687296ece41b9c13a4c6845d034	JCB 15 digit	39.4672014659348918	-119.811703154973316
6718	2019-12-09 17:58:43	2019-12-09	Jazmyn Schimmel MD	jazmyn.schimmel.md@warmmail.com	Aurora	Illinois	3088392040280858004	b03cde6efcba876bbfcd8b632638e509	VISA 16 digit	41.7477297032941124	-88.2081590292904423
6719	2019-12-09 18:36:16	2019-12-09	Hymen Gottlieb III	hymen.gottlieb.iii@warmmail.com	Anchorage	Alaska	6011019076810901834	b566cbfce0030a7b67306df53d32a2d1	JCB 16 digit	61.18253604813777	-149.338171567687027
6720	2019-12-09 19:18:59	2019-12-09	Ruthie O'Conner	ruthie.o'conner@woohoo.com	Pembroke Pines	Florida	4305366959570224	4219f0aa5fe235be5da2c49c7586a253	JCB 16 digit	26.0641989130564049	-80.4363204954095181
6721	2019-12-09 19:49:08	2019-12-09	Jerald Jaskolski	jerald.jaskolski@geemail.com	San Francisco	California	3158048581043597148	55b977e4b4935d0e3c506736f4386fff	Diners Club / Carte Blanche	37.7415634199517385	-122.437284369796146
6722	2019-12-09 21:10:19	2019-12-09	Ashli Bailey	ashli.bailey@geemail.com	Baltimore	Maryland	675992566616907	d28c19e351f9d685b66e963dba3a8273	JCB 15 digit	39.2920066407881663	-76.6334623055551276
6723	2019-12-09 22:07:22	2019-12-09	Mrs. Giana Towne	mrs.giana.towne@warmmail.com	Spokane	Washington	676155544738606	8a25f24d1be82c892c5d1121cfaaa392	Discover	47.6546998818177698	-117.382064954833311
6724	2019-12-09 22:14:43	2019-12-09	Cristen Lesch	cristen.lesch@geemail.com	Irvine	California	180035969170635143	402daa1f1349bc19eefbc2a9d704d368	American Express	33.7276851172108252	-117.697361458140605
6725	2019-12-09 22:49:05	2019-12-09	Dr. Needham Schuster II	dr.needham.schuster.ii@woohoo.com	Berkeley	California	3158433888071330364	d93e08ae315fd89b9774eb3e159910c3	Diners Club / Carte Blanche	37.9069212641046036	-122.296123696216171
6726	2019-12-09 23:41:41	2019-12-09	Leanna Sanford-Bashirian	leanna.sanford.bashirian@warmmail.com	New York	New York	3158302568810726167	a1622922afb2015da292fc2265e09f1a	Discover	40.5915323568265904	-73.9499767523620193
6727	2019-12-09 23:51:38	2019-12-09	Mr. Carmel Weissnat V	mr.carmel.weissnat.v@geemail.com	Round Rock	Texas	3733111734349190	98b808f369f3e4989d859269cf26b28d	JCB 15 digit	30.5183549254339219	-97.6305797997713114
6728	2019-12-09 23:53:32	2019-12-09	Marni Lehner	marni.lehner@warmmail.com	Tampa	Florida	675933365096669	1f6b5f60a94ec801d092d4de9e764a3f	Mastercard	27.9244896906543509	-82.3905778619207325
6729	2019-12-10 00:14:33	2019-12-10	Mr. Derrek Hand III	mr.derrek.hand.iii@warmmail.com	Hialeah	Florida	4280135897401	d3b3cb1571705df9dff5c8735cadb6c9	Voyager	25.8637618183601674	-80.3396513320408729
6730	2019-12-10 00:19:00	2019-12-10	Dr. Osborne Abshire	dr.osborne.abshire@geemail.com	Chicago	Illinois	3528576826979245083	dbad90cc59273bc8114c3d6835fcdcbc	Mastercard	41.822507786361875	-87.6930205504905445
6731	2019-12-10 00:34:35	2019-12-10	Lamonte Kling	lamonte.kling@geemail.com	Akron	Ohio	4975765799795546	ea5b0e69b69adaf1472d5dbf936138b2	VISA 16 digit	41.0778250261507907	-81.5642242733702005
6732	2019-12-10 00:44:28	2019-12-10	Shirlee Johns	shirlee.johns@geemail.com	Stamford	Connecticut	4317763688205716	f16aa41c0b65996f189716fecb8fb676	American Express	41.0062725229538998	-73.5021567867174781
6733	2019-12-10 00:46:55	2019-12-10	Lester Rau	lester.rau@geemail.com	Berkeley	California	3088690443546930139	0ddb6802862071ce542ff94029af0fc6	VISA 16 digit	37.8627956081329629	-122.293866266590371
6734	2019-12-10 00:56:58	2019-12-10	Philomene McKenzie DVM	philomene.mckenzie.dvm@geemail.com	San Francisco	California	54418010401961656	3d07bc4df3f1e51f9046a0721dc5776b	Diners Club / Carte Blanche	37.7875804937149127	-122.42854342054811
6735	2019-12-10 01:10:26	2019-12-10	Mr. Merl Rolfson	mr.merl.rolfson@warmmail.com	San Francisco	California	3096592239959608538	131f59771cc4462dceb04cbec247357c	Maestro	37.7922992530392179	-122.438032275158122
6777	2019-12-10 15:54:46	2019-12-10	Herma Donnelly	herma.donnelly@geemail.com	San Francisco	California	6011662848403811038	a010f7b9a7aca68497e0b85a5c94bcd8	Mastercard	37.7854726846669635	-122.446003051645064
6736	2019-12-10 01:23:40	2019-12-10	Miss Chris Nitzsche	miss.chris.nitzsche@geemail.com	Palmdale	California	180048120610033698	898256ec567eca724a62eba754a93ace	VISA 13 digit	34.6129233612995577	-118.181448367843032
6737	2019-12-10 02:22:17	2019-12-10	Domenick Harber	domenick.harber@geemail.com	Joliet	Illinois	4630888830225187	320ea8bbaa2acb3b85cc4b591e8da6ff	Diners Club / Carte Blanche	41.4589931998260326	-88.1363551343895466
6738	2019-12-10 02:59:00	2019-12-10	Luther McKenzie	luther.mckenzie@geemail.com	Fort Wayne	Indiana	4957028190008	92d2665722f6da423366f2f74af30589	JCB 16 digit	41.0116426175709847	-85.0684319003704985
6739	2019-12-10 03:38:24	2019-12-10	Doug Collins	doug.collins@geemail.com	Memphis	Tennessee	4368163560570113	44ef5f4a92c57aa792c5df8d891d46e7	JCB 16 digit	35.0603589619576965	-90.0736341049686047
6740	2019-12-10 03:46:01	2019-12-10	Roselyn Collins	roselyn.collins@woohoo.com	Chula Vista	California	4775340699073642	5b8a93cb6daaff8ac3df1a52bb84d53d	Maestro	32.6141186276216004	-117.000202034762864
6741	2019-12-10 03:56:01	2019-12-10	Kala Pacocha-Renner	kala.pacocha.renner@geemail.com	Phoenix	Arizona	3088806945023326731	27576950bd5b56bdfb5dd18901f057f7	Maestro	33.5573241673342935	-112.071245415315417
6742	2019-12-10 04:02:33	2019-12-10	Mrs. Vina Wehner DDS	mrs.vina.wehner.dds@woohoo.com	Milwaukee	Wisconsin	869962841870024074	a96888ef3a6e41d0edf8bb7c8d9306af	Diners Club / Carte Blanche	43.1536316409327085	-87.9318335451286259
6743	2019-12-10 04:29:55	2019-12-10	Kelby Mills	kelby.mills@geemail.com	Temecula	California	4219617481223194	df078ab9b1d198a4399072abfa52b92a	VISA 13 digit	33.5479046953510505	-117.079233350018782
6744	2019-12-10 05:12:56	2019-12-10	Mr. Linden Mills DVM	mr.linden.mills.dvm@geemail.com	San Francisco	California	676257171703432	9c41be2fdbaf21e879dbc678f833c841	JCB 15 digit	37.7407424529170896	-122.468250226698316
6745	2019-12-10 05:47:05	2019-12-10	Robin McClure	robin.mcclure@warmmail.com	San Francisco	California	3158789607407863306	f6a966ea03542301a03c07ff0546b9cf	JCB 16 digit	37.8050829368849364	-122.399364241284886
6746	2019-12-10 06:13:27	2019-12-10	Rice Dickinson	rice.dickinson@geemail.com	Shreveport	Louisiana	52772971703573327	35e9e0f7730246235d395b39033a1168	Voyager	32.5363958552718202	-93.8209975086364807
6747	2019-12-10 06:32:56	2019-12-10	Evaline Kerluke	evaline.kerluke@geemail.com	Saint Paul	Minnesota	3096933877783993788	cbf2311503030aadf35da003f21a1192	American Express	45.0232507973384131	-93.1958648499831526
6748	2019-12-10 06:52:19	2019-12-10	Carroll Lemke-Thompson	carroll.lemke.thompson@geemail.com	Mesa	Arizona	4958265349059	45857854d8e17e9f909df2740d8cb95b	Voyager	33.4987460168223805	-111.670360174670435
6749	2019-12-10 07:23:53	2019-12-10	Mora Barton	mora.barton@geemail.com	Portland	Oregon	6011368730962559298	638ce212e1ad6b492f3f9360aedd4ce4	VISA 16 digit	45.443069368962199	-122.694053190806883
6750	2019-12-10 07:26:37	2019-12-10	Ms. Gerri Murazik PhD	ms.gerri.murazik.phd@geemail.com	Oakland	California	869902446779608614	47d24b99ad36b00e551bf8f1cc4b22c7	Maestro	37.7973310736414874	-122.26586075169422
6751	2019-12-10 08:35:18	2019-12-10	Brianda Kautzer	brianda.kautzer@geemail.com	New York	New York	3096805665590989981	bdb1f0a543908d94fe767ccd042e31b3	American Express	40.6993431864064164	-73.9172770420450718
6752	2019-12-10 08:35:34	2019-12-10	Katheryn Mann	katheryn.mann@warmmail.com	Fort Wayne	Indiana	6011755492512829363	50d50fa3ebad83fb4870648740f07077	Diners Club / Carte Blanche	41.1489899410650111	-85.2065256446819745
6753	2019-12-10 08:36:08	2019-12-10	Dr. Owens Huels DDS	dr.owens.huels.dds@geemail.com	Cedar Rapids	Iowa	3012345452385203	41985d52edf75f5cf0a8200a6c1b5c9a	Mastercard	42.0362365868482755	-91.7551559733759632
6754	2019-12-10 08:39:05	2019-12-10	Hilah Rau	hilah.rau@geemail.com	San Francisco	California	6011258271914121393	7b9afe85bcf22b47a7fecdd572ad8864	VISA 16 digit	37.7736119860784072	-122.441602255809798
6755	2019-12-10 08:47:49	2019-12-10	Shiela Botsford	shiela.botsford@geemail.com	Oakland	California	3010098714839820	36d85be8d5daebcd7f9ea7e30f578a19	JCB 16 digit	37.7975792622610385	-122.271699818261368
6756	2019-12-10 09:07:25	2019-12-10	Ed Kihn	ed.kihn@warmmail.com	San Francisco	California	3337226714883553061	3bed2906b63c41529ad3a109fda6ad6f	Diners Club / Carte Blanche	37.7306381792224954	-122.430303261477974
6757	2019-12-10 09:26:51	2019-12-10	Hailie Bins	hailie.bins@geemail.com	Riverside	California	51042948365449859	0c110f66238598a80fa6398c2b67d38a	JCB 15 digit	34.0283540559414774	-117.435898420584195
6758	2019-12-10 09:37:50	2019-12-10	Miss Rosemarie Kuhic PhD	miss.rosemarie.kuhic.phd@geemail.com	Berkeley	California	6011296682605480852	a2197f0a834e5a9456fa6dce347b14ef	JCB 16 digit	37.8874161576784516	-122.292941980506569
6759	2019-12-10 09:47:50	2019-12-10	Toya Bashirian-Koepp	toya.bashirian.koepp@geemail.com	Houston	Texas	4721692307878787	7dede6e855d6c66703fe4f3602417758	American Express	29.7145402285348617	-95.3684420613121233
6760	2019-12-10 09:50:22	2019-12-10	Eddie Jenkins	eddie.jenkins@geemail.com	Sioux Falls	South Dakota	4045117056486821	a7d7fad46fc577cb380e3d0abe9ad69c	Diners Club / Carte Blanche	43.4506828452546117	-96.6378282464277021
6761	2019-12-10 10:19:50	2019-12-10	Reese Leuschke	reese.leuschke@geemail.com	Atlanta	Georgia	53546540411241090	f5881e6192422a59ef611a0579fcf809	VISA 16 digit	33.7198535791873937	-84.3674035777848275
6762	2019-12-10 10:31:50	2019-12-10	Jalon Fadel II	jalon.fadel.ii@geemail.com	Spokane	Washington	3041447302885159	129c3aef185aaded80046bb6ffb87e25	VISA 16 digit	47.6671976288087649	-117.34446309533827
6763	2019-12-10 10:35:08	2019-12-10	Pamella Harber	pamella.harber@warmmail.com	Newark	New Jersey	3456438513703871	f35d2bdf5c8559748a62cfd4284cb406	VISA 16 digit	40.6337479494892122	-74.2173885097470105
6764	2019-12-10 10:55:38	2019-12-10	Pinkie Koepp-Osinski	pinkie.koepp.osinski@warmmail.com	Jurupa Valley	California	3006799904541068	b2bfe1754b62b32e0648d823ae394231	Voyager	34.0250124926608066	-117.408136416321994
6765	2019-12-10 11:23:17	2019-12-10	Miss Amelie Waters DVM	miss.amelie.waters.dvm@geemail.com	St. Petersburg	Florida	180079493337215712	98866a4e4321e47ae10c2e8713385661	JCB 16 digit	27.7106158824060103	-82.5974336366061124
6766	2019-12-10 11:41:49	2019-12-10	Luana Swaniawski	luana.swaniawski@woohoo.com	Huntsville	Alabama	3112134405353590169	7d95722e434225ed6b6e80c66aa6ae52	VISA 13 digit	34.7800869355685975	-86.5802785598225881
6767	2019-12-10 11:53:50	2019-12-10	Lenwood Beer-Brown	lenwood.beer.brown@geemail.com	Lincoln	Nebraska	4487216589282	73f81d86b993a42651e263f1928e7a69	JCB 15 digit	40.8907618460729694	-96.74335974340066
6768	2019-12-10 12:22:02	2019-12-10	Cleda Braun	cleda.braun@geemail.com	Newport News	Virginia	52865290026903428	1385423265934f145494a7cdb8da2f42	Maestro	36.9866286420159014	-76.5864466917030597
6769	2019-12-10 13:01:44	2019-12-10	Mr. Alessandro Sporer II	mr.alessandro.sporer.ii@woohoo.com	Oakland	California	676126310476721	f82832d47d958ef112c4848cb77117dc	Diners Club / Carte Blanche	37.7888783301321851	-122.290751584253726
6770	2019-12-10 13:15:54	2019-12-10	Dr. Edw Simonis	dr.edw.simonis@geemail.com	Austin	Texas	502044573190442	5e25c248d44ad60abf732954f639494f	VISA 13 digit	30.2799286109521972	-97.8031656533718206
6771	2019-12-10 13:19:51	2019-12-10	Ms. Lucero Sanford	ms.lucero.sanford@geemail.com	Fort Worth	Texas	3027897938599851	22337030036204c9baad773628df3109	Diners Club / Carte Blanche	32.7464512656964359	-97.3335365460541055
6772	2019-12-10 13:38:04	2019-12-10	Isam D'Amore-Adams	isam.d'amore.adams@geemail.com	San Francisco	California	3725054899601155	31101cd88d7a616daaea8b58cc2de7f4	JCB 15 digit	37.7815330274651444	-122.434186713395334
6773	2019-12-10 13:44:35	2019-12-10	Alicia Treutel	alicia.treutel@geemail.com	Detroit	Michigan	4949337561769357	a228e81a9ae60849e99a39e07c6227a0	American Express	42.434884415792304	-83.0946692519940342
6774	2019-12-10 14:42:37	2019-12-10	Wyatt Luettgen	wyatt.luettgen@geemail.com	Berkeley	California	6011305739588651534	b73f3b8f424c0331eb9818ea658f1144	Mastercard	37.8721361991663343	-122.272290846730698
6775	2019-12-10 14:43:47	2019-12-10	Mr. Hayward Stracke	mr.hayward.stracke@geemail.com	San Francisco	California	4324232105896367	d207b4673baf92646744773354fc99d8	VISA 16 digit	37.7835304498084454	-122.417778216584381
6776	2019-12-10 15:08:59	2019-12-10	Ms. Danica Ebert	ms.danica.ebert@geemail.com	Roseville	California	55170051878525671	1a06c6831797243b6c62e16f644e76b1	VISA 16 digit	38.7702449841015024	-121.357347618996727
6778	2019-12-10 16:52:40	2019-12-10	Gracie Schmeler-Medhurst	gracie.schmeler.medhurst@geemail.com	Jackson	Mississippi	55479365143129442	d731e2df3f03b504fd44ff971cd3c53c	JCB 15 digit	32.25511948519312	-90.2072214765913856
6779	2019-12-10 17:00:10	2019-12-10	Miss Adaline Bashirian DDS	miss.adaline.bashirian.dds@geemail.com	Charlotte	North Carolina	6011361278564382518	95ce24178b0a6a1da2c9ad48b2de317c	JCB 16 digit	35.2871446644209286	-80.903863461682576
6780	2019-12-10 18:56:54	2019-12-10	Lorie O'Conner DDS	lorie.o'conner.dds@geemail.com	San Francisco	California	180078991046022411	efef4970542e2a148adba747ffa9951c	VISA 13 digit	37.7801285657129498	-122.43277005186512
6781	2019-12-10 19:01:00	2019-12-10	Charla Lind	charla.lind@woohoo.com	Austin	Texas	676142449172297	9b21813338cac6a1b4f874fdaae6b15d	JCB 16 digit	30.2335560394112015	-97.7336345301713862
6782	2019-12-10 19:21:15	2019-12-10	Damon Kemmer	damon.kemmer@geemail.com	Dallas	Texas	4370599076344178	bd9516964118630d80558643634acf71	JCB 16 digit	32.7762678873997189	-96.8272920285779861
6783	2019-12-10 19:36:17	2019-12-10	Dr. Bertrand Goodwin	dr.bertrand.goodwin@geemail.com	Mesa	Arizona	869914641989130237	1427f1264708302bd55675c2e62c938e	VISA 13 digit	33.3939611483510532	-111.626800091227139
6784	2019-12-10 19:49:10	2019-12-10	Sharday Osinski PhD	sharday.osinski.phd@geemail.com	San Francisco	California	51392081115597292	694d7d4784a9340af9d54548f6ef3afb	JCB 16 digit	37.8001553195112265	-122.425433921320462
6785	2019-12-10 20:00:51	2019-12-10	Marley Mante	marley.mante@warmmail.com	Tyler	Texas	676113889632975	b79d78db21ffec8a8304f0c886ee7385	American Express	32.3152063089005708	-95.328088435494891
6786	2019-12-10 21:49:23	2019-12-10	Malaki Mosciski	malaki.mosciski@geemail.com	Las Vegas	Nevada	3528618303622014761	a61d9e9bef4010826383d8d6398cd4c9	Maestro	36.2735382416851806	-115.358571163352948
6787	2019-12-10 22:14:00	2019-12-10	Wilford Crist	wilford.crist@geemail.com	Detroit	Michigan	4902815743067365	0a00fea8b006c6dd29aaa7ec470507b6	VISA 16 digit	42.4207476851921541	-83.1946206261988692
6788	2019-12-10 22:14:35	2019-12-10	Orlena Homenick	orlena.homenick@geemail.com	New York	New York	180021603130346865	81bf029d2e4a535e1ef5d8c373a3b834	JCB 15 digit	40.6859524369928991	-73.9503329274605932
6789	2019-12-10 22:21:47	2019-12-10	Mr. Foster Purdy IV	mr.foster.purdy.iv@geemail.com	San Francisco	California	6011877368174004904	78cba02ed59d2ea78f43cbd003c0f447	JCB 16 digit	37.7913321995875293	-122.439425925177815
6790	2019-12-10 22:58:59	2019-12-10	Kirby Lowe	kirby.lowe@geemail.com	Oakland	California	3337528662024362634	1268e52c617f5e75e4969a9153d56bac	JCB 16 digit	37.7963582102415785	-122.273291791342061
6791	2019-12-10 23:15:18	2019-12-10	Rosario Wunsch-Kirlin	rosario.wunsch.kirlin@geemail.com	Ontario	California	639039083365609	b091330fcb871f59703eb54d31f3a404	VISA 16 digit	34.1324213963147258	-117.677159837084645
6792	2019-12-10 23:46:39	2019-12-10	Boysie Huel	boysie.huel@warmmail.com	Houston	Texas	3742935464706990	370ce5ddabbae370269fba434ea014ea	Maestro	29.7672188827846185	-95.4341397960685214
6793	2019-12-10 23:58:32	2019-12-10	Mae Bauch	mae.bauch@geemail.com	San Francisco	California	3112540936796403089	e5a5dc4799d5fc5a5fb543fab09abc9e	JCB 15 digit	37.7680766994541983	-122.462098340068181
6794	2019-12-10 23:59:02	2019-12-10	Lupe Kutch	lupe.kutch@geemail.com	New York	New York	3528742305989076829	dce26411c5b278266a4d893fdbdb5f73	JCB 16 digit	40.5879368311017714	-73.9551260490797375
6795	2019-12-11 00:08:02	2019-12-11	Donaciano Wehner	donaciano.wehner@warmmail.com	San Antonio	Texas	503842139342598	a2ca53c0a7a6b7b0590e472ef4a02e3c	Maestro	29.4030424931157377	-98.4810323323890486
6796	2019-12-11 00:29:11	2019-12-11	Eligah Runte-Harber	eligah.runte.harber@geemail.com	San Francisco	California	6011815933460706366	d528897f768c6b4c42f11cedddab18a0	American Express	37.7451447570947209	-122.403922495067164
6797	2019-12-11 00:43:48	2019-12-11	Kendrick Koelpin	kendrick.koelpin@geemail.com	Omaha	Nebraska	4674743083581314	fd0e8def28147f034edcae50fe32f6db	Diners Club / Carte Blanche	41.352684705951809	-96.0329962147049656
6798	2019-12-11 00:54:17	2019-12-11	Mr. Melville Little	mr.melville.little@geemail.com	San Francisco	California	3337002287721663954	76452451a12a375d9dfe57415bedeb7b	VISA 16 digit	37.7901326999502345	-122.431003521125007
6799	2019-12-11 01:25:32	2019-12-11	Shanell Conroy	shanell.conroy@geemail.com	Roseville	California	4250330693602151	391a5dc29bb2daf4e7e5f7f18c7df970	JCB 16 digit	38.8638268746957181	-121.269499829386916
6800	2019-12-11 01:29:44	2019-12-11	Ebbie Davis	ebbie.davis@geemail.com	Tampa	Florida	3410450172408721	1ca4e105d0ce9f8e404c1de6ae340e32	Voyager	27.97878556764908	-82.5240502700887504
6801	2019-12-11 01:40:08	2019-12-11	Finnegan Bernier-Crona	finnegan.bernier.crona@warmmail.com	Indianapolis	Indiana	3037102898552127	b4aedd11abbf4aec70e94ad5d3357ca5	Mastercard	39.8083619749180926	-86.0869461273975674
6802	2019-12-11 02:30:20	2019-12-11	Debby Dietrich	debby.dietrich@geemail.com	Portland	Oregon	4857700685365818	0f4d6ce27864728de5b5798721c866f6	VISA 16 digit	45.6162764844838549	-122.629931642860186
6803	2019-12-11 02:31:33	2019-12-11	Ms. Jamie Hintz PhD	ms.jamie.hintz.phd@geemail.com	Torrance	California	869939799196682266	bdbdc69f40ba5ad938e4b193eb891d1e	Diners Club / Carte Blanche	33.8986605925392368	-118.402986079234253
6804	2019-12-11 02:58:25	2019-12-11	Eddie Swaniawski	eddie.swaniawski@geemail.com	Las Vegas	Nevada	210084037601249056	31d01eb563076a2466912befc815b9f1	VISA 16 digit	36.1471024858865846	-115.240244616728646
6805	2019-12-11 02:59:32	2019-12-11	Mrs. Lilie Daniel	mrs.lilie.daniel@geemail.com	Ann Arbor	Michigan	4510080170242	bdb42bca0d9253a7fceff192554f340c	Diners Club / Carte Blanche	42.3508783020604369	-83.7690200550124047
6806	2019-12-11 03:30:55	2019-12-11	Mrs. Meghann Kemmer	mrs.meghann.kemmer@warmmail.com	Arlington	Texas	869942069881318468	d1bcc21b423a1e29a2e7f3e1c82ed17a	Maestro	32.6495185961265122	-97.0942790879894062
6807	2019-12-11 03:46:38	2019-12-11	Scotty Schroeder	scotty.schroeder@geemail.com	Berkeley	California	180069883910350690	100a18564c0dae8b9a97b367841114b1	American Express	37.8506259553659987	-122.286346583385793
6808	2019-12-11 03:52:03	2019-12-11	Terri Lindgren-Bergstrom	terri.lindgren.bergstrom@geemail.com	Norfolk	Virginia	3448595580425935	236bdf47d17a9418ee699c5f624b76f7	Maestro	36.9729107816722262	-76.2974737184591589
6809	2019-12-11 03:56:23	2019-12-11	Osie Collier	osie.collier@geemail.com	Minneapolis	Minnesota	180093483020093643	72bb135b37d0168aaed702876772efe0	VISA 16 digit	44.9725296581249623	-93.2760716478612295
6810	2019-12-11 04:11:52	2019-12-11	Cathern Bayer	cathern.bayer@geemail.com	Oakland	California	4202914664701750	f7623d77dec4d3a69aea9e5092a01fef	JCB 15 digit	37.7518220940117502	-122.306792263121821
6811	2019-12-11 04:29:49	2019-12-11	Charlotte Kutch	charlotte.kutch@geemail.com	San Diego	California	869938215283978914	5a4a73db188a49f7e7e8a6d56f8cd2d8	JCB 16 digit	32.7725403406724354	-117.059429675703868
6812	2019-12-11 04:29:58	2019-12-11	Malaki Hartmann	malaki.hartmann@geemail.com	Anchorage	Alaska	3449719231189588	3c35db8a692d023be0c1caf75142a065	VISA 16 digit	61.091331418206174	-149.336467397039002
6813	2019-12-11 04:41:17	2019-12-11	Miss Marcie Wiegand DVM	miss.marcie.wiegand.dvm@geemail.com	Hartford	Connecticut	3112117403590531527	abcbb7b106bb16553e20838646d0b326	Mastercard	41.6702357535265406	-72.7355055585395576
6814	2019-12-11 04:52:03	2019-12-11	Dr. Margretta Abernathy	dr.margretta.abernathy@woohoo.com	New York	New York	3014544108178024	ca563d809ca83cf61d268c872f5596a9	Discover	40.7415235352460314	-74.0016002473782777
6815	2019-12-11 06:33:23	2019-12-11	Sylvania Bartoletti	sylvania.bartoletti@woohoo.com	Chicago	Illinois	4668052726636826	ba88f8f1e63ace8540c241f973ec40f9	American Express	41.7380696100018937	-87.7398940888263184
6816	2019-12-11 07:04:44	2019-12-11	Evan Huel	evan.huel@geemail.com	Fort Worth	Texas	3056784687503162	e503c392c0347c9af08ff27233d3bbde	VISA 16 digit	32.7936584383770864	-97.3890985085450041
6817	2019-12-11 07:04:58	2019-12-11	Dr. Champ Bailey I	dr.champ.bailey.i@geemail.com	Oakland	California	6011675949510027982	ee7689abdabcc4a110fc47d9b35322f3	American Express	37.7760704097158637	-122.292795734327711
6818	2019-12-11 07:30:09	2019-12-11	Nathanial Larkin	nathanial.larkin@geemail.com	San Diego	California	561249312252072	765c092d056691e71723a97b64e46dc4	Discover	32.9070606155388035	-117.06614576907829
6819	2019-12-11 07:44:15	2019-12-11	Sharron Lind	sharron.lind@geemail.com	Fort Lauderdale	Florida	3401145724419306	0abef7fb5ca18a658a9f6de8c911395a	VISA 16 digit	26.1497222595836973	-80.2246287566430851
6820	2019-12-11 07:52:51	2019-12-11	Nunzio Raynor	nunzio.raynor@woohoo.com	West Valley City	Utah	6011661914504353097	22594104a4e4c2055ef60dde68a34d8e	Diners Club / Carte Blanche	40.7122974589690543	-111.925947284394127
6821	2019-12-11 08:00:55	2019-12-11	Claudette Bradtke	claudette.bradtke@geemail.com	Carrollton	Texas	3038689914093887	edb2443e86546ee0141eb8ee6540f0d9	VISA 16 digit	33.0263115391522604	-96.9682203580487538
6822	2019-12-11 08:41:35	2019-12-11	Torrance Simonis-Mayert	torrance.simonis.mayert@geemail.com	New York	New York	4599106700975800	2c93e428f7c0bc8adfb9745f5dfc9b9d	Maestro	40.6494737270511663	-73.9405374390900079
6823	2019-12-11 09:07:20	2019-12-11	Dr. Leala Bernier	dr.leala.bernier@woohoo.com	Orlando	Florida	3038995309694209	4990ed63408980ca023bccb847e8fdc5	Maestro	28.38046181274429	-81.2166583864916163
6824	2019-12-11 09:40:27	2019-12-11	Lizette Bednar	lizette.bednar@warmmail.com	San Mateo	California	869944561160277447	095715998c0fda55e114384d353098cf	VISA 16 digit	37.6151865109682078	-122.342279872190574
6825	2019-12-11 10:11:50	2019-12-11	Ica Lehner	ica.lehner@geemail.com	Berkeley	California	3088247530664587457	52065ccbd6e6f16afed0e2b10bc59627	VISA 13 digit	37.8698573982628091	-122.243632622100932
6826	2019-12-11 11:02:59	2019-12-11	Berneice King	berneice.king@geemail.com	Fullerton	California	6011381872363856775	7434e6a461cdef614d9765a7ab905261	JCB 16 digit	33.8630573295678943	-117.834630305573342
6827	2019-12-11 11:27:43	2019-12-11	Mariano Schoen MD	mariano.schoen.md@geemail.com	Philadelphia	Pennsylvania	6011808934755642174	5d362d6f8f1a1c5f529577f5bff066a0	Diners Club / Carte Blanche	39.9811369521502371	-75.0602212448038273
6828	2019-12-11 11:41:55	2019-12-11	Coolidge Kautzer DVM	coolidge.kautzer.dvm@geemail.com	Sacramento	California	3158463965705034258	763d7b1a2a53e043e31856dbd5040257	JCB 16 digit	38.4817521300431338	-121.458265322750805
6829	2019-12-11 11:45:20	2019-12-11	Tayshaun Swaniawski	tayshaun.swaniawski@woohoo.com	San Francisco	California	210098732463329608	1c5884d35e103586f70c26e4e2851db0	VISA 16 digit	37.7743023897057242	-122.446460879279627
6830	2019-12-11 11:55:32	2019-12-11	Graham Littel	graham.littel@warmmail.com	Louisville	Kentucky	6011314883733718902	9c037acbf2c793772e541f410c81747a	JCB 15 digit	38.2619929492842417	-85.7091575212847516
6831	2019-12-11 11:57:49	2019-12-11	Verne Kuphal	verne.kuphal@geemail.com	Newport News	Virginia	4267722016053453	11e24c3929f96b5f8f51227c49ee5538	Voyager	37.1418076028943034	-76.4462579962592628
6832	2019-12-11 12:14:06	2019-12-11	Sharen Bosco	sharen.bosco@warmmail.com	Detroit	Michigan	180056752322613778	d4582e0b8578357d7e1c95f2d27cdf62	Mastercard	42.4544683813042951	-83.002385702601444
6833	2019-12-11 12:16:53	2019-12-11	Alina Rath-Jakubowski	alina.rath.jakubowski@geemail.com	San Francisco	California	3769136534653472	417a7ec88808e0452aa6f04cbe485379	VISA 16 digit	37.7471576950825565	-122.407531224972232
6834	2019-12-11 12:58:53	2019-12-11	Jayda Aufderhar	jayda.aufderhar@geemail.com	New York	New York	180009409533168666	d8345eacc02e6d9ba265a4b37e061c0f	American Express	40.6534095659144228	-73.8817667902342947
6835	2019-12-11 13:28:07	2019-12-11	Dr. Izetta Terry DVM	dr.izetta.terry.dvm@warmmail.com	Anchorage	Alaska	3006424115885671	d35225ce276b07792d6bf4df9952e436	American Express	61.1037512917753318	-149.257129464962702
6836	2019-12-11 13:38:25	2019-12-11	Abby Fay	abby.fay@geemail.com	Alexandria	Virginia	3052845030275735	7f71400c1177d444b372f1fe328380a8	Maestro	38.853808020858466	-77.0586722995605413
6837	2019-12-11 13:43:49	2019-12-11	Minda Rosenbaum MD	minda.rosenbaum.md@warmmail.com	San Francisco	California	4508100312679827	7bf73998a9704977dbe5111d36c782ad	VISA 16 digit	37.7497251299954684	-122.405282671660146
6838	2019-12-11 14:00:21	2019-12-11	Lillianna Heller	lillianna.heller@geemail.com	Centennial	Colorado	869975236322945908	12bdd74c6a75284dc095a8fb448bce89	Maestro	39.6290175212122548	-104.967481249327221
6839	2019-12-11 14:05:07	2019-12-11	Georganna Blanda-Rolfson	georganna.blanda.rolfson@woohoo.com	Phoenix	Arizona	210093522904169621	6f410cd747e9274b48b1a46ffb27e19a	American Express	33.577801767031481	-112.185191019617406
6840	2019-12-11 14:19:24	2019-12-11	Judd Walsh	judd.walsh@geemail.com	San Antonio	Texas	3096537918468510396	70bd8fb3faa1d44f78cb8e38dab23b16	JCB 16 digit	29.5030043892633174	-98.5829347144182719
6841	2019-12-11 14:54:21	2019-12-11	Alden Goldner Sr.	alden.goldner.sr.@geemail.com	Oakland	California	3041171698660006	0ec20a2436c389ca89acc56360f3a050	Diners Club / Carte Blanche	37.8049906688773447	-122.242232984650656
6842	2019-12-11 15:17:11	2019-12-11	Christion Oberbrunner	christion.oberbrunner@geemail.com	San Francisco	California	4356188942919492	ac950f43133108a2e25b19868963e3b6	JCB 16 digit	37.7921816604897103	-122.41452508254649
6843	2019-12-11 17:08:21	2019-12-11	Rosey Grimes	rosey.grimes@geemail.com	San Francisco	California	869978503635739741	bf638cc43b2e657d4deaf289c8f6d2e2	Maestro	37.7688599683487567	-122.432284417968944
6844	2019-12-11 17:09:53	2019-12-11	Mrs. Ruth Effertz DDS	mrs.ruth.effertz.dds@geemail.com	Berkeley	California	3053653318132399	7160db3cc353efc5c68ec4a1f34828db	Voyager	37.92315328667096	-122.286471006711082
6845	2019-12-11 17:48:15	2019-12-11	Dr. Hellen Gutmann DDS	dr.hellen.gutmann.dds@warmmail.com	Oakland	California	3015808860437210	ce0f3c9c2adcf9a80dddfbf0983924dd	Discover	37.7782899400140622	-122.274494601938812
6846	2019-12-11 18:44:11	2019-12-11	Treva Glover	treva.glover@geemail.com	New York	New York	4596974102888	31a461e44ea7d00567a83f70ec08da61	Diners Club / Carte Blanche	40.6010281009823046	-73.9241238855652512
6847	2019-12-11 19:22:15	2019-12-11	Pearlene Mills-Kassulke	pearlene.mills.kassulke@geemail.com	Murfreesboro	Tennessee	3763472166983358	74472db54f57870ad823bfc763580451	Diners Club / Carte Blanche	35.75870872043334	-86.3429718937110096
6848	2019-12-11 19:25:34	2019-12-11	Zelda Hahn	zelda.hahn@warmmail.com	San Francisco	California	4637620165943	4bbaa76ac02b8b6eb128c9cf9c638de2	VISA 16 digit	37.7808074429854628	-122.451987676315724
6849	2019-12-11 19:49:11	2019-12-11	Margery Waelchi	margery.waelchi@woohoo.com	Vancouver	Washington	3487423210752549	4a775e6da136c62ed4003d8931f18017	Voyager	45.689318324865404	-122.567756510159739
6850	2019-12-11 19:51:19	2019-12-11	Mr. Constantine Hoppe I	mr.constantine.hoppe.i@geemail.com	Plano	Texas	4186968809563	30a929de336417c3a3f0d6b38c4d9fe1	Mastercard	32.9990748768758024	-96.6507445232659563
6851	2019-12-11 19:57:47	2019-12-11	Ancil Murray	ancil.murray@geemail.com	Berkeley	California	4644784928249	c28ea6b13e259115f2c3d2f05521ca07	Diners Club / Carte Blanche	37.8740368505122973	-122.260241329403485
6852	2019-12-11 20:00:33	2019-12-11	Mrs. Bettylou Balistreri	mrs.bettylou.balistreri@woohoo.com	Grand Rapids	Michigan	4339838155448421	f4dec7eafbf816a1c0b9e1596e0553fe	Discover	42.8638247917674491	-85.7384766408842154
6853	2019-12-11 20:42:59	2019-12-11	Elenore Prosacco	elenore.prosacco@geemail.com	New York	New York	6011072987040542814	afa30da7ede233329fbe7c0bff3dd9d2	JCB 15 digit	40.6189813043214372	-73.9076600683282976
6854	2019-12-11 21:11:31	2019-12-11	Brent Toy	brent.toy@geemail.com	Mobile	Alabama	589339453056861	8e7a0d35640e42c4a2ec9a2d79e7a0c1	JCB 16 digit	30.6957389917798338	-88.0982681702028998
6855	2019-12-11 21:42:06	2019-12-11	Leona Sipes	leona.sipes@geemail.com	San Francisco	California	4591868008804	151756f2f0cc48999b714abe38940ce2	JCB 16 digit	37.7670332244803788	-122.435857736313494
6856	2019-12-11 22:15:51	2019-12-11	Pamala Dooley	pamala.dooley@geemail.com	New York	New York	53292444113606807	e861f3fb82e724178af86309d378aac8	JCB 15 digit	40.5668836275339117	-73.9286270579218865
6857	2019-12-11 22:35:05	2019-12-11	Dr. Alease Dickinson	dr.alease.dickinson@woohoo.com	Glendale	California	4154508399404	79f631bd34576961d69edb646b10a3e2	Mastercard	34.1511917644865761	-118.29533918987886
6858	2019-12-11 22:40:02	2019-12-11	Jovany Eichmann	jovany.eichmann@geemail.com	San Francisco	California	52769064947999857	2b93bb3a96f865a9521274aa9c88d408	JCB 16 digit	37.7573485788827341	-122.45308205246333
6899	2019-12-12 13:51:30	2019-12-12	Kennedy Feest	kennedy.feest@warmmail.com	San Francisco	California	3476491485866628	dbe17c2ebce0dad4f44c47d880bdac73	Mastercard	37.7586323310315635	-122.444416537797792
6859	2019-12-11 23:04:48	2019-12-11	Janiya Kilback	janiya.kilback@geemail.com	San Francisco	California	54410195324542366	250debe82f4b0453741712e4c17254f9	Diners Club / Carte Blanche	37.7838452170570847	-122.427234444106233
6860	2019-12-11 23:23:08	2019-12-11	Augustin Prosacco	augustin.prosacco@woohoo.com	San Francisco	California	503845659361773	85cf2c151f82a259eb7ecfec7beab329	Diners Club / Carte Blanche	37.7912979316954889	-122.436359565377728
6861	2019-12-11 23:33:49	2019-12-11	Joline Abernathy	joline.abernathy@geemail.com	San Antonio	Texas	501835883774909	40f9b09fc1c426e8556adaf2de3d8105	Diners Club / Carte Blanche	29.4594174076873827	-98.5952172245666389
6862	2019-12-12 00:41:03	2019-12-12	Kirby Schimmel	kirby.schimmel@geemail.com	San Francisco	California	3004664060069589	65c06e30fe2bfea996e8af425befffce	American Express	37.781623778148905	-122.481242978480822
6863	2019-12-12 00:57:15	2019-12-12	Walton Hickle	walton.hickle@geemail.com	San Francisco	California	3752560488876509	ecf388470ce2552ed29ae1720c0791cf	Diners Club / Carte Blanche	37.7834126060009012	-122.44675037594557
6864	2019-12-12 01:17:17	2019-12-12	Lavelle Johnston	lavelle.johnston@geemail.com	New York	New York	3528508153861576308	e8a4deb3ca5be71d9073bcbe88a03eda	Diners Club / Carte Blanche	40.563996191577985	-73.8691889145307243
6865	2019-12-12 02:46:40	2019-12-12	Meryl Cassin PhD	meryl.cassin.phd@geemail.com	San Francisco	California	4416330690080	b1a0157587e5c771edd7e9bcc273a7b9	VISA 16 digit	37.7805100568871453	-122.400012228786082
6866	2019-12-12 02:48:24	2019-12-12	Tre Shields	tre.shields@geemail.com	Costa Mesa	California	4428869147812	c42e6cde869acef6364416598f02d444	American Express	33.6688058966785704	-117.86887608420588
6867	2019-12-12 03:17:14	2019-12-12	Kimberli Purdy	kimberli.purdy@geemail.com	Oakland	California	53017317463224138	3587922a8ae732103d65893b714bf006	Diners Club / Carte Blanche	37.7947564148596271	-122.278438920351803
6868	2019-12-12 03:27:25	2019-12-12	Hazel Kreiger	hazel.kreiger@warmmail.com	Kenosha	Wisconsin	4206635264131	69cf4c50746aaef06a3e62eca03d5733	VISA 16 digit	42.6335129155617238	-87.8205431303702397
6869	2019-12-12 03:46:04	2019-12-12	Cari Ziemann DVM	cari.ziemann.dvm@geemail.com	Berkeley	California	3021850299730413	fda74836c3c1d07cfeca4f11cf38498b	JCB 15 digit	37.8746033384764047	-122.294691541257606
6870	2019-12-12 04:08:35	2019-12-12	Mrs. Carlotta Reynolds MD	mrs.carlotta.reynolds.md@woohoo.com	New York	New York	3112501686742655418	8b4d5b0a401be40e55a875ba68187a2d	Discover	40.7256453620027727	-73.8389048542257314
6871	2019-12-12 04:17:07	2019-12-12	Miss Ayana Grant PhD	miss.ayana.grant.phd@geemail.com	Charlotte	North Carolina	54957041806753205	692c24ffc76bf83f4bb9d0e5d371971f	Mastercard	35.247098944966865	-80.8544345649369092
6872	2019-12-12 04:57:14	2019-12-12	Ewell Roberts	ewell.roberts@geemail.com	Oxnard	California	6011412656267072701	860add6268ceefb1efd90f50db64c6c1	VISA 13 digit	34.2877410917032535	-119.154695221120861
6873	2019-12-12 05:31:07	2019-12-12	Junious Ruecker	junious.ruecker@geemail.com	Los Angeles	California	6011971291182251611	bb3161b9af5d6877b6f4418601898111	Discover	34.0311645375430558	-118.396036793383956
6874	2019-12-12 06:07:31	2019-12-12	Mrs. Chyna Wolf PhD	mrs.chyna.wolf.phd@woohoo.com	Charlotte	North Carolina	4822239773258785	89e81a22dda05fe1674c17e7cfeaa068	Diners Club / Carte Blanche	35.2337890954475839	-80.7671344217788487
6875	2019-12-12 07:02:40	2019-12-12	Miss Chaya Price	miss.chaya.price@geemail.com	Chula Vista	California	3337053716998423096	08dc1c144bc5373cd3df45d9833cfd9b	JCB 16 digit	32.6719120741587119	-117.034668925707038
6876	2019-12-12 07:22:27	2019-12-12	Dr. Cruz Streich Jr.	dr.cruz.streich.jr.@geemail.com	Dallas	Texas	3337723341743198248	5b84d12e1e8d4cff6f20168ab0c04444	VISA 16 digit	32.8688418606568149	-96.8495974891781799
6877	2019-12-12 07:27:10	2019-12-12	Davin Tremblay	davin.tremblay@geemail.com	Portland	Oregon	54133579688334369	601790e016c3deabda395f5adf8b0d92	American Express	45.5931345932539571	-122.555871022818621
6878	2019-12-12 08:22:24	2019-12-12	Chip Lehner	chip.lehner@geemail.com	Phoenix	Arizona	3096629733866643338	5145738aefa2b834d932f01c38b9eeaa	VISA 16 digit	33.577609731063994	-112.089946773268665
6879	2019-12-12 08:32:41	2019-12-12	Caleigh Stracke	caleigh.stracke@geemail.com	McKinney	Texas	3337349609836444396	59f7c61b2b984a303bc3f3490137dbb3	Discover	33.1051662590019404	-96.7417504161428781
6880	2019-12-12 08:44:21	2019-12-12	Nolan Denesik	nolan.denesik@geemail.com	Sandy Springs	Georgia	4666991490416	564996283c22f7d0efa2c668045ca04d	JCB 15 digit	33.9794019938968148	-84.3944548885420005
6881	2019-12-12 09:02:28	2019-12-12	Lugenia Harris	lugenia.harris@geemail.com	Charlotte	North Carolina	52990624039532980	9435c11476d6e917b764ef770df3dd5e	Discover	35.2142405103214102	-80.8890567608121813
6882	2019-12-12 09:22:58	2019-12-12	Dr. Lucetta Stokes DDS	dr.lucetta.stokes.dds@geemail.com	Santa Rosa	California	4028320527220	fea3b25dadbb9cf06685f87e46871e3b	Maestro	38.4905010363675686	-122.804244201841215
6883	2019-12-12 09:26:23	2019-12-12	Socorro Wuckert	socorro.wuckert@geemail.com	Manchester	New Hampshire	869957854809882782	eb203b8bffbf25ec593a4bc5d803e246	Discover	42.898182669428742	-71.4422047022622166
6884	2019-12-12 09:44:06	2019-12-12	Cato Connelly IV	cato.connelly.iv@warmmail.com	San Angelo	Texas	4114343128228	09e02d1d0c2585468cdc530feaaa48ef	JCB 15 digit	31.5161367496628309	-100.479869244491681
6885	2019-12-12 09:46:02	2019-12-12	Mr. Kiyoshi Steuber	mr.kiyoshi.steuber@geemail.com	San Francisco	California	4561881566907840	5a7dff9461cad521494860345d3c258d	JCB 16 digit	37.778918102253165	-122.446503516478714
6886	2019-12-12 09:53:16	2019-12-12	Lacie Russel-Denesik	lacie.russel.denesik@geemail.com	Fort Worth	Texas	52206107091713615	120ba2dc9f6adb86ba323ccf9192f6a6	Voyager	32.82243022267334	-97.2584169348523062
6887	2019-12-12 10:41:18	2019-12-12	Emerson Mayer	emerson.mayer@warmmail.com	San Francisco	California	6011884473691005037	d852fa731a6c1cd065470d445df3a56b	VISA 13 digit	37.7744015251041603	-122.425771547587729
6888	2019-12-12 10:42:56	2019-12-12	Lauryn Roob-Bins	lauryn.roob.bins@geemail.com	San Jose	California	869914926288903503	2e65992e35c484d39fa8ffa22ac9f17a	VISA 13 digit	37.3070077144827721	-121.727005986751621
6889	2019-12-12 11:04:36	2019-12-12	Dr. Kermit Hand	dr.kermit.hand@geemail.com	Phoenix	Arizona	3112159486663976678	5c48cd2fc7dc324d845c92dfbebb7062	VISA 13 digit	33.5524619829308293	-112.034412713528056
6890	2019-12-12 11:05:45	2019-12-12	Gennie Ruecker	gennie.ruecker@warmmail.com	Plano	Texas	3025053112628205	ff3efa7797ccd1aec37f81a7a5b6d00d	Maestro	32.964087407206371	-96.8296373893689406
6891	2019-12-12 11:07:02	2019-12-12	Dayton Weber	dayton.weber@geemail.com	Wichita	Kansas	4428995071331354	6499135c33f95cbd5586c8f831695112	VISA 13 digit	37.6206697826150815	-97.3176531174421342
6892	2019-12-12 11:14:29	2019-12-12	Sol Powlowski-Johnston	sol.powlowski.johnston@warmmail.com	Portland	Oregon	869951167900540118	23c86654003b5e6819b6d8555696399c	Voyager	45.5146317790150619	-122.592166524566721
6893	2019-12-12 12:11:31	2019-12-12	Mr. Jerod Gleichner	mr.jerod.gleichner@warmmail.com	Norman	Oklahoma	3404077864839653	2c70682a6f66befa37d64dff51b5f7ea	JCB 15 digit	35.3327510589774718	-97.4203686249230003
6894	2019-12-12 12:22:24	2019-12-12	Audley D'Amore	audley.d'amore@woohoo.com	Aurora	Colorado	561213220525235	18573cca730a85c98515a8715b3da7e6	Diners Club / Carte Blanche	39.6296489546187232	-104.66874500551522
6895	2019-12-12 13:01:26	2019-12-12	Lavar Kassulke	lavar.kassulke@warmmail.com	Escondido	California	210045169072175771	e349817044775348b493f341ab02bb0a	Voyager	33.1791576065815974	-116.994380632486198
6896	2019-12-12 13:21:09	2019-12-12	Affie Murphy	affie.murphy@woohoo.com	San Francisco	California	54274423193144931	7b15ea3850a9489f22b1c8471636ff63	JCB 16 digit	37.7479229715330789	-122.436952905504882
6897	2019-12-12 13:29:06	2019-12-12	Iva Dibbert	iva.dibbert@geemail.com	New York	New York	4310176551892568	e360ec745efe48ae49b8b145658a3e6d	JCB 16 digit	40.6382725455090394	-73.9667267140362412
6898	2019-12-12 13:40:59	2019-12-12	Isiah Langosh DDS	isiah.langosh.dds@geemail.com	San Antonio	Texas	3337758427419550412	b8d8edb9ae4f8c729c80521718f32384	Diners Club / Carte Blanche	29.5497665383923795	-98.5506329437088198
6900	2019-12-12 13:53:43	2019-12-12	Jaylee Roob	jaylee.roob@geemail.com	Chicago	Illinois	3006426069360452	ab5704b37273ba7a35a7b2c1685412e2	JCB 16 digit	41.8850284464493399	-87.7584046855598672
6901	2019-12-12 14:00:46	2019-12-12	Dante Bayer	dante.bayer@geemail.com	Berkeley	California	4986042436394	76fd3a6de6df4b61ea231dd2e6a846a7	Maestro	37.8630953670729369	-122.236313916581935
6902	2019-12-12 14:19:29	2019-12-12	Amado Corkery	amado.corkery@woohoo.com	Baltimore	Maryland	4960548931157958	b6bdc7e7e84dc75c059df8ea9a946995	Diners Club / Carte Blanche	39.3407080993056297	-76.5408153107874085
6903	2019-12-12 14:25:46	2019-12-12	Rosco Nikolaus MD	rosco.nikolaus.md@geemail.com	Riverside	California	6011204374713452301	11c5e3257649442f81fe7f539ef3e140	Discover	33.9892160451918812	-117.344253631724783
6904	2019-12-12 14:58:32	2019-12-12	Lue McClure	lue.mcclure@woohoo.com	Berkeley	California	3337863904172788712	6203033afcaa6984d498e7d0e347119f	JCB 15 digit	37.8349930853389367	-122.255861366063229
6905	2019-12-12 15:20:42	2019-12-12	Alisa Kuphal	alisa.kuphal@geemail.com	Wichita	Kansas	502006936613675	6b0c4f8dc5c01fa5dcd2561009859cd3	JCB 16 digit	37.7565670419361439	-97.2520137417797059
6906	2019-12-12 15:29:04	2019-12-12	Joseline Schuppe	joseline.schuppe@geemail.com	San Francisco	California	3000275581468293	1e6a7facf35c46f7693460e4d5ba5d70	JCB 15 digit	37.7879262280922035	-122.46133484590159
6907	2019-12-12 17:18:14	2019-12-12	Lilian Reichert	lilian.reichert@geemail.com	Peoria	Illinois	3053043388581230	1ed8141ff68f86cc0c616927b998030c	JCB 15 digit	40.7343148914501043	-89.6170486241929325
6908	2019-12-12 17:22:02	2019-12-12	Mrs. Hildur Reinger DVM	mrs.hildur.reinger.dvm@geemail.com	San Francisco	California	4095422960716	67dc69a4a439725d62b1bafe5fa4afc3	Mastercard	37.8066852084303733	-122.442221240844475
6909	2019-12-12 17:43:48	2019-12-12	Montie Cormier	montie.cormier@geemail.com	Irvine	California	3096155295504387001	3df8f12dffc677bea679559190055e40	JCB 15 digit	33.5906353288810706	-117.869592149184271
6910	2019-12-12 18:12:21	2019-12-12	Cris Barton	cris.barton@geemail.com	San Francisco	California	55011406998852905	f29e091dd5129bb62cbc52c569644aeb	Mastercard	37.7208579120070979	-122.458024740316901
6911	2019-12-12 18:23:17	2019-12-12	Miss Julisa Borer DVM	miss.julisa.borer.dvm@geemail.com	Louisville	Kentucky	869920902951894594	0dcc70c382235df75bebfac0e3e4bd61	American Express	38.2556403231244531	-85.5528920880123991
6912	2019-12-12 18:46:44	2019-12-12	Abelardo Stoltenberg	abelardo.stoltenberg@warmmail.com	San Jose	California	3088566591379458445	b04d09a12f11e4364841a198b2862f65	American Express	37.2240176501970765	-121.872550786960502
6913	2019-12-12 18:48:39	2019-12-12	Miss Melina Ullrich PhD	miss.melina.ullrich.phd@warmmail.com	Raleigh	North Carolina	6011268123248264324	28a1b545c90f9fc75ec5cfeb1e76d76c	American Express	35.7999299971520841	-78.6155657000310697
6914	2019-12-12 19:26:24	2019-12-12	Mr. Darryll Pacocha MD	mr.darryll.pacocha.md@warmmail.com	St. Louis	Missouri	3112232068004951775	41c6bd811518b94e5b845398b3827a81	VISA 16 digit	38.679202710526809	-90.2910922020677589
6915	2019-12-12 19:51:10	2019-12-12	Carma Olson DVM	carma.olson.dvm@geemail.com	San Jose	California	3088947214728902183	77890f7ed00f3c6ef2020d8f1e4bad54	JCB 16 digit	37.3555267306331586	-121.789449011370166
6916	2019-12-12 20:15:40	2019-12-12	Brain Gulgowski	brain.gulgowski@geemail.com	Oakland	California	639084184520728	605d0c1e128c3361a935f41102d94775	Diners Club / Carte Blanche	37.7909025960963021	-122.261874187378169
6917	2019-12-12 20:45:55	2019-12-12	Lorna Gerhold DVM	lorna.gerhold.dvm@geemail.com	San Francisco	California	4867163084215	36873877e62e3312cdc0e52ea2e2ec88	Discover	37.7975498907305791	-122.434643523687996
6918	2019-12-12 20:49:55	2019-12-12	Dr. Arlington Larson	dr.arlington.larson@geemail.com	Torrance	California	4641376888765	87c2f1d0a285d518a22e085cc4205367	Voyager	33.8677448190655568	-118.247127545544501
6919	2019-12-12 20:51:01	2019-12-12	Amelia Stark-Stroman	amelia.stark.stroman@warmmail.com	Fremont	California	54053675965686194	6c0c90f3fc7db851cd89467e37991c48	VISA 16 digit	37.4814758075568832	-121.987833321745313
6920	2019-12-12 21:51:10	2019-12-12	Britni Ondricka	britni.ondricka@woohoo.com	New York	New York	3528500002757889713	b07c3e1835542653129369f6d28349c2	Diners Club / Carte Blanche	40.7193099952992057	-73.9774758270371677
6921	2019-12-12 21:56:57	2019-12-12	Landin Buckridge	landin.buckridge@geemail.com	New York	New York	675946229251874	2b44b1a93a1669bff24c74b0b1873f65	JCB 16 digit	40.723246441198512	-73.9618258591636959
6922	2019-12-12 22:02:47	2019-12-12	Ms. Danica Breitenberg DVM	ms.danica.breitenberg.dvm@warmmail.com	Los Angeles	California	54638216930261344	9eb64d89051450a78082e1cbdf2a7177	Diners Club / Carte Blanche	34.0913657238107177	-118.31418676096871
6923	2019-12-12 22:30:00	2019-12-12	Kadyn Hilpert	kadyn.hilpert@geemail.com	Los Angeles	California	4769949279979750	1d8526884d84b6b2f69e2e6c08f52490	VISA 16 digit	33.967690904052553	-118.440515046798808
6924	2019-12-12 22:35:24	2019-12-12	Miss Tamia Collier	miss.tamia.collier@warmmail.com	San Francisco	California	4582560093475	c751b381c89d68c126206b7c9f026ec3	JCB 16 digit	37.7964812328620425	-122.420213604053217
6925	2019-12-12 22:48:53	2019-12-12	Johnnie Wuckert	johnnie.wuckert@geemail.com	Houston	Texas	3528737513828081309	6499559322baf319aa45cc83f6800539	VISA 13 digit	29.6986199294760809	-95.4608821450281937
6926	2019-12-12 22:52:14	2019-12-12	Mr. Jaxton Wilkinson MD	mr.jaxton.wilkinson.md@geemail.com	San Francisco	California	180055383939042069	5a052760ef9140af8a7ed0a86fa8cfbb	JCB 15 digit	37.7787151490559623	-122.432017538779689
6927	2019-12-12 22:53:45	2019-12-12	Dr. Stephanie Vandervort DDS	dr.stephanie.vandervort.dds@warmmail.com	San Francisco	California	4073541460802957	e20a00c57ab24a01f6d589f4d0746d64	JCB 15 digit	37.7820875900408453	-122.415402315950359
6928	2019-12-12 23:41:56	2019-12-12	Corey Hammes DVM	corey.hammes.dvm@geemail.com	Plano	Texas	53891035179784770	d749184e374133abb10b84db5d410db3	Voyager	33.0326749341182406	-96.7927045214172495
6929	2019-12-12 23:59:29	2019-12-12	Efrain Kub	efrain.kub@geemail.com	Berkeley	California	6011608557746498257	7b05d1b2e0e5136ced9980156ad8b6ef	Diners Club / Carte Blanche	37.8619394796950814	-122.2639765022398
6930	2019-12-13 00:06:51	2019-12-13	Woody Keebler	woody.keebler@woohoo.com	San Diego	California	4067787052355	ed29aaf15d4f77fb255774da8fa9863f	Diners Club / Carte Blanche	32.7479260204892597	-117.073774630427366
6931	2019-12-13 01:00:14	2019-12-13	Nat Davis	nat.davis@geemail.com	San Francisco	California	51705212469401086	6019ae13be27af08c7f02a6bcfab30a3	VISA 13 digit	37.7965609943390461	-122.475944291675276
6932	2019-12-13 02:14:32	2019-12-13	Markita Rempel	markita.rempel@woohoo.com	Baltimore	Maryland	501817266218415	115fa1f893c2822a813c4685a14de4c5	VISA 16 digit	39.2268125594127923	-76.5424182614795825
6933	2019-12-13 02:27:41	2019-12-13	Margot Dare	margot.dare@geemail.com	Memphis	Tennessee	639013764126200	b8fb0c91347f4a9baa719c6bc34dd84f	Discover	35.197232185823097	-89.9083021492488683
6934	2019-12-13 02:57:56	2019-12-13	Hung Schaden	hung.schaden@geemail.com	San Diego	California	54397469917898957	ea5cb7ac7e4e598d92dded14093fac6d	American Express	32.8384936123687794	-117.113582512633883
6935	2019-12-13 03:08:15	2019-12-13	Lona Klein	lona.klein@warmmail.com	Chesapeake	Virginia	4788316941808345	441fedea750b942c0e40a128b05a6e66	American Express	36.7723642931558174	-76.288310216398159
6936	2019-12-13 03:19:22	2019-12-13	Oneal Johnston II	oneal.johnston.ii@geemail.com	Visalia	California	3528854892958948967	f7c6564e7266fae76f739aecb318f195	Discover	36.2648339852646018	-119.261612185243152
6937	2019-12-13 03:34:21	2019-12-13	Marin Nolan	marin.nolan@geemail.com	Clarksville	Tennessee	4183515863223034	aeea1ef7a0b945a0d7f8dcb290f7a3b4	Maestro	36.5637884144797951	-87.4032906053539449
6938	2019-12-13 04:08:55	2019-12-13	Dwight Reinger II	dwight.reinger.ii@geemail.com	Columbia	South Carolina	4113502449341089	0c8444b881f93f5e9d1eb9d9947a3978	JCB 16 digit	34.0798604777812955	-80.8491094612535051
6939	2019-12-13 04:16:26	2019-12-13	Fletcher Jenkins	fletcher.jenkins@geemail.com	Lansing	Michigan	6011299585605333145	8db0e28271409a7d872c02f87290f575	VISA 16 digit	42.7276866692427575	-84.550995312969377
7102	2019-12-15 18:57:56	2019-12-15	Katerina Johns	katerina.johns@geemail.com	Memphis	Tennessee	3096863125498274639	40ba5b055d0cd8e25fc2b1f8ad69b862	JCB 15 digit	35.0514462237313396	-89.9559048589110404
6940	2019-12-13 04:53:37	2019-12-13	Lamonte Hodkiewicz-Crist	lamonte.hodkiewicz.crist@warmmail.com	San Francisco	California	3088063647148727623	483d0e8f2ef096b12ae1f4fd59284274	Voyager	37.7917984453185554	-122.45506257474166
6941	2019-12-13 05:23:51	2019-12-13	Dr. Knute Gorczany	dr.knute.gorczany@geemail.com	San Francisco	California	180016639894970141	d83d70f00e9a8345fb6bec729d8127bf	Discover	37.7988488075687741	-122.392820057708462
6942	2019-12-13 05:55:13	2019-12-13	Ever Wisoky MD	ever.wisoky.md@geemail.com	San Francisco	California	3046975079562184	646eb8845086892bf2d14e5d2e38e9ed	JCB 16 digit	37.7682248734941268	-122.431411797504722
6943	2019-12-13 06:00:29	2019-12-13	Eldridge Schmitt	eldridge.schmitt@geemail.com	Indianapolis	Indiana	3431359148899191	a454fdc1e7643bec8b5d5c828cabbf87	JCB 16 digit	39.7221038077034052	-86.1844265405289747
6944	2019-12-13 06:02:26	2019-12-13	Roosevelt Roberts Sr.	roosevelt.roberts.sr.@geemail.com	San Francisco	California	4051587682798115	93d47690b0916d0af170739782b39fb5	VISA 16 digit	37.8018078299458011	-122.434929479202168
6945	2019-12-13 06:11:29	2019-12-13	Dr. Brown Zemlak DVM	dr.brown.zemlak.dvm@geemail.com	San Francisco	California	3337377133659462869	7384a5d043237fa19f26b24afd9a4be0	American Express	37.77328550984938	-122.414435641144479
6946	2019-12-13 06:41:00	2019-12-13	Gerhard Quigley	gerhard.quigley@warmmail.com	San Francisco	California	3780410878296692	4a59791b79cf90b1f2ed0b07e3ad631d	JCB 15 digit	37.7709996815537252	-122.434422443272098
6947	2019-12-13 06:43:48	2019-12-13	Lilyan White	lilyan.white@woohoo.com	Oakland	California	4137578191632554	c26e3fb5c9b4b74258740c325ec33db9	Voyager	37.8048591112433741	-122.277841266993008
6948	2019-12-13 07:03:22	2019-12-13	Mercer Jacobs-Weimann	mercer.jacobs.weimann@geemail.com	San Francisco	California	589358537634972	e011f37fc92b07d654f17d686238b72e	VISA 13 digit	37.7527131541081005	-122.463529841760831
6949	2019-12-13 07:04:23	2019-12-13	Codie Waters	codie.waters@geemail.com	Phoenix	Arizona	55049134696705474	3b43ca32b721225ff31941b0f7a1eb4e	VISA 13 digit	33.6026782355204219	-112.041719312260312
6950	2019-12-13 07:45:26	2019-12-13	Loyal Wuckert	loyal.wuckert@geemail.com	San Francisco	California	4432731479992263	4c042da2bce004fb7361345b2709d853	VISA 16 digit	37.7579980125240624	-122.401016513207423
6951	2019-12-13 07:55:55	2019-12-13	Trudy Howell	trudy.howell@geemail.com	Elk Grove	California	3029234412690543	d975a91fa060c1e80ac4aba0099699f2	Voyager	38.4854783799316706	-121.320920505644764
6952	2019-12-13 07:57:22	2019-12-13	Hugh Dietrich-Littel	hugh.dietrich.littel@geemail.com	Oakland	California	4987064358279712	d11ce3eb723c609c07a4e7553aabe45a	JCB 15 digit	37.8149671579127542	-122.261619297513121
6953	2019-12-13 08:14:51	2019-12-13	Sandy Carroll	sandy.carroll@geemail.com	Mesa	Arizona	6011047475793856740	46f464caaaebce502a8c3a505b66c26c	JCB 15 digit	33.3393934711027882	-111.618111937574668
6954	2019-12-13 08:49:38	2019-12-13	Adam Jakubowski-Fisher	adam.jakubowski.fisher@geemail.com	Macon	Georgia	4112250834659738	e39c9a9a6f7ae48faebff9a5cde094f2	Discover	32.7666463920392061	-83.6308212711203822
6955	2019-12-13 08:59:40	2019-12-13	Vincenza Turcotte PhD	vincenza.turcotte.phd@geemail.com	Oakland	California	3775167332192076	d7bec9dc7383ef501282cf8e178fbe63	VISA 13 digit	37.8075001258570751	-122.265195267958944
6956	2019-12-13 09:21:52	2019-12-13	Arminta Harvey DVM	arminta.harvey.dvm@woohoo.com	Philadelphia	Pennsylvania	4839955421947	2970473133bc0bda0de4d3a72b44dd0f	JCB 15 digit	39.9247696469962605	-75.1222902919065234
6957	2019-12-13 09:44:48	2019-12-13	Kristian Kuhic	kristian.kuhic@geemail.com	San Francisco	California	210065273216586722	aa2b8e7d961fa5fc4d6e50e8708c2d00	Mastercard	37.7666491259060635	-122.456442057094648
6958	2019-12-13 10:26:53	2019-12-13	Ivy Breitenberg	ivy.breitenberg@warmmail.com	Louisville	Kentucky	3054057030850891	8a380eeec2183382d9a5453d5683047a	VISA 16 digit	38.0844990362782028	-85.7438761482551683
6959	2019-12-13 10:29:12	2019-12-13	Davey Kuhic	davey.kuhic@geemail.com	Corona	California	3014798766947068	a134e57b8adcecdfb1ae029a3bb653ad	JCB 16 digit	33.8859001625217502	-117.504632456528029
6960	2019-12-13 11:55:53	2019-12-13	Dr. Dempsey Fahey	dr.dempsey.fahey@woohoo.com	Fargo	North Dakota	6011907280945842823	554fb8eb935a7274424d7c06c7f940fd	VISA 16 digit	46.7958803488172634	-96.7410915972161973
6961	2019-12-13 12:06:28	2019-12-13	Oakley Jacobson	oakley.jacobson@geemail.com	San Jose	California	6011549022209279183	f36cb7242dd2e9201e624e4ed99b0202	JCB 16 digit	37.3369669524773968	-121.799104904498535
6962	2019-12-13 12:23:53	2019-12-13	Miss Judyth Koepp	miss.judyth.koepp@geemail.com	San Francisco	California	3425276422059631	464790a314d76acdc47215d361947732	Discover	37.7513966091154245	-122.439499350923029
6963	2019-12-13 12:48:52	2019-12-13	Dr. Rayan Keebler	dr.rayan.keebler@geemail.com	Oceanside	California	6011458985655921228	c5cc923823edf6141f7c7addf993b2a2	JCB 16 digit	33.3071923314481992	-117.238516516712309
6964	2019-12-13 13:30:11	2019-12-13	Miss Ethyle Gottlieb DDS	miss.ethyle.gottlieb.dds@woohoo.com	Nashville	Tennessee	210043850504154722	538a4c0f959e0f3479186f1dbb11d5d8	VISA 13 digit	36.1354750125791853	-86.7914726754557364
6965	2019-12-13 13:50:50	2019-12-13	Ms. Kendall Smith DVM	ms.kendall.smith.dvm@geemail.com	San Francisco	California	180096214533416196	d2e3edef4d3a81d91911f4b4bf3f031f	JCB 16 digit	37.7665361324008515	-122.409166331145045
6966	2019-12-13 16:05:26	2019-12-13	Fremont Kreiger	fremont.kreiger@geemail.com	Spokane	Washington	869946099685041418	6f60cb0c1b122532567c8c2cf9cd591a	VISA 13 digit	47.7499718268174647	-117.408378369723636
6967	2019-12-13 16:29:16	2019-12-13	Shalonda Koepp	shalonda.koepp@geemail.com	Gresham	Oregon	6011187407424234963	6b616eb769ed296c8ece65f8edbcc5d2	JCB 16 digit	45.5700685472182911	-122.418743926545972
6968	2019-12-13 16:32:58	2019-12-13	Devyn Bosco DVM	devyn.bosco.dvm@geemail.com	San Francisco	California	3088701742010843885	06a29add273813b3c7e85e55fd9e12c8	American Express	37.7721636918005998	-122.400959150737464
6969	2019-12-13 16:52:31	2019-12-13	Mrs. Afton Cole	mrs.afton.cole@warmmail.com	Colorado Springs	Colorado	676398581640467	7fde57f4ace1bd4cd944fb5cf80081e9	Discover	38.9131493473473924	-104.722136475953093
6970	2019-12-13 16:57:06	2019-12-13	Tito Grimes	tito.grimes@geemail.com	Berkeley	California	6011154028213802882	13bd3d529a3981499057890b7585737e	JCB 16 digit	37.8578700140653694	-122.264981969049884
6971	2019-12-13 17:09:35	2019-12-13	Doshie Lowe	doshie.lowe@geemail.com	San Francisco	California	869916535581567960	4bf77cdaa3af99adb8e546d6056862a8	Diners Club / Carte Blanche	37.764778422824314	-122.407312169019377
6972	2019-12-13 17:50:35	2019-12-13	Austen Jacobi	austen.jacobi@geemail.com	San Francisco	California	210015766347715871	c63e2e819ee9b347af941ea41997e32f	JCB 16 digit	37.7712699839820445	-122.428560895382162
6973	2019-12-13 18:29:32	2019-12-13	Yulissa Boyer MD	yulissa.boyer.md@geemail.com	San Francisco	California	52127339887292894	c0673900905f89a53f9059a27ad77797	JCB 15 digit	37.7868421267912282	-122.477551249892187
6974	2019-12-13 19:31:22	2019-12-13	Miss Brittnay McCullough	miss.brittnay.mccullough@geemail.com	Albuquerque	New Mexico	4445039264590960	6169235930e211c7644e59ac6100bc36	Maestro	35.0744047743868137	-106.695676639124386
6975	2019-12-13 20:36:19	2019-12-13	Woodie Carroll	woodie.carroll@geemail.com	San Francisco	California	210072559131391359	b9d47f8695f577f60562386b32de8881	VISA 13 digit	37.8217330364824846	-122.421269360348191
6976	2019-12-13 20:47:40	2019-12-13	Therman Witting	therman.witting@geemail.com	Denver	Colorado	3158279230156863588	50c5ac082a5198005ef7481e03d5b3a6	VISA 13 digit	39.7232988535944358	-104.835801720364401
6977	2019-12-13 21:30:04	2019-12-13	Hillard Welch	hillard.welch@woohoo.com	San Francisco	California	51243042246194079	5e7020483dc047c4e478630015225746	Mastercard	37.7618680321837772	-122.444750422534995
6978	2019-12-13 22:13:17	2019-12-13	Juelz Kub	juelz.kub@geemail.com	Oakland	California	4245662704676248	4561abc204047e62d21a897f5f8dcc80	American Express	37.7924032736640356	-122.306313279297797
6979	2019-12-13 22:23:43	2019-12-13	Wilma Labadie	wilma.labadie@geemail.com	Houston	Texas	3337442763517407812	bfcd36087230876f74bdafc464fb2593	Voyager	29.7633573053948588	-95.4416666976656813
7184	2019-12-17 04:52:08	2019-12-17	Adolfo O'Hara	adolfo.o'hara@geemail.com	San Diego	California	3158373367068237686	57f06d3fa25275964857a9999e2a4273	Mastercard	32.8556537716716548	-117.14894995884039
6980	2019-12-13 22:27:57	2019-12-13	Dr. Arlene DuBuque DVM	dr.arlene.dubuque.dvm@geemail.com	New York	New York	589335141666046	9670a92919d653cd95a8dc76a15b962c	Diners Club / Carte Blanche	40.739482137117534	-73.8855031529802773
6981	2019-12-13 23:52:23	2019-12-13	Phoebe Macejkovic-Klein	phoebe.macejkovic.klein@geemail.com	North Charleston	South Carolina	3026361265072017	f86d6b0920d31796e497901dbeb2f9fa	JCB 16 digit	32.8200873183712361	-80.1083286505751317
6982	2019-12-14 00:02:41	2019-12-14	Maybell Keebler	maybell.keebler@geemail.com	Oakland	California	3470846652794398	d94110b0cfa6c6fb9db2545d1ce0ea51	JCB 16 digit	37.8214151014629749	-122.281461783367092
6983	2019-12-14 00:34:03	2019-12-14	Ricki Keeling I	ricki.keeling.i@warmmail.com	Detroit	Michigan	3733169241063514	50d49588878f0559d21631805bbc7598	VISA 16 digit	42.4300627557486294	-83.1799404918801031
6984	2019-12-14 00:52:34	2019-12-14	Hayward Mayer	hayward.mayer@woohoo.com	San Francisco	California	55771963431963749	774137f4ffb3a0d624caf088a4c9285d	Mastercard	37.7603634481040942	-122.423902310711057
6985	2019-12-14 01:28:17	2019-12-14	Ragna Watsica	ragna.watsica@warmmail.com	San Francisco	California	53630576973829002	a751f65e772cf8f68893b4945aa339a5	JCB 16 digit	37.7459851424096584	-122.446564334607586
6986	2019-12-14 02:19:56	2019-12-14	Gabriella Bartell-Prosacco	gabriella.bartell.prosacco@geemail.com	Aurora	Colorado	3729906208369079	9bd16e64127b9e6c4785b1ee3f9c8bc5	Voyager	39.7025234914030918	-104.619702745473759
6987	2019-12-14 02:20:55	2019-12-14	Byron Stamm	byron.stamm@geemail.com	San Francisco	California	210033138490118154	ad490223420d02553a8e5884cc054071	VISA 13 digit	37.7934758656289347	-122.401883480035409
6988	2019-12-14 02:44:55	2019-12-14	Leola Olson	leola.olson@geemail.com	Buffalo	New York	3096518056293484280	c02ba1955dc2c8db05b72f6bbb8326ed	American Express	42.812822225429116	-78.8631475399181312
6989	2019-12-14 03:05:43	2019-12-14	Emory Collins	emory.collins@geemail.com	Ontario	California	51507522618541958	7f001fe6792c11afac02a366000eeaed	VISA 16 digit	33.9680021799314744	-117.58670311478042
6990	2019-12-14 03:08:25	2019-12-14	Ms. Oleta Koss MD	ms.oleta.koss.md@woohoo.com	San Francisco	California	4545168082182566	281c72bea8740b0b34df13fcfa6f183c	VISA 16 digit	37.8040147498113512	-122.44393642242521
6991	2019-12-14 04:00:01	2019-12-14	Norene Nitzsche	norene.nitzsche@geemail.com	Pembroke Pines	Florida	51749504732813461	301a6112c5dd606db10abf5204026dac	Discover	26.0602376085277641	-80.2832413958754358
6992	2019-12-14 04:17:40	2019-12-14	Jewell Brekke	jewell.brekke@geemail.com	Bellevue	Washington	4391888591763391	ee578079b88e8b97243551ff27a86355	VISA 13 digit	47.516724429856616	-122.085642252728334
6993	2019-12-14 04:45:30	2019-12-14	Dr. Jim Sauer MD	dr.jim.sauer.md@geemail.com	Pittsburgh	Pennsylvania	4833408557795	3b154b53c5b658133e5432684e06700a	Mastercard	40.4898037084333566	-79.9845837779514568
6994	2019-12-14 04:51:12	2019-12-14	Savanah Lueilwitz DVM	savanah.lueilwitz.dvm@warmmail.com	Berkeley	California	3798824913108631	a682239c7c00c41527930c2b01c8f878	American Express	37.8768637608858825	-122.289135291031982
6995	2019-12-14 05:14:21	2019-12-14	Pleasant Hintz	pleasant.hintz@woohoo.com	San Francisco	California	52178082073631180	2b44d8502eb65eed2f37584791bce4bd	Mastercard	37.7891141643242321	-122.454796323690957
6996	2019-12-14 06:26:10	2019-12-14	Danika Hirthe	danika.hirthe@geemail.com	Berkeley	California	869989075774580548	57424046687787bdd9e06c083894aee9	Voyager	37.8616651205963421	-122.288334346559267
6997	2019-12-14 06:48:24	2019-12-14	Andon Bogan	andon.bogan@geemail.com	Vallejo	California	3528484105751460132	f200cb4796f95d82cc82e452215fb0ca	VISA 16 digit	38.0209033267661951	-122.290868586614721
6998	2019-12-14 07:19:07	2019-12-14	Ms. Maryjo Gorczany	ms.maryjo.gorczany@warmmail.com	Frisco	Texas	6011057882964219169	f792df7c85663402b40f0424aa3f4aa5	JCB 16 digit	33.0921577724624427	-96.8224408742714644
6999	2019-12-14 07:22:22	2019-12-14	Ms. Aspen Auer	ms.aspen.auer@geemail.com	Colorado Springs	Colorado	180076599375967924	81007fab2d31b312dfde14845c0cddaa	American Express	38.7818861612167183	-104.750872322280699
7000	2019-12-14 07:22:55	2019-12-14	Immanuel Herzog Sr.	immanuel.herzog.sr.@warmmail.com	Saint Paul	Minnesota	561221340063177	ff9e44376f9182b73540d5ef3a426f1d	American Express	45.0064103139970442	-93.0909476293515468
7001	2019-12-14 08:59:03	2019-12-14	Park Stracke	park.stracke@geemail.com	Nashville	Tennessee	4342522357501287	83243f4051fd39a7c8cdc8ed21e08724	JCB 16 digit	36.1942873786792134	-86.7746338643040502
7002	2019-12-14 09:02:26	2019-12-14	Mrs. Sammie Denesik DDS	mrs.sammie.denesik.dds@warmmail.com	Phoenix	Arizona	4351274325239	f7610acac54c4f0c44dd11acf2753d5d	JCB 16 digit	33.6655648411650219	-111.999074061673511
7003	2019-12-14 09:04:03	2019-12-14	Ms. Georgia Wiza	ms.georgia.wiza@geemail.com	Henderson	Nevada	3723494496092113	2f8738bcf21f5d4dcde9eb708f211c7e	Maestro	35.9777363142397277	-115.071862490583968
7004	2019-12-14 09:18:47	2019-12-14	Crockett Rohan	crockett.rohan@warmmail.com	Jacksonville	Florida	4392925250100306	37cc66a91d30b90edd43b5192002f42f	Voyager	30.4301613916229456	-81.7113217389289304
7005	2019-12-14 09:31:58	2019-12-14	Fleeta Stark	fleeta.stark@geemail.com	Seattle	Washington	4111996482912115	5e24b6cd92a986a152efa4b8f0b27465	Diners Club / Carte Blanche	47.6961974900607046	-122.378914475107194
7006	2019-12-14 10:17:24	2019-12-14	Hence Hegmann	hence.hegmann@geemail.com	Jacksonville	Florida	180032123491748317	1761143213a63d76b4247ec227723d6c	JCB 16 digit	30.2552789572212859	-81.5993687744330742
7007	2019-12-14 10:23:29	2019-12-14	Janiya Waelchi	janiya.waelchi@geemail.com	Los Angeles	California	3112457939817541359	a48e6cb58afe5d85c04f1b76737138e1	Discover	34.0583312082901557	-118.352983169303457
7008	2019-12-14 10:52:37	2019-12-14	Arabella Hyatt	arabella.hyatt@geemail.com	San Francisco	California	3096841390526707854	b23c976694f75cfabb544c4ae34d6055	VISA 13 digit	37.7811408442028309	-122.421666740371464
7009	2019-12-14 11:05:05	2019-12-14	Prudence Herzog DDS	prudence.herzog.dds@geemail.com	Seattle	Washington	3025048751261052	d1014a1b00c1a15fc960bd9d98eb58ec	VISA 16 digit	47.6117385990843189	-122.439364825507255
7010	2019-12-14 11:22:28	2019-12-14	Maurine Powlowski DDS	maurine.powlowski.dds@geemail.com	San Francisco	California	3112227969653124704	7852fe4ed91fe2502bb5beac03aea654	VISA 13 digit	37.7713092884535371	-122.444802012209138
7011	2019-12-14 11:32:33	2019-12-14	Mikalah Boehm	mikalah.boehm@geemail.com	New York	New York	3096161056747102736	8e107be1656a7afcace559779998f96b	Diners Club / Carte Blanche	40.7369478528145663	-74.0314433507051319
7012	2019-12-14 11:38:52	2019-12-14	Greta Okuneva	greta.okuneva@woohoo.com	San Francisco	California	4368816569808608	b3a1080efee5a56d8b9c1493692eeb2f	VISA 16 digit	37.8064008001041572	-122.429248452007556
7013	2019-12-14 11:40:14	2019-12-14	Mrs. Averi Hoeger	mrs.averi.hoeger@geemail.com	Colorado Springs	Colorado	210094245586929497	67c46f34b9087d6654590f6273ec7b99	Maestro	38.7767421283807607	-104.68866130753122
7014	2019-12-14 11:55:24	2019-12-14	Simpson Ebert	simpson.ebert@warmmail.com	Houston	Texas	4919548365544	f6bb9a8a65dc1cc56956a7789c9057e7	Diners Club / Carte Blanche	29.7029284376263618	-95.3459543510355019
7015	2019-12-14 12:07:51	2019-12-14	Gemma Littel	gemma.littel@geemail.com	Jacksonville	Florida	3012181779079504	77a5f6222da4782a47969902510f9699	American Express	30.263367854669319	-81.7429177006784897
7016	2019-12-14 12:40:11	2019-12-14	Dr. Khalil Torp	dr.khalil.torp@geemail.com	Detroit	Michigan	51320515632836060	431c69e73572f2fd2e2711a8aa06da01	American Express	42.3079030194710981	-83.0265153500370587
7017	2019-12-14 12:48:34	2019-12-14	Lue Miller	lue.miller@geemail.com	San Francisco	California	4489157191857216	0faf1989193c84b16bda164b5818e978	Maestro	37.8031371552257127	-122.396938233067957
7018	2019-12-14 12:49:26	2019-12-14	Miss Adah Breitenberg	miss.adah.breitenberg@warmmail.com	Memphis	Tennessee	6011379799839995826	b0c37796a11a8ba5e94aee16cbc84da4	JCB 16 digit	35.1238486026015124	-90.072756764411551
7019	2019-12-14 12:50:13	2019-12-14	Anahi Thiel	anahi.thiel@geemail.com	Berkeley	California	869924465340746293	ee0da0aa3511577989ff15ec70553765	VISA 16 digit	37.872318419083733	-122.295081872657263
7020	2019-12-14 12:52:36	2019-12-14	Harve Lehner	harve.lehner@geemail.com	North Las Vegas	Nevada	3337633326987217407	f547ffece3516263e9daf13e6a569a31	JCB 16 digit	36.2095911216147215	-115.03668546711431
7021	2019-12-14 12:53:40	2019-12-14	Dr. Hunt Gottlieb	dr.hunt.gottlieb@woohoo.com	Philadelphia	Pennsylvania	55634952275107270	9c9ee350c04b90777fc93c2ea6695cdc	VISA 16 digit	40.078585587065291	-75.1130343601472674
7022	2019-12-14 12:56:32	2019-12-14	Mr. Elihu Schumm DVM	mr.elihu.schumm.dvm@warmmail.com	New York	New York	4922779558332	1b5c798b02ea240b7eb61a8ff3fc2a5a	VISA 16 digit	40.724172955866905	-73.894749560476086
7023	2019-12-14 13:11:31	2019-12-14	Erving Senger	erving.senger@geemail.com	Corona	California	52371996247169402	9cbcb6ce981bb554a7a2469400846a58	JCB 15 digit	33.8311764072980736	-117.622687182828784
7024	2019-12-14 13:11:32	2019-12-14	Ema Marvin	ema.marvin@warmmail.com	Chula Vista	California	55258445122229525	420bea5673a8d0fa58b22ad7f67f3116	JCB 16 digit	32.7259900391798411	-117.060190173168479
7025	2019-12-14 13:15:55	2019-12-14	Gasper Yundt-Wilderman	gasper.yundt.wilderman@woohoo.com	San Diego	California	6011949002738903186	601d103fd10c0af316b71e40d5929f16	VISA 16 digit	32.7460142799254541	-117.080456754928463
7026	2019-12-14 13:31:52	2019-12-14	Clara Runolfsdottir-Schinner	clara.runolfsdottir.schinner@geemail.com	Raleigh	North Carolina	6011714132140868090	2986533b237078a8efb5eaefd3d2a7b4	Voyager	35.7437443592254027	-78.6214183930709964
7027	2019-12-14 13:32:49	2019-12-14	Jacklyn Legros	jacklyn.legros@geemail.com	New York	New York	4727345775351548	fdf751fc9cf1ee086fa7644aac7fc572	JCB 16 digit	40.6014905731882862	-73.8902263233799488
7028	2019-12-14 13:36:04	2019-12-14	Ms. Skylar Purdy DDS	ms.skylar.purdy.dds@woohoo.com	Stockton	California	4995548865759323	efec689f76c31928806a600c98a369db	JCB 16 digit	37.9369995742302422	-121.322141944765292
7029	2019-12-14 13:37:51	2019-12-14	Jeffrey Sanford-Osinski	jeffrey.sanford.osinski@geemail.com	Nashville	Tennessee	869953622423481040	49693cb626d70009e7638ce57cfea140	VISA 16 digit	36.1225280128076633	-86.792796885166311
7030	2019-12-14 14:30:26	2019-12-14	Abraham Senger	abraham.senger@warmmail.com	Jacksonville	Florida	51352996225229676	200ba8a7228e156a21905b16ce374e58	JCB 16 digit	30.2384784902963801	-81.5658296468746045
7031	2019-12-14 14:57:54	2019-12-14	Rick Schiller	rick.schiller@geemail.com	Las Vegas	Nevada	6011529915839741585	0e3b3ccd3c24c613d15b1703a2f3264d	JCB 15 digit	36.250020409851146	-115.182699668474868
7032	2019-12-14 14:58:49	2019-12-14	Deondre Witting	deondre.witting@warmmail.com	San Francisco	California	52801362246450329	6c106f7897ea5556dae0cd6a117754db	VISA 16 digit	37.7929026746701808	-122.423153564689287
7033	2019-12-14 17:08:56	2019-12-14	Mikal Koepp	mikal.koepp@geemail.com	San Francisco	California	3158931938076772859	e6d16ab6554c88dfe1f6eb31e0794d83	VISA 16 digit	37.7705281663170993	-122.450411325576738
7034	2019-12-14 17:12:07	2019-12-14	Stephanie Mayert	stephanie.mayert@woohoo.com	San Francisco	California	4299122844234	cadeecc4714a868cc19012a2c36aef29	Mastercard	37.7845663657002149	-122.423503635960529
7035	2019-12-14 17:52:55	2019-12-14	Tracy Mosciski	tracy.mosciski@warmmail.com	Pasadena	Texas	180067502445655462	80f6647dba599a4e3a558fcab9593068	Discover	29.7360040150921776	-95.2444755976036106
7036	2019-12-14 18:26:31	2019-12-14	Watson Cassin	watson.cassin@geemail.com	New York	New York	6011277369344413302	4a1b014c4c3f39750ff612b3e0ff86c4	American Express	40.5643957546669967	-73.8938801343914093
7037	2019-12-14 18:27:33	2019-12-14	Wayman Cole MD	wayman.cole.md@geemail.com	Virginia Beach	Virginia	3112203950845711242	3dc2f48918f186520a9c9cfca6481aab	Discover	36.7774531794898252	-75.9459375160418375
7038	2019-12-14 18:33:28	2019-12-14	Trina Roberts	trina.roberts@geemail.com	San Francisco	California	3096052281538078091	dd407b7ebd414ecec3ae3a5ede7bd889	JCB 16 digit	37.7439744385608478	-122.488527581295259
7039	2019-12-14 18:36:59	2019-12-14	Carmella Lueilwitz	carmella.lueilwitz@woohoo.com	Providence	Rhode Island	180071785263179087	7df5f67c9f3297133679f7e54efa0301	Mastercard	41.8432061462052118	-71.4145594489213096
7040	2019-12-14 18:49:04	2019-12-14	Mr. Skip Ankunding PhD	mr.skip.ankunding.phd@geemail.com	Berkeley	California	4987919944837176	2d3f804be927f38ec42539e9e84ceea8	VISA 16 digit	37.8448640266935072	-122.277883178755971
7041	2019-12-14 19:28:16	2019-12-14	Bedford Marks	bedford.marks@geemail.com	Sandy Springs	Georgia	52381364809900250	bbc5b451a711c82549e8a4f5d3f2d2bc	Mastercard	33.8686965736150754	-84.2890180714510393
7042	2019-12-14 19:32:07	2019-12-14	Alwilda Bashirian-Kshlerin	alwilda.bashirian.kshlerin@geemail.com	Los Angeles	California	51945500381855102	65a63ac97d2e62ac6b3d2c311954b271	Mastercard	34.1003833338949818	-118.442077370406309
7043	2019-12-14 19:46:19	2019-12-14	Rosemary Jerde	rosemary.jerde@geemail.com	San Francisco	California	589333671248327	e26c02c3ea55fbc2eea65580bb973b5e	Discover	37.7786143370993273	-122.437073643086848
7044	2019-12-14 20:01:22	2019-12-14	Willam Wilkinson Sr.	willam.wilkinson.sr.@geemail.com	Santa Clarita	California	51834084582486185	7d32f007573f9f01481d5a102cabdec7	VISA 16 digit	34.3630017094984623	-118.484794749189916
7045	2019-12-14 22:26:37	2019-12-14	Clement Boyle	clement.boyle@woohoo.com	Colorado Springs	Colorado	4519117843534468	12507861583e1d2246f5526f15801578	Mastercard	38.9339841692291202	-104.679468273619932
7046	2019-12-14 22:37:37	2019-12-14	Kenyon Witting	kenyon.witting@woohoo.com	San Francisco	California	869947143115507280	a6db6f1ad33efea277b50853efebb2d3	Voyager	37.7243966685539291	-122.447099020554106
7047	2019-12-14 22:41:39	2019-12-14	Lou Ferry-Hirthe	lou.ferry.hirthe@geemail.com	Elgin	Illinois	52326801461330340	84153ff8155e0b8ce29312ec333679ec	Voyager	42.1376693645309643	-88.2603768989730639
7048	2019-12-14 22:48:12	2019-12-14	Ms. Farrah Bernier DVM	ms.farrah.bernier.dvm@geemail.com	Knoxville	Tennessee	4346978835905	ca593e128388dc7e783a484cef885025	Discover	36.0309261621039383	-83.8978808628611148
7049	2019-12-14 23:24:15	2019-12-14	Celena Cassin	celena.cassin@geemail.com	New York	New York	3088460323756549654	56654ef3c66f38bde41df616a9ce2a27	Maestro	40.7443078216388841	-73.9231176788814395
7050	2019-12-14 23:56:15	2019-12-14	Gale Jacobson	gale.jacobson@woohoo.com	San Francisco	California	561216121633578	bc476f80eb5365a3c6471376002466e4	American Express	37.7760687513173039	-122.422002745753247
7051	2019-12-15 00:03:58	2019-12-15	Alida Lind	alida.lind@geemail.com	San Francisco	California	3112768671548495704	c466c260889ee10f2593bfa052457182	VISA 16 digit	37.7771266027390311	-122.420832433144142
7052	2019-12-15 00:16:06	2019-12-15	Rikki Paucek DDS	rikki.paucek.dds@geemail.com	Seattle	Washington	180062886423296943	6a5a4970ce9b2ae5661d3bb02cab7a6c	American Express	47.7107109447866691	-122.41870345933512
7053	2019-12-15 02:12:17	2019-12-15	Tamekia Hermann	tamekia.hermann@geemail.com	San Francisco	California	4809991063665627	b4d1d62877c0283864de9af33ec4756e	JCB 16 digit	37.7858462900434091	-122.39250645489345
7054	2019-12-15 02:38:33	2019-12-15	Ms. Nancy Konopelski MD	ms.nancy.konopelski.md@geemail.com	Fullerton	California	54203808602478621	c022972054367ca171af9f5c58be0ace	JCB 16 digit	33.8860553114831475	-118.00382852318883
7055	2019-12-15 02:44:46	2019-12-15	Ximena Schmitt	ximena.schmitt@warmmail.com	Dallas	Texas	630450556918303	4afb1d3c4484afdb056d6502ef984670	Mastercard	32.8820910317163921	-96.6921137304939293
7056	2019-12-15 02:56:34	2019-12-15	Ms. Brynn Runolfsdottir	ms.brynn.runolfsdottir@geemail.com	Lowell	Massachusetts	3436556874639817	3f7113e81b7e99d153c66ffe9c14a26f	American Express	42.7269691419191702	-71.2330618635158999
7057	2019-12-15 03:10:23	2019-12-15	Valentine Jenkins	valentine.jenkins@woohoo.com	San Francisco	California	676116556828297	c2102db0f613bc9a8b0c4c573e7690f3	VISA 16 digit	37.7731029038011101	-122.414734867614982
7058	2019-12-15 03:15:44	2019-12-15	Robyn Hermann-Effertz	robyn.hermann.effertz@geemail.com	Oakland	California	3088793860823568850	74130ae499e2af7c673324774bc2932a	VISA 13 digit	37.7799496106652981	-122.287217314986052
7059	2019-12-15 03:30:41	2019-12-15	Vicky Maggio-Greenholt	vicky.maggio.greenholt@warmmail.com	Portland	Oregon	4580690761587118	939b3d77492591c7f0b033b38041c9f6	Maestro	45.4741425225865115	-122.745230119675398
7060	2019-12-15 03:40:19	2019-12-15	Kennard Brekke	kennard.brekke@geemail.com	Los Angeles	California	561264463817698	94fcc1ca43c233b9b25d7c2166bbf94d	VISA 13 digit	33.9985505726054313	-118.436995448962961
7061	2019-12-15 03:50:28	2019-12-15	Mr. Horton Donnelly	mr.horton.donnelly@woohoo.com	San Francisco	California	3528118819670476409	839785bbc00ec8091c32bf94a4f5ae8b	American Express	37.75574900536445	-122.44503995633913
7062	2019-12-15 03:51:08	2019-12-15	Fritz Ryan Sr.	fritz.ryan.sr.@woohoo.com	Milwaukee	Wisconsin	3112678402970559695	4b96a8d3c7084ddfea1998746cc2b50c	JCB 15 digit	42.9770884713709336	-87.9166777847435412
7063	2019-12-15 03:55:58	2019-12-15	Exa Runte-Brown	exa.runte.brown@geemail.com	Ann Arbor	Michigan	180045962383079579	2277423524810ea9b8a0a791313b0e95	JCB 15 digit	42.233203175483645	-83.803345069206884
7064	2019-12-15 04:12:32	2019-12-15	Ham Hudson	ham.hudson@geemail.com	San Antonio	Texas	4278575276740319	e9641641f88ff4b7ad57a20bf8bc4bb5	American Express	29.5672008147533987	-98.5724557661753096
7065	2019-12-15 04:25:34	2019-12-15	Miss Vincenza Lockman	miss.vincenza.lockman@woohoo.com	Birmingham	Alabama	4503026231149912	75f902c40b638926cdf5ad9ed0e363bd	Discover	33.5022166094534128	-86.7866249358058042
7066	2019-12-15 04:40:18	2019-12-15	Dr. Kory Gleichner	dr.kory.gleichner@geemail.com	Eugene	Oregon	869966664811610520	68f1662b2d0fd3e82317c2e261bd4043	Voyager	44.0607856534615152	-123.16759106744901
7067	2019-12-15 05:00:24	2019-12-15	Dr. Cyril Rempel I	dr.cyril.rempel.i@warmmail.com	San Francisco	California	869944162027001417	d710016e37a7053977201f1d937caf3a	JCB 16 digit	37.7836366274869917	-122.42633906509505
7068	2019-12-15 05:19:43	2019-12-15	Seaborn Beatty	seaborn.beatty@geemail.com	New York	New York	3782286729068003	014e8088df2d267f48a0edb595ea46aa	VISA 16 digit	40.5963429788351036	-73.9534753538563763
7069	2019-12-15 05:41:07	2019-12-15	Hailie Steuber	hailie.steuber@geemail.com	San Francisco	California	3158929138451394858	69a72a325484fe862a877eb7170ee925	Voyager	37.8186297784573711	-122.445258745806697
7070	2019-12-15 07:17:29	2019-12-15	Dr. Rod Boyle DVM	dr.rod.boyle.dvm@warmmail.com	Oxnard	California	589327948184703	3ec095444ee17c830d0ac673014891e1	Maestro	34.2414039592679629	-119.174942732407146
7071	2019-12-15 07:37:09	2019-12-15	Maryjo Blanda DVM	maryjo.blanda.dvm@geemail.com	Corpus Christi	Texas	6011851701589860082	d9c85cdf5b681fdadbc3b290bea9ef4c	Diners Club / Carte Blanche	27.7950853992190225	-97.1683101279489705
7072	2019-12-15 07:37:31	2019-12-15	Miss Alina Bins DDS	miss.alina.bins.dds@woohoo.com	San Francisco	California	869936101825635075	4c857710258608987538ff14c5632c99	Mastercard	37.7441678057201599	-122.442060619657752
7073	2019-12-15 08:04:03	2019-12-15	Kinte Flatley	kinte.flatley@warmmail.com	New York	New York	6011774178092988300	e4aae357b5ed91f403a09801efc19fbc	American Express	40.6537447335422044	-73.8889784887794434
7074	2019-12-15 08:24:44	2019-12-15	Dr. Diallo Boyer	dr.diallo.boyer@woohoo.com	San Francisco	California	060474367555468	2fc064a121750c250283a50ffa9c8d56	Mastercard	37.7712961725266041	-122.433984198465296
7075	2019-12-15 08:53:01	2019-12-15	Brooke O'Hara-Willms	brooke.o'hara.willms@geemail.com	San Francisco	California	503805968033281	35ccaf7011c740960f8292621e6dfc43	Voyager	37.8020471928011617	-122.414867188574519
7076	2019-12-15 10:01:51	2019-12-15	Nelly Schulist	nelly.schulist@geemail.com	Mesa	Arizona	3158245054531061275	cafb8385e40beece913c8ad0b79856cf	Voyager	33.3863567890279	-111.651162048138303
7077	2019-12-15 10:05:55	2019-12-15	Lafe Waters-Veum	lafe.waters.veum@geemail.com	Santa Ana	California	180071789403706288	449ce760debd9d5f769377b8b13f073c	Voyager	33.7983437716599582	-117.980356758080418
7078	2019-12-15 10:14:46	2019-12-15	Carissa VonRueden	carissa.vonrueden@geemail.com	Sparks	Nevada	3051813437566784	5d7cad781b2113a7d73c4cabca6aa983	JCB 16 digit	39.4581857198156456	-119.689758966336399
7079	2019-12-15 10:19:56	2019-12-15	Chanda Toy-Wuckert	chanda.toy.wuckert@geemail.com	Oakland	California	3476731691235906	326398d226c7204996ff9d395b30ec5c	VISA 13 digit	37.805320627339853	-122.253029284410545
7080	2019-12-15 10:25:55	2019-12-15	Andra Yundt	andra.yundt@geemail.com	San Francisco	California	3158280035616563901	e709caf3d386e4c22d8e9697e16918a4	Mastercard	37.7714979945643918	-122.416898150573175
7081	2019-12-15 11:02:08	2019-12-15	Neil Reynolds	neil.reynolds@geemail.com	San Francisco	California	53610924917880786	6c927dc179bd5e02f49b672a35bc4445	VISA 16 digit	37.778751364990562	-122.472169008329004
7082	2019-12-15 11:02:48	2019-12-15	Elissa Haley DDS	elissa.haley.dds@geemail.com	Los Angeles	California	180077721106996894	0a258df65e123dd773c6b4fb3b1134a6	JCB 15 digit	34.031666654707486	-118.366035847970466
7083	2019-12-15 11:09:26	2019-12-15	Simon Cartwright	simon.cartwright@geemail.com	San Francisco	California	55190629298367844	ed1d89b654d8759158a12ae7e5bb97ff	VISA 16 digit	37.7696014414599901	-122.459123366650061
7084	2019-12-15 11:41:53	2019-12-15	Chesley Blick-Baumbach	chesley.blick.baumbach@woohoo.com	San Francisco	California	3056368940083715	a3604cc4954ef31868fb3186a2e9ef88	Diners Club / Carte Blanche	37.7849979606354935	-122.428394034732619
7085	2019-12-15 11:58:11	2019-12-15	Rubi Brown-Nikolaus	rubi.brown.nikolaus@woohoo.com	Denver	Colorado	51347906206630675	af0a7422b98f3cabe851509cebecaacf	Mastercard	39.7743815596267538	-104.791020601313932
7086	2019-12-15 12:02:07	2019-12-15	Tari Jacobs	tari.jacobs@geemail.com	San Francisco	California	3423384996735883	4d0e09a150d9de2cedf2b1497b484a1f	Voyager	37.8069920369364354	-122.408482015949488
7087	2019-12-15 13:25:00	2019-12-15	Muhammad Gibson	muhammad.gibson@warmmail.com	Mobile	Alabama	869972152680181288	0e64539e610c5b11c8317c8ed0424cd1	JCB 16 digit	30.6042834536746113	-88.1437047673527161
7088	2019-12-15 13:41:35	2019-12-15	Lyric Heaney	lyric.heaney@geemail.com	Macon	Georgia	3088960371033983563	6836751a99142228e644176a9fca6105	Voyager	32.7528412392839741	-83.770036590630923
7089	2019-12-15 14:15:06	2019-12-15	Katheryn Emmerich	katheryn.emmerich@geemail.com	Las Vegas	Nevada	3033860211939966	c3fa1f3dcfe1080c2e2eb8f4ae13038b	American Express	36.2280603379577357	-115.258935337674245
7090	2019-12-15 14:52:20	2019-12-15	Mr. Nigel Mills	mr.nigel.mills@geemail.com	Los Angeles	California	51947151308327979	72e0637b93017648de1c159169a20a1b	VISA 16 digit	34.0167045028746102	-118.425271023902297
7091	2019-12-15 15:51:51	2019-12-15	Archibald DuBuque	archibald.dubuque@warmmail.com	Fremont	California	4215876011093	fd327f4783b2392d491e04f475906fc2	VISA 13 digit	37.4827618089672185	-121.865762400858841
7092	2019-12-15 15:52:38	2019-12-15	Dr. Jacob Kling	dr.jacob.kling@geemail.com	Houston	Texas	180075885122715356	9b41027529fa28b7e137ce397cd7a401	Discover	29.8493805387135609	-95.3394293904785144
7093	2019-12-15 15:54:50	2019-12-15	Mrs. Marcy Bins	mrs.marcy.bins@geemail.com	New York	New York	4419074978858017	cc73cfce695d69b3077afff590924b67	JCB 16 digit	40.7512110319212084	-73.921545625653863
7094	2019-12-15 16:03:54	2019-12-15	Sage Gerlach	sage.gerlach@geemail.com	San Francisco	California	3088344837626620678	f5447d973cb74bd4f2ed86c6c26f310c	Maestro	37.7839669518719603	-122.417072879302239
7095	2019-12-15 17:07:13	2019-12-15	Tinnie Wolf	tinnie.wolf@warmmail.com	Chula Vista	California	3158561515078521349	d11e0848e8401bce62c39ec76921779c	American Express	32.5427550309568616	-116.921672661765285
7096	2019-12-15 17:44:56	2019-12-15	Isidro Hettinger	isidro.hettinger@geemail.com	San Francisco	California	3702862815798013	cef3580f80395eec7c4d4e9bb851902f	JCB 15 digit	37.7592279973348894	-122.441783643617683
7097	2019-12-15 17:45:45	2019-12-15	Arland Senger	arland.senger@geemail.com	Oakland	California	3528573088630596908	d659bbd85c4ffa569abf056e04e30af0	Voyager	37.8021281920636909	-122.271212603455226
7098	2019-12-15 17:46:24	2019-12-15	Howell Donnelly	howell.donnelly@geemail.com	San Francisco	California	51151508199705350	9efe54d642cb4176e1f4441d54e7793b	Voyager	37.7649474793082547	-122.449701567401092
7099	2019-12-15 18:10:17	2019-12-15	Livia Hermiston	livia.hermiston@geemail.com	Clearwater	Florida	4790503941052646	5794dfba92ebe16dc8634b129ca995fa	JCB 16 digit	28.0185621404215688	-82.8255723880402712
7100	2019-12-15 18:12:46	2019-12-15	Ms. Doris Runte	ms.doris.runte@geemail.com	San Francisco	California	3337910811666271068	17320010c89d77a461e3a54d40c33bfa	Mastercard	37.7533285575397954	-122.418709242388502
7101	2019-12-15 18:48:47	2019-12-15	Long Abernathy Jr.	long.abernathy.jr.@geemail.com	Sioux Falls	South Dakota	3460730354996471	b41726437ca9722ce8504498cf56516e	Diners Club / Carte Blanche	43.5897653547666977	-96.7197979989163628
7103	2019-12-15 19:32:45	2019-12-15	Mrs. Attie Spinka PhD	mrs.attie.spinka.phd@geemail.com	Berkeley	California	4456761216260	0739c7cbc963d4c1c48ef2385a8cb8fa	JCB 16 digit	37.8622223673112899	-122.252744491783545
7104	2019-12-15 19:56:58	2019-12-15	Cary Herzog	cary.herzog@warmmail.com	New York	New York	3778645623424842	af4fa346eba9e2480a1d2d88e0445d63	VISA 16 digit	40.6873085543736792	-73.9393100235506893
7105	2019-12-15 20:25:23	2019-12-15	Gerold Armstrong	gerold.armstrong@warmmail.com	San Francisco	California	4894137956633	582237fc83c66d95f2ace00111e07797	JCB 16 digit	37.7808466300497585	-122.431031580099145
7106	2019-12-15 21:12:53	2019-12-15	Dr. Vicy Leffler DDS	dr.vicy.leffler.dds@woohoo.com	Bakersfield	California	210063809231722909	a2c63a675447a68435953dd0b317add3	Voyager	35.2908896653156674	-119.096128673273327
7107	2019-12-15 21:25:09	2019-12-15	Ms. Kaylah Hickle MD	ms.kaylah.hickle.md@geemail.com	Pasadena	California	869939427921613675	c5cd133b7df79ba27f4e46d481ea353e	VISA 16 digit	34.2365229506365978	-118.159138552500309
7108	2019-12-15 21:29:26	2019-12-15	Clyda Runte DVM	clyda.runte.dvm@geemail.com	Akron	Ohio	3112214705010388888	bfae879920ca4ae5bc9b3a280ddb4bf2	JCB 16 digit	41.0937569527253501	-81.5232249026499716
7109	2019-12-15 22:22:11	2019-12-15	Mr. Acy Cummings	mr.acy.cummings@geemail.com	Fort Collins	Colorado	3012033893882729	b08c2404c24cbd3b85b9f61f6225b073	Mastercard	40.4541563743881909	-105.11455386569277
7110	2019-12-15 22:52:05	2019-12-15	Orland Orn	orland.orn@warmmail.com	College Station	Texas	4374375950095798	46b8c4127e0de74e9456665c18920cd7	American Express	30.6007416353140016	-96.3203456783514582
7111	2019-12-15 23:12:11	2019-12-15	Audrey Corkery	audrey.corkery@warmmail.com	Laredo	Texas	869904521461237878	11fa800157d99a7e15954128bf0cc929	American Express	27.6223467741809792	-99.5690726587090609
7112	2019-12-15 23:31:56	2019-12-15	Wenzel Bergstrom	wenzel.bergstrom@geemail.com	Columbia	South Carolina	180049365140228958	8e8ec19131c1e1e4d9e4c9bc657cae82	Diners Club / Carte Blanche	33.9916915520358813	-80.8662276066392565
7113	2019-12-16 01:56:13	2019-12-16	Miss Gaynell Dibbert DVM	miss.gaynell.dibbert.dvm@geemail.com	New York	New York	4863355302541622	2c58dafd474a1e5640016da20f8ddb2a	Discover	40.6300634994860701	-73.9750742303103124
7114	2019-12-16 02:13:30	2019-12-16	Roma Kihn	roma.kihn@geemail.com	Lancaster	California	180025744691698173	0f8fc0877ca3862dd77feef658de8b6e	Voyager	34.6768632213831012	-118.221447702354936
7115	2019-12-16 03:18:01	2019-12-16	Dr. Buna Simonis	dr.buna.simonis@warmmail.com	Inglewood	California	676282131255158	63fbd595fd56f9292038ec9b207ee9f8	Discover	34.0427654303390526	-118.341158867909769
7116	2019-12-16 03:45:12	2019-12-16	Mr. Tristian Koch	mr.tristian.koch@geemail.com	Louisville	Kentucky	501817559520733	b046b2a853c7a059f1e27ac38ec8957e	VISA 13 digit	38.2391076748628151	-85.6513021743927254
7117	2019-12-16 03:49:38	2019-12-16	Citlalli Keeling	citlalli.keeling@geemail.com	San Francisco	California	6011384226036991484	6f65198b4c17e657b7485f302932e38f	JCB 16 digit	37.7413786094092742	-122.436217240629333
7118	2019-12-16 04:04:03	2019-12-16	Takisha Stracke	takisha.stracke@geemail.com	San Francisco	California	4643287845496	b44c9f8b1f3fbd799f4e159bcda63842	JCB 16 digit	37.7878078523343603	-122.420796091756088
7119	2019-12-16 05:02:43	2019-12-16	Tanika Schiller-Grady	tanika.schiller.grady@geemail.com	San Francisco	California	3031429206001448	97e868baced01e01661d6a5266c65ccc	Diners Club / Carte Blanche	37.7844496413090383	-122.40248162894315
7120	2019-12-16 05:37:41	2019-12-16	Oneal Beatty	oneal.beatty@geemail.com	Stockton	California	869944969528625183	096ed783648ab71c78d260c95c0fd8e5	Mastercard	37.9839629897113937	-121.24368932001218
7121	2019-12-16 05:38:41	2019-12-16	Sylva Hudson	sylva.hudson@geemail.com	Thousand Oaks	California	869940269152809052	884bbfdc3cd232575c754ad519bd63b1	VISA 13 digit	34.203974820188435	-118.949150757017364
7122	2019-12-16 06:34:31	2019-12-16	Tavaris Deckow MD	tavaris.deckow.md@warmmail.com	Kansas City	Missouri	4705357744188	4098ab411ff45f5834a69394801f6dc6	VISA 13 digit	39.2018632082570377	-94.5428790146242903
7123	2019-12-16 08:01:44	2019-12-16	Burnett Wilderman	burnett.wilderman@geemail.com	Kansas City	Missouri	4613849277751	7a2618743e3d8863649b4425a9366e2b	Discover	39.1968613730579634	-94.6250545778069636
7124	2019-12-16 08:05:07	2019-12-16	Joye Howe	joye.howe@warmmail.com	San Francisco	California	3096674650057121110	3515d36b467bb91062595359504c41ae	JCB 16 digit	37.7614799422325902	-122.451819556649511
7125	2019-12-16 08:26:58	2019-12-16	Gustaf Pfeffer	gustaf.pfeffer@geemail.com	Chicago	Illinois	676304402392940	f3dca30bee0b0f08b98a1cc52daf8198	Maestro	41.9344871338293004	-87.7799869118288143
7126	2019-12-16 08:27:33	2019-12-16	Preston Kuvalis-Connelly	preston.kuvalis.connelly@woohoo.com	San Francisco	California	3096489126007655270	36fa4de3588139014ed1642af137c4f7	JCB 16 digit	37.7927681590479381	-122.443528753585767
7127	2019-12-16 09:35:28	2019-12-16	Tavon Weimann	tavon.weimann@geemail.com	Los Angeles	California	3528037536829772656	c22cf94dccdddf543e504da3d434ea66	Mastercard	34.065312030106405	-118.404113721287985
7128	2019-12-16 09:40:22	2019-12-16	Reese Kris III	reese.kris.iii@woohoo.com	San Francisco	California	3088523108786452671	0942840aabadaffd58f512b39447ba70	Maestro	37.7617083622933407	-122.411295818974509
7129	2019-12-16 09:53:40	2019-12-16	Ms. Rhiannon Farrell DDS	ms.rhiannon.farrell.dds@geemail.com	Fort Worth	Texas	4636344833869450	d53ead9f5c5f81c2ba0ea65562619f8b	Voyager	32.8803292243331668	-97.3701841589815871
7130	2019-12-16 09:54:07	2019-12-16	Adina Considine-O'Connell	adina.considine.o'connell@geemail.com	Indianapolis	Indiana	54182623986547577	4d4a8024ec35ce302e8ecc5a68e5504c	Diners Club / Carte Blanche	39.8761003784842742	-86.2113458983801308
7131	2019-12-16 10:08:38	2019-12-16	Osie Collins DDS	osie.collins.dds@warmmail.com	Fort Lauderdale	Florida	6011915631882708544	b3a1107b7abb6b5d817fee8e8d00dac1	Discover	26.2210605293501189	-80.0543633132994188
7132	2019-12-16 10:14:41	2019-12-16	Frederic Kemmer	frederic.kemmer@woohoo.com	Norfolk	Virginia	4646113450468013	5596a6015311a0ae3a5baf2ff3a4510d	VISA 16 digit	36.9964678748063776	-76.2544587147891519
7133	2019-12-16 10:18:07	2019-12-16	Harman Muller-Weimann	harman.muller.weimann@geemail.com	Simi Valley	California	55731275107972196	1931abaaf9c03e9b4cb35a499c05ccbf	JCB 15 digit	34.1902350554481131	-118.755682954438043
7134	2019-12-16 10:57:36	2019-12-16	Amaya Barrows PhD	amaya.barrows.phd@geemail.com	Albuquerque	New Mexico	4235333334415991	9dc65ade8ae3203e8bec176fe08c3e9a	Voyager	35.0562493691820691	-106.719281808247416
7135	2019-12-16 11:01:08	2019-12-16	Miss Hayley Fisher	miss.hayley.fisher@woohoo.com	San Francisco	California	3005110043183633	c325509aa90d3bb3c3c395d8c13be8e8	VISA 16 digit	37.7700440490688365	-122.438936145899348
7136	2019-12-16 11:41:21	2019-12-16	Brendon Ebert	brendon.ebert@geemail.com	San Francisco	California	4837859546011295	88a19e621a8d15c4722ec2fa9779f9cd	JCB 16 digit	37.7498403115242809	-122.426155378841202
7137	2019-12-16 12:11:14	2019-12-16	Lexi Boehm	lexi.boehm@woohoo.com	Madison	Wisconsin	3112908307699664506	68d59ffacd02fe4c39d9989fca28ecce	JCB 16 digit	43.1409370839104085	-89.376147562533248
7138	2019-12-16 12:18:25	2019-12-16	Aliana Weissnat	aliana.weissnat@geemail.com	Tulsa	Oklahoma	675924173891789	593f4b4f2fd392a32345340386348e97	VISA 16 digit	36.0510551953591403	-95.8869843249164546
7139	2019-12-16 12:22:53	2019-12-16	Jacquelyn Jenkins	jacquelyn.jenkins@geemail.com	San Francisco	California	55771115434142983	a671fa7501c41b6fa915e2ebe7b97ba7	Maestro	37.7865714404242183	-122.453270284079224
7140	2019-12-16 12:31:41	2019-12-16	Ms. Lynn Weber PhD	ms.lynn.weber.phd@warmmail.com	San Francisco	California	3528514541380534521	9ff2b86c107c7c6dbec8bd5288c647c2	American Express	37.7780847930632717	-122.420221374992266
7141	2019-12-16 12:42:38	2019-12-16	Harmony Krajcik	harmony.krajcik@woohoo.com	Boise	Idaho	210032457426805887	d839943accd55bc318ae75c611ee9c21	Diners Club / Carte Blanche	43.5261365103207538	-116.310008606613437
7142	2019-12-16 12:50:06	2019-12-16	Adriana Larkin-Dare	adriana.larkin.dare@warmmail.com	Akron	Ohio	869981741474339174	9192d82bc0f4b298bdaf149e30461420	Mastercard	41.1476895398292726	-81.4809052974764256
7185	2019-12-17 05:01:25	2019-12-17	Raina Johns	raina.johns@geemail.com	Mesa	Arizona	3096183003604930027	29b74e3c8fc02a12cccbcf10b862b34c	Mastercard	33.4407970826286771	-111.635320343531291
7143	2019-12-16 13:44:17	2019-12-16	Joseph Christiansen	joseph.christiansen@warmmail.com	Lubbock	Texas	675900962647301	e28d89564e9dc937be776b59c4492f05	Diners Club / Carte Blanche	33.6337068882346202	-101.940052938033645
7144	2019-12-16 13:53:33	2019-12-16	Darien Roberts	darien.roberts@geemail.com	Miami	Florida	3423690658964755	5a56393eb1783adf730126b5eb895a87	Voyager	25.7341983404614041	-80.2556732394140226
7145	2019-12-16 14:08:04	2019-12-16	Mrs. Loria Batz	mrs.loria.batz@geemail.com	Fort Worth	Texas	3337116783858737309	8817c7877434805ef94f1f73cc7679e7	JCB 16 digit	32.8802653742544351	-97.2488950065158235
7146	2019-12-16 14:51:17	2019-12-16	Dr. Billie Powlowski	dr.billie.powlowski@geemail.com	Mesquite	Texas	3499500301376589	33a8e384c7a508ab349ec38dcfbf2b2e	Discover	32.7848158513471475	-96.6173172861069531
7147	2019-12-16 14:54:14	2019-12-16	Zina Marquardt	zina.marquardt@warmmail.com	Abilene	Texas	3528637886768679329	afdba0d943c174bfe2b938dd45a3f908	JCB 16 digit	32.4272534481324257	-99.7787240835785951
7148	2019-12-16 14:57:34	2019-12-16	Rosina Stamm-Leffler	rosina.stamm.leffler@geemail.com	Berkeley	California	6011676174177154255	004dd7bed3ca731f8d428c66de9860e2	Diners Club / Carte Blanche	37.8695688981639123	-122.257288355540709
7149	2019-12-16 15:24:50	2019-12-16	Dr. Rand Zulauf	dr.rand.zulauf@warmmail.com	Cedar Rapids	Iowa	3096370070152539099	07cf852c446c309c632f1655ba3c7148	JCB 15 digit	41.9865743883028628	-91.6994956767719316
7150	2019-12-16 16:04:33	2019-12-16	Ms. Sally Nicolas DDS	ms.sally.nicolas.dds@warmmail.com	San Francisco	California	3112601980462684487	c627ff19e909b073aab3e7b629bb9543	Maestro	37.7435339185324068	-122.429512960063221
7151	2019-12-16 16:10:04	2019-12-16	Mr. Abner Abshire	mr.abner.abshire@woohoo.com	San Francisco	California	3030509758731590	645c2a80ebac845f42fd3b0d989fefab	American Express	37.7775824604362569	-122.413536700818867
7152	2019-12-16 16:51:19	2019-12-16	Keshaun Hansen	keshaun.hansen@woohoo.com	Glendale	Arizona	4183801369629647	46fa31bf684f9f37d89435b79f4fc584	JCB 16 digit	33.6263519427035007	-112.171014728050295
7153	2019-12-16 16:54:31	2019-12-16	Sophie Conn PhD	sophie.conn.phd@geemail.com	Alexandria	Virginia	676296803693074	5fb5654e3c1fed652c6dc8f07f1c44a6	VISA 16 digit	38.8230312600847327	-77.0433656535562221
7154	2019-12-16 16:56:20	2019-12-16	Johnna Rowe	johnna.rowe@geemail.com	Elizabeth	New Jersey	4382811492502917	585093ddaf0ed13bc40e2427afb403c9	Maestro	40.6031331752087965	-74.2246241334304244
7155	2019-12-16 16:56:27	2019-12-16	Ninnie Lehner	ninnie.lehner@geemail.com	Oakland	California	4066764656790	1db5efa71863b3417b6ceb45063ac259	JCB 16 digit	37.8231331181313024	-122.259371952199572
7156	2019-12-16 17:24:01	2019-12-16	Elaina Smith	elaina.smith@geemail.com	San Francisco	California	54631975440277952	00c0309f0fb51c5f14c3e55fcd0b5c5a	Mastercard	37.7798683571664284	-122.45899750279608
7157	2019-12-16 17:25:43	2019-12-16	Ms. Angelique Paucek	ms.angelique.paucek@woohoo.com	Yonkers	New York	6011665059150661413	1eb4ca6398356c6bb60b51f4e31b3bf6	VISA 13 digit	41.0116874154858309	-73.8379882975365973
7158	2019-12-16 18:25:31	2019-12-16	Mr. Kip Medhurst IV	mr.kip.medhurst.iv@woohoo.com	Salem	Oregon	180058776632353484	b26b2352631b6827854d9133c376b005	JCB 16 digit	44.9886578603450147	-123.106300722450769
7159	2019-12-16 19:34:00	2019-12-16	Kennth Cole	kennth.cole@geemail.com	Oakland	California	639033517959640	0a8ec3818aae7f613d25c3f70246c6be	Mastercard	37.7994132245009737	-122.278982680123022
7160	2019-12-16 20:04:56	2019-12-16	Mrs. Anona Jaskolski	mrs.anona.jaskolski@geemail.com	Downey	California	4375157394087378	98e976e03b56097680611cb67d846706	VISA 16 digit	33.9058462072413462	-118.056834820668769
7161	2019-12-16 20:10:00	2019-12-16	Zelia Brakus	zelia.brakus@geemail.com	Carlsbad	California	4642279382202202	af2aab11d829d43f7d4466a69dbd3a2b	Discover	33.0578886909816418	-117.201751450055454
7162	2019-12-16 20:46:52	2019-12-16	Maynard Weber	maynard.weber@geemail.com	Tucson	Arizona	869903721515294211	0eaefee8aa4785bf7e2171a21e4ccece	American Express	32.0556589273311232	-110.923869430715584
7163	2019-12-16 20:53:38	2019-12-16	Welton Torphy	welton.torphy@geemail.com	Grand Prairie	Texas	6011381022811787368	faa3241ed74b741fb34142f45b5f958b	Discover	32.6799312908254578	-97.0854604792188951
7164	2019-12-16 20:59:50	2019-12-16	Lanita Barrows	lanita.barrows@geemail.com	Jersey City	New Jersey	639071875386386	60238f1e372042803b473921300994ad	JCB 16 digit	40.7470278321705734	-74.1023864719506378
7165	2019-12-16 21:46:49	2019-12-16	Maralyn Heidenreich	maralyn.heidenreich@warmmail.com	Killeen	Texas	6011645605573568158	daa005dbf6ec1831faa38029e7736d1a	VISA 13 digit	31.0528711760647589	-97.8063245666380965
7166	2019-12-16 22:03:46	2019-12-16	Regena Roberts	regena.roberts@woohoo.com	Oakland	California	210039156970658659	0d37a8cf73359f035ebd8067555e814d	Mastercard	37.7949071624906168	-122.249946594193702
7167	2019-12-16 22:44:19	2019-12-16	Maribel Bailey	maribel.bailey@geemail.com	Minneapolis	Minnesota	6011168279536467846	2a412f1b01d9f701c72a772aa6f8bee4	Diners Club / Carte Blanche	44.9981348306957614	-93.2198139216557138
7168	2019-12-16 23:06:53	2019-12-16	Vella Walsh-Mayer	vella.walsh.mayer@geemail.com	Cambridge	Massachusetts	3528780620783697221	a12b832111eeab0ed5883d06a2e42165	JCB 16 digit	42.4453704714532947	-71.1372759564396091
7169	2019-12-16 23:38:46	2019-12-16	Justice Hayes	justice.hayes@geemail.com	Santa Ana	California	4537645385478	685c86a57cc2420e0127e42c0f7aef3d	American Express	33.7758648223813651	-117.810551701525227
7170	2019-12-16 23:48:03	2019-12-16	Kris Wehner	kris.wehner@woohoo.com	San Francisco	California	3497434634113646	8e5c97179f4115ffb0c29e9368a91682	VISA 16 digit	37.7325863343070793	-122.460746893811461
7171	2019-12-17 00:30:49	2019-12-17	Herminia Welch	herminia.welch@geemail.com	San Francisco	California	589371067159021	e253c401ffce8cb98250710ec25f9155	JCB 15 digit	37.7570070283670418	-122.411677071454989
7172	2019-12-17 00:49:36	2019-12-17	Shonda Walker	shonda.walker@geemail.com	El Paso	Texas	3528764085940211755	850e4f784e46dc70030699285fbfd447	Diners Club / Carte Blanche	31.9180824292186678	-106.437219191806392
7173	2019-12-17 01:12:34	2019-12-17	Idamae Conroy	idamae.conroy@geemail.com	San Francisco	California	3112989147257864003	da12165c61d0f4301b6afd867903b985	Maestro	37.8075192710692818	-122.423927039874712
7174	2019-12-17 01:19:05	2019-12-17	Ms. Nora Bernhard DDS	ms.nora.bernhard.dds@warmmail.com	Athens	Georgia	869909164694426789	0af67655711d32b66bcfefb2b5559456	VISA 16 digit	33.8626244883242933	-83.3281939707346169
7175	2019-12-17 01:29:47	2019-12-17	Rodney Schamberger	rodney.schamberger@geemail.com	Savannah	Georgia	3112003707675282625	a4092e5f4f791cad1467b246feca05f3	Voyager	31.9257730647083342	-81.0945758250694695
7176	2019-12-17 01:30:02	2019-12-17	Nathaly O'Reilly-Wolf	nathaly.o'reilly.wolf@geemail.com	Inglewood	California	869974928009783534	8c5fde58e67dc3469c86d57862f47697	Diners Club / Carte Blanche	33.9129629025015973	-118.307131819243736
7177	2019-12-17 02:07:01	2019-12-17	Dr. Ardyce Runolfsdottir	dr.ardyce.runolfsdottir@woohoo.com	Berkeley	California	3039793184979889	960863bfcb449c64d67fef8a6fb61af1	JCB 16 digit	37.8409416707022785	-122.269660180710687
7178	2019-12-17 02:21:25	2019-12-17	Denita Feeney-Lakin	denita.feeney.lakin@woohoo.com	San Antonio	Texas	3096314691532322952	6041518786a18d10fece181873a05a2d	American Express	29.557291240717845	-98.5585954117424734
7179	2019-12-17 02:24:20	2019-12-17	Zilpha Mertz	zilpha.mertz@geemail.com	San Francisco	California	54242656047230567	bff32ece47304b31ae7bc3b3f39bf4c1	Maestro	37.8020822347631977	-122.406838508076135
7180	2019-12-17 03:13:38	2019-12-17	Duke Cronin	duke.cronin@geemail.com	Columbus	Georgia	4383968111073172	4cd4bdf704501c4387eb47870441213a	VISA 16 digit	32.4698069016028157	-84.9626277347259133
7181	2019-12-17 03:43:35	2019-12-17	Mrs. Shaunna Kohler PhD	mrs.shaunna.kohler.phd@geemail.com	Tucson	Arizona	502012018114806	55dc0f9bcb47de6329a10071f678c9a0	VISA 16 digit	32.1154956292867695	-110.844380992813399
7182	2019-12-17 04:48:50	2019-12-17	Dr. Victoriano Champlin	dr.victoriano.champlin@geemail.com	San Francisco	California	4126312919546414	61a1aa44150916b433971cd3b0bcd9f4	VISA 16 digit	37.785848681547499	-122.448871005490503
7183	2019-12-17 04:51:56	2019-12-17	Sigrid Haag	sigrid.haag@woohoo.com	Atlanta	Georgia	4401480415470235	d7952a6e1a20bcc5246042d59e708bff	JCB 16 digit	33.7968463059324762	-84.3293033691167864
7186	2019-12-17 05:08:42	2019-12-17	Oral Lockman	oral.lockman@geemail.com	San Francisco	California	3112058744322943949	748c47de0d9759a2e3c0fff710f9d549	VISA 13 digit	37.7630735980051	-122.407984619691362
7187	2019-12-17 05:09:42	2019-12-17	Sarita Kub	sarita.kub@geemail.com	San Francisco	California	3112296649534119943	985f8596089d942a2d7a8d91152e6134	VISA 16 digit	37.7773769982065488	-122.44042206182371
7188	2019-12-17 05:21:29	2019-12-17	Jase Johns	jase.johns@geemail.com	Baton Rouge	Louisiana	869963142847491002	563ff2663d80f0ed12760e32629bf6f5	Mastercard	30.3577129359569398	-91.1513865374136714
7189	2019-12-17 05:23:03	2019-12-17	Worth Prohaska	worth.prohaska@geemail.com	San Francisco	California	210080894672723219	e8172b5d08faf3ada038d2923705a7c0	JCB 15 digit	37.7620939378725353	-122.407910713988755
7190	2019-12-17 05:46:58	2019-12-17	Dr. Micah Mohr MD	dr.micah.mohr.md@woohoo.com	San Francisco	California	3753311945318209	aa6199bf5a243df0307f6f6db04e26f9	JCB 16 digit	37.7367125027334041	-122.436591879660369
7191	2019-12-17 06:11:08	2019-12-17	Thornton Collins	thornton.collins@geemail.com	New York	New York	501874917283124	7f94be5d5946a0fb9b2cfa121710c365	Discover	40.7555466342940917	-73.970881843090794
7192	2019-12-17 06:22:18	2019-12-17	Mrs. Daisye Prosacco	mrs.daisye.prosacco@warmmail.com	Fairfield	California	180079355077579286	428f5c333bc95d68cfeaaa14b957d367	Discover	38.2604418224778087	-121.938729273574793
7193	2019-12-17 06:28:29	2019-12-17	Deacon Lubowitz	deacon.lubowitz@geemail.com	Berkeley	California	6011391559197205208	849069f4496bc5c7f31cc7e70a9cb0c4	JCB 16 digit	37.9093081229664435	-122.264997916478492
7194	2019-12-17 08:03:53	2019-12-17	Jayvion Harris	jayvion.harris@geemail.com	San Francisco	California	3158677571518559093	142ba4b70916d1cda3f788db89db84a8	American Express	37.7313612028700334	-122.43752148776575
7195	2019-12-17 08:19:49	2019-12-17	Immanuel Dickens Jr.	immanuel.dickens.jr.@geemail.com	New York	New York	180038754539549020	e486e85518e4a443cc9e56eb4f4976f3	JCB 16 digit	40.7348828911539158	-73.9842656131729512
7196	2019-12-17 08:21:55	2019-12-17	Mrs. Liberty Romaguera DDS	mrs.liberty.romaguera.dds@geemail.com	Honolulu	Hawaii	4261327693474968	1ff3830f97c6635127127ed2e0b4bcc6	JCB 16 digit	21.3689404186543079	-157.932102111701283
7197	2019-12-17 08:47:30	2019-12-17	Joe Gusikowski	joe.gusikowski@geemail.com	Miramar	Florida	3470483373174674	983b1d5addbf223f03bfd172c56d8953	American Express	26.0109745247270929	-80.4225942306678832
7198	2019-12-17 08:50:43	2019-12-17	Dr. Zeb Bauch Sr.	dr.zeb.bauch.sr.@geemail.com	Hialeah	Florida	3754919968533634	e294529353346b4a7f45918218f1a2a5	VISA 16 digit	25.7965094419639556	-80.2852950225021686
7199	2019-12-17 09:09:57	2019-12-17	Rafael Hegmann IV	rafael.hegmann.iv@geemail.com	Tucson	Arizona	676356213624424	7f0d2932b3c1c5f88e647373abe94bc3	Discover	32.1036979661364157	-110.786014281934499
7200	2019-12-17 09:17:35	2019-12-17	Rosendo Thiel	rosendo.thiel@warmmail.com	San Francisco	California	3096125931606414742	7824414cb6bea83e8dc09ba0c533abcd	VISA 13 digit	37.7685754822529631	-122.413076629369044
7201	2019-12-17 09:45:38	2019-12-17	Gary Barton	gary.barton@geemail.com	San Francisco	California	3158569824957410489	e4b9af480b7ee375f33fa4c77df1b7c4	JCB 15 digit	37.7709112781311518	-122.449855839348302
7202	2019-12-17 09:49:44	2019-12-17	Rosaline Towne	rosaline.towne@woohoo.com	Davie	Florida	869982146944146713	df07e8915521a26141dc5bd57c67297a	American Express	26.1400077957458805	-80.3521185285318609
7203	2019-12-17 09:50:47	2019-12-17	Keara Emard DDS	keara.emard.dds@woohoo.com	Berkeley	California	6011314390747653331	21e836c498a41696cfda038476d811df	VISA 16 digit	37.8609275354141701	-122.283233700319784
7204	2019-12-17 09:51:16	2019-12-17	Maggie Konopelski	maggie.konopelski@geemail.com	New York	New York	4281922740607416	af043c33524cbc843672f92037d2bc34	Maestro	40.6716086753401882	-73.8410443745914762
7205	2019-12-17 10:41:06	2019-12-17	Mazie Wisozk	mazie.wisozk@geemail.com	San Francisco	California	210097561422283049	0ef2a544000902972e524cb0618c5203	JCB 16 digit	37.814734191593665	-122.414628507479961
7206	2019-12-17 11:19:23	2019-12-17	Lue Schaefer	lue.schaefer@woohoo.com	San Francisco	California	869983780680043764	01bf6e4754723114561dce09770de670	Voyager	37.8259530686140053	-122.413542123060907
7207	2019-12-17 11:41:47	2019-12-17	Domonique Dooley	domonique.dooley@geemail.com	Virginia Beach	Virginia	54774157652461999	6bac45405b418a14a5b6a0b72c156c6e	JCB 16 digit	36.8749041963554944	-75.9691915690571022
7208	2019-12-17 11:57:33	2019-12-17	Lessie Baumbach	lessie.baumbach@geemail.com	Atlanta	Georgia	3025865306803363	435bb67018e7d4f98e403fa9ec41810e	VISA 16 digit	33.8107638622444142	-84.3583605280656457
7209	2019-12-17 12:09:59	2019-12-17	Haskell Lang MD	haskell.lang.md@warmmail.com	Chicago	Illinois	4545938030620051	1e417c89fdccbec9aff6f39707ce409f	JCB 16 digit	41.8977759133860488	-87.7371346023894745
7210	2019-12-17 13:13:07	2019-12-17	Ermine Hintz	ermine.hintz@geemail.com	Phoenix	Arizona	210016598894712806	6cd0ea9ecc4c6383ee873fd536732076	Maestro	33.4915407869432116	-112.06149288559557
7211	2019-12-17 13:22:04	2019-12-17	Riley Wintheiser PhD	riley.wintheiser.phd@geemail.com	Las Vegas	Nevada	210030446592866064	7314b2630c73d17e97f935f59458bf7d	VISA 16 digit	36.1987273583754856	-115.258781259946886
7212	2019-12-17 14:19:38	2019-12-17	Alberta Fahey PhD	alberta.fahey.phd@geemail.com	Tulsa	Oklahoma	3096027302007420556	93044801a94280b324a1f315ae8f5f81	Voyager	36.0354495139229982	-95.9982563163109148
7213	2019-12-17 14:28:20	2019-12-17	Bud Johnston	bud.johnston@geemail.com	Laredo	Texas	869931475259236617	9e8890158e168ab5dc1c2021e88fe665	Maestro	27.594855855563285	-99.5185173584621339
7214	2019-12-17 14:49:53	2019-12-17	Minna Bernhard	minna.bernhard@geemail.com	Boston	Massachusetts	3337237181355879951	2ead0069c08d223f856d1c04877fea7d	Diners Club / Carte Blanche	42.4250712302215405	-70.9395917992524829
7215	2019-12-17 15:39:27	2019-12-17	Kyrie Heaney	kyrie.heaney@geemail.com	Atlanta	Georgia	3003094826951386	6e4175a1035cc2e3222c02f32ffccef0	American Express	33.7509279341246966	-84.3227519690103833
7216	2019-12-17 15:50:05	2019-12-17	Juston Legros	juston.legros@woohoo.com	Wichita	Kansas	3705673325699436	19d7f2bcff26ea147cde82e18f413bef	VISA 13 digit	37.6775178629316372	-97.3299880307834542
7217	2019-12-17 16:17:29	2019-12-17	Hollie Harvey-Schmeler	hollie.harvey.schmeler@woohoo.com	Killeen	Texas	3469086865924945	11530fb50e09c2867cf04b4bda372d79	VISA 13 digit	31.1475712577112027	-97.7917613079007708
7218	2019-12-17 18:00:06	2019-12-17	Megan Roob	megan.roob@geemail.com	Chesapeake	Virginia	4367742656388026	abd020513137075774d2495e4975c04a	JCB 16 digit	36.5972430779837055	-76.2376474893029723
7219	2019-12-17 18:16:38	2019-12-17	Reno Kertzmann	reno.kertzmann@geemail.com	Oakland	California	4340357813076232	85d7928b0ded8f446a58c5984e936c64	Diners Club / Carte Blanche	37.7648026772731598	-122.267814811391929
7220	2019-12-17 18:24:41	2019-12-17	Mr. Winnie Dach	mr.winnie.dach@woohoo.com	Fort Worth	Texas	869946840887290638	b502c9c903f348b5b3a5eaa25ac8b71e	VISA 16 digit	32.7369845266044166	-97.4374577285077379
7221	2019-12-17 18:25:53	2019-12-17	Otho Becker	otho.becker@geemail.com	Mesa	Arizona	3051725543440516	b92016d78d526a1fb0e10490d1491c68	JCB 16 digit	33.4551310975249834	-111.81394622045346
7222	2019-12-17 18:59:43	2019-12-17	Seamus Kuvalis IV	seamus.kuvalis.iv@geemail.com	Los Angeles	California	3444427997625051	9e3b14a0a3aaa184ebd2bff36917d786	VISA 16 digit	34.048980127447841	-118.414715319312364
7223	2019-12-17 19:14:00	2019-12-17	Mrs. Kayley Runolfsson	mrs.kayley.runolfsson@geemail.com	Paterson	New Jersey	6011984063452222365	431970aef8d92658fd0e17763004089a	VISA 16 digit	40.8558371961537716	-74.120284184671192
7224	2019-12-17 19:15:36	2019-12-17	Mrs. Elisa Halvorson MD	mrs.elisa.halvorson.md@geemail.com	Toledo	Ohio	3045220687627116	ba3374b6ac394526d2ce8671aebb3d58	VISA 16 digit	41.6658501818016163	-83.5529410884581551
7225	2019-12-17 19:23:56	2019-12-17	Durward Kuhic PhD	durward.kuhic.phd@warmmail.com	New York	New York	3158040783214946934	ae06f5c0767d2eb01b73d29cd1695845	JCB 15 digit	40.7218709324710062	-73.8704188468761771
7226	2019-12-17 19:55:58	2019-12-17	Cory Marquardt	cory.marquardt@warmmail.com	Albuquerque	New Mexico	869959865791765171	08afcc2c9cce0ebefe97afaf9161a9ae	JCB 16 digit	35.1174510996922891	-106.550651682221897
7227	2019-12-17 20:13:58	2019-12-17	Wilfred Gutmann Jr.	wilfred.gutmann.jr.@geemail.com	Chula Vista	California	54915657356947581	f2aff3be28c114c31264bba9a889a61f	VISA 16 digit	32.5978790538616465	-116.970068447734036
7228	2019-12-17 20:24:43	2019-12-17	Rachael Reinger	rachael.reinger@geemail.com	San Francisco	California	4513657659068	11cb42aed49da09f8f2cf2f439577034	JCB 16 digit	37.7978031929421689	-122.420206530822099
7229	2019-12-17 20:27:00	2019-12-17	Ephriam Tromp III	ephriam.tromp.iii@geemail.com	Sterling Heights	Michigan	4127231606048	3afa849711cc927d9d4b41241b16aedc	VISA 16 digit	42.5507584054104981	-82.9948426253322538
7230	2019-12-17 20:43:55	2019-12-17	Mrs. Cathey Schowalter	mrs.cathey.schowalter@warmmail.com	San Francisco	California	6011594963272749046	01953e529c13d2bebab16ec3bc177ee5	Voyager	37.7396437915475147	-122.429636220599278
7231	2019-12-17 20:56:33	2019-12-17	Mr. Jerrell White	mr.jerrell.white@geemail.com	St. Louis	Missouri	3337712796920739325	57e685bd9a7ca32e3cbcfc835ec2a386	VISA 16 digit	38.6664748286519213	-90.2815237546343354
7232	2019-12-17 21:01:30	2019-12-17	Phoenix Will	phoenix.will@geemail.com	Portland	Oregon	6011796591984585931	3acab45ac6bd5c9f1d251f312076e155	Diners Club / Carte Blanche	45.576716092543677	-122.555753997573632
7233	2019-12-17 21:12:53	2019-12-17	Harlon Wilkinson V	harlon.wilkinson.v@geemail.com	Allentown	Pennsylvania	3781889867941336	fc5b8134c12ecbd76ad9d5c81bcd0553	VISA 13 digit	40.5428365051992259	-75.5430067622117605
7234	2019-12-17 21:32:51	2019-12-17	Stetson Weber IV	stetson.weber.iv@geemail.com	Charlotte	North Carolina	4505657532980	449080521975edb4e41f0f74a73e8b45	Voyager	35.2606681533411148	-80.8762707851305578
7235	2019-12-17 22:05:05	2019-12-17	Alto Legros	alto.legros@woohoo.com	San Francisco	California	4284407284561432	28a49014fe31488a93e96212b821a6cb	VISA 16 digit	37.73112273935498	-122.45572268932203
7236	2019-12-17 22:06:23	2019-12-17	Rosalie Carter MD	rosalie.carter.md@warmmail.com	Bakersfield	California	3491188335636877	ba0df443c41b437ae642d6c6df3dad77	JCB 15 digit	35.3892917885620122	-119.105670453961196
7237	2019-12-17 22:12:07	2019-12-17	Allisson Olson	allisson.olson@warmmail.com	Greensboro	North Carolina	869970604320365582	e63f5e442cf6016b237e939ec6709afc	JCB 15 digit	36.041483001562213	-79.7426226496677799
7238	2019-12-17 22:24:45	2019-12-17	Zavion Gutkowski II	zavion.gutkowski.ii@geemail.com	San Antonio	Texas	3488073729262297	53642d141c0edbd8d91429b41a1fa5d8	JCB 16 digit	29.5561301700841632	-98.4731107728391777
7239	2019-12-17 22:28:51	2019-12-17	Jedidiah Kassulke-Hauck	jedidiah.kassulke.hauck@geemail.com	Corpus Christi	Texas	3112411447157400777	bce1d856f76928006d4491f741dc1da8	JCB 16 digit	27.7623316369887441	-97.1581871271427673
7240	2019-12-17 22:42:12	2019-12-17	Santana Huels PhD	santana.huels.phd@geemail.com	Escondido	California	51006076183598113	b02d1b6030008f32a652e75585228c52	VISA 16 digit	33.1665722095169144	-117.033779642708595
7241	2019-12-17 23:15:54	2019-12-17	Dr. Dixon Haag V	dr.dixon.haag.v@geemail.com	Houston	Texas	6011460197147246182	1d0bba634f9b51229a9c32f9c13640f6	Mastercard	29.7219282116353511	-95.4244573165211847
7242	2019-12-18 00:15:56	2019-12-18	Shawn Mohr	shawn.mohr@geemail.com	Long Beach	California	3088632494321238173	7abfa300596be8aeb311504f6feab4d5	American Express	33.8422529797822236	-118.147980957168343
7243	2019-12-18 00:18:17	2019-12-18	Mrs. Floretta Williamson	mrs.floretta.williamson@warmmail.com	San Francisco	California	6011570814727154282	60bfea08d2fb0ef71d900b483863eb26	Mastercard	37.7836126252544275	-122.434261420760947
7244	2019-12-18 00:18:36	2019-12-18	Lucia Hickle	lucia.hickle@geemail.com	Killeen	Texas	3088362059400133763	8bed857143c193d207e126919a19ac54	Mastercard	30.9844364303860829	-97.731324708245694
7245	2019-12-18 01:02:21	2019-12-18	Uriel Smitham	uriel.smitham@geemail.com	Fort Collins	Colorado	6011513062702237934	e9457d3325ff28bb726849369cfe9974	JCB 16 digit	40.4973656252183005	-105.035590030155333
7246	2019-12-18 01:27:47	2019-12-18	Travis Howe	travis.howe@geemail.com	Dallas	Texas	3052071279668957	49fd93f948a91cfe72aba911ee8ac6d5	VISA 16 digit	32.8695673608493095	-96.7604738768152828
7247	2019-12-18 01:43:36	2019-12-18	Stanford Turner	stanford.turner@geemail.com	San Francisco	California	180087075112777493	e2927fd854da04e42b01827582a21e7a	Voyager	37.7530540449688417	-122.440098386182285
7248	2019-12-18 02:06:59	2019-12-18	Elia Gorczany	elia.gorczany@warmmail.com	San Francisco	California	54467950111234482	69c74f825f5968e043b63db7e04767a3	JCB 16 digit	37.7617492828941508	-122.419744901676211
7249	2019-12-18 02:14:35	2019-12-18	Jamya Wisoky	jamya.wisoky@geemail.com	Detroit	Michigan	210070412851275778	86835bb7ba6d5e41eee474a90b9eea57	JCB 16 digit	42.3752343489248346	-83.1729812820561136
7250	2019-12-18 02:16:16	2019-12-18	Charline Feest	charline.feest@warmmail.com	Berkeley	California	4592890220797	b9a1b41ea85431e24014feffc7d4c439	Mastercard	37.9020289777105859	-122.264981658521563
7251	2019-12-18 02:17:37	2019-12-18	Gracia Balistreri	gracia.balistreri@geemail.com	Davenport	Iowa	630465545774542	650e86ca96dd6d5f7721858db276ea80	VISA 13 digit	41.5406126735996466	-90.5259249124638785
7252	2019-12-18 02:36:46	2019-12-18	Leontine Abshire	leontine.abshire@geemail.com	San Francisco	California	3740850222929911	3c1dc6bbb1e8f7563da6f32229b6b337	JCB 16 digit	37.7644697910400566	-122.432243900762685
7253	2019-12-18 02:50:35	2019-12-18	Odalis Hamill	odalis.hamill@geemail.com	Oklahoma City	Oklahoma	3402380964678183	8ae2ce89fedb24e6a2f7808c25582f36	JCB 15 digit	35.4810334658160826	-97.5995543931506546
7254	2019-12-18 02:51:21	2019-12-18	Mrs. Leafy Cummerata PhD	mrs.leafy.cummerata.phd@geemail.com	Roseville	California	3096509081537582351	2014ab5071192b9cfdc95a44415d8a57	VISA 16 digit	38.8380697320736914	-121.396756482006609
7255	2019-12-18 03:09:40	2019-12-18	Thomasina McClure	thomasina.mcclure@geemail.com	San Francisco	California	6011425706215585786	0ac8d244ab99729e88bf4871f7743b1f	American Express	37.7674679019278159	-122.446692480148798
7256	2019-12-18 03:37:24	2019-12-18	Dr. Adam Corkery	dr.adam.corkery@geemail.com	Gainesville	Florida	3112299919485638200	4f9e9ff6e432df737037481634e6ba51	JCB 15 digit	29.6255714586295191	-82.4394259285520832
7257	2019-12-18 04:16:54	2019-12-18	Delbert Eichmann	delbert.eichmann@geemail.com	San Francisco	California	6011710760742567175	5107e12bf75ff877f8029c4ce54d91b6	VISA 16 digit	37.7935789848525587	-122.424547372187519
7258	2019-12-18 04:31:26	2019-12-18	Jordan Smith DVM	jordan.smith.dvm@geemail.com	Atlanta	Georgia	210003677094395722	02517171ee287ec0253b96e66d4729f8	VISA 16 digit	33.6687515200857064	-84.4636398984629722
7259	2019-12-18 04:44:40	2019-12-18	Hester Wolff-Wisoky	hester.wolff.wisoky@woohoo.com	San Diego	California	4992767823591148	b3ee62ed758052429a69cd76ac02a79e	JCB 16 digit	32.8345723764572313	-117.082402843786411
7260	2019-12-18 04:47:59	2019-12-18	Maximilian Leffler	maximilian.leffler@woohoo.com	San Francisco	California	4799478554817075	3a7e3cc08f5b46d9819302f180190495	Maestro	37.7584308715798045	-122.449168113985394
7261	2019-12-18 05:10:56	2019-12-18	Estela Larkin	estela.larkin@geemail.com	Los Angeles	California	3470605893956582	a4f9a65148719b47f2d417526a1ceafe	Mastercard	34.0921967581711698	-118.413536421348525
7262	2019-12-18 05:25:02	2019-12-18	Hollie Murray	hollie.murray@woohoo.com	Irvine	California	3483927610196010	6e7d87a25cb241bb8945e60d6423ca5d	JCB 16 digit	33.6652940752465284	-117.726471338003122
7263	2019-12-18 05:35:59	2019-12-18	Dr. Everette Rippin III	dr.everette.rippin.iii@warmmail.com	Tulsa	Oklahoma	869909430238478242	be20d2e361dd5b903e760ed2ad573714	Voyager	36.14386513097174	-95.9861043310679491
7264	2019-12-18 05:49:09	2019-12-18	Codey Greenfelder	codey.greenfelder@geemail.com	San Diego	California	3112769338711261086	b3c227d26ea6b65c2550c43d01e4d0da	VISA 13 digit	32.8131406540583797	-117.234406717577954
7265	2019-12-18 06:30:52	2019-12-18	Dr. Zaiden Corwin II	dr.zaiden.corwin.ii@geemail.com	San Diego	California	52775413620221307	1733372aa42390b1868ad545d75ba6da	VISA 16 digit	32.8129112844422437	-117.165053114239129
7266	2019-12-18 07:43:29	2019-12-18	Nataly Batz	nataly.batz@geemail.com	San Francisco	California	3088961620307818064	eec317aff3c18103ee4d4e4f3d7dd962	VISA 16 digit	37.7879585006543905	-122.421384510830876
7267	2019-12-18 07:47:58	2019-12-18	Mr. Tanner Beer	mr.tanner.beer@geemail.com	Phoenix	Arizona	869984885374260407	ca10bc451ee78997e7a896cfafc51834	JCB 15 digit	33.5638569566819811	-112.059612042496354
7268	2019-12-18 08:24:06	2019-12-18	Shelly Moore	shelly.moore@geemail.com	Greeley	Colorado	6011551540426598304	904f7a999299167602aeb30118f9198d	Discover	40.4198009999070322	-104.824200567819929
7269	2019-12-18 08:27:11	2019-12-18	Effa Cummings	effa.cummings@warmmail.com	Oklahoma City	Oklahoma	869994790687592736	c17eda1d000b0221764c4da57e86b541	VISA 16 digit	35.421889935285229	-97.5048490011494664
7270	2019-12-18 08:31:55	2019-12-18	Giles Swaniawski	giles.swaniawski@geemail.com	San Francisco	California	3088734403854304135	0145dbb657eb303af854695067462600	Voyager	37.7420125458805273	-122.421181162813596
7271	2019-12-18 08:32:39	2019-12-18	Ira Kovacek	ira.kovacek@warmmail.com	Kansas City	Kansas	501897663494637	3a8b1d543aca5c4eaf987f30f60fedc9	Maestro	39.0847634622268387	-94.7773452551506495
7272	2019-12-18 09:13:07	2019-12-18	Dr. Deja Lueilwitz DVM	dr.deja.lueilwitz.dvm@geemail.com	San Jose	California	3001974090351839	c33371dbb8b3114aa40d80d489d913f3	VISA 13 digit	37.2327343422740711	-121.857663801986348
7273	2019-12-18 09:20:01	2019-12-18	Garfield Goldner-Dooley	garfield.goldner.dooley@geemail.com	San Antonio	Texas	4930198970858384	1773308d193318ae86a65771854645c4	VISA 16 digit	29.3891211282998341	-98.5893138704657446
7274	2019-12-18 09:31:33	2019-12-18	Dr. Frances Brown I	dr.frances.brown.i@geemail.com	Dallas	Texas	3337201139513762859	4a95643e3d9f2b3a51ced8b46d3e5e7e	VISA 16 digit	32.8070989395763775	-96.7007991756275231
7275	2019-12-18 09:37:42	2019-12-18	Miss Jacquline Tromp	miss.jacquline.tromp@geemail.com	San Francisco	California	210034412158878378	20687895b5439d017f786416a1f4291f	JCB 16 digit	37.7598748588238635	-122.449216684049929
7276	2019-12-18 09:41:42	2019-12-18	Odie Marks-Brekke	odie.marks.brekke@geemail.com	Costa Mesa	California	4177953627678599	5d8ce569580443d7eb0560e6bd78c6bc	JCB 16 digit	33.7185454102713607	-117.976288558575519
7277	2019-12-18 09:46:07	2019-12-18	Mrs. Buelah Walter	mrs.buelah.walter@geemail.com	West Covina	California	3410766581525270	bc24c89a48c09529c217b91cd65bcfd2	VISA 13 digit	34.0396234188336919	-117.810396361684042
7278	2019-12-18 09:54:18	2019-12-18	Ms. Jaelyn Rosenbaum DDS	ms.jaelyn.rosenbaum.dds@geemail.com	Phoenix	Arizona	4546587226745245	1580372337d6405679f60ed6149c059a	JCB 16 digit	33.5931407552611105	-112.07123480661997
7279	2019-12-18 09:57:53	2019-12-18	Sue Kiehn	sue.kiehn@geemail.com	Philadelphia	Pennsylvania	639068218371810	a82d1ed8cdd0c6179266cb2295a38107	VISA 16 digit	39.9791224332951032	-75.0623370168164428
7280	2019-12-18 10:04:41	2019-12-18	Trina Zboncak-Johnson	trina.zboncak.johnson@geemail.com	Saint Paul	Minnesota	3787812230888418	1dd86a350f1260b967eba0919fef0088	JCB 16 digit	44.9413613178242031	-93.1824771243412044
7281	2019-12-18 10:10:08	2019-12-18	Arman Rath	arman.rath@geemail.com	Reno	Nevada	210077459292343403	405f29b62c6ebf15c2ed2092f138f109	VISA 16 digit	39.540297597188875	-119.902258038257813
7282	2019-12-18 11:45:32	2019-12-18	Miss Fronnie Strosin	miss.fronnie.strosin@woohoo.com	San Francisco	California	3088830753997744552	0d7f49b0b4b4c9240092ac6cae47ec04	Diners Club / Carte Blanche	37.7852568727513685	-122.430798127050011
7283	2019-12-18 11:53:08	2019-12-18	Valentine O'Hara	valentine.o'hara@geemail.com	Winston–Salem	North Carolina	3038454051579119	d76b4d34dbe3e949aeb4b01a0325a00c	Diners Club / Carte Blanche	36.1092597141627181	-80.2579089694321084
7284	2019-12-18 12:10:52	2019-12-18	Daren Glover	daren.glover@warmmail.com	Oakland	California	3112677405075260698	019393f53ed67d338309ce0028528466	JCB 15 digit	37.8055447883377624	-122.303688346471617
7285	2019-12-18 12:12:06	2019-12-18	Ms. Linna Witting	ms.linna.witting@geemail.com	San Francisco	California	3722356266877364	3c1d84e4f40a41d9ae847091f1ba480f	JCB 16 digit	37.7679831389798224	-122.438290561766209
7286	2019-12-18 13:33:39	2019-12-18	Hadley Aufderhar	hadley.aufderhar@geemail.com	Detroit	Michigan	4476828451289028	f14b5d4300430ca6b71c4c849aa4e508	JCB 16 digit	42.3332937120851156	-83.064834551897647
7287	2019-12-18 13:36:43	2019-12-18	Miss Tristen Sipes	miss.tristen.sipes@woohoo.com	Killeen	Texas	060443399909829	5f97773e8279be48aa2fd301c68b32d6	Maestro	31.1764617738544949	-97.7050723012704339
7288	2019-12-18 13:47:24	2019-12-18	Miss Clementina Conn	miss.clementina.conn@woohoo.com	Irvine	California	3112311403710681818	fd2ee3bbe4feb3b8fcbfd820fa1c9da2	American Express	33.7295735971085762	-117.770292955777791
7289	2019-12-18 14:06:37	2019-12-18	Mr. Guss Carter	mr.guss.carter@woohoo.com	Columbus	Georgia	3337423891202008638	9f1b8f8cf8f8779e5debacd3fbcb33fb	JCB 16 digit	32.5121517232198229	-84.8305969413533774
7290	2019-12-18 14:26:39	2019-12-18	Janet Volkman	janet.volkman@geemail.com	San Francisco	California	4316725396327471	e9042dfd950029da50025afd47ea1808	Discover	37.7878421107214848	-122.443002675078148
7291	2019-12-18 14:51:42	2019-12-18	Cosmo Waters	cosmo.waters@geemail.com	Jersey City	New Jersey	869934850080455395	9aa670235781bac7882d4dd4c14e0c95	JCB 15 digit	40.7085003633458129	-74.0810153396289905
7292	2019-12-18 14:54:32	2019-12-18	Ivie Weissnat MD	ivie.weissnat.md@geemail.com	Memphis	Tennessee	210086699067461000	b88da4957da098cacd2a32f7e10401e9	Maestro	35.0913801856406025	-90.0127356167208461
7293	2019-12-18 15:38:23	2019-12-18	Joaquin Gutmann	joaquin.gutmann@geemail.com	Pasadena	California	3158545246151880912	c34f136eccc4c7e173b7658559a34dff	Mastercard	34.0764254815731249	-118.063684491934623
7294	2019-12-18 15:38:30	2019-12-18	Aubree Leannon	aubree.leannon@warmmail.com	Long Beach	California	869913181355356653	17b5de3e08528aaf3cd6ee9f9e90ce42	Voyager	33.8383658189147667	-118.239283393386003
7295	2019-12-18 15:46:41	2019-12-18	Randall Nitzsche	randall.nitzsche@geemail.com	Downey	California	210008172936140861	844b2ca6c75a8ee13a7136e0dc0ba944	Diners Club / Carte Blanche	33.9171440803695461	-118.120232689205181
7296	2019-12-18 16:27:56	2019-12-18	Karen Dare	karen.dare@woohoo.com	Antioch	California	675929294681886	d06653408912ad404b391fc26bc298c7	Maestro	38.0397703405268501	-121.873288604867454
7297	2019-12-18 16:35:38	2019-12-18	Bebe Koelpin	bebe.koelpin@woohoo.com	Berkeley	California	4467471410689	60f4442bfd0aefd342ac13adb39d70a9	VISA 13 digit	37.8920835329977592	-122.276346836700526
7298	2019-12-18 17:30:19	2019-12-18	Dr. Javen Satterfield II	dr.javen.satterfield.ii@geemail.com	Tempe	Arizona	3158824562596520612	12487ee5c3a7f3264184f5c8a025f2da	Diners Club / Carte Blanche	33.4686873602602617	-111.896158282182355
7299	2019-12-18 17:44:48	2019-12-18	Keeley Leuschke DDS	keeley.leuschke.dds@warmmail.com	Tallahassee	Florida	3496062653606850	e2b4a5b389721299c0b25cbbe93f82c5	Discover	30.4496390203502045	-84.3211531324326984
7300	2019-12-18 17:57:13	2019-12-18	Nevaeh Daniel	nevaeh.daniel@geemail.com	Ventura	California	3096581159764899788	bc605a4cc429a2a2e253515139e2fbbf	JCB 16 digit	34.3509098032649618	-119.262888239054746
7301	2019-12-18 17:59:22	2019-12-18	Pinkey Waters-Koepp	pinkey.waters.koepp@woohoo.com	San Francisco	California	3016966445171750	7b4a57b9c21fa7afeeef96afa166d350	VISA 13 digit	37.7724449442291643	-122.411966139050165
7302	2019-12-18 18:28:07	2019-12-18	Mr. Liston Dibbert DDS	mr.liston.dibbert.dds@geemail.com	Baltimore	Maryland	4401783515205926	1164ff88a8fc7a4e21a288d1ed433331	VISA 16 digit	39.2427725251298369	-76.5919366881735613
7303	2019-12-18 19:02:45	2019-12-18	Oscar McLaughlin	oscar.mclaughlin@geemail.com	Sunnyvale	California	869956129884064296	a3ded0c0863fd65df70b926a5b3f314d	VISA 16 digit	37.4119870385147664	-121.927168966570136
7304	2019-12-18 19:06:46	2019-12-18	Nicholas Leuschke	nicholas.leuschke@geemail.com	San Francisco	California	3337581821189646686	a3e73a9a9486adf947be7a7c7fc2f7cc	VISA 16 digit	37.7603343376704075	-122.432696281860061
7305	2019-12-18 19:15:25	2019-12-18	Dr. Shyheim Altenwerth Jr.	dr.shyheim.altenwerth.jr.@geemail.com	Los Angeles	California	869991462215403652	353050adbda8ce6c721dd6de7ff1c12b	American Express	34.0177920821454336	-118.442534056491397
7306	2019-12-18 19:25:29	2019-12-18	Mallorie Raynor-Kshlerin	mallorie.raynor.kshlerin@geemail.com	Berkeley	California	502013010031360	f963eab4c62b033a96c0a8c8679668c8	Mastercard	37.8515909667785166	-122.28388272884898
7307	2019-12-18 19:41:01	2019-12-18	Malinda Goodwin	malinda.goodwin@geemail.com	North Las Vegas	Nevada	869902633028639660	b7d5b044a31332e0777c3899131a3a30	Discover	36.253860562915726	-115.1867569813259
7308	2019-12-18 19:50:35	2019-12-18	Mildred Conn	mildred.conn@geemail.com	Austin	Texas	53754240172113516	e438e9acecab3d403c4c3531745a7264	VISA 16 digit	30.2535902591548833	-97.8458360665250666
7309	2019-12-18 20:07:06	2019-12-18	Noel Klocko	noel.klocko@woohoo.com	Tucson	Arizona	3794765297989779	243d1839adb70cbc4610ea1f04518c8d	Mastercard	32.0998497931793381	-110.773333568055548
7310	2019-12-18 20:56:23	2019-12-18	Mrs. Darian Johnston DDS	mrs.darian.johnston.dds@warmmail.com	Pearland	Texas	3337642164230918060	36e2c2fce46386b616dcd1a8b2a20647	Discover	29.5907570729769773	-95.3317064541246708
7311	2019-12-18 21:23:51	2019-12-18	Lavona Kub-Hamill	lavona.kub.hamill@woohoo.com	Roseville	California	3112405094127965006	04cfa037155504097eb56922e978b563	Mastercard	38.8119907736368432	-121.258654698332393
7312	2019-12-18 21:48:54	2019-12-18	Finis Herman-Simonis	finis.herman.simonis@geemail.com	Antioch	California	3528429309733890451	7b0bd5b9fa2438e5e6b7ab14b24d3eed	American Express	38.0749076315000679	-121.718358513544132
7313	2019-12-19 00:05:48	2019-12-19	Ewin O'Connell-Gleason	ewin.o'connell.gleason@woohoo.com	Oakland	California	869933920521964692	749dd7f409048f9466b3d68295853767	Voyager	37.8194757203043608	-122.260783066323285
7314	2019-12-19 00:32:51	2019-12-19	Ailene Mosciski-Beatty	ailene.mosciski.beatty@geemail.com	Atlanta	Georgia	6011167486784492951	4c59e07ceaea823ac8b5bdcd4b127b5b	Maestro	33.751822007335349	-84.4951581067916067
7315	2019-12-19 00:48:24	2019-12-19	Ossie Gibson	ossie.gibson@geemail.com	Detroit	Michigan	210004446711715327	1cdba8eaef6489ee19f59db0a624a6fd	JCB 15 digit	42.2949285127148045	-83.0719059269994489
7316	2019-12-19 01:38:59	2019-12-19	Mr. Marco Wyman MD	mr.marco.wyman.md@warmmail.com	Phoenix	Arizona	4570928630773	66dea2340451daf58976d3c8705638c3	VISA 16 digit	33.5943761895809345	-112.017598581307013
7317	2019-12-19 01:44:29	2019-12-19	Carmel Blanda	carmel.blanda@geemail.com	Berkeley	California	4882595458798354	2faf5bc7ea2c651fc64090c0ea239730	JCB 15 digit	37.9191208500891079	-122.275642541524505
7318	2019-12-19 01:49:42	2019-12-19	Dr. Earnest Hansen	dr.earnest.hansen@geemail.com	Durham	North Carolina	51409628799953414	063067592b8cb6803a47d747a2034dec	JCB 16 digit	35.9080557599443893	-78.9079378383137282
7319	2019-12-19 01:58:12	2019-12-19	Ms. Kristen Jacobi	ms.kristen.jacobi@geemail.com	Berkeley	California	060446359986414	91e6782e201ef8efdb274050c7776c68	Maestro	37.8566748738024188	-122.286343270709253
7320	2019-12-19 02:22:06	2019-12-19	Cleta Jenkins	cleta.jenkins@warmmail.com	San Francisco	California	4594186423861	dacd213a43b3140235835030e7f38440	JCB 16 digit	37.7821372363570021	-122.417106181889196
7321	2019-12-19 02:38:37	2019-12-19	Margaretta Ruecker	margaretta.ruecker@geemail.com	Milwaukee	Wisconsin	6011886895198179105	4bd1d93f324225ffe347be368eff9fcb	VISA 16 digit	43.156165881556646	-87.9087450237114041
7322	2019-12-19 02:57:25	2019-12-19	Vicy McLaughlin	vicy.mclaughlin@geemail.com	Lexington	Kentucky	3022769913285753	a1e9a101c0e723e7204514de4da5e1ca	Mastercard	37.9458777790300559	-84.4963769604351285
7323	2019-12-19 03:06:28	2019-12-19	Kristie Wolf	kristie.wolf@warmmail.com	Tucson	Arizona	3088380636895761568	345046e111c0bcf982449c98a12fcd5b	Diners Club / Carte Blanche	32.174793151956429	-110.860317476349323
7324	2019-12-19 03:23:30	2019-12-19	Annamarie Dicki	annamarie.dicki@geemail.com	Henderson	Nevada	180081703700291793	49e18cf598b5d26d24a72dd959a3e67c	Maestro	35.9542930067449831	-115.042504546434444
7325	2019-12-19 04:18:40	2019-12-19	Kasen Schuster	kasen.schuster@geemail.com	Overland Park	Kansas	3497422554739961	c860db37a5d29836300e400bebafa251	VISA 16 digit	38.8509130757171661	-94.6722298769321355
7326	2019-12-19 04:25:19	2019-12-19	Jermaine Koelpin	jermaine.koelpin@geemail.com	Indianapolis	Indiana	3721476958625441	1d3eb08b9befe8cbe00eba854158192b	JCB 15 digit	39.7910215538933869	-86.1876045419570005
7327	2019-12-19 04:27:57	2019-12-19	Alpha Leuschke	alpha.leuschke@warmmail.com	Henderson	Nevada	869966202936675480	3eeb6a2a8eadeb27cb4620110bf395d7	VISA 16 digit	36.0721451784882703	-115.126818717379876
7328	2019-12-19 04:30:25	2019-12-19	Miss Lia Dibbert	miss.lia.dibbert@geemail.com	San Francisco	California	4885131272792758	3d8afc1c243d76cc29332cdf7fcdc3bf	Mastercard	37.7746316934372857	-122.42456799208577
7329	2019-12-19 04:33:05	2019-12-19	Esco Bartell	esco.bartell@geemail.com	Portland	Oregon	55065568613989613	f4334a4bb8fe53ed7cb6f43075eaa1dd	VISA 16 digit	45.5660115040726978	-122.693567072460439
7330	2019-12-19 05:10:48	2019-12-19	Mr. Louie Gutmann	mr.louie.gutmann@geemail.com	Oakland	California	3088290784060402193	278e63d10d42963c629184bc75c5d459	JCB 16 digit	37.8064721828101042	-122.30041333116354
7331	2019-12-19 05:32:05	2019-12-19	Powell Leffler	powell.leffler@geemail.com	Oakland	California	4506759518159983	17bd027df91659d6f413b65cf7f27eb5	VISA 13 digit	37.7766866302212208	-122.285720191024794
7332	2019-12-19 06:03:22	2019-12-19	Pattie Considine PhD	pattie.considine.phd@geemail.com	Peoria	Illinois	675974921664491	63b68599782fd97e8e43b202ed83a3a3	JCB 16 digit	40.744012691579762	-89.5732086320292211
7333	2019-12-19 06:11:05	2019-12-19	Mr. Earl Jones	mr.earl.jones@geemail.com	San Francisco	California	53818761400933494	98008805c337245e2039cebc300ad4fa	VISA 13 digit	37.7826386036414945	-122.420772725744854
7334	2019-12-19 06:30:05	2019-12-19	Justina Walker	justina.walker@geemail.com	Seattle	Washington	51150523174775980	1d97a6fd975b897da8506281f464069b	VISA 16 digit	47.6104876611772951	-122.277240745761986
7335	2019-12-19 06:32:07	2019-12-19	Dr. Dagmar Armstrong	dr.dagmar.armstrong@warmmail.com	Sacramento	California	3046568335350906	62680d5acacac9bb0a999b866b9db284	Diners Club / Carte Blanche	38.5214068138305095	-121.501176710265128
7336	2019-12-19 07:39:42	2019-12-19	Dayne Schmidt	dayne.schmidt@geemail.com	Lexington	Kentucky	6011227732971548917	0689d78334e7653f98d45d3bf3362d31	Maestro	37.9734979908790464	-84.5110548812795344
7337	2019-12-19 07:45:39	2019-12-19	Ms. Margaretta Harber MD	ms.margaretta.harber.md@geemail.com	Wichita	Kansas	3465487045641355	39b3d67e27f8a1b71d91844cfd1e9c90	VISA 16 digit	37.7747056245680923	-97.3443640039969296
7338	2019-12-19 08:10:43	2019-12-19	Cleva Schneider	cleva.schneider@geemail.com	Houston	Texas	3014068123859442	48656dc474d4391c1fc434c717e7313d	Discover	29.8452227974854409	-95.4531158685699097
7339	2019-12-19 08:31:35	2019-12-19	Santos Mayert	santos.mayert@geemail.com	San Francisco	California	676256822318236	75e71ce067be5e3bb8f611024cae31de	VISA 16 digit	37.8000586336074917	-122.420225996851812
7340	2019-12-19 08:46:48	2019-12-19	Miss Josefina Jenkins DVM	miss.josefina.jenkins.dvm@geemail.com	San Francisco	California	6011531669983367012	72ead4a28b2439cfde0f511c4ac671fe	VISA 16 digit	37.7641955752035159	-122.464311125510505
7341	2019-12-19 09:01:10	2019-12-19	Mr. Destry Mueller MD	mr.destry.mueller.md@geemail.com	Berkeley	California	4367428590854154	365232f73f0a5de36696ce48cdbdf453	American Express	37.8630133287198447	-122.29578074659041
7342	2019-12-19 09:16:22	2019-12-19	Demarcus Romaguera	demarcus.romaguera@geemail.com	Henderson	Nevada	4685874153685961	20f78ca2de94821bf9183a221f81bfb4	JCB 15 digit	36.0257260498058045	-114.96610025928058
7343	2019-12-19 11:04:38	2019-12-19	Shardae Brekke-Kuvalis	shardae.brekke.kuvalis@warmmail.com	Mesa	Arizona	4146097039297552	55f2f2e8d134c2d9820f885795f6e3b9	Mastercard	33.3233028250426031	-111.635801230173186
7344	2019-12-19 12:36:15	2019-12-19	Kamryn Lynch	kamryn.lynch@warmmail.com	San Francisco	California	4988844987307367	8c90518ce728163cbce3899f0b0502b9	Diners Club / Carte Blanche	37.8094835892284564	-122.485434544534968
7345	2019-12-19 12:42:49	2019-12-19	Samuel Weber	samuel.weber@woohoo.com	Tuscaloosa	Alabama	180001488844520508	3cb0485aa3531351dc9632a6ae7f1eb1	Diners Club / Carte Blanche	33.2798320375904453	-87.5173188894618335
7346	2019-12-19 12:52:30	2019-12-19	Brandy Kassulke	brandy.kassulke@geemail.com	San Francisco	California	3337529410453157805	53bb3096e142f49112ddfe3a0958973e	Maestro	37.7992837282730605	-122.399902442440776
7347	2019-12-19 12:56:09	2019-12-19	Dr. Francisco Pollich	dr.francisco.pollich@geemail.com	Yonkers	New York	4950878582397708	4d6501223f98e6087d5c6d6fc3475de8	JCB 16 digit	40.944405511460829	-73.7905449780054425
7348	2019-12-19 13:08:28	2019-12-19	Hampton Schinner III	hampton.schinner.iii@woohoo.com	San Francisco	California	4675758244361	276458586fcb258fd6dd4d681ed6ec4d	Voyager	37.7949160845579328	-122.397974209212251
7349	2019-12-19 13:52:07	2019-12-19	Maryann Lynch	maryann.lynch@geemail.com	Virginia Beach	Virginia	869946513874631722	7c4e274cdb7b65cdc0bb5d66ca6a73b9	VISA 16 digit	36.7966789763607096	-76.1129724313177149
7350	2019-12-19 13:55:08	2019-12-19	Mr. Max Roberts Jr.	mr.max.roberts.jr.@geemail.com	Mesa	Arizona	6011750132025110084	6d0aef98e0a2da47f516bcd914daa3b9	VISA 16 digit	33.3641080092318347	-111.663852089026562
7351	2019-12-19 14:19:48	2019-12-19	Dayton Prohaska	dayton.prohaska@geemail.com	Corpus Christi	Texas	180018483812487344	832782f58b70bb8a3db2255282919800	Voyager	27.8172634456243379	-97.2398287314750291
7352	2019-12-19 14:58:18	2019-12-19	Jamir Deckow-Buckridge	jamir.deckow.buckridge@geemail.com	Nashville	Tennessee	210072696650875964	ff9da567e68acaeff7c67a3fa3690f8b	Mastercard	36.183615558932722	-86.86988305001519
7353	2019-12-19 15:22:33	2019-12-19	Reginald Hermiston	reginald.hermiston@woohoo.com	New York	New York	6011290263049580619	b0953f89755a708710ee2b68e0407bca	JCB 15 digit	40.5663951433487213	-73.9516190502222628
7354	2019-12-19 15:51:10	2019-12-19	Kayli Koepp	kayli.koepp@geemail.com	Berkeley	California	4658549721965813	a1acfac6324e9e385714193baad8de4a	VISA 16 digit	37.8421687854213786	-122.279479371875638
7355	2019-12-19 16:01:24	2019-12-19	Mr. Hermon Legros PhD	mr.hermon.legros.phd@geemail.com	Anchorage	Alaska	210074211987295098	a394ec9a8636487dcef7fef610694b30	American Express	61.2657231200236865	-149.360276387271654
7356	2019-12-19 16:03:17	2019-12-19	Dr. Lucious Treutel	dr.lucious.treutel@geemail.com	Berkeley	California	3528181685450805535	0928092d764d232b4e88d706b9e401dd	Diners Club / Carte Blanche	37.8834657879971246	-122.227588037490733
7357	2019-12-19 16:34:51	2019-12-19	Mr. Math Cormier IV	mr.math.cormier.iv@geemail.com	New York	New York	6011799704553822885	b9f8b21ca8f20e45be2cc06c83132ead	Maestro	40.6143703280240302	-73.91288834003619
7358	2019-12-19 16:37:29	2019-12-19	Jordan Waters	jordan.waters@geemail.com	St. Petersburg	Florida	3112147327327126943	d76db348605d2b6bab43e77fc68b6516	American Express	27.807352114876732	-82.6234912830296793
7359	2019-12-19 16:50:13	2019-12-19	Dr. Cicero Zboncak I	dr.cicero.zboncak.i@geemail.com	Los Angeles	California	6011509015391531724	7e0ebe82e441f314670db0784cbb2b70	VISA 16 digit	33.9461664179671558	-118.497565742395068
7360	2019-12-19 16:51:02	2019-12-19	Anya Quigley-Mosciski	anya.quigley.mosciski@geemail.com	Sterling Heights	Michigan	676374858733756	f7f32edd3032ddbccd52137d9de8cc21	Diners Club / Carte Blanche	42.5769435957621809	-82.9848459019951434
7361	2019-12-19 17:12:07	2019-12-19	Sawyer Barton	sawyer.barton@geemail.com	San Francisco	California	210043557754331336	655640ff620d12b84d37274d65f9079b	VISA 13 digit	37.8145363037985618	-122.4528039390256
7362	2019-12-19 18:27:45	2019-12-19	Cristina Wisoky-Goldner	cristina.wisoky.goldner@woohoo.com	Santa Clarita	California	3032092607928962	4c7566c2b6de672f15757265b4de623b	VISA 16 digit	34.3039690237231554	-118.446911968393991
7363	2019-12-19 18:58:00	2019-12-19	Winifred Schumm	winifred.schumm@geemail.com	Louisville	Kentucky	3337069262962814640	3ec4a9a96cdcaf8c6da055d54960d1b6	American Express	38.2373152591191214	-85.7112757905457272
7364	2019-12-19 20:51:56	2019-12-19	Sibbie Lubowitz-Waters	sibbie.lubowitz.waters@warmmail.com	New York	New York	3042114120185894	397bb6b2548fa576a2452c0ffb5f1e6a	Mastercard	40.5923932153023799	-73.8622730167012662
7365	2019-12-19 20:54:59	2019-12-19	Shaniece Lueilwitz	shaniece.lueilwitz@geemail.com	Albuquerque	New Mexico	4077105308918	1db3e6f332a3b478a698c2bce4ff1adf	Voyager	35.0292263302154865	-106.715153759212797
7366	2019-12-19 21:01:07	2019-12-19	Giada Kozey	giada.kozey@geemail.com	McAllen	Texas	869918383286634290	166f24a005ba30d7acabe0c3a5e4581d	Discover	26.1895469325900052	-98.1590750101800893
7367	2019-12-19 21:01:21	2019-12-19	Redden Labadie Sr.	redden.labadie.sr.@geemail.com	San Francisco	California	503835501839076	6034dcbf7833975a7d1404642898f562	JCB 16 digit	37.7832330651385391	-122.412497507739872
7368	2019-12-19 21:08:24	2019-12-19	Errol Yost	errol.yost@geemail.com	Nashville	Tennessee	869989328519296916	93d386743885a1ff767d064f3cb5b477	VISA 13 digit	36.2340340431436871	-86.7398272023908703
7369	2019-12-19 21:14:26	2019-12-19	Jayden Schamberger	jayden.schamberger@geemail.com	Clinton	Michigan	180015070640342404	4b23ce162e8e824e786cb2f8e7926ad0	Maestro	42.6273712932664921	-82.8848246979136007
7370	2019-12-19 21:17:54	2019-12-19	Erasmus Morar-Lynch	erasmus.morar.lynch@warmmail.com	Portland	Oregon	4355260536303259	ce2937ba3e8b2857d20f9e9d22b1cab8	VISA 16 digit	45.5657988999858503	-122.695544607657951
7371	2019-12-19 21:57:11	2019-12-19	Demetrios Russel	demetrios.russel@geemail.com	Philadelphia	Pennsylvania	210048031241443406	eb187a2ab52125732722c61f82fcc40e	JCB 15 digit	39.9804496507119396	-75.1644380923260087
7372	2019-12-19 22:27:16	2019-12-19	Kelley Bayer	kelley.bayer@geemail.com	Clarksville	Tennessee	3051368234741239	553885aa118be754836539ae4cf2e058	VISA 16 digit	36.5702339645136192	-87.4247351024717148
7373	2019-12-19 22:41:25	2019-12-19	Elwyn Ondricka	elwyn.ondricka@geemail.com	San Diego	California	3158209259721865997	e71cd4d4da071befa16fc098e898f6fd	VISA 16 digit	32.8113635853000005	-117.18574444552884
7374	2019-12-19 22:55:35	2019-12-19	Casen Ruecker	casen.ruecker@geemail.com	St. Louis	Missouri	4927945916436161	99a8bf8eb4bffb21fa58fc5a680b4d80	Maestro	38.624107215103507	-90.2468048788610844
7375	2019-12-19 23:14:44	2019-12-19	Braiden Daniel	braiden.daniel@geemail.com	Oklahoma City	Oklahoma	3791728392761983	17c06d47ff129e44fb511504fb08e028	VISA 16 digit	35.5648111869026025	-97.4336348714202671
7376	2019-12-19 23:15:02	2019-12-19	Toya Volkman	toya.volkman@woohoo.com	Berkeley	California	3023198986448354	8c6b317f5e488499745e8fbddacd8793	JCB 16 digit	37.8784158543881233	-122.280938586607036
7377	2019-12-20 01:19:00	2019-12-20	Vincent Wilderman	vincent.wilderman@geemail.com	San Francisco	California	3009332847669056	b63d94d07f8318107e5cfe04fd238478	American Express	37.7734408236799268	-122.469079174698336
7378	2019-12-20 01:51:54	2019-12-20	Lauryn Kulas	lauryn.kulas@geemail.com	Toledo	Ohio	3337944114489236727	e02a7056cba83531ab13ddbbba16b80e	Diners Club / Carte Blanche	41.6807279587894683	-83.5897245693352176
7379	2019-12-20 02:49:06	2019-12-20	Racquel Schultz-Bosco	racquel.schultz.bosco@geemail.com	Jacksonville	Florida	4222368010138	4141c10e4206230f5299ef7487e52f07	Mastercard	30.2834130019001648	-81.6902162505392084
7380	2019-12-20 03:25:25	2019-12-20	Buddie Sanford-Ward	buddie.sanford.ward@warmmail.com	San Francisco	California	3018021553945757	0a1918d7a8166795056f50895c5beba0	JCB 16 digit	37.7968721786058239	-122.452030825771047
7381	2019-12-20 03:34:41	2019-12-20	Orrie Wolff	orrie.wolff@warmmail.com	San Francisco	California	4027980610438238	b1b89291e6c5f2376861fb6bf6e7a64e	American Express	37.7683873581248051	-122.393721949962739
7382	2019-12-20 03:46:57	2019-12-20	Ambers Shanahan	ambers.shanahan@woohoo.com	Irvine	California	6011743288792024963	bb2acb401c09156912099b828acde35f	VISA 16 digit	33.7160691404730102	-117.712543104496973
7383	2019-12-20 03:53:57	2019-12-20	Elliott Howe	elliott.howe@geemail.com	San Francisco	California	3112226127070170567	6a2e2737f592df057b008fba57a996be	VISA 13 digit	37.7415633770393697	-122.409081842239061
7384	2019-12-20 04:02:28	2019-12-20	Mrs. Kelcie Feil DVM	mrs.kelcie.feil.dvm@warmmail.com	New York	New York	4098239457173	ffd7211f9ca0d8bdcb7fc67705731d8a	American Express	40.6815226552300118	-73.9635292732052534
7385	2019-12-20 04:16:08	2019-12-20	Lexie Boyle	lexie.boyle@geemail.com	San Francisco	California	4481736129699085	c25c07f041e269609b69016a67259376	Discover	37.7645140585779444	-122.429985203192757
7386	2019-12-20 04:56:44	2019-12-20	Imo Ritchie	imo.ritchie@woohoo.com	Winston–Salem	North Carolina	180064331212004115	7b5b1613b0c9c5e3ef8bce8d6062b9c3	Discover	36.0981941924195695	-80.2743831492159501
7387	2019-12-20 05:49:56	2019-12-20	Ms. Shyann Bernier	ms.shyann.bernier@geemail.com	Philadelphia	Pennsylvania	3158186551699115729	c6a0edb2e40434a44e08d759cc2b7268	VISA 16 digit	39.9186088243458386	-75.1211489791881348
7388	2019-12-20 06:00:50	2019-12-20	Carri Larson	carri.larson@geemail.com	Stockton	California	55472251737233039	cfe12b851c63d4459bc4fd8a9dfd7650	VISA 13 digit	38.0412106989614713	-121.245694007267431
7389	2019-12-20 06:04:56	2019-12-20	Kaitlyn Hills PhD	kaitlyn.hills.phd@woohoo.com	San Francisco	California	4890017019526	44e64fafbd94f06a783f127fa9b7d49a	VISA 16 digit	37.769082887183302	-122.42192423971288
7390	2019-12-20 06:45:05	2019-12-20	Ivah Hauck DDS	ivah.hauck.dds@geemail.com	Albuquerque	New Mexico	676372701731092	eba17f75b4d043b6098a400ab5d4ad62	VISA 13 digit	35.140073209269346	-106.586570767553155
7391	2019-12-20 07:12:15	2019-12-20	Rahn Ruecker	rahn.ruecker@geemail.com	Columbus	Ohio	180096931335134582	75fdeb253c94cd301ae39dc655555e37	JCB 15 digit	40.0095477365933334	-83.0622858101736767
7392	2019-12-20 07:12:26	2019-12-20	Harve Cummerata	harve.cummerata@geemail.com	Miami	Florida	676323423399072	ff5d4949231c29ff71bbd001ce716b42	American Express	25.8382505679640921	-80.3035505346827279
7393	2019-12-20 07:42:00	2019-12-20	Dewey Gibson	dewey.gibson@woohoo.com	Los Angeles	California	4644152550735915	9d92442995cf192b7a4a1b6391420453	Discover	34.0637253676872689	-118.489600051007415
7394	2019-12-20 08:31:13	2019-12-20	Lia Mohr	lia.mohr@geemail.com	Phoenix	Arizona	3036051302920803	3755a6eeb3cde8a3aa71bb5c29bc758e	Mastercard	33.4884000357173406	-112.086704175213725
7395	2019-12-20 08:47:24	2019-12-20	Wilmer Goldner-Dooley	wilmer.goldner.dooley@geemail.com	San Jose	California	4365363448807967	6276ae0cd08a212f4bedc7eddbd3c435	Diners Club / Carte Blanche	37.3793198309659971	-121.800070092104008
7396	2019-12-20 08:50:04	2019-12-20	Dr. Tiarra Batz DDS	dr.tiarra.batz.dds@warmmail.com	Wichita Falls	Texas	6011159047236474730	d58125a081b88011f213a224814b8568	JCB 16 digit	33.9345207173105337	-98.4922947078399318
7397	2019-12-20 08:55:47	2019-12-20	Hortencia Blanda-Tromp	hortencia.blanda.tromp@geemail.com	Oakland	California	3337331293385285912	7a85fdd5af6819b7820a2dcc0bbdcda8	Diners Club / Carte Blanche	37.8091748467831863	-122.275461987026787
7398	2019-12-20 09:00:10	2019-12-20	Deforest Quitzon	deforest.quitzon@geemail.com	San Francisco	California	869986486985502994	da3e814e1f0e70fe537a16449b9bb6f1	American Express	37.7584645060668294	-122.4555307025188
7399	2019-12-20 09:45:39	2019-12-20	Gussie Zemlak V	gussie.zemlak.v@warmmail.com	Port St. Lucie	Florida	4113865101043	9b5cc8126d7c871f45aa22e092cf5195	American Express	27.1827125394850952	-80.4430419316601046
7400	2019-12-20 09:48:01	2019-12-20	Janae Turner-Koelpin	janae.turner.koelpin@geemail.com	Phoenix	Arizona	3158995634450492270	61e47ce58bb439a884b117ccaebd8a66	JCB 16 digit	33.5483260449886345	-112.055916129557801
7401	2019-12-20 09:49:35	2019-12-20	Cindy Paucek PhD	cindy.paucek.phd@geemail.com	Fresno	California	589327907092822	af489f45bb22894dfcd5f2c25bfdb0e6	American Express	36.8686263590924455	-119.807932143529513
7402	2019-12-20 10:22:42	2019-12-20	Crista Abernathy PhD	crista.abernathy.phd@geemail.com	San Francisco	California	6011736712353982938	83c5630368e6cbe4f629bd58ad09e672	VISA 13 digit	37.7856993906543224	-122.40139889470241
7403	2019-12-20 10:34:54	2019-12-20	Berta Langosh	berta.langosh@woohoo.com	Long Beach	California	4789032035964	333b3c463c366da17a8b1f0fa3117bef	VISA 16 digit	33.888291050243005	-118.15495010765008
7404	2019-12-20 11:31:54	2019-12-20	Eunice Stark	eunice.stark@geemail.com	San Francisco	California	55398843432915695	d6324f68fc1e03fa34b113f0b1907b77	Maestro	37.787189747968938	-122.408285410380714
7405	2019-12-20 11:35:08	2019-12-20	Garland Pagac	garland.pagac@geemail.com	San Francisco	California	3022496669532929	08a371c5a0cb88e861ceb6eb5be79228	VISA 16 digit	37.7513706020428472	-122.392704630016652
7406	2019-12-20 11:51:56	2019-12-20	Jeffie Langworth V	jeffie.langworth.v@geemail.com	Surprise	Arizona	4740208358429599	1eaa66774cdb24235ef605800f9ec660	Maestro	33.6619636322133218	-112.46973317398205
7407	2019-12-20 12:03:45	2019-12-20	Garnet Goldner	garnet.goldner@warmmail.com	San Francisco	California	3411425456707856	9a85cdea6f11651ef6e9ddb2463bc528	VISA 13 digit	37.7584861403509393	-122.412116454385142
7408	2019-12-20 12:17:32	2019-12-20	Katie Gaylord	katie.gaylord@geemail.com	San Francisco	California	3096273306697299460	30890a0309f7e698663dc6bb5aff4297	JCB 15 digit	37.764107843506352	-122.38574466011697
7409	2019-12-20 12:26:01	2019-12-20	Margurite Davis DDS	margurite.davis.dds@geemail.com	Colorado Springs	Colorado	3088627536598450068	1618342332b8216dfa18e7863b40057f	Diners Club / Carte Blanche	38.9192994562957466	-104.748695070731273
7410	2019-12-20 13:14:46	2019-12-20	Ms. Layla Bednar	ms.layla.bednar@warmmail.com	San Francisco	California	3025530840873799	1fb239f3405758b145aa879b71780953	JCB 15 digit	37.7705315957610779	-122.435680148701465
7411	2019-12-20 13:32:56	2019-12-20	Ms. Maranda Von	ms.maranda.von@geemail.com	Lubbock	Texas	4323065971125045	75fe8e3e63412bc6782df9edaf07710c	Discover	33.5402748412493636	-101.89711792868637
7412	2019-12-20 14:02:22	2019-12-20	Hunter Watsica PhD	hunter.watsica.phd@geemail.com	Seattle	Washington	3016608800137709	9c37834513e92149e7be28385fe2341b	VISA 16 digit	47.5496829049121601	-122.295368567846339
7413	2019-12-20 14:37:43	2019-12-20	Griffin Grant	griffin.grant@geemail.com	Anaheim	California	3428236671426151	99304a48a33050303ac952200e2e7103	JCB 15 digit	33.8128818051256204	-117.768846269205582
7414	2019-12-20 14:52:28	2019-12-20	Gustav Berge	gustav.berge@geemail.com	San Francisco	California	869971997571515700	0c2d960ebf770d3aa5e55f6d5af7e85f	JCB 16 digit	37.7761368082987445	-122.400136108752307
7415	2019-12-20 15:20:34	2019-12-20	Kandy Kunze	kandy.kunze@warmmail.com	San Francisco	California	4557747913239730	c13b01d05cd6b2076f62fd5f2021c6b8	Voyager	37.7885295182494474	-122.435590931457924
7416	2019-12-20 15:50:15	2019-12-20	Alanzo Marvin	alanzo.marvin@geemail.com	Colorado Springs	Colorado	3088235122367377156	63a50eed174050881f02e8f214f5f520	JCB 15 digit	38.8035379173748183	-104.836807038510969
7417	2019-12-20 16:20:41	2019-12-20	Darrel Schmitt	darrel.schmitt@woohoo.com	Fresno	California	53101889156482444	030df598649ed4b2bdb99a204757f869	JCB 16 digit	36.7252267101652947	-119.81226284854263
7418	2019-12-20 16:47:55	2019-12-20	Blanche Huels	blanche.huels@warmmail.com	Irvine	California	3000680318008611	54ecd8682a08ab6eac70398dd4afa474	VISA 16 digit	33.6349422083251213	-117.870880889428037
7419	2019-12-20 17:03:32	2019-12-20	Nickolas Stanton-Cummings	nickolas.stanton.cummings@woohoo.com	Lubbock	Texas	3158665239397788332	edbffaeb1cc5b6efe765b52325f1c816	JCB 16 digit	33.5483332860790213	-101.925284073586397
7420	2019-12-20 17:10:18	2019-12-20	Almus Gerlach-Effertz	almus.gerlach.effertz@geemail.com	San Diego	California	4126730063110879	b96020fa1543565271f6d0e835c51bb4	Discover	32.9147048391468857	-117.201655761050063
7421	2019-12-20 17:29:24	2019-12-20	Merrie Altenwerth-Hickle	merrie.altenwerth.hickle@woohoo.com	Philadelphia	Pennsylvania	3763936442430806	6bff416217416bb96ad23b9fffb3a034	Diners Club / Carte Blanche	40.0923999713692822	-75.0677639333430733
7422	2019-12-20 17:34:18	2019-12-20	Gladys Lebsack	gladys.lebsack@geemail.com	Peoria	Arizona	3158958673436245860	206d85f12138ae960fa256489ef18b9e	JCB 16 digit	33.7696801820572503	-112.326739781156192
7423	2019-12-20 17:44:06	2019-12-20	Durrell Batz	durrell.batz@woohoo.com	San Francisco	California	6011345176902686684	1df59e61967a610ff54ff2796f78aedf	Voyager	37.7725554567402284	-122.461189477214461
7424	2019-12-20 17:44:52	2019-12-20	Antoine Olson MD	antoine.olson.md@geemail.com	San Francisco	California	869929971337364474	aa68b0c6735a37098b3e1e5dff4f6295	Maestro	37.7684536069341235	-122.428472196403433
7425	2019-12-20 17:50:37	2019-12-20	Miss Dolly Rempel	miss.dolly.rempel@warmmail.com	New York	New York	869978328836406381	0886b7b53763577811e3097a5c56a2a1	JCB 15 digit	40.5933802637495091	-73.9329287319339841
7426	2019-12-20 18:04:36	2019-12-20	Champ Turner	champ.turner@geemail.com	El Paso	Texas	561278297384337	e1558496642ced5e1c9000eb0ecd3007	Diners Club / Carte Blanche	31.8017262265846163	-106.51641470715218
7427	2019-12-20 18:07:51	2019-12-20	Dr. Kegan Watsica Sr.	dr.kegan.watsica.sr.@geemail.com	Baton Rouge	Louisiana	51754197663388215	af9e6df66e42beed1065698343a3a694	Mastercard	30.3433247689370056	-91.1485044578198256
7428	2019-12-20 18:26:17	2019-12-20	West Weber	west.weber@geemail.com	Saint Paul	Minnesota	210061044901481097	c6b8adae1d6e900fbe144a846f59ad98	Mastercard	44.9867193088807156	-93.0068020922396386
7429	2019-12-20 18:29:27	2019-12-20	Odus Kreiger	odus.kreiger@woohoo.com	Berkeley	California	4114004741912260	bea085860716c681a8cce8b2358a527a	JCB 16 digit	37.8467936663085354	-122.272129726060683
7430	2019-12-20 19:40:07	2019-12-20	Miss Porsha Smitham	miss.porsha.smitham@geemail.com	San Francisco	California	3018910998686879	5a8bc181a8bc11538c67d617b219f69d	JCB 16 digit	37.8204607221491713	-122.443411981749719
7431	2019-12-20 20:09:27	2019-12-20	Miss Star Ebert	miss.star.ebert@woohoo.com	Phoenix	Arizona	6011904024495370527	870075f0fef0faeda4f3ccb4e768dda1	Discover	33.4769627997584678	-112.001395295692987
7432	2019-12-20 20:14:48	2019-12-20	Cleola Kunde	cleola.kunde@geemail.com	San Francisco	California	869947964687925497	842619b9ddd932a8dfdde4c0f16337bb	Discover	37.7569500871126209	-122.433888046156071
7433	2019-12-20 21:08:19	2019-12-20	Pratt VonRueden	pratt.vonrueden@geemail.com	San Francisco	California	3449756306846791	e0e2c37030036364ef3aec838cf16c07	Maestro	37.7719738512403254	-122.414027788763903
7434	2019-12-20 21:54:00	2019-12-20	Madeline McKenzie	madeline.mckenzie@geemail.com	Minneapolis	Minnesota	4660710719254	c11837f98c05a7e52e3abb29af14ab42	VISA 13 digit	44.9081550275061261	-93.2917695993829454
7435	2019-12-20 21:54:05	2019-12-20	Michel O'Connell	michel.o'connell@geemail.com	Berkeley	California	4191824279060083	7dbf50eaff556184a25b9be7938e4699	JCB 16 digit	37.8899444241374113	-122.265449324843573
7436	2019-12-20 22:00:37	2019-12-20	Antione Trantow	antione.trantow@geemail.com	San Antonio	Texas	3044275956553972	968098fd9286d5f38ad96c349b0dc5ca	VISA 16 digit	29.4829704575311382	-98.483304469038174
7437	2019-12-20 22:08:08	2019-12-20	Toney Bernier	toney.bernier@woohoo.com	Tallahassee	Florida	6011097474558314796	65700f2dfd83692bb9441c2094f98f8b	VISA 13 digit	30.4606091220885524	-84.3307329672403654
7438	2019-12-20 22:16:25	2019-12-20	Mr. Elzie Robel	mr.elzie.robel@geemail.com	Houston	Texas	3158095287069123874	6f8cf52a18c6a86211bea2c6b9118dca	Mastercard	29.6992644903328262	-95.3450762589011305
7439	2019-12-20 23:05:18	2019-12-20	Bobby Abernathy	bobby.abernathy@geemail.com	Rochester	Minnesota	676208188631249	ced476674bb4c846816374231631d227	Diners Club / Carte Blanche	44.0501688333597059	-92.3871611883517261
7440	2019-12-20 23:22:10	2019-12-20	Konner Nicolas	konner.nicolas@geemail.com	Los Angeles	California	4868231871588101	74f6f404f8869091a4125e966316ca86	American Express	33.9614884681865519	-118.500841884221131
7441	2019-12-20 23:34:58	2019-12-20	Toivo Boyle	toivo.boyle@geemail.com	Chicago	Illinois	4630642465045638	d5972e716c56ecf43311cd2004d96382	Diners Club / Carte Blanche	41.7962318514309814	-87.6715551223170024
7442	2019-12-21 00:14:38	2019-12-21	Treva Kovacek	treva.kovacek@geemail.com	Los Angeles	California	3468687360112109	810d425b812639ef0317d0d2830ad37d	VISA 16 digit	34.0565301098260989	-118.460056048211825
7443	2019-12-21 00:28:09	2019-12-21	Dr. Mariela Boyle	dr.mariela.boyle@geemail.com	New York	New York	502091172330630	99115ffddeeb5804367cf9504810f311	Mastercard	40.6214134898260255	-73.9741377056937637
7444	2019-12-21 01:28:24	2019-12-21	Cressie Mohr	cressie.mohr@warmmail.com	San Antonio	Texas	3112391203308415964	30bb4815f3a12ebfd4a6fc94a9ad5f90	JCB 15 digit	29.4602744881134484	-98.5509788809180236
7445	2019-12-21 01:39:23	2019-12-21	Theresia Schultz	theresia.schultz@geemail.com	San Francisco	California	3017851621696680	4058bfadd9dc65f06d0af96a67772189	VISA 13 digit	37.8126132016449645	-122.446735045715144
7446	2019-12-21 02:07:03	2019-12-21	Toshiko Brown	toshiko.brown@geemail.com	Rancho Cucamonga	California	502071839210417	9f05aea73b8b5d338feb13aab05dcfc1	JCB 16 digit	34.1920734376173456	-117.547578853742039
7447	2019-12-21 02:41:03	2019-12-21	Gardner Blick-Herzog	gardner.blick.herzog@woohoo.com	Lancaster	California	6011668315366759111	b68d7520af016e5e2605d4061e5d33e7	Mastercard	34.609359998233991	-118.151659544042488
7448	2019-12-21 02:41:05	2019-12-21	Benito Kulas	benito.kulas@geemail.com	San Jose	California	3717960416253157	64cbce69333515ab9c9caf6b3989ec5b	JCB 15 digit	37.225631370936334	-121.737093722655999
7449	2019-12-21 02:51:03	2019-12-21	Marie Sawayn	marie.sawayn@warmmail.com	El Paso	Texas	3049430265146100	1c04640be5003ff2fcafe77c35947862	JCB 16 digit	31.9290508480571233	-106.442518187405554
7450	2019-12-21 02:53:15	2019-12-21	Judy Denesik	judy.denesik@geemail.com	Inglewood	California	4949204397952	681e8c347232a9969cf468136ea62ff6	Maestro	33.9542556595768801	-118.438668305988614
7451	2019-12-21 03:09:56	2019-12-21	Dr. Harper Boehm	dr.harper.boehm@geemail.com	Burbank	California	3404275355927538	30449af59bce6fbed142a9306380d0af	VISA 16 digit	34.261350417502598	-118.239142070248363
7452	2019-12-21 04:04:18	2019-12-21	Dr. Star Daniel	dr.star.daniel@geemail.com	Austin	Texas	6011563133865135139	d59a052fac447898b36972903cf1dbaa	JCB 16 digit	30.3787352397233228	-97.8511924622353177
7453	2019-12-21 04:10:45	2019-12-21	Mrs. Loree Pfeffer	mrs.loree.pfeffer@geemail.com	League City	Texas	4602760132577066	d81bc05cb15f0828ac7cd434d59a5e81	JCB 16 digit	29.3978484261244546	-95.0549397225476724
7454	2019-12-21 04:31:48	2019-12-21	Dr. Sarrah Will	dr.sarrah.will@geemail.com	Milwaukee	Wisconsin	3337377475284801411	3391707ac90a8b21a0bc7a85c22fe49c	VISA 13 digit	43.1117034099150445	-88.0218758392714022
7455	2019-12-21 04:37:23	2019-12-21	Mcarthur Strosin	mcarthur.strosin@woohoo.com	Boston	Massachusetts	53804335291362380	b5307fdac9e9a7c52256831e8297dbab	VISA 16 digit	42.2591228152327218	-71.0323938300784761
7456	2019-12-21 05:03:11	2019-12-21	Mrs. Gracia Schultz PhD	mrs.gracia.schultz.phd@woohoo.com	New York	New York	53636671014906580	8bf5bfd23f730e275b7ada0a9b7b6ff8	Diners Club / Carte Blanche	40.5646136201210297	-73.9197744070913672
7457	2019-12-21 05:11:43	2019-12-21	Jeanna Johnston	jeanna.johnston@geemail.com	Milwaukee	Wisconsin	3425814482414682	0474b99658f28246c585d6c2a7ccd6a2	JCB 15 digit	43.0272940569642941	-87.8913393724344729
7458	2019-12-21 05:19:30	2019-12-21	Blaine Nienow	blaine.nienow@geemail.com	Phoenix	Arizona	3112610249686945614	8276d4f4f1e534ab53407262bda666e6	JCB 16 digit	33.5403276604998908	-112.100366569163654
7459	2019-12-21 05:37:19	2019-12-21	Ingrid Greenholt-Davis	ingrid.greenholt.davis@warmmail.com	Jacksonville	Florida	869945886039805816	1b70195c3f85016f5fe7a8a0fdcc7a22	Voyager	30.3558502947032451	-81.7194391087241598
7460	2019-12-21 06:21:59	2019-12-21	Hannah Welch	hannah.welch@warmmail.com	Vallejo	California	4927018950489	c0422da08ba9edc1e079f3350e82c2b7	JCB 16 digit	38.1327092534951859	-122.238624477280297
7461	2019-12-21 07:08:49	2019-12-21	Dr. Jamison Pollich III	dr.jamison.pollich.iii@geemail.com	Chattanooga	Tennessee	3096528401007225496	cae33e9b1e15728c9b57af036d2082f2	VISA 16 digit	34.9817541051041374	-85.2775283728089164
7462	2019-12-21 08:21:22	2019-12-21	Ardis Schroeder	ardis.schroeder@woohoo.com	Wilmington	North Carolina	3050094645568414	ce97417b9889f6527364d26a26f68d5b	JCB 15 digit	34.2581722636528312	-77.8602367131963433
7463	2019-12-21 08:48:10	2019-12-21	Marin Marvin	marin.marvin@geemail.com	San Francisco	California	3004607068791308	81b2d82f3d512702f12f0d61d405d917	JCB 15 digit	37.7801118953241684	-122.439002527052281
7464	2019-12-21 11:00:01	2019-12-21	Mr. Layton Schimmel PhD	mr.layton.schimmel.phd@geemail.com	Lancaster	California	53752194663318211	c520ea6245bac1676505d770c8390b06	Discover	34.6563145916689237	-118.233983607401314
7465	2019-12-21 11:06:54	2019-12-21	Mr. Duwayne Metz	mr.duwayne.metz@geemail.com	Oakland	California	4018952572066019	c57158a0747a2859ca1a9f147999ea30	VISA 16 digit	37.8203230333387523	-122.272983468920302
7466	2019-12-21 11:18:19	2019-12-21	Ronda Schmidt	ronda.schmidt@geemail.com	Denver	Colorado	4514940681556375	40e6b3871589cfe9d52761b21afa81c1	VISA 13 digit	39.7751299172691972	-104.830306683784727
7467	2019-12-21 11:25:14	2019-12-21	Caitlynn Pollich	caitlynn.pollich@warmmail.com	San Francisco	California	4593500411040	2096f49fed6a9e0e6ee700e2383680e6	Discover	37.7983154205712708	-122.4194524764292
7468	2019-12-21 11:30:17	2019-12-21	Mcarthur Gibson	mcarthur.gibson@geemail.com	Tucson	Arizona	3485908053179943	c1d1db4f03b260caf67705a04b16dd6a	American Express	32.2381008381996352	-110.927753699547054
7469	2019-12-21 12:08:53	2019-12-21	Alfreda Hilpert	alfreda.hilpert@woohoo.com	West Palm Beach	Florida	3158401271932490586	0f45fba19c76d9e579e5384687649f13	American Express	26.8180847371310023	-80.0665828878361765
7470	2019-12-21 12:10:08	2019-12-21	Jade Russel	jade.russel@warmmail.com	Chattanooga	Tennessee	6011446026949647983	9b677178b83bb14d140b2263b66663af	Mastercard	35.0471729300301575	-85.1518983635414486
7471	2019-12-21 12:13:44	2019-12-21	Dr. Ronin Brown	dr.ronin.brown@woohoo.com	Virginia Beach	Virginia	4194907823299161	4274212c67e7458d1a98fd30a0184085	American Express	36.6971500291675312	-76.0360817439526357
7472	2019-12-21 12:20:05	2019-12-21	Christop Brown	christop.brown@geemail.com	Phoenix	Arizona	4665768218554036	50056daf90d7e39bf712504f9435a076	Discover	33.589529106386756	-112.132067455390853
7473	2019-12-21 12:30:18	2019-12-21	Josephine Swift	josephine.swift@geemail.com	Phoenix	Arizona	4427365687396	ba214d3ed7019283ffd9b07e5ecd0245	VISA 16 digit	33.530482857667657	-112.180748399153728
7474	2019-12-21 12:32:58	2019-12-21	Taurus Collier	taurus.collier@woohoo.com	Houston	Texas	180027515416800247	7f985a3febcb74b239a70da34a57661c	Maestro	29.7608276274599142	-95.4596034439295522
7475	2019-12-21 12:33:24	2019-12-21	Dr. Donte Dibbert	dr.donte.dibbert@geemail.com	Everett	Washington	3755609063198818	5ba432536a1672ede5287c7a0ae9aa45	Diners Club / Carte Blanche	48.0002292816884832	-122.161506087112798
7476	2019-12-21 12:41:05	2019-12-21	Stanton Steuber	stanton.steuber@woohoo.com	Olathe	Kansas	6011431405756156014	525dac78bca2772f4ca7b343663591ed	Maestro	38.9397280768148661	-94.754503568418329
7477	2019-12-21 12:45:38	2019-12-21	Lurena Kirlin PhD	lurena.kirlin.phd@geemail.com	Los Angeles	California	4988074061785	08f27d729c5f6252b6777382b5c33ea7	Maestro	33.9936507869843396	-118.3608559891574
7478	2019-12-21 12:54:19	2019-12-21	Miss Rosetta Runte DDS	miss.rosetta.runte.dds@geemail.com	San Francisco	California	3057239559312597	a5b09d6f77c32094ce465fe3d2c0799f	Diners Club / Carte Blanche	37.7734039255659084	-122.411208230332278
7479	2019-12-21 13:12:52	2019-12-21	Campbell Medhurst	campbell.medhurst@geemail.com	Louisville	Kentucky	3112488163802600038	8e8ea150d9871ee840a32e08efe73bc7	Diners Club / Carte Blanche	38.2136142197899531	-85.6030000447832151
7480	2019-12-21 13:13:25	2019-12-21	Dr. Lexis Smith	dr.lexis.smith@geemail.com	San Francisco	California	55582550422365486	2dcc977f9c0206de90d46c4ce79c2e73	Diners Club / Carte Blanche	37.7820007954074839	-122.42255968060897
7481	2019-12-21 13:13:46	2019-12-21	Elenor Breitenberg	elenor.breitenberg@geemail.com	San Francisco	California	869919196105681311	682ce8a469667d2b2d3f3993b5d6a281	Diners Club / Carte Blanche	37.7803569178440668	-122.435280680470782
7482	2019-12-21 13:29:34	2019-12-21	Karri West DVM	karri.west.dvm@woohoo.com	San Francisco	California	210065763852539274	9a2a54ebafe8fe659313098f9107915d	VISA 13 digit	37.7574978676422361	-122.421202313638858
7483	2019-12-21 13:31:37	2019-12-21	Israel Rath	israel.rath@geemail.com	Sioux Falls	South Dakota	6011385267407846161	4694dc6bfce202a359a178be0173bd76	VISA 16 digit	43.4781693649098244	-96.810723554313185
7484	2019-12-21 13:34:47	2019-12-21	Alijah Rosenbaum	alijah.rosenbaum@geemail.com	Long Beach	California	6011438839020411131	c11e2b9df094905401c3fe945a89b705	American Express	33.8433713168192654	-118.180766984510413
7485	2019-12-21 13:52:07	2019-12-21	Earline Bergnaum-Legros	earline.bergnaum.legros@geemail.com	Houston	Texas	3088278085295867069	23d334232dba3981dc4895ad26ca5e9f	VISA 16 digit	29.7976075552482165	-95.3414029445514046
7486	2019-12-21 14:00:26	2019-12-21	Zeno Gleason IV	zeno.gleason.iv@geemail.com	Saint Paul	Minnesota	210050346046449803	0d78053d5307f018b0450fc1455af659	Discover	44.8998191404562448	-93.1926146832559255
7487	2019-12-21 14:12:00	2019-12-21	Bryant Weber	bryant.weber@geemail.com	Cleveland	Ohio	3528267552349754968	121c7e96287fce07e7a40e7007db9169	Voyager	41.4730017305668426	-81.6619521187856776
7488	2019-12-21 14:22:23	2019-12-21	Cassandra Ankunding	cassandra.ankunding@geemail.com	Tucson	Arizona	3053743139829586	afd81126545692c081841c4092160e9c	Discover	32.2441861965734518	-110.799094462324305
7489	2019-12-21 14:25:59	2019-12-21	Medora Turner	medora.turner@woohoo.com	New York	New York	869994656794917167	914893dc982a425cef2a750142b36840	JCB 16 digit	40.7629686392601585	-73.9348859162896872
7490	2019-12-21 14:41:44	2019-12-21	Nan Gutkowski	nan.gutkowski@geemail.com	New York	New York	3047815228139154	6825ed863be2e7a2e774c9db60c99eda	Voyager	40.5712166477683951	-73.897628484795618
7491	2019-12-21 14:56:27	2019-12-21	Dr. Dink Goyette	dr.dink.goyette@geemail.com	Fort Collins	Colorado	3088798701118047918	821410bc5b8bc500c3bc33cf2adad144	Discover	40.530337826643887	-105.071304254182806
7492	2019-12-21 15:29:56	2019-12-21	Dr. Burney Romaguera II	dr.burney.romaguera.ii@geemail.com	Fresno	California	869926492257380625	680133153c8cb62c1b9eff3cb084c412	VISA 16 digit	36.6943864323537809	-119.889660978002112
7493	2019-12-21 15:52:02	2019-12-21	Algernon Cole	algernon.cole@warmmail.com	San Francisco	California	3096798610265488801	1813138a1702c7bbd5c484ab9465e74b	Maestro	37.8049509160527464	-122.466537595527868
7494	2019-12-21 15:54:38	2019-12-21	Dr. Shoji Leannon	dr.shoji.leannon@geemail.com	Rochester	New York	3528669778373462863	4f85dee27228642df09600e6a4a6ff08	Voyager	43.082614921217413	-77.6822181721456388
7495	2019-12-21 16:02:16	2019-12-21	Ozie Hermiston	ozie.hermiston@geemail.com	San Francisco	California	589372708268106	6a52fecf1e708a455360c6498bbb5395	Maestro	37.7977952362340019	-122.422188159864135
7496	2019-12-21 16:35:30	2019-12-21	Kaitlyn Kautzer PhD	kaitlyn.kautzer.phd@geemail.com	San Francisco	California	561212735022431	65f9f49b0fc7209ab89f9edf9fecc137	Voyager	37.7760260530758529	-122.476478213989139
7497	2019-12-21 16:51:08	2019-12-21	Estill Hartmann	estill.hartmann@warmmail.com	Ann Arbor	Michigan	3779235056568932	0eba5f26e1ebae8b58cbf860ee594443	Voyager	42.2368821356970798	-83.7160693512871887
7498	2019-12-21 16:55:20	2019-12-21	Hailie Lubowitz DVM	hailie.lubowitz.dvm@geemail.com	Lafayette	Louisiana	3466763674927854	3468d8f756b3abe582f088dc1ca6f92a	JCB 16 digit	30.286860633778943	-91.9295151985567003
7499	2019-12-21 17:05:29	2019-12-21	Lular Wolff DVM	lular.wolff.dvm@geemail.com	Tucson	Arizona	676160451306421	1da45428a33990268afd9d725af7e370	American Express	32.2378719392273609	-110.908513732789459
7500	2019-12-21 17:16:43	2019-12-21	Jewell Spinka-Considine	jewell.spinka.considine@geemail.com	Corpus Christi	Texas	3088943247731941354	8fb9679794c537c91e75fc60dc4731a0	American Express	27.6633095095802091	-97.1876182183451931
7501	2019-12-21 17:20:26	2019-12-21	Sade Olson MD	sade.olson.md@geemail.com	Oakland	California	55304952523063100	8fd6a43061707d929c51b727052c651f	JCB 15 digit	37.8075420007736867	-122.270935726772819
7502	2019-12-21 17:41:36	2019-12-21	Gonzalo Dibbert	gonzalo.dibbert@geemail.com	Berkeley	California	6011770837909221783	328a75b86f9bc901061ff88d70a1a207	Discover	37.8796694150943409	-122.276700580794568
7503	2019-12-21 18:05:42	2019-12-21	Errol Bernier	errol.bernier@warmmail.com	New York	New York	3337709598325010483	c6a42373b0315f55823f0ca48da6ed1b	VISA 16 digit	40.6753408103473504	-73.9583150538977208
7504	2019-12-21 18:22:29	2019-12-21	Lige Anderson	lige.anderson@geemail.com	Oakland	California	3158167108232059329	885ddda21fefb92350b411e388a3c24e	Voyager	37.8275091485504973	-122.264819837254038
7505	2019-12-21 18:26:55	2019-12-21	Dangelo Prosacco	dangelo.prosacco@geemail.com	San Francisco	California	180028052097297302	c47bd33aa013a5d4e7630cf24f062672	Maestro	37.7968653386898552	-122.399995063219734
7506	2019-12-21 18:29:08	2019-12-21	Imanol Oberbrunner	imanol.oberbrunner@warmmail.com	Hartford	Connecticut	589386922172639	9e35171b620ca39a5c3b8e1adc68ebf6	Diners Club / Carte Blanche	41.8408706743285066	-72.6601948064178202
7507	2019-12-21 18:36:32	2019-12-21	Mrs. Maralyn Schneider DDS	mrs.maralyn.schneider.dds@geemail.com	San Francisco	California	6011808462022543595	9b74b2aa1325779a3b09cf9afc9a8d14	Diners Club / Carte Blanche	37.7732628833218769	-122.429829434040045
7508	2019-12-21 19:01:14	2019-12-21	Aurelia Crist	aurelia.crist@geemail.com	New York	New York	3053770767777928	a3bd0daf74d88bff673b38db495ecb32	Voyager	40.7086668630354112	-73.8412014752056365
7509	2019-12-21 19:53:22	2019-12-21	Ms. Lisette Bayer	ms.lisette.bayer@woohoo.com	Detroit	Michigan	3493842110547075	59b81de95db398434c92edb0140f458a	VISA 16 digit	42.4200492006186423	-83.1436648668374829
7510	2019-12-21 20:00:09	2019-12-21	Betha D'Amore	betha.d'amore@geemail.com	San Francisco	California	52628159225399928	ad36815311ad3e33180fbdb7ec314808	JCB 15 digit	37.7381695307692411	-122.47999546884185
7511	2019-12-21 20:16:04	2019-12-21	Jerica Mann	jerica.mann@geemail.com	Fort Collins	Colorado	6011362213659312319	d337b864f9f544622eb7dd11f96b5305	JCB 16 digit	40.6474197736166403	-105.066159291421258
7512	2019-12-21 20:17:36	2019-12-21	Mellisa Veum	mellisa.veum@warmmail.com	Rochester	New York	6011510163058430942	9c4b59501dc9a2cf6c672f214b066655	VISA 16 digit	43.2199537557993096	-77.5186170543316706
7513	2019-12-21 20:41:07	2019-12-21	Rakeem Lindgren	rakeem.lindgren@warmmail.com	Antioch	California	4063245997406	547afdc28ebcbca43fbc966ee36ccb18	VISA 16 digit	37.9345058169480467	-121.830025743896883
7514	2019-12-21 20:53:44	2019-12-21	Dr. Veola Yundt	dr.veola.yundt@woohoo.com	Simi Valley	California	210024997908249559	37eb0ca397eff6ac9829a2ae335d2001	American Express	34.3283111551549283	-118.83633817747608
7515	2019-12-21 20:56:22	2019-12-21	Dr. Pete Herman	dr.pete.herman@geemail.com	Charlotte	North Carolina	210067763135336744	4eb1e92ae3421698d212ac33f11aa9f2	American Express	35.2100631302010285	-80.7355068148523571
7516	2019-12-21 21:25:48	2019-12-21	Madalynn Bosco	madalynn.bosco@geemail.com	San Francisco	California	869974223949495419	bbe32ed706aab7396e6ac7b9794ecd26	JCB 15 digit	37.7582401052014731	-122.388677969281943
7517	2019-12-21 21:26:09	2019-12-21	Mr. Edmund Turner	mr.edmund.turner@geemail.com	San Francisco	California	4230503853185721	9fd238197ccc30266a6a8457aafdffda	American Express	37.7963912515101228	-122.41543626381231
7518	2019-12-21 21:32:28	2019-12-21	Doctor Moen III	doctor.moen.iii@geemail.com	Jackson	Mississippi	3528601989913959588	da92de7d6c666e2c3d6430f6e3c2b54d	Mastercard	32.3081782125115424	-90.2842395410381329
7519	2019-12-21 21:43:38	2019-12-21	Reggie Gulgowski	reggie.gulgowski@woohoo.com	Houston	Texas	3088425127067258523	61fd98f244b002dc17448f7830879205	American Express	29.8072041482277221	-95.4777951547425232
7520	2019-12-21 21:52:09	2019-12-21	Milton Miller	milton.miller@geemail.com	Las Vegas	Nevada	3112787507197792016	933b1c07ff52020f83fe057c4aa85fac	Voyager	36.1836252940453562	-115.352796464387694
7521	2019-12-21 21:59:58	2019-12-21	Dr. Juanita Stamm	dr.juanita.stamm@geemail.com	San Francisco	California	3007586000882580	dbed7aef47fdb3b89b6e4fceea3e2ae7	JCB 16 digit	37.7663791957983719	-122.458200025868152
7522	2019-12-21 22:11:58	2019-12-21	Campbell Legros-Renner	campbell.legros.renner@geemail.com	San Francisco	California	3048562867474943	0d005bcc49ac03aebb213a3de8579e80	American Express	37.7739814428900971	-122.438113001629176
7523	2019-12-21 22:26:50	2019-12-21	Dominic Becker-Homenick	dominic.becker.homenick@geemail.com	Austin	Texas	869950240781410650	1e39a246977088febcad1fd4c63c13b5	Voyager	30.3241130997087787	-97.79874013185092
7524	2019-12-21 22:32:57	2019-12-21	Lular Williamson-Shields	lular.williamson.shields@geemail.com	Portland	Oregon	3337006417946080470	2437fe94715f299af84d753b992d6db1	JCB 16 digit	45.5098670407552248	-122.737313330778861
7525	2019-12-21 23:03:03	2019-12-21	Hettie Little	hettie.little@geemail.com	Greensboro	North Carolina	4978483618081539	97a87fcf8e62b6e62ca065daaeb1fb8a	Maestro	36.1308488610781779	-79.8450872668512091
7526	2019-12-21 23:11:24	2019-12-21	Carly Kovacek	carly.kovacek@geemail.com	Riverside	California	6011747889438106878	1c50f0e5405e9dc010adf661ec490f39	JCB 15 digit	33.9961407474655672	-117.489248265835258
7527	2019-12-21 23:13:59	2019-12-21	Posey Collins	posey.collins@geemail.com	San Francisco	California	4104461829552271	54ad75636269297192998eb32c8a95c6	Diners Club / Carte Blanche	37.770969557448332	-122.378606737719025
7528	2019-12-21 23:50:17	2019-12-21	Dr. Bob Larson PhD	dr.bob.larson.phd@woohoo.com	Killeen	Texas	54252677852253145	34a4e8029ed1cf5354c40f7424244d64	American Express	30.9913606772430228	-97.6651827637739416
7529	2019-12-21 23:58:51	2019-12-21	Bulah Hilll	bulah.hilll@geemail.com	Nashville	Tennessee	4072887047781821	4128b01611222a9e78f43dcd16a07562	VISA 16 digit	36.2175860247697656	-86.8459064265619958
7530	2019-12-22 00:00:31	2019-12-22	Sinda Shields DDS	sinda.shields.dds@woohoo.com	Tacoma	Washington	3430390418908181	e8a850d90f235565d8676922e46cfebd	VISA 13 digit	47.2111379595592666	-122.405959348497163
7531	2019-12-22 01:17:57	2019-12-22	Val Gottlieb	val.gottlieb@geemail.com	Mesa	Arizona	4312285436357	b06b838636ded65705cdaa6d2f4d9fb1	VISA 16 digit	33.5003676424879586	-111.756889010116083
7532	2019-12-22 01:28:53	2019-12-22	Mr. Thompson Jacobs II	mr.thompson.jacobs.ii@geemail.com	Oceanside	California	6011212252183949453	5941104ca185b1fb401691361b16f0d4	Mastercard	33.2154436303190863	-117.291637485249723
7533	2019-12-22 01:34:24	2019-12-22	Mr. Perley Howe III	mr.perley.howe.iii@geemail.com	Los Angeles	California	4406749002233536	906b1eba5ff3d95f6dff6e4cd38655fb	Mastercard	34.0004462949797457	-118.42346797017305
7534	2019-12-22 01:35:03	2019-12-22	Chloe Turner	chloe.turner@geemail.com	Houston	Texas	4112238353562	b8e9f21931197a8813dfe8dd1a02832f	JCB 16 digit	29.8768100909035645	-95.4219454664286246
7535	2019-12-22 01:46:54	2019-12-22	Ellie Fadel	ellie.fadel@warmmail.com	Boston	Massachusetts	3005991775854438	00467b10c8dc89cb7acbd639f21035fc	VISA 16 digit	42.367106169339273	-70.9338208385694742
7536	2019-12-22 01:52:36	2019-12-22	Ardelia Boyle PhD	ardelia.boyle.phd@geemail.com	Mesa	Arizona	3337413229167865811	bc29df226700f3202d3299cf97334d6a	Discover	33.3359481526218318	-111.684120381192855
7537	2019-12-22 01:53:17	2019-12-22	Mr. Codie Lowe	mr.codie.lowe@geemail.com	San Francisco	California	561271330537896	473837fe5c39238b9203f3577374a9ac	Discover	37.7696849352163753	-122.432911975556593
7538	2019-12-22 02:26:25	2019-12-22	Verna Corwin-Strosin	verna.corwin.strosin@geemail.com	New York	New York	6011561721791225552	5c5d0d089d29cfe554f0f66bf5672514	VISA 13 digit	40.6348740567211024	-73.9751354584366112
7539	2019-12-22 02:36:44	2019-12-22	Samson Skiles	samson.skiles@geemail.com	San Francisco	California	3030495229783354	8b0026ef91458d66404ce1e159470f91	JCB 15 digit	37.7515739487686233	-122.412725502735441
7540	2019-12-22 02:38:33	2019-12-22	Lavina Skiles	lavina.skiles@geemail.com	North Las Vegas	Nevada	3004753967095332	f87c4accf722f30793090c8156749ee2	JCB 15 digit	36.2676924037903561	-115.102023084623369
7541	2019-12-22 02:44:48	2019-12-22	Mariano Stanton-Yundt	mariano.stanton.yundt@woohoo.com	St. Louis	Missouri	4166712268370616	b90193b108e945e1de31c785234ac556	Mastercard	38.646676317618045	-90.2614623306322841
7542	2019-12-22 03:14:19	2019-12-22	Math Reynolds II	math.reynolds.ii@geemail.com	Cedar Rapids	Iowa	4863823886469346	a1e13621d83ee6a46687cb9dd200c46b	Mastercard	42.0126079266499701	-91.7556897345531723
7543	2019-12-22 03:42:35	2019-12-22	Mrs. Stacia Pagac DDS	mrs.stacia.pagac.dds@warmmail.com	Broken Arrow	Oklahoma	676264306357100	dcab0ef3dca2bf8a1b0af02ade3a7d0b	Maestro	36.0117041227649892	-95.7430180020574539
7544	2019-12-22 03:49:26	2019-12-22	Camisha Pacocha	camisha.pacocha@woohoo.com	Anaheim	California	4771949562448154	0cbd89dd5ae0b859ab09c782b7ea7ec0	JCB 15 digit	33.7715456808749579	-117.705350904886046
7545	2019-12-22 03:51:11	2019-12-22	Dallas Lubowitz	dallas.lubowitz@geemail.com	Clearwater	Florida	3007854899754587	6c9396a8976ea9abc0624419650611e9	Discover	28.0125065766401598	-82.8023375411782325
7546	2019-12-22 04:05:07	2019-12-22	Dr. Andy Morar	dr.andy.morar@geemail.com	Berkeley	California	4431852122112736	564221c84ae982316c0c61936a7a3a15	Mastercard	37.870257429844159	-122.255378269537218
7547	2019-12-22 04:08:08	2019-12-22	Ayana Jaskolski	ayana.jaskolski@woohoo.com	Reno	Nevada	3096510731770379496	2ba9cb6eabb81b33cfe33cfb52c00be7	Mastercard	39.559415217683096	-119.765934273663547
7548	2019-12-22 04:32:15	2019-12-22	Dr. Earnest Hane	dr.earnest.hane@geemail.com	Peoria	Illinois	869951738217543563	5d4623073010ed8bb5ed8b41fa33bba3	Voyager	40.7354115206617848	-89.6312356471434271
7549	2019-12-22 04:39:43	2019-12-22	Avon Rosenbaum	avon.rosenbaum@woohoo.com	Chicago	Illinois	4247696104859978	b6725cff5e57afa2aba65b969e2cbcbb	VISA 16 digit	41.8190906353130956	-87.6682548907615171
7550	2019-12-22 05:45:15	2019-12-22	Dr. Pryor Cole II	dr.pryor.cole.ii@geemail.com	San Francisco	California	3112298906784007451	e508a932500e9af98ae6c99782295a04	VISA 16 digit	37.7749504349242926	-122.433086988945149
7551	2019-12-22 06:14:11	2019-12-22	Olene Wehner	olene.wehner@geemail.com	Louisville	Kentucky	4265862136560	89f88171e5c4b417f6ffddf8843d099a	JCB 16 digit	38.1815956539377552	-85.7280405195035087
7552	2019-12-22 06:30:32	2019-12-22	Eldon Weimann II	eldon.weimann.ii@geemail.com	San Francisco	California	3019791327905043	f4c1f394d9f4ecc59fd45925bd13e543	VISA 13 digit	37.7506748533465029	-122.420127896578578
7553	2019-12-22 06:46:03	2019-12-22	Dimitri Olson	dimitri.olson@geemail.com	Boston	Massachusetts	210040033510325627	a140b4cae67fa47161b4c903e0e4e1c3	VISA 16 digit	42.4059695725031176	-71.0814125617917654
7554	2019-12-22 06:48:20	2019-12-22	Geralyn Gutmann-Corwin	geralyn.gutmann.corwin@geemail.com	San Francisco	California	55846037431468461	41520e4883d0938681058ae3d5dbd9e1	Discover	37.7517861236652834	-122.4265775440429
7555	2019-12-22 07:08:51	2019-12-22	Mr. Elmore Kohler II	mr.elmore.kohler.ii@geemail.com	Washington	District of Columbia	6011246050658306807	326b82896792883738ae64c83534e119	Voyager	38.8651574376769346	-77.057875917034977
7556	2019-12-22 07:17:32	2019-12-22	Nathaly Eichmann	nathaly.eichmann@geemail.com	San Francisco	California	6011940644930925688	50a3652f7e8ee0f0b41f70fd3722462f	JCB 16 digit	37.7802370336436368	-122.409101802110214
7557	2019-12-22 08:36:59	2019-12-22	Cortney Lang PhD	cortney.lang.phd@geemail.com	Oklahoma City	Oklahoma	53864453847145873	86640cc2f8e497ea812489483cebe87c	Discover	35.4169487994540475	-97.4888549595501246
7558	2019-12-22 09:39:05	2019-12-22	Zachariah Kautzer V	zachariah.kautzer.v@geemail.com	Durham	North Carolina	51647873430296813	376d8b9973764f75ab57a10677676a87	JCB 15 digit	36.0397739173624672	-78.8135919049750981
7559	2019-12-22 09:42:09	2019-12-22	Trever Jenkins	trever.jenkins@geemail.com	Louisville	Kentucky	4541915774833	a6cebe27656e38067a5137d1a14695f1	Voyager	38.0697582088313951	-85.7447293713759677
7560	2019-12-22 09:46:09	2019-12-22	Miss Alla Koelpin PhD	miss.alla.koelpin.phd@woohoo.com	Philadelphia	Pennsylvania	869937483825829760	d33b1c34ab51eaa818c20ab8ccc021a7	VISA 13 digit	40.0827832225669169	-75.1271163551501928
7561	2019-12-22 10:15:17	2019-12-22	Oral Feil V	oral.feil.v@geemail.com	Berkeley	California	3059481395503090	8477ca5a198aaf10f827a5919b7531f4	VISA 16 digit	37.8853732312557483	-122.264785691000796
7562	2019-12-22 10:19:15	2019-12-22	Garold Hessel	garold.hessel@geemail.com	Springfield	Illinois	869932814121129924	f4c78a2006998e64a8a5f943b6bb4d09	VISA 16 digit	39.722021955639498	-89.5705930310305121
7563	2019-12-22 10:53:32	2019-12-22	Roslyn Leannon	roslyn.leannon@warmmail.com	Nashville	Tennessee	3528100451147578185	e1c60b320a3d5289f662d3a305b42c1d	Mastercard	36.1212196475017819	-86.7376472051162182
7564	2019-12-22 11:10:33	2019-12-22	Maxie Blick	maxie.blick@woohoo.com	Palmdale	California	51051895386119235	5f09207834ae9c4b6d7d10dd95c6abeb	Mastercard	34.5532240359894942	-118.151127513218299
7565	2019-12-22 11:16:26	2019-12-22	Dr. Lamar Gusikowski Sr.	dr.lamar.gusikowski.sr.@geemail.com	San Francisco	California	676130083125440	82f750210259f41f0e210adb56b5064a	Diners Club / Carte Blanche	37.7883219977137372	-122.44270742521951
7566	2019-12-22 11:25:22	2019-12-22	Jeromy Pagac	jeromy.pagac@geemail.com	San Francisco	California	6011045523953277041	dc859a19deca8aeb05917f50449f56c5	Voyager	37.7785842396926483	-122.407055462990854
7567	2019-12-22 11:54:29	2019-12-22	Junie Mante DVM	junie.mante.dvm@geemail.com	San Diego	California	4475710911896	0ebb787dbe8b7576f529eb486eda7f15	Mastercard	32.8226425773065529	-117.117279333239424
7568	2019-12-22 12:01:27	2019-12-22	Emmanuel Reichel	emmanuel.reichel@woohoo.com	Portland	Oregon	869926932083825319	d45bd51d405531cc0e8cb36351241d46	JCB 15 digit	45.5298998274262985	-122.63047469938175
7569	2019-12-22 12:02:42	2019-12-22	Carmel Beier-Kuphal	carmel.beier.kuphal@geemail.com	Sacramento	California	4916109138906	a645ec744dd1f8d545c9a26d4b3f6a4a	JCB 16 digit	38.5363046241257337	-121.38149114896207
7570	2019-12-22 13:30:42	2019-12-22	Toivo Harris	toivo.harris@woohoo.com	San Antonio	Texas	180063192657363551	409498abb880154c70b20ff06d202820	Diners Club / Carte Blanche	29.4640000579949479	-98.6158695230562188
7571	2019-12-22 13:38:15	2019-12-22	Felicity Homenick	felicity.homenick@woohoo.com	San Francisco	California	53139301850865755	bf7e8ad01f580b0e5ed8c7f14bd1290b	VISA 16 digit	37.7688734040572669	-122.422417052012065
7572	2019-12-22 13:45:45	2019-12-22	Dr. Mohamed D'Amore	dr.mohamed.d'amore@warmmail.com	San Francisco	California	180099064914394893	385f19cb9ad1c7c9d17f3fc1683b9d81	Mastercard	37.8024500675737869	-122.421338527030883
7573	2019-12-22 13:46:34	2019-12-22	Mr. Bynum Torp DVM	mr.bynum.torp.dvm@geemail.com	Aurora	Illinois	3158308810272588907	7a5681a24bf519826eadf22c4fe058c5	Diners Club / Carte Blanche	41.8354436748884595	-88.3850210452847165
7574	2019-12-22 13:55:28	2019-12-22	Kiyoshi DuBuque	kiyoshi.dubuque@geemail.com	San Francisco	California	4761298630143	0bd5a1e6795ebd4f0a59fd0537329c0b	Maestro	37.7781566699932725	-122.447802764110278
7575	2019-12-22 14:06:10	2019-12-22	Rolanda Hansen	rolanda.hansen@geemail.com	Dallas	Texas	869986940913221036	ae35c5c44f69ffc74bdcba072adf03b2	Mastercard	32.7071437382411219	-96.7423011672180024
7576	2019-12-22 14:09:37	2019-12-22	Cailyn Koss	cailyn.koss@geemail.com	San Jose	California	869964843115688513	26c1de7ee6374b6fa3c7fd75b7bab1ea	VISA 16 digit	37.3910136086221812	-121.742921162651484
7577	2019-12-22 14:38:35	2019-12-22	Hassie VonRueden	hassie.vonrueden@woohoo.com	West Palm Beach	Florida	869914791129145064	fd4c397b9ddeac25837ff6eb7c8a9901	JCB 15 digit	26.7251177334539598	-80.0297693093609155
7578	2019-12-22 15:28:15	2019-12-22	Redden Harris	redden.harris@geemail.com	Fort Lauderdale	Florida	4455951688130008	a731a6e2333c9cc3eccfbe0e1532269d	Maestro	26.1325020190782844	-80.2259881408706264
7579	2019-12-22 15:43:41	2019-12-22	Edward Lebsack	edward.lebsack@geemail.com	Portland	Oregon	3112738404606466608	0b86098bceb9faee754ef3ba0ac56d39	JCB 16 digit	45.483505210269243	-122.733659008610999
7580	2019-12-22 15:54:07	2019-12-22	Evelena Kshlerin	evelena.kshlerin@geemail.com	Broken Arrow	Oklahoma	3096764039784444428	e28ca603481c829b112bf75a2b2019b9	VISA 13 digit	36.0269697363730472	-95.7854260083697824
7581	2019-12-22 16:38:04	2019-12-22	Amya Schmitt	amya.schmitt@woohoo.com	El Paso	Texas	53768344100317134	3f0f97d77274e1d8a900230f03994791	Maestro	31.7484708186067657	-106.479633389178673
7582	2019-12-22 17:18:29	2019-12-22	Palmer Wyman	palmer.wyman@woohoo.com	Oakland	California	503839727178749	3ad2436ae06de9a6dcfb9f2528be2e79	Diners Club / Carte Blanche	37.8151804968111307	-122.328281662020387
7583	2019-12-22 17:30:43	2019-12-22	Dr. Margaretha Gutkowski PhD	dr.margaretha.gutkowski.phd@warmmail.com	Norfolk	Virginia	210026991932966724	ee41c3c5ce9044e3bfa08abc2c7766de	Mastercard	37.0189854659158755	-76.2857181999370511
7584	2019-12-22 17:37:13	2019-12-22	Clarabelle Cummerata	clarabelle.cummerata@geemail.com	Chicago	Illinois	55152694209041926	c0cb1d13adf021699e190eb0fef66093	JCB 16 digit	41.7905824999626745	-87.7603630783066109
7585	2019-12-22 17:48:24	2019-12-22	Richmond Huels	richmond.huels@geemail.com	Kansas City	Missouri	3096329721797583551	bb7e5a188c30e8fc0c5450d705833fdd	Maestro	39.0984511627186109	-94.5410745804421566
7586	2019-12-22 17:52:47	2019-12-22	Tea Erdman	tea.erdman@geemail.com	Louisville	Kentucky	53416789440931752	215fa397df00aa0b17ec6d90c11d1d8f	Diners Club / Carte Blanche	38.2257578802198168	-85.7175059869024949
7587	2019-12-22 17:57:01	2019-12-22	Marta Walsh	marta.walsh@geemail.com	San Francisco	California	3718578195732271	0dd1b71a8081f6dba08169c6eea0a324	Maestro	37.7653304558916929	-122.404206668281134
7588	2019-12-22 18:30:11	2019-12-22	Jessye Spencer	jessye.spencer@warmmail.com	Los Angeles	California	4221810364630	f42f653a0282bc528f84703481055eb8	Discover	34.0394884031597513	-118.5001812731374
7589	2019-12-22 18:30:47	2019-12-22	Marina Kuvalis	marina.kuvalis@geemail.com	San Francisco	California	3422101938385929	fc2c87099da1db914a9cd09bfd73e99c	VISA 13 digit	37.7721793450145427	-122.375748199660478
7590	2019-12-22 18:49:10	2019-12-22	Dr. Howell Nikolaus	dr.howell.nikolaus@woohoo.com	San Francisco	California	3048976020528819	fb9ac90c46c925e23cf1e4ab6615086f	JCB 16 digit	37.7881871092577057	-122.451287875302981
7591	2019-12-22 18:50:02	2019-12-22	Ward Schmitt-Huels	ward.schmitt.huels@warmmail.com	Berkeley	California	3732099218918880	f71aa1c70e385987f2d51c2700befc11	American Express	37.8711417722858599	-122.300299856597604
7592	2019-12-22 19:11:20	2019-12-22	Miss Olga Beatty DVM	miss.olga.beatty.dvm@geemail.com	Chicago	Illinois	55963495465601125	e200b4de77db25f00dcad3ee90ba4df8	VISA 16 digit	41.908350739146023	-87.7290736400086359
7593	2019-12-22 19:22:05	2019-12-22	Gena Wyman DDS	gena.wyman.dds@woohoo.com	San Francisco	California	639008406168685	5fc0d02dda099e5f1a3a7d1e6d03943c	JCB 16 digit	37.7236691282333183	-122.461902534874284
7594	2019-12-22 19:27:23	2019-12-22	Lindell Lueilwitz	lindell.lueilwitz@woohoo.com	New York	New York	3337164005725706270	56276e0637f42f61f152442e82500f99	American Express	40.75289585313201	-73.8772744767729108
7595	2019-12-22 19:53:52	2019-12-22	Elliott Ullrich	elliott.ullrich@woohoo.com	Oakland	California	180036214366776784	43e265078d71524ad17985fc9afddb2a	Maestro	37.7921475350930436	-122.244372895662295
7596	2019-12-22 20:02:07	2019-12-22	Mora Kiehn	mora.kiehn@geemail.com	Aurora	Colorado	4873507120395973	3cf78797b067fc4b6e2511d52722dff5	VISA 16 digit	39.7529572520982484	-104.692407589045175
7597	2019-12-22 20:18:10	2019-12-22	Cassie Bernier	cassie.bernier@geemail.com	Chula Vista	California	6011089513021603051	b9b644e024eaa1a39941b14334a96b76	American Express	32.5986823483601214	-116.986506770341464
7598	2019-12-22 20:21:23	2019-12-22	Trudy Hartmann	trudy.hartmann@geemail.com	McKinney	Texas	3018558691776826	c5dc2447ca3f4020a4e2d695c0a93edd	Maestro	33.1580813459716737	-96.7087050235196983
7599	2019-12-22 21:18:21	2019-12-22	Sebastian Bergstrom	sebastian.bergstrom@geemail.com	Lexington	Kentucky	4924105585922	af111d250b39c3030b7bb0f9961f17aa	Voyager	38.0397722426213321	-84.4180739267628582
7600	2019-12-22 22:08:19	2019-12-22	Magan Oberbrunner	magan.oberbrunner@woohoo.com	Phoenix	Arizona	501890303433784	ce7f5358fb9f7a03fc42d0bc95b629b1	JCB 15 digit	33.4726010800737939	-112.146787207426883
7601	2019-12-22 22:39:39	2019-12-22	Shay Muller	shay.muller@geemail.com	Berkeley	California	3158092386764404176	acdaa65ea65f90bd2f1d432f1a772eaf	Voyager	37.8401090176157666	-122.257315118087021
7602	2019-12-22 23:25:29	2019-12-22	Ms. Kanesha Murphy	ms.kanesha.murphy@geemail.com	Columbus	Ohio	3096610722504792004	2d8f06d23e233208a6f39d9b1fbfecf9	Voyager	40.0762548593383272	-83.0527463701322688
7603	2019-12-22 23:56:53	2019-12-22	Shalonda Braun	shalonda.braun@geemail.com	San Francisco	California	4224653637520277	f9bd2dba6426361c8514fa9c44c51875	Mastercard	37.7712129714457916	-122.406918107798205
7604	2019-12-23 00:35:29	2019-12-23	Jerrica Simonis	jerrica.simonis@geemail.com	Santa Clara	California	869905821029208745	25348e6a4921de9229d0199d2c8fad64	American Express	37.2803389560248704	-121.881355713493747
7605	2019-12-23 00:36:00	2019-12-23	Sherman Murazik	sherman.murazik@geemail.com	San Francisco	California	180004735804953179	634feb9d09e43774bacef7d39484c767	Diners Club / Carte Blanche	37.7741414863819429	-122.445496191058666
7606	2019-12-23 00:36:36	2019-12-23	Murphy Strosin	murphy.strosin@warmmail.com	New York	New York	3158176865463134498	dae402297ca1d863ed95a63a3edcc602	JCB 15 digit	40.6522557306326888	-73.8427810859762133
7607	2019-12-23 00:41:53	2019-12-23	Martez Sipes	martez.sipes@geemail.com	Mesa	Arizona	4898324350427	8b4f765077295171bc58e6dbf2f01821	American Express	33.4027927412796757	-111.61928435101882
7608	2019-12-23 01:16:26	2019-12-23	Dr. Aiden Botsford I	dr.aiden.botsford.i@geemail.com	Lowell	Massachusetts	54385610983729493	9389ae0dc149cc1de1fe290d49fda025	Maestro	42.6866067982148394	-71.3007430285088759
7609	2019-12-23 01:33:18	2019-12-23	Rondal Erdman-Casper	rondal.erdman.casper@geemail.com	San Francisco	California	676323532119023	60fcf30e9aca1cefd65b71d66d02b0c5	Mastercard	37.7768321189036982	-122.437085100047923
7610	2019-12-23 02:03:25	2019-12-23	Maymie Heaney-Von	maymie.heaney.von@woohoo.com	Tulsa	Oklahoma	4587230701579280	6f339cc84be4eb7f151ab03f176af5a7	Discover	36.1896184479255183	-95.812684827479714
7611	2019-12-23 02:13:18	2019-12-23	Parrish Jaskolski	parrish.jaskolski@geemail.com	Philadelphia	Pennsylvania	3528055086703763238	87ab221c7a861710823b33ca14630697	Voyager	40.0317471547011294	-75.2326306979071404
7612	2019-12-23 02:16:09	2019-12-23	Leota Pfannerstill	leota.pfannerstill@geemail.com	San Francisco	California	3096100639231359112	4584f3bd2bc749d5567af20f6c6b6680	VISA 16 digit	37.7821892476546495	-122.43922348692405
7613	2019-12-23 02:17:42	2019-12-23	Savanna Hamill-Hackett	savanna.hamill.hackett@geemail.com	Norman	Oklahoma	3472154829530367	1fe7b3bfec06040b56907da51e39cb8c	Mastercard	35.2506446918047942	-97.4398422111544704
7614	2019-12-23 02:29:07	2019-12-23	Haven Brekke	haven.brekke@geemail.com	Oklahoma City	Oklahoma	3045863262221324	e0f4120549be722aa61988a7d4fbd039	JCB 16 digit	35.4771303876213722	-97.5024478205375402
7615	2019-12-23 02:34:09	2019-12-23	Francisca Huel	francisca.huel@geemail.com	San Francisco	California	4428779460487	9323d5e4819d6db53d14539874966db1	Maestro	37.7439514030009278	-122.445727391991426
7616	2019-12-23 02:47:21	2019-12-23	Benny Ferry	benny.ferry@geemail.com	Brownsville	Texas	3437863680077128	45cb5f1c38638e916e34cb59dd410722	Diners Club / Carte Blanche	26.0903124992813886	-97.3882154565490765
7617	2019-12-23 02:51:13	2019-12-23	Alberto Heathcote	alberto.heathcote@geemail.com	Salinas	California	869923860352492466	c0d34155ef2e76208087dfabb8819fac	Discover	36.7788116496752906	-121.623475374624888
7618	2019-12-23 03:10:15	2019-12-23	Blair Schultz	blair.schultz@geemail.com	San Francisco	California	3058079944569959	f23a9c778a05cd281a976e4472299c81	American Express	37.7916250148834223	-122.413180275950765
7619	2019-12-23 03:48:14	2019-12-23	Rodrick Franecki	rodrick.franecki@geemail.com	New York	New York	54085726464901576	d7a19391577043f47d7403d28b206b52	VISA 16 digit	40.7323121996819992	-73.9145378446567776
7620	2019-12-23 04:05:22	2019-12-23	Marquis Berge	marquis.berge@geemail.com	Charlotte	North Carolina	6011405254981628542	2170b6ca4288a90e3a2be4163c110277	VISA 16 digit	35.160186809932064	-80.756303879007703
7621	2019-12-23 04:08:09	2019-12-23	Eartha Wolff DDS	eartha.wolff.dds@geemail.com	Oakland	California	4926237684430779	e4f9bfe47eb841be1c9662cab46dc0cb	VISA 13 digit	37.8268633318413023	-122.227196492252645
7622	2019-12-23 05:03:19	2019-12-23	Sabrina Schinner	sabrina.schinner@warmmail.com	Chula Vista	California	53390148248237161	b60d2d7a782cb4f43dba91d2ae6ad130	JCB 16 digit	32.6938491592880283	-117.09193678454011
7623	2019-12-23 05:05:07	2019-12-23	Cinthia Roberts	cinthia.roberts@warmmail.com	Houston	Texas	3016509386101590	a8afee2ed890322f00eec29bb915ddf2	Mastercard	29.8188632959112532	-95.3627290976714335
7624	2019-12-23 05:06:55	2019-12-23	Melvin Erdman	melvin.erdman@warmmail.com	Berkeley	California	3096190040079445710	5545fa23d6e57d49c14061a51dfbc0ec	American Express	37.8812959138178513	-122.270437730588867
7625	2019-12-23 05:47:55	2019-12-23	Lucian Herzog	lucian.herzog@geemail.com	Midland	Texas	4669120570928802	63c186d8f4b69f4b4255aaa868d61e43	Discover	32.0150889789875563	-102.199596687382083
7626	2019-12-23 06:14:47	2019-12-23	Dr. Mima Trantow	dr.mima.trantow@geemail.com	Oakland	California	4681602033236679	b05cefabc10318743d4e405a1d586535	JCB 16 digit	37.8007004543851437	-122.263559956227354
7627	2019-12-23 06:33:21	2019-12-23	Hurley Ruecker	hurley.ruecker@geemail.com	San Francisco	California	869914224106651367	2b1f12962c41713c1b55a1fd9c286393	Mastercard	37.8141605596667816	-122.401254505567934
7628	2019-12-23 07:12:46	2019-12-23	Francesco Tromp	francesco.tromp@geemail.com	Eugene	Oregon	4148069090498948	1c02bff351fed0391cd545809f5b103c	Discover	44.0938350868139395	-123.152330056437108
7629	2019-12-23 07:29:44	2019-12-23	Willard Moen	willard.moen@geemail.com	Chicago	Illinois	3437428745033969	98ae474adb6aaeaf3f88a8d6bdbf3f3b	Discover	41.9104978664148646	-87.5890623808868156
7630	2019-12-23 07:33:13	2019-12-23	Madora Graham DVM	madora.graham.dvm@geemail.com	San Francisco	California	675913457388935	b9fe5d07e498e0a9f1b9420ed6079c2a	American Express	37.7751093449545152	-122.421249600745568
7631	2019-12-23 07:33:37	2019-12-23	Pallie Muller-Stamm	pallie.muller.stamm@geemail.com	San Francisco	California	4091343899330215	cb9ff589cfb28c8941c50e9900ea9121	JCB 15 digit	37.7770427884858293	-122.436404192928066
7632	2019-12-23 07:43:41	2019-12-23	Shyanne Gibson	shyanne.gibson@geemail.com	Richmond	Virginia	4245884954895472	1f59599e63750456f60fb471c52e64d4	JCB 16 digit	37.5750279917135828	-77.4838464401885858
7633	2019-12-23 08:27:26	2019-12-23	Grove Balistreri	grove.balistreri@warmmail.com	Fort Worth	Texas	4262036722467815	220d88a1907cdc9fd12a91d4cbee5ee6	JCB 15 digit	32.7546804329436299	-97.3229467979919178
7634	2019-12-23 08:38:36	2019-12-23	Anissa Nienow DDS	anissa.nienow.dds@warmmail.com	Chicago	Illinois	54529869845705995	99a1448cb084b6ffdb5d6a70110a6302	JCB 16 digit	41.8664472410291424	-87.6917788303021268
7635	2019-12-23 10:09:39	2019-12-23	Simeon Breitenberg	simeon.breitenberg@geemail.com	Jacksonville	Florida	630452996760717	78bfbeda3a8e3306dd6b830248267c59	Maestro	30.2546436873316757	-81.7393015054132803
7636	2019-12-23 10:17:05	2019-12-23	Lora Farrell	lora.farrell@woohoo.com	Cleveland	Ohio	675955297559126	80a106966b072abf837c001905e2d264	VISA 16 digit	41.4431699596196381	-81.6579276690497977
7637	2019-12-23 10:18:06	2019-12-23	Shirlee Mohr-Witting	shirlee.mohr.witting@geemail.com	Los Angeles	California	3787351838058546	b4e61e3d1027e13965cd39dbc25f3a61	JCB 16 digit	34.0736640537489208	-118.431132233933724
7638	2019-12-23 10:25:09	2019-12-23	Vena Gaylord	vena.gaylord@geemail.com	Clarksville	Tennessee	3035287600908683	1eeeb13a329870495a511691c7b3df95	VISA 16 digit	36.6297015211205945	-87.438628405048334
7639	2019-12-23 10:46:57	2019-12-23	Riley Herman	riley.herman@woohoo.com	Oakland	California	210073894314316165	c867ce80287e7012837b7740118f3585	VISA 16 digit	37.8083896786495544	-122.28874389407882
7640	2019-12-23 11:13:21	2019-12-23	Jedidiah Hansen-Cole	jedidiah.hansen.cole@geemail.com	West Jordan	Utah	3088253232994003039	71bc249c5698a496cd4402d189c5709b	Diners Club / Carte Blanche	40.6767294930551202	-112.079454852416362
7641	2019-12-23 11:27:18	2019-12-23	Goebel Ratke	goebel.ratke@geemail.com	Los Angeles	California	4706969808891355	fb23bec4a33d737fea9537746aeed65b	Voyager	34.021483114534611	-118.427689078868553
7642	2019-12-23 11:30:25	2019-12-23	Mikhail Bradtke	mikhail.bradtke@geemail.com	Laredo	Texas	3739134622747279	4fec913baa8d7141a9af0f5bb618a929	Voyager	27.602164856688681	-99.4294081233914966
7643	2019-12-23 11:42:47	2019-12-23	Miss Berdie Schumm PhD	miss.berdie.schumm.phd@geemail.com	New York	New York	869959124512913854	c7726e219aaf294bfcce9a574d4d61a3	Discover	40.5674660591166472	-74.0073635866761208
7644	2019-12-23 11:56:07	2019-12-23	Breanna Stark	breanna.stark@geemail.com	Oakland	California	4144358220218845	64e86dc532fbf728a3a7ab2d486a0ef4	Diners Club / Carte Blanche	37.7806058548859411	-122.311102322604356
7645	2019-12-23 12:26:33	2019-12-23	Anjanette Boehm MD	anjanette.boehm.md@woohoo.com	League City	Texas	210046200323325151	2eed8e47a6b17ab2b37a3b233a411e53	JCB 16 digit	29.5852252165716152	-95.1058801052145668
7646	2019-12-23 12:37:53	2019-12-23	Bynum Heidenreich	bynum.heidenreich@geemail.com	New York	New York	180059180642550636	e299f23ccbce36a2f2302835244514c5	Discover	40.6338489980194737	-73.9895123103994905
7647	2019-12-23 13:13:42	2019-12-23	Emil Goodwin DVM	emil.goodwin.dvm@warmmail.com	New York	New York	4366096556763874	5b39b91f304a6f92f68e141c8e353943	Mastercard	40.7369822705853721	-73.9274721378356219
7648	2019-12-23 13:28:45	2019-12-23	Hurley Jast MD	hurley.jast.md@warmmail.com	Birmingham	Alabama	4007864417865	bd93048d401f60ae357d72ebd4b52872	Maestro	33.5888584988448784	-86.7909147713575635
7649	2019-12-23 14:28:49	2019-12-23	Leila Lakin	leila.lakin@geemail.com	Houston	Texas	3740538963432951	54d1056cd05b34e2f064e8c3c64a757b	Mastercard	29.6996455882754162	-95.4732562840931109
7650	2019-12-23 14:53:18	2019-12-23	Ronin Wunsch	ronin.wunsch@geemail.com	Raleigh	North Carolina	4643887613778482	8237cbaa19c79243fa5d3817a0f377af	Voyager	35.8172331052500752	-78.7348276870261969
7651	2019-12-23 16:11:50	2019-12-23	Reed Dickinson	reed.dickinson@geemail.com	Berkeley	California	4802911669993196	69bcbb03bbde5ce9934673a5c4467c5c	Mastercard	37.8576405610507933	-122.301342985732433
7652	2019-12-23 16:37:43	2019-12-23	Carolann O'Reilly-Raynor	carolann.o'reilly.raynor@geemail.com	San Francisco	California	3528648277437018320	7a45327a41832c2585fa139c1b7f6e6a	VISA 13 digit	37.7212363227372265	-122.443203068025255
7653	2019-12-23 18:11:02	2019-12-23	Lim Carter	lim.carter@geemail.com	Long Beach	California	3431564295149528	82cea016c4a06b603a1fcf65ebedc32c	JCB 16 digit	33.9008732262819947	-118.209219216338539
7654	2019-12-23 18:17:12	2019-12-23	Dr. Boyd Lemke	dr.boyd.lemke@geemail.com	North Las Vegas	Nevada	3039559253403014	b717007f7861a77a69ba78c437e5e28d	VISA 13 digit	36.2029591960523263	-114.996221774419396
7655	2019-12-23 18:38:04	2019-12-23	Magdalene Price	magdalene.price@geemail.com	Waco	Texas	630415272475789	49503e145ffad8038d6187b62663b03f	Mastercard	31.6187722048465147	-97.1059808990117261
7656	2019-12-23 18:45:10	2019-12-23	Media Waters	media.waters@geemail.com	Eugene	Oregon	4028203130202805	51b1ab9344370e9bb11832af46e1673b	JCB 16 digit	44.1040319030366845	-123.020962977687645
7657	2019-12-23 18:48:41	2019-12-23	Mrs. Lyric Kuvalis	mrs.lyric.kuvalis@woohoo.com	New York	New York	869916258987761687	8de666af727d7f74227f50c6f73b7043	VISA 16 digit	40.5911557721663243	-74.0166041580390157
7658	2019-12-23 18:59:02	2019-12-23	Griselda Bruen	griselda.bruen@geemail.com	Dallas	Texas	3727426603804424	90be5a75ab0b525b886680116d214a7b	VISA 16 digit	32.720366864212977	-96.7940587235577397
7659	2019-12-23 19:12:10	2019-12-23	Cicero Shields-Jacobi	cicero.shields.jacobi@geemail.com	San Francisco	California	180071574203971005	7e08626290d238d8227d7e7c2e0bff30	JCB 16 digit	37.8033308032461903	-122.420155320278752
7660	2019-12-23 20:31:48	2019-12-23	Kailyn Effertz	kailyn.effertz@geemail.com	Murfreesboro	Tennessee	4263532712668783	96ef8ac68b1a69866245e7d6b45ee495	VISA 16 digit	35.9300647041879628	-86.4496687461007411
7661	2019-12-23 20:33:26	2019-12-23	Raoul Parker	raoul.parker@geemail.com	Albuquerque	New Mexico	52421411480453653	f47e2f8bdd966b020e266ae3766f9e75	American Express	35.0166264724120495	-106.726482812508578
7662	2019-12-23 20:38:40	2019-12-23	Miss Chantelle Brakus MD	miss.chantelle.brakus.md@geemail.com	San Francisco	California	4638167942638831	d8a9c22568c36a761a572a2bd92660c0	Mastercard	37.7487268397422966	-122.400875641209012
7663	2019-12-23 21:00:40	2019-12-23	Cyril Weimann	cyril.weimann@geemail.com	San Francisco	California	3442654785203476	072a523d3955919cc0639144232c8ff2	JCB 16 digit	37.7661889686926528	-122.425271675337356
7664	2019-12-23 21:26:34	2019-12-23	Lossie Schmitt-Wunsch	lossie.schmitt.wunsch@warmmail.com	Lubbock	Texas	3480749200155799	8ce81ea0fa936bc7bd23dc85cfae2140	VISA 16 digit	33.564390298774839	-101.820257357359679
7665	2019-12-23 21:33:21	2019-12-23	Mrs. Mabell Quigley PhD	mrs.mabell.quigley.phd@warmmail.com	Los Angeles	California	4559555907059	bcf0f011beed81d7a7ae8d17f84f71db	Discover	34.0783156294707155	-118.451454631517819
7666	2019-12-23 21:42:00	2019-12-23	Norman Emmerich	norman.emmerich@geemail.com	Oklahoma City	Oklahoma	6011955408157044116	0f70c0904c94fe4fde8b15c82d86bf3b	VISA 13 digit	35.3856311415232767	-97.5738299499161599
7667	2019-12-23 22:33:00	2019-12-23	Janiyah Bosco	janiyah.bosco@woohoo.com	Westminster	Colorado	3158120901987388539	b54dcd1507aeb435a18e466d27e86c69	JCB 15 digit	39.8579307519670536	-105.02593552876786
7668	2019-12-23 22:44:59	2019-12-23	Dr. Era Cronin DVM	dr.era.cronin.dvm@geemail.com	Boise	Idaho	6011862398810308390	118b100102f73264ef41249ee0d2d2ee	Discover	43.5570666481412943	-116.206486875443531
7669	2019-12-24 00:10:26	2019-12-24	Ilona Upton	ilona.upton@geemail.com	Cleveland	Ohio	3096440764836484195	17294f49f752e2d365944caef44ea18b	Mastercard	41.5136489954162329	-81.6633669907465531
7670	2019-12-24 00:17:42	2019-12-24	Georgia Schmeler	georgia.schmeler@geemail.com	Raleigh	North Carolina	6011861875348653877	18c083cd3d6cbaa84e100069acd4b6d1	Discover	35.7386787908285797	-78.6244461127493537
7671	2019-12-24 00:47:52	2019-12-24	Delano Nienow DDS	delano.nienow.dds@warmmail.com	San Francisco	California	3096881976489014857	e147926a88af4f3efedb49e10df01bca	JCB 16 digit	37.7779830841281381	-122.43299842806411
7672	2019-12-24 01:15:56	2019-12-24	Mr. Willie Nienow IV	mr.willie.nienow.iv@geemail.com	Seattle	Washington	3043724204966883	fb10bd0e4c16889601e0fb938560169e	Mastercard	47.7158033345751491	-122.403401649316393
7673	2019-12-24 01:20:04	2019-12-24	Mr. Drew Reilly IV	mr.drew.reilly.iv@geemail.com	Shreveport	Louisiana	4378946326689443	0c62f87f65ef06a478335fbd1c0eca58	VISA 16 digit	32.442454244825619	-93.7112106922294856
7674	2019-12-24 01:24:52	2019-12-24	Sherrill Hyatt	sherrill.hyatt@woohoo.com	Los Angeles	California	3747736332798507	c7a8e99977e72e6155fb2e59abee6a6a	JCB 15 digit	33.9604724957007917	-118.373943805554134
7675	2019-12-24 01:47:37	2019-12-24	Dana Deckow	dana.deckow@geemail.com	Rialto	California	6011895237656611312	b2404b9a0944ca826aa927c9397ab891	JCB 16 digit	34.1771269680682579	-117.329008851208911
7676	2019-12-24 02:02:27	2019-12-24	Lashunda Nader-Kilback	lashunda.nader.kilback@geemail.com	Fresno	California	869965844637694418	1bf766ec0ce2c20d785748efe56f5b6c	JCB 15 digit	36.8337826900523169	-119.768440814885878
7677	2019-12-24 02:02:35	2019-12-24	Clarinda Roberts	clarinda.roberts@geemail.com	Kansas City	Missouri	3528099818638381951	757f90f9f67af5436bb36216f9721b1a	Maestro	39.202861060418563	-94.6111933353114836
7678	2019-12-24 02:08:53	2019-12-24	Roseanna Gutmann DDS	roseanna.gutmann.dds@geemail.com	San Francisco	California	503818385439825	391f49295876809031b3cdceb1ee3f3d	VISA 16 digit	37.8045035972553904	-122.436586788791104
7679	2019-12-24 02:14:15	2019-12-24	Dr. Braulio Herman	dr.braulio.herman@woohoo.com	Sioux Falls	South Dakota	676217429462058	20dfd0529085705fd262054d7d233181	VISA 13 digit	43.4453247828960443	-96.7782036221288138
7680	2019-12-24 02:49:22	2019-12-24	Mrs. Merry Kessler	mrs.merry.kessler@geemail.com	Sunnyvale	California	3112949803788121862	444491cc8f1693415bc9b5746b76264e	JCB 16 digit	37.4824157248243708	-122.096998706759152
7681	2019-12-24 03:07:48	2019-12-24	Dr. Tiesha Cartwright	dr.tiesha.cartwright@geemail.com	Montgomery	Alabama	53209629437432946	50164276e3e57d4496cdaa0d01f54bb1	Diners Club / Carte Blanche	32.3682697091650198	-86.2166284593440508
7682	2019-12-24 04:17:02	2019-12-24	Arman Marks	arman.marks@geemail.com	Henderson	Nevada	4456550374605460	3d845701af0472de773176c6ed978239	Maestro	36.0460910381216593	-115.024943039954465
7683	2019-12-24 04:34:43	2019-12-24	Ember Smitham MD	ember.smitham.md@woohoo.com	San Francisco	California	3158019708817681650	ecfb47502cee95ce9fb4870d51c519a2	Discover	37.7862874689889736	-122.39312496687559
7684	2019-12-24 04:39:15	2019-12-24	Dillon Streich-Morar	dillon.streich.morar@geemail.com	San Antonio	Texas	3466053504224338	fc365ac4c60f7bdd87cb84dbf63be8bb	JCB 15 digit	29.4920269973181206	-98.5227859359536211
7685	2019-12-24 05:10:45	2019-12-24	Melany Grimes	melany.grimes@geemail.com	San Diego	California	4832495529378	f449b74cb8dea88797f34fd2a4cc403a	Voyager	32.7403563897192456	-117.20832482002676
7686	2019-12-24 05:16:24	2019-12-24	Kittie Ferry PhD	kittie.ferry.phd@geemail.com	Miami Gardens	Florida	210081288084961179	3556cc0d5a3e1b3b4ad1b37783e09bfb	JCB 15 digit	26.0219782607104619	-80.2749627905677983
7687	2019-12-24 05:27:50	2019-12-24	Sonny Kautzer	sonny.kautzer@woohoo.com	San Francisco	California	3337345743830058516	8f60ed7d5aa55802ab3fb051b4a39c46	JCB 16 digit	37.8073144086945376	-122.421587498845398
7688	2019-12-24 05:47:22	2019-12-24	Jaylen McDermott DVM	jaylen.mcdermott.dvm@geemail.com	San Francisco	California	3088836201908502184	5b7fda6f8ee34b7d11e9724fb6e78d78	JCB 16 digit	37.7407615290645495	-122.438471610535927
7689	2019-12-24 05:54:06	2019-12-24	Jermey Rutherford	jermey.rutherford@geemail.com	Oakland	California	6011433882854466677	4941835d3c664ea1156fd064eec20fa7	Diners Club / Carte Blanche	37.7908140772866332	-122.272330219120008
7690	2019-12-24 06:13:06	2019-12-24	Tyrik Boehm	tyrik.boehm@geemail.com	Oakland	California	3036732800268809	216c82805f2d500559115bf103141b51	Maestro	37.8319585693623637	-122.26868770658831
7691	2019-12-24 06:16:55	2019-12-24	Eleonore Schamberger	eleonore.schamberger@woohoo.com	Berkeley	California	4777568503166	c058022107cffb29951fd2d33760712c	Voyager	37.8552629513902374	-122.259426451364234
7692	2019-12-24 06:47:19	2019-12-24	Lenon Douglas	lenon.douglas@geemail.com	Orlando	Florida	54930890487063579	44cf29c53d911a4e0811ff53c6705313	Mastercard	28.4731958729479437	-81.3503607448622574
7693	2019-12-24 08:08:36	2019-12-24	Aubrey Bednar	aubrey.bednar@geemail.com	Amarillo	Texas	4367081777262301	65e099b7cd9a037b04d7d3564d7a5f37	JCB 15 digit	35.1392746158108125	-101.815340605317431
7694	2019-12-24 09:16:45	2019-12-24	Harlow Walter	harlow.walter@woohoo.com	Chandler	Arizona	54059964651891282	cc6b1f0442e99f83fbc3f8cf30cc0183	Maestro	33.2595622426453943	-111.897503305913503
7695	2019-12-24 09:30:38	2019-12-24	Mrs. Risa O'Conner PhD	mrs.risa.o'conner.phd@geemail.com	High Point	North Carolina	869905646678315719	22a8843de3c7d7d066e79e6052e18bf4	JCB 16 digit	36.0721146523579961	-80.0113289945498138
7696	2019-12-24 09:32:06	2019-12-24	Mr. Festus Cassin I	mr.festus.cassin.i@geemail.com	San Jose	California	3034815340781423	cdb60536ee473a71389a8557fd478d14	Diners Club / Carte Blanche	37.2810713724054423	-121.780206879622867
7697	2019-12-24 09:56:47	2019-12-24	Jacey Armstrong-Jerde	jacey.armstrong.jerde@geemail.com	Columbia	Missouri	3337519484110593738	3b1c6b4ef5839d526d9be97c87911405	JCB 16 digit	38.9034470382493538	-92.3551719615289102
7698	2019-12-24 10:00:29	2019-12-24	Dilan Volkman	dilan.volkman@geemail.com	Ann Arbor	Michigan	630480058564297	6edd6e3cb353b2d021900fca7830bb99	Mastercard	42.2191523412302132	-83.7055912517119225
7699	2019-12-24 10:03:14	2019-12-24	Dr. Medora Farrell DDS	dr.medora.farrell.dds@geemail.com	Brownsville	Texas	3158249338788319007	b014941acb9cc4faed46d286b0fd9c01	JCB 15 digit	25.9567664541382328	-97.450586168626316
7700	2019-12-24 10:12:56	2019-12-24	Cordie Crooks MD	cordie.crooks.md@geemail.com	Berkeley	California	4279326715241413	6dded04f13f2835e5687d5b619d92476	VISA 13 digit	37.8647660052231743	-122.284946512196697
7701	2019-12-24 10:36:04	2019-12-24	Cyndi Bins	cyndi.bins@warmmail.com	Cedar Rapids	Iowa	4435816383703141	94612030dcdd36879b9ff2f39514d8e1	VISA 16 digit	41.8927217803969967	-91.7586817693963752
7702	2019-12-24 10:43:53	2019-12-24	Garland Conroy-Collier	garland.conroy.collier@geemail.com	Norwalk	California	675935211200072	4cfa197dda1a2cd4d1f88c35810f1d2f	JCB 16 digit	33.9556871449690334	-118.085697726583106
7703	2019-12-24 11:07:26	2019-12-24	Mr. Halsey Rosenbaum DVM	mr.halsey.rosenbaum.dvm@woohoo.com	Laredo	Texas	4190434972708	555d51dba389508c098d2c2ea935fc51	Diners Club / Carte Blanche	27.4831992876432842	-99.5592619813986062
7704	2019-12-24 11:20:28	2019-12-24	Allen Jast Jr.	allen.jast.jr.@warmmail.com	Los Angeles	California	52338896428589802	012831d1f977518d25ccf20ff2bdff8c	JCB 16 digit	34.0476067197840635	-118.482799603416765
7705	2019-12-24 11:53:11	2019-12-24	Eli Quitzon	eli.quitzon@woohoo.com	Oakland	California	3024792359702774	bd3481e82b538373419f0e0e78f8d0bb	VISA 16 digit	37.829749247490625	-122.249124768502611
7706	2019-12-24 12:43:11	2019-12-24	Dr. Jeramie Gislason	dr.jeramie.gislason@geemail.com	Berkeley	California	3055843904775069	e323a86d38e48bac630fbda823921c0f	Diners Club / Carte Blanche	37.8639328889089271	-122.277041169773511
7707	2019-12-24 13:11:39	2019-12-24	Mr. Horatio Parisian Sr.	mr.horatio.parisian.sr.@geemail.com	Oakland	California	6011558272510335384	4d13b79c70954be3377e6bde5acb25d6	Mastercard	37.8011493323595076	-122.281620916721224
7708	2019-12-24 13:23:08	2019-12-24	Estie Ryan	estie.ryan@geemail.com	Fort Worth	Texas	6011490635847509635	5741d0a5da2ebb8203a11969837478ff	VISA 16 digit	32.8015364679098127	-97.4025497373014701
7709	2019-12-24 14:08:32	2019-12-24	Ms. Fran Schamberger DDS	ms.fran.schamberger.dds@geemail.com	Baltimore	Maryland	4720580610339335	6726f88feaf8569672024e99ec039ea3	American Express	39.208978171786292	-76.5952597084939555
7710	2019-12-24 14:09:40	2019-12-24	Kizzy Ebert	kizzy.ebert@geemail.com	Berkeley	California	869953602830945290	71b5432cbd5195c2729ddad1c01371ae	Discover	37.8533834886569096	-122.251683730436952
7711	2019-12-24 14:15:23	2019-12-24	Chalmer Turner-Schimmel	chalmer.turner.schimmel@geemail.com	Phoenix	Arizona	4983587928588	8677ed81884e6a202fd7db3cfec97812	Diners Club / Carte Blanche	33.600713308428233	-112.154265807841355
7712	2019-12-24 15:11:43	2019-12-24	Miss Trula Steuber MD	miss.trula.steuber.md@geemail.com	Pompano Beach	Florida	4368781615175222	aaa596fb8d4aeb13806e40d974646069	JCB 15 digit	26.3385592003617433	-80.2053679873082785
7713	2019-12-24 15:11:44	2019-12-24	Pierre Fisher	pierre.fisher@warmmail.com	Minneapolis	Minnesota	4956760411058988	4cee6397c1b90cd5e50318d645088a7e	VISA 13 digit	44.9088582075286595	-93.2104769984532169
7714	2019-12-24 16:13:56	2019-12-24	Annabella Bradtke	annabella.bradtke@woohoo.com	Wilmington	North Carolina	3158568435335155273	260fa7f7f85facf7ae085088a2fc6fb4	Maestro	34.2001420581534532	-77.8178018159691334
7715	2019-12-24 16:58:46	2019-12-24	Jaycie Emmerich	jaycie.emmerich@warmmail.com	New York	New York	501844001329422	b10e4aec5e61e0bc25d6e88f05d97707	JCB 15 digit	40.6266146625149958	-73.8404661217134475
7716	2019-12-24 17:29:33	2019-12-24	Brylee Schmidt	brylee.schmidt@geemail.com	Los Angeles	California	3419884127847537	6e8c4ad286cf4f3f16825c3b52daee15	VISA 16 digit	34.06770022812821	-118.312876532086349
7717	2019-12-24 17:52:00	2019-12-24	Conor Gulgowski	conor.gulgowski@geemail.com	Midland	Texas	3047102830364565	30c9d5c99a042c2936ce63b9028caedc	VISA 16 digit	32.0760161556959176	-102.034667445229374
7718	2019-12-24 19:19:45	2019-12-24	Myrtice Johns	myrtice.johns@geemail.com	San Francisco	California	3088539318235756596	ffcbf2351af84ba83ac679b6d3c69acc	Mastercard	37.7510912579415958	-122.451297542107739
7719	2019-12-24 19:23:00	2019-12-24	Emma Kautzer Jr.	emma.kautzer.jr.@geemail.com	Scottsdale	Arizona	4339928484345693	06bb2cc4058f4475bf26be01003465e6	Discover	33.5971597095143082	-111.867772693323332
7720	2019-12-24 19:47:30	2019-12-24	Lucious Shields	lucious.shields@geemail.com	Modesto	California	6011925806301089787	6e6c35fc7d8475c3c89f1f17eb432a79	JCB 16 digit	37.6301411240827335	-120.956959207469595
7721	2019-12-24 20:09:57	2019-12-24	Mr. Moshe Steuber IV	mr.moshe.steuber.iv@geemail.com	San Francisco	California	3036313737064486	cbe6faf260cea3f18c2362cba9b2baa5	VISA 13 digit	37.7969524827262759	-122.438699776836643
7722	2019-12-24 20:13:04	2019-12-24	Mr. Marcos Block MD	mr.marcos.block.md@warmmail.com	Philadelphia	Pennsylvania	3528827279668713556	c06c8afe28e3c1cfa163cd96c3eb7e64	Mastercard	39.9372816417325254	-75.2095263542506842
7723	2019-12-24 20:49:00	2019-12-24	Mrs. Mathilde Doyle MD	mrs.mathilde.doyle.md@warmmail.com	Tulsa	Oklahoma	4494434746674146	0c6dbf20bf753dab0656a1eeb212b84b	American Express	36.139439042042568	-95.8911241807930139
7724	2019-12-24 22:12:14	2019-12-24	Gisele Dickinson	gisele.dickinson@geemail.com	San Francisco	California	180045829518641138	808f1722b85ebaf654edafa4e38552fa	Voyager	37.7716459447595341	-122.411891574639753
7725	2019-12-24 22:27:11	2019-12-24	Pat Leuschke	pat.leuschke@geemail.com	Portland	Oregon	6011206333223466902	a1c0a7797f5a451be36cb2720aa4f1f1	Maestro	45.5020820534676318	-122.582313869195062
7726	2019-12-24 22:37:09	2019-12-24	Ginger Goldner-Shields	ginger.goldner.shields@geemail.com	San Francisco	California	6011208231655932847	eb12ffe3d4a00daa2070cdeabf4b40ff	JCB 16 digit	37.7892599908131928	-122.422212543353197
7727	2019-12-24 22:42:11	2019-12-24	Dr. Ferman VonRueden III	dr.ferman.vonrueden.iii@geemail.com	Chesapeake	Virginia	4857295185237781	f13353a68d76241883edbf22510143ee	JCB 16 digit	36.7035030159406404	-76.3761215878494113
7728	2019-12-24 22:49:50	2019-12-24	Marlee Gulgowski-Koss	marlee.gulgowski.koss@woohoo.com	Cleveland	Ohio	675935656255268	22c36344908f2265b4b0951e5a3065de	Diners Club / Carte Blanche	41.5305432222634536	-81.5877590314257901
7729	2019-12-24 22:57:32	2019-12-24	Jamel Reichel	jamel.reichel@geemail.com	Oakland	California	3096024347085326004	22b0421cd770ba9483d65fa49b89c3e0	JCB 16 digit	37.8100768637213207	-122.254543420771327
7730	2019-12-25 00:15:51	2019-12-25	Herschel Kuphal-Stark	herschel.kuphal.stark@geemail.com	Jackson	Mississippi	3096665878262223360	542aaea4e244c4e2f8de16cd013493a6	Discover	32.3908431672670005	-90.1274443943958801
7731	2019-12-25 00:38:15	2019-12-25	Stephon Schaefer	stephon.schaefer@woohoo.com	Fort Worth	Texas	3416802685724818	fa9917721fa077b15b8ae9d4f2d9cd39	Diners Club / Carte Blanche	32.7578904458377522	-97.2615353011347281
7732	2019-12-25 00:48:52	2019-12-25	Misael Jenkins-Witting	misael.jenkins.witting@warmmail.com	Columbia	Missouri	180086532469152994	05a32f5d708363ee694aab07e58f7625	JCB 16 digit	38.9452389787763948	-92.3382090115507168
7733	2019-12-25 01:03:58	2019-12-25	Mr. Tyrin Bins	mr.tyrin.bins@geemail.com	Lubbock	Texas	3799618875136302	c2dbe150d529554710a0b579e04e5b43	Maestro	33.662299821762744	-101.886476255758481
7734	2019-12-25 01:21:02	2019-12-25	Dorr Deckow	dorr.deckow@geemail.com	Albuquerque	New Mexico	4390626816874739	dd1e96d81925b4192fc180533b37bc1b	JCB 15 digit	35.1754918399401006	-106.660165006255369
7735	2019-12-25 01:49:17	2019-12-25	Berenice Littel	berenice.littel@geemail.com	San Francisco	California	4218155983948704	cd29ae182c0708cfd444d33c6ec112ed	VISA 13 digit	37.770488766181586	-122.438966262916594
7736	2019-12-25 02:37:42	2019-12-25	Dr. Marcellus Fadel	dr.marcellus.fadel@warmmail.com	Fort Lauderdale	Florida	3158998897722892752	affb2213a3d53a27d993736a3a54bb4c	JCB 15 digit	26.2259459930460928	-80.2099755692116929
7737	2019-12-25 02:46:56	2019-12-25	Shan Zemlak	shan.zemlak@geemail.com	Austin	Texas	869995676602214531	a893040ae6e058aa77c9fecbd7f2a759	American Express	30.3175378530412907	-97.782740888116507
7738	2019-12-25 02:47:49	2019-12-25	Khalid Stracke	khalid.stracke@woohoo.com	Akron	Ohio	3528935318297435287	a2442f292929231b3dca421d0c8be657	Discover	41.0773449926935115	-81.5572762957621364
7739	2019-12-25 02:48:38	2019-12-25	Levern Senger-Kihn	levern.senger.kihn@geemail.com	Charlotte	North Carolina	4940732637662	f78c9c88ed158de48bac0eaeef60fffa	Mastercard	35.1944129339206953	-80.7497175631523163
7740	2019-12-25 02:52:30	2019-12-25	Jayvon Dickinson	jayvon.dickinson@warmmail.com	Dallas	Texas	4820966298946	4e388e63fb4425687602e3a6d11bd5d2	JCB 16 digit	32.7043586330760263	-96.7593223364055035
7741	2019-12-25 03:14:31	2019-12-25	Mr. Herman Dietrich	mr.herman.dietrich@warmmail.com	San Francisco	California	3743444970236856	323a42f9cfcaa02aea28b5989803c107	Voyager	37.7603561465784381	-122.41693759344416
7742	2019-12-25 03:24:12	2019-12-25	Kelsea Satterfield	kelsea.satterfield@warmmail.com	Daly City	California	53143909383988318	d63173c3a53358975e568ffb76bd1ca4	JCB 16 digit	37.7427784860521527	-122.420417298572147
7743	2019-12-25 03:30:46	2019-12-25	Shanda Buckridge	shanda.buckridge@woohoo.com	Houston	Texas	51214426608597646	3e510acb41ec6b2ad5e0b83d31f69413	JCB 16 digit	29.7778208748981363	-95.3306902833297869
7744	2019-12-25 03:51:50	2019-12-25	Shawnna Bruen	shawnna.bruen@warmmail.com	Amarillo	Texas	630471837801597	08ee682015a412e022b849a1e1ba4e95	JCB 16 digit	35.2881736999075883	-101.803489183760064
7745	2019-12-25 04:29:29	2019-12-25	Keyon O'Kon-Fay	keyon.o'kon.fay@geemail.com	Berkeley	California	3458297484858306	09e18e6c2295d902fd97a5efeb9385f9	JCB 16 digit	37.9169015366449216	-122.263811007870629
7746	2019-12-25 04:49:47	2019-12-25	Kinsey Nitzsche-Wunsch	kinsey.nitzsche.wunsch@warmmail.com	Berkeley	California	3528954430178727108	3c0d7db74734cf4acbadef4cb5ee59fa	Maestro	37.8240629301364422	-122.249014884732361
7747	2019-12-25 04:53:41	2019-12-25	Moshe Feeney	moshe.feeney@geemail.com	San Francisco	California	060456726398466	f6164f2697f1bfd33eb533668149a03a	Diners Club / Carte Blanche	37.7657972270154048	-122.429024573103902
7748	2019-12-25 05:37:53	2019-12-25	Rettie Roob	rettie.roob@geemail.com	Springfield	Massachusetts	3007465825025180	83e45aa01e7ca1c41b84d66d98c1a25c	VISA 16 digit	42.2012730162795577	-72.5075383785739547
7749	2019-12-25 06:11:30	2019-12-25	Floyd Conroy	floyd.conroy@woohoo.com	Augusta	Georgia	55489736362133026	dca774d54a0416383e86a4350d5f087a	VISA 16 digit	33.4108820495866183	-82.05056716551222
7750	2019-12-25 06:12:01	2019-12-25	Ms. Lannie Steuber DVM	ms.lannie.steuber.dvm@geemail.com	San Antonio	Texas	3337166035159954797	5cd2eea670ae67f206e48ce4d8ab825c	JCB 16 digit	29.5039894902683812	-98.4592361633967528
7751	2019-12-25 06:14:56	2019-12-25	Juliana Muller	juliana.muller@geemail.com	New York	New York	54396836587537589	6837df6460e9acda31f17a71734522e8	VISA 13 digit	40.7519446397423764	-73.9649082569301157
7752	2019-12-25 06:54:21	2019-12-25	Leah Collins	leah.collins@geemail.com	Tulsa	Oklahoma	4987891701664	14235ff502af2b868a76004fb90f3972	Discover	36.116654596095529	-95.9435147744093086
7753	2019-12-25 07:36:10	2019-12-25	Rozella Volkman MD	rozella.volkman.md@geemail.com	Little Rock	Arkansas	180093072744155471	9a4fe7d0223f3d96ba8f8deafa98f8ed	Diners Club / Carte Blanche	34.6354439994595964	-92.3389749773651261
7754	2019-12-25 07:50:36	2019-12-25	Jaron Stokes	jaron.stokes@geemail.com	Indianapolis	Indiana	3048257726707530	731437393bada40d3add08974790a3cf	VISA 16 digit	39.7372973932426419	-86.2204973813347522
7755	2019-12-25 08:16:11	2019-12-25	Verna Hyatt	verna.hyatt@warmmail.com	San Francisco	California	3096707387094146849	208ddaf27c4780b41397e625fe5ab76f	JCB 16 digit	37.7708745084749324	-122.442609924339735
7756	2019-12-25 09:13:01	2019-12-25	Duke Nicolas	duke.nicolas@geemail.com	Irvine	California	3442982597066256	3ddbde445a2eabc8cc24de4ff7e8f7f4	Mastercard	33.6121376584764633	-117.807275280217823
7757	2019-12-25 09:16:28	2019-12-25	Octave Cassin	octave.cassin@geemail.com	Fairfield	California	3528371060075059142	bae7e8776deee86d6eefab9c99bf7233	VISA 16 digit	38.2860634723335522	-122.128117661411309
7758	2019-12-25 09:33:59	2019-12-25	Johnie Waters	johnie.waters@geemail.com	San Francisco	California	3035056897976061	86e7f220673b939a5f343237466df48c	Voyager	37.7753676683105226	-122.42040100534355
7759	2019-12-25 09:34:14	2019-12-25	Jayce Zieme I	jayce.zieme.i@geemail.com	Baltimore	Maryland	869964222089294550	d7296647fbdbba7ca5ca14fa099c0db5	Mastercard	39.2503032636363045	-76.5980483946874813
7760	2019-12-25 10:43:34	2019-12-25	Jeffrey Larson	jeffrey.larson@geemail.com	Oakland	California	6011799578370397754	ddeb35f15aaba4e1ee4aa50097c6314f	JCB 16 digit	37.7970309398441628	-122.284883409555619
7761	2019-12-25 10:48:45	2019-12-25	Mr. Adalberto Schiller MD	mr.adalberto.schiller.md@geemail.com	Frisco	Texas	54875491383831792	08066d48d4840f800614dc66ae55eb41	Mastercard	33.1871189822439092	-96.901217080906406
7762	2019-12-25 10:54:18	2019-12-25	Casey Feil	casey.feil@warmmail.com	Oakland	California	4628002796651121	18e5af49b81aec154ef7d05d31c07725	Discover	37.7742475723865638	-122.291538364281479
7763	2019-12-25 11:32:52	2019-12-25	Beadie Brakus	beadie.brakus@geemail.com	Albuquerque	New Mexico	3047033334137936	9c2f785f9315a4f8b5554084b94ed421	JCB 15 digit	35.1548173753213149	-106.67916711685956
7764	2019-12-25 12:22:06	2019-12-25	Auguste Boyle	auguste.boyle@warmmail.com	Broken Arrow	Oklahoma	3528143418937695734	4d2ca08a2519cd2d2050e6a4d2c5f1ab	Maestro	36.0420328680667978	-95.7446957654263855
7765	2019-12-25 12:26:35	2019-12-25	Candy Kiehn	candy.kiehn@geemail.com	San Antonio	Texas	3044560665061965	c7c23dd041834d6cc26e7ba19234df89	American Express	29.3971480143792938	-98.5096987500622845
7766	2019-12-25 12:26:52	2019-12-25	Quinn Kemmer	quinn.kemmer@warmmail.com	Oakland	California	3158251436815639283	8251b4ca1c3478bc48ae8a5ce3b25b68	JCB 16 digit	37.7937935385710588	-122.269323294291084
7767	2019-12-25 13:34:48	2019-12-25	Kloe Bergnaum	kloe.bergnaum@geemail.com	Fremont	California	4568638055092440	7c968f4de379eda374de35b5b06573ea	Discover	37.4926833988800681	-121.985116666274891
7768	2019-12-25 13:42:31	2019-12-25	Verne Hintz	verne.hintz@geemail.com	Chicago	Illinois	4776027509053042	4e9947316ba685003ce920686bdbfb7c	VISA 16 digit	41.8727244099438209	-87.7363989088714078
7769	2019-12-25 14:54:51	2019-12-25	Daneen Goyette	daneen.goyette@warmmail.com	San Francisco	California	3337917542887779901	77a5cfa773f6d29cceb49823760da304	Voyager	37.7916270440919106	-122.419875236209577
7770	2019-12-25 15:26:37	2019-12-25	Essa Cremin	essa.cremin@geemail.com	Chicago	Illinois	4304182970508973	663d23fa769fecf8a9f609711f30888f	JCB 15 digit	41.7626837727449853	-87.6746989216219532
7771	2019-12-25 15:47:02	2019-12-25	Amari Macejkovic	amari.macejkovic@geemail.com	Oakland	California	3112002675575615478	a2a0b1f9fef20ed5b89b993aa5d74133	JCB 16 digit	37.8014621381327345	-122.248759663600183
7772	2019-12-25 15:52:37	2019-12-25	Verna Nienow	verna.nienow@warmmail.com	San Francisco	California	4979928553339333	2cd6574ce553d87cd6f0c7c2eb3ad161	American Express	37.758719313551552	-122.414444532589911
7773	2019-12-25 16:17:45	2019-12-25	Madlyn Bradtke	madlyn.bradtke@geemail.com	Pomona	California	52331735431005801	fdb343ee0b4776e54b7f54207e26e778	Diners Club / Carte Blanche	34.1130168721582763	-117.834201796954872
7774	2019-12-25 16:21:10	2019-12-25	Buffy Hudson	buffy.hudson@geemail.com	San Diego	California	6011321777453627080	61b84a2ec081cfd1df9b4226480ea426	VISA 16 digit	32.8604883206609628	-117.090346040613952
7775	2019-12-25 16:24:52	2019-12-25	Lucious Lindgren	lucious.lindgren@geemail.com	Honolulu	Hawaii	869910182948161116	5e738bb14b405ef3bf68774e3e0bf4e0	VISA 16 digit	21.2274385845970386	-157.839593499640387
7776	2019-12-25 17:02:09	2019-12-25	Adrianne Daugherty	adrianne.daugherty@warmmail.com	San Francisco	California	3435650421647299	fe52cfe88db680da07b0b398c99b467a	JCB 16 digit	37.756899009105986	-122.4609610428233
7777	2019-12-25 17:10:11	2019-12-25	Mayme O'Keefe	mayme.o'keefe@warmmail.com	San Diego	California	3158041294619063910	0be8b49f4f33f8d4da67f74bd8165dba	JCB 15 digit	32.9065531483918434	-117.228562715780001
7778	2019-12-25 17:45:59	2019-12-25	Elena Wyman	elena.wyman@geemail.com	Las Vegas	Nevada	52659569638515013	7a8bd182f28902a33efc2ffc7b3fd130	VISA 13 digit	36.1627428463295075	-115.194376106301689
7779	2019-12-25 17:49:10	2019-12-25	Mireya Terry DDS	mireya.terry.dds@geemail.com	Houston	Texas	4454115444416603	185e2bc04a3d10abea6ce33bfbd15f6a	Mastercard	29.8756484674368039	-95.3744295432712903
7780	2019-12-25 17:59:21	2019-12-25	Osborne Stracke	osborne.stracke@woohoo.com	Chicago	Illinois	6011513390431898209	ede441c9ae8ff1e961a4a803a799978a	Voyager	41.893843399810045	-87.5947889270756406
7781	2019-12-25 18:08:24	2019-12-25	Dora Hodkiewicz PhD	dora.hodkiewicz.phd@geemail.com	Birmingham	Alabama	4018973088145766	53a1c42dd0dd46241f9caa92806e8378	Voyager	33.5872727736622068	-86.8371305708549954
7782	2019-12-25 18:14:53	2019-12-25	Dr. Lisbeth Franecki	dr.lisbeth.franecki@warmmail.com	San Francisco	California	54150177562149025	063f81c63704d34163f1e7ac6dd27fd3	Mastercard	37.7518936260971216	-122.416434131186847
7783	2019-12-25 19:36:40	2019-12-25	Dr. Hedwig Kuphal MD	dr.hedwig.kuphal.md@warmmail.com	San Francisco	California	3039545508239238	2256ea85f3b6eee76555e5a368261da2	Discover	37.7914896747106681	-122.424248503961962
7784	2019-12-25 19:51:43	2019-12-25	Ira Shanahan	ira.shanahan@geemail.com	San Antonio	Texas	52109693844637464	ac946c2ac92e827e5c8c2b4ec94d8fa8	JCB 16 digit	29.5115799623612318	-98.4550477032385771
7785	2019-12-25 20:10:39	2019-12-25	Jerrad Koch	jerrad.koch@geemail.com	Omaha	Nebraska	869985535881213295	95094a589637423fb0d41b7cc798b0ea	Diners Club / Carte Blanche	41.2345478265225935	-96.1360998446702979
7786	2019-12-25 20:19:54	2019-12-25	Dr. Dessie Shanahan Jr.	dr.dessie.shanahan.jr.@geemail.com	San Diego	California	3010727497804508	825f6b92db5e0b7755e86a4c3ab7a658	JCB 16 digit	32.8176205978330202	-117.108614206630747
7787	2019-12-25 20:54:58	2019-12-25	Ednah Marks	ednah.marks@woohoo.com	San Francisco	California	210040829923444032	d3c38d04a31113da434df935a0685bfe	Voyager	37.7882636693088045	-122.437643148997694
7788	2019-12-25 21:07:13	2019-12-25	Talmage Lueilwitz	talmage.lueilwitz@woohoo.com	Oakland	California	869999310519071059	27ea08f807226c116973980ea7522723	Discover	37.8115767151080391	-122.304746724112405
7789	2019-12-25 21:09:47	2019-12-25	Miss Zillah Bernhard DVM	miss.zillah.bernhard.dvm@geemail.com	Jacksonville	Florida	3088386510114490545	94231075daa34334c4e60f802ad677fd	Maestro	30.4004702952276915	-81.56278987038732
7790	2019-12-25 21:43:09	2019-12-25	Stephania Stiedemann	stephania.stiedemann@woohoo.com	St. Louis	Missouri	4803244631580050	a1bb5941ee00f2a98ae73f9d436c96e3	JCB 16 digit	38.5424215098533764	-90.1487611016728039
7791	2019-12-25 22:01:53	2019-12-25	Jocelyne Renner-Kub	jocelyne.renner.kub@geemail.com	Philadelphia	Pennsylvania	4703742488587	31e44ac2672e0557e51ca6943375fc06	Discover	39.9346239875029738	-75.1047332174975537
7792	2019-12-25 22:09:52	2019-12-25	Melony Johns	melony.johns@warmmail.com	Santa Clarita	California	3112415682056817491	e0028c08a438120c6dc917c6273777b1	VISA 16 digit	34.4686033490318806	-118.437261966719106
7793	2019-12-25 22:43:00	2019-12-25	Cris West	cris.west@geemail.com	San Francisco	California	3528971164828142413	4a91ef34647dc8aa6eb5fd2a34a11439	Discover	37.7716794708046777	-122.447151329593964
7794	2019-12-25 22:50:46	2019-12-25	Bula Wisoky-Batz	bula.wisoky.batz@woohoo.com	Virginia Beach	Virginia	639091134996429	825294f014adbb78b6b98a7fd7db5083	Diners Club / Carte Blanche	36.7903298754896966	-75.9749401677072029
7795	2019-12-25 22:58:11	2019-12-25	Alva Boehm	alva.boehm@warmmail.com	Tucson	Arizona	55319129642932290	ca880d48e46eefc62b6d8e026bd21c84	Discover	32.1224634136114275	-110.838228612508999
7796	2019-12-25 23:24:34	2019-12-25	Miss Carla Hyatt PhD	miss.carla.hyatt.phd@warmmail.com	Henderson	Nevada	869901663627236064	4d23e4db517b5d2d55211796e9b3a58d	Maestro	36.0686632732328079	-115.096794969371345
7797	2019-12-25 23:38:27	2019-12-25	Racheal Murazik	racheal.murazik@geemail.com	Grand Prairie	Texas	180047776551786031	ccee6ae73fbbd8f06122d256d97293dc	Mastercard	32.7369245052389815	-96.9607105001680623
7798	2019-12-25 23:38:37	2019-12-25	Lester Dach	lester.dach@geemail.com	Portland	Oregon	3049144132914398	b773edc8fca0dfbe630ef18d0b88e6b0	Voyager	45.5811665250342344	-122.607030010456228
7799	2019-12-25 23:54:30	2019-12-25	Hilton Casper-Gutkowski	hilton.casper.gutkowski@woohoo.com	Miramar	Florida	4584562950454	9f6f6edd4e8201ee8c870656575f68f1	Diners Club / Carte Blanche	25.9931291494965571	-80.2510483273297552
7800	2019-12-26 00:18:06	2019-12-26	Roscoe Cruickshank-Yundt	roscoe.cruickshank.yundt@geemail.com	San Francisco	California	4859659794712	2d702115d950c47391cb224a8b953bce	VISA 13 digit	37.7923306373758479	-122.424788655418396
7801	2019-12-26 00:18:45	2019-12-26	Ramiro Lynch-Bartoletti	ramiro.lynch.bartoletti@geemail.com	San Francisco	California	3030445091914488	76da78e76583025567c9ea327aab87c6	Discover	37.7728315566774882	-122.442031536558531
7802	2019-12-26 01:47:42	2019-12-26	Winter Hickle DVM	winter.hickle.dvm@woohoo.com	Wichita	Kansas	6011728507937472202	0ce8a1f0caf9c8eddc58da3b70a156ee	VISA 16 digit	37.7464183418888624	-97.4053261545222284
7803	2019-12-26 02:07:48	2019-12-26	Sean Batz-Dach	sean.batz.dach@geemail.com	South Bend	Indiana	4536088320166323	53eb45eb6b46fc45b967ba84adc5741d	Diners Club / Carte Blanche	41.763428797214857	-86.2624403936844431
7804	2019-12-26 03:08:20	2019-12-26	Holden Pfeffer-Goldner	holden.pfeffer.goldner@geemail.com	Santa Clarita	California	4993753889720	476bcc96a4505f76ee3eca2d237fc19a	VISA 13 digit	34.3528849249910522	-118.413958900757876
7805	2019-12-26 04:16:06	2019-12-26	Shoji Romaguera	shoji.romaguera@geemail.com	Los Angeles	California	4934118128513075	7396a348e15c26a1c408f5c7567a480d	VISA 13 digit	34.0198097003489721	-118.356727100814879
7806	2019-12-26 04:20:48	2019-12-26	Gerardo Donnelly	gerardo.donnelly@geemail.com	Berkeley	California	180049226270648466	9836fcaab39e0c24acf5e138c62de705	Diners Club / Carte Blanche	37.8650752616333079	-122.279257719511122
7807	2019-12-26 04:25:55	2019-12-26	Gretta Rath	gretta.rath@geemail.com	Baton Rouge	Louisiana	3040190053720800	d8215d3719fe75ba896273b962c3b3c5	VISA 16 digit	30.4102825517047179	-91.1830077011711921
7808	2019-12-26 04:30:08	2019-12-26	Cornell Bernhard III	cornell.bernhard.iii@geemail.com	San Francisco	California	6011544159592091505	940bd8d6124fd303d43afbfe52f06271	VISA 16 digit	37.7454237644171116	-122.44843233124918
7809	2019-12-26 04:54:35	2019-12-26	Mr. Barry Cummings Sr.	mr.barry.cummings.sr.@woohoo.com	Washington	District of Columbia	4171513632280	55adb1f30472399bab0c91cf3a95d196	VISA 16 digit	38.9111461913477612	-77.0347646553747438
7810	2019-12-26 05:01:45	2019-12-26	Mrs. Zoie Herzog	mrs.zoie.herzog@woohoo.com	San Francisco	California	210073772752074951	8fbcb46ad1678e5cda35ac86a182b652	Maestro	37.7717051470343677	-122.404909437333075
7811	2019-12-26 05:22:58	2019-12-26	Vennie Yost	vennie.yost@geemail.com	San Diego	California	55860241094372470	a83db255053c9c22b5227f737e95f6dc	Diners Club / Carte Blanche	32.7177843361228682	-117.04668568232097
7812	2019-12-26 05:33:43	2019-12-26	Catrina Lowe	catrina.lowe@geemail.com	Dallas	Texas	501801451357543	27ceed8b49c2ef715c58cbb7b82c4e62	Mastercard	32.8095687326781444	-96.7134277722760913
7813	2019-12-26 07:01:17	2019-12-26	Tab Batz	tab.batz@geemail.com	Los Angeles	California	4604408765013	3d603b5914b78c24932d88a1b2b1f526	Maestro	33.942242997545371	-118.337102042976014
7814	2019-12-26 07:05:44	2019-12-26	Virgel Brekke	virgel.brekke@geemail.com	San Francisco	California	3720701993472140	a01a80e47d39d36bf2e4d8c115efdc0c	Diners Club / Carte Blanche	37.7555014500328028	-122.40663188077032
7815	2019-12-26 07:24:08	2019-12-26	Dr. Welton Kulas I	dr.welton.kulas.i@geemail.com	San Francisco	California	4845102042809	d900b2d2661868a3befcc1c4ddf9af0a	JCB 16 digit	37.7910110686997953	-122.42257710962609
7816	2019-12-26 07:27:45	2019-12-26	Alcie Gleason	alcie.gleason@geemail.com	Los Angeles	California	4214407816361041	d40add7993af83c7ee65b368f6fc7cb2	VISA 16 digit	34.0377637317735662	-118.503603796101359
7817	2019-12-26 07:29:45	2019-12-26	Martha Kub	martha.kub@geemail.com	Oakland	California	52752883551358137	4653eeaeff1674b88aede09778dc9177	Diners Club / Carte Blanche	37.7888915863737722	-122.292918679306894
7818	2019-12-26 07:38:42	2019-12-26	Xzavier Barton-Kessler	xzavier.barton.kessler@warmmail.com	Santa Ana	California	3754877116967361	3e90375aa608dd6dc6c4eeab1028428a	Diners Club / Carte Blanche	33.6546717877138377	-117.813746357142918
7819	2019-12-26 08:37:49	2019-12-26	Dr. Parker Rippin DVM	dr.parker.rippin.dvm@woohoo.com	Fort Worth	Texas	53954715612866615	8aa96c35e46f4985a583eb6f2e80ee4e	Mastercard	32.8336510161459429	-97.3108677006147786
7820	2019-12-26 08:42:22	2019-12-26	Dequan Hand	dequan.hand@geemail.com	Oakland	California	55336679138865361	d2042a3285a96774c656ef167a1e8f78	JCB 16 digit	37.797983808552658	-122.245702515524371
7821	2019-12-26 09:04:12	2019-12-26	Leigh Wilkinson	leigh.wilkinson@geemail.com	Honolulu	Hawaii	4305620499644893	def5fb802f3125fd8af2e8a792629dd7	Diners Club / Carte Blanche	21.3827588378202194	-157.7783210661471
7822	2019-12-26 09:14:27	2019-12-26	Dr. Kristy Terry	dr.kristy.terry@geemail.com	Akron	Ohio	4800123958069546	c8f7c004f592b73e3db90601815ca4da	JCB 16 digit	40.9899097326044028	-81.4353077381696551
7823	2019-12-26 10:03:36	2019-12-26	Zoe Satterfield	zoe.satterfield@geemail.com	Philadelphia	Pennsylvania	6011025559099171585	fc0fa01060aafe5a138b16c2d6c2b68e	VISA 16 digit	40.0045848649885514	-75.0851191601615398
7824	2019-12-26 10:26:06	2019-12-26	Jessie Hilll	jessie.hilll@geemail.com	Fort Worth	Texas	3044625134118546	641c382854f6f95dacd9262d516c1473	VISA 16 digit	32.7438507068026823	-97.30077830043696
7825	2019-12-26 10:35:29	2019-12-26	Asa Hoeger	asa.hoeger@geemail.com	Greensboro	North Carolina	180055805453749257	cb689935d1e547a4d5f9d9f17391aa72	Diners Club / Carte Blanche	36.0218164594493828	-79.8949023819975537
7826	2019-12-26 11:05:08	2019-12-26	Lila Cruickshank	lila.cruickshank@warmmail.com	Houston	Texas	3701976338515760	1c3b885b052cbb614f91605ecd8bf894	VISA 16 digit	29.8383214809544377	-95.4674011567156811
7827	2019-12-26 11:24:15	2019-12-26	Stephanie Wehner-Trantow	stephanie.wehner.trantow@geemail.com	San Francisco	California	3054108992115227	f96ef02e1d457d25c68e31f314701b7f	Voyager	37.788553461944872	-122.430867499969636
7828	2019-12-26 12:12:05	2019-12-26	Gifford Oberbrunner	gifford.oberbrunner@warmmail.com	Glendale	Arizona	6011744221071701646	7741f8c4a35c56a41c4265bf37b84240	JCB 15 digit	33.4402367840282579	-112.157575077868614
7829	2019-12-26 12:17:33	2019-12-26	Loren Heaney-Robel	loren.heaney.robel@geemail.com	Savannah	Georgia	180092535401010750	7421d85f77b597002654eb419ecaff99	VISA 16 digit	31.9903229865804306	-81.0742066091544871
7830	2019-12-26 12:39:59	2019-12-26	Mr. Koen Braun V	mr.koen.braun.v@geemail.com	Omaha	Nebraska	4115044620355370	a66b728bf4b9fe92a1f633ad694ccb2a	VISA 13 digit	41.207477236227696	-96.0569074940051877
7831	2019-12-26 12:52:43	2019-12-26	Irena Schmitt	irena.schmitt@geemail.com	Oakland	California	4975368315688	eff9bf6884fb929d3a4f1aebe5565343	American Express	37.7793862606024149	-122.303203344293166
7832	2019-12-26 13:14:56	2019-12-26	Isai Kunde	isai.kunde@geemail.com	San Francisco	California	4002147342047187	f5aa39ef9068fb89167c14bd1973708e	Maestro	37.7592002130074462	-122.444811864986903
7833	2019-12-26 14:22:17	2019-12-26	Jeremie Monahan-Auer	jeremie.monahan.auer@geemail.com	Garland	Texas	53386317156301519	96fd7dd475d8dc525f1e840cb221245a	Voyager	32.846438960987328	-96.6804258512958938
7834	2019-12-26 14:55:26	2019-12-26	Madelynn Oberbrunner	madelynn.oberbrunner@woohoo.com	San Francisco	California	6011378281681038683	ee0d32e8e4d5a2d4da45b351a9dcd527	VISA 13 digit	37.7589810910292698	-122.437040091193666
7835	2019-12-26 15:13:42	2019-12-26	Adrienne Osinski DVM	adrienne.osinski.dvm@warmmail.com	Oakland	California	51707956939149471	6ad2c1ff59180e1f974884cff85ff549	Maestro	37.7749963712879122	-122.297099226872874
7836	2019-12-26 15:28:06	2019-12-26	Mr. Rondal Casper	mr.rondal.casper@geemail.com	Gainesville	Florida	4898284812766272	3f95e65e789cbbfe60fa2667a0cf4fcb	VISA 16 digit	29.624993127846345	-82.346849877560885
7837	2019-12-26 16:25:52	2019-12-26	Halbert Shields DDS	halbert.shields.dds@warmmail.com	Louisville	Kentucky	3730938947127481	8646bf88eac2e60d5085b249384639e4	Discover	38.1780009823288751	-85.5631543989364047
7838	2019-12-26 16:35:05	2019-12-26	Orrin Douglas DVM	orrin.douglas.dvm@geemail.com	Milwaukee	Wisconsin	869935886724667853	21d6b45aadaf86b6264d889890c10a58	Mastercard	43.0558080946646626	-88.0535132409639658
7839	2019-12-26 16:43:31	2019-12-26	Dr. Bernice Marquardt PhD	dr.bernice.marquardt.phd@geemail.com	New York	New York	3047114484403920	3b62635d4b9420ec840d5220f69f6a52	VISA 13 digit	40.7477308325227341	-74.010250094569102
7840	2019-12-26 16:44:26	2019-12-26	Zola Hirthe	zola.hirthe@geemail.com	Corpus Christi	Texas	589308119256470	e2530e2660c84c82b4b92a86c945ef0c	JCB 15 digit	27.6976665275108083	-97.088024326722703
7841	2019-12-26 16:58:11	2019-12-26	Murry Christiansen	murry.christiansen@geemail.com	San Francisco	California	3088146631440145271	da77a0e879f084eb446be3c7b83111e3	Diners Club / Carte Blanche	37.768902589912301	-122.408754220750055
7842	2019-12-26 17:01:02	2019-12-26	Anastacio Sanford Sr.	anastacio.sanford.sr.@warmmail.com	Colorado Springs	Colorado	53648300620724023	927edb84564dac4d9e0a4ab2e354a9f4	American Express	38.7712999729953722	-104.832564753169933
7843	2019-12-26 17:22:58	2019-12-26	Love Runolfsson-Lemke	love.runolfsson.lemke@geemail.com	Lubbock	Texas	3112320349369831403	4b95a027ddc633fed173545768dbc15b	Mastercard	33.5618772880215204	-101.86245019830838
7844	2019-12-26 17:44:21	2019-12-26	Mr. Jammie Reilly II	mr.jammie.reilly.ii@geemail.com	Reno	Nevada	51856595755937657	c7ba183a2e57cb948071ac56ac192784	Voyager	39.6424506170287785	-119.879814077417933
7845	2019-12-26 17:50:42	2019-12-26	Daquan Brown	daquan.brown@woohoo.com	San Francisco	California	51802508214242994	be9fbe5d0299f4370a6db869b13ffeda	VISA 16 digit	37.7944008122121318	-122.434698068977411
7846	2019-12-26 17:52:58	2019-12-26	Dr. Layla Schumm DVM	dr.layla.schumm.dvm@warmmail.com	Los Angeles	California	501817399541584	96569446ad5a4fd39343742721d0f8a1	VISA 16 digit	33.9575256432272496	-118.506618558102474
7847	2019-12-26 18:00:09	2019-12-26	Mortimer Smith	mortimer.smith@geemail.com	Provo	Utah	52034327031862813	0d07ec435b9884086061ea17f2ae68d6	JCB 16 digit	40.3089620508972573	-111.579720374490321
7848	2019-12-26 18:29:32	2019-12-26	Harvy Torphy	harvy.torphy@geemail.com	Oakland	California	6011000668588760235	20c8ccf310f35da78776ddff7fa9c8bd	Mastercard	37.8049135912843184	-122.251578676469677
7849	2019-12-26 18:39:20	2019-12-26	Arlie Langworth V	arlie.langworth.v@geemail.com	Fresno	California	869962254278470826	bbe19119dc762057f4ece29ae38ad727	American Express	36.83030640346594	-119.746151569496476
7850	2019-12-26 18:55:33	2019-12-26	Marina Herzog	marina.herzog@warmmail.com	New York	New York	3033903373236993	53ef257b09305a06e813725887f96088	Diners Club / Carte Blanche	40.5823425600994341	-74.0333420893073111
7851	2019-12-26 19:00:42	2019-12-26	Ever Hagenes	ever.hagenes@woohoo.com	Pearland	Texas	4670578354511911	f1b8995d32b1929436241cb826dd319a	Mastercard	29.5328328856538995	-95.3085244126938278
7852	2019-12-26 19:20:35	2019-12-26	Mariel Schneider	mariel.schneider@geemail.com	Davenport	Iowa	676136756276139	b44300175eb082e259601cf023838e2e	VISA 16 digit	41.5268990403305693	-90.6593647423162992
7853	2019-12-26 19:25:53	2019-12-26	Daryl Dietrich	daryl.dietrich@geemail.com	Yonkers	New York	3002476256755570	1e1dc226860d1fe8d6f7abb746b4de99	VISA 16 digit	40.9821618804443659	-73.9166954557761642
7854	2019-12-26 19:34:06	2019-12-26	Wiliam Blanda	wiliam.blanda@geemail.com	San Francisco	California	3035699370590378	210f9116f5a0e8c1d71740d6d071aaa2	JCB 15 digit	37.7691247193329218	-122.40347096687205
7855	2019-12-26 19:46:47	2019-12-26	Xavier Klocko	xavier.klocko@geemail.com	Killeen	Texas	4585206701948	f1418e1f40953eaac76ab6aadda92552	JCB 16 digit	30.9925520176764593	-97.7991524857170873
7856	2019-12-26 20:00:35	2019-12-26	Ms. Lolla Macejkovic	ms.lolla.macejkovic@woohoo.com	Salt Lake City	Utah	3112918688667993086	0396a986e842a1a904bc3a654482e791	VISA 13 digit	40.7102859530743189	-111.866750925354651
7857	2019-12-26 20:32:30	2019-12-26	Dr. Hadley Batz I	dr.hadley.batz.i@warmmail.com	Columbus	Ohio	210004322328600592	53b1b1bfef6974a86baf2f8a29c6d993	JCB 16 digit	39.9741907003846038	-83.0654989079806967
7858	2019-12-26 20:42:02	2019-12-26	Andreas Metz	andreas.metz@woohoo.com	New York	New York	3010336745328094	795a05923d52aa8f47a5be2461683ea9	Voyager	40.6485442761555333	-74.0385771415557628
7859	2019-12-26 20:59:01	2019-12-26	Rae Reichel	rae.reichel@geemail.com	Seattle	Washington	6011487837593152108	3ac3229d51b3fa2ca33ef0a24407083b	Diners Club / Carte Blanche	47.6882075703162727	-122.304168949594342
7860	2019-12-26 21:11:34	2019-12-26	Oland Donnelly-Conroy	oland.donnelly.conroy@geemail.com	Colorado Springs	Colorado	6011819821387713324	48fccc314f3d1167799902b5460a782f	VISA 13 digit	38.8453210377182785	-104.665760735438013
7861	2019-12-26 21:27:10	2019-12-26	Joann Kunze MD	joann.kunze.md@geemail.com	Phoenix	Arizona	210059963506513240	96f57dcb30ae204de8fe114d0527d9b2	VISA 16 digit	33.6536740554429628	-112.057058043584604
7862	2019-12-26 21:50:39	2019-12-26	Sterling Rice	sterling.rice@warmmail.com	Oakland	California	3088155874642470216	f1eff8e0457b907cf6526b12aa354e8e	Maestro	37.8109515324782421	-122.285683157298848
7863	2019-12-26 21:54:47	2019-12-26	Magen Hilll MD	magen.hilll.md@geemail.com	Los Angeles	California	676359699122905	e32f053c6cc7a9b2eb4fa4607c362efc	American Express	33.9811375981993962	-118.434807659079496
7864	2019-12-26 22:04:22	2019-12-26	Shedrick Graham Sr.	shedrick.graham.sr.@geemail.com	Garden Grove	California	4839258821122513	c2a228e459910e3c54fda6d6bbcc55aa	Diners Club / Carte Blanche	33.727585081692034	-117.908474799014627
7865	2019-12-26 22:21:29	2019-12-26	Lisa Botsford	lisa.botsford@geemail.com	Denver	Colorado	6011469563966430820	04862c9f471ba84f6fb8e202c833145e	JCB 15 digit	39.6908826101157786	-104.857766536182169
7866	2019-12-26 22:55:27	2019-12-26	Jaquan Wuckert	jaquan.wuckert@woohoo.com	San Francisco	California	3158263127653987639	295d3743e612fad0af8b0a9ded980dad	JCB 15 digit	37.773633461637651	-122.406136013882502
7867	2019-12-26 23:20:01	2019-12-26	Odin Fay	odin.fay@woohoo.com	San Bernardino	California	3158903014509695622	76df83dd9371bc276efe74128b57f14d	Mastercard	34.1748614706363512	-117.259146669252218
7868	2019-12-26 23:34:37	2019-12-26	Jaylah Douglas	jaylah.douglas@woohoo.com	Hayward	California	6011912931178396969	dee549d64454f56fe44b725b3480eb42	American Express	37.6073598694976425	-122.092336028933161
7869	2019-12-26 23:48:27	2019-12-26	Olin Pfannerstill	olin.pfannerstill@woohoo.com	Richmond	Virginia	4821504203307	16abac229d95df4629f5549b6e81c8bb	VISA 16 digit	37.5252500245567404	-77.4695517719481188
7870	2019-12-27 00:09:36	2019-12-27	Andy Treutel	andy.treutel@geemail.com	Indianapolis	Indiana	180071751980718193	ada260bee5785f39999359db65f5622f	Maestro	39.7887228442363394	-86.1588568930249608
7871	2019-12-27 00:12:12	2019-12-27	Miss Maiya Barton	miss.maiya.barton@geemail.com	Amarillo	Texas	3112863060099079360	bd1f903683c93403614905657a5b1242	American Express	35.1259165865067402	-101.837146080550554
7872	2019-12-27 00:30:39	2019-12-27	Marge Huels	marge.huels@geemail.com	Jacksonville	Florida	501812396795184	e29b74652ccca831694e0f26f65287f4	JCB 15 digit	30.4340243902575232	-81.5995936665296568
7873	2019-12-27 01:03:53	2019-12-27	Kathaleen Bartell	kathaleen.bartell@geemail.com	Raleigh	North Carolina	4939705896429248	25952c219b43b1d1070df8041bee5aad	VISA 16 digit	35.8019626258540882	-78.6317949557147955
7874	2019-12-27 01:25:24	2019-12-27	Rella Langosh	rella.langosh@geemail.com	San Francisco	California	3088278606912428900	46582012a2e9a17b148b514724e78193	VISA 13 digit	37.7387163593224884	-122.42188452122933
7875	2019-12-27 01:29:11	2019-12-27	Gerald Prosacco	gerald.prosacco@geemail.com	Salinas	California	3754927756524319	98fcca591a578cbc52ee042666e8d7e8	Mastercard	36.6910509829174671	-121.601972310914476
7876	2019-12-27 01:56:22	2019-12-27	Almedia Huels-Parker	almedia.huels.parker@geemail.com	Amarillo	Texas	3158101403901504914	1d58d1a7b2dba1400a5677bb7fd6f6a0	VISA 13 digit	35.2322748354334365	-101.81212167012022
7877	2019-12-27 03:04:34	2019-12-27	Donnie Jakubowski-McDermott	donnie.jakubowski.mcdermott@warmmail.com	Los Angeles	California	3016678949883091	f6e714c5507be077fbe72d79e02aa564	Discover	34.0823742476157818	-118.383785492786387
7878	2019-12-27 03:53:57	2019-12-27	Sie Towne	sie.towne@geemail.com	Concord	California	4009594163162749	1203ca486c685f8b83b9bb08e61610e3	American Express	38.0584809434067495	-122.00798153753243
7879	2019-12-27 04:22:25	2019-12-27	Darron Gottlieb	darron.gottlieb@geemail.com	San Francisco	California	4352346021641536	583c0c339977d50e53da84b4c4b03939	JCB 16 digit	37.7813730506007204	-122.419835177020985
7880	2019-12-27 04:28:45	2019-12-27	Marlene Crist	marlene.crist@geemail.com	Oakland	California	51569999418253833	1c1cab4198b2c209c5f1ac79337ca4d0	American Express	37.8178004786863866	-122.281651790963053
7881	2019-12-27 04:46:02	2019-12-27	Mr. Britt Stanton	mr.britt.stanton@geemail.com	Palmdale	California	869970780715322667	35e9f52b8440f4a06682957f9ba58b97	JCB 16 digit	34.6103391949404013	-118.110515877557546
7882	2019-12-27 04:57:24	2019-12-27	Bird Quitzon	bird.quitzon@woohoo.com	Cambridge	Massachusetts	3052558414757968	f4dccc9436a6b9ee164263fdac1df7e3	VISA 13 digit	42.3755582972187526	-71.1631246207363972
7883	2019-12-27 05:18:58	2019-12-27	Hermann O'Connell-McCullough	hermann.o'connell.mccullough@geemail.com	New York	New York	55146733223461873	210b1526eabaced7258bbabc8273c8b5	JCB 15 digit	40.7230409480389213	-73.9121810017980607
7884	2019-12-27 06:03:51	2019-12-27	Corbin Douglas	corbin.douglas@woohoo.com	New York	New York	3337472314736954078	86e8a79e370f5ba601876532638ee834	VISA 16 digit	40.7153162976484708	-73.8540392273932724
7885	2019-12-27 06:27:06	2019-12-27	Julia Langworth	julia.langworth@geemail.com	Nashville	Tennessee	4976587184517	4cbce885bc6ea8cbec481afc29357be4	Maestro	36.2519995293702877	-86.8712337603233777
7886	2019-12-27 07:42:12	2019-12-27	Leslee Donnelly	leslee.donnelly@geemail.com	San Francisco	California	4528928689736	8209a3ee65fb1a8cbf6484da73ae945f	American Express	37.7670434494091722	-122.415650500044819
7887	2019-12-27 07:46:09	2019-12-27	Genevieve McCullough	genevieve.mccullough@warmmail.com	Chicago	Illinois	3005367163793977	37f5471ae945ff1858fca640bd425c43	Discover	41.8617157338954513	-87.6207233822002962
7888	2019-12-27 07:51:57	2019-12-27	Dr. Theodis Heidenreich	dr.theodis.heidenreich@geemail.com	Fullerton	California	3337388393914113973	969e823d13ebb367e622ed45bb47ed48	Maestro	33.9075940963502944	-117.992960786793375
7889	2019-12-27 08:05:03	2019-12-27	Mr. Shellie Hackett Sr.	mr.shellie.hackett.sr.@geemail.com	Knoxville	Tennessee	4402359669263497	b0f206593c87389593fac061ef6a527f	JCB 16 digit	35.9545587887585185	-83.9800320963125557
7890	2019-12-27 08:14:29	2019-12-27	Carmine Larkin-Rutherford	carmine.larkin.rutherford@warmmail.com	Killeen	Texas	54808334177542930	e05cb8eabe4f1aff8a5b6f5ee4be8cb2	VISA 13 digit	30.9829970991469921	-97.6546534851826777
7891	2019-12-27 08:20:27	2019-12-27	Otis Kuhn	otis.kuhn@geemail.com	San Francisco	California	6011756557300133936	c6c4ab4744194e7f76269655287053b1	JCB 16 digit	37.810999408032238	-122.423529632199106
7892	2019-12-27 08:44:27	2019-12-27	Mr. Buster Metz	mr.buster.metz@geemail.com	Chicago	Illinois	3474482095579760	895266fa36535fe723321b7754e8358c	JCB 15 digit	41.7610353596810242	-87.635897315203394
7893	2019-12-27 09:18:12	2019-12-27	Erik Jakubowski	erik.jakubowski@geemail.com	New York	New York	6011286890516521662	aa869eced637c66346798abb58fcb8f6	JCB 15 digit	40.5917183500938137	-74.0235867241758854
7894	2019-12-27 09:20:24	2019-12-27	Meta Wiegand	meta.wiegand@geemail.com	San Francisco	California	3034698381088563	b1b6273e5500500874441e850fe5e711	Discover	37.7687326681083064	-122.432296419878256
7895	2019-12-27 09:49:25	2019-12-27	Tyriq Hodkiewicz-Fritsch	tyriq.hodkiewicz.fritsch@geemail.com	Kansas City	Kansas	3337712890348821490	ba79ed05b969783b3710783fd57f6260	Voyager	39.1631402450520554	-94.7605357072718419
7896	2019-12-27 09:55:59	2019-12-27	Mrs. Kiyoko Ondricka	mrs.kiyoko.ondricka@geemail.com	Austin	Texas	6011466898615811894	508081dd471a852fadffb482fde0bf19	VISA 13 digit	30.329796593788636	-97.7844343743525428
7897	2019-12-27 10:01:46	2019-12-27	Aniyah Christiansen PhD	aniyah.christiansen.phd@geemail.com	San Francisco	California	4164019078629	92cbbd43492877d177bbfd8949460247	VISA 13 digit	37.7761817364875085	-122.443319419771029
7898	2019-12-27 10:23:33	2019-12-27	Ottie Senger	ottie.senger@woohoo.com	San Francisco	California	54365567889214232	1ae365d8cb475f9e99674cfa8ed3cbf6	Voyager	37.7936944473802754	-122.410895655630938
7899	2019-12-27 11:07:32	2019-12-27	Mr. Linden Heidenreich II	mr.linden.heidenreich.ii@warmmail.com	Riverside	California	180026582926396919	36acdeae4f163f21fcc5c53d07066a8a	JCB 16 digit	33.8864577620703713	-117.380545706624901
7900	2019-12-27 11:13:06	2019-12-27	Joselyn Beatty	joselyn.beatty@geemail.com	Los Angeles	California	6011358000317793311	5f5d1ed5a794831a6dd091d0f8cc4852	VISA 16 digit	33.9308891173783636	-118.425321748991678
7901	2019-12-27 11:33:39	2019-12-27	Nigel Strosin	nigel.strosin@geemail.com	Jacksonville	Florida	3158897320878180684	3ea4dc724d0749021734e684c15740ed	Discover	30.3752380616083748	-81.7026211318638218
7902	2019-12-27 12:18:13	2019-12-27	Garrison Langworth	garrison.langworth@woohoo.com	New York	New York	51578294375614196	fda4c7c42d2ce74726ceb48954a3374d	JCB 16 digit	40.6822887356616576	-74.0091555789939974
7903	2019-12-27 13:06:27	2019-12-27	Rodney Dach	rodney.dach@geemail.com	San Jose	California	180001589835714388	1cd61d8d3b8ab630f0c25c622e6b68ca	American Express	37.2944046264801159	-121.73221979101524
7904	2019-12-27 13:11:11	2019-12-27	Gustavus Schmidt	gustavus.schmidt@geemail.com	San Francisco	California	3423021443087902	dedfc32ec286f93e06011e2ebd73ffa0	American Express	37.7644989041355572	-122.43098307160956
7905	2019-12-27 13:49:48	2019-12-27	Zara Wolf-Kunze	zara.wolf.kunze@woohoo.com	Oakland	California	180030196105181069	c0e732773d895371ee386189c138ed91	JCB 16 digit	37.8593259924955419	-122.276123017352703
7906	2019-12-27 14:07:26	2019-12-27	Alvina Keebler	alvina.keebler@woohoo.com	Pompano Beach	Florida	3096967994292016826	2bf8ad60d46d8230607bf4172d057dde	Maestro	26.3251823071654876	-80.1275465411912649
7907	2019-12-27 14:40:03	2019-12-27	Isaiah Dooley	isaiah.dooley@geemail.com	Newport News	Virginia	3528096530126849984	694b08dc4e54735c2f971b13adddcd36	Diners Club / Carte Blanche	37.0005665498215706	-76.6167722104843705
7908	2019-12-27 14:45:44	2019-12-27	Rosia Bruen	rosia.bruen@geemail.com	Charlotte	North Carolina	180029209451965945	f1483b8a76549ee63b71dfd7d18f0223	VISA 16 digit	35.1343204017981847	-80.7558578523751436
7909	2019-12-27 14:56:07	2019-12-27	Scotty Auer	scotty.auer@warmmail.com	Pasadena	Texas	4663223003786	7333264c573803bbbebfcb3025238c9d	Mastercard	29.611629986517503	-95.2505163942877147
7910	2019-12-27 15:30:02	2019-12-27	Vernell Johnson	vernell.johnson@geemail.com	Lubbock	Texas	3024040142823972	9a1f27add4d84c07aed973e783e380e7	VISA 16 digit	33.6203448903787887	-101.821594328704109
7911	2019-12-27 15:41:37	2019-12-27	Tess Tillman PhD	tess.tillman.phd@geemail.com	New York	New York	3718823767627545	21cd671acb3fc3370e307f044b0264e8	JCB 16 digit	40.7599196288958154	-74.0257963439810993
7912	2019-12-27 16:19:41	2019-12-27	Kimberlee Wehner	kimberlee.wehner@geemail.com	Phoenix	Arizona	55247613981637203	1cca8a7fd0eb1add19f0c75b3cff2046	Discover	33.6273296204328531	-112.000784484848765
7913	2019-12-27 16:33:14	2019-12-27	Odalis Maggio-Stiedemann	odalis.maggio.stiedemann@geemail.com	San Francisco	California	55922432587904160	ae8176d917e2f3af9e4525300a982b47	JCB 16 digit	37.7654388185275565	-122.456775327795114
7914	2019-12-27 16:33:37	2019-12-27	Mr. Adolf Legros	mr.adolf.legros@woohoo.com	Elgin	Illinois	4316362792624085	873c7d47544f9a1066bddb296fd2f98c	Diners Club / Carte Blanche	41.9464549337331221	-88.2267917959772063
7915	2019-12-27 17:15:27	2019-12-27	Laisha Lang	laisha.lang@geemail.com	San Francisco	California	3011584511016018	d829fc6bb04a9765fe111c285ed8880a	Voyager	37.8056967820734329	-122.438015494018842
7916	2019-12-27 17:52:15	2019-12-27	Ms. Alyson Boyer MD	ms.alyson.boyer.md@geemail.com	Las Cruces	New Mexico	869927389806601171	3268ef2d814fbd22def3efd20af21388	American Express	32.2764073072966156	-106.748145714786645
7917	2019-12-27 17:52:50	2019-12-27	Melville Romaguera PhD	melville.romaguera.phd@geemail.com	Stamford	Connecticut	3096413479856705824	efc49b116b095a3f6b1ba4621c3566ab	Mastercard	41.0751995947096518	-73.6322914492841818
7918	2019-12-27 17:58:10	2019-12-27	Millie Herman	millie.herman@geemail.com	San Francisco	California	3088828889890651728	f05e222893e6094684ee2d9bdb9966d9	VISA 16 digit	37.769217771282527	-122.432814390976418
7919	2019-12-27 18:10:34	2019-12-27	Wyatt Satterfield	wyatt.satterfield@geemail.com	San Francisco	California	4454579020222	fc9277f9035f6be0f202c447ba35a7df	VISA 16 digit	37.7777154317591766	-122.397735418325908
7920	2019-12-27 18:20:22	2019-12-27	Miss Alethea O'Keefe	miss.alethea.o'keefe@geemail.com	Honolulu	Hawaii	53630937608433042	03318e81a2e7ff106750fabcafda0eee	VISA 13 digit	21.3706623704854408	-157.863270069213968
7921	2019-12-27 18:24:03	2019-12-27	Hartley Shanahan	hartley.shanahan@geemail.com	San Francisco	California	869923995208548317	a23c1c50e5958476290d12a60560fd14	JCB 16 digit	37.7654142709480851	-122.433257310257204
7922	2019-12-27 18:26:20	2019-12-27	Osvaldo McDermott	osvaldo.mcdermott@geemail.com	San Francisco	California	3528333854954698294	50d8424f0d11b121a8ae6bddb9080153	VISA 16 digit	37.8131460163030795	-122.48603299641708
7923	2019-12-27 18:37:32	2019-12-27	Myrl Nicolas	myrl.nicolas@geemail.com	New York	New York	210022261395939178	146f62b74d5f292fb125bd83e5f0c044	Voyager	40.7409362644180675	-73.9758214478276699
7924	2019-12-27 19:12:00	2019-12-27	Mrs. Tosha Wolf DDS	mrs.tosha.wolf.dds@geemail.com	South Bend	Indiana	4190571242641850	4c5debe77e2f8b4eeab2f7f001a88564	Voyager	41.6199141099262988	-86.3309008549489079
7925	2019-12-27 19:23:03	2019-12-27	Donat Homenick	donat.homenick@geemail.com	Oklahoma City	Oklahoma	6011820572990177319	f2dbfccb07c427beb8b59e4710d88bb4	JCB 16 digit	35.5419308000620475	-97.6056145765714405
7926	2019-12-27 19:29:40	2019-12-27	Ebbie Hyatt-Leffler	ebbie.hyatt.leffler@geemail.com	Berkeley	California	4192529893750709	a63c504e1b3e5c998b4c20c206617935	Voyager	37.8395876353473426	-122.267990235481932
7927	2019-12-27 19:57:03	2019-12-27	Hervey Botsford	hervey.botsford@geemail.com	Berkeley	California	3712382268046412	d47726f93e703815a71a814cb5412728	Mastercard	37.8741959733744835	-122.257811628888078
7928	2019-12-27 20:29:49	2019-12-27	Pennie Konopelski	pennie.konopelski@geemail.com	Chula Vista	California	51598268159045153	27c2f6e06e7f5062f5e5a0188cb8d784	JCB 16 digit	32.5297989111624659	-116.928560075419767
7929	2019-12-27 20:44:50	2019-12-27	Latoria Fay	latoria.fay@geemail.com	New York	New York	4123584613145	b148d09544e2a758d5abd3e83c2a0854	JCB 16 digit	40.601332729611542	-73.8982241707749665
7930	2019-12-27 20:46:49	2019-12-27	Mr. Doyle Schimmel II	mr.doyle.schimmel.ii@warmmail.com	Lakeland	Florida	3337672601920925734	1bf020fc8b71812cea6f2117b56ce57a	JCB 16 digit	27.9735636819917701	-81.8926368409186551
7931	2019-12-27 21:23:53	2019-12-27	Thora Wiegand	thora.wiegand@woohoo.com	San Francisco	California	6011499930619753300	d11eab61287ba55dd33067fa4b80c2c9	American Express	37.8192204960159515	-122.450960898271447
7932	2019-12-27 21:54:13	2019-12-27	Erin Lindgren	erin.lindgren@geemail.com	Chicago	Illinois	54927308068828885	bf305328afdad4cf6d23f05a1e818aec	American Express	41.8147388528868547	-87.6613679164584738
7933	2019-12-27 22:15:27	2019-12-27	Terence Orn Jr.	terence.orn.jr.@geemail.com	Austin	Texas	4861905351495	643a86c0b3a49ff761e1873cf1b4f3e5	American Express	30.3766829304989407	-97.772595120757444
7934	2019-12-27 22:30:28	2019-12-27	Katerina Konopelski	katerina.konopelski@woohoo.com	San Francisco	California	4390130309326	cf26dbc712695c8bed6df140afbafdb8	Maestro	37.800722470346372	-122.418477181037247
7935	2019-12-27 22:30:51	2019-12-27	Adin Champlin	adin.champlin@geemail.com	Stamford	Connecticut	3112390149571026197	efe82761f2965dbe132db6959f2f4861	Mastercard	41.1690424884088344	-73.5731749185398343
7936	2019-12-27 22:46:24	2019-12-27	Zeke Bauch	zeke.bauch@geemail.com	Boston	Massachusetts	3112648054649797813	00ae95556b4e5714d6eeec2157d49e85	VISA 16 digit	42.4273080390114359	-70.9823179473586379
7937	2019-12-27 22:56:21	2019-12-27	Clifford Dach	clifford.dach@warmmail.com	San Francisco	California	4519799694338584	915f89d41bc7d32b96165d29549ec693	Discover	37.7724260957848443	-122.425850865108771
7938	2019-12-27 22:58:55	2019-12-27	Davy Considine	davy.considine@warmmail.com	Chicago	Illinois	3528695467553117178	da3def2268fe9458b96b74a5d2f51f2d	American Express	41.9318295961082015	-87.7009669730003907
7939	2019-12-27 23:08:29	2019-12-27	Dr. Alberto Weimann	dr.alberto.weimann@geemail.com	Los Angeles	California	6011862029532315351	aa54e5e62395735511def9e01018d362	Voyager	33.9833556034933721	-118.445863587361941
7940	2019-12-27 23:10:32	2019-12-27	Hasel Nader	hasel.nader@geemail.com	Arlington	Texas	3452077454776779	a483172a29275d762e8366ffa955604e	JCB 15 digit	32.7664715656794598	-97.0871097752384884
7941	2019-12-27 23:48:28	2019-12-27	Sherwin Hand	sherwin.hand@warmmail.com	Oakland	California	180023771411136905	e049f7c9949b4301ad720b3a5aab9fa9	VISA 13 digit	37.7965028735041102	-122.284539652910965
7942	2019-12-28 00:03:42	2019-12-28	Benjiman Mueller I	benjiman.mueller.i@woohoo.com	San Antonio	Texas	3158829741466934070	35f1bfc9d7c8e5408635239555bd216f	American Express	29.5139493778418753	-98.4664261402864014
7943	2019-12-28 00:18:04	2019-12-28	Susanna Klein	susanna.klein@geemail.com	Lincoln	Nebraska	869951943972230527	eebee9c69696ef2788e4784dd3e6bdfe	JCB 16 digit	40.8745596771612725	-96.7194591964289572
7944	2019-12-28 00:27:44	2019-12-28	Carley Pfannerstill	carley.pfannerstill@geemail.com	Temecula	California	4367109814347551	14c103a24f74349a24ba65ed01e549a0	JCB 15 digit	33.5697909908503291	-117.095476347273959
7945	2019-12-28 00:32:30	2019-12-28	Gilmer Weissnat	gilmer.weissnat@geemail.com	San Francisco	California	3528088072091462808	851da5dc98d50e397cb83b5a0730477b	Mastercard	37.7804266265585582	-122.442076811004355
7946	2019-12-28 01:03:25	2019-12-28	Mr. Lloyd Jaskolski DVM	mr.lloyd.jaskolski.dvm@geemail.com	St. Louis	Missouri	4294569021016	302fe8cf7eba3cb25eb9b0f678f9d95c	Discover	38.6062341648310436	-90.2852676218845005
7947	2019-12-28 01:18:02	2019-12-28	Devante Gleichner	devante.gleichner@warmmail.com	Houston	Texas	4475058185327	f7d0ee1c9e82cc579d2922a7d68793d9	Mastercard	29.7615468315392739	-95.3076366629932039
7948	2019-12-28 01:39:15	2019-12-28	Cody Nienow	cody.nienow@geemail.com	Columbia	Missouri	4791772693673896	bd4ae4609295273e025b47488722557d	Discover	38.984091477922405	-92.2316706478183193
7949	2019-12-28 01:43:02	2019-12-28	Shelvia Little	shelvia.little@woohoo.com	San Francisco	California	4706057214090661	48f6ec0561a299f47c71432b7082dfcc	Voyager	37.7723060307412197	-122.459048783323198
7950	2019-12-28 02:08:38	2019-12-28	Mr. Hervey Bogan DDS	mr.hervey.bogan.dds@warmmail.com	Milwaukee	Wisconsin	3724553135143725	09bfa6e2704ff7f2991d7f9c4c1a65df	Discover	43.1398302218496781	-88.0666059963040055
7951	2019-12-28 02:12:29	2019-12-28	Kamryn Koch	kamryn.koch@geemail.com	New York	New York	4677945046647457	84ae835e3d430472e5030eed6d0fec8f	JCB 16 digit	40.6983397247493244	-73.8904594483681052
7952	2019-12-28 02:23:04	2019-12-28	Gracelyn Huels	gracelyn.huels@geemail.com	New York	New York	6011804036708556636	7e3680d20edc1fa0dc21eb4dc68c5366	Diners Club / Carte Blanche	40.7596718956939839	-73.9777377697534888
7953	2019-12-28 02:32:46	2019-12-28	Margarito Sauer	margarito.sauer@warmmail.com	New York	New York	3112579394353175456	7be217878840ee0cdb7b972063c091c8	VISA 13 digit	40.640558733021841	-73.8665744851704602
7954	2019-12-28 02:33:21	2019-12-28	Dr. Kristopher Becker	dr.kristopher.becker@geemail.com	Oakland	California	180059730563935024	527a3757cd17cf86a6a477dbd7d417ad	VISA 13 digit	37.828694902269973	-122.251697040688057
7955	2019-12-28 02:43:12	2019-12-28	Glenwood Lang	glenwood.lang@woohoo.com	New York	New York	51333167675538545	70f4bcf3f81e3454bee172c91f515164	JCB 15 digit	40.5977005836311733	-73.9924491669412703
7956	2019-12-28 02:47:26	2019-12-28	Nickolas Hirthe-Kulas	nickolas.hirthe.kulas@geemail.com	Denver	Colorado	869972768513736368	90f06d5e28e7aa4185f8e7cf575715af	Voyager	39.7758840017072828	-104.850267504459623
7957	2019-12-28 03:04:52	2019-12-28	Mrs. Analia Emmerich	mrs.analia.emmerich@geemail.com	San Francisco	California	4494597992912756	dfaecaa7e6d89c11f71038747a422f50	American Express	37.7780828302495166	-122.430373369108835
7958	2019-12-28 03:14:42	2019-12-28	Dr. Cheryll Barton PhD	dr.cheryll.barton.phd@woohoo.com	San Francisco	California	3337563217657886460	4119ac1eeba0025361037c442713defc	JCB 16 digit	37.7930844468875549	-122.413917480466068
7959	2019-12-28 03:25:20	2019-12-28	Mr. Kristopher Smitham V	mr.kristopher.smitham.v@geemail.com	Santa Rosa	California	4576157475640	f6bd6e5ff5b2c553448ea95a34ef43b9	VISA 16 digit	38.4415737398091721	-122.793186558761079
7960	2019-12-28 03:38:35	2019-12-28	Elmore Romaguera	elmore.romaguera@geemail.com	San Francisco	California	4275807697342984	184a5639d774d4e5dd7c545ae1d58359	Diners Club / Carte Blanche	37.7887869645225223	-122.438186180057343
7961	2019-12-28 03:39:39	2019-12-28	Marin Daniel DDS	marin.daniel.dds@geemail.com	San Francisco	California	3158424630925812697	9bb3acaf80c1fcac668fd4cec5255c2b	American Express	37.7665770649792591	-122.427470795778518
7962	2019-12-28 04:00:41	2019-12-28	Arvil Kihn	arvil.kihn@woohoo.com	Houston	Texas	3406573735549701	1feef0dbc5c5a593643ad9baaf99b029	JCB 16 digit	29.7323157947123065	-95.3806721104789546
7963	2019-12-28 04:11:02	2019-12-28	Lona Hand	lona.hand@geemail.com	San Francisco	California	3528943570078787589	46eb2896ce2659ede54a4459e53a2884	Voyager	37.7812939145280353	-122.416232128719784
7964	2019-12-28 04:18:25	2019-12-28	Lily Carter	lily.carter@warmmail.com	Cleveland	Ohio	3775048008547357	779f4d716d1c273503e6764b64af9fa8	VISA 16 digit	41.4473973018433881	-81.638494801405443
7965	2019-12-28 04:22:54	2019-12-28	Mr. Arba Nolan	mr.arba.nolan@geemail.com	San Diego	California	6011306318552539014	53bac5c4df7e146324d4b35d5cdd3829	Diners Club / Carte Blanche	32.8520409773636644	-117.064580678651112
7966	2019-12-28 04:24:14	2019-12-28	Ivey Kreiger DDS	ivey.kreiger.dds@geemail.com	Concord	California	3496753228404728	646d3f051b898038d9191897b139acaa	Voyager	38.0301058042727433	-121.97562252922765
7967	2019-12-28 04:32:02	2019-12-28	Lillis Brekke	lillis.brekke@woohoo.com	San Francisco	California	3037564268142302	1ddf51bdbb05bff698f0dd670c5a4c77	JCB 15 digit	37.7825060224779108	-122.444149749297679
7968	2019-12-28 04:59:11	2019-12-28	Ethel Feeney MD	ethel.feeney.md@woohoo.com	New York	New York	3112626455393060587	88ef30a0c7d43a93676ca0b438f926be	JCB 16 digit	40.6992811040245002	-73.9740472935967119
7969	2019-12-28 05:10:21	2019-12-28	Tallie Fritsch	tallie.fritsch@geemail.com	Springfield	Massachusetts	3796320466371405	bafcc30341e3cf1645e689190ea255c9	VISA 13 digit	42.0916123529169681	-72.4988608578313176
7970	2019-12-28 05:38:22	2019-12-28	Carole Kuhlman	carole.kuhlman@woohoo.com	Washington	District of Columbia	869903642374379861	4d66532f2962201fc8d00a87ab1dec30	Maestro	38.8335689123984409	-76.9335779613096236
7971	2019-12-28 06:05:25	2019-12-28	Olan Fisher	olan.fisher@warmmail.com	San Jose	California	3779123876773256	3b2a8404133ed1b132c154f8b8aa5976	VISA 16 digit	37.2967008819624795	-121.804867470891779
7972	2019-12-28 06:34:02	2019-12-28	Fidelia Strosin	fidelia.strosin@geemail.com	Baton Rouge	Louisiana	3018481459219907	4c41898ff2788d0c322d43a4b4dbe3d3	VISA 13 digit	30.5083006329115491	-91.0423367067813842
7973	2019-12-28 06:41:44	2019-12-28	Chip Smitham-Leannon	chip.smitham.leannon@geemail.com	New York	New York	3774152072928328	595559f140d2d6d2dacc01d872e3dbf4	Diners Club / Carte Blanche	40.7052594827245926	-74.0374018884625258
7974	2019-12-28 06:53:57	2019-12-28	Sheyla Herzog DVM	sheyla.herzog.dvm@warmmail.com	Berkeley	California	3776649553470561	657b7e5922f234de460a09a28a752644	American Express	37.9032422724807674	-122.264089464722929
7975	2019-12-28 07:04:05	2019-12-28	Ronald Ullrich	ronald.ullrich@geemail.com	San Francisco	California	3028162621521970	14e3ede52cd63bc1e98cb278280d9786	VISA 16 digit	37.7434562008663193	-122.429995316429569
7976	2019-12-28 07:29:11	2019-12-28	Doreen Koepp	doreen.koepp@geemail.com	Los Angeles	California	3056300185986310	40c7acaadcd25aad14742b35965cda1e	VISA 13 digit	34.0981605889141548	-118.486936735873286
7977	2019-12-28 07:33:04	2019-12-28	Dr. Tavian Rath V	dr.tavian.rath.v@geemail.com	San Francisco	California	561217531412280	5bda86203691b325da79e30c8ad791ea	JCB 16 digit	37.7491183741161223	-122.431296532475031
7978	2019-12-28 07:34:48	2019-12-28	Tatiana Feeney	tatiana.feeney@geemail.com	Garden Grove	California	869990631278001642	a3d7cab7bac466638229dbf63b78e86a	Mastercard	33.732953030039738	-117.87607556763291
7979	2019-12-28 07:44:41	2019-12-28	Everette Hagenes	everette.hagenes@geemail.com	Washington	District of Columbia	210074502029192768	b0ff793f4d2ad3221aee44055e21ea01	Maestro	38.9039667460400622	-77.0763267616488008
7980	2019-12-28 07:59:45	2019-12-28	Stanford Gulgowski	stanford.gulgowski@geemail.com	Winston–Salem	North Carolina	4587856075392973	aa1b7e59fae4a80b5a9823b9671408bb	Mastercard	36.0681526456259149	-80.3325464785694976
7981	2019-12-28 08:16:03	2019-12-28	River Pacocha	river.pacocha@geemail.com	Phoenix	Arizona	180040518814228626	062f2e3d317573e0eb03f4507b5a2e3a	VISA 13 digit	33.5490359082285323	-112.126939471198625
7982	2019-12-28 08:31:34	2019-12-28	Dr. Burk Connelly MD	dr.burk.connelly.md@warmmail.com	Louisville	Kentucky	3112741225402270380	5d96f0fda0bef693145b8e1994340c8d	VISA 16 digit	38.252355983052027	-85.5908359408915089
7983	2019-12-28 08:39:21	2019-12-28	Dr. Marian Paucek	dr.marian.paucek@geemail.com	Berkeley	California	3402283489782755	7e28ddad4710a84df1a7e6235936cf86	Diners Club / Carte Blanche	37.8266084486704557	-122.280963870305044
7984	2019-12-28 09:16:58	2019-12-28	Mr. Lute Brakus DVM	mr.lute.brakus.dvm@geemail.com	San Francisco	California	4158428135930900	c9baa45f56758e500019f1cddfbbdbaf	Diners Club / Carte Blanche	37.7754069877405385	-122.460321145969317
7985	2019-12-28 10:05:55	2019-12-28	Laken Rippin-Stroman	laken.rippin.stroman@geemail.com	Joliet	Illinois	676336207849401	640dec1f886cb81094026e34b1386503	VISA 16 digit	41.5078061374694087	-88.0628259670559288
7986	2019-12-28 10:15:22	2019-12-28	Giovanni VonRueden-Welch	giovanni.vonrueden.welch@geemail.com	New York	New York	3045088118843713	762d4f05b460e8ef36a42045a6cfd6f0	Discover	40.6048429663050925	-73.9872942626371923
7987	2019-12-28 12:16:47	2019-12-28	Mrs. Becky Torphy DVM	mrs.becky.torphy.dvm@geemail.com	Jackson	Mississippi	869909973101571510	cfb792f6e47b64fa0d674326cb60eed8	Mastercard	32.2868987215861694	-90.2722835519790721
7988	2019-12-28 12:17:33	2019-12-28	Cecily Yost	cecily.yost@geemail.com	Oakland	California	3112769909430529456	8e4ac8705e8ed470e5715d05182328c2	JCB 16 digit	37.8206500378220056	-122.296573848920914
7989	2019-12-28 12:19:31	2019-12-28	Val Weissnat	val.weissnat@geemail.com	Fresno	California	639046160365816	c24317c90dcc345f860fb6e56c8aecac	JCB 15 digit	36.6983885435726478	-119.801845723215123
7990	2019-12-28 12:38:41	2019-12-28	Dwaine Von	dwaine.von@warmmail.com	Lakeland	Florida	4008467640213453	74fbc29626959ced5a051921b3cc09e5	Voyager	28.0303263749293983	-81.9666463670670993
7991	2019-12-28 12:43:30	2019-12-28	Scot Muller	scot.muller@woohoo.com	Albuquerque	New Mexico	501880725300109	4e88c6c1ed313e4a86b274ad7c00d959	American Express	35.201296441922338	-106.717262918276347
7992	2019-12-28 13:04:56	2019-12-28	Bertrand Feest II	bertrand.feest.ii@geemail.com	San Francisco	California	3466921187785942	63f6bcac64245a5f7001219537de401e	VISA 16 digit	37.7838863021456746	-122.444320430608016
7993	2019-12-28 13:13:51	2019-12-28	Deegan Miller	deegan.miller@geemail.com	San Francisco	California	52040905215064181	8a783a270b16f375b96dd61a1257d61a	Diners Club / Carte Blanche	37.7605799975302503	-122.486638176868354
7994	2019-12-28 13:33:57	2019-12-28	Guthrie Hamill Jr.	guthrie.hamill.jr.@warmmail.com	Saint Paul	Minnesota	3528545007566228711	7b293433d4b55f1972c1778ea8bf61b3	VISA 13 digit	44.9127284191489267	-93.1843287694532449
7995	2019-12-28 13:37:10	2019-12-28	Layla Schinner	layla.schinner@woohoo.com	Phoenix	Arizona	3774478839991378	cea9a0f3a5d686729fc7330fb22b12b7	JCB 15 digit	33.6218568850707271	-112.124009315429632
7996	2019-12-28 13:37:52	2019-12-28	Madeleine Conroy	madeleine.conroy@geemail.com	Naperville	Illinois	3011551276515179	69cc6b0a361dc916ec4b1873e45583ef	JCB 15 digit	41.6540608106561052	-88.1033057263475001
7997	2019-12-28 14:02:09	2019-12-28	Christoper Cronin	christoper.cronin@geemail.com	Irving	Texas	869944504207709899	87420a8efe735c5e0fdd87862834a67b	Diners Club / Carte Blanche	32.7903879376079885	-96.9072076289262583
7998	2019-12-28 14:05:53	2019-12-28	Clemens Glover	clemens.glover@geemail.com	Fairfield	California	675972340763514	0d689aa91f0d845b3908fa464cfe51c8	JCB 16 digit	38.2557057455770675	-121.978705320693919
7999	2019-12-28 14:09:34	2019-12-28	Wess Windler	wess.windler@geemail.com	San Francisco	California	4561380487257	8f15bb8c5a3eee24f9c10ad7e3b04c8f	Voyager	37.7963237155324094	-122.433521849177922
8000	2019-12-28 14:44:33	2019-12-28	Brannon Mayert-Gleichner	brannon.mayert.gleichner@geemail.com	Dallas	Texas	3158646474779760245	6f5a8ff09ca946223877eddc4f922f6f	JCB 15 digit	32.7897960508048527	-96.794274691348889
8001	2019-12-28 14:46:34	2019-12-28	Duwayne Cole	duwayne.cole@geemail.com	San Francisco	California	6011191764061046017	c484bd66592c0bed1aefecd72180460f	VISA 13 digit	37.7673840073415761	-122.41993034921498
8002	2019-12-28 14:51:51	2019-12-28	Isaias DuBuque	isaias.dubuque@geemail.com	San Jose	California	4564478897015	06bba196e3ee43e09d1e655d545ef3fb	JCB 16 digit	37.3674125470507903	-121.725755833483859
8003	2019-12-28 15:00:31	2019-12-28	Frank Morissette	frank.morissette@warmmail.com	Berkeley	California	210034141696424631	dece424d0acd399f254c69550ad4611c	American Express	37.8911742599350561	-122.302922765388573
8004	2019-12-28 15:17:02	2019-12-28	Dr. Irl Fadel DDS	dr.irl.fadel.dds@geemail.com	San Francisco	California	3337373553577086116	1ab54558ae3009e720d9566297980d21	JCB 16 digit	37.759338859881602	-122.422138326388961
8005	2019-12-28 15:27:17	2019-12-28	Hunt Wolf-Dach	hunt.wolf.dach@geemail.com	Los Angeles	California	4096341968459	fae5e6b6fdd8354102acb6654307443e	American Express	34.0412650617171053	-118.431695268581805
8006	2019-12-28 16:20:26	2019-12-28	Arnoldo Kerluke-Thiel	arnoldo.kerluke.thiel@woohoo.com	Palmdale	California	3436880863266246	0a3e31cad73df44b93ed70cca42cab49	Voyager	34.6586953648682723	-118.153948646876586
8007	2019-12-28 16:24:20	2019-12-28	Dr. Juana Kassulke MD	dr.juana.kassulke.md@woohoo.com	San Diego	California	54390354545013053	77de68216ad334e680f183faf4a64e98	Mastercard	32.8716537529204018	-117.153673598440363
8008	2019-12-28 17:01:28	2019-12-28	Etna Collins	etna.collins@geemail.com	San Antonio	Texas	6011662640464440322	d58d353c225b67d378e81865608a5b03	VISA 16 digit	29.430940854044259	-98.4636570225771521
8009	2019-12-28 17:03:26	2019-12-28	Nautica Wolff DVM	nautica.wolff.dvm@geemail.com	Charleston	South Carolina	676261896924489	48e52034092fb3a0d1e902fcc0285033	American Express	32.9127039546608913	-79.9789996603652895
8010	2019-12-28 17:14:36	2019-12-28	Verda Lehner PhD	verda.lehner.phd@geemail.com	Lincoln	Nebraska	210099872331082127	aca0dad3fe9d4092aadefc070c22cf49	American Express	40.8005380600243797	-96.6317477733988284
8011	2019-12-28 17:15:36	2019-12-28	Leeann Jaskolski	leeann.jaskolski@geemail.com	Los Angeles	California	3096939055755578119	101bd263248d45835c34a98b5e9a8be2	Mastercard	34.0554078651458028	-118.482220698193828
8012	2019-12-28 17:42:04	2019-12-28	Dr. Jessie Zemlak	dr.jessie.zemlak@geemail.com	Pompano Beach	Florida	3337284389128077355	c53264e206c42155d65304d47914d064	JCB 16 digit	26.2337362644992744	-80.2107413369078159
8013	2019-12-28 18:04:12	2019-12-28	Juelz Nicolas	juelz.nicolas@geemail.com	Los Angeles	California	676206372496866	e979d862ba018be07a46264499aff8a4	VISA 16 digit	33.9512373992573444	-118.495301612046731
8014	2019-12-28 18:43:04	2019-12-28	Johny Kautzer	johny.kautzer@geemail.com	San Francisco	California	869972094933917011	006097a0d4bd988e0a01c760b7b8d114	Voyager	37.7518350754788443	-122.441377837880609
8015	2019-12-28 19:13:51	2019-12-28	Minerva Boyer	minerva.boyer@geemail.com	Fort Worth	Texas	54610923843947214	5b4ef70bf96fdaa8873a5419ab7a91ce	Mastercard	32.776945764996114	-97.296524468698351
8016	2019-12-28 19:13:55	2019-12-28	Dr. Landyn Flatley	dr.landyn.flatley@geemail.com	Chicago	Illinois	51964177549658391	943fda45cf63b729b09de3f638d46ce6	American Express	41.8397528194192816	-87.7389273297537073
8017	2019-12-28 19:27:23	2019-12-28	Zora Greenfelder	zora.greenfelder@geemail.com	Los Angeles	California	6011022705085543120	293234c3d402e356795654b78e08e87d	Discover	34.0000992671452451	-118.457388851604605
8018	2019-12-28 19:42:28	2019-12-28	Miss Katlin Satterfield DDS	miss.katlin.satterfield.dds@geemail.com	Berkeley	California	3040367018665755	7cb50da69ed7d607c57267169c9f6fc7	VISA 16 digit	37.9168906196163817	-122.256505890075488
8019	2019-12-28 19:49:29	2019-12-28	Dr. Sherrill Schamberger	dr.sherrill.schamberger@geemail.com	San Francisco	California	3054629647394545	0fe80a697901367aaa94067bc7499c68	Mastercard	37.7582060062686082	-122.441776738746896
8020	2019-12-28 20:11:29	2019-12-28	Amari Littel	amari.littel@woohoo.com	San Francisco	California	3013242818671880	4125e48d2579d4657b69d871422d48af	Discover	37.7387842315273971	-122.429836673190053
8021	2019-12-28 20:21:25	2019-12-28	Jonah Ankunding	jonah.ankunding@geemail.com	Louisville	Kentucky	4375331445964949	20edae2c200a40c58d2aedae1d04b612	JCB 16 digit	38.1274790018700074	-85.5882236627932684
8022	2019-12-28 20:48:15	2019-12-28	Elick Armstrong II	elick.armstrong.ii@woohoo.com	Washington	District of Columbia	3024722112327536	eb037ff94073a2d1508f015bc17e0e61	VISA 13 digit	38.813947937803718	-76.9642109017100182
8023	2019-12-28 20:54:37	2019-12-28	Khadijah Lueilwitz	khadijah.lueilwitz@geemail.com	New York	New York	210015782802323242	faee2dfa364f14612bfdc47953968fa8	JCB 16 digit	40.738076549371705	-73.9731168538227593
8024	2019-12-28 21:17:40	2019-12-28	Isla Padberg	isla.padberg@geemail.com	San Antonio	Texas	6011915869944945445	c94dcf38a0b2f0e2687d85d84d333519	Discover	29.4558198928438131	-98.6099734600003757
8025	2019-12-28 21:30:14	2019-12-28	Jasmin Bins	jasmin.bins@warmmail.com	San Francisco	California	4603071973037	d52908b2b39d8b0c6374fca6d88993ed	Maestro	37.7574757125830729	-122.436350578525037
8026	2019-12-28 21:42:56	2019-12-28	Alvis Brakus	alvis.brakus@geemail.com	Charleston	South Carolina	4971249543083347	402e82162c371253656243df93ffc7b3	Voyager	32.8395700263787091	-79.8647776178233357
8027	2019-12-28 21:51:54	2019-12-28	Terrill Abbott	terrill.abbott@geemail.com	Stockton	California	4980866379136938	aa46165bc7f0c8ca7f0ffd28ce281950	Mastercard	38.005662528212369	-121.292972816721715
8028	2019-12-28 22:08:56	2019-12-28	Sampson Gibson	sampson.gibson@geemail.com	San Francisco	California	4390811889020010	43425c51852ab880865a56f14079434c	Maestro	37.7627032661669801	-122.440456226014064
8029	2019-12-28 22:55:46	2019-12-28	Abdullah Eichmann-Abernathy	abdullah.eichmann.abernathy@warmmail.com	Olathe	Kansas	3112641699811510753	57dbceedb588a202bfe6b83236d4eb95	Diners Club / Carte Blanche	38.9682215442072604	-94.8635499193966467
8030	2019-12-28 23:18:14	2019-12-28	Mr. Dorr Nader V	mr.dorr.nader.v@geemail.com	Berkeley	California	4524255623892624	89fe6188ca7af57d4905f5c08f3dce4c	JCB 15 digit	37.9105897664135014	-122.272560628999159
8031	2019-12-28 23:23:28	2019-12-28	Shea Lemke	shea.lemke@geemail.com	New York	New York	3014070451160120	ecacb62adf0646d177123da648c25c5c	Mastercard	40.6945042056720681	-73.963778119011593
8032	2019-12-28 23:23:59	2019-12-28	Lucio Berge DVM	lucio.berge.dvm@geemail.com	New York	New York	4917416831431	8ba893a97c22da73e7ec05d9e5d6a656	VISA 16 digit	40.6374203585777423	-73.9341544370062564
8033	2019-12-28 23:40:18	2019-12-28	Vivian Lemke	vivian.lemke@geemail.com	Charlotte	North Carolina	3088248846608019517	a2bb5229076ed17e7d63118336f4785a	Diners Club / Carte Blanche	35.1613603045020255	-80.9174748350810233
8034	2019-12-28 23:54:07	2019-12-28	Mr. Evans Heller III	mr.evans.heller.iii@woohoo.com	New York	New York	4661056876523103	3d9650630ca3289eb9c20675dec31410	American Express	40.7511063549891119	-73.9587672455597698
8035	2019-12-29 00:04:59	2019-12-29	Mrs. Katarina Heller	mrs.katarina.heller@geemail.com	Grand Prairie	Texas	869906998002992690	a72eed474924c5b794ba5836d2a49cbe	Voyager	32.774376348178464	-96.9392475596502408
8036	2019-12-29 00:09:38	2019-12-29	Krystina Schuster-Erdman	krystina.schuster.erdman@geemail.com	Seattle	Washington	4073883717762331	6cbfa5fafd038970c414b0492c534921	VISA 16 digit	47.5583550266381323	-122.316139559905594
8037	2019-12-29 00:35:26	2019-12-29	Dr. Washington Johnston IV	dr.washington.johnston.iv@geemail.com	Denver	Colorado	3158025038338261010	1c6990c3abaa19d6cf67bff2243ac8b6	VISA 16 digit	39.7194251189526142	-104.867460368179167
8038	2019-12-29 01:01:11	2019-12-29	Ward Williamson	ward.williamson@geemail.com	Rancho Cucamonga	California	180017822139033904	709ef34c666c8b9597210ae73875f4ee	VISA 13 digit	34.1052466765038673	-117.580134877237299
8039	2019-12-29 01:35:49	2019-12-29	Miss Kerrie Ernser	miss.kerrie.ernser@woohoo.com	San Francisco	California	3774282753273973	1a983eaf1f11eb73582bfa06959cb1b7	VISA 16 digit	37.7610921092811225	-122.418472367222378
8040	2019-12-29 01:46:11	2019-12-29	Savanna Hettinger MD	savanna.hettinger.md@geemail.com	College Station	Texas	4265259415787573	6802d4220b5c091e8f6fb81d22695449	JCB 15 digit	30.5155161362651732	-96.2061955701407072
8041	2019-12-29 01:52:04	2019-12-29	Audley Corwin	audley.corwin@geemail.com	Wichita	Kansas	4454905363029803	b032b04ed3be3ec5f405c4010efa24fd	JCB 15 digit	37.7898401165258164	-97.4397680118881198
8042	2019-12-29 02:01:52	2019-12-29	Skyla Marks	skyla.marks@geemail.com	Oakland	California	6011277643406491103	b0f2c1c3259034cd3f630e08dd0ea9bf	VISA 13 digit	37.8140546177506991	-122.279481267689377
8043	2019-12-29 02:10:41	2019-12-29	Moises Heidenreich	moises.heidenreich@woohoo.com	Los Angeles	California	4587779875828	7b1e37704aa090419b5cec775f50629b	JCB 15 digit	33.9596113938238418	-118.504401467227552
8044	2019-12-29 02:38:29	2019-12-29	Dr. Laron Murazik DDS	dr.laron.murazik.dds@geemail.com	Pasadena	California	6011413292075092571	b9739161fa9af31366e03aeb20f11614	JCB 16 digit	34.2494684608042235	-118.220041595986487
8045	2019-12-29 02:49:51	2019-12-29	Mr. Hillard Crist	mr.hillard.crist@warmmail.com	Irvine	California	180020410269456288	b8d7ffe630d9c4110f591fcf9c5da865	Diners Club / Carte Blanche	33.7685339617557858	-117.795649001934748
8046	2019-12-29 02:59:45	2019-12-29	Nicolas Runolfsson DVM	nicolas.runolfsson.dvm@geemail.com	San Francisco	California	060482088096050	be32cd12339808584038b229b4a1ca04	Voyager	37.7727783281926222	-122.447269025147222
8047	2019-12-29 03:08:08	2019-12-29	Antonette Sporer	antonette.sporer@woohoo.com	San Diego	California	4513016271522	935e7f9ac6efef7e23b8a2e88975fca1	VISA 16 digit	32.791058260581643	-117.158016074439516
8048	2019-12-29 03:21:30	2019-12-29	Tamatha Hudson MD	tamatha.hudson.md@warmmail.com	Berkeley	California	3050133161549869	12857e18774bcf0d761b4a022c5743bd	Mastercard	37.8781521742335485	-122.274908001625192
8049	2019-12-29 03:54:57	2019-12-29	Georgeanna Jacobson	georgeanna.jacobson@geemail.com	Corpus Christi	Texas	501808250158253	935dd7e18cc8b80a08edcb725b4430db	VISA 13 digit	27.661525722679869	-97.2140180673744538
8050	2019-12-29 04:11:37	2019-12-29	Clearence Stroman	clearence.stroman@geemail.com	Oceanside	California	4851938003999	7e111673b516416d94d7c0bc594ba4a6	American Express	33.2680589502099906	-117.288163627971713
8051	2019-12-29 04:12:25	2019-12-29	Amara Legros	amara.legros@warmmail.com	Sacramento	California	3473511046779458	b944b87ceb5463b0029dcf5ca355d693	JCB 16 digit	38.6561161995664264	-121.511119889073441
8052	2019-12-29 04:12:34	2019-12-29	Auston Bailey DDS	auston.bailey.dds@geemail.com	Tempe	Arizona	869905070493912487	deff795374e028baccb8d2ab3afa0381	Discover	33.446734683626886	-111.922412177085121
8053	2019-12-29 05:00:29	2019-12-29	Stacey Ziemann	stacey.ziemann@woohoo.com	Los Angeles	California	676248956210305	a96772b2b02c829cc6ab0cf5ed8ef325	Mastercard	33.9387904194980834	-118.357378038251028
8054	2019-12-29 05:26:52	2019-12-29	Dr. Daxton Waelchi DDS	dr.daxton.waelchi.dds@woohoo.com	Oakland	California	54314503895629578	c55b897f6f73900782c105b25cf82f58	Voyager	37.81418897208777	-122.258113845658912
8055	2019-12-29 05:34:54	2019-12-29	Chaim Donnelly	chaim.donnelly@warmmail.com	San Jose	California	3777717797954135	98b91eea8e06db32a666bc334a4d606d	Diners Club / Carte Blanche	37.2296526355024469	-121.847812213398143
8056	2019-12-29 05:39:53	2019-12-29	Caron Mosciski	caron.mosciski@geemail.com	Denver	Colorado	4923270292389	b19f165869fbbdfd2d3f6183bed1d1ad	Discover	39.7264581910386667	-104.915443795245523
8057	2019-12-29 05:41:46	2019-12-29	Ritchie Buckridge III	ritchie.buckridge.iii@geemail.com	San Francisco	California	3052013381249912	30f8f3db3787556a91aa74e069bfc6e1	Mastercard	37.781664765174682	-122.480476562437303
8058	2019-12-29 06:20:08	2019-12-29	Willa Cummings	willa.cummings@geemail.com	San Francisco	California	3096174034382781465	738987101e079f10eebf3578995589e6	VISA 13 digit	37.8158537886972113	-122.436968130997514
8059	2019-12-29 06:20:38	2019-12-29	Deborah Dickens DVM	deborah.dickens.dvm@geemail.com	Houston	Texas	180023439657124981	a06444ab8cb9e1eac93f741897b4dd26	VISA 16 digit	29.7141362460408374	-95.4126551094014275
8060	2019-12-29 06:55:57	2019-12-29	Othel Hills	othel.hills@geemail.com	Los Angeles	California	53215904280641899	f187d7bf26a4a1b100bd6b9bb3dbef86	JCB 15 digit	34.1021238103840503	-118.35784372654669
8061	2019-12-29 07:26:36	2019-12-29	Brittnay Parker MD	brittnay.parker.md@warmmail.com	Colorado Springs	Colorado	869981406296980536	042ba128b62e39c0d553076c7017254c	JCB 16 digit	38.8294807953808458	-104.694490241414684
8062	2019-12-29 07:32:44	2019-12-29	Quinton Becker	quinton.becker@geemail.com	Phoenix	Arizona	869961896706942023	caa43dbb6f9f8b3b317f518315a0519c	Maestro	33.5231307750966394	-112.067132997971413
8063	2019-12-29 07:40:39	2019-12-29	Dr. Chadwick Howell	dr.chadwick.howell@geemail.com	New York	New York	4339382983833	a349bf5a7717a30fbcefe2a99ecc1e23	JCB 15 digit	40.6233973840940763	-73.9328472603939417
8064	2019-12-29 07:51:06	2019-12-29	Hall Ortiz	hall.ortiz@geemail.com	North Las Vegas	Nevada	6011145181692713484	60193b583b50b2047276ad1e15726dff	VISA 16 digit	36.2946631936047197	-115.106656738206382
8065	2019-12-29 08:04:06	2019-12-29	Rashad Pagac	rashad.pagac@warmmail.com	Oakland	California	3735478308660973	b878be9887eb0808f12a91b86eff153f	JCB 15 digit	37.7962646460457705	-122.235676127853964
8066	2019-12-29 09:21:44	2019-12-29	Ireland Donnelly	ireland.donnelly@geemail.com	Akron	Ohio	3096804181144757263	4c88b53ec53525e9a4b07141ed0c774d	Diners Club / Carte Blanche	40.992019225826489	-81.4647953367173727
8067	2019-12-29 09:34:03	2019-12-29	Sheryll Rempel	sheryll.rempel@geemail.com	El Cajon	California	3025915503280483	0715bc1ff95e65866982dae8e95e0c5a	VISA 16 digit	32.7732702803805438	-117.046409332444526
8068	2019-12-29 09:48:40	2019-12-29	Gwyn Kshlerin	gwyn.kshlerin@geemail.com	Oakland	California	210084245774435127	37a5535683246bb9b01307abbfc89cbe	VISA 16 digit	37.807952086025864	-122.291666928268953
8069	2019-12-29 10:04:21	2019-12-29	Arlin Becker-Johnson	arlin.becker.johnson@geemail.com	Los Angeles	California	6011097209922114914	d45df5b7b4ceae3b543ea1b03e036d19	American Express	33.9565568808332046	-118.420362229877327
8070	2019-12-29 10:27:24	2019-12-29	Delma Metz	delma.metz@geemail.com	Las Vegas	Nevada	3088830320481488706	e889505d8b82a48875aad1926913b01c	VISA 13 digit	36.3168142886467251	-115.217482285362109
8071	2019-12-29 10:35:54	2019-12-29	Luann Von	luann.von@warmmail.com	San Francisco	California	6011217152019199338	a86e167d6db7afe50feb29336b35a2b1	VISA 13 digit	37.7834095108497436	-122.428275373327935
8072	2019-12-29 10:39:57	2019-12-29	Dr. Denice Schultz PhD	dr.denice.schultz.phd@geemail.com	Houston	Texas	503877722787528	36b799c99d6343064c7de028ca036c43	Maestro	29.7325212190005921	-95.3340119830347561
8073	2019-12-29 11:36:54	2019-12-29	Brett Olson	brett.olson@woohoo.com	Lewisville	Texas	4608973408187692	71db66f96fdadc1cf032ce8c2dfe407c	VISA 16 digit	33.1166373417232194	-97.0218616552215138
8074	2019-12-29 11:44:28	2019-12-29	Mr. Cris Johns	mr.cris.johns@woohoo.com	Cincinnati	Ohio	502010204967540	6ab252f95a85755c785f6daf6345909a	Discover	39.2071098741840558	-84.5956118703626032
8075	2019-12-29 11:52:40	2019-12-29	Huey Gutkowski	huey.gutkowski@geemail.com	San Francisco	California	3786131030594105	37b11ba2baad5d122dc2de8ffbdea301	JCB 15 digit	37.775392476503157	-122.46448323359229
8076	2019-12-29 13:05:04	2019-12-29	Rudy Carter	rudy.carter@geemail.com	Fort Lauderdale	Florida	3337248797340531121	d1c1af568dc6ed66c7d993ddf4d29333	VISA 13 digit	26.0853951801534762	-80.101902930141236
8077	2019-12-29 13:48:50	2019-12-29	Ignatz Skiles	ignatz.skiles@geemail.com	San Francisco	California	3705424685792118	34d7313344a6d8d76e7a6beff891ddfb	VISA 13 digit	37.7613996317233642	-122.426469177829631
8078	2019-12-29 14:11:18	2019-12-29	Karley Bergstrom	karley.bergstrom@geemail.com	San Francisco	California	502067682834121	7cd829be8fcc7d485e8a7bf9a0711855	JCB 15 digit	37.7574364869943508	-122.429463992894128
8079	2019-12-29 14:57:03	2019-12-29	Demond Macejkovic	demond.macejkovic@geemail.com	Omaha	Nebraska	3003506650286324	aaca36c8f55ed80105ebd0f1ea283842	Mastercard	41.2896773719374082	-96.0625903304316182
8080	2019-12-29 15:05:12	2019-12-29	Wendy Pollich PhD	wendy.pollich.phd@geemail.com	Anaheim	California	4478932352691	54421e5051be9d846e8b82c405b01f93	Maestro	33.9216290203686768	-117.702994348828113
8081	2019-12-29 16:13:16	2019-12-29	Marshal Bruen	marshal.bruen@geemail.com	Berkeley	California	869921403049768519	a0054750842c1ff66b8500467853dbda	JCB 16 digit	37.8655609625744987	-122.270264475936656
8082	2019-12-29 16:17:58	2019-12-29	Mazie Denesik-Lakin	mazie.denesik.lakin@geemail.com	New York	New York	3435040542776153	4013aebbd92f9ff533f2df34eeada8a1	JCB 16 digit	40.6097585122324531	-73.9956817866198691
8083	2019-12-29 16:37:03	2019-12-29	Mat Torp	mat.torp@geemail.com	Oakland	California	4379549347787	9b792bd9233798f484aac332dc2b611f	JCB 16 digit	37.8362331057886934	-122.241156345377533
8084	2019-12-29 16:37:41	2019-12-29	Armin Towne DDS	armin.towne.dds@geemail.com	Los Angeles	California	3088083109489464957	c35224632ca07fbf7bfc1b1cd4bab46b	VISA 16 digit	34.0397910965006787	-118.495908907148234
8085	2019-12-29 16:52:36	2019-12-29	Abdullah Stiedemann	abdullah.stiedemann@geemail.com	Chicago	Illinois	4533347501191028	1125d8834eac4fbd3f949fc73f6d5958	Maestro	41.7710291880484661	-87.6896321329783603
8086	2019-12-29 16:54:17	2019-12-29	Millie Heaney MD	millie.heaney.md@geemail.com	San Francisco	California	3158015529590539434	033c68366b61dd1459d1db2eb152e39c	Mastercard	37.7802404430264716	-122.389648552721269
8087	2019-12-29 16:54:45	2019-12-29	Nile Rodriguez I	nile.rodriguez.i@woohoo.com	Oceanside	California	3011804840889335	c80c2b37a853d994070e697decc7e478	Mastercard	33.3116164408978079	-117.291803047162304
8088	2019-12-29 17:43:40	2019-12-29	Kathlene Beer DDS	kathlene.beer.dds@geemail.com	Berkeley	California	3528056923348377314	36faa2035e56b8c8c566432804e09d9a	Discover	37.8545546619029452	-122.302177354521561
8089	2019-12-29 17:53:28	2019-12-29	Presley Hayes	presley.hayes@woohoo.com	Oakland	California	4448992550682	274119071522f39fbba0b8117f939713	American Express	37.8018266441866402	-122.279390616458528
8090	2019-12-29 18:12:02	2019-12-29	Oneal Heidenreich	oneal.heidenreich@geemail.com	San Francisco	California	4448204064709973	f7cb71c25a7c3943fd2627c699c955aa	VISA 16 digit	37.7495983061915936	-122.44574740543807
8091	2019-12-29 18:27:38	2019-12-29	Dr. Adah Hermann DVM	dr.adah.hermann.dvm@geemail.com	Chicago	Illinois	3528313053491137031	bfcdc1334cb583976d46a0d5ae540afd	JCB 16 digit	41.8928419825457041	-87.611270142582427
8092	2019-12-29 18:47:29	2019-12-29	Mignon Heller	mignon.heller@geemail.com	Daly City	California	180014056258162425	5198c6b26a47f9b338e12969639564c5	Maestro	37.6319689861420485	-122.383175170524055
8093	2019-12-29 18:47:42	2019-12-29	Stacy Harris	stacy.harris@geemail.com	High Point	North Carolina	3408345078839181	ac146528883d4e7c47abc253be4f68d0	JCB 16 digit	35.9695145476236959	-80.0537148138247403
8094	2019-12-29 18:52:42	2019-12-29	Luke O'Reilly	luke.o'reilly@warmmail.com	Chandler	Arizona	3096692285362616179	02242f6804b8dc36575c051450959c0a	VISA 13 digit	33.3259658091325264	-111.826097247132665
8095	2019-12-29 19:07:46	2019-12-29	Toccara Wolff	toccara.wolff@geemail.com	Elk Grove	California	869919997168628762	35182db1da719727e053b299c4009e36	Discover	38.497137714950739	-121.33986710346305
8096	2019-12-29 19:14:18	2019-12-29	Genesis Gulgowski	genesis.gulgowski@geemail.com	Miami	Florida	6011825424680896078	70170626a05ec426ef0bd4acd8b24f1d	JCB 15 digit	25.869312541992219	-80.1494213426824729
8097	2019-12-29 19:24:04	2019-12-29	Kaelyn Hand	kaelyn.hand@geemail.com	Orlando	Florida	4957634808934649	d22cabc7036d0f12d7aa31c138e544fe	VISA 13 digit	28.4113615521028642	-81.1878745884601045
8098	2019-12-29 19:33:14	2019-12-29	Syed Ferry	syed.ferry@geemail.com	San Francisco	California	52277878816089697	d6f28c750a8a5ee257d0946865cf7334	American Express	37.7620117624918308	-122.418816370237991
8099	2019-12-29 19:51:10	2019-12-29	Ermine Becker	ermine.becker@geemail.com	Anaheim	California	3722719168889102	e818664d89cb3f78f686c8abc0c80669	JCB 16 digit	33.8254657842982525	-117.779778562739864
8100	2019-12-29 19:54:30	2019-12-29	Isabella Cremin	isabella.cremin@geemail.com	Los Angeles	California	676171468704821	96f2906e9d04e3877b66c4a64a9f1518	Diners Club / Carte Blanche	34.0631750914134059	-118.364547105784709
8101	2019-12-29 20:03:50	2019-12-29	Loren Wiegand-Gleichner	loren.wiegand.gleichner@woohoo.com	Omaha	Nebraska	53690023505201993	e667ca5458f3876c69170a7e8acf0c1a	JCB 16 digit	41.205923111518473	-96.1091586933586797
8102	2019-12-29 20:38:44	2019-12-29	Mr. Rodger Rogahn IV	mr.rodger.rogahn.iv@geemail.com	Lafayette	Louisiana	53820616018566746	1a507a90deff4651d728175bb060c8ee	JCB 15 digit	30.1777034213744102	-92.1247509951088546
8103	2019-12-29 21:10:49	2019-12-29	Mr. Jonas Roob	mr.jonas.roob@woohoo.com	Manchester	New Hampshire	869968107047265618	f7bd2f05bdf5dac66356cb1a0bceece2	Discover	43.0728908000119048	-71.4099694413024935
8104	2019-12-29 21:48:12	2019-12-29	Dolly Ratke	dolly.ratke@geemail.com	Oakland	California	4596773775926	48cd56a28469c10d89164042efe872c2	VISA 16 digit	37.780822211160519	-122.26320816207047
8105	2019-12-29 22:33:10	2019-12-29	Hosea Howell	hosea.howell@geemail.com	Concord	California	3467483054878853	ecffba466c2e9188b35dd7a2d7e216be	Maestro	37.9017032926369453	-121.97343320731855
8106	2019-12-29 22:42:01	2019-12-29	Shaquan Robel	shaquan.robel@warmmail.com	Columbus	Ohio	676240803082102	9cde40107fb8b54f62173933fde7adb6	Mastercard	40.0039986359000181	-83.0141153945822339
8107	2019-12-29 22:51:11	2019-12-29	Miss Kala Dibbert	miss.kala.dibbert@geemail.com	Dallas	Texas	3528611436815340101	71a0e37b8fc7d322fab3d070e4e73c04	Mastercard	32.8600118166573338	-96.8455699953213269
8108	2019-12-29 23:23:03	2019-12-29	Jemal Wehner	jemal.wehner@woohoo.com	Oklahoma City	Oklahoma	4045847525974	61b88ab67137903572f078e45a77d56f	JCB 16 digit	35.5122238004025093	-97.584678131052101
8109	2019-12-29 23:44:36	2019-12-29	Dr. Erich Klocko Jr.	dr.erich.klocko.jr.@geemail.com	San Francisco	California	210078989149492408	3d19d336fb455aca7921842c542ee3e9	JCB 16 digit	37.7919541074816223	-122.444720602079869
8110	2019-12-30 00:21:06	2019-12-30	Dr. Lemma Skiles DVM	dr.lemma.skiles.dvm@geemail.com	Milwaukee	Wisconsin	4556315080525264	d35a0186ad8d9e6923ff4d528a4cbb08	Voyager	43.1396429831713419	-88.0550117376826762
8111	2019-12-30 00:22:03	2019-12-30	Lennie Goyette	lennie.goyette@geemail.com	Houston	Texas	3007679252338672	e0fa404ac8a53dcafe0acb3d9a0e6d24	JCB 16 digit	29.8366792847014963	-95.3725571403294765
8112	2019-12-30 01:11:46	2019-12-30	Chaz Smitham-Hudson	chaz.smitham.hudson@geemail.com	Grand Prairie	Texas	3465507923783076	2fce42edf1815a969f727546417ef4e2	VISA 16 digit	32.775994371814285	-97.0432989555284422
8113	2019-12-30 01:34:52	2019-12-30	Tenisha Haag	tenisha.haag@warmmail.com	Chesapeake	Virginia	55170108061476920	cb19c862a50675bb04f4e21123bc309e	JCB 15 digit	36.6864756879635152	-76.3894959922723444
8114	2019-12-30 02:11:56	2019-12-30	Kamron Walter	kamron.walter@geemail.com	Philadelphia	Pennsylvania	869910541369816179	344013e68e6d006f75d4147256cbeda4	VISA 16 digit	40.0822512272238711	-75.2237740669764605
8115	2019-12-30 02:51:35	2019-12-30	Ellar Reilly	ellar.reilly@geemail.com	Berkeley	California	3026170259165186	96d8266c7e101510b38b93239eaf662a	JCB 16 digit	37.88635436140693	-122.24631963556061
8116	2019-12-30 02:56:19	2019-12-30	Alva Lindgren	alva.lindgren@woohoo.com	San Francisco	California	4631907684429015	bc771a4c775bc84db5187b1e7e4d8c5f	Voyager	37.7668299106087062	-122.411154349201468
8117	2019-12-30 03:20:20	2019-12-30	Amit Rippin	amit.rippin@geemail.com	New York	New York	3096121969163927478	cf38decd2b9afd7ff01a7b6926560ca7	Discover	40.6893269547019116	-73.9534014919668437
8118	2019-12-30 03:28:14	2019-12-30	Dr. Chase Heaney DVM	dr.chase.heaney.dvm@geemail.com	Los Angeles	California	3431110732144423	d85695f35001b392384ec82944e1030f	Voyager	33.9476488569151584	-118.465899927401168
8119	2019-12-30 03:49:13	2019-12-30	Tillman Friesen-Jacobi	tillman.friesen.jacobi@geemail.com	Syracuse	New York	53357091406809747	fa72fa137b8166b47a3ba4fa53162c6b	Maestro	43.0087880740258797	-76.0695240090847022
8120	2019-12-30 04:06:07	2019-12-30	Lyndon Stanton-Hilpert	lyndon.stanton.hilpert@geemail.com	Detroit	Michigan	869902367425882702	eb2deac13417a0348b06d824527d5c0f	VISA 16 digit	42.3383355486132231	-83.0878260890606697
8121	2019-12-30 04:06:29	2019-12-30	Erwin Rippin	erwin.rippin@geemail.com	Reno	Nevada	4003957606222832	7ab67243f44b706394417fdc5471c75c	Voyager	39.5454786781765577	-119.907865654367583
8244	2019-12-31 15:56:42	2019-12-31	Gerald Hane	gerald.hane@woohoo.com	Mesa	Arizona	4072027129336	cc2fcb5702fa024448b6f479fa410970	American Express	33.3611531598173059	-111.714579037611927
8122	2019-12-30 04:26:14	2019-12-30	Sophie Zieme	sophie.zieme@geemail.com	Cary	North Carolina	676286387969289	80bc65909c13cecdbf35177a4f96098c	Diners Club / Carte Blanche	35.7429972566306589	-78.8093552440490583
8123	2019-12-30 04:49:59	2019-12-30	Mathilde Hane	mathilde.hane@geemail.com	Oakland	California	4216942081993639	b486bde6bf0c6fb4dc625616407d8e42	VISA 16 digit	37.7703559242794427	-122.241343030146098
8124	2019-12-30 04:50:32	2019-12-30	Zavier Wolf	zavier.wolf@geemail.com	Glendale	Arizona	6011387373761459423	569a88e1e488b6c3069466fe40ed1ff2	Discover	33.5066749441664626	-112.230237962005276
8125	2019-12-30 05:08:59	2019-12-30	Melissia Rodriguez	melissia.rodriguez@woohoo.com	New York	New York	3478389726927241	79c21cc72e265da67c5f088535b703cd	Maestro	40.6906229083184172	-73.9193749333161776
8126	2019-12-30 05:37:34	2019-12-30	Dr. Shafter Nitzsche MD	dr.shafter.nitzsche.md@woohoo.com	Columbus	Ohio	4007563917902108	84b03c05186d8cf47862ec891c0f9018	American Express	39.958306823116537	-82.9955636836357513
8127	2019-12-30 06:20:20	2019-12-30	Alwina Feeney	alwina.feeney@geemail.com	San Francisco	California	51111737145830389	e4f2628be7e7fc8942e0f51e3e025240	Discover	37.7748993629610013	-122.437709410090747
8128	2019-12-30 06:25:43	2019-12-30	Adria Jast	adria.jast@woohoo.com	Chattanooga	Tennessee	6011248228699454707	15504b95ee6df522299892b1990b896f	Diners Club / Carte Blanche	35.0740415477510581	-85.2465393803376799
8129	2019-12-30 06:37:35	2019-12-30	Ebony Ernser DVM	ebony.ernser.dvm@geemail.com	Cape Coral	Florida	630430537494376	5c540a448715bf324da7cf5cb56f8559	American Express	26.6189978030946115	-82.0659363175813041
8130	2019-12-30 06:55:09	2019-12-30	Richmond Quitzon	richmond.quitzon@warmmail.com	Houston	Texas	3528796291728712327	396317fb6f128695122db67c17313018	JCB 16 digit	29.6970592341929667	-95.3192351352903984
8131	2019-12-30 07:31:56	2019-12-30	Babette Mosciski	babette.mosciski@woohoo.com	Glendale	Arizona	869900841700155358	165b516e6b3017a20e7da282c737b2d9	Diners Club / Carte Blanche	33.5991676593892237	-112.261479951979211
8132	2019-12-30 08:11:30	2019-12-30	Bose Langosh	bose.langosh@geemail.com	Los Angeles	California	4787480953746	c0c0d70d9bdd91caf4881937d2d3012f	JCB 16 digit	33.9313499942753438	-118.497047566482053
8133	2019-12-30 08:37:51	2019-12-30	Loyal Sporer	loyal.sporer@geemail.com	Los Angeles	California	501836789999129	613771d079bec99df974a7765fed7428	Maestro	33.9732199359085385	-118.349450830928234
8134	2019-12-30 08:43:48	2019-12-30	Tonda Cormier-Paucek	tonda.cormier.paucek@geemail.com	Raleigh	North Carolina	639042321554992	23567c653281487b8a1989b013a6b347	VISA 13 digit	35.8540422523062645	-78.6659732134949508
8135	2019-12-30 09:22:51	2019-12-30	Cameron Schultz I	cameron.schultz.i@warmmail.com	New York	New York	4748776023538012	28fa00c5553abdfaa83cca627c90729c	Maestro	40.6974968508109427	-73.8388030043698791
8136	2019-12-30 09:25:12	2019-12-30	Harris Beahan	harris.beahan@geemail.com	Los Angeles	California	4383977078943087	fe56563a0b64e603db6b49ee043d6feb	JCB 15 digit	33.9375834966875587	-118.334753385557974
8137	2019-12-30 09:35:43	2019-12-30	Newt Krajcik-Thompson	newt.krajcik.thompson@geemail.com	San Francisco	California	3782112383979352	81713b9462a7f7b43422b89e0da0bd7a	VISA 16 digit	37.7657307498187365	-122.446115429451766
8138	2019-12-30 09:45:38	2019-12-30	Ari McKenzie	ari.mckenzie@geemail.com	Chicago	Illinois	3112292201129324571	853807dfb6689c7f61ef0dc6936400e8	Discover	41.915617916297542	-87.6161833709135607
8139	2019-12-30 10:22:31	2019-12-30	Justin Parisian III	justin.parisian.iii@geemail.com	Houston	Texas	3096574955856817805	f694599911700dfa8796640486251e83	American Express	29.8672030162144466	-95.4332378151841425
8140	2019-12-30 11:16:12	2019-12-30	Dr. Lish Rice DVM	dr.lish.rice.dvm@geemail.com	New York	New York	6011087456376026621	efe15eea699c491b02db62cfb6899922	Maestro	40.5803390255421377	-73.931680493931097
8141	2019-12-30 11:27:44	2019-12-30	Kathryn Davis	kathryn.davis@geemail.com	San Francisco	California	869993202377440839	322c09885a9c02ba3907ea09dae389cc	American Express	37.7898140361756134	-122.463437230831971
8142	2019-12-30 12:10:59	2019-12-30	Ms. Saniya Hilll	ms.saniya.hilll@geemail.com	New York	New York	3055530033552143	cc004d73091a266f29ec49d95db36436	JCB 16 digit	40.6962754094731025	-74.011314362603045
8143	2019-12-30 12:23:00	2019-12-30	Shantel Douglas-Balistreri	shantel.douglas.balistreri@woohoo.com	Warren	Michigan	55858357429548347	85f8785e0ed5e102ae66919b6f6c9df4	American Express	42.4340500298418064	-82.9364405801519808
8144	2019-12-30 12:40:40	2019-12-30	Sienna Bergnaum	sienna.bergnaum@warmmail.com	Las Cruces	New Mexico	4678340493678	c6d33744556276c965b15650977cfba4	JCB 16 digit	32.2904762784518269	-106.835009014990916
8145	2019-12-30 12:48:20	2019-12-30	Jamila McKenzie	jamila.mckenzie@geemail.com	Berkeley	California	6011657542619652560	438ca7fa349fe87a24f0eada5eef3fd4	JCB 16 digit	37.8279590305061788	-122.254452562724438
8146	2019-12-30 12:48:40	2019-12-30	Cristopher Gorczany	cristopher.gorczany@geemail.com	San Francisco	California	3088423243157172292	8dc3b6aef82755a8604684a3cb92850a	JCB 15 digit	37.7489039408492744	-122.421102899300735
8147	2019-12-30 13:09:55	2019-12-30	Norah Gutmann	norah.gutmann@geemail.com	Indianapolis	Indiana	3528795800527577144	964f18aee0f981420bba5f77033587c0	JCB 16 digit	39.8152590730700595	-86.1617170444425113
8148	2019-12-30 13:28:49	2019-12-30	Seamus Wolff PhD	seamus.wolff.phd@geemail.com	San Francisco	California	4527241726867389	c82f6399949c605e1fbfacb69ca3e775	JCB 15 digit	37.7857742153167635	-122.452143165602166
8149	2019-12-30 13:44:14	2019-12-30	Irwin Cormier	irwin.cormier@geemail.com	Broken Arrow	Oklahoma	4804197260503	dae0d4f3d6c07377132439bd3f1881d8	JCB 15 digit	35.9876177868116613	-95.7544820038080218
8150	2019-12-30 13:47:52	2019-12-30	Alecia Ebert	alecia.ebert@geemail.com	San Francisco	California	210039868605033989	4e47149c19c29f618f83068c98021c05	American Express	37.7479528227410128	-122.42886538602059
8151	2019-12-30 14:05:53	2019-12-30	Reagan Lynch	reagan.lynch@geemail.com	Minneapolis	Minnesota	52430490215668123	dbb79aa2b71b3a833f3ad8226595aa2c	Voyager	44.8872315810147668	-93.2742729672037001
8152	2019-12-30 14:30:43	2019-12-30	Dr. Antwon Hamill	dr.antwon.hamill@geemail.com	Berkeley	California	180092105144181233	131c6f87024fdd66b71aed1169ef86ba	JCB 16 digit	37.8491285183493034	-122.300608156317438
8153	2019-12-30 14:33:04	2019-12-30	Hayden Pfannerstill PhD	hayden.pfannerstill.phd@geemail.com	Berkeley	California	3528484517299849545	e66f90e44e198f054d6076609c8e1574	Discover	37.8779233069006409	-122.256847349188277
8154	2019-12-30 15:27:43	2019-12-30	Ms. Chessie Zboncak	ms.chessie.zboncak@geemail.com	Gainesville	Florida	4002436173010459	c6b0b4bd5f2d38be0e6b6366a8db199a	VISA 16 digit	29.5878043994598094	-82.3213132118214048
8155	2019-12-30 15:38:25	2019-12-30	Kody Walsh V	kody.walsh.v@geemail.com	Los Angeles	California	4211407167384736	b8d541764f987cd49f15e80fc7f06d0a	VISA 16 digit	33.9196460744697603	-118.316282731573281
8156	2019-12-30 15:51:46	2019-12-30	Dr. Lolla Stark MD	dr.lolla.stark.md@geemail.com	Albuquerque	New Mexico	3112640545414245944	445da7f428fc5e8d00af293adb54085c	VISA 16 digit	35.1662258510611991	-106.716505960987519
8157	2019-12-30 16:37:51	2019-12-30	Dr. Stephan Fadel II	dr.stephan.fadel.ii@woohoo.com	Fort Worth	Texas	675964364370664	56f2701979a0985564ecb2f2260901f0	JCB 16 digit	32.7209587010610861	-97.4375335425890938
8158	2019-12-30 16:51:22	2019-12-30	Ashlynn Ward-Mraz	ashlynn.ward.mraz@geemail.com	New York	New York	3011982580992939	91b6598901afcda150c7c6948d4b23fa	JCB 16 digit	40.6942469070889032	-73.8673726489197406
8159	2019-12-30 16:54:37	2019-12-30	Kristin Lemke	kristin.lemke@geemail.com	Gilbert	Arizona	3436202959398512	5f5b7a6b7bf64cc34b7afdf33b41d064	Mastercard	33.2339315479967752	-111.69816039406173
8160	2019-12-30 17:01:17	2019-12-30	Reggie Macejkovic	reggie.macejkovic@geemail.com	New York	New York	3112891178028780936	b9d8ce04e3d5a43f54089810f9fc9ad9	JCB 16 digit	40.7015666344426563	-73.904921217578277
8161	2019-12-30 17:20:37	2019-12-30	Cheyenne Little Jr.	cheyenne.little.jr.@woohoo.com	San Francisco	California	3088429680917709893	4cd6e6541a8adf0a4c93e99cbcb5d9b4	Maestro	37.7672366668061841	-122.425864271968464
8162	2019-12-30 17:35:39	2019-12-30	Ottilie Farrell	ottilie.farrell@geemail.com	San Antonio	Texas	676153484275929	5b930c6b7d3b6d93d57e2c82358239eb	Discover	29.4593849514216188	-98.4731399653315549
8163	2019-12-30 17:40:22	2019-12-30	Cristine VonRueden-Rohan	cristine.vonrueden.rohan@geemail.com	Berkeley	California	4680569515964899	b9c8e029235770d812cdb029cd63d7bb	American Express	37.9115353896729843	-122.252414042446119
8164	2019-12-30 17:45:21	2019-12-30	Dr. Storm Gibson	dr.storm.gibson@geemail.com	Amarillo	Texas	6011503888074734971	c9e7c902dac17f3be7905f55cdcf0ead	JCB 16 digit	35.1592662390485415	-101.853578134565439
8165	2019-12-30 17:54:51	2019-12-30	Mr. Ty Okuneva Jr.	mr.ty.okuneva.jr.@geemail.com	Nashville	Tennessee	180065753714187933	d892dca0c4fb439a7340ebd2f2ef80d7	Voyager	36.2420444270253128	-86.7451837047841394
8166	2019-12-30 17:57:12	2019-12-30	Constantine McCullough	constantine.mccullough@geemail.com	Charlotte	North Carolina	4793713457281	57cc466222738076e009d5868f3db12f	VISA 16 digit	35.2872499278999854	-80.7772595865596088
8167	2019-12-30 17:57:44	2019-12-30	Ms. Lavona Purdy DDS	ms.lavona.purdy.dds@geemail.com	San Francisco	California	4127311946766986	4035e06cea73f341f83c4144f4102fb8	JCB 16 digit	37.7411083610075835	-122.452674832067729
8168	2019-12-30 18:13:42	2019-12-30	Ms. Emilee Price	ms.emilee.price@geemail.com	Salinas	California	210031135693601681	3e23f721e9f977fed4d6c9cc30d2ca67	VISA 16 digit	36.6829754219621407	-121.582479084207492
8169	2019-12-30 18:51:06	2019-12-30	Sabra Koepp	sabra.koepp@geemail.com	San Francisco	California	3723421916845937	83c3b10794fea8bfdf7e71df93e1540d	JCB 16 digit	37.7647872340481499	-122.424633401838278
8170	2019-12-30 19:04:52	2019-12-30	Siobhan Hagenes	siobhan.hagenes@geemail.com	San Francisco	California	4516177419444602	15b12c4ff22dce0bf8136ede1826ab83	JCB 15 digit	37.7754435602527607	-122.398465776421759
8171	2019-12-30 19:06:41	2019-12-30	Ariane McDermott	ariane.mcdermott@geemail.com	Salt Lake City	Utah	675918315458069	18ef4b569a0d0f9922a9a466f7008a84	Voyager	40.8591186918463549	-111.981567214563484
8172	2019-12-30 19:12:44	2019-12-30	Dr. Porfirio Murray I	dr.porfirio.murray.i@warmmail.com	Norman	Oklahoma	180081104172098347	a3c447ad1626e59bb6d20c8ea34ae390	JCB 15 digit	35.2555238490965195	-97.3111259147312495
8173	2019-12-30 19:18:50	2019-12-30	Miss Lourdes Rutherford	miss.lourdes.rutherford@geemail.com	Philadelphia	Pennsylvania	3051012100801632	d0e1eb6b5856276688bfb5874f8fc017	VISA 16 digit	39.9158524698071204	-75.1814591452378806
8174	2019-12-30 19:46:19	2019-12-30	Jamel Considine	jamel.considine@geemail.com	Santa Ana	California	4773472965609	ffd8aa794a7eaf4e35ef65a1cee604b8	Voyager	33.7731276580702513	-117.882490003101523
8175	2019-12-30 19:46:21	2019-12-30	Ms. Earlie Kub DVM	ms.earlie.kub.dvm@geemail.com	Louisville	Kentucky	52034031467748740	5319721cbef4626ff7d81b73980ce915	VISA 13 digit	38.14245004373565	-85.5578458136949678
8176	2019-12-30 20:02:47	2019-12-30	Dandre Yundt-Kutch	dandre.yundt.kutch@geemail.com	Birmingham	Alabama	869949969965556078	ddf06fc99b8c6b07767343deed43a3f7	VISA 16 digit	33.5171967999335365	-86.7201463403888084
8177	2019-12-30 20:33:32	2019-12-30	Christiana Jaskolski	christiana.jaskolski@geemail.com	Mesa	Arizona	3337598812520601481	c14938e00212d22192022d1a5152d44c	Discover	33.4278402542840638	-111.724246538232634
8178	2019-12-30 20:37:41	2019-12-30	Orelia Schimmel	orelia.schimmel@geemail.com	Arlington	Texas	4994577305385226	d39bcf06e33a5de2c56aa164638297ea	JCB 16 digit	32.6082195437297173	-97.1226004055727259
8179	2019-12-30 21:19:17	2019-12-30	Jerald Roob	jerald.roob@geemail.com	Anaheim	California	4920461155683254	ca8eb03e78aeb14740b0dc53eea3156e	VISA 16 digit	33.7853000923357882	-117.782535497678808
8180	2019-12-30 21:43:23	2019-12-30	Carey Abernathy	carey.abernathy@geemail.com	San Francisco	California	3744490863502556	e6b86ded232fa3017c7e4fea19ef1eda	VISA 16 digit	37.7775295550454189	-122.413558225272908
8181	2019-12-30 21:43:27	2019-12-30	Napoleon Kautzer	napoleon.kautzer@geemail.com	Houston	Texas	869971090055488451	577c41c7a0842dd5022bd74dcfc2d6c2	Diners Club / Carte Blanche	29.8587422937698648	-95.303716308345642
8182	2019-12-30 22:08:37	2019-12-30	Tayshaun Langworth	tayshaun.langworth@geemail.com	Irving	Texas	869921899969370055	c1462996ca9616a89c343079341148bd	VISA 16 digit	32.8734960006035877	-97.0175328235421262
8183	2019-12-30 22:54:41	2019-12-30	Julia Smith	julia.smith@geemail.com	Augusta	Georgia	180081597053807837	d218cb24131df178d3d4581682c2dac0	American Express	33.4551180019713925	-82.0141072891946976
8184	2019-12-30 23:01:14	2019-12-30	Katarina Batz	katarina.batz@geemail.com	Overland Park	Kansas	53883520210597331	dafd2f0a16dfa9b0689740366028521d	American Express	38.8104339986909181	-94.7701835782773827
8185	2019-12-30 23:04:18	2019-12-30	Delores Kuvalis	delores.kuvalis@geemail.com	San Francisco	California	3773553444055917	eaeff076efe9984c6c7e00df5955fc5f	JCB 15 digit	37.7853463611615652	-122.415351517488347
8186	2019-12-30 23:21:27	2019-12-30	Newton Kiehn	newton.kiehn@warmmail.com	New York	New York	210059971510143383	48de6482a222e7f7473904582f361a6f	Discover	40.6378000848684451	-73.952826159576702
8187	2019-12-30 23:34:14	2019-12-30	Kegan Greenfelder	kegan.greenfelder@geemail.com	New York	New York	210065375231750793	d5c1e76e47618d39e51e6dd76ee546a9	JCB 15 digit	40.6891544500589362	-73.965955916409186
8188	2019-12-30 23:39:05	2019-12-30	Hennie Torp	hennie.torp@geemail.com	Los Angeles	California	3337814184217077914	1317487d57cc069c23503b2856576e4d	Maestro	34.0155751854047139	-118.316401664772258
8189	2019-12-30 23:48:04	2019-12-30	Signe Konopelski	signe.konopelski@geemail.com	San Francisco	California	3496632181257341	7197acf296b8dc42a7d58ca4a01d7d78	VISA 16 digit	37.7755169774142772	-122.443466625996265
8190	2019-12-30 23:50:33	2019-12-30	Ms. Micah Stanton	ms.micah.stanton@geemail.com	Memphis	Tennessee	4705187795878597	0afbeea9c174f20ff5d4a69fcc267aa8	JCB 16 digit	35.0359418892834356	-89.976216261999312
8191	2019-12-31 00:24:34	2019-12-31	Kalyn Jacobs	kalyn.jacobs@geemail.com	Portland	Oregon	676255094397316	3f74ff8fb4cdce397da73fc7e53b76f2	VISA 13 digit	45.5921720006391382	-122.661145255854365
8192	2019-12-31 00:32:30	2019-12-31	Demi Lang DVM	demi.lang.dvm@geemail.com	Berkeley	California	180008606834585982	4e4b98d9287aa94cc68869069444fa2b	Voyager	37.8868894808139487	-122.271907180918276
8193	2019-12-31 00:41:38	2019-12-31	Clarine Haley MD	clarine.haley.md@geemail.com	New York	New York	52596830973732738	f20694c7e5ea2da8ca07080e363a9be3	Diners Club / Carte Blanche	40.6571852029524763	-73.9106026023521991
8194	2019-12-31 00:47:47	2019-12-31	Drury Gleichner	drury.gleichner@geemail.com	Columbus	Ohio	54624731128411259	60bcb5c2ecfd5efd0a95c2db11bf3289	Mastercard	39.9723814253274341	-82.994857596582932
8195	2019-12-31 01:28:47	2019-12-31	Dr. Salena Harber DVM	dr.salena.harber.dvm@geemail.com	Plano	Texas	3096429033508074709	64436f50aa466c5ede79c8f298ff06be	JCB 15 digit	33.1040723883632566	-96.675101037993656
8196	2019-12-31 01:44:11	2019-12-31	Mr. Fabian Gutkowski IV	mr.fabian.gutkowski.iv@geemail.com	Los Angeles	California	4850134526522	8252a64fccee74371e2f0b28324440f1	VISA 13 digit	34.0006579591292848	-118.343348326998949
8197	2019-12-31 01:55:09	2019-12-31	Rashida Monahan-McKenzie	rashida.monahan.mckenzie@warmmail.com	San Francisco	California	52673269752444833	3fbf01dc523afad42e4e20401991fb2d	JCB 16 digit	37.7874341383240235	-122.445263586198436
8198	2019-12-31 02:04:47	2019-12-31	Trevon Wiza	trevon.wiza@warmmail.com	Phoenix	Arizona	3096037945446495015	c5fd0d86f4d50f5dfab27714eacc11c6	Diners Club / Carte Blanche	33.6060345341850066	-112.049686765104909
8199	2019-12-31 02:17:09	2019-12-31	Willian Johnston-Windler	willian.johnston.windler@geemail.com	San Antonio	Texas	4292419812506532	e415281b1c8177ef0045cbc708dbe2e8	Voyager	29.5193825722277161	-98.5904375490102893
8200	2019-12-31 02:21:36	2019-12-31	Mr. Rowan Rosenbaum	mr.rowan.rosenbaum@geemail.com	Winston–Salem	North Carolina	869970546399308052	70c8bda8d40bbdedba4dd2d08f382b9e	VISA 16 digit	36.0293807095613303	-80.2071790669243683
8201	2019-12-31 02:31:53	2019-12-31	Archibald Leuschke DDS	archibald.leuschke.dds@geemail.com	San Diego	California	869956250235434119	3d2cf8c7e61a359e97f52c3e5f505c7f	Voyager	32.8675299886215484	-117.155847849268469
8202	2019-12-31 02:37:57	2019-12-31	Lindell Smitham	lindell.smitham@warmmail.com	Cedar Rapids	Iowa	4648704470966487	489c801319585ef231287d7031dc0eef	Diners Club / Carte Blanche	42.0273813287336395	-91.6858234215594905
8203	2019-12-31 02:43:10	2019-12-31	Ms. Nilda Crona	ms.nilda.crona@warmmail.com	Sterling Heights	Michigan	869902516282594178	86ece59bddaeed80cdb65be186e2a382	JCB 16 digit	42.5512161215849218	-82.9904184236351341
8204	2019-12-31 03:11:24	2019-12-31	Mr. Juston Hansen	mr.juston.hansen@geemail.com	Cleveland	Ohio	869979054713734336	4796677c9a2c33b083d7606a844cf060	VISA 16 digit	41.5685274947285635	-81.6269767542142404
8205	2019-12-31 04:00:47	2019-12-31	Mr. Alfonso Price	mr.alfonso.price@geemail.com	San Francisco	California	3424733758832289	555872832adfb48b9b4038c156ec28ac	JCB 16 digit	37.7728654374438619	-122.45242875883666
8206	2019-12-31 04:21:10	2019-12-31	Mr. Hilliard Waelchi	mr.hilliard.waelchi@geemail.com	Dallas	Texas	3462067767923125	a2504b788895f04331d48f9ad6d938d1	JCB 16 digit	32.8113613318458235	-96.7952765602581167
8207	2019-12-31 04:29:59	2019-12-31	Daryl Torp	daryl.torp@geemail.com	Columbia	Missouri	6011678578589755012	46d23ec7f19c5c909ab9c3c81df37f17	Discover	38.9915206903007459	-92.3705304122117496
8208	2019-12-31 04:30:25	2019-12-31	Orene Dach	orene.dach@geemail.com	San Francisco	California	3009205532094964	6ff0267b62914e1fb6dbef26247c6369	VISA 13 digit	37.7789863710046561	-122.463666789803924
8209	2019-12-31 04:39:40	2019-12-31	Mayme Hand	mayme.hand@geemail.com	San Francisco	California	869977174130858906	a7e33d383e7f5c3d14190b3b1ee15c3e	Maestro	37.7808654359010134	-122.42939883097074
8210	2019-12-31 04:46:13	2019-12-31	Cassidy Schowalter MD	cassidy.schowalter.md@geemail.com	Lubbock	Texas	3112989813172339534	ecc8d4868a217d889816e010788582f2	Diners Club / Carte Blanche	33.6188708512153482	-101.836011215151103
8211	2019-12-31 05:36:41	2019-12-31	Ebb Thompson	ebb.thompson@warmmail.com	Chicago	Illinois	3337440925596006185	46c515e426930905c814c30217c8a98d	JCB 15 digit	41.7861920950304722	-87.6235883728165135
8212	2019-12-31 05:54:33	2019-12-31	Davie Crist	davie.crist@geemail.com	New York	New York	4962560160435086	017da89bae1fd110cf4c47dcdf597a4e	Voyager	40.7363643107227986	-74.0153970876138629
8213	2019-12-31 05:59:00	2019-12-31	Esau Watsica	esau.watsica@woohoo.com	New York	New York	4335750997148701	6ccb14fd7b0095f6490ae6a26aec954b	VISA 16 digit	40.6085774203985892	-73.9480372225295781
8214	2019-12-31 06:02:44	2019-12-31	Eusebio Nitzsche	eusebio.nitzsche@geemail.com	Renton	Washington	630493989488643	f6cca3be84f05cae3da5f794cee99793	Voyager	47.5614471145965183	-122.138921380236738
8215	2019-12-31 06:52:00	2019-12-31	Mrs. Doretha Hahn	mrs.doretha.hahn@geemail.com	New York	New York	4350999698557	8683c49842c6c78655ce2f28390b7fa3	VISA 16 digit	40.6069590486809631	-73.8557413974206867
8216	2019-12-31 06:52:29	2019-12-31	Jensen Schowalter-Wilkinson	jensen.schowalter.wilkinson@geemail.com	Clarksville	Tennessee	3088077324721588707	7973a80e9a8693505573c9412c2ed0ac	VISA 13 digit	36.6598601623099327	-87.3160238666411601
8217	2019-12-31 07:00:08	2019-12-31	Mckayla Carroll	mckayla.carroll@warmmail.com	Virginia Beach	Virginia	3057328661098614	6f43db903155a00c762c962876566b37	Discover	36.7171023328509207	-75.9847917245838715
8218	2019-12-31 07:59:43	2019-12-31	Gilmer Mitchell	gilmer.mitchell@geemail.com	Plano	Texas	503889637030779	3072c973f8908dce054117dc7d3baea9	American Express	33.1245618339713701	-96.6479464955344838
8219	2019-12-31 08:01:16	2019-12-31	Manuela Prohaska	manuela.prohaska@geemail.com	San Francisco	California	180006680911534769	1368de9b1b4f8619dd4467ff22a51766	JCB 16 digit	37.7916412946504394	-122.41594061828259
8220	2019-12-31 08:43:59	2019-12-31	Magdalene Weimann	magdalene.weimann@warmmail.com	Lakewood	New Jersey	639010192087624	87441c5673eaac8e9c93e74e28221ea2	Diners Club / Carte Blanche	40.1594967044707403	-74.1253862030614243
8221	2019-12-31 08:50:28	2019-12-31	Dr. Nathanael Cronin	dr.nathanael.cronin@geemail.com	Austin	Texas	3096398624990943471	4d506283a8f2afba60d7951fed833e4f	Diners Club / Carte Blanche	30.3790305667217808	-97.7868636954348602
8222	2019-12-31 08:59:33	2019-12-31	Titus Ferry-Mueller	titus.ferry.mueller@geemail.com	Berkeley	California	3158884908701294667	9cba73b0ecb957e146d64928fddff4f4	JCB 16 digit	37.8855395634754686	-122.261168482122514
8223	2019-12-31 09:43:02	2019-12-31	Anwar O'Connell	anwar.o'connell@warmmail.com	New York	New York	4546633128675	699e118696b982a08ade96082464cef8	Discover	40.6605593949314184	-73.8607646225381558
8224	2019-12-31 10:05:57	2019-12-31	Basil Braun	basil.braun@woohoo.com	San Francisco	California	3528865001940519301	b4fe6e0c57b71896691c80c1bb6568a2	VISA 16 digit	37.7678555960685074	-122.43151989089057
8225	2019-12-31 10:27:05	2019-12-31	Worley Klein	worley.klein@geemail.com	Albuquerque	New Mexico	3771738118379121	0112e550dda829a7aa268218aafd8f1d	Maestro	35.0225597770553136	-106.588887709712239
8226	2019-12-31 10:28:40	2019-12-31	Whitney Powlowski	whitney.powlowski@geemail.com	Los Angeles	California	3011839341575678	8b51a08ee51246d8a6d875b5694253f6	JCB 16 digit	34.0448814751446207	-118.360524644236264
8227	2019-12-31 10:30:56	2019-12-31	Nash O'Connell-Berge	nash.o'connell.berge@geemail.com	Oakland	California	869950844096945746	219e2182eb09a5de06e02058587b6805	Discover	37.7965713286420026	-122.220713254493333
8228	2019-12-31 10:58:44	2019-12-31	Victory Bogan	victory.bogan@woohoo.com	Anaheim	California	4767015619749	293f128b8e480c2a92918bb37d12df10	Mastercard	33.7830381979998222	-117.802618842685959
8229	2019-12-31 11:05:55	2019-12-31	Tory Cormier	tory.cormier@geemail.com	San Francisco	California	180093869765342395	3401d68c012b7d6ce3b053ce0d6c40f2	JCB 15 digit	37.7683419897144219	-122.451867202015194
8230	2019-12-31 11:39:46	2019-12-31	Mr. Corbett Huel	mr.corbett.huel@geemail.com	New York	New York	3088277585516418981	6c41f7deaaf20a638b3eb85823fc3294	VISA 16 digit	40.6758490144498666	-73.924223044411093
8231	2019-12-31 12:17:19	2019-12-31	Mrs. Johnna Bergnaum	mrs.johnna.bergnaum@geemail.com	Arlington	Texas	869965949231869090	0c323157b178456fb992508d5979cf37	Maestro	32.6657379085913249	-97.1638487278044209
8232	2019-12-31 12:25:49	2019-12-31	Storm Monahan PhD	storm.monahan.phd@geemail.com	San Francisco	California	180094481839412599	4ef147baac5e30edcf176d9e5762316a	JCB 15 digit	37.7985488537997583	-122.447026741375041
8233	2019-12-31 13:22:59	2019-12-31	Angie Hills	angie.hills@geemail.com	Tucson	Arizona	3745298573192058	cfdf9f0d46c47981285af87b2dd79ef3	Diners Club / Carte Blanche	32.0981151778757621	-110.859171451371537
8234	2019-12-31 13:30:01	2019-12-31	Gabriel Homenick	gabriel.homenick@geemail.com	Huntington Beach	California	6011943210081186616	2aea46f8b4c4adb025c05065682c6333	Discover	33.6241924018174458	-117.921073717589678
8235	2019-12-31 13:49:36	2019-12-31	Ms. Lizette Lindgren	ms.lizette.lindgren@geemail.com	Berkeley	California	4830369756100686	5bdb83882737cfce49e6a7e7914be746	American Express	37.8827306704486446	-122.269430466867377
8236	2019-12-31 14:04:27	2019-12-31	Dr. Rolla Ondricka	dr.rolla.ondricka@woohoo.com	Stockton	California	3096756363440696662	2fff3e6f5f36aec3c9c9e4701d172652	JCB 16 digit	37.9293935727059832	-121.225976587048919
8237	2019-12-31 14:10:48	2019-12-31	Reason Ruecker	reason.ruecker@woohoo.com	San Francisco	California	6011614407712404800	fb4b4de0da36d584c54bf4b126ae2847	JCB 15 digit	37.7859566982012112	-122.420534152775801
8238	2019-12-31 14:22:58	2019-12-31	Delmer Kemmer	delmer.kemmer@geemail.com	South Bend	Indiana	3112803732287153206	77e7d811b32c2ab32d35db6290995949	JCB 16 digit	41.6963787522312259	-86.2472883705571292
8239	2019-12-31 14:29:22	2019-12-31	Caleigh Harris	caleigh.harris@geemail.com	Phoenix	Arizona	676208821749721	390383375d3592927931beeddb236ac3	Voyager	33.6551676963388928	-112.165705058856318
8240	2019-12-31 14:55:12	2019-12-31	Ivanna Morar DVM	ivanna.morar.dvm@woohoo.com	San Francisco	California	52078247882744281	93dc817295951a645e05dc73a3044cd8	JCB 16 digit	37.7436649987286899	-122.452666161275616
8241	2019-12-31 15:21:00	2019-12-31	Dr. Ambers Wisozk	dr.ambers.wisozk@geemail.com	Indianapolis	Indiana	4642845893176265	9020b1e29592c22b3e870ec0a17cdd24	Maestro	39.8382082763135443	-86.0507097797669473
8242	2019-12-31 15:26:39	2019-12-31	Buelah Denesik	buelah.denesik@geemail.com	San Jose	California	3096029808338522611	0d80abba03f03ef5a633ef62807c6c1a	Voyager	37.2144598046604571	-121.858546388730034
8243	2019-12-31 15:37:20	2019-12-31	Dr. Mignon Kutch MD	dr.mignon.kutch.md@woohoo.com	Chicago	Illinois	4525624414901424	76e10c6e0336264758ee1b621b842e73	JCB 16 digit	41.7572727505885055	-87.6167085180554466
8245	2019-12-31 16:08:57	2019-12-31	Almina Cummings	almina.cummings@geemail.com	Colorado Springs	Colorado	3046937770095856	38f3001a17f7ab9d45bf43472609a8f2	JCB 15 digit	38.8241430952727811	-104.706435934609544
8246	2019-12-31 16:13:33	2019-12-31	Polly Toy	polly.toy@geemail.com	Santa Ana	California	3528695803923488578	c7bc11ecce394983830058d37a2f6a32	JCB 15 digit	33.7892305998701588	-117.858759901059784
8247	2019-12-31 16:33:57	2019-12-31	Ms. Cassidy Bosco DDS	ms.cassidy.bosco.dds@warmmail.com	Oxnard	California	3158935707570105122	4fe8c2f1fe2307a7336873ae81461136	VISA 16 digit	34.164999323520064	-119.247894560071074
8248	2019-12-31 16:39:05	2019-12-31	Mr. Larry Beatty Jr.	mr.larry.beatty.jr.@geemail.com	Carlsbad	California	3046828717413254	6dc5b95d638a131e2493deba349db6f4	American Express	33.1750062493082112	-117.222741250486294
8249	2019-12-31 17:04:36	2019-12-31	Birdella Yundt	birdella.yundt@woohoo.com	Milwaukee	Wisconsin	869993823924351565	8b2ae6b65029a96041043c933420b60d	VISA 16 digit	43.0518375628247867	-87.8711413182418823
8250	2019-12-31 17:04:39	2019-12-31	Sterling Mohr	sterling.mohr@geemail.com	Plano	Texas	4171548321891	e40ca5eb2fb4e90d6d193a90202c0bbe	Discover	33.1102997502863445	-96.7649615345705314
8251	2019-12-31 17:27:21	2019-12-31	Dr. Kelley Ritchie	dr.kelley.ritchie@geemail.com	Oakland	California	54152585488126729	69def4d3c23d355942d9ea42ad0118f1	Diners Club / Carte Blanche	37.8095003735176647	-122.273182018554749
8252	2019-12-31 18:29:59	2019-12-31	Devonte Conroy	devonte.conroy@geemail.com	San Francisco	California	561291918108894	8f16e6ccd86525eaa24516da40c12b70	VISA 16 digit	37.7784056755463098	-122.413352483840185
8253	2019-12-31 19:25:55	2019-12-31	Olga Klein-Treutel	olga.klein.treutel@geemail.com	New York	New York	210026283294937943	e2f252d8902dfa1742183c2a6835989a	JCB 15 digit	40.6825317953471099	-74.0336414272326948
8254	2019-12-31 19:30:13	2019-12-31	Callie Roob	callie.roob@warmmail.com	McKinney	Texas	4630877059901370	0cef3d55ebcd970daaffbc2b19993aa9	Voyager	33.1973357117865291	-96.7654544111639296
8255	2019-12-31 19:38:37	2019-12-31	Annmarie Mayer	annmarie.mayer@warmmail.com	Salem	Oregon	4419074600318166	b425b76de4ee4f6ffe07517451e3d4b9	JCB 15 digit	44.9904518342845137	-123.003264890626824
8256	2019-12-31 19:42:43	2019-12-31	Charley Greenholt	charley.greenholt@warmmail.com	Fort Worth	Texas	4185579771723517	fbdb0eeb2df6fb46c1a551216d3820e7	Mastercard	32.8514568311683846	-97.3686000854063707
8257	2019-12-31 19:57:29	2019-12-31	Anders Kub	anders.kub@geemail.com	Surprise	Arizona	060453296124984	c6b0bce027536e427ad7f76c8579c88c	Diners Club / Carte Blanche	33.7357879259850861	-112.418905287817864
8258	2019-12-31 20:16:47	2019-12-31	Starling Cremin	starling.cremin@warmmail.com	Houston	Texas	4221122086509	903963e6887fe5e11e928ca5471976ba	Voyager	29.7746794948898241	-95.3746403984274735
8259	2019-12-31 20:20:12	2019-12-31	Deondre Toy	deondre.toy@woohoo.com	San Francisco	California	869914226439579256	0119803ded5bb556da368abcfe46295d	VISA 16 digit	37.754686659363486	-122.429408019411383
8260	2019-12-31 21:35:36	2019-12-31	Mr. Dewey Lind	mr.dewey.lind@geemail.com	San Francisco	California	4524655818143	0c21ca8c710f8ae091ae10d9e392cc94	Diners Club / Carte Blanche	37.7498173532152848	-122.446228892937881
8261	2019-12-31 22:28:39	2019-12-31	Jovanny VonRueden-Tremblay	jovanny.vonrueden.tremblay@woohoo.com	San Francisco	California	676216388389054	cee427f20b3235ca105e1f9ab959105a	JCB 16 digit	37.7594743059800493	-122.441473021889792
8262	2019-12-31 22:52:22	2019-12-31	Mr. Dameon West PhD	mr.dameon.west.phd@woohoo.com	Roseville	California	53256184665016732	10d7483eaf4f3eaf2285e4cd553dcf0b	Maestro	38.6884581200834319	-121.306062009673198
8263	2019-12-31 22:55:28	2019-12-31	Jerod Schmidt	jerod.schmidt@geemail.com	Baltimore	Maryland	3791660848514205	4163aa80ec4a0f18bb7eb7644431b59a	VISA 16 digit	39.370802937541157	-76.6670858994145021
8264	2019-12-31 23:15:35	2019-12-31	Janiya Kuhn-Larson	janiya.kuhn.larson@geemail.com	Jersey City	New Jersey	3467234686308839	a99c6ea4d035e01bd4304092bda16f5f	Discover	40.7233905445259055	-74.0026736523445692
8265	2019-12-31 23:16:15	2019-12-31	Cael Cummings	cael.cummings@geemail.com	Berkeley	California	4968598547954415	2dab011e9b79e8cf652aeb77285af568	JCB 16 digit	37.9010506169665078	-122.286724318050389
8266	2019-12-31 23:35:52	2019-12-31	Kathryne Ondricka	kathryne.ondricka@geemail.com	Jersey City	New Jersey	180087481163496738	9d7fba82fa0dd0c88f5f7470ece8e5cd	Mastercard	40.6638688167963167	-74.0610672625668371
8267	2019-12-31 23:39:36	2019-12-31	Alize Moen	alize.moen@geemail.com	Sacramento	California	52922474982267280	73906103db096ebb04c78b4c7f48cbe0	VISA 16 digit	38.6091879742018875	-121.460881340016044
8268	2020-01-01 00:07:42	2020-01-01	Neola Hane PhD	neola.hane.phd@geemail.com	Lafayette	Louisiana	3337963634177939361	3c28bd4a9544992474adf40ddac60b8c	Diners Club / Carte Blanche	30.1346864784579722	-91.9883683639429393
8269	2020-01-01 00:18:51	2020-01-01	Herb Runte-Walsh	herb.runte.walsh@geemail.com	Hampton	Virginia	869969674897198321	79bd6c21b577d71b53151f88f9a08c6a	Discover	36.9500609911996918	-76.362270751977718
8270	2020-01-01 00:44:46	2020-01-01	Marylee Kovacek	marylee.kovacek@geemail.com	Clarksville	Tennessee	3088476385691372502	82635999dc572660c973a5d17a2ddecf	Mastercard	36.6344015324614958	-87.3756297448601629
8271	2020-01-01 01:00:19	2020-01-01	Charline McClure	charline.mcclure@geemail.com	San Francisco	California	4732777009650118	06c3e7c856380eda172181e2a1c05450	VISA 16 digit	37.7598390454802768	-122.450922558012948
8272	2020-01-01 01:36:01	2020-01-01	Merry Willms	merry.willms@geemail.com	Los Angeles	California	6011465339810188805	250bc5983c11aa4e1f83ec65fc8fab0f	VISA 16 digit	34.0308889814052691	-118.391175719256694
8273	2020-01-01 01:38:44	2020-01-01	Haven Wilkinson	haven.wilkinson@geemail.com	Boston	Massachusetts	4969056333813492	6b7105640f648ae3778150d462ece048	Diners Club / Carte Blanche	42.3794590486381182	-71.1164904276326268
8274	2020-01-01 01:50:30	2020-01-01	Dr. Alma Wilkinson DDS	dr.alma.wilkinson.dds@geemail.com	Las Vegas	Nevada	4182169495886726	b1ff6c800e3b2fe22ac2980aed62cb26	VISA 13 digit	36.2684246494069669	-115.201414764926199
8275	2020-01-01 02:12:28	2020-01-01	Emmett Lesch-Gorczany	emmett.lesch.gorczany@geemail.com	Dallas	Texas	52178643613758690	f09329df46b3f6a866690ea69f90e3cf	VISA 16 digit	32.8665995640952175	-96.819962207876145
8276	2020-01-01 02:12:33	2020-01-01	Efrem Kulas	efrem.kulas@geemail.com	Lexington	Kentucky	3528557490468038336	5f7fded400ac9565b4b3faeb39cf4d27	JCB 16 digit	38.1153490537188944	-84.3903406429003837
8277	2020-01-01 02:23:08	2020-01-01	Roselyn Volkman	roselyn.volkman@geemail.com	Vacaville	California	180015797977150584	1b9897d2f5a597b65e2458fd449c6e73	American Express	38.3585975008212046	-121.928464899153639
8278	2020-01-01 02:38:32	2020-01-01	Millicent Hilpert	millicent.hilpert@geemail.com	Charlotte	North Carolina	4919490992705031	e3a3f0ed48aabb8bddd4d2086a5e801d	JCB 16 digit	35.1513848956927646	-80.895282171288514
8279	2020-01-01 03:42:29	2020-01-01	Earlie Goodwin	earlie.goodwin@warmmail.com	Port St. Lucie	Florida	4165356858745828	2ad2164b3c4fcbf382bf57ac28dba30c	VISA 16 digit	27.3572541898716253	-80.464128981259833
8280	2020-01-01 03:51:56	2020-01-01	Mr. Michial Gerlach	mr.michial.gerlach@geemail.com	San Francisco	California	53235858005322936	dc2af03b52001e47ec1567ef91126fac	VISA 13 digit	37.7425416958841424	-122.4288058033884
8281	2020-01-01 04:35:33	2020-01-01	Shawn Heaney	shawn.heaney@woohoo.com	Minneapolis	Minnesota	4076828198675673	4b76bfb740727188ae18ccc41fb1073a	VISA 13 digit	45.0070499326188056	-93.2960743151877097
8282	2020-01-01 04:36:41	2020-01-01	Delwin Jakubowski	delwin.jakubowski@geemail.com	San Francisco	California	6011702584945717613	c939eb5232c0dc5e53b91f9df5dd9645	VISA 13 digit	37.7872739366708714	-122.453452173728579
8283	2020-01-01 04:43:30	2020-01-01	Rey Blanda	rey.blanda@geemail.com	Berkeley	California	3528311259999994870	03487779813f991032d6953fcbcc1531	Voyager	37.8485156393096887	-122.262716117973852
8284	2020-01-01 05:02:28	2020-01-01	Miss Chanel Olson DDS	miss.chanel.olson.dds@warmmail.com	San Francisco	California	180061599752839750	77d24a39d08fa2772157546314276f1a	American Express	37.8018312559897822	-122.459981890158488
8285	2020-01-01 05:42:08	2020-01-01	Dr. Hildur McKenzie DDS	dr.hildur.mckenzie.dds@geemail.com	San Francisco	California	869976907676027829	253cd8d23e32b1644b3af6d14141c409	VISA 13 digit	37.7746415355657774	-122.425786876363304
8286	2020-01-01 05:45:26	2020-01-01	Hughes Fay	hughes.fay@geemail.com	San Francisco	California	6011400982043121263	212b83895fdea22843afc4aa03af7bbf	Voyager	37.7515488115049109	-122.436838675930019
8287	2020-01-01 05:50:47	2020-01-01	Ms. Sophia Marks	ms.sophia.marks@warmmail.com	San Antonio	Texas	52074332480017605	103df6fd3357438c4d75c5ad1cd870e9	Mastercard	29.3983847757872212	-98.6113894725985745
8288	2020-01-01 05:52:24	2020-01-01	Shon Collier Sr.	shon.collier.sr.@geemail.com	Modesto	California	4309901691571	2746e5463d14412184012fa713809136	VISA 16 digit	37.598304211674261	-121.082191446397459
8289	2020-01-01 06:10:29	2020-01-01	Dr. Deven Sporer	dr.deven.sporer@geemail.com	Jackson	Mississippi	3038956517730318	2c9569628e2faf51b602f5e66e9ee684	JCB 15 digit	32.2948263889823153	-90.2302230325501426
8290	2020-01-01 06:17:33	2020-01-01	Travis Keebler	travis.keebler@woohoo.com	Louisville	Kentucky	4367113927993	78e03b24409ab3b725ede39b192f9a57	VISA 16 digit	38.192334228371827	-85.6992279526848364
8291	2020-01-01 06:19:06	2020-01-01	Cale Rice-Mante	cale.rice.mante@geemail.com	New York	New York	4574262542594	e935dcebc80ddded5d4916216f105332	JCB 16 digit	40.6893180357515831	-74.0155355771899224
8292	2020-01-01 06:42:36	2020-01-01	Mr. Iverson McLaughlin	mr.iverson.mclaughlin@geemail.com	Richmond	Virginia	3056661610319108	8019db40c1dd00971909caf67894d24a	VISA 16 digit	37.558288997061176	-77.4910842786300975
8293	2020-01-01 06:54:46	2020-01-01	Maud Runolfsson-Spinka	maud.runolfsson.spinka@geemail.com	New York	New York	3750279214285453	a3d864e52ce5bda8c597a42bd612dab3	VISA 16 digit	40.5765178937222828	-73.8659553731221621
8294	2020-01-01 07:21:39	2020-01-01	Dr. Serenity Green DVM	dr.serenity.green.dvm@woohoo.com	Las Vegas	Nevada	869969615066488563	d070b07b584ce847d9aeab45320eaf88	VISA 16 digit	36.2032809460636216	-115.346676567916191
8295	2020-01-01 07:28:36	2020-01-01	Golden Dietrich	golden.dietrich@woohoo.com	Charlotte	North Carolina	6011607902703704001	3e637694f0988f00e1a331b930fa8983	Diners Club / Carte Blanche	35.1834927149370316	-80.7322979044113396
8296	2020-01-01 07:55:44	2020-01-01	Wright Hirthe	wright.hirthe@geemail.com	Columbus	Ohio	3158833061243249187	60700460cc7061dd9893371d7387ac7e	Diners Club / Carte Blanche	39.9761817003179303	-82.9523172830931941
8297	2020-01-01 07:55:58	2020-01-01	Ira Haley	ira.haley@geemail.com	San Francisco	California	4114616992514246	856cdffa8a56e43dd0c27ba6133355c9	Maestro	37.7699557648508417	-122.450563519837544
8298	2020-01-01 08:53:58	2020-01-01	Helaine Monahan-Osinski	helaine.monahan.osinski@geemail.com	San Francisco	California	180025310550487379	eacf87446d6c4281efa4c17269f42db2	Diners Club / Carte Blanche	37.7879680745990214	-122.42736100561045
8299	2020-01-01 09:04:54	2020-01-01	Mr. Camren Volkman I	mr.camren.volkman.i@geemail.com	Irvine	California	869973911811960046	c77412a6ed9b04cccc984d46675e3d7c	Maestro	33.5895857369542128	-117.844335308532408
8300	2020-01-01 09:08:22	2020-01-01	Clementina Koelpin DVM	clementina.koelpin.dvm@woohoo.com	San Francisco	California	3158463698197696512	4fc647a1a18b8f3514b80fe91b3881e2	American Express	37.7277588951274439	-122.457837826946857
8301	2020-01-01 11:29:42	2020-01-01	Kindra Lang-Crona	kindra.lang.crona@geemail.com	Aurora	Colorado	4886821279869737	90f43ade2b6517617752e1c664d563cf	JCB 15 digit	39.6414288144670479	-104.620973719156169
8302	2020-01-01 11:42:27	2020-01-01	Ms. Sarita Nader	ms.sarita.nader@geemail.com	Newark	New Jersey	4400779813119638	8c82020618a83ba4d94f7748db41a35f	Discover	40.6463605172380866	-74.1298488010395289
8303	2020-01-01 11:44:34	2020-01-01	Jaylen Pagac II	jaylen.pagac.ii@geemail.com	Berkeley	California	3049005671249175	4e79f43ca92d2a82a28eea49713cc584	Mastercard	37.8807244429177814	-122.281639166019389
8304	2020-01-01 13:58:12	2020-01-01	Mrs. Emerson Bogan DDS	mrs.emerson.bogan.dds@woohoo.com	Tucson	Arizona	3753525356709735	86809e151b4ef8c2c48542fd1a2aea6b	Diners Club / Carte Blanche	32.0772443023551261	-110.911967304185396
8305	2020-01-01 14:28:04	2020-01-01	Ms. Quinn Bode DDS	ms.quinn.bode.dds@geemail.com	Rochester	New York	54351808907637178	083d19ecbf9b99b91a1c2a3a45d6ed7e	Diners Club / Carte Blanche	43.2576783092670141	-77.564606813085831
8306	2020-01-01 15:02:18	2020-01-01	Adda Johnson	adda.johnson@geemail.com	Bakersfield	California	3763124554993552	ebbf289e6a7d13cf8f3eabefe29999a1	Discover	35.415453747817125	-118.929867684821787
8307	2020-01-01 15:13:10	2020-01-01	Justina Casper	justina.casper@geemail.com	Wichita	Kansas	3528832164834373613	b0aa3a6c2873175b7d79c395647e8991	VISA 16 digit	37.6591554145205762	-97.2548796668849889
8308	2020-01-01 15:33:25	2020-01-01	Jeanie Waelchi	jeanie.waelchi@geemail.com	Tulsa	Oklahoma	589323305805915	732d5026025ebb9ec84b6e36fe3f6550	JCB 16 digit	36.1661772803306576	-95.9191576948810365
8309	2020-01-01 15:34:01	2020-01-01	Nena Quitzon	nena.quitzon@geemail.com	North Las Vegas	Nevada	4994887588782	b92b8191900c7f76e77bc2aaa28cd7a6	Discover	36.2729236002702251	-115.157235523707797
8310	2020-01-01 15:46:21	2020-01-01	Marlo Hahn	marlo.hahn@geemail.com	Oakland	California	630446632058833	565205cd3ed2afc9cc88c307d38e52c6	VISA 16 digit	37.8129524577333811	-122.281349464831422
8311	2020-01-01 15:46:30	2020-01-01	Kai Schaden	kai.schaden@woohoo.com	Denton	Texas	3088680339890788572	ac77cbd7929d4a838258f96da3715cf3	JCB 16 digit	33.2841627255812256	-97.100778042072065
8312	2020-01-01 16:01:33	2020-01-01	Tristan Kuhn	tristan.kuhn@geemail.com	Oakland	California	869958573302904856	3050fa4a8cec59068596bf75cccf2fe0	VISA 16 digit	37.822721546692776	-122.283526248844822
8313	2020-01-01 16:08:55	2020-01-01	Sharonda Rogahn	sharonda.rogahn@geemail.com	Springfield	Illinois	869974924344918166	58c5610844b339cfef3d3472cb6a0c28	Mastercard	39.8229903448991465	-89.6370247484188525
8314	2020-01-01 16:10:20	2020-01-01	Mal Huel	mal.huel@warmmail.com	New York	New York	3158928337035503908	5e88983ba7cdfdee7bd23f316d51a9f0	American Express	40.5840634834244867	-73.9665606686741057
8315	2020-01-01 16:15:33	2020-01-01	Zoa Dach	zoa.dach@geemail.com	Charlotte	North Carolina	6011040951753057336	df1c5a440fd93a9aa7439734806bc574	VISA 13 digit	35.2951406316619369	-80.9169363577328653
8316	2020-01-01 16:35:08	2020-01-01	Vela Vandervort	vela.vandervort@warmmail.com	Memphis	Tennessee	4955125956952600	78c647af06886db7d78a355bbc883c65	Discover	35.1976046685196451	-89.9630139794923451
8317	2020-01-01 16:40:29	2020-01-01	Jabbar Kuhic	jabbar.kuhic@geemail.com	Columbia	Missouri	3088739795386568268	43590f8966c6033ebb35f6bfe1c4f5fc	American Express	38.9404111374982307	-92.2676141356636919
8318	2020-01-01 16:42:24	2020-01-01	Jorge Homenick	jorge.homenick@geemail.com	Oakland	California	3158363736489439208	3259499b999f5fc4cd356d716e504e42	JCB 16 digit	37.8151156811862066	-122.293387409364101
8319	2020-01-01 17:48:29	2020-01-01	Sedrick Auer	sedrick.auer@geemail.com	Buffalo	New York	6011946542373882784	86f0efd5b80f4818ef4dfcad98ba72fa	Voyager	42.8335784449893993	-78.7752550449620941
8320	2020-01-01 17:51:32	2020-01-01	Marcos Fay	marcos.fay@geemail.com	Indianapolis	Indiana	3432415218807792	09168c326bbea4293463cae8c05e0229	Diners Club / Carte Blanche	39.6981424454607037	-86.1385377641968404
8321	2020-01-01 18:24:51	2020-01-01	Dr. Oren Waelchi	dr.oren.waelchi@warmmail.com	Norfolk	Virginia	3030583939752700	5875a3e1d53603a144e708bb3a8ecb5d	Mastercard	37.0106335801091078	-76.2905241540636894
8322	2020-01-01 18:43:12	2020-01-01	Algie Abernathy	algie.abernathy@woohoo.com	Oakland	California	3024563630115627	56a508b857818bb7b64712f7aef20d3b	JCB 16 digit	37.8235151058804817	-122.26318602013923
8323	2020-01-01 19:06:55	2020-01-01	Jamil Hessel	jamil.hessel@geemail.com	San Francisco	California	3708039672741295	219ea936d432edd2d59c05a32cb1499b	JCB 15 digit	37.76658734969498	-122.408648668702028
8324	2020-01-01 19:15:59	2020-01-01	Dagny Rath	dagny.rath@woohoo.com	South Bend	Indiana	6011522300746634073	01eed1d57a5e7aa63fb3629db86c5cc8	Voyager	41.5985148951556596	-86.183509590994575
8325	2020-01-01 19:33:18	2020-01-01	Sharon Welch	sharon.welch@woohoo.com	Chandler	Arizona	869928027988130655	cb433552f1c4b844b48726a6c2057d22	VISA 16 digit	33.1862263980411001	-111.817369995114959
8326	2020-01-01 20:07:17	2020-01-01	Drury Feest	drury.feest@woohoo.com	San Francisco	California	4619148341107	4daea8a4a213ebda62ba730042f17585	JCB 16 digit	37.7577611376825004	-122.452784724007941
8327	2020-01-01 20:07:38	2020-01-01	Shakira Parker	shakira.parker@geemail.com	Worcester	Massachusetts	4003256163571	d3aadfe270903c0683f0a6ba39a39936	JCB 15 digit	42.3545894614588505	-71.7395350638098961
8328	2020-01-01 20:16:00	2020-01-01	Friend Runte	friend.runte@geemail.com	Frisco	Texas	53033105209864535	bdd665eb964693740ebddee3a116cc62	Mastercard	33.1623392743986116	-96.9225057467561157
8329	2020-01-01 20:16:15	2020-01-01	Ebenezer Stroman	ebenezer.stroman@geemail.com	Independence	Missouri	3007786914531949	2492e29fe56d94e6491079e95b7a2fbd	Mastercard	39.068739915082233	-94.3404380507118958
8330	2020-01-01 21:09:41	2020-01-01	Patric Maggio MD	patric.maggio.md@geemail.com	Cincinnati	Ohio	4854969309427287	b009b4bf28761d700f003c34df6c50e6	JCB 15 digit	39.2043683157999041	-84.4593039364360152
8331	2020-01-01 21:26:30	2020-01-01	Mr. Orion Fadel III	mr.orion.fadel.iii@geemail.com	New York	New York	180086146449885191	9f4c2436154517c3876f8688e9532019	JCB 15 digit	40.6084908724985993	-73.8855843223526989
8332	2020-01-01 21:31:13	2020-01-01	Cathryn Torp	cathryn.torp@geemail.com	Glendale	Arizona	869919003862025189	419b49f822764c041fee55b087e26573	VISA 16 digit	33.5858603284455839	-112.11890529303588
8333	2020-01-01 21:33:24	2020-01-01	Kaycee Cole	kaycee.cole@geemail.com	Chicago	Illinois	3040021399820394	fdfb752ab9505988e77d8f4d4d99ae97	Discover	41.9071527088828404	-87.7735577039450305
8334	2020-01-01 21:57:29	2020-01-01	Renata Altenwerth	renata.altenwerth@warmmail.com	Phoenix	Arizona	561258701774984	5734736d2ed0af7ad87fb40d25d55fd2	JCB 16 digit	33.6523808025687927	-112.040792903669555
8335	2020-01-01 22:10:12	2020-01-01	Jayden Bergstrom	jayden.bergstrom@geemail.com	San Francisco	California	4319745771540941	5c24de378e06ad4c2bc7d6f313b6df64	American Express	37.7681347211898313	-122.449745271702426
8336	2020-01-01 22:22:35	2020-01-01	Jasen Bernhard	jasen.bernhard@geemail.com	Phoenix	Arizona	3158097610434073367	5bacfa1182bde68bb92006c388879a78	VISA 16 digit	33.6167312912575937	-112.044301338952408
8337	2020-01-01 22:38:41	2020-01-01	Addisyn Conroy	addisyn.conroy@woohoo.com	Tampa	Florida	3528212362680024302	42f7eb743b60d051ecdcaf86b24f8489	JCB 15 digit	28.064071671210602	-82.4615364826030941
8338	2020-01-01 22:40:09	2020-01-01	Zeno Grant	zeno.grant@woohoo.com	San Francisco	California	4187877997996869	f27c84b110e2307137470593b7cdab7a	Mastercard	37.7686285531177433	-122.430538835673516
8339	2020-01-01 22:49:29	2020-01-01	Miss Leona Bogan PhD	miss.leona.bogan.phd@geemail.com	Virginia Beach	Virginia	3088613901125403483	e76e9b806c06595cb66f29e93bdd5cb8	Diners Club / Carte Blanche	36.7074089628830578	-76.0516120803680309
8340	2020-01-01 23:12:56	2020-01-01	Katerina Runolfsdottir-Abbott	katerina.runolfsdottir.abbott@geemail.com	Grand Prairie	Texas	4726488142831387	2fd1351f89e77fb7a70e2aa1b6e6db09	Diners Club / Carte Blanche	32.7553751571156084	-97.0095764099493607
8341	2020-01-01 23:41:47	2020-01-01	Minda Sanford	minda.sanford@geemail.com	Oakland	California	4554053305073487	67170ff500a2204fa0b3a85f0b62c130	Mastercard	37.8172410783992134	-122.251767566781666
8342	2020-01-02 00:11:17	2020-01-02	Tanika McKenzie	tanika.mckenzie@geemail.com	Houston	Texas	210067385355435350	a0cc6c67954ac5e07e519f0ebb2f837c	Diners Club / Carte Blanche	29.8446505459103726	-95.4662220011945806
8343	2020-01-02 00:13:28	2020-01-02	Mrs. Regena Keebler DVM	mrs.regena.keebler.dvm@geemail.com	Indianapolis	Indiana	630477899268567	de028c97f2f03723167611c696fa467e	Mastercard	39.8004439515534756	-86.2380982369851239
8344	2020-01-02 00:47:53	2020-01-02	Selina Wisozk	selina.wisozk@geemail.com	Glendale	California	3027169611978004	d017c766b4d2505c8e54d408c602c300	Diners Club / Carte Blanche	34.1257695526104357	-118.193495038234815
8345	2020-01-02 01:00:44	2020-01-02	Iliana Grimes	iliana.grimes@geemail.com	San Jose	California	3054944867407012	3f6324c3b1ac0308c706e59904e4355e	JCB 16 digit	37.3160034172989441	-121.782884572142365
8346	2020-01-02 01:02:58	2020-01-02	Winifred Larson	winifred.larson@warmmail.com	Milwaukee	Wisconsin	4185873169476212	ff2f9c45c31eadd3cf03d94886c8af3b	Maestro	43.1120829200457791	-87.9713388289891185
8347	2020-01-02 01:11:53	2020-01-02	Governor Kris	governor.kris@geemail.com	San Francisco	California	4765629334002	e1b0c441466cd4450f28640abe3c7415	JCB 16 digit	37.7622730647378404	-122.405317673206454
8348	2020-01-02 01:45:28	2020-01-02	Kory Schulist	kory.schulist@geemail.com	Arlington	Texas	4884463860423822	a8caa8251dc2acde99712617a5af9d67	JCB 16 digit	32.751762690047542	-97.0992150605216722
8349	2020-01-02 02:28:27	2020-01-02	Emit Larson	emit.larson@woohoo.com	Phoenix	Arizona	6011245653998821822	2af94187863fc2c3c4bb2ceeb5d7522f	VISA 16 digit	33.5909949591781967	-112.019696407152722
8350	2020-01-02 02:57:30	2020-01-02	Seamus Bednar	seamus.bednar@woohoo.com	San Francisco	California	6011221077184575745	3198615a198270c7e17967aa19a1864d	Mastercard	37.7726698716807547	-122.442425332463216
8351	2020-01-02 02:59:47	2020-01-02	Macie Williamson-Volkman	macie.williamson.volkman@geemail.com	San Francisco	California	55850496456739664	007c2083e2d2e621676e1b0497063953	VISA 16 digit	37.7901662755019885	-122.399039631320605
8352	2020-01-02 03:17:58	2020-01-02	Mr. Gilberto Gulgowski	mr.gilberto.gulgowski@geemail.com	North Las Vegas	Nevada	4561215430951	79d7740968d663e8272b93e45fac8d44	JCB 16 digit	36.3142247497260584	-115.033884697801994
8353	2020-01-02 03:48:25	2020-01-02	Boyd Reinger	boyd.reinger@woohoo.com	Boston	Massachusetts	869923452089615161	74ac23167f5b5ea7820f16fe451d2a8e	Diners Club / Carte Blanche	42.2583419197872274	-70.9342578576363678
8354	2020-01-02 04:46:55	2020-01-02	Sable Rempel	sable.rempel@geemail.com	San Francisco	California	3337425755186753170	519df2ed3cea277878ddf6b4fb9c62f1	JCB 16 digit	37.7630174280037636	-122.45478478424036
8355	2020-01-02 04:59:03	2020-01-02	Dr. Chrystal Schuppe PhD	dr.chrystal.schuppe.phd@geemail.com	San Francisco	California	3785050254434684	67f51d9385c6303cc0e033941fe27ca8	Maestro	37.7360709370199103	-122.41669484726367
8356	2020-01-02 05:47:17	2020-01-02	Rutha Russel	rutha.russel@geemail.com	Corpus Christi	Texas	6011351146052632417	d8769ae708c6e721f88186411cf304cc	VISA 13 digit	27.8140629282157867	-97.1616098131813146
8357	2020-01-02 06:11:50	2020-01-02	Dr. Linton O'Keefe Jr.	dr.linton.o'keefe.jr.@geemail.com	Houston	Texas	4679104079878922	bbb57680ae3501053dd6aaa408f1dcc0	VISA 13 digit	29.7502840921360985	-95.3631617872059394
8358	2020-01-02 06:30:11	2020-01-02	Ferdinand Kshlerin	ferdinand.kshlerin@warmmail.com	San Francisco	California	3427710992298151	8e3948ccb10279f9531bfa918a3d01e0	Mastercard	37.782733049468078	-122.402504493102541
8359	2020-01-02 06:36:00	2020-01-02	Mr. Offie Waelchi	mr.offie.waelchi@warmmail.com	Ontario	California	210055353786441243	8a425a382454e663cfb18bce3451eb42	JCB 16 digit	34.1313505654368541	-117.693563081334162
8360	2020-01-02 06:38:30	2020-01-02	Darrell Aufderhar I	darrell.aufderhar.i@geemail.com	Westminster	Colorado	3059556547454779	a238add8d4ee45f8c52d74f67a26bf02	VISA 16 digit	39.9565178205564564	-104.9869765414536
8361	2020-01-02 06:48:51	2020-01-02	Aisha Heathcote	aisha.heathcote@geemail.com	Lewisville	Texas	3789491489327663	4bdfa7c03ca93d72fe11f383a891d905	Diners Club / Carte Blanche	32.9692586136035573	-96.9610476115748412
8362	2020-01-02 06:57:38	2020-01-02	Shyheim O'Conner	shyheim.o'conner@geemail.com	Columbus	Ohio	180070525581757623	9bd8d93cafe92acb74cbc43a295b75ea	Voyager	39.9079455698419352	-83.0782350847266713
8363	2020-01-02 07:10:24	2020-01-02	Mr. Gorge Hansen	mr.gorge.hansen@woohoo.com	Oakland	California	869946491279780065	e8f6ea54a0ec3ed49175da05b4151bad	Discover	37.8021506319680611	-122.264300650747174
8364	2020-01-02 07:27:27	2020-01-02	Kati Wisozk-Bogisich	kati.wisozk.bogisich@geemail.com	Cleveland	Ohio	3411283935939594	be49df83e1a008949e141202d7b0a073	Maestro	41.4909525821767744	-81.768603843334688
8365	2020-01-02 07:34:27	2020-01-02	Diane Jacobs	diane.jacobs@geemail.com	Moreno Valley	California	6011688801125399667	7333b00765353d4c3472a7f6ee092ebc	JCB 15 digit	33.8401283782899327	-117.202845268088197
8366	2020-01-02 07:38:43	2020-01-02	Nan Stanton DVM	nan.stanton.dvm@warmmail.com	Hialeah	Florida	4698694282139	4940959c0f41e6eb0e80bceb9bdc2608	VISA 16 digit	25.9603965115711119	-80.2274964412577418
8367	2020-01-02 08:11:55	2020-01-02	Yurem Bailey	yurem.bailey@geemail.com	Reno	Nevada	3051672059825013	95b479b764ee671394471fe48caab6f7	VISA 16 digit	39.4828933266535458	-119.756035303713389
8368	2020-01-02 08:25:54	2020-01-02	Tyree O'Hara	tyree.o'hara@geemail.com	Springfield	Illinois	869928539839885873	8ee33c7d216db4eaf3259fb82df40b15	VISA 16 digit	39.8272833666451263	-89.555095659150183
8369	2020-01-02 08:54:31	2020-01-02	Eino Feest	eino.feest@geemail.com	Austin	Texas	630467612702661	60c86d190a9626de7b0f1f712006419b	Voyager	30.3047380852174015	-97.7802099511731484
8370	2020-01-02 09:00:26	2020-01-02	Cheryll Runolfsson	cheryll.runolfsson@geemail.com	Portland	Oregon	3337934978276343363	6aaf1563f309e745cf4bd068ad746666	JCB 16 digit	45.4836386863030455	-122.6061641605571
8371	2020-01-02 09:57:36	2020-01-02	Ermine Bednar DVM	ermine.bednar.dvm@geemail.com	San Francisco	California	869975136666837903	06bf7e811d472912b734548f9b3b4286	American Express	37.7750469001710982	-122.431472967547919
8372	2020-01-02 10:06:28	2020-01-02	Gavyn Greenholt	gavyn.greenholt@warmmail.com	Berkeley	California	3446140241143056	dce06ddf34ed2d6b8388a1d84a52587e	Mastercard	37.8985289015655624	-122.262917165233162
8373	2020-01-02 10:25:00	2020-01-02	Arvil Baumbach	arvil.baumbach@geemail.com	Seattle	Washington	676295278050380	87fe81443d79f23a7252e97be4a8d88a	VISA 16 digit	47.6204678088352082	-122.32417401833608
8374	2020-01-02 10:29:09	2020-01-02	Ethyl Jerde	ethyl.jerde@geemail.com	San Francisco	California	4562044600875536	d217c8333c0813ce6f1508455a54996b	JCB 16 digit	37.7593937759057425	-122.425065783947304
8375	2020-01-02 10:55:18	2020-01-02	Fronie Champlin-O'Reilly	fronie.champlin.o'reilly@geemail.com	San Francisco	California	4804642969278	a9dc09b44809453ada4f01ea85d486b9	Voyager	37.8034625741786314	-122.415901437933272
8376	2020-01-02 10:57:07	2020-01-02	Delano Kuhlman	delano.kuhlman@geemail.com	Santa Rosa	California	3158023234241621836	8360e1317356ef1bdfe58c9678784a8f	Maestro	38.4523505330208692	-122.673488344323275
8377	2020-01-02 11:04:38	2020-01-02	Hoover Stark-Legros	hoover.stark.legros@geemail.com	El Monte	California	210004021174136145	19289826b05a6508e0a1861a2a7aa9c9	American Express	34.1484336432259497	-117.988322751297062
8378	2020-01-02 11:08:29	2020-01-02	Wesley Walker-Bergstrom	wesley.walker.bergstrom@geemail.com	Anaheim	California	676116037636731	7cb558878563af4b290c85322b25228d	JCB 16 digit	33.7760078287050121	-117.843114747500408
8379	2020-01-02 12:41:45	2020-01-02	Bridget Padberg PhD	bridget.padberg.phd@geemail.com	Montgomery	Alabama	4308147901669885	c0283127ec6657941db6991104dd00fe	VISA 13 digit	32.2600424804657706	-86.2637882611867042
8380	2020-01-02 12:49:13	2020-01-02	Spencer McLaughlin DVM	spencer.mclaughlin.dvm@geemail.com	Chicago	Illinois	3705626968241593	3fcc289d58b2df7ca975306781b987e1	Mastercard	41.845153398143502	-87.6230315304856759
8381	2020-01-02 14:09:30	2020-01-02	Aiyana Ryan	aiyana.ryan@geemail.com	Dallas	Texas	869923699191551300	60d4aba6e24694533a37202d48574e2a	VISA 16 digit	32.8779344400197289	-96.7117399577479802
8382	2020-01-02 14:48:30	2020-01-02	Dr. Rosamond Upton MD	dr.rosamond.upton.md@warmmail.com	New York	New York	3035665620046602	111b019f0b36a7a140359b04efdd9906	JCB 15 digit	40.7529975693430728	-74.0249088889349167
8383	2020-01-02 14:53:21	2020-01-02	Dr. Kloe Jakubowski	dr.kloe.jakubowski@geemail.com	San Francisco	California	4306309885514287	bd14bcdc05c43c1c7e730e36dbf7cd26	Diners Club / Carte Blanche	37.7930727717197001	-122.429524568298177
8384	2020-01-02 15:13:54	2020-01-02	Dr. Lakendra Stark PhD	dr.lakendra.stark.phd@geemail.com	San Francisco	California	4678620621910393	508d0ddc7f8c97b6cd0b5f0510d01b00	Maestro	37.7718403577729944	-122.451521209173535
8385	2020-01-02 15:32:03	2020-01-02	Treasure Wuckert	treasure.wuckert@geemail.com	San Antonio	Texas	869956862308332812	2df51ab53941c984f496b80b437062ef	American Express	29.5614891443472345	-98.574318996474517
8386	2020-01-02 15:36:03	2020-01-02	Miss Siobhan Wolf DVM	miss.siobhan.wolf.dvm@geemail.com	Los Angeles	California	4454344517765122	d6c26771cc20e400df91fe7bf217947b	JCB 16 digit	34.0451786467205721	-118.357661774055288
8387	2020-01-02 15:36:32	2020-01-02	Dr. Evelynn Jacobson	dr.evelynn.jacobson@geemail.com	Berkeley	California	3088953302359023196	b47c2cccc68d6ab2e55caaaf8e4cb69e	JCB 16 digit	37.8889786969492945	-122.269227325171713
8388	2020-01-02 15:41:06	2020-01-02	Keenan Kuhlman	keenan.kuhlman@geemail.com	San Francisco	California	3052636919633411	f72c78ee0c6e8d732afcf4ed3c83cc1b	Mastercard	37.769807903291408	-122.436471705457109
8389	2020-01-02 15:42:27	2020-01-02	Joy Franecki-Ondricka	joy.franecki.ondricka@geemail.com	Boston	Massachusetts	6011111649062786512	c9e50d0a2820c38bbbf52c50a93b2ab7	Voyager	42.2834191319234662	-70.9268952838096851
8390	2020-01-02 15:52:32	2020-01-02	Korey Johnson	korey.johnson@woohoo.com	Edison	New Jersey	6011745592884014099	64f8ef07a54cb2c23921b31fab479c00	VISA 16 digit	40.4826766467150279	-74.2584718213468875
8391	2020-01-02 17:14:34	2020-01-02	Dr. Hugh Haag	dr.hugh.haag@geemail.com	Omaha	Nebraska	4338711900248654	d957e63fce59fb8c41c9501afcc6ff40	JCB 16 digit	41.2901942628115464	-96.14326980813631
8392	2020-01-02 17:15:25	2020-01-02	Tyesha Cormier-Reichel	tyesha.cormier.reichel@geemail.com	San Francisco	California	53094458272877751	3818a55f39be4fa0d56a941a984024f6	VISA 13 digit	37.7752717729441656	-122.441891808219907
8393	2020-01-02 18:11:01	2020-01-02	Winnie Gusikowski III	winnie.gusikowski.iii@woohoo.com	Rancho Cucamonga	California	676276583159751	c2ee00f01113fe211f4ecc85796612d9	VISA 13 digit	34.16507552713081	-117.511862095632409
8394	2020-01-02 18:15:00	2020-01-02	Nilda Braun	nilda.braun@geemail.com	Oakland	California	210039731955400127	daa78ab06d89a206ac511df859c0557f	JCB 16 digit	37.8093181124109208	-122.269865294875913
8395	2020-01-02 18:20:53	2020-01-02	Maebell Bednar	maebell.bednar@warmmail.com	San Francisco	California	54554655730773042	1c1281a7841b3940b16b82efc3a7c110	JCB 16 digit	37.7880085249274273	-122.393252856583644
8396	2020-01-02 18:36:32	2020-01-02	Dr. Leonel Dicki	dr.leonel.dicki@woohoo.com	Sparks	Nevada	180016206793806212	f43e95eacb40c627258716391b7ae9b2	JCB 16 digit	39.6033860200788865	-119.831371940192213
8397	2020-01-02 19:16:50	2020-01-02	Bambi Hamill	bambi.hamill@woohoo.com	Tucson	Arizona	210094034230868313	42dc575d42650bca1d0123e179414b92	Diners Club / Carte Blanche	32.1349850796669756	-110.824611373873793
8398	2020-01-02 19:43:24	2020-01-02	Omie Leuschke MD	omie.leuschke.md@geemail.com	Scottsdale	Arizona	675914206241631	0e5920adc5c68886a95464b106e408a5	VISA 16 digit	33.7391682765569527	-111.784151286302503
8399	2020-01-02 20:36:57	2020-01-02	Giles Morar	giles.morar@warmmail.com	Coral Springs	Florida	51950700510904282	22ae954fab39baa11a4850023db518e1	Discover	26.321464471106232	-80.2610485065851265
8400	2020-01-02 20:39:39	2020-01-02	Jerald Stroman	jerald.stroman@geemail.com	Tempe	Arizona	4913115054326	3ca9743a4f498da862d5f70877bb9e60	JCB 15 digit	33.2932760776407974	-111.887720311389486
8401	2020-01-02 20:46:40	2020-01-02	Mrs. Kellee Rutherford	mrs.kellee.rutherford@geemail.com	New York	New York	3158564249355932949	846fb874f6ebfe9bb400cb098ac7d111	VISA 16 digit	40.7629991655927171	-74.0127988266654313
8402	2020-01-02 20:53:39	2020-01-02	Dr. Pierce Dickinson PhD	dr.pierce.dickinson.phd@geemail.com	San Francisco	California	4788065429458	d91a6eff195678191f72689993869d9b	Voyager	37.796058340235021	-122.420398414760257
8403	2020-01-02 22:16:23	2020-01-02	Mr. Bart Howe	mr.bart.howe@woohoo.com	Philadelphia	Pennsylvania	53295298594352449	251e7bd30de3335531a477e85d73036b	Voyager	39.9612878006841967	-75.0790037458196338
8404	2020-01-02 22:18:34	2020-01-02	Denton Runte	denton.runte@woohoo.com	Detroit	Michigan	4566953199668	2c610310a65f3bc1e36eca72ccdbaa76	VISA 16 digit	42.3654551352299791	-83.0066158683624025
8405	2020-01-02 22:19:32	2020-01-02	Dr. Braiden Beahan V	dr.braiden.beahan.v@woohoo.com	Centennial	Colorado	3031458448510197	e1a01042c662432de44f30ab5c694016	VISA 16 digit	39.5150152286555638	-104.896167976724357
8406	2020-01-02 23:07:58	2020-01-02	Wing Reilly	wing.reilly@woohoo.com	Berkeley	California	3088993313966491181	ac31f024a59e640e1978251937a8df11	JCB 16 digit	37.8782830445828225	-122.279987858066121
8407	2020-01-02 23:46:43	2020-01-02	Farah Bauch	farah.bauch@geemail.com	San Francisco	California	6011225349788912459	0b231907fe2a333dde4122c973f27afa	JCB 16 digit	37.78912634762208	-122.441509910953471
8408	2020-01-02 23:49:03	2020-01-02	Ermina Gerlach	ermina.gerlach@geemail.com	New York	New York	180053380732644648	76e24917b0c42f4cf6c153e6cc4795a9	American Express	40.696988997910168	-73.8454093160934661
8409	2020-01-02 23:54:49	2020-01-02	Mrs. Jossie Jones	mrs.jossie.jones@warmmail.com	Chicago	Illinois	3487836318701086	5fd74aee21ac0e34dcb760a1551957a1	JCB 16 digit	41.8876153563916702	-87.649517465758322
8410	2020-01-03 00:26:10	2020-01-03	Duwayne VonRueden	duwayne.vonrueden@woohoo.com	Pasadena	California	589359829427034	541fe1c0881389d60c0c64bc0495dad1	Voyager	34.2360895418416717	-118.171539307367425
8411	2020-01-03 01:36:12	2020-01-03	Mr. Cleo Collins DVM	mr.cleo.collins.dvm@geemail.com	Memphis	Tennessee	4078643256486	e967686ec192e3882d393eee757a87cc	Voyager	35.1230752856537691	-89.9507903867192624
8412	2020-01-03 02:27:34	2020-01-03	Blair Nienow Sr.	blair.nienow.sr.@geemail.com	New York	New York	3437812397842159	d6734cc16b367b99b8506b70e63c3ea1	JCB 16 digit	40.7374383139181901	-73.9173631796974604
8413	2020-01-03 02:37:43	2020-01-03	Annamae Von	annamae.von@geemail.com	Dallas	Texas	3017024266244543	7571540dd3a46c6191b694ea57df6856	Mastercard	32.8617130291920176	-96.859860908562311
8414	2020-01-03 03:05:26	2020-01-03	Mr. Javonte Schowalter	mr.javonte.schowalter@geemail.com	St. Petersburg	Florida	676296968933554	46ab1335543e7d10067cda2007097b30	Mastercard	27.7139930424634358	-82.5510611612707379
8415	2020-01-03 03:07:12	2020-01-03	Dr. Frazier Feeney I	dr.frazier.feeney.i@woohoo.com	Wichita	Kansas	060462647954833	058f841a5383d604f8fc9c7c0b6d1ecf	JCB 16 digit	37.6903135430876191	-97.2949733940619979
8416	2020-01-03 03:13:50	2020-01-03	Mr. Kelvin Beatty PhD	mr.kelvin.beatty.phd@geemail.com	McKinney	Texas	501830025784031	29d9cc0ab3f504a6eb066dec2ee55943	Maestro	33.2907718338668346	-96.7300488135609839
8417	2020-01-03 03:37:43	2020-01-03	Andrae Durgan	andrae.durgan@geemail.com	Los Angeles	California	4824396028123525	fe55aaa616f95f327f5085b3c5a1d49d	Voyager	33.9526622232381214	-118.4021805485703
8418	2020-01-03 03:39:36	2020-01-03	Nicole Cremin DDS	nicole.cremin.dds@geemail.com	San Francisco	California	6011296046307576336	9356f355b867ec761918b598ce3307af	Voyager	37.7857064871373112	-122.399636755412402
8419	2020-01-03 03:47:48	2020-01-03	Jo Swaniawski	jo.swaniawski@woohoo.com	San Francisco	California	869929610906952984	075bc08c7804ffa58dec4012cff2ed6f	JCB 15 digit	37.7656614527837604	-122.386504314859451
8420	2020-01-03 03:58:12	2020-01-03	Selene Gaylord	selene.gaylord@geemail.com	Berkeley	California	3012571477387409	e939d95d015ec4bc767d1ff40665ee3b	VISA 16 digit	37.8789090226829899	-122.220597444524003
8421	2020-01-03 04:45:57	2020-01-03	Barron Reichel-Rosenbaum	barron.reichel.rosenbaum@warmmail.com	Salt Lake City	Utah	3337693878076882001	97e61acfd33988e8327d97d09436044d	VISA 16 digit	40.7485340337879904	-111.851958926342419
8422	2020-01-03 05:10:36	2020-01-03	Miss Cheryle Klocko DDS	miss.cheryle.klocko.dds@warmmail.com	Oklahoma City	Oklahoma	4487028944917759	3cab79dae2cca392bda02fe00c7e236c	VISA 16 digit	35.3900673130903414	-97.4820245803229568
8423	2020-01-03 05:25:39	2020-01-03	Donaciano Russel IV	donaciano.russel.iv@geemail.com	Seattle	Washington	180051869075132890	87bf7f7fc5164c5fadf9cf9b2c2588fe	Mastercard	47.5839364954195929	-122.38589508136883
8424	2020-01-03 05:28:41	2020-01-03	Mrs. Kiera Mills PhD	mrs.kiera.mills.phd@geemail.com	Houston	Texas	3158507095682838402	32cb22e0cd47e9a75772e2673a48ea22	Voyager	29.8434957502953715	-95.4509547119043731
8425	2020-01-03 05:33:45	2020-01-03	Christian Aufderhar DVM	christian.aufderhar.dvm@woohoo.com	San Francisco	California	3337097706585800788	f364790e2aec0672636d8eb339e3a9dd	Discover	37.7853116128322029	-122.407854581186143
8426	2020-01-03 05:48:48	2020-01-03	Polk Stokes II	polk.stokes.ii@geemail.com	San Francisco	California	53018853988682268	b16edce1ba769ed37ea63509b5eaef0d	American Express	37.8145042453337439	-122.421146257794916
8427	2020-01-03 05:55:43	2020-01-03	Gianna Mueller	gianna.mueller@geemail.com	Gresham	Oregon	3337915371994434776	40038c6b6e8defa77b1e54f3d12e992a	American Express	45.4770528103180212	-122.426636070039493
8428	2020-01-03 06:10:15	2020-01-03	Miss Carlee Yost MD	miss.carlee.yost.md@geemail.com	Oklahoma City	Oklahoma	4342688990155	5bdf13380182e20fe32f6b68526b6ff4	VISA 16 digit	35.3717131900511674	-97.4851867797680143
8429	2020-01-03 06:30:37	2020-01-03	Mckenna Mohr MD	mckenna.mohr.md@geemail.com	San Francisco	California	3088448026702277695	b3fde23995c891948287afe2183a5562	JCB 16 digit	37.7723109298560544	-122.438174596698914
8430	2020-01-03 07:07:29	2020-01-03	Mrs. Versa Friesen	mrs.versa.friesen@geemail.com	Denver	Colorado	4737738448098	d2d2ba647cb2d28f37473cfc95565c41	JCB 16 digit	39.7153636406693593	-104.865849947069222
8431	2020-01-03 07:11:49	2020-01-03	Mr. Armando Waters	mr.armando.waters@warmmail.com	San Francisco	California	3012586360356709	936ee36f15f57e9cfef7f8f7383bc55f	Diners Club / Carte Blanche	37.7988996597555058	-122.451886331890179
8432	2020-01-03 07:33:48	2020-01-03	Phoenix Howell	phoenix.howell@geemail.com	Hollywood	Florida	869959375967182581	2e181e7c2d5b118fc2e83a59dd532591	JCB 15 digit	25.952607098309322	-80.2380702858608146
8433	2020-01-03 08:19:24	2020-01-03	Odessa Schaden PhD	odessa.schaden.phd@geemail.com	Torrance	California	3112245393305477212	d6ed6fb7d4e0384f9615a856ac2e8b23	JCB 16 digit	33.7375920229963953	-118.33157640221863
8434	2020-01-03 09:01:14	2020-01-03	Miss Onnie Mosciski	miss.onnie.mosciski@geemail.com	Los Angeles	California	3337038611497616409	3314e8d6f3ace7d6b76315e41480c2b6	Mastercard	34.044521469888835	-118.506654155952106
8435	2020-01-03 09:21:28	2020-01-03	Shirley Veum	shirley.veum@geemail.com	Lansing	Michigan	869943817605949441	5013741996d87b078a8afa66a086303b	VISA 13 digit	42.6966723846115173	-84.6220560481429089
8436	2020-01-03 10:09:51	2020-01-03	Clemmie Effertz	clemmie.effertz@geemail.com	New York	New York	180011213550553511	cdfd4fdf5776e73d5698eed0903fd204	JCB 15 digit	40.6788197205159818	-73.8819173519860897
8437	2020-01-03 10:10:29	2020-01-03	Vincent Rohan II	vincent.rohan.ii@geemail.com	San Francisco	California	3337930364669416658	c7f8aa0aa56c33adfd689254a464d411	Maestro	37.7749859293409074	-122.408832075076276
8438	2020-01-03 10:54:38	2020-01-03	Sarah Schmitt MD	sarah.schmitt.md@geemail.com	Montgomery	Alabama	4541680765707281	c429ca73965f04d212a594f52e0ee986	JCB 16 digit	32.2829105921488235	-86.2684226114455583
8439	2020-01-03 11:35:04	2020-01-03	Dylon Bruen	dylon.bruen@geemail.com	San Francisco	California	3112695892773530571	6b9a2a57a061b0a24f43fb69237957b3	JCB 16 digit	37.8005641395830736	-122.42691061012043
8440	2020-01-03 11:44:21	2020-01-03	Keesha Hauck	keesha.hauck@woohoo.com	Winston–Salem	North Carolina	180004419619714486	2c063eb8a363c62e7e69e742ec8392ee	Voyager	36.1477074349995675	-80.2506325382869647
8441	2020-01-03 11:45:27	2020-01-03	Chadwick Gutmann	chadwick.gutmann@geemail.com	Detroit	Michigan	3096349693904946706	5f75377522727ccf0705e40c0a9c94b8	Mastercard	42.3204140410218415	-83.024413262738662
8442	2020-01-03 11:58:44	2020-01-03	Lupe Greenfelder I	lupe.greenfelder.i@geemail.com	Oakland	California	4746323230589	4f0e4462afdaabb0c20383febb033811	VISA 16 digit	37.7944902027687277	-122.298055100624737
8443	2020-01-03 12:20:11	2020-01-03	Minoru Koss	minoru.koss@geemail.com	Olathe	Kansas	4860434952994069	51cae305ec78e96dc7b8fc4708b7cc6c	VISA 16 digit	38.8986802853301228	-94.8399387622885399
8444	2020-01-03 12:21:47	2020-01-03	Hoke Conroy	hoke.conroy@geemail.com	Daly City	California	869957206273913520	8d4b605836844b657a351da540069c13	Voyager	37.7544668290685834	-122.493312232531608
8445	2020-01-03 12:30:27	2020-01-03	Denise Wisozk	denise.wisozk@geemail.com	San Jose	California	4242565062925185	8a071f398b79fab6ce108ecc60e2b474	Discover	37.3663676496882005	-121.778562862448027
8446	2020-01-03 12:58:37	2020-01-03	Ross Schmeler	ross.schmeler@woohoo.com	San Francisco	California	3016788008621785	468a8b63fc0964d93ae479ad7c1b3388	JCB 15 digit	37.7633856768545257	-122.459545709446829
8447	2020-01-03 13:14:21	2020-01-03	Jorge Bayer-Bartoletti	jorge.bayer.bartoletti@woohoo.com	El Paso	Texas	210028408788014408	41e0002b204e102039cc10470ba975e4	Voyager	31.7540207596790047	-106.421737332826481
8448	2020-01-03 13:31:08	2020-01-03	Eldora O'Reilly	eldora.o'reilly@geemail.com	San Francisco	California	3775528397839234	cc310e9da113c76f2e24c111dc12e069	Maestro	37.7687298323978169	-122.425021286563165
8449	2020-01-03 14:58:19	2020-01-03	Kirstin Wiza DDS	kirstin.wiza.dds@geemail.com	San Francisco	California	869988874073000062	844d8ec014acfc17fbdb1b4c3d2ee481	Maestro	37.7884360565819151	-122.456540059592342
8450	2020-01-03 15:07:06	2020-01-03	Ione McDermott	ione.mcdermott@geemail.com	San Antonio	Texas	3337873445645651531	a6489ab96ce98dce44bfa2528e5c1c0f	Discover	29.5585691433005024	-98.5276248324498454
8451	2020-01-03 15:12:19	2020-01-03	Sheldon Bayer DVM	sheldon.bayer.dvm@geemail.com	Fort Wayne	Indiana	3482775219210679	22e06623dd683fd70074c42ddcd69558	American Express	41.0000023926392174	-85.1036617260646153
8452	2020-01-03 15:28:40	2020-01-03	Dr. Donavan Kassulke MD	dr.donavan.kassulke.md@geemail.com	New York	New York	4630582581847253	3269420f54bd602de874dd7c6af52991	Discover	40.7585204997323416	-73.8689243775222479
8453	2020-01-03 15:36:31	2020-01-03	Micky Flatley	micky.flatley@geemail.com	Garland	Texas	3724971523080269	6a94dda2273fc35dc1bec6ee3d14c5ca	Discover	32.8390345701716839	-96.6417465083926999
8454	2020-01-03 15:41:35	2020-01-03	Trent Ferry IV	trent.ferry.iv@geemail.com	San Francisco	California	3019715510924230	2188c7cdf1a8472d5ccd7d8026492f31	Mastercard	37.7355938274428624	-122.426647408012542
8455	2020-01-03 16:10:34	2020-01-03	Ms. Mikayla Littel	ms.mikayla.littel@warmmail.com	Newark	New Jersey	3096529133249673238	2a1fda6d2d91ea26d5e59b268123bd96	Maestro	40.8175670447673653	-74.1466693560801531
8456	2020-01-03 16:25:05	2020-01-03	Mrs. Adyson Kunde PhD	mrs.adyson.kunde.phd@woohoo.com	Milwaukee	Wisconsin	3038777877391891	8838512f899188f44f6c6e5ee427e1dc	Mastercard	43.1268771121364054	-87.9882233993250935
8457	2020-01-03 16:40:57	2020-01-03	Scarlet Durgan	scarlet.durgan@warmmail.com	Berkeley	California	4353054243083714	729fb462565ab48f55fff0c025808335	VISA 13 digit	37.8705397135169193	-122.276416367488338
8458	2020-01-03 17:00:21	2020-01-03	Tayla Haley	tayla.haley@geemail.com	Berkeley	California	869923041069392733	6f41ce9c10e560dd7b2030fec1d2f58b	Mastercard	37.8386495508610352	-122.260610729867807
8459	2020-01-03 17:01:38	2020-01-03	Solon Kassulke	solon.kassulke@geemail.com	San Francisco	California	3006079755530811	04057c5960399e2788a8f4dac37a4a26	VISA 16 digit	37.793188171995773	-122.441838607920729
8460	2020-01-03 17:16:28	2020-01-03	Mr. Derik Swift	mr.derik.swift@geemail.com	Victorville	California	4504011088007743	f4d96cfa07097b38823112425650fd9c	JCB 16 digit	34.5571093317817954	-117.33749092474244
8461	2020-01-03 17:19:14	2020-01-03	Laurie Murphy	laurie.murphy@geemail.com	Fresno	California	4873154808359631	67c56465d847f5fec022455a022987ac	JCB 16 digit	36.797032398112492	-119.854533947363123
8462	2020-01-03 17:39:25	2020-01-03	Dr. Soledad Blanda	dr.soledad.blanda@geemail.com	Baltimore	Maryland	3088572960900342109	27c65fec4169b157ef0a20c9d3d9cbdc	Diners Club / Carte Blanche	39.2686957285739453	-76.6184807291738679
8463	2020-01-03 18:00:09	2020-01-03	Alonzo Roberts-Feil	alonzo.roberts.feil@geemail.com	San Francisco	California	210036972825126012	84d648a6166a9c58c65edf4a98906823	JCB 15 digit	37.7673280344171047	-122.414276140024427
8464	2020-01-03 18:18:04	2020-01-03	Sedrick Green III	sedrick.green.iii@geemail.com	Las Vegas	Nevada	51475876043131977	ee48dc0a7d54673c469600c340108921	VISA 16 digit	36.3000432439248968	-115.229448185742271
8465	2020-01-03 18:23:21	2020-01-03	Archibald Ratke	archibald.ratke@geemail.com	Fayetteville	North Carolina	676253053595673	af734fbc9b529207870343c98b3c394c	Diners Club / Carte Blanche	35.0205312504686432	-79.025727457519622
8466	2020-01-03 18:25:08	2020-01-03	Donavon Lindgren	donavon.lindgren@warmmail.com	New York	New York	589339587842335	6be3b0930c66dab0f58193d8293c5711	Discover	40.5823363002613178	-73.9190600874263737
8467	2020-01-03 18:42:21	2020-01-03	Dwight Willms-Pollich	dwight.willms.pollich@geemail.com	Fresno	California	52852099016363211	a26490a58caf2083ee5cc37577b336f9	Diners Club / Carte Blanche	36.8146413672123103	-119.824007086978852
8468	2020-01-03 19:07:31	2020-01-03	Judd Hane	judd.hane@geemail.com	Sacramento	California	3337413201251938937	46449c5ef8a6a29db81af2d6fc973447	Discover	38.5220555686190735	-121.404780871538819
8469	2020-01-03 19:20:21	2020-01-03	Miss Roxane Gulgowski	miss.roxane.gulgowski@geemail.com	Clearwater	Florida	869991519441153003	5467f3c536c81cf4dfc3ac1dab298e3e	JCB 16 digit	28.0313201745633016	-82.8217801581401289
8470	2020-01-03 19:56:45	2020-01-03	Gaston Bergstrom	gaston.bergstrom@geemail.com	Cleveland	Ohio	4045987955324269	1f3ae1c225610e2f209454e9820a4556	Discover	41.5144432563185646	-81.7560404560767182
8471	2020-01-03 20:06:39	2020-01-03	Lisle Lynch	lisle.lynch@warmmail.com	San Francisco	California	3337802919887536358	22e2cbb36f74798eaa2ce3aaef02cdc2	Voyager	37.7718506821619115	-122.44444038603875
8472	2020-01-03 20:35:27	2020-01-03	Briana Glover	briana.glover@geemail.com	El Monte	California	4906512872253231	782ae299035d8dd3d3634984222f9e24	Voyager	34.1156012528765942	-118.033876165634396
8473	2020-01-03 20:41:52	2020-01-03	Shonna Ernser	shonna.ernser@geemail.com	Jurupa Valley	California	3008950331507093	df89211b7d0dcc4373cffbb8e86da255	VISA 16 digit	34.0403605229150514	-117.388419895900796
8474	2020-01-03 20:41:55	2020-01-03	Polly Oberbrunner-Hagenes	polly.oberbrunner.hagenes@geemail.com	San Francisco	California	3112966828868129400	9115e55485a6e29fcf82cf78b3ce70de	VISA 13 digit	37.743265003815786	-122.472639693909173
8475	2020-01-03 21:50:15	2020-01-03	Dr. Georgianna Feest	dr.georgianna.feest@woohoo.com	Port St. Lucie	Florida	3337190034707799648	964bcd9237bb0733fd1503f3c6b69902	Diners Club / Carte Blanche	27.3501244785398256	-80.2969109000258214
8476	2020-01-03 21:58:02	2020-01-03	Alease McCullough	alease.mccullough@woohoo.com	San Antonio	Texas	4491893361791	0e95a1f4befc14579862cf0c272fe5f1	VISA 16 digit	29.4589434061735886	-98.4667236632969178
8477	2020-01-03 22:01:55	2020-01-03	Dr. Worth Orn	dr.worth.orn@woohoo.com	San Francisco	California	51460946035653598	eb2b70f25d3369cf163f76c7f19602b9	American Express	37.7903641215283201	-122.424656251681412
8478	2020-01-03 22:52:37	2020-01-03	Dr. Christopher Howe	dr.christopher.howe@geemail.com	Jacksonville	Florida	4739170076155	8634f53586ffda32e61e9af22bc94e6c	Diners Club / Carte Blanche	30.4308912648405894	-81.6326571956355167
8479	2020-01-03 22:58:54	2020-01-03	Caryn Witting	caryn.witting@woohoo.com	San Jose	California	4542254444110322	3236e2add5f5143568ce7b55a69c598c	Mastercard	37.3853751844082041	-121.805415926895662
8480	2020-01-03 23:19:32	2020-01-03	Dr. Courtney Hand I	dr.courtney.hand.i@geemail.com	Phoenix	Arizona	3760289412386142	d0238b8c081dd865cfa9b874b295c3b0	JCB 15 digit	33.5690689492437997	-112.037941345658538
8481	2020-01-03 23:45:17	2020-01-03	Mr. Gabe Rippin	mr.gabe.rippin@geemail.com	Madison	Wisconsin	3032856781507127	bec905e112b439597758f5845878ad58	Discover	43.1189252871062649	-89.4316762836068904
8482	2020-01-04 00:34:06	2020-01-04	Kalel Gusikowski	kalel.gusikowski@geemail.com	Sacramento	California	210061609708651587	823a75e9d70d8bebf40438a46550206b	Maestro	38.5701480353515578	-121.372924447782708
8483	2020-01-04 00:49:19	2020-01-04	Dr. Kaitlyn Kiehn	dr.kaitlyn.kiehn@geemail.com	Norfolk	Virginia	55361790794728211	d6c07f34d62da9317c2616182ee0ca71	JCB 15 digit	36.9824860113225924	-76.331472272379699
8484	2020-01-04 00:56:27	2020-01-04	Bettyjane Dickens-Greenfelder	bettyjane.dickens.greenfelder@geemail.com	Anchorage	Alaska	4654036570459	e5a89931e1035c12731312d332fb34d0	Voyager	61.2071175082337149	-149.265676005755751
8485	2020-01-04 00:58:48	2020-01-04	Dr. Metha Johnson PhD	dr.metha.johnson.phd@geemail.com	San Francisco	California	3053164300789626	de1d72b3f0dd49b1070672c794bd6a3d	VISA 13 digit	37.788019712314636	-122.406961118768294
8486	2020-01-04 01:02:54	2020-01-04	Dr. Hervey Hirthe	dr.hervey.hirthe@woohoo.com	Miami	Florida	4663178637077126	5c140418b874f08253f85f8faf106503	Voyager	25.843916743495317	-80.2007579335816274
8487	2020-01-04 01:18:36	2020-01-04	Dr. Lisha Medhurst	dr.lisha.medhurst@geemail.com	Wichita	Kansas	3018952856163153	42c28207ba119bab0ad3df8213580d1d	Voyager	37.711117425176127	-97.3478763014744999
8488	2020-01-04 01:30:28	2020-01-04	Ms. Alvina Hansen MD	ms.alvina.hansen.md@woohoo.com	Berkeley	California	676319435837752	31f43670d45836e750ab15c6db996c40	Diners Club / Carte Blanche	37.8809408613412089	-122.276651545853369
8489	2020-01-04 03:10:38	2020-01-04	Julianne Cremin	julianne.cremin@woohoo.com	Berkeley	California	4379376851145851	57085955bed3ac5abbc223d6ee08fc5b	Discover	37.863396435623585	-122.261887630078263
8490	2020-01-04 03:20:21	2020-01-04	Pattie Batz DVM	pattie.batz.dvm@woohoo.com	El Paso	Texas	4651183662510292	e15dada2daa6d12d2c260c94d46df866	Mastercard	31.7502253179267058	-106.507901928851382
8491	2020-01-04 03:23:00	2020-01-04	Rafe Sanford	rafe.sanford@geemail.com	Los Angeles	California	3112825441986499670	b37282362d72a73875582506b8e24cab	Diners Club / Carte Blanche	34.0957407459482553	-118.370869141583512
8492	2020-01-04 03:33:56	2020-01-04	Esteban Kuhlman	esteban.kuhlman@geemail.com	Olathe	Kansas	676124250664232	03e7b5d85c794af780ef84baac99b28d	Discover	38.8046694686293634	-94.7370016816705487
8493	2020-01-04 03:44:11	2020-01-04	Moody Harber	moody.harber@geemail.com	San Francisco	California	869957805561244215	6c16aecdeb8a6539e97239ba06076184	VISA 16 digit	37.8004135286115357	-122.4192021386677
8494	2020-01-04 03:51:20	2020-01-04	Hattie Glover	hattie.glover@geemail.com	Dallas	Texas	3528817588521062130	d53f10b35f6c099aec92a4c8b6ba3a13	Diners Club / Carte Blanche	32.8423611402783564	-96.8086426517423178
8495	2020-01-04 04:08:12	2020-01-04	Tia Waters-Hamill	tia.waters.hamill@geemail.com	Chesapeake	Virginia	3528375097534835304	57e4f7995cbcae80b423fc22c0414b7e	VISA 13 digit	36.7584814496576797	-76.2885831096518814
8496	2020-01-04 04:08:57	2020-01-04	Isabell Heller	isabell.heller@geemail.com	Vallejo	California	6011408148681634031	827689520e886776cde4d8da56900bbc	VISA 16 digit	38.0134104271043114	-122.198807378984981
8497	2020-01-04 04:13:49	2020-01-04	Elvis Lang	elvis.lang@geemail.com	New Orleans	Louisiana	3413586330556880	a1768fba4a71bf8497cc44307aa0891f	VISA 16 digit	30.1369477838758364	-89.8530166917275608
8498	2020-01-04 04:18:55	2020-01-04	Felicity Dooley	felicity.dooley@geemail.com	Baltimore	Maryland	210059516232449269	f6ca3acd4ab458679ba480354bf5cab8	Maestro	39.2560885573737295	-76.680310909172519
8499	2020-01-04 04:19:16	2020-01-04	Essex McGlynn	essex.mcglynn@geemail.com	Akron	Ohio	4138731486922	c2b6e3640c2c1a23b00973dca0d4af71	Voyager	41.0039572299756117	-81.5843768048413125
8500	2020-01-04 04:32:04	2020-01-04	Sammy Hand	sammy.hand@warmmail.com	Durham	North Carolina	6011219437860039396	38eab9668194b62a332ba174c8913fcd	JCB 16 digit	35.9665574906639733	-79.002377633694195
8501	2020-01-04 04:48:00	2020-01-04	Anastacia Cronin	anastacia.cronin@geemail.com	San Francisco	California	3112699068205589909	1c59d732d466b85af357361097d7386e	Diners Club / Carte Blanche	37.7826205627370157	-122.426312245017201
8502	2020-01-04 05:03:54	2020-01-04	Conway Smith	conway.smith@warmmail.com	Denver	Colorado	3008705525215451	d956f9838d7687b7ba2bbe93529b0db5	American Express	39.6682840170390847	-104.862588796975473
8503	2020-01-04 06:08:43	2020-01-04	Chandra Monahan	chandra.monahan@woohoo.com	Chesapeake	Virginia	6011202550206299463	59996d4f357e02432067134d99a9dd34	JCB 15 digit	36.6339209985692094	-76.2346538020141367
8504	2020-01-04 06:35:30	2020-01-04	Rico Murphy	rico.murphy@warmmail.com	Fresno	California	3158750144343995302	4fe33a0cad3621b057281a17fff43203	JCB 16 digit	36.698924023831637	-119.882703747378301
8505	2020-01-04 07:05:46	2020-01-04	Arlyne McKenzie DDS	arlyne.mckenzie.dds@geemail.com	Oakland	California	502079386854552	15fad95e1845e72627a6d960e093cf35	JCB 15 digit	37.7944346247411858	-122.265475282209948
8506	2020-01-04 07:14:49	2020-01-04	Leatha Murazik	leatha.murazik@geemail.com	Springfield	Massachusetts	180026251002756467	3616d5e66421aee8c8b1dc1c0148c689	Mastercard	42.1475521493442358	-72.5709797662776026
8507	2020-01-04 07:22:56	2020-01-04	Lethia Hartmann	lethia.hartmann@geemail.com	San Francisco	California	3747332010093336	b5ac515774fb645ca5d02ff465ad3eb1	VISA 13 digit	37.7893425009254287	-122.455190109196892
8508	2020-01-04 07:38:14	2020-01-04	Dock Cormier-Hettinger	dock.cormier.hettinger@woohoo.com	Rialto	California	3337961179376193461	943a3dbf98635eb7f132517721fbbd37	VISA 16 digit	34.1871004414029471	-117.297681524147464
8509	2020-01-04 07:49:18	2020-01-04	Adah Torp	adah.torp@woohoo.com	Fremont	California	4479961665698	8361a46ef950a435f982476cc8bb3ea9	VISA 16 digit	37.4007291768379559	-122.017909109963838
8510	2020-01-04 07:53:18	2020-01-04	Mr. Kelly Dicki	mr.kelly.dicki@geemail.com	Houston	Texas	4546067196562201	93c71c954a4e3191b05f1a9beacf73a9	Voyager	29.7767074968278393	-95.353578948370739
8511	2020-01-04 08:04:10	2020-01-04	Arden Dibbert DDS	arden.dibbert.dds@geemail.com	New York	New York	6011994919316919975	36d4bac4f4550278c35fd19fea7ad6f9	VISA 16 digit	40.7346724259890607	-74.0384127179521982
8512	2020-01-04 08:14:09	2020-01-04	Dr. Littleton Kunze	dr.littleton.kunze@geemail.com	Waco	Texas	3727187261698702	5aadef2256b56af81d32fbf270c2fd0f	Maestro	31.4681241686664492	-97.1477829127702961
8513	2020-01-04 08:19:35	2020-01-04	Ossie Daugherty PhD	ossie.daugherty.phd@geemail.com	Norfolk	Virginia	3701843786285447	2f608a8623ef1efb67d4b6be11853fa0	JCB 16 digit	36.8850033030398237	-76.2151364638939555
8514	2020-01-04 08:46:47	2020-01-04	Kelsey Cartwright DDS	kelsey.cartwright.dds@woohoo.com	Albuquerque	New Mexico	3088128389338068467	27c385b404dde120aa59e1e8914381ed	Diners Club / Carte Blanche	35.0468668336648506	-106.551046061196928
8515	2020-01-04 08:53:03	2020-01-04	Dr. Kyree Becker	dr.kyree.becker@geemail.com	New York	New York	3041184933649957	b2b1035bef761935fc7f3d52f4248f5c	Discover	40.5775261302236459	-73.8486130195565522
8516	2020-01-04 09:06:45	2020-01-04	Brain Jaskolski	brain.jaskolski@warmmail.com	San Francisco	California	55658175008439205	d5cfe1a5d5f4154f6ba00f5218aa647b	VISA 16 digit	37.7905097105789807	-122.425731008950322
8517	2020-01-04 09:08:52	2020-01-04	Jarvis Hilll	jarvis.hilll@geemail.com	New York	New York	3448284751460191	bf6d57e4695a037da830493d3d0aa538	Voyager	40.6434177526962017	-74.0200765816856148
8518	2020-01-04 09:31:26	2020-01-04	Math Gerhold	math.gerhold@geemail.com	Wichita	Kansas	589312428592443	b8485958dd5553a9a8347d00a1ba209f	VISA 16 digit	37.6175082121387092	-97.3621757381796868
8519	2020-01-04 09:32:43	2020-01-04	Dr. Larae Mayer PhD	dr.larae.mayer.phd@geemail.com	Berkeley	California	180062439178902453	63fc0b8b7c874def6760bed63b32a7cd	Mastercard	37.8987328349185191	-122.262093959748583
8520	2020-01-04 09:59:33	2020-01-04	Eleanora Beahan	eleanora.beahan@geemail.com	Albuquerque	New Mexico	4617596230461776	d1ad3f253f5b5a0d22d89ed56651416e	American Express	35.0404239158745909	-106.59806546956078
8521	2020-01-04 10:52:51	2020-01-04	Mrs. Yoshiko Prohaska PhD	mrs.yoshiko.prohaska.phd@geemail.com	San Francisco	California	4320253882056	3562cd34fa30772296802b0f264bd964	Voyager	37.778042737586162	-122.38089102246623
8522	2020-01-04 11:06:20	2020-01-04	Dr. Ron Koelpin PhD	dr.ron.koelpin.phd@geemail.com	Huntington Beach	California	3088778320638754012	38161c1e98410e2acc442c02a12cb3d5	JCB 15 digit	33.637080928827082	-118.104154173064231
8523	2020-01-04 11:12:54	2020-01-04	Dino Larkin	dino.larkin@geemail.com	Oceanside	California	3158830809300605862	e9843ced91fe984185e6a9e61ff4edf6	Mastercard	33.1730653241165001	-117.334652647617091
8524	2020-01-04 11:15:01	2020-01-04	Domenico Smitham	domenico.smitham@geemail.com	West Jordan	Utah	4395675284677	2d6d7db52ba07f75f73718cd24b6cc6b	Voyager	40.5406975328248009	-111.909878489430241
8525	2020-01-04 11:15:25	2020-01-04	Dr. Lovie Fadel	dr.lovie.fadel@warmmail.com	San Francisco	California	3756260560110374	36e15ffee3cd20414dfbf5c6075bd41f	JCB 16 digit	37.806652170258559	-122.391772744462727
8526	2020-01-04 11:29:15	2020-01-04	Lyda Wiegand	lyda.wiegand@woohoo.com	Grand Rapids	Michigan	54677553952193381	fb26acf07c06b5cee15f8c9b67111980	Maestro	42.8950738393504167	-85.6367696850229123
8527	2020-01-04 11:29:39	2020-01-04	Aidan Gaylord	aidan.gaylord@woohoo.com	Pasadena	Texas	180052832543332483	f18d9c79e4590e4debdb534672735609	JCB 16 digit	29.7468876527495674	-95.0581478329323204
8528	2020-01-04 12:39:32	2020-01-04	Dr. Manie Spencer	dr.manie.spencer@woohoo.com	Dallas	Texas	4519623447306	1cddab2ad9617686d6ab8649c5df1f7b	Voyager	32.865013553974407	-96.8364159460142133
8529	2020-01-04 12:40:37	2020-01-04	Keith Adams III	keith.adams.iii@warmmail.com	San Francisco	California	4532266463105795	9d753141a5df09068e5972307b97a2c3	JCB 16 digit	37.7770514523996681	-122.41235048398525
8530	2020-01-04 12:48:10	2020-01-04	Rylee Hyatt	rylee.hyatt@geemail.com	San Francisco	California	3112678813353378695	bb16579190b790a1ca4e7b73b4bed18f	Discover	37.7436125537913441	-122.421623969103379
8531	2020-01-04 13:29:49	2020-01-04	Devin Hartmann	devin.hartmann@geemail.com	Miami	Florida	6011445217504401962	5b77aaea9b153b1f9a46b56a9e79543e	VISA 13 digit	25.7052974663812677	-80.147360820217429
8532	2020-01-04 13:35:25	2020-01-04	Mrs. Elvina Murphy DVM	mrs.elvina.murphy.dvm@woohoo.com	Dallas	Texas	4601003154296	509bd12a3e61f937e8b36ed0f892b861	JCB 16 digit	32.7093270267631908	-96.8616100591570017
8533	2020-01-04 13:44:33	2020-01-04	Domenick Leannon	domenick.leannon@geemail.com	Boise	Idaho	869924291619224618	5194d497fea923e893f98855e6cdb54e	VISA 13 digit	43.6980882088325941	-116.257310569678253
8534	2020-01-04 14:22:39	2020-01-04	Mr. Milan Bauch	mr.milan.bauch@woohoo.com	Lexington	Kentucky	3422435729499436	ad48bf74b9e219770edc2119ab9c5ff3	JCB 16 digit	38.0238854343414303	-84.4650785706371039
8535	2020-01-04 14:27:00	2020-01-04	Charity Durgan-Skiles	charity.durgan.skiles@warmmail.com	Spokane	Washington	3088244094991539254	3abf2f8781f46b8123af6efe08e3e98e	Discover	47.6453339069854422	-117.394878018823647
8536	2020-01-04 14:30:55	2020-01-04	Philomene King-Ondricka	philomene.king.ondricka@warmmail.com	Overland Park	Kansas	4190729072197787	f415245d6e47872b5ed81a11669e5d0d	American Express	38.8281522878315357	-94.7307896326337016
8537	2020-01-04 14:34:39	2020-01-04	Marlys Effertz	marlys.effertz@geemail.com	Manchester	New Hampshire	3096253175547027130	b51b5a097f7a4d29a1c9eba4d0e7e0ea	JCB 16 digit	42.9471125889640319	-71.4123205864228368
8538	2020-01-04 14:38:29	2020-01-04	Osbaldo Haley	osbaldo.haley@woohoo.com	Las Cruces	New Mexico	4575319239900631	bf3d0fecfd0f9d5a8e6c7718ec3246dc	Discover	32.2284402130670813	-106.873831579706447
8539	2020-01-04 14:45:58	2020-01-04	Veola Cormier-Maggio	veola.cormier.maggio@geemail.com	Lexington	Kentucky	3088783653458568036	2d8914afedf789c7fa9ddc56f9d3bc86	Discover	38.0783904303208018	-84.495666788508359
8540	2020-01-04 15:06:01	2020-01-04	Shanon Simonis-Leuschke	shanon.simonis.leuschke@geemail.com	San Diego	California	4897428971524797	d325313bdf334620a5efd2dc55b2745b	VISA 16 digit	32.7785808477152116	-117.08139678434469
8541	2020-01-04 15:06:12	2020-01-04	Victoria Jast	victoria.jast@woohoo.com	Lakewood	New Jersey	4334682179557386	c81f04b765c1e217670affed187ac596	VISA 13 digit	40.1684657740224154	-74.2148608024507723
8542	2020-01-04 15:09:07	2020-01-04	Toy Hodkiewicz DVM	toy.hodkiewicz.dvm@geemail.com	Tucson	Arizona	51323270753376929	8f3f37fdbfb33a360271316e2d4621ee	Maestro	32.2131706671364597	-110.947612270409607
8543	2020-01-04 15:15:29	2020-01-04	Abb Hermann-Nienow	abb.hermann.nienow@geemail.com	Berkeley	California	502044389172220	93f3936961766b304f6c90c7c6def23b	VISA 13 digit	37.8781082371223619	-122.279425316384703
8544	2020-01-04 15:26:38	2020-01-04	Volney Renner	volney.renner@geemail.com	Athens	Georgia	6011324037943618380	f1263d16afead10615164bf7a22c701b	JCB 15 digit	33.8500177371505586	-83.3294938328791375
8545	2020-01-04 15:32:29	2020-01-04	Mrs. Brooklyn Smitham	mrs.brooklyn.smitham@geemail.com	Birmingham	Alabama	3704588453833030	4df4fc172eef8302f1f0702ad73bf185	American Express	33.4815101034730702	-86.7965268300157078
8546	2020-01-04 15:57:41	2020-01-04	Dena Brekke-Bartell	dena.brekke.bartell@warmmail.com	San Francisco	California	3158154991998018737	b13bee87894e832a81527816dff9ab85	Discover	37.7871835978289141	-122.424585816264212
8547	2020-01-04 16:31:36	2020-01-04	Mrs. Laureen Rempel DDS	mrs.laureen.rempel.dds@geemail.com	Stamford	Connecticut	3402560763165728	781f702b7dab640a4a3a483f61918bd7	JCB 16 digit	41.1565950572840862	-73.5551337895952173
8548	2020-01-04 16:38:48	2020-01-04	Dr. Jerrad Hermiston	dr.jerrad.hermiston@geemail.com	Hillsboro	Oregon	3096779789047677262	bff5a4e49ad77992c6023536557258a2	JCB 15 digit	45.5565976440180052	-123.008752955744782
8549	2020-01-04 16:41:17	2020-01-04	Dr. Burdette Goodwin I	dr.burdette.goodwin.i@geemail.com	Akron	Ohio	4003166770419147	b9c90bda15265ae309c165558229d5a5	JCB 15 digit	41.0052073130682118	-81.5762397211823611
8550	2020-01-04 16:46:35	2020-01-04	Mariel Beier	mariel.beier@geemail.com	San Francisco	California	6011074726195796397	b7e5abe25e44c3bd06949302ebb4e05e	VISA 16 digit	37.7584274960162958	-122.428003994493565
8551	2020-01-04 17:03:44	2020-01-04	Trina Langworth DVM	trina.langworth.dvm@warmmail.com	San Antonio	Texas	869993869955334715	e04cd0dd82129d615ce76c1a5fb8bff3	VISA 16 digit	29.4667859166931372	-98.581054249482591
8552	2020-01-04 17:06:21	2020-01-04	Elinore Kshlerin	elinore.kshlerin@geemail.com	Modesto	California	3777070847286722	7fba847471f7bb8e2f7519d506ce6794	American Express	37.6745597152039409	-120.917194469759238
8553	2020-01-04 17:09:39	2020-01-04	Reyna Kulas	reyna.kulas@geemail.com	Phoenix	Arizona	4739110892711	e9c04dbd9659615f346d4a65084a9cc5	JCB 16 digit	33.6345102004174166	-112.09675234201589
8554	2020-01-04 17:20:18	2020-01-04	Dr. Marvel Mitchell	dr.marvel.mitchell@woohoo.com	Portland	Oregon	4756509445679	8b3e3740c814e6331b008eda0caec23f	JCB 16 digit	45.4808538043759754	-122.60253074807116
8555	2020-01-04 17:34:45	2020-01-04	Jayne Heaney	jayne.heaney@woohoo.com	Midland	Texas	3452081448119161	1907021a3c001af268b50c01d714ed24	Discover	32.0300424508940438	-102.180366916371511
8556	2020-01-04 17:48:31	2020-01-04	Miss Vina Reichert	miss.vina.reichert@geemail.com	Tulsa	Oklahoma	4766199426215947	3a701abaae8470d8c3ef622aa59757be	Mastercard	36.106388451289007	-95.9817842732604589
8557	2020-01-04 17:56:38	2020-01-04	Audie Block PhD	audie.block.phd@geemail.com	New York	New York	52787829481597566	40be39805161a388aa48e618d88e748e	VISA 16 digit	40.6104680688809623	-73.9014425248268907
8558	2020-01-04 18:18:18	2020-01-04	Kole Hammes-Morar	kole.hammes.morar@geemail.com	Los Angeles	California	53628315673339317	b2b3b364e093354103973e923f5f9e76	JCB 16 digit	34.1043424746353168	-118.36714538838639
8559	2020-01-04 18:42:28	2020-01-04	Kori Williamson	kori.williamson@warmmail.com	Charlotte	North Carolina	55360581190381213	d576f77e74ec85f2ed4b9662e9de885f	JCB 16 digit	35.1549969516016532	-80.7850320221334783
8560	2020-01-04 20:01:51	2020-01-04	Miss Dennie Kiehn PhD	miss.dennie.kiehn.phd@geemail.com	New York	New York	869994355945225410	e584c414045ee522dbd73854ac177702	VISA 13 digit	40.6303547880835794	-73.9964010520733808
8561	2020-01-04 20:19:49	2020-01-04	Jadyn Gislason	jadyn.gislason@warmmail.com	San Francisco	California	869961316959750221	e24dff7df94ccfbaac3c66ff6170a4e7	American Express	37.7693879818729599	-122.440157447537075
8562	2020-01-04 20:20:24	2020-01-04	Reina Streich	reina.streich@geemail.com	Chicago	Illinois	4905863862884	64374a8e16f5a081adc4b85b44f55433	JCB 16 digit	41.8603334311697637	-87.6296673864155906
8563	2020-01-04 20:46:11	2020-01-04	Dr. Jaxon Blanda V	dr.jaxon.blanda.v@warmmail.com	Overland Park	Kansas	6011609875051680882	01c0ae12eee75c72f5b056123c9d5b22	VISA 16 digit	38.8209491527043298	-94.7809567072004171
8564	2020-01-04 21:00:40	2020-01-04	Vicente Feil	vicente.feil@geemail.com	Boston	Massachusetts	3025078620545641	7a2951bac3d27d7bd6962c5ec2cce88c	VISA 16 digit	42.3355396558698303	-71.0282421313643511
8565	2020-01-04 21:16:42	2020-01-04	Miss Margarita Roob	miss.margarita.roob@woohoo.com	San Francisco	California	502071777083883	b7fc19d99c82f2537b0b3b5e86fb5350	VISA 16 digit	37.8053345233304441	-122.433905958052492
8566	2020-01-04 21:23:56	2020-01-04	Marlo Kshlerin	marlo.kshlerin@geemail.com	San Francisco	California	639082590192587	af470bce3e910026a47907e5d58996a3	Diners Club / Carte Blanche	37.7596259986849034	-122.447777064242985
8567	2020-01-04 21:28:31	2020-01-04	Charls Lind PhD	charls.lind.phd@geemail.com	San Francisco	California	210014328106992877	83e12efb85a9ebbe1e9e2a4611cf9563	Diners Club / Carte Blanche	37.7774543465426831	-122.451849112896411
8568	2020-01-04 21:29:37	2020-01-04	Urijah O'Conner	urijah.o'conner@geemail.com	Grand Prairie	Texas	3112307579376416536	ab72762d74be867686f7d59b1d454721	American Express	32.700451363302399	-97.0862527480688016
8569	2020-01-04 22:04:12	2020-01-04	Louisa Bogan	louisa.bogan@woohoo.com	Indianapolis	Indiana	4924092137018	4d9ae1e4b988c5abeb47dcd8b2a5489a	Mastercard	39.8170683074284355	-86.2038253734555013
8570	2020-01-04 22:05:05	2020-01-04	Dr. Maureen Blanda	dr.maureen.blanda@geemail.com	Albuquerque	New Mexico	6011151946168078369	5b655f06fbec4c3d855e1f7e2018a6ce	VISA 16 digit	35.1015771797526668	-106.73761802195348
8571	2020-01-04 22:09:56	2020-01-04	Cher Ryan	cher.ryan@geemail.com	Kansas City	Kansas	52028681333644768	c2627dd96fa8295f0fffe9f33ce0fd76	JCB 16 digit	39.0488825244270288	-94.6425796327117865
8572	2020-01-04 22:16:51	2020-01-04	Betsy Kessler	betsy.kessler@geemail.com	San Francisco	California	180069736287620170	0014445fd48712756503c919ac29ca45	Discover	37.7989979228015045	-122.453523632147082
8573	2020-01-04 22:24:16	2020-01-04	Dr. Marcella Eichmann PhD	dr.marcella.eichmann.phd@warmmail.com	New York	New York	4288130662305984	d925e3b458c16e3424b4428848f0a8c2	Maestro	40.7522497312389334	-73.9015091575112137
8574	2020-01-04 22:32:44	2020-01-04	Joann Hagenes	joann.hagenes@geemail.com	San Francisco	California	3088822030317036112	b0b85ed62ddf8449b27d1cdc26f8bb83	JCB 16 digit	37.7617376721113231	-122.450755015894345
8575	2020-01-04 22:45:04	2020-01-04	Liz Powlowski	liz.powlowski@warmmail.com	San Francisco	California	676157512810607	097f5245cb934017146e5fbdcea6ed43	Discover	37.7553681620237072	-122.436332305693668
8576	2020-01-04 23:13:46	2020-01-04	Brynlee Yost-Frami	brynlee.yost.frami@woohoo.com	Austin	Texas	180024812223857111	f6e145025c7fc0b7b0e507322483a62a	JCB 16 digit	30.2158266174267958	-97.8194734512135398
8577	2020-01-04 23:52:13	2020-01-04	Quinn Fadel	quinn.fadel@warmmail.com	San Francisco	California	4379206499180350	bf2104ed3f6ec098642968fe65babcc3	VISA 16 digit	37.8124014145420304	-122.427952182650927
8578	2020-01-04 23:54:33	2020-01-04	Xiomara Barrows	xiomara.barrows@warmmail.com	Columbia	South Carolina	52320616849809617	2cabd724f3a512042ee20a3f9f5ece1f	American Express	34.0129158272672427	-80.9683821466770013
8579	2020-01-05 00:12:37	2020-01-05	Vernie Wisoky	vernie.wisoky@geemail.com	San Francisco	California	180038138178085993	6325db6f7e24e3a0d8f3ef2b595def6a	VISA 13 digit	37.8061993586592138	-122.42793566874667
8580	2020-01-05 00:33:04	2020-01-05	Renada Marks	renada.marks@geemail.com	Phoenix	Arizona	4779208270610	ef1ba803aa9450b193a21e82dba74920	JCB 16 digit	33.5226514802712998	-112.035434699423988
8581	2020-01-05 00:47:15	2020-01-05	Chauncy Lubowitz	chauncy.lubowitz@woohoo.com	Aurora	Colorado	3054820261729716	38406ee4e2794ad450f93d8ac962224b	VISA 16 digit	39.5990641284845779	-104.680502268590786
8582	2020-01-05 01:18:33	2020-01-05	Maddux Crona	maddux.crona@geemail.com	San Diego	California	210043893152251010	7cb1d97ac8f6283aee55891e5a470ee5	VISA 16 digit	32.7586572213631158	-117.166367324385803
8583	2020-01-05 01:22:14	2020-01-05	Ancel Emmerich-Romaguera	ancel.emmerich.romaguera@warmmail.com	Las Vegas	Nevada	3403537482839527	879fc634e65b5c88c073402c326242ef	Discover	36.1858470433957891	-115.240037387304369
8584	2020-01-05 01:32:28	2020-01-05	Shanelle Bailey	shanelle.bailey@warmmail.com	Frisco	Texas	3021208548482346	463d2f86de233716fb595119d34bbb70	VISA 16 digit	33.1821437293659898	-96.8658555499952172
8585	2020-01-05 01:35:47	2020-01-05	Miss Cristen Kreiger	miss.cristen.kreiger@geemail.com	Denver	Colorado	869954693819352318	f60711dd4b1240740db4c227f11f488b	VISA 13 digit	39.7066905100416392	-104.87493052485064
8586	2020-01-05 01:37:57	2020-01-05	Mr. Ebenezer Konopelski	mr.ebenezer.konopelski@woohoo.com	Concord	California	639091272303248	df770915d942edaba16484b58f921734	JCB 16 digit	37.9254395800575637	-122.046847165393075
8587	2020-01-05 01:55:36	2020-01-05	Kunta Greenfelder	kunta.greenfelder@woohoo.com	Vallejo	California	51571406562514131	f10fa94d0845a7517fb9362f835881b8	Diners Club / Carte Blanche	38.2053965186323978	-122.195882022973151
8588	2020-01-05 02:10:27	2020-01-05	Chalmers Goodwin	chalmers.goodwin@woohoo.com	Winston–Salem	North Carolina	54096594447531275	1c0193d26a6261ac9bbab1ecd4540838	VISA 16 digit	36.0247712554641026	-80.1636370898820445
8589	2020-01-05 02:22:28	2020-01-05	Dejon Walter	dejon.walter@geemail.com	New York	New York	3528399162360153453	d97cd7cfd24b0408497eef25ebf449f0	VISA 13 digit	40.7134522154219454	-73.9589272992115383
8590	2020-01-05 02:31:17	2020-01-05	Dr. Judge Hayes PhD	dr.judge.hayes.phd@geemail.com	Pittsburgh	Pennsylvania	3016065139482464	2f87990f60bd8cf9457092bc889f3d8d	Discover	40.5286219411019246	-79.8987749696414937
8591	2020-01-05 02:34:39	2020-01-05	Dangelo Homenick	dangelo.homenick@geemail.com	Springfield	Missouri	4125038589292	21403fa3db6d50b152f0d95df5daca0e	Maestro	37.1769771935611999	-93.2229139785107321
8592	2020-01-05 03:27:41	2020-01-05	Eston Jerde	eston.jerde@geemail.com	Oakland	California	3112853758233233825	52a747e48fdfba803b185a238ce21a9d	JCB 16 digit	37.8194663917926235	-122.276683739251212
8593	2020-01-05 03:38:12	2020-01-05	Arvel Murray	arvel.murray@geemail.com	Rancho Cucamonga	California	3337550694077876187	28bf09ef2ac594b08324f3638049bf7d	VISA 16 digit	34.1138716881621633	-117.472179588536548
8594	2020-01-05 04:05:52	2020-01-05	Mr. Laurance Bergstrom	mr.laurance.bergstrom@geemail.com	New York	New York	3158033925885746163	5740e5518d55543888a7279c2697c07f	Mastercard	40.6186322294864794	-73.9694176702655852
8595	2020-01-05 04:08:19	2020-01-05	Bird Schulist	bird.schulist@geemail.com	San Francisco	California	3459456760731889	93ed05dd7512c735da51e5ff62141e0f	Mastercard	37.7838646126350497	-122.43212522677436
8596	2020-01-05 04:08:46	2020-01-05	Mame Trantow	mame.trantow@geemail.com	Phoenix	Arizona	4517651095021	f3316d4f58dd02feaf25a225db84c1a6	Diners Club / Carte Blanche	33.6275520815446995	-112.071080798555542
8597	2020-01-05 04:24:58	2020-01-05	Mozelle Beatty	mozelle.beatty@geemail.com	Aurora	Colorado	3096447987790469091	5a66fba0af66261735052bb54bf23915	Discover	39.7878018199577923	-104.675002634956314
8598	2020-01-05 05:38:22	2020-01-05	Patsy Luettgen	patsy.luettgen@geemail.com	Berkeley	California	6011694955183460324	c9bca41b865c5fa289f4c7bcddb3deaa	VISA 13 digit	37.8826956222422666	-122.270355836559517
8599	2020-01-05 05:47:46	2020-01-05	Lillard Champlin	lillard.champlin@geemail.com	Amarillo	Texas	6011952717395006155	b38f62d02ea573bc601a6454ccf3b1be	Maestro	35.2254635630339408	-101.892386137121179
8600	2020-01-05 05:47:48	2020-01-05	Carley Ritchie	carley.ritchie@geemail.com	Los Angeles	California	210035256153781049	dc670384d21f27d5d7a42675351a4b21	Discover	34.0875696372106631	-118.361421891906474
8601	2020-01-05 05:54:48	2020-01-05	Dr. Ewell Schulist	dr.ewell.schulist@geemail.com	Fayetteville	North Carolina	3793328604466147	a3914bfb66ba0bf858ac848adde0157e	Diners Club / Carte Blanche	35.0008358581710581	-78.9499733622316313
8602	2020-01-05 06:29:43	2020-01-05	Gabriel Pouros-Monahan	gabriel.pouros.monahan@geemail.com	Memphis	Tennessee	869982686429591198	1502d3f432d320f72b765dc6f5aa5697	Voyager	35.0381805656079237	-90.013567712928733
8603	2020-01-05 06:51:40	2020-01-05	Chaka Greenholt	chaka.greenholt@woohoo.com	Milwaukee	Wisconsin	3337915764999556553	975ebf9e89926e5f7f2c5dedd00521ae	Discover	43.1251129873648296	-87.8829689481396201
8604	2020-01-05 06:55:28	2020-01-05	Len Russel	len.russel@geemail.com	Chicago	Illinois	210004043778201869	5038676d10f18a752a5e2593adcd34d1	JCB 16 digit	41.7825351846706141	-87.7769449260581212
8605	2020-01-05 06:56:14	2020-01-05	Kiara Turcotte DDS	kiara.turcotte.dds@geemail.com	New York	New York	3096057988589582137	e1779af62aca9223e1b5941b685ea69a	VISA 16 digit	40.5689029587656265	-74.0027703118406208
8606	2020-01-05 06:57:11	2020-01-05	Allyssa Kulas DVM	allyssa.kulas.dvm@geemail.com	Dayton	Ohio	54686449275525889	4ce04de3cf5053e6a75fb44831fc0ab5	Maestro	39.8070366177499295	-84.2420963552039126
8607	2020-01-05 06:57:49	2020-01-05	Hartwell Eichmann	hartwell.eichmann@geemail.com	Oakland	California	3112879531123572473	cd6c6b0955fafecaa74cf9b5320e1ced	Mastercard	37.8161229836600157	-122.263039305777284
8608	2020-01-05 06:59:45	2020-01-05	Dr. Sophie Herman	dr.sophie.herman@warmmail.com	Philadelphia	Pennsylvania	6011819161575927950	b91fb1f5e383dda072628510c5cc5401	Diners Club / Carte Blanche	40.0067366518039265	-75.2208850100070237
8609	2020-01-05 07:06:18	2020-01-05	Butler Crist	butler.crist@geemail.com	San Francisco	California	4862192796338038	4d02210a7ad2a3e4cf2ad6558e891bb1	Maestro	37.7819609391279556	-122.399610800355916
8610	2020-01-05 08:38:28	2020-01-05	Maddox Kessler	maddox.kessler@woohoo.com	Berkeley	California	3055221053629272	9cebf1af6a304466fbd2e15c1d260a08	JCB 16 digit	37.8766700520103399	-122.265412984890148
8611	2020-01-05 08:51:59	2020-01-05	Marchello Bogan	marchello.bogan@woohoo.com	San Francisco	California	675963684266552	31d1b7559e07c2ef7953e2d51d6525f3	Maestro	37.788793958235928	-122.438276891145293
8612	2020-01-05 09:04:32	2020-01-05	Casandra Abernathy	casandra.abernathy@geemail.com	Dallas	Texas	869993335070640436	0501abf8eaa44e7f6b0e9c455358ca22	VISA 16 digit	32.6982752956256277	-96.7777461118958797
8613	2020-01-05 09:35:27	2020-01-05	Ryne Breitenberg-Emard	ryne.breitenberg.emard@geemail.com	Anaheim	California	869998091046371524	73cf1c654f9508fd715377f1a67e50d3	JCB 16 digit	33.9099868679717176	-117.820450570641455
8614	2020-01-05 10:01:58	2020-01-05	Milda Cremin	milda.cremin@geemail.com	New York	New York	561288621979017	9f75c14b7ce1e1a64eeb806f4b21dc5b	Mastercard	40.7388319581504916	-73.9867002441443447
8615	2020-01-05 10:36:33	2020-01-05	Shanon Lynch	shanon.lynch@geemail.com	Bridgeport	Connecticut	869976205286806843	4aabd613cba4b7aa54163cdf163ec9a5	Mastercard	41.1393485909026069	-73.1739688620802013
8616	2020-01-05 10:38:16	2020-01-05	Marcel Bins	marcel.bins@geemail.com	Chicago	Illinois	180011747282336018	647c49d14e6013daf59e90b1c9a5bc5b	American Express	41.8029111110907081	-87.6361576729483858
8617	2020-01-05 10:41:19	2020-01-05	Wanita Mayert PhD	wanita.mayert.phd@warmmail.com	San Francisco	California	3055312260618388	14ac457c6dad0b7f34a8892b18771235	JCB 15 digit	37.7364005600259347	-122.412559402049283
8618	2020-01-05 10:53:24	2020-01-05	Dr. Hans Turcotte I	dr.hans.turcotte.i@warmmail.com	San Francisco	California	4783433586959237	460995c1c4e1b7cbc996d44215d78082	JCB 16 digit	37.753872503888303	-122.417402623349972
8619	2020-01-05 11:01:51	2020-01-05	Dr. Josephus Cremin PhD	dr.josephus.cremin.phd@geemail.com	Knoxville	Tennessee	869980144387093486	ae5c993bab459bfed76eb1eecc06921f	JCB 16 digit	35.9106523353669829	-84.0459862946748615
8620	2020-01-05 11:14:29	2020-01-05	Renee Skiles	renee.skiles@woohoo.com	San Francisco	California	4703241807295225	7164a090c95d74066ba96e5672abe8b0	JCB 16 digit	37.7778618787473732	-122.442603131182253
8621	2020-01-05 11:24:05	2020-01-05	Nery Zboncak V	nery.zboncak.v@warmmail.com	Indianapolis	Indiana	180037705854848422	d3819cc1a1db00966108392e685aba1d	VISA 16 digit	39.8755266324158768	-86.1172773405179299
8622	2020-01-05 11:37:11	2020-01-05	Dr. Edwin McLaughlin	dr.edwin.mclaughlin@geemail.com	Louisville	Kentucky	3035319446077165	a9354e8c2eea4cf7b45c1a6902205ccf	JCB 16 digit	38.1665983920820011	-85.6561186776567354
8623	2020-01-05 11:49:50	2020-01-05	Audrina Treutel	audrina.treutel@geemail.com	San Francisco	California	3088619895853962864	672a6b66503402802ed1d5a5f46746db	JCB 15 digit	37.783166197440579	-122.426244828481089
8624	2020-01-05 12:10:04	2020-01-05	Davante Hahn	davante.hahn@geemail.com	Colorado Springs	Colorado	53289232206510365	3d12dec0e3af80fd4222f4366e8a27ec	Diners Club / Carte Blanche	38.9576711293358358	-104.769731083248558
8625	2020-01-05 13:13:30	2020-01-05	Mr. Lafe Hintz PhD	mr.lafe.hintz.phd@geemail.com	San Francisco	California	210070401903006570	4076de03644b2ce2079f963388521c6f	VISA 13 digit	37.7684863653634011	-122.414205311325759
8626	2020-01-05 13:18:14	2020-01-05	Deangelo Hoeger Sr.	deangelo.hoeger.sr.@geemail.com	Fremont	California	6011060956626083703	815bdaef2f0c8d8b0f8a0803cd7a685b	JCB 16 digit	37.5365257082208998	-121.995133122847221
8627	2020-01-05 13:38:20	2020-01-05	Miss Brinley Macejkovic	miss.brinley.macejkovic@geemail.com	Los Angeles	California	3096403424919788955	6b6bc1a7041a5eb9bfef5e06c393edce	VISA 13 digit	34.0352375897444759	-118.436005201888449
8628	2020-01-05 14:18:51	2020-01-05	Rodney Lebsack	rodney.lebsack@geemail.com	New York	New York	869968011544605989	2e6f58a6afd400b51a37015169497fd9	JCB 16 digit	40.6277969117034203	-73.8515164520021443
8629	2020-01-05 14:36:03	2020-01-05	Donnell Leffler	donnell.leffler@geemail.com	San Francisco	California	4125169118622003	3de336fba23cb8edc1fd62dec7fceb42	VISA 13 digit	37.7205695573160398	-122.45128987295297
8630	2020-01-05 14:55:59	2020-01-05	Kate Goodwin	kate.goodwin@woohoo.com	Modesto	California	869958050039347659	11b81044bb86e91a9b8b5d77d20ef1aa	Maestro	37.5974518216215117	-121.007446577420453
8631	2020-01-05 14:56:08	2020-01-05	Orren O'Keefe	orren.o'keefe@geemail.com	Dallas	Texas	3528584890599648696	5baeafd30875c15e2cc48c119409ecc2	American Express	32.7646657326065025	-96.7622624869886749
8632	2020-01-05 15:07:32	2020-01-05	Arther Okuneva	arther.okuneva@warmmail.com	San Francisco	California	3040717183711141	9037d4d15f7c61921d02f3ab4cdd4277	VISA 16 digit	37.7677402350153173	-122.440043015844282
8633	2020-01-05 15:14:38	2020-01-05	Camille Sporer PhD	camille.sporer.phd@geemail.com	Anaheim	California	503809666913232	d1d1595c5374560b89758d73526897c6	Diners Club / Carte Blanche	33.8257468495350295	-117.790911099009577
8634	2020-01-05 15:18:35	2020-01-05	Ms. Sheree Goldner DVM	ms.sheree.goldner.dvm@geemail.com	Miramar	Florida	3112579014221562731	54430c0602ade9edfdccc2e4e5c8146d	Mastercard	25.8864446871429692	-80.3826954485375467
8635	2020-01-05 15:35:02	2020-01-05	Dimple Jones	dimple.jones@geemail.com	Albuquerque	New Mexico	4873476099284412	11131e93ad8140acc8c29cf4acd6d16b	Mastercard	35.1234574629593652	-106.590851539287343
8636	2020-01-05 15:52:34	2020-01-05	Cammie Stoltenberg	cammie.stoltenberg@geemail.com	Norfolk	Virginia	3031942425762376	8c4736d3896aa0358c2c57022f796768	VISA 16 digit	36.8694400155004161	-76.2306779481474308
8637	2020-01-05 15:57:17	2020-01-05	Pinkney Trantow	pinkney.trantow@geemail.com	Oakland	California	4187617794998837	c2abd65b7c6955b7f6a08e5b643a9384	JCB 15 digit	37.806118786128792	-122.305522927600492
8638	2020-01-05 15:57:40	2020-01-05	Leticia Christiansen-Durgan	leticia.christiansen.durgan@geemail.com	San Francisco	California	3528199041156481504	bed29d1d8793b4f7807f9c569fae4620	Mastercard	37.7564406780264221	-122.400976147272829
8639	2020-01-05 16:10:45	2020-01-05	Debbi Brekke	debbi.brekke@geemail.com	Bellevue	Washington	4119722187179285	2010c1b3eb5b353ca0c2920cf1a96061	JCB 15 digit	47.6047703976925476	-122.227375300094479
8640	2020-01-05 16:26:13	2020-01-05	Mrs. Nathalie Kuphal	mrs.nathalie.kuphal@woohoo.com	San Francisco	California	4487340154706	598f4d6015491d261303d8540fbf53f7	Discover	37.7652141312169292	-122.449202478534815
8641	2020-01-05 16:56:32	2020-01-05	Sigrid Stark MD	sigrid.stark.md@woohoo.com	New York	New York	6011172282068545041	f204b63b28b2a057b0a43301b366a211	JCB 16 digit	40.721118733495473	-73.8771948655031565
8642	2020-01-05 17:06:41	2020-01-05	Yahir Considine-Veum	yahir.considine.veum@geemail.com	Indianapolis	Indiana	869955142638490577	aa046caaf1e52ded14ccb4b9feb816ea	JCB 16 digit	39.7996149834718551	-86.1048589562732758
8643	2020-01-05 18:15:15	2020-01-05	Coletta Nitzsche	coletta.nitzsche@geemail.com	Santa Maria	California	4378573061041	6f99577eaa17c6fd9a229abbbf4ab210	VISA 16 digit	35.0229606226149954	-120.5336398343008
8644	2020-01-05 18:27:35	2020-01-05	Mrs. Estelle Moore DVM	mrs.estelle.moore.dvm@woohoo.com	Phoenix	Arizona	3474331971745732	c4cc519e07dd9928201cc066de0b7d7e	Discover	33.480871359345322	-112.098018320177133
8645	2020-01-05 18:56:47	2020-01-05	Germaine Leannon	germaine.leannon@warmmail.com	Boise	Idaho	3048825265507162	f817ce8da4f4a9f63779729fc11b93a8	Mastercard	43.5638671771761068	-116.297593243672324
8646	2020-01-05 19:24:46	2020-01-05	Leora Sipes MD	leora.sipes.md@geemail.com	Richmond	Virginia	180082180060112001	83e03848948a638a1dba0765d9ae4448	Diners Club / Carte Blanche	37.4565984885893712	-77.4359544384982428
8647	2020-01-05 19:31:22	2020-01-05	Meyer Schaden	meyer.schaden@geemail.com	San Francisco	California	4144036631261	45e6f7317c0e468193cf61a3bd944ece	Diners Club / Carte Blanche	37.7757776699002008	-122.455094905800109
8648	2020-01-05 19:57:52	2020-01-05	Omie Reilly	omie.reilly@woohoo.com	Chesapeake	Virginia	3337619338700239533	1bed04a9ded3b7bc10f1b3f8e3bc7ca0	JCB 16 digit	36.6810029036138232	-76.3687894698541641
8649	2020-01-05 19:59:42	2020-01-05	Ms. Pearlene VonRueden	ms.pearlene.vonrueden@woohoo.com	Lubbock	Texas	4929020145688483	2a56bcdac984825edb34f4627c6c3874	JCB 16 digit	33.4883605598047396	-101.83902121068985
8650	2020-01-05 20:28:39	2020-01-05	Ms. Luda Mosciski MD	ms.luda.mosciski.md@warmmail.com	Milwaukee	Wisconsin	180055917208895408	73510abecfbfcf0d5157e5fa0cf6f68a	JCB 16 digit	43.0086702987637324	-87.8721443657863972
8651	2020-01-05 20:40:58	2020-01-05	Giles Von	giles.von@geemail.com	Garden Grove	California	869976883817378126	a716fd79d8b6ecd838142fddc745e659	Voyager	33.7514188565604343	-117.964077249823134
8652	2020-01-05 20:53:43	2020-01-05	Mr. Colton Fisher MD	mr.colton.fisher.md@woohoo.com	Oakland	California	54109753143114191	31d9896ebe0b606efaa41e90c477cf84	Diners Club / Carte Blanche	37.7952021999720031	-122.308347560807363
8653	2020-01-05 21:07:04	2020-01-05	Jane Kuvalis	jane.kuvalis@geemail.com	Miami	Florida	4882835899586103	edb16d44436c4c5d27ea3d4004b91987	Voyager	25.8719105507850671	-80.1681376074779877
8654	2020-01-05 21:33:57	2020-01-05	Elwyn Renner	elwyn.renner@warmmail.com	Miami	Florida	210081631959865647	7d66ee658b6501f0198f9c50ef0276ae	JCB 15 digit	25.834116360791775	-80.1397433996539661
8655	2020-01-05 21:46:14	2020-01-05	Mrs. Brittney Kuhlman DVM	mrs.brittney.kuhlman.dvm@geemail.com	San Francisco	California	6011265836802153350	c6cf3a572495c73c936d425934ef0e66	VISA 13 digit	37.7547550286799378	-122.431334592390371
8656	2020-01-05 22:09:31	2020-01-05	Kylie Braun	kylie.braun@woohoo.com	Berkeley	California	4395757147671299	94af07769e10a1eef60128827a6efba1	American Express	37.8697625043222104	-122.28603685719834
8657	2020-01-05 22:17:11	2020-01-05	Dr. Sanford Schaden	dr.sanford.schaden@geemail.com	Oakland	California	180015796330303450	a3df3e91b55c51853da3fea5f0a975c0	Discover	37.7948309244915848	-122.282696354344267
8658	2020-01-05 22:25:49	2020-01-05	Mr. Oren Botsford MD	mr.oren.botsford.md@geemail.com	San Francisco	California	3021138277336431	a42a3b5a8247cb432a22af20aba07ce2	Diners Club / Carte Blanche	37.7458796407120687	-122.410818614185416
8659	2020-01-05 22:30:48	2020-01-05	Lera Dooley	lera.dooley@warmmail.com	Phoenix	Arizona	3112573066414358802	508fcb9b5ea3a44a07ebc3acafc54ff1	VISA 13 digit	33.5747403579231403	-112.103543651469437
8660	2020-01-05 22:36:22	2020-01-05	Genie Lakin	genie.lakin@geemail.com	New York	New York	4688164870794701	0c26f239898e0631c046d1346d806c33	VISA 13 digit	40.633464253623039	-73.8751884151145788
8661	2020-01-05 22:41:23	2020-01-05	Eunice Mosciski	eunice.mosciski@geemail.com	Newark	New Jersey	4779390423138159	60f7fe2ebfd5900834836eccc5e1a738	VISA 16 digit	40.7004414987664731	-74.1378997326571465
8662	2020-01-05 22:50:29	2020-01-05	Faustino Koepp	faustino.koepp@geemail.com	Dayton	Ohio	6011586084791235852	8ebb051d4ceb4d4cfb4cf55521149a77	Discover	39.8171345452569412	-84.1578531297579389
8663	2020-01-05 23:09:43	2020-01-05	Lavar Jacobs	lavar.jacobs@geemail.com	Rochester	Minnesota	630452377068748	74332729cce32455ed56cf18d4a6f8d0	Diners Club / Carte Blanche	44.018111332356554	-92.4602372856464143
8664	2020-01-05 23:22:09	2020-01-05	Odessa Smitham	odessa.smitham@geemail.com	San Diego	California	4453891778564520	3d0fefdfc3c72f8445b157d3967e5a27	Mastercard	32.7934301767565302	-117.063796367067852
8665	2020-01-05 23:25:51	2020-01-05	Weldon Metz	weldon.metz@geemail.com	New York	New York	639036846023582	bb8fdb045ccf828c0cac414ec136e3e3	JCB 15 digit	40.7357843846306196	-74.0032814946386992
8666	2020-01-05 23:28:51	2020-01-05	Mrs. Bobbie Heathcote PhD	mrs.bobbie.heathcote.phd@geemail.com	Berkeley	California	6011551584234785133	fb5ef18d47297704e7dc7844fb5d9c3e	Discover	37.8919543025196006	-122.298407886632049
8667	2020-01-05 23:47:23	2020-01-05	Lucy Marquardt	lucy.marquardt@geemail.com	Miami	Florida	54560657145200688	9516a4cfad64a103995528e376a44831	Diners Club / Carte Blanche	25.7344385270632827	-80.223420653805519
8668	2020-01-05 23:54:30	2020-01-05	Jon Abbott	jon.abbott@geemail.com	San Francisco	California	869988385789704046	c4effad4bb56435505f1958794107447	JCB 15 digit	37.7511976837744854	-122.436652699332981
8669	2020-01-06 01:47:43	2020-01-06	Jeramy Pfeffer	jeramy.pfeffer@geemail.com	Tampa	Florida	4627578838112	b9bac0d77714156e3dd76d3784fa61c4	JCB 15 digit	27.915125917934251	-82.5475735912777395
8670	2020-01-06 02:31:10	2020-01-06	Franz Zieme-Kessler	franz.zieme.kessler@warmmail.com	San Francisco	California	3528215393203799010	579fa8f460c2096e7c66a0dad3ad7e18	VISA 16 digit	37.7677765215931629	-122.4436919640345
8671	2020-01-06 02:31:23	2020-01-06	Metta Dibbert MD	metta.dibbert.md@warmmail.com	New York	New York	503831195306076	7cfa258cd74d1f80bd0b8006b74567a5	Discover	40.6437122065331806	-73.951093446872008
8672	2020-01-06 02:36:19	2020-01-06	Isom Jacobi	isom.jacobi@geemail.com	New York	New York	4215316311509	64e56e40a5f16db339606de6fdd899b5	Voyager	40.5663617055155328	-73.9623984320450489
8673	2020-01-06 02:41:29	2020-01-06	Tye McLaughlin	tye.mclaughlin@geemail.com	San Francisco	California	6011874205723924518	83d72977c71d5835f548c05b61f5f421	JCB 15 digit	37.7868765263849511	-122.397596265678558
8674	2020-01-06 02:43:32	2020-01-06	Earlie Keebler	earlie.keebler@geemail.com	College Station	Texas	3337563769458285458	a0da7d1d90c14697910ab8d655836dfd	VISA 16 digit	30.5892946272667494	-96.2881303001042568
8675	2020-01-06 02:46:40	2020-01-06	Kennth Glover	kennth.glover@geemail.com	Indianapolis	Indiana	3047156740655876	f5603ff264f55b0316ce5cc83d5421c2	JCB 16 digit	39.8668558994315561	-86.1357652717005493
8676	2020-01-06 03:15:10	2020-01-06	Miss Jaylyn Nitzsche PhD	miss.jaylyn.nitzsche.phd@geemail.com	Albuquerque	New Mexico	4899956080833053	d26611d424f999a4471f3b74c8abb236	JCB 16 digit	35.0218751843687173	-106.660598118610309
8677	2020-01-06 03:59:36	2020-01-06	Dr. Theda Robel	dr.theda.robel@warmmail.com	Daly City	California	51286289505946180	e888236ee7b2c430a9e06954fab0f8d1	JCB 16 digit	37.6749687844343484	-122.562586359037084
8678	2020-01-06 04:11:16	2020-01-06	Kailey Block-Morar	kailey.block.morar@woohoo.com	San Francisco	California	869926009758599238	04f1ee4c26e1dc650a5067c155ca82d5	Discover	37.7858244671858756	-122.408823083690791
8679	2020-01-06 04:12:36	2020-01-06	Mr. Isaak Herzog	mr.isaak.herzog@geemail.com	San Francisco	California	3419495046539558	6dad651cece5aa60e9ef3c3385c029ac	Diners Club / Carte Blanche	37.7431089217638061	-122.431385169815499
8680	2020-01-06 04:17:50	2020-01-06	Gifford Renner	gifford.renner@geemail.com	Cambridge	Massachusetts	53659834288370477	a40bbddec53eec32609b31e478844d83	Mastercard	42.3747451831344506	-71.1210748114239522
8681	2020-01-06 04:28:50	2020-01-06	Brenden VonRueden	brenden.vonrueden@woohoo.com	Berkeley	California	3528608386748277208	831412651b8ee961cb2fd1fb670af2ff	Mastercard	37.8943571055598767	-122.27489860410067
8682	2020-01-06 04:32:16	2020-01-06	Ms. Diamond Kris	ms.diamond.kris@geemail.com	Fontana	California	52154050539796317	5161adb58019d0c5f5ce27f0cef3e715	JCB 16 digit	34.0539852997437151	-117.421498305936908
8683	2020-01-06 05:02:05	2020-01-06	Rilla Boyle	rilla.boyle@geemail.com	Phoenix	Arizona	4362021436393	0a896d93c8018456f50f1832fa5387ff	JCB 16 digit	33.5453108149979258	-112.031139878362794
8684	2020-01-06 05:10:56	2020-01-06	Clovis Graham	clovis.graham@geemail.com	Cincinnati	Ohio	3088391910798671241	6b1268d92dd1802f0f8380e3f76dbaed	JCB 15 digit	39.2388333277076455	-84.5083484023149936
8685	2020-01-06 05:11:57	2020-01-06	Carrie McLaughlin	carrie.mclaughlin@warmmail.com	Indianapolis	Indiana	589368416258934	556113fbdb6deef30a32f2ad6b1e4a46	Mastercard	39.7725154032938164	-86.1398995955675844
8686	2020-01-06 05:19:08	2020-01-06	Britta Bogisich	britta.bogisich@woohoo.com	Montgomery	Alabama	4356844062709762	6195fa7b73f8c6134abcae352f22dee0	Diners Club / Carte Blanche	32.2885746864534937	-86.324016260370982
8687	2020-01-06 05:47:20	2020-01-06	Samie Bartoletti-Welch	samie.bartoletti.welch@geemail.com	Fort Worth	Texas	3002990755548583	af9764e1b45b9ca8fedf069936883bc5	Mastercard	32.7665138759240548	-97.4117398487690878
8688	2020-01-06 05:56:04	2020-01-06	Clayton Glover-Hoeger	clayton.glover.hoeger@geemail.com	San Francisco	California	630475288693445	ddaf2476b53a93748872d49d3a54a52b	VISA 16 digit	37.7664344715917437	-122.471583025289476
8689	2020-01-06 06:14:43	2020-01-06	Shonda Bahringer	shonda.bahringer@geemail.com	Los Angeles	California	53516087436237410	21017bd9b1d039c8d8900a80b15e0f48	Mastercard	34.1160144130565186	-118.453830830658973
8690	2020-01-06 06:16:29	2020-01-06	Meggan Rice PhD	meggan.rice.phd@geemail.com	Portland	Oregon	3158795726703070234	324b8c8a8527aae32918588c65c1b92b	VISA 16 digit	45.5776295159366001	-122.702105093421423
8691	2020-01-06 06:22:31	2020-01-06	Dennie Balistreri	dennie.balistreri@warmmail.com	Fort Worth	Texas	869903158266841975	f78ad4ba77eb5e586cab6341a95e49ad	JCB 16 digit	32.6864775171559288	-97.2480442479539704
8692	2020-01-06 06:55:38	2020-01-06	Dr. Sasha Doyle PhD	dr.sasha.doyle.phd@geemail.com	Little Rock	Arkansas	630400611995150	8d0c9810b1eafae3b026346d73703b71	JCB 16 digit	34.796454071513935	-92.4286797124765798
8693	2020-01-06 06:58:11	2020-01-06	Vicky Bayer DDS	vicky.bayer.dds@geemail.com	San Francisco	California	210014570433048838	2b8e45e1612fad50045505d96c4c7475	Diners Club / Carte Blanche	37.766150679083907	-122.45423749739723
8694	2020-01-06 07:18:18	2020-01-06	Mrs. Sherita Flatley DDS	mrs.sherita.flatley.dds@geemail.com	Ann Arbor	Michigan	869904419454046291	094ffb4d228265525a3ee61e7dd77c00	Voyager	42.2588705670148101	-83.638470323487752
8695	2020-01-06 07:20:43	2020-01-06	Max Bailey	max.bailey@woohoo.com	New York	New York	3785747597726979	535f5352dc14058ab328034eb421bf7b	VISA 16 digit	40.5851350550297667	-73.9203199348773836
8696	2020-01-06 07:29:25	2020-01-06	Tatyanna Berge-Harber	tatyanna.berge.harber@woohoo.com	Buffalo	New York	3480988454863605	5fdf7bb5902b0eae819ab84acf650c3e	VISA 13 digit	42.8578110922314224	-78.9369532840259467
8697	2020-01-06 07:35:39	2020-01-06	Fabiola Pollich	fabiola.pollich@geemail.com	Portland	Oregon	3026467392482381	ba34942214330a0ebc95a089fefb7f15	Mastercard	45.5141295933518535	-122.629927453631538
8698	2020-01-06 07:36:15	2020-01-06	Evie Carter	evie.carter@warmmail.com	Jacksonville	Florida	3088472611040771936	19c7e77418b20d01263b76f3ed1a013a	JCB 16 digit	30.2645665944140418	-81.6216433348212433
8699	2020-01-06 08:44:22	2020-01-06	Concha Maggio	concha.maggio@geemail.com	Nashville	Tennessee	4137759892470649	a490c6befbb59eddf4f5c3764e249fb3	Discover	36.271245560341697	-86.6947034506034129
8700	2020-01-06 09:01:35	2020-01-06	Debra Reilly	debra.reilly@geemail.com	San Francisco	California	4831654397585	28201b2268f5274bb66e3b662b5f0704	JCB 15 digit	37.7835384536396006	-122.426036105080541
8701	2020-01-06 09:56:04	2020-01-06	Mr. Drury O'Conner II	mr.drury.o'conner.ii@geemail.com	New York	New York	52662362494291837	b04704da5f822ea8c507a7fec4a100f5	Discover	40.7476556043364084	-73.8602105804614695
8702	2020-01-06 10:00:53	2020-01-06	Mr. Sharif Beier Sr.	mr.sharif.beier.sr.@warmmail.com	Fort Collins	Colorado	4072446126558	c5653888ae97f852c15a8ee60d5e666c	Maestro	40.4531615257419688	-105.091625839374217
8703	2020-01-06 10:15:52	2020-01-06	Rupert Hyatt	rupert.hyatt@geemail.com	Mesquite	Texas	4702216312222303	91dcb685c8f6ec6b38ce98c3b1b84424	VISA 16 digit	32.7818732292667079	-96.5863603294093167
8704	2020-01-06 10:26:15	2020-01-06	Alberta Reinger-Deckow	alberta.reinger.deckow@geemail.com	Virginia Beach	Virginia	210090761744085174	4d862f8b8127bf8778dfe68a5fffeec6	VISA 16 digit	36.8564851234853279	-76.0620484283797396
8705	2020-01-06 10:32:03	2020-01-06	Mr. Cristian Predovic	mr.cristian.predovic@geemail.com	Richmond	Virginia	4423335775023	71b94c1504989bedbd8084700ad9127e	VISA 13 digit	37.5254848930738873	-77.4922439976818822
8706	2020-01-06 10:35:54	2020-01-06	Geo Cremin	geo.cremin@geemail.com	San Francisco	California	3776448337042238	93fbd285dd7a9b5b5f668da7e31c74a1	VISA 13 digit	37.7763201887512494	-122.388191098240569
8707	2020-01-06 11:21:48	2020-01-06	Tonda Witting	tonda.witting@warmmail.com	Houston	Texas	51108899124479516	ec66604cc32a75d7fda8840643cf8805	Discover	29.845237021295727	-95.4450734358761537
8708	2020-01-06 11:44:00	2020-01-06	Mr. Hughey Spencer	mr.hughey.spencer@geemail.com	Denver	Colorado	3015311581254113	54adf37d0a1c1e4106690b9c1b6ded68	Diners Club / Carte Blanche	39.6809043428912744	-104.875023880252996
8709	2020-01-06 11:53:37	2020-01-06	Miss Bula Goodwin DDS	miss.bula.goodwin.dds@geemail.com	Louisville	Kentucky	3026607551892835	ec57211219fdd50078ef8f6fcc31af40	VISA 16 digit	38.2101546876501246	-85.6055071191933052
8710	2020-01-06 12:01:37	2020-01-06	Mr. Nikko Miller IV	mr.nikko.miller.iv@geemail.com	Lubbock	Texas	3158792626969812340	499055f7f1b37301c002439481ef1f59	VISA 16 digit	33.6652953401248922	-101.904166187383979
8711	2020-01-06 12:03:47	2020-01-06	Miss Classie Skiles MD	miss.classie.skiles.md@geemail.com	Dallas	Texas	3041393957634569	5d16fbcc41b6b77a7384ddae4170d7e4	American Express	32.738926280317088	-96.6689090712424246
8712	2020-01-06 12:40:02	2020-01-06	Fronia Kshlerin-Blick	fronia.kshlerin.blick@geemail.com	Berkeley	California	4284168560976112	267e54f50933960113e4d730d59a2d38	VISA 16 digit	37.9065708908092205	-122.270661019971897
8713	2020-01-06 14:12:26	2020-01-06	Lilyana Kulas PhD	lilyana.kulas.phd@geemail.com	Boston	Massachusetts	869938606933605321	1c93489954873ff854c9b7d88a492b55	VISA 16 digit	42.3049952684137978	-70.9544572262510655
8714	2020-01-06 14:21:53	2020-01-06	Mable Larson	mable.larson@woohoo.com	Jacksonville	Florida	3443344425929321	c8f29b37972cd3f5595126b4831ac3f8	JCB 16 digit	30.3186819272167973	-81.5989405194375763
8715	2020-01-06 14:31:57	2020-01-06	Miss Elizebeth Fritsch	miss.elizebeth.fritsch@geemail.com	Los Angeles	California	180001998202102269	80be6bf7cd032a5e580af54b3d4751aa	VISA 13 digit	34.0564396791491646	-118.341840095118798
8716	2020-01-06 14:33:11	2020-01-06	Lori Dare	lori.dare@geemail.com	Berkeley	California	4936893790035	007ea0eaa2715db63892c5ec1391d638	JCB 16 digit	37.8573793603138142	-122.23869307882957
8717	2020-01-06 14:37:52	2020-01-06	Ms. Fairy Mraz	ms.fairy.mraz@geemail.com	Fremont	California	503843870230919	49e349aaf9840d46b69cd386b7443e1e	VISA 16 digit	37.5571175423152752	-122.009793033263449
8718	2020-01-06 15:07:44	2020-01-06	Violet Stanton	violet.stanton@geemail.com	Warren	Michigan	4749050673029535	c59eee8da6d7c4261ce3c7263bd847e7	JCB 16 digit	42.450892947893216	-82.9649534867610896
8719	2020-01-06 15:22:42	2020-01-06	Kayla Kuhn-White	kayla.kuhn.white@woohoo.com	Oakland	California	6011597891407465997	4aa9811d47b2ea6f5642fc4ec8f5d301	American Express	37.8173747755872824	-122.242698104852209
8720	2020-01-06 15:31:15	2020-01-06	Dr. Jethro Romaguera IV	dr.jethro.romaguera.iv@geemail.com	San Francisco	California	4698396594971359	8f5362a4c6c4df463b01647e07a06ff6	JCB 16 digit	37.7643226748045819	-122.464729502157141
8721	2020-01-06 15:39:04	2020-01-06	Ms. Maebelle Medhurst	ms.maebelle.medhurst@geemail.com	Oakland	California	869967743182214606	5ebd596e1adedb7a26633af4e63f660b	JCB 16 digit	37.8391697016533612	-122.271820541423324
8722	2020-01-06 16:24:13	2020-01-06	Johney Cruickshank	johney.cruickshank@geemail.com	Bellevue	Washington	3486362757089751	ed2d34a4ad8a66a43b32ff842016b861	Maestro	47.5636028372399551	-122.190636682376265
8723	2020-01-06 16:54:47	2020-01-06	Mr. Darcy Gibson III	mr.darcy.gibson.iii@geemail.com	Jackson	Mississippi	180098873835953327	1f09bd512db47260830328507e996678	Voyager	32.4143833577346072	-90.1818777370240525
8724	2020-01-06 17:50:26	2020-01-06	Mr. Mearl Smith	mr.mearl.smith@warmmail.com	Nashville	Tennessee	51806274031650762	5ae98924f17592a486b5592063debd13	JCB 16 digit	36.1164680512279261	-86.7328155975230004
8725	2020-01-06 18:29:46	2020-01-06	Mrs. Kaitlynn Ebert MD	mrs.kaitlynn.ebert.md@geemail.com	Kansas City	Missouri	4724535813416815	27bf6757e92984abaeef901544c57235	Diners Club / Carte Blanche	39.1892846144106244	-94.5516574815604827
8726	2020-01-06 18:37:31	2020-01-06	Declan Baumbach	declan.baumbach@geemail.com	New York	New York	3337793023518082071	9a8123e6932eb6d2a75b34f2ffa15f79	JCB 16 digit	40.5930585059095179	-73.9479792059760541
8727	2020-01-06 18:45:19	2020-01-06	Kash Reichert	kash.reichert@woohoo.com	Jackson	Mississippi	3033416217117386	e95ab87ac34f422da223855c384d34c0	JCB 16 digit	32.2482352767318545	-90.2400220874205274
8728	2020-01-06 19:01:14	2020-01-06	Lota Barrows DDS	lota.barrows.dds@geemail.com	Santa Clara	California	3158040515283385879	f39661319e8e1d26755476d3bdaba97f	JCB 16 digit	37.2950574366193308	-121.887786501319709
8729	2020-01-06 19:11:28	2020-01-06	Addyson Hermann	addyson.hermann@geemail.com	Las Vegas	Nevada	502050585534600	beef112dcdcd4a627ab7f0fd7f4c6f86	Mastercard	36.2778735654994833	-115.255826671535516
8730	2020-01-06 19:25:22	2020-01-06	Aidan Lehner DVM	aidan.lehner.dvm@warmmail.com	San Francisco	California	3337168704339271517	e1696cb7ce03580837f95387735e48a7	Mastercard	37.7665733068117646	-122.409608195520619
8731	2020-01-06 19:52:46	2020-01-06	Mrs. Lauri Will	mrs.lauri.will@geemail.com	Austin	Texas	4820802161167	cfa3a5448a46b24351dc08f9926cbbf3	VISA 16 digit	30.2877576716370882	-97.7512115571886397
8732	2020-01-06 20:30:03	2020-01-06	Myer Leuschke	myer.leuschke@geemail.com	San Francisco	California	869961017044562049	96e936cf5669a9679d233765d1f2d1f3	Maestro	37.7828577027137484	-122.449808451134956
8733	2020-01-06 20:37:41	2020-01-06	Caddie Funk	caddie.funk@geemail.com	Orange	California	4443276762753714	d28eb6787985d2f1fe79ce3d4782b127	Diners Club / Carte Blanche	33.8481101912800213	-117.79896113473103
8734	2020-01-06 21:20:34	2020-01-06	Kala Hegmann	kala.hegmann@geemail.com	Minneapolis	Minnesota	4392349117656	a330702477b8ddf0c710ee28bdd32ae7	American Express	44.9053303585473387	-93.2396557493872962
8735	2020-01-06 21:20:51	2020-01-06	Terri Rath	terri.rath@geemail.com	Jacksonville	Florida	3018492536396048	7fe1a11b2d178f9b4b5b80d62064853f	JCB 16 digit	30.3025587819568827	-81.6653389415316298
8736	2020-01-06 21:27:32	2020-01-06	Versa Larkin	versa.larkin@geemail.com	Houston	Texas	676157181086448	6c46a6ec78fdbdafd4db5744592d6d7b	Mastercard	29.7195093093518174	-95.4787756204620024
8737	2020-01-06 21:30:12	2020-01-06	Margarete Lynch	margarete.lynch@geemail.com	Amarillo	Texas	4458251527813980	15c3fde1305b8e6cb74edd854703ef38	JCB 16 digit	35.2505298732478138	-101.916544137089332
8738	2020-01-06 21:36:47	2020-01-06	Ms. Madisyn Buckridge DDS	ms.madisyn.buckridge.dds@geemail.com	Atlanta	Georgia	4603955162458364	cd2de5e445fba1536164f080d53dcf27	Discover	33.7530632471941416	-84.3899309544868856
8739	2020-01-06 22:08:05	2020-01-06	Brantley Quigley MD	brantley.quigley.md@geemail.com	San Francisco	California	869907444441196956	230785b7aecbaf635bfd3ab2bd8abfba	American Express	37.7628411350171334	-122.40660976784072
8740	2020-01-06 22:10:39	2020-01-06	Gertrude Wolff	gertrude.wolff@geemail.com	Los Angeles	California	869906074153352744	64374c0ab174d7fa11d88809a341d6f3	JCB 16 digit	33.9922795506060069	-118.35895127956681
8741	2020-01-06 22:20:25	2020-01-06	Elmire Wuckert DDS	elmire.wuckert.dds@geemail.com	Houston	Texas	3013310017878752	5b6434ebc8be4c82a92cf43c52a3ae50	JCB 16 digit	29.7704577387388802	-95.4733930770322701
8742	2020-01-06 22:44:16	2020-01-06	Raul Bashirian	raul.bashirian@geemail.com	Baltimore	Maryland	3045987127724626	5c45cc31545ad47d9578b30ce447ca69	Discover	39.2148689691908601	-76.6925943693630359
8743	2020-01-06 22:53:05	2020-01-06	Claribel Lesch	claribel.lesch@woohoo.com	Berkeley	California	3715758031007111	6acda58000002c292a8ac6d3141ca496	VISA 16 digit	37.8721932390931286	-122.294408369985504
8744	2020-01-06 23:02:42	2020-01-06	Mr. Stoney Ward	mr.stoney.ward@geemail.com	Philadelphia	Pennsylvania	3754793215779625	b9cff3736092d90f671a22dd1150c5a6	Voyager	39.9262835306074493	-75.1554176086925025
8745	2020-01-06 23:26:02	2020-01-06	Ricki Zboncak	ricki.zboncak@geemail.com	Lancaster	California	869948905607284019	a75aa5294173050912849e9e7e9959a5	VISA 16 digit	34.6349523925934051	-118.185836071890961
8746	2020-01-06 23:42:49	2020-01-06	Timmie Halvorson DVM	timmie.halvorson.dvm@geemail.com	San Francisco	California	52369863783197615	ee23311bf1e28fe9586acbd82ba1dab6	JCB 15 digit	37.7544518170715051	-122.456597449978787
8747	2020-01-06 23:42:58	2020-01-06	Grisel Marks	grisel.marks@geemail.com	San Francisco	California	060420252017858	023d2542ff46334c954f54c49af4e44c	VISA 16 digit	37.7518682308580438	-122.438746464296642
8748	2020-01-06 23:45:46	2020-01-06	Garnet Bernhard	garnet.bernhard@woohoo.com	San Francisco	California	54243116957552004	4b8a29e6d207624f88347fc1b3f52a68	Discover	37.7682790964519839	-122.445201824780341
8749	2020-01-06 23:53:40	2020-01-06	Van Lubowitz	van.lubowitz@woohoo.com	Santa Ana	California	869926284441169166	92219807f226a1bcbbcd5089de5a9375	VISA 16 digit	33.747815571223569	-117.873303729102005
8750	2020-01-06 23:55:12	2020-01-06	Miss Angele Abshire	miss.angele.abshire@geemail.com	Jacksonville	Florida	6011177692014572086	cd2e8a8ada8bbb9794f544924756289f	American Express	30.3075763063557453	-81.5986007056743006
8751	2020-01-07 00:31:12	2020-01-07	Dashawn Graham	dashawn.graham@geemail.com	Eugene	Oregon	6011738726873445547	347bdc98beb764b635c00f922f749bba	VISA 16 digit	44.0366888974521302	-123.210254146949211
8752	2020-01-07 00:59:00	2020-01-07	Mrs. Ednah Lowe MD	mrs.ednah.lowe.md@geemail.com	Elgin	Illinois	4444025940996532	578dd5b7101c6072a478304e67d6598a	Mastercard	42.0470021035339698	-88.250211449042709
8753	2020-01-07 01:06:38	2020-01-07	Leta Fritsch	leta.fritsch@warmmail.com	Victorville	California	4351878146230549	547a4bbc528ba4f00d553f60e7ad9d02	Discover	34.589134482596819	-117.347712201966345
8754	2020-01-07 01:07:29	2020-01-07	Jensen Veum	jensen.veum@geemail.com	Richardson	Texas	6011779169915706594	8d69ed7658539ac7ec927b9fd31572d4	American Express	32.9628584604945019	-96.7632899006124632
8755	2020-01-07 02:02:21	2020-01-07	Margarita Quitzon	margarita.quitzon@geemail.com	San Francisco	California	6011795623780443030	cf761adaf0366a29c6ddb055114a544d	JCB 16 digit	37.7608092138698126	-122.435465225885707
8756	2020-01-07 02:10:59	2020-01-07	Dessie Lang PhD	dessie.lang.phd@warmmail.com	Chicago	Illinois	180049561989071455	b2992cbe4f77ead1425b67eef7182375	Voyager	41.8572362611837718	-87.7150182910758929
8757	2020-01-07 02:20:03	2020-01-07	Chuck Brown	chuck.brown@geemail.com	Berkeley	California	3493217273803690	f38e58886f80f3f61a382ab701b6c720	Mastercard	37.85722516117346	-122.268037197199206
8758	2020-01-07 02:42:11	2020-01-07	Mr. Thurman Lind Sr.	mr.thurman.lind.sr.@warmmail.com	San Francisco	California	869920144286091501	60cdee15f563c21fbd254ff97ef329eb	VISA 16 digit	37.8038212849876771	-122.410422725791079
8759	2020-01-07 03:03:33	2020-01-07	Dr. Charley Nicolas	dr.charley.nicolas@geemail.com	Costa Mesa	California	3795715359224580	faea69d2da49888f00bc300fd594eccd	Diners Club / Carte Blanche	33.6072573971018187	-117.910909961476179
8760	2020-01-07 03:08:51	2020-01-07	Cheyenne Murray-Klein	cheyenne.murray.klein@warmmail.com	New York	New York	3088640617239038661	e742be209271ac5b80952eb086010ba7	JCB 16 digit	40.6952314757965468	-74.0024345010880324
8761	2020-01-07 03:49:24	2020-01-07	Dr. Loren Greenholt	dr.loren.greenholt@geemail.com	Vancouver	Washington	52292590595982072	951c205577b8e183dbda6dd0b28a3f7f	VISA 13 digit	45.5982658843115018	-122.616366774455457
8762	2020-01-07 03:54:23	2020-01-07	Dr. Roby Mosciski	dr.roby.mosciski@woohoo.com	Albuquerque	New Mexico	869968882833525199	26f5067d4bfb249b3e13b30afdb49651	VISA 16 digit	35.1895231896214185	-106.68541557938569
8763	2020-01-07 04:04:34	2020-01-07	Rosanne Abernathy	rosanne.abernathy@geemail.com	Arlington	Texas	4057574883138	3181e7d91e353d4837f34048dddd0de2	Voyager	32.6243702120397217	-97.0942075514726355
8764	2020-01-07 04:12:47	2020-01-07	Jaycob Wilkinson	jaycob.wilkinson@geemail.com	Tampa	Florida	502092826344340	1826a4151ec8247f39e5846eda5da317	Voyager	27.9367497159283609	-82.3926396348725945
8765	2020-01-07 04:33:08	2020-01-07	Mervyn Feil	mervyn.feil@geemail.com	Coral Springs	Florida	3528447249527375434	44873ad35c366a11751801c54ac5acde	VISA 16 digit	26.2936370613582433	-80.1953270751174472
8766	2020-01-07 04:39:46	2020-01-07	Cheri Simonis DVM	cheri.simonis.dvm@warmmail.com	Berkeley	California	3112275132818869462	ee2b31e6f38c040e8a7f3b9c1463da71	Maestro	37.9073540358592069	-122.276010924264426
8767	2020-01-07 05:05:18	2020-01-07	Bentley Dickens	bentley.dickens@geemail.com	Long Beach	California	676361669931893	311d9ac8cf65a114a6a7e4afb955bead	Voyager	33.7349855522911994	-118.115821937115115
8768	2020-01-07 05:42:59	2020-01-07	Emery Mann	emery.mann@geemail.com	New York	New York	869932803323714252	ea288c4d4847ee773016c1da78a30cd8	JCB 16 digit	40.623808796307074	-73.8802395361836943
8769	2020-01-07 05:48:21	2020-01-07	Janelle Steuber-Treutel	janelle.steuber.treutel@warmmail.com	Stockton	California	210019765544416966	2a17950545597eccf5080ad593f53aff	VISA 16 digit	37.9196155997656277	-121.338615791554744
8770	2020-01-07 06:07:46	2020-01-07	Faith DuBuque DVM	faith.dubuque.dvm@geemail.com	Virginia Beach	Virginia	3158393389400603215	8ff3f0576fd40f4d7284ed2b128def8c	Maestro	36.7696183383651061	-76.1073629855316085
8771	2020-01-07 06:08:16	2020-01-07	Jovani Jacobson	jovani.jacobson@woohoo.com	Hollywood	Florida	210086321668953828	36ecd6fcf5a79360a06709371ce45f47	American Express	25.9356970400493587	-80.1975458795022149
8772	2020-01-07 06:22:40	2020-01-07	Ruffin Flatley	ruffin.flatley@geemail.com	Indianapolis	Indiana	210028641822912274	5d635ec9b374829906e1bddc36e45677	Maestro	39.7853458824109296	-86.218355324791375
8773	2020-01-07 06:36:26	2020-01-07	Ab Denesik	ab.denesik@geemail.com	Berkeley	California	4552768806796	26dc1c7b7bb3720a13408ef932720dfa	VISA 13 digit	37.86272339932151	-122.244702554986588
8774	2020-01-07 06:47:20	2020-01-07	Osborne Towne-Waelchi	osborne.towne.waelchi@geemail.com	San Francisco	California	639044727708321	c9bca2e16ba6cab2bd2522e6ff7dfd80	VISA 16 digit	37.8146306694183068	-122.460228556246847
8775	2020-01-07 07:56:49	2020-01-07	Isabel Bradtke	isabel.bradtke@geemail.com	San Francisco	California	4443703902420417	3a339c676eb3b576c3dd870f78dcbbff	Maestro	37.8222177786245339	-122.433306995712456
8776	2020-01-07 08:14:30	2020-01-07	Donat Veum	donat.veum@woohoo.com	Santa Ana	California	3041968056078261	c479a15ec1c8e8d21e4353fd86f05d4e	VISA 16 digit	33.7452406762737809	-117.785120998408644
8777	2020-01-07 08:17:24	2020-01-07	Muhammad Konopelski	muhammad.konopelski@geemail.com	Detroit	Michigan	501884439727441	ab30d1687c4ca5a22e297a8c13a4557b	Diners Club / Carte Blanche	42.4521599721089018	-83.009991523030024
8778	2020-01-07 08:28:58	2020-01-07	Zakary Bins	zakary.bins@warmmail.com	San Francisco	California	210013936070975040	53ec5be455cea372de2ba56aba5cf97b	VISA 13 digit	37.7517376132367204	-122.397656441523139
8779	2020-01-07 08:55:12	2020-01-07	Jaden Hansen	jaden.hansen@geemail.com	Killeen	Texas	060421478357375	8c591bc08e5d1d1458a9a8f714ab1d12	VISA 13 digit	31.1748393651328968	-97.706552946444603
8780	2020-01-07 08:58:08	2020-01-07	Mauricio Huel	mauricio.huel@geemail.com	Charlotte	North Carolina	3010124509559082	8779152a66e6d59a06af5b907c980659	JCB 16 digit	35.1321074510712137	-80.7458510806262524
8781	2020-01-07 09:06:29	2020-01-07	Reagan Murazik-Mante	reagan.murazik.mante@woohoo.com	Memphis	Tennessee	869949783494164407	1851fe9c2ed74aa0dbc65e179669e7ac	VISA 16 digit	35.0720011785693515	-89.9260185024492529
8782	2020-01-07 09:12:21	2020-01-07	Shelby Renner	shelby.renner@geemail.com	Chicago	Illinois	3476386295802302	0d3cecbc4212fe0ce59d3d0daab008ad	VISA 13 digit	41.836343847478183	-87.6990926620580211
8783	2020-01-07 09:31:43	2020-01-07	Latricia Johnson	latricia.johnson@geemail.com	Oxnard	California	060456476257037	f0c420e034847cc612d4e730c65689be	JCB 15 digit	34.2790371701542327	-119.280042079547798
8784	2020-01-07 09:40:35	2020-01-07	Benny Wisoky-Kuhic	benny.wisoky.kuhic@woohoo.com	College Station	Texas	4747658150195322	5bfbecd3ef7688f2cf13991ec318b8ce	VISA 16 digit	30.5364889663223167	-96.2363136259220653
8785	2020-01-07 09:57:57	2020-01-07	Myer Bechtelar	myer.bechtelar@geemail.com	Long Beach	California	4587781787542345	c225e8a36a96eb9e2044c2a5875c7d73	VISA 13 digit	33.7543393217779695	-118.241634722954771
8786	2020-01-07 10:10:24	2020-01-07	Theola Kohler	theola.kohler@woohoo.com	Nashville	Tennessee	55418292134581601	22b76212ef5b906c534716e91c98fe55	VISA 13 digit	36.2479467444710437	-86.8647073519322959
8787	2020-01-07 10:30:49	2020-01-07	Gaven Rodriguez	gaven.rodriguez@geemail.com	Lancaster	California	3096798938893000056	3c0d241c497f75af8bc073638b282117	Maestro	34.6621947863850792	-118.200345197084545
8788	2020-01-07 10:31:19	2020-01-07	Lynne Feest DVM	lynne.feest.dvm@woohoo.com	Austin	Texas	869915569218742945	7c93aa6772fe3b999dbaa5710ebd908b	Mastercard	30.3393073591530325	-97.7347187309764394
8789	2020-01-07 10:51:10	2020-01-07	Frankie Rippin	frankie.rippin@geemail.com	Berkeley	California	3775372092461303	b0d478bfadf21b238913623e5603e2c7	Mastercard	37.8876425991429997	-122.311528626904746
8790	2020-01-07 11:10:27	2020-01-07	Romello Braun I	romello.braun.i@geemail.com	Las Vegas	Nevada	180002757152132349	110d5ceba598fbfe13acc6d8048069ec	VISA 16 digit	36.2002808041039827	-115.35551962272487
8791	2020-01-07 11:50:08	2020-01-07	Ivor Abshire-Larson	ivor.abshire.larson@geemail.com	San Francisco	California	4174090948477121	4597f4463eb5078f75d1a82c2f92ff0d	Discover	37.750160571175428	-122.44359197772755
8792	2020-01-07 12:15:44	2020-01-07	Del Cole	del.cole@geemail.com	Fort Worth	Texas	869963444965198108	4593f7886e4ca8194fe47352b64cb02d	Diners Club / Carte Blanche	32.8388667467571835	-97.3514160558402466
8793	2020-01-07 12:22:19	2020-01-07	Karri Buckridge DDS	karri.buckridge.dds@warmmail.com	New Orleans	Louisiana	4140249233015050	f3fda09660719dea93c3872d6f5eaf46	American Express	30.1320976158153258	-90.0097839109394755
8794	2020-01-07 12:22:33	2020-01-07	Dolphus Berge	dolphus.berge@geemail.com	Columbus	Ohio	4875358956814580	766fbffe1471cd202d6f10811a2e164c	JCB 16 digit	40.0152870427861771	-82.9551389484435333
8795	2020-01-07 12:23:49	2020-01-07	Harlow Batz	harlow.batz@geemail.com	Buffalo	New York	676385467409448	74b5a7973c6a51e7ea590d83bb326621	Mastercard	42.7948798210546357	-78.8930272038493285
8796	2020-01-07 13:04:16	2020-01-07	Shanna Lesch	shanna.lesch@geemail.com	Vancouver	Washington	3528291497992863502	c59ff28e91b3beae0357afd4ec9840db	Diners Club / Carte Blanche	45.5464969816688452	-122.587152932078382
8797	2020-01-07 13:25:16	2020-01-07	Rory Keeling-Adams	rory.keeling.adams@woohoo.com	Columbus	Georgia	180099538140633794	97c92f10c0998363f44d74c5219952a4	Mastercard	32.4141013061206777	-84.7765369208227781
8798	2020-01-07 13:33:28	2020-01-07	Shari Yundt-Torphy	shari.yundt.torphy@geemail.com	Tacoma	Washington	869991746546616119	5b986c0801e63f402ec956c504592277	VISA 16 digit	47.229163784545662	-122.524079459742836
8799	2020-01-07 13:46:54	2020-01-07	Randi Pacocha	randi.pacocha@woohoo.com	Berkeley	California	3741196791328310	865ec57b852549e9fe254bbdb56635c5	Mastercard	37.8584056424178499	-122.284347776824745
8800	2020-01-07 13:51:07	2020-01-07	Unnamed Emard	unnamed.emard@geemail.com	San Francisco	California	3403740881136251	b267296c81b65536e2d5658f2760f80a	VISA 16 digit	37.7620776539820184	-122.437008081883448
8801	2020-01-07 14:13:37	2020-01-07	Verena Rutherford	verena.rutherford@geemail.com	Henderson	Nevada	3528319482141873055	a4019c6eada0fdd4f11beeff211bebc2	Discover	36.0304023835275373	-114.975000501253461
8802	2020-01-07 14:36:13	2020-01-07	Mr. Orrin Haley Jr.	mr.orrin.haley.jr.@geemail.com	Oakland	California	210046972826374981	bacfeeb318afc8d8578ef95d373920ad	American Express	37.8200588044460204	-122.227687570455871
8803	2020-01-07 15:30:16	2020-01-07	Tito Bogan	tito.bogan@warmmail.com	San Francisco	California	3158351806662980130	e201b9c40226e2617abe535a58c65b0e	VISA 13 digit	37.7565004293026547	-122.45724069899309
8804	2020-01-07 15:34:18	2020-01-07	Ladonna Dibbert MD	ladonna.dibbert.md@geemail.com	Salt Lake City	Utah	6011908224247709461	f9689451ea6333a55c3a0fba0d0fbd0d	VISA 13 digit	40.7420031983084954	-112.007069671427828
8805	2020-01-07 15:37:20	2020-01-07	Winnie Kuhlman	winnie.kuhlman@warmmail.com	Berkeley	California	3053761050981483	607b0e11ee7e772b086d2e3978d06b74	JCB 15 digit	37.8569366854246212	-122.28453174931073
8806	2020-01-07 16:14:43	2020-01-07	Devante Dooley V	devante.dooley.v@geemail.com	San Francisco	California	3418204110594106	eb77fa3b173aaed83943e304245fdc10	Maestro	37.7889458275001147	-122.434142271848529
8807	2020-01-07 16:38:22	2020-01-07	Anabelle Renner	anabelle.renner@warmmail.com	Albuquerque	New Mexico	3751613197691684	73f7ae264949ad9104d92f7332cccca0	Voyager	35.0246145588014315	-106.645419632417713
8808	2020-01-07 17:10:03	2020-01-07	Ashlyn Lueilwitz	ashlyn.lueilwitz@woohoo.com	Moreno Valley	California	6011109352962867037	3addfdc48ec6ba3924d57d1b79b86ea1	VISA 16 digit	33.9733187848694627	-117.200451964136946
8809	2020-01-07 17:24:08	2020-01-07	Lenwood Weimann	lenwood.weimann@geemail.com	Colorado Springs	Colorado	4157633416619210	92803e461c150f75996f6dae57c161df	JCB 15 digit	38.9304348070688562	-104.832065899452942
8810	2020-01-07 17:26:49	2020-01-07	Carl Bauch	carl.bauch@geemail.com	Indianapolis	Indiana	4384819146778	37701e68ba2f70a3a6f87808d41c3a9e	VISA 16 digit	39.8659607163172183	-86.1879665772631682
8811	2020-01-07 17:34:55	2020-01-07	Lynn Mueller	lynn.mueller@geemail.com	Oakland	California	3017213114851910	e031b9df6a312722467348439c547f2c	American Express	37.815931325890169	-122.261485363864566
8812	2020-01-07 18:23:10	2020-01-07	Oda Altenwerth	oda.altenwerth@geemail.com	Oklahoma City	Oklahoma	4402474672703064	65054759f0520aa15faa6da5749a8a83	JCB 15 digit	35.3807219323612756	-97.6119440017629358
8813	2020-01-07 18:35:55	2020-01-07	Zeno DuBuque	zeno.dubuque@geemail.com	Topeka	Kansas	3528403613902722209	22eb91aca20b73d75d11fed5305d8e83	JCB 16 digit	39.0313509816702435	-95.6445239703811723
8814	2020-01-07 19:16:45	2020-01-07	Alberta Hoeger	alberta.hoeger@geemail.com	High Point	North Carolina	6011708140024183666	fca12ebd116e55d5881329139521ac0c	Discover	36.0139458802156156	-79.9113593370858553
8815	2020-01-07 19:18:38	2020-01-07	Mohammed Bradtke DDS	mohammed.bradtke.dds@geemail.com	San Francisco	California	51521796018497589	09f522fc94f5efa5a5d89e097b6a4b45	VISA 16 digit	37.7938693730151343	-122.463392053173919
8816	2020-01-07 19:23:27	2020-01-07	Austen Barrows	austen.barrows@geemail.com	San Francisco	California	210026138931111650	4109145c9d0911c0486974ab94410783	Discover	37.763475752329704	-122.474666745527003
8817	2020-01-07 19:57:50	2020-01-07	Racheal Von	racheal.von@geemail.com	Richmond	Virginia	3112048476861781777	03ff88022ec47972fe933ff5b0b8f7fc	Maestro	37.4372433349244247	-77.5665017725657719
8818	2020-01-07 20:25:54	2020-01-07	Dr. Bruno Altenwerth	dr.bruno.altenwerth@geemail.com	New York	New York	3781458474387125	af0676e825adad5294dcdb094514388f	Mastercard	40.7471507057305402	-73.8741023550636982
8819	2020-01-07 21:13:13	2020-01-07	Elmer Powlowski-Simonis	elmer.powlowski.simonis@geemail.com	Tampa	Florida	210064874912404374	58dc0baae7d0c4a471939cdafa32e851	JCB 16 digit	27.9477197895407663	-82.4492830473676293
8820	2020-01-07 21:13:32	2020-01-07	Abbie Feeney	abbie.feeney@warmmail.com	Oxnard	California	210068976547311258	6b53bff201b74905aee8bb8d9f702e90	Mastercard	34.210973413610084	-119.298450418133655
8821	2020-01-07 21:48:02	2020-01-07	Ms. Zadie Auer DDS	ms.zadie.auer.dds@geemail.com	Dallas	Texas	3762002557125102	36d1727480142cc50de83595bb02e2ab	Mastercard	32.6947340111985838	-96.6818433842584426
8822	2020-01-07 21:58:00	2020-01-07	Frieda Rogahn	frieda.rogahn@warmmail.com	Detroit	Michigan	3528927421304066432	4d621e2cc402294429ecf63dbf974c55	American Express	42.3350817141979974	-83.0739496694996973
8823	2020-01-07 22:32:11	2020-01-07	Kane Luettgen	kane.luettgen@geemail.com	New York	New York	4158983962955594	2bbec11fe20e60816e59e92cbb92905a	JCB 15 digit	40.7276569303348666	-73.9511235999770378
8824	2020-01-07 23:46:12	2020-01-07	Charlee Schuster	charlee.schuster@warmmail.com	Sacramento	California	3481917605583142	1a58196037b539d1e3605e7bf69502d3	VISA 16 digit	38.6306930416528118	-121.518728468545149
8825	2020-01-07 23:47:09	2020-01-07	Fabiola Johnson	fabiola.johnson@woohoo.com	Daly City	California	639040587078599	ca5df68db2b2b2fa7175896f3508231f	Discover	37.7788870698228436	-122.521387523096053
8826	2020-01-07 23:54:41	2020-01-07	Dr. Ottilia Bode	dr.ottilia.bode@geemail.com	San Francisco	California	210012543684825313	d7110d8b2a2236394c776eb9e979b501	Voyager	37.8108824329101338	-122.380068340560655
8827	2020-01-08 00:30:24	2020-01-08	Miss Dema McGlynn DVM	miss.dema.mcglynn.dvm@warmmail.com	San Francisco	California	639091977864478	db81002671a7ccbb131c607286ec78d5	Voyager	37.761474409467894	-122.434355730410417
8828	2020-01-08 00:32:42	2020-01-08	Tariq Morar	tariq.morar@geemail.com	El Paso	Texas	869905572168109471	124ac789514f89f83e38ad237135d0c8	JCB 16 digit	31.8544582727193841	-106.356345890088008
8829	2020-01-08 00:54:41	2020-01-08	Arno Hudson	arno.hudson@warmmail.com	San Antonio	Texas	3783547018217703	0a263ed09378d8e748c93852007e1524	Discover	29.4908066128451374	-98.5781776955652873
8830	2020-01-08 01:04:51	2020-01-08	Mariah Spinka	mariah.spinka@geemail.com	Dallas	Texas	3158768384374038453	548a5dc4c31e65082a823ff7f05a166a	Voyager	32.7571649998232743	-96.7707368523776523
8831	2020-01-08 01:47:40	2020-01-08	Raina Weimann	raina.weimann@geemail.com	New York	New York	51679937668743787	98f3a1b9ef2fdc9c436ad756e91e288b	Voyager	40.6689098657332337	-73.94569852691032
8832	2020-01-08 02:06:00	2020-01-08	Mr. Grove Kiehn	mr.grove.kiehn@geemail.com	Virginia Beach	Virginia	3528276434743679530	57dd242dce0cb9d486d1e00c543a5e5f	Discover	36.818424509158362	-76.006840001200132
8833	2020-01-08 02:11:21	2020-01-08	Claiborne Braun-Bauch	claiborne.braun.bauch@geemail.com	Berkeley	California	54561689866098834	14a7b0b25f5129f3968bc93e7fb9e3ff	VISA 16 digit	37.8558525170214395	-122.26429186294439
8834	2020-01-08 02:16:41	2020-01-08	Kaliyah Windler DVM	kaliyah.windler.dvm@warmmail.com	Columbus	Ohio	4017973712619	0939f81fc6569a58885e5bc301d5b2e5	Maestro	39.9084080421410476	-82.9998281605310808
8835	2020-01-08 02:18:56	2020-01-08	Wilfrid Marks	wilfrid.marks@geemail.com	Fresno	California	4098881947772253	c4f5f40bb70207702da42cc41cd62602	Maestro	36.8689348202072082	-119.785612625965484
8836	2020-01-08 02:47:23	2020-01-08	Alphonso Greenholt	alphonso.greenholt@geemail.com	Berkeley	California	3337769281961312649	bd4e7c4059e37e17782445864c4559bc	American Express	37.8703991835450324	-122.239352085047727
8837	2020-01-08 02:51:15	2020-01-08	Dorine Block	dorine.block@woohoo.com	Los Angeles	California	52913515890791471	13a970910c6f93262c26ce503300932c	Maestro	34.1026911701872919	-118.35500765135437
8838	2020-01-08 02:51:37	2020-01-08	Dr. Reynaldo Hartmann	dr.reynaldo.hartmann@woohoo.com	Wichita	Kansas	676378503073914	abe9d0c2d2b55df5ce1335774420097e	Discover	37.6840311726432304	-97.4155223238017385
8839	2020-01-08 03:00:18	2020-01-08	Danelle Beahan-Armstrong	danelle.beahan.armstrong@geemail.com	Berkeley	California	210097935810033747	7a3a5031b4ab962b4a0795c20265e407	Maestro	37.8790206871000592	-122.259446664518322
8840	2020-01-08 03:04:11	2020-01-08	Ray Eichmann	ray.eichmann@woohoo.com	Houston	Texas	3337520172911443057	1fac7f029344477e72378d8b2cb6e995	VISA 16 digit	29.8125293721523121	-95.4334512545742086
8841	2020-01-08 03:12:41	2020-01-08	Jeremie Kohler	jeremie.kohler@geemail.com	Grand Rapids	Michigan	561225169478085	c1a46c29353744ca064e29ef421e6ab5	Mastercard	43.0076485231786947	-85.579589347973851
8842	2020-01-08 03:20:11	2020-01-08	Miss Inger Kunde	miss.inger.kunde@geemail.com	Charlotte	North Carolina	3096974027891696655	7174e5dab0cee2e3333fa1163d653402	VISA 16 digit	35.2711886294905099	-80.8593504951745246
8843	2020-01-08 03:53:52	2020-01-08	Mila King	mila.king@geemail.com	Lakeland	Florida	4589492625597	a02fefff4d3fdaf0243bf740aaa1fdce	Mastercard	28.111482479499653	-81.9770756257582462
8844	2020-01-08 04:24:19	2020-01-08	Verle Keeling-Kub	verle.keeling.kub@geemail.com	Detroit	Michigan	52036537698675559	3727d18f41ffbb134be69fae6cf77f87	American Express	42.4329184665735824	-83.0738149224434039
8845	2020-01-08 04:32:36	2020-01-08	Mr. Tyquan Franecki Jr.	mr.tyquan.franecki.jr.@woohoo.com	Tulsa	Oklahoma	54839085453098848	e1cca3dbd21f420ca012749718674120	Maestro	36.1645318210493727	-95.9094221679449106
8846	2020-01-08 04:39:48	2020-01-08	Arkie Murray-Bartell	arkie.murray.bartell@warmmail.com	Milwaukee	Wisconsin	4939428768704651	250eab8ceb9a46bafbfe0321049714ff	VISA 13 digit	42.9683197682809066	-88.0232360374283047
8847	2020-01-08 04:47:11	2020-01-08	Merton Aufderhar	merton.aufderhar@woohoo.com	St. Petersburg	Florida	3158164544311413057	9f3363e74095c41ca4d9ec4defda3a9d	JCB 15 digit	27.728500367969275	-82.6690323603697124
8848	2020-01-08 05:20:25	2020-01-08	Josette Cremin	josette.cremin@warmmail.com	Columbus	Ohio	3036449807350403	414eef0e56c017096154fecd31b14e99	Diners Club / Carte Blanche	40.0469761175148165	-82.9895440470662038
8849	2020-01-08 05:23:12	2020-01-08	Hart Labadie	hart.labadie@geemail.com	San Francisco	California	4131713941963498	d1f986f39b87c057cd7550c40286b2e9	Diners Club / Carte Blanche	37.7745264300499599	-122.438470726169882
8850	2020-01-08 05:44:04	2020-01-08	Keli Jones	keli.jones@geemail.com	Meridian	Idaho	3096164436952329553	052a8a42955843c26b9a735b6c4aaf9d	VISA 16 digit	43.6411358124583941	-116.405494598246733
8851	2020-01-08 05:53:49	2020-01-08	Leontine Crist	leontine.crist@warmmail.com	Baltimore	Maryland	4962211893734128	714e3959a9e84bc288d696404c52869e	JCB 15 digit	39.2702920594252589	-76.6699035640358915
8852	2020-01-08 06:21:43	2020-01-08	Ms. Lilyana Kub	ms.lilyana.kub@geemail.com	Phoenix	Arizona	210057856632611494	c3e2f9d437669fa59c06b9598e926747	VISA 16 digit	33.5395663692083232	-111.996060076348869
8853	2020-01-08 06:42:38	2020-01-08	Merrilee Kutch	merrilee.kutch@geemail.com	San Francisco	California	3050762625548495	672e396d36fcfd6d61dd5807fffe9033	Voyager	37.7549602361835213	-122.410537025173142
8854	2020-01-08 06:42:55	2020-01-08	Marc Bode	marc.bode@geemail.com	Chicago	Illinois	4655680337262932	db12267252689125f25b4d49a2b2a0fd	JCB 16 digit	41.7536877081565549	-87.6912001452904093
8855	2020-01-08 06:54:24	2020-01-08	Dr. Ely Stokes Sr.	dr.ely.stokes.sr.@geemail.com	Oakland	California	3337415385162689693	53a97d4d36024894190a4af171dd6733	JCB 15 digit	37.7966207490624839	-122.25188575212897
8856	2020-01-08 06:59:02	2020-01-08	Edd Dickens-Marks	edd.dickens.marks@warmmail.com	Oxnard	California	53786152943546720	e5d98b85ddfa7c6c5e25c78adc17bf6d	Maestro	34.2729065888982305	-119.125620803460848
8857	2020-01-08 07:01:48	2020-01-08	Ouida Osinski-Barrows	ouida.osinski.barrows@geemail.com	Los Angeles	California	4852078840383447	ad2928af4ad307f4c59d3aae1a3155cd	VISA 16 digit	34.0495388341002112	-118.360145510313288
8858	2020-01-08 07:03:19	2020-01-08	Dr. Lauren Nader MD	dr.lauren.nader.md@geemail.com	Cedar Rapids	Iowa	3748529998659223	fa0858e608f3ee0bdd8d28acf9d627c0	JCB 15 digit	41.9790542036835106	-91.7519206942591836
8859	2020-01-08 07:05:29	2020-01-08	Ovid Moore-Rau	ovid.moore.rau@woohoo.com	Los Angeles	California	3052813397915657	a697d3442c4e333d98231c7e6059d869	JCB 15 digit	33.9374671898182427	-118.390036136469988
8860	2020-01-08 07:50:40	2020-01-08	Maliyah Olson	maliyah.olson@geemail.com	Berkeley	California	4988221312677683	a8c6fab8e033f554427d0ebb5d6d93a1	VISA 16 digit	37.89330156923792	-122.289064294759555
8861	2020-01-08 08:18:14	2020-01-08	Anna Parisian-Graham	anna.parisian.graham@geemail.com	Concord	California	4739790385689	4801ba193526b764553f90a0f554f621	JCB 15 digit	37.9997469798129046	-121.942021913331374
8862	2020-01-08 08:36:12	2020-01-08	Tamia Halvorson	tamia.halvorson@warmmail.com	Anchorage	Alaska	210074282548446033	b83523c62f771f85dbc6ffb41242b871	Voyager	61.2274220631673955	-149.262177601282673
8863	2020-01-08 08:50:06	2020-01-08	Nikole Reynolds	nikole.reynolds@geemail.com	San Francisco	California	3528073688011017609	c5809c2c0157d3224d0c19acaee64eff	VISA 16 digit	37.7870428237293368	-122.379423750892286
8864	2020-01-08 10:08:58	2020-01-08	Maverick Wolff	maverick.wolff@warmmail.com	Hartford	Connecticut	3033378216531688	0db58bb879e632bb39b91499598e4b68	Voyager	41.7523877806510768	-72.6186164054445982
8865	2020-01-08 10:45:56	2020-01-08	Mr. Lonnie Macejkovic III	mr.lonnie.macejkovic.iii@geemail.com	New York	New York	3112174906763602636	b663b7bc4240e2253ff27ccb4e1ec115	Voyager	40.5718645602688213	-74.0092615831539007
8866	2020-01-08 10:47:09	2020-01-08	Icy Wilderman	icy.wilderman@geemail.com	New York	New York	6011977432565889247	c384d970f1ce759ce5cb6c710fc51076	American Express	40.6865251697357735	-73.9406738962873789
8867	2020-01-08 10:50:09	2020-01-08	Mertie Dietrich DVM	mertie.dietrich.dvm@geemail.com	Memphis	Tennessee	4135877606825478	2a6211753fff32ed0c43970b52facaa1	Mastercard	35.0606564335126478	-90.03095218686164
8868	2020-01-08 11:23:02	2020-01-08	Mrs. Sunny Hartmann DDS	mrs.sunny.hartmann.dds@geemail.com	El Paso	Texas	4496302115969	d5a283e04745da8e02dcd341fefe7461	American Express	31.8144829457454392	-106.490905230863021
8869	2020-01-08 11:23:43	2020-01-08	Dr. Loma Effertz	dr.loma.effertz@woohoo.com	Glendale	California	3337403718424236305	b015a9ea0da399886852542450df9220	Mastercard	34.2638638734105925	-118.147252760631218
8870	2020-01-08 11:26:02	2020-01-08	Alfredo Hartmann	alfredo.hartmann@geemail.com	Tulsa	Oklahoma	3096969319903395732	3021e7337261047056f33dd7de0cb724	American Express	36.1731663862146391	-95.9728998457036937
8871	2020-01-08 11:26:42	2020-01-08	Mr. Vidal Bergstrom	mr.vidal.bergstrom@geemail.com	Ontario	California	869929079205992622	b6e6c719f08dfc10a6c522e7b38e8c11	VISA 16 digit	34.066485190219808	-117.558395005586377
8872	2020-01-08 11:31:48	2020-01-08	Miracle Morar DVM	miracle.morar.dvm@warmmail.com	Seattle	Washington	4608635328258669	00744fbeb5e44b8703216a166ff4511d	Discover	47.5338400840684798	-122.364658332096042
8873	2020-01-08 11:35:00	2020-01-08	Lolla Carter	lolla.carter@geemail.com	San Francisco	California	3057367379300029	c59e9c20356e9b1035edf628a3adfce1	American Express	37.7693339724501627	-122.436943082539472
8874	2020-01-08 12:07:11	2020-01-08	Nettie Bechtelar	nettie.bechtelar@geemail.com	Jacksonville	Florida	54191134991362597	d369165f42e44dcd830e385e5a30575c	Maestro	30.32345772781931	-81.6307422602161807
8875	2020-01-08 12:13:40	2020-01-08	Karen Marks	karen.marks@geemail.com	New York	New York	676205785765446	25df4c14ffa26c3fefd8ead618ceab3d	JCB 16 digit	40.6863622886817922	-73.8578048620734364
8876	2020-01-08 12:53:01	2020-01-08	Kimberlee Sanford	kimberlee.sanford@geemail.com	Portland	Oregon	210007343121110677	18bba7af0d6de9a144397e4cbf67f3c8	Voyager	45.6072789660077547	-122.601204247586438
8877	2020-01-08 13:13:47	2020-01-08	Lahoma Gulgowski-Kuhlman	lahoma.gulgowski.kuhlman@warmmail.com	Beaumont	Texas	4262869168985	6ccf9dc4ef50f6d0f81c2d9dd15ec276	American Express	30.0667118643015634	-94.1360903900370118
8878	2020-01-08 13:15:12	2020-01-08	Dr. Clarance Dickens Sr.	dr.clarance.dickens.sr.@geemail.com	San Francisco	California	210032372802762638	0a3aa1360306912ae5c85d9fbebcd546	VISA 16 digit	37.7669132760987267	-122.405606659758305
8879	2020-01-08 13:33:16	2020-01-08	Miss Karrie Crist	miss.karrie.crist@geemail.com	San Francisco	California	6011592139724110002	88194e617c0a2e4ebb2bdad02d411943	American Express	37.7559467172027752	-122.419731295435469
8880	2020-01-08 13:33:16	2020-01-08	Ali Pollich	ali.pollich@geemail.com	Fort Lauderdale	Florida	4146951808055	fddac268ff8021301fed3367029d08e3	American Express	26.1520737632632283	-80.052326873252909
8881	2020-01-08 13:55:37	2020-01-08	Sharron Langosh-Adams	sharron.langosh.adams@geemail.com	Houston	Texas	54686182674542490	de3df7ba6b1b08d789f627631398dab0	Mastercard	29.8176728998389109	-95.3224689435228782
8882	2020-01-08 14:22:53	2020-01-08	Dr. Artie Howe	dr.artie.howe@geemail.com	Mesa	Arizona	51923704780403433	ec657a3e02fce256aceadf462d2e36b8	VISA 16 digit	33.4744781350396536	-111.774365206516904
8883	2020-01-08 14:37:50	2020-01-08	Lynda Haag MD	lynda.haag.md@geemail.com	Berkeley	California	6011035159249188809	96e38d7a90ff7d3e04d4f7fe9c649bb2	American Express	37.8597933025866737	-122.263722671916625
8884	2020-01-08 14:43:06	2020-01-08	Galilea Simonis	galilea.simonis@warmmail.com	New Orleans	Louisiana	3035498972348537	40e4d34b73a3bafbe4f83dfafa112a51	Discover	30.0300595248598619	-89.9256596864461955
8885	2020-01-08 15:00:43	2020-01-08	Vena Rau	vena.rau@warmmail.com	San Francisco	California	060499232949893	84e8eddeed2a3fa57d5a743f4d84e86e	Maestro	37.7990191130384332	-122.440829205508876
8886	2020-01-08 15:20:06	2020-01-08	Clydie Greenfelder-Erdman	clydie.greenfelder.erdman@geemail.com	St. Louis	Missouri	4917922847236	30cf7d5c585fcd28c388976f703b53c3	VISA 13 digit	38.6584192775346338	-90.1789103623949018
8887	2020-01-08 15:25:24	2020-01-08	Ardith Hermiston	ardith.hermiston@geemail.com	San Francisco	California	676296303303893	a94f6280dea244cabb908f422f15d77e	JCB 16 digit	37.7659589235527591	-122.438877468066593
8888	2020-01-08 15:52:58	2020-01-08	Ms. Dorinda Reinger PhD	ms.dorinda.reinger.phd@geemail.com	Lubbock	Texas	4633623161638204	962768b6a53bedb0d086a4d721203b69	JCB 15 digit	33.5226249951444615	-101.951628889833401
8889	2020-01-08 16:15:18	2020-01-08	Winfield Wilderman	winfield.wilderman@geemail.com	Fontana	California	3467786400708784	d0229b65177166aba7d266392f2db4bb	JCB 15 digit	34.0549663807880165	-117.447297576330229
8890	2020-01-08 17:31:27	2020-01-08	Keesha Walter	keesha.walter@warmmail.com	Evansville	Indiana	3158188738285221684	6f8ef00f0d8f39c1440d96340c877033	VISA 16 digit	37.949725103531776	-87.4862695060603386
8891	2020-01-08 17:36:00	2020-01-08	Troy Homenick	troy.homenick@woohoo.com	Pomona	California	3725652826182668	e45e4f787f427b2caf0b584c4bccd45c	Mastercard	34.0634722282681608	-117.718976085676246
8892	2020-01-08 19:31:36	2020-01-08	Dr. Berkley Rohan	dr.berkley.rohan@geemail.com	Shreveport	Louisiana	3337722317882771327	18603ec5fa266fbdba621959df807757	VISA 13 digit	32.4685740721184786	-93.8082576138645408
8893	2020-01-08 20:28:59	2020-01-08	Sydney Predovic	sydney.predovic@geemail.com	Moreno Valley	California	4142242950897	51f190112562bb4acb699a5984e0b8ee	American Express	34.0180295790538167	-117.184491834088035
8894	2020-01-08 20:36:09	2020-01-08	Miss Tomeka Yost	miss.tomeka.yost@geemail.com	San Francisco	California	210068985743529779	579fdfaef78c708dd74467a78875a695	Discover	37.8110507732971115	-122.424590350045221
8895	2020-01-08 21:43:41	2020-01-08	Ronny Hammes-Hodkiewicz	ronny.hammes.hodkiewicz@geemail.com	San Francisco	California	3462136746737045	0b4065e87801a752f2bacc3528f5a9ea	VISA 13 digit	37.7768394663251783	-122.449965934781503
8896	2020-01-08 21:54:54	2020-01-08	Rock Dietrich	rock.dietrich@woohoo.com	Houston	Texas	4940946584329897	56f3790e2979e9d8034c9a8822818e16	JCB 16 digit	29.7876113710537567	-95.3257139113280942
8897	2020-01-08 22:15:42	2020-01-08	Amina Fisher	amina.fisher@geemail.com	Athens	Georgia	4910563040645083	eb62b90bb9f45a54fa5445f827b2138c	JCB 16 digit	34.0281944651346606	-83.4251942164845701
8898	2020-01-08 22:51:26	2020-01-08	Cleo Stark Sr.	cleo.stark.sr.@geemail.com	New York	New York	4636936497777364	0e0090c618d75f9d3e79e08c98de0924	Voyager	40.675655270949008	-73.9576185368828476
8899	2020-01-08 22:53:29	2020-01-08	Minda Witting PhD	minda.witting.phd@warmmail.com	San Francisco	California	561207187995621	16eae9f870b37abd8809bcf762189a29	Mastercard	37.7583017215595262	-122.414069830058565
8900	2020-01-08 23:13:06	2020-01-08	Don Morissette Jr.	don.morissette.jr.@geemail.com	San Francisco	California	4493735300913246	c8231dfcdcb8e287cc1bdcdd51922caf	VISA 13 digit	37.7513051764507992	-122.443542158891759
8901	2020-01-08 23:48:50	2020-01-08	Mr. Wing White	mr.wing.white@geemail.com	Cape Coral	Florida	3337667955866249625	64e532159513eaf11c9ce5fb4bf00100	Discover	26.6662233112350116	-82.0519142631512182
8902	2020-01-08 23:50:47	2020-01-08	Mrs. Sonja Blick MD	mrs.sonja.blick.md@geemail.com	San Francisco	California	3112817331115215875	9be0044abf8136ed2f61183a4e9a6106	Maestro	37.7878404774921748	-122.431414290042184
8903	2020-01-08 23:56:22	2020-01-08	Jemima O'Connell	jemima.o'connell@geemail.com	Wichita	Kansas	180029357981359764	cce8bf8d018cb67463c76f8a30b74e63	VISA 16 digit	37.7851095206446956	-97.2880421736013119
8904	2020-01-09 00:15:15	2020-01-09	Lolla Hermiston	lolla.hermiston@woohoo.com	San Francisco	California	53331217950055392	5f45a61994372c9eb71de5f0545aceb7	VISA 16 digit	37.7615786432367244	-122.419255341130253
8905	2020-01-09 00:50:45	2020-01-09	Killian Rutherford DVM	killian.rutherford.dvm@geemail.com	San Francisco	California	3096544487652753783	9783e5fd365dde4437147f51094741ff	JCB 16 digit	37.7670502939115309	-122.405007217189208
8906	2020-01-09 01:03:42	2020-01-09	Darci Jaskolski	darci.jaskolski@geemail.com	San Francisco	California	4178430645897229	d73ad2632ecb13348e5de8e3abeea4f9	VISA 13 digit	37.7566964702215131	-122.434826049754278
8907	2020-01-09 01:14:58	2020-01-09	Dr. Tariq Abshire	dr.tariq.abshire@geemail.com	Tulsa	Oklahoma	4605476190676016	bc9f07523c54a4fca55c5d0ebef2ebf7	Discover	36.0408388646222591	-95.9383725437290877
8908	2020-01-09 02:34:43	2020-01-09	Rodger Dickens	rodger.dickens@geemail.com	New York	New York	502033956450697	0a59b5ed9ee3c5af3b74d6a6072f881b	Voyager	40.7354478531740583	-73.8981876090995939
8909	2020-01-09 02:45:13	2020-01-09	Harris Barton	harris.barton@geemail.com	Berkeley	California	3337191729728100267	d7254da17316fece6dad0d8d56d28473	VISA 16 digit	37.8839412884175744	-122.290571092805948
8910	2020-01-09 02:46:49	2020-01-09	Toshio Cummings	toshio.cummings@warmmail.com	Riverside	California	676170010257981	4e7e9bf4dce2e9bcbfaddb99d4c5789c	JCB 15 digit	33.9539050369936959	-117.484624527298649
8911	2020-01-09 02:47:13	2020-01-09	Mr. Gilbert Hartmann	mr.gilbert.hartmann@geemail.com	San Francisco	California	210033331531398782	5aa7781a92250d767a592c60a1cf3274	JCB 16 digit	37.7648071424144263	-122.421622278170418
8912	2020-01-09 02:48:21	2020-01-09	Burrell Mann	burrell.mann@geemail.com	Huntsville	Alabama	4171552207694566	96e5e98bdb0aa480a46a3bbd68c383d5	VISA 16 digit	34.6952294450029726	-86.5737863391656504
8913	2020-01-09 02:57:42	2020-01-09	Jaylan Bednar	jaylan.bednar@geemail.com	San Francisco	California	3476503323687220	39588b2b425142eaf3f76f23f1ca2d0c	JCB 16 digit	37.7732266984595668	-122.458318444861618
8914	2020-01-09 04:13:10	2020-01-09	Miss Geri Smith	miss.geri.smith@geemail.com	Winston–Salem	North Carolina	51430006645966265	a2e7fa51b4ff8480f03aaf99aaed145e	VISA 16 digit	36.199077351740371	-80.303614569561546
8915	2020-01-09 04:24:09	2020-01-09	Mrs. Hildred Koch PhD	mrs.hildred.koch.phd@geemail.com	Berkeley	California	180080779216115511	c46376b83789e824426ed370d2853002	Maestro	37.8740274987553747	-122.251812069403485
8916	2020-01-09 04:29:31	2020-01-09	Waylon Kuvalis-Halvorson	waylon.kuvalis.halvorson@geemail.com	San Francisco	California	3337170682129506654	0b9c6929c0ba5e0c8d5c3b4d435fc74d	Voyager	37.7511325083467142	-122.443786809075618
8917	2020-01-09 05:18:42	2020-01-09	Dr. Storm Thompson	dr.storm.thompson@geemail.com	Bakersfield	California	869929707065905686	0a803c3f7beacafe48e3cc93427e2dc4	Mastercard	35.2778025932319466	-118.965921504077684
8918	2020-01-09 05:26:16	2020-01-09	Olena Considine DDS	olena.considine.dds@geemail.com	Long Beach	California	6011958703522641332	ead61ed9a6f12e91ebe363a187c4bf03	JCB 15 digit	33.8722387874785795	-118.238442933342597
8919	2020-01-09 07:07:10	2020-01-09	Pansy Kub-Legros	pansy.kub.legros@geemail.com	Salt Lake City	Utah	3112044782701558364	a7202ea6d6c75e37a332d08220498282	JCB 15 digit	40.8123985564481444	-111.851827091997492
8920	2020-01-09 07:20:15	2020-01-09	Mitzi O'Kon-VonRueden	mitzi.o'kon.vonrueden@geemail.com	Stockton	California	3706473511057153	e03ffa8205569d4fbb51f6a9dd685ec8	Discover	38.0489070885080878	-121.363112822416426
8921	2020-01-09 07:23:04	2020-01-09	Juliet Kemmer	juliet.kemmer@geemail.com	Albuquerque	New Mexico	3158519344884480019	165d9911d170a39c92425c5dbb9995ef	JCB 16 digit	35.1940609001688713	-106.659590110143284
8922	2020-01-09 07:38:57	2020-01-09	Jahir Johnston	jahir.johnston@warmmail.com	Carlsbad	California	3757988781800741	0acc52f001e7504693acade4daf57ffc	VISA 16 digit	33.1886882409393777	-117.292865513243896
8923	2020-01-09 08:02:46	2020-01-09	Vester Hoeger	vester.hoeger@geemail.com	San Francisco	California	54415628525254683	68454a837970393c30955615b6288d17	JCB 15 digit	37.7679693222405746	-122.409617870688791
8924	2020-01-09 08:42:05	2020-01-09	Mario Bogisich	mario.bogisich@geemail.com	Norman	Oklahoma	3112034746011985742	7cb82110968a0fc35f26e432ffdcfa09	Diners Club / Carte Blanche	35.2237459825858465	-97.319285688248641
8925	2020-01-09 09:19:16	2020-01-09	Erla Eichmann-Quitzon	erla.eichmann.quitzon@geemail.com	Milwaukee	Wisconsin	6011379758395711456	be2b1dd8aa409d43bac93f2dde7ba5ca	American Express	42.9822622745849188	-87.9869369834762125
8926	2020-01-09 09:53:03	2020-01-09	Major Roberts	major.roberts@geemail.com	San Francisco	California	180060412934517867	0d390b648834daa3c9c3adb7c7d38072	Discover	37.7559909228378388	-122.436929992143703
8927	2020-01-09 09:53:56	2020-01-09	Marisela Smith	marisela.smith@geemail.com	West Covina	California	6011315092014868662	0f180dd90dcb54e1412dc4a53be66dbf	VISA 13 digit	33.982052560021728	-117.815655875399329
8928	2020-01-09 10:18:34	2020-01-09	Squire Grimes-Hessel	squire.grimes.hessel@warmmail.com	Berkeley	California	4486286673836	e35773019c443bd202d4aa96d8e0fc86	Mastercard	37.8772723085725715	-122.265807067217779
8929	2020-01-09 10:37:55	2020-01-09	Washington Marks	washington.marks@warmmail.com	San Antonio	Texas	3096052910017834182	6f53d2187bf6c64628ed06642d8f371b	Voyager	29.5466855580057945	-98.4688896938994418
8930	2020-01-09 11:19:05	2020-01-09	Burgess Will	burgess.will@geemail.com	San Francisco	California	3337963788041045241	270f503764ceb2bbb9390206633a24b5	Maestro	37.7728836208454268	-122.420236627559859
8931	2020-01-09 11:33:25	2020-01-09	Desi D'Amore	desi.d'amore@warmmail.com	El Paso	Texas	3337903496374279576	f54d533d057a8ad858ed4cf937f82d11	VISA 13 digit	31.8460077008992464	-106.443907215025277
8932	2020-01-09 11:34:17	2020-01-09	Raquan Denesik	raquan.denesik@warmmail.com	Birmingham	Alabama	4182548843208826	483b1bd1651d76ba163fdee1a95515ea	Mastercard	33.6199692483317136	-86.8244760400857842
8933	2020-01-09 12:01:26	2020-01-09	Mr. Jayme Kutch	mr.jayme.kutch@geemail.com	San Francisco	California	4816635471419355	4a55cc5618f92bf862fe98b8d8e69ee9	VISA 16 digit	37.7650628009688631	-122.415619357544443
8934	2020-01-09 12:05:59	2020-01-09	Khiry Trantow	khiry.trantow@geemail.com	New York	New York	3058952376921338	ba02c21bab648ed536100c31e11f62e0	Discover	40.7364201754555069	-74.0247883140470861
8935	2020-01-09 12:16:39	2020-01-09	Santiago Cronin DVM	santiago.cronin.dvm@warmmail.com	Sunnyvale	California	51632421648754012	490b43d7060c6d72075d846659e982a9	Mastercard	37.4657980851355958	-121.960287941639507
8936	2020-01-09 12:35:34	2020-01-09	Reed Goyette	reed.goyette@geemail.com	Minneapolis	Minnesota	4883143504750	75bdfd36c82cb06289683158a614fcf9	VISA 13 digit	44.8735497371379282	-93.2146120535947347
8937	2020-01-09 12:52:29	2020-01-09	Dr. Levar Leannon	dr.levar.leannon@geemail.com	Anchorage	Alaska	3088286715733336778	d76987b734c67183761ca6fd3dae930a	Maestro	61.1975887465972477	-149.206403795967987
8938	2020-01-09 13:22:47	2020-01-09	Milda Weber	milda.weber@geemail.com	San Francisco	California	3748819571585931	daa787efb1f45c27ad455216b5106f79	American Express	37.7620028384721067	-122.42852032888257
8939	2020-01-09 13:29:07	2020-01-09	Mrs. Milly Jones	mrs.milly.jones@geemail.com	San Francisco	California	4638273414408826	6ca4271a9831e29bfa71a70f868ebf30	JCB 16 digit	37.7573727152122842	-122.432415902620718
8940	2020-01-09 13:42:40	2020-01-09	North Batz	north.batz@geemail.com	San Francisco	California	3337352790499564037	a351f59fa0fe87dc18daa6f4e4371758	JCB 16 digit	37.7454107560167031	-122.414452541633906
8941	2020-01-09 14:15:10	2020-01-09	Berenice Zieme-Medhurst	berenice.zieme.medhurst@geemail.com	Jurupa Valley	California	6011670523149071144	1eaa05e9f94e989b05ae3096285923f1	Voyager	34.0460206398669669	-117.494512614842876
8942	2020-01-09 14:15:24	2020-01-09	Mirtie McGlynn-Bashirian	mirtie.mcglynn.bashirian@geemail.com	Los Angeles	California	3767070468199040	6154f8b5686ca1caaa82f9f20d320f1b	Mastercard	34.0201592015434002	-118.320332219590611
8943	2020-01-09 14:24:19	2020-01-09	Eddy O'Connell	eddy.o'connell@geemail.com	Coral Springs	Florida	3403230967723115	81b1bd350083c6d3dab561ac84133ee3	American Express	26.3399888206802331	-80.3343047282781413
8944	2020-01-09 14:35:48	2020-01-09	Beyonce Waters	beyonce.waters@woohoo.com	Minneapolis	Minnesota	4784569022029652	ff7147b5da65ca60aecbbeaab3c275fa	Mastercard	44.8745518553156373	-93.34360551566742
8945	2020-01-09 14:41:30	2020-01-09	Helmer Klocko	helmer.klocko@geemail.com	Los Angeles	California	6011419741564087025	f90178ebb3ddde04e9330c48cf834801	VISA 16 digit	34.0086241636291149	-118.46750668650418
8946	2020-01-09 14:45:26	2020-01-09	Dr. Lott Lubowitz Sr.	dr.lott.lubowitz.sr.@warmmail.com	Phoenix	Arizona	4738215959567051	424809156389cf63afaaff38315f010e	VISA 16 digit	33.6333567595042311	-112.012765631165735
8947	2020-01-09 14:56:37	2020-01-09	Dr. Elias Harvey MD	dr.elias.harvey.md@geemail.com	Memphis	Tennessee	3337393461580038106	ecc4f6a6b0f1d930de512b1e7b58190c	VISA 13 digit	35.0945246090248233	-89.89816615081169
8948	2020-01-09 14:58:27	2020-01-09	Mr. Matthias Lakin II	mr.matthias.lakin.ii@woohoo.com	Los Angeles	California	210057503496070942	5eaa40013347af80e58c8793c6480b8d	VISA 16 digit	34.0372674048278441	-118.453303266595299
8949	2020-01-09 15:06:56	2020-01-09	Duff Walter	duff.walter@geemail.com	San Francisco	California	503840158519476	f96620dfdf259c8cd2dc5693f9481cc7	VISA 16 digit	37.779330512055715	-122.424567953462429
8950	2020-01-09 15:12:16	2020-01-09	Mrs. Bebe Mayer	mrs.bebe.mayer@geemail.com	Columbus	Ohio	3337036611927638777	4d03b8aef083ae0af22259de7a1cc734	Voyager	40.0092825437009338	-83.0001948911931464
8951	2020-01-09 15:15:56	2020-01-09	Henri Feest	henri.feest@warmmail.com	Fargo	North Dakota	180091038140502931	77c3a2df0d6d286c532d91118befcb7d	JCB 16 digit	46.9118468067374081	-96.7465638569053255
8952	2020-01-09 16:00:15	2020-01-09	Dr. Susannah Stokes PhD	dr.susannah.stokes.phd@woohoo.com	Hialeah	Florida	180032775711305861	09611807e2c6b7e1c2b3a8bece89077a	Voyager	25.9087195818290112	-80.3146962903343109
8953	2020-01-09 16:07:04	2020-01-09	Coral Leffler MD	coral.leffler.md@geemail.com	Phoenix	Arizona	4094689568064627	53970380ea2af580f2da2db62a7bf1bd	JCB 15 digit	33.4772170577131263	-112.04332239343077
8954	2020-01-09 16:15:18	2020-01-09	Coleton Runte DVM	coleton.runte.dvm@woohoo.com	Anchorage	Alaska	4166063981137	26efa23d48264781f02f60415ca5efbe	Maestro	61.1468134018808627	-149.228278205183528
8955	2020-01-09 16:20:46	2020-01-09	Mrs. Kathryne Orn	mrs.kathryne.orn@geemail.com	Lincoln	Nebraska	869990280725756307	9f1ed97ec6e41bff74b547437ea609ac	Maestro	40.728991261033336	-96.5932270110279347
8956	2020-01-09 16:31:31	2020-01-09	Deyanira Dickens	deyanira.dickens@geemail.com	Berkeley	California	180085428490592095	09f9d1aa90cc687c5e586b1fe0e0187c	Discover	37.9018486133891344	-122.303142297940411
8957	2020-01-09 17:00:06	2020-01-09	Manuela Huel	manuela.huel@geemail.com	Las Vegas	Nevada	3010748764708339	5f7ba69c1ee7fd0701d72e9f93f38b53	Voyager	36.2838140991616953	-115.169840820014841
8958	2020-01-09 17:16:50	2020-01-09	Billie Lowe	billie.lowe@geemail.com	Las Vegas	Nevada	3462955497616383	2a45b06c7a7e4937614b432ff25cba6d	Mastercard	36.1394121959906087	-115.196910186272476
8959	2020-01-09 17:35:03	2020-01-09	Durell Larson	durell.larson@geemail.com	North Las Vegas	Nevada	3700769749161964	557fa9c26110fcda97b53a52ea7c2a7f	JCB 16 digit	36.3060829551115631	-115.066336936339368
8960	2020-01-09 17:45:28	2020-01-09	Mr. Murphy Johns III	mr.murphy.johns.iii@geemail.com	New York	New York	4575614585419321	220faf83ce011577eba6997b3b7878cf	JCB 16 digit	40.5663186954092225	-74.0091083716031193
8961	2020-01-09 17:55:10	2020-01-09	Icey Hoeger-Huel	icey.hoeger.huel@woohoo.com	Ventura	California	060464175339445	3db469c9855e8253977c7bd91bf82bc6	JCB 15 digit	34.2582535046312984	-119.265922788820035
8962	2020-01-09 18:39:35	2020-01-09	Mrs. Cheryle Auer	mrs.cheryle.auer@geemail.com	Riverside	California	55610197147225052	b75137cdd4afc353eabca92cc08ef97d	American Express	33.8764524761535242	-117.381825277252858
8963	2020-01-09 18:58:45	2020-01-09	Dr. Althea White DDS	dr.althea.white.dds@warmmail.com	Atlanta	Georgia	210003873088507204	f930cf217731d3c8deeb452b84fcb578	JCB 16 digit	33.857066727876294	-84.35450108102971
8964	2020-01-09 19:21:20	2020-01-09	Desean Walter	desean.walter@geemail.com	Oakland	California	502015192178240	e9928315c2e72c26f1fbe6cadb4a6b21	Maestro	37.8060500188592314	-122.243378999597923
8965	2020-01-09 19:30:30	2020-01-09	Rudy Kiehn	rudy.kiehn@geemail.com	Houston	Texas	3337483661938572588	4514d2ae64416038712e643d06e8ef1a	Voyager	29.7980655202720328	-95.3404355849154257
8966	2020-01-09 20:35:05	2020-01-09	Nathen Rutherford-Auer	nathen.rutherford.auer@warmmail.com	San Francisco	California	3012584344558979	36506f1f79cbf2ed0fde47fff8372e2c	Discover	37.8051293551618244	-122.449255173106323
8967	2020-01-09 20:36:58	2020-01-09	Rolland Douglas	rolland.douglas@geemail.com	Lincoln	Nebraska	6011241475992869449	3f780b6870d3c765b1ef4bea93939e7e	JCB 15 digit	40.7761728777103087	-96.7193135350637192
8968	2020-01-09 20:38:42	2020-01-09	Ab Dooley-Carroll	ab.dooley.carroll@woohoo.com	El Paso	Texas	4979700868784	f56ce881fb38a4028bc8ce514499fcb8	VISA 13 digit	31.7522951918017142	-106.353995219197131
8969	2020-01-09 21:38:14	2020-01-09	Stoney Schowalter	stoney.schowalter@geemail.com	Cincinnati	Ohio	3005392193884828	129b0c47646f75547a41bcab785f7ef2	VISA 16 digit	39.1386966697636964	-84.5352293399434416
8970	2020-01-09 21:38:35	2020-01-09	Horace Walsh	horace.walsh@warmmail.com	Chicago	Illinois	675973287582727	15ae54b3093705c5d6a51aff8236fb49	JCB 15 digit	41.9127223666127762	-87.6020959081623687
8971	2020-01-09 22:13:06	2020-01-09	Aric Ebert-Kreiger	aric.ebert.kreiger@warmmail.com	El Paso	Texas	55300557708155748	9aa49f7dae01eb8cef9a52c472489102	Voyager	31.876229420054333	-106.464977829808376
8972	2020-01-09 23:04:22	2020-01-09	Alfredo Welch	alfredo.welch@geemail.com	Louisville	Kentucky	180057505287477277	2776d6f834f05abe51e7f8e8dc32ab68	VISA 16 digit	38.2440697459407133	-85.5886395327352005
8973	2020-01-09 23:12:27	2020-01-09	Acy Glover	acy.glover@geemail.com	Sterling Heights	Michigan	4562542009689382	fa5bd05edfbf1822b7858bf46447190c	VISA 16 digit	42.5932021857321317	-82.9568380219090642
8974	2020-01-09 23:28:29	2020-01-09	Dino Kozey-Morar	dino.kozey.morar@warmmail.com	Miami	Florida	3112006167014287495	2c02b2632c2428f9e6a16f073fc7c431	JCB 15 digit	25.769489879780263	-80.2193339117676061
8975	2020-01-09 23:49:29	2020-01-09	Damond Little	damond.little@geemail.com	Berkeley	California	869945350962556870	f4d4a5e6d8f3e21422f9ef0c3773a785	JCB 15 digit	37.8506643662307312	-122.279230004152566
8976	2020-01-09 23:57:56	2020-01-09	Farrell Baumbach MD	farrell.baumbach.md@geemail.com	Memphis	Tennessee	869960134313002242	a24c3405927f2b0c60edc043fdc53c8a	Discover	35.1030878571394851	-90.0711525424174937
8977	2020-01-10 00:45:19	2020-01-10	Bunk Krajcik	bunk.krajcik@geemail.com	Los Angeles	California	3011739166961930	c160513b5a04bc63a138e06f0d898b5d	JCB 16 digit	34.0526520181778807	-118.365969904790816
8978	2020-01-10 00:59:04	2020-01-10	Burnell Denesik	burnell.denesik@geemail.com	Kansas City	Missouri	869972693809235463	6f36cf4a137c6027ad6f12e3981c607b	VISA 16 digit	39.2051031542312387	-94.6279998730160372
8979	2020-01-10 01:29:32	2020-01-10	Harvie Tremblay	harvie.tremblay@woohoo.com	Lakewood	Colorado	4506893091459955	67fb6d39698ce62448f8570a51918a03	JCB 15 digit	39.7087485611844855	-105.028344380159297
8980	2020-01-10 02:00:22	2020-01-10	Kortney Herman	kortney.herman@geemail.com	San Diego	California	4708686459288628	b6d654b187bce82fcdc9c0d33e240f04	Voyager	32.7937316151402882	-117.186935419207444
8981	2020-01-10 02:07:21	2020-01-10	Maury Dickinson Jr.	maury.dickinson.jr.@geemail.com	San Francisco	California	3008819286833855	5ae49623a0e6b61428792c8a3d5aecb8	VISA 13 digit	37.7734301996097983	-122.443101701638994
8982	2020-01-10 02:22:04	2020-01-10	Selena Walsh	selena.walsh@geemail.com	Albuquerque	New Mexico	54854434865677015	f704a78961cae02b55d7169e6d28529b	VISA 13 digit	35.1001823171641689	-106.676168216026952
8983	2020-01-10 02:26:11	2020-01-10	Larue Rogahn	larue.rogahn@geemail.com	Tampa	Florida	52215396014288032	277a83c71cf1f1dac97d164f04a2ef1a	Maestro	28.015142496500534	-82.4317761258900106
8984	2020-01-10 02:59:34	2020-01-10	Miss Kinsley Wuckert	miss.kinsley.wuckert@warmmail.com	Detroit	Michigan	4039646048643	4cba03d70869e9a828c51a410abf4045	Voyager	42.4734100965708521	-83.1284521645054184
8985	2020-01-10 03:38:50	2020-01-10	Wayde Deckow	wayde.deckow@geemail.com	San Francisco	California	3112637007440295315	1a3697ead657da509062c389c6eb8bbf	Mastercard	37.7721486984340729	-122.402025510881074
8986	2020-01-10 03:42:01	2020-01-10	Laverne Hahn	laverne.hahn@geemail.com	Boston	Massachusetts	3096056165871720888	8bfa8cab7331a8168190640f70cd26fd	VISA 13 digit	42.3646926365960397	-71.0496593652244712
8987	2020-01-10 03:45:11	2020-01-10	Tamisha Kreiger	tamisha.kreiger@geemail.com	Lakewood	Colorado	561257092631191	ab86cfbba8ffde966efbd05d7532454b	Diners Club / Carte Blanche	39.7834827571116421	-105.138552138025304
8988	2020-01-10 03:54:43	2020-01-10	Mr. Carroll Connelly	mr.carroll.connelly@geemail.com	Chicago	Illinois	6011012640744532937	4ab5940cc66494a0561b98df99e10d6b	Voyager	41.9063033666763474	-87.7356393026683463
8989	2020-01-10 04:06:58	2020-01-10	Rosetta Walker	rosetta.walker@geemail.com	Irvine	California	52720253270228442	e9ca48fbe87c4357b4cac93fe23536a5	JCB 16 digit	33.6086060684189221	-117.754653547193101
8990	2020-01-10 04:19:11	2020-01-10	Damion Smitham	damion.smitham@geemail.com	Hampton	Virginia	4569038655647	050bafbf017e2fa47d18f851a3302c8d	American Express	36.9728074476607134	-76.2190128280412438
8991	2020-01-10 04:26:28	2020-01-10	Rosalind DuBuque	rosalind.dubuque@woohoo.com	Norfolk	Virginia	210057398699303111	751fc6e8df72020eb494db1a966d5cef	Diners Club / Carte Blanche	37.0226724190656142	-76.3418495038527993
8992	2020-01-10 04:42:09	2020-01-10	Ms. Kacy Brakus DDS	ms.kacy.brakus.dds@geemail.com	Brownsville	Texas	4684614969603621	ee28bfba9e7a8820627e55260d862ea7	JCB 16 digit	25.9192384109910563	-97.5007551783416346
8993	2020-01-10 05:22:19	2020-01-10	Miss Ethyl Schmeler DVM	miss.ethyl.schmeler.dvm@warmmail.com	Dallas	Texas	3734262726849538	5d92cd0aac2ebcdc18178f2f8b1ad228	Diners Club / Carte Blanche	32.7772498434681481	-96.7571597539782431
8994	2020-01-10 05:51:30	2020-01-10	Dr. Marius Schroeder	dr.marius.schroeder@geemail.com	West Palm Beach	Florida	180005909103060775	3d1dcbb9845560ac15285d84e59168a2	VISA 13 digit	26.8079356877446173	-80.1835122860338601
8995	2020-01-10 06:59:37	2020-01-10	Deforest Ebert	deforest.ebert@geemail.com	San Francisco	California	4982350955800256	7273ca664fe7fd8c1ba0add15519c1d5	Voyager	37.7857153857891888	-122.42819318940127
8996	2020-01-10 07:07:17	2020-01-10	Isaak Emmerich	isaak.emmerich@geemail.com	Joliet	Illinois	869957961221478790	755ee722beeebd217eaf93905881b486	Mastercard	41.5041850360900142	-88.1373656710714073
8997	2020-01-10 07:26:54	2020-01-10	Dannielle Bode	dannielle.bode@geemail.com	Chicago	Illinois	3112132034606715928	24c1ba6c7520363037e886efcdc36364	Maestro	41.8926407525151987	-87.6861546204920757
8998	2020-01-10 07:43:58	2020-01-10	Tavares Berge-Nienow	tavares.berge.nienow@warmmail.com	Berkeley	California	53234724641534568	89550b1345503476e7211075686a79a6	JCB 16 digit	37.9041670118712233	-122.258508778256314
8999	2020-01-10 07:58:04	2020-01-10	Jermaine Huels-Zulauf	jermaine.huels.zulauf@geemail.com	Rancho Cucamonga	California	6011223958453210478	b03a981bb1bb6202b51e211f92e5a042	VISA 16 digit	34.0982451843090359	-117.524985090830171
9000	2020-01-10 08:05:23	2020-01-10	Isaak Lynch	isaak.lynch@warmmail.com	Chicago	Illinois	4680600205966	ace7a8454fa77e56a820203badcceb16	Discover	41.7864215368241076	-87.7014152816992265
9001	2020-01-10 08:07:40	2020-01-10	Ruthanne Cruickshank	ruthanne.cruickshank@geemail.com	Miami	Florida	3731880276141171	0cba60d9ab10d19b79029731c813c057	Voyager	25.8303937158219519	-80.2220574515279452
9002	2020-01-10 08:42:10	2020-01-10	Miss Lee Fadel	miss.lee.fadel@geemail.com	Chicago	Illinois	52530185578428961	5ceea8c96e302c17313e2dea91d1f586	American Express	41.8154535015415405	-87.6364830614097343
9003	2020-01-10 08:51:24	2020-01-10	Mr. Keon Boyer IV	mr.keon.boyer.iv@geemail.com	Chicago	Illinois	6011542683549049144	9012250e5f6b3d798b28be93176f3fd8	Voyager	41.7400208564776918	-87.5874162320543093
9004	2020-01-10 09:01:28	2020-01-10	Karin Wyman	karin.wyman@geemail.com	San Antonio	Texas	3441510445456899	8d91eb309b06e299c4d00792ceb43050	JCB 15 digit	29.4676675031032431	-98.5978797597646661
9005	2020-01-10 09:04:07	2020-01-10	Ami Mueller	ami.mueller@geemail.com	Detroit	Michigan	4700157960939479	e4286203f9a2522b0f30aaaccdb0b8cf	American Express	42.3907626716345547	-83.1131946869313651
9006	2020-01-10 09:56:02	2020-01-10	Loney Wilkinson	loney.wilkinson@geemail.com	Phoenix	Arizona	3528194627325643407	d14933caa97a4ce3e495ea563b4f9ef0	Diners Club / Carte Blanche	33.6629824637368316	-112.117392435010899
9007	2020-01-10 10:11:40	2020-01-10	Deryl Lemke	deryl.lemke@woohoo.com	Sparks	Nevada	4384501918657639	a246a7906ede385cbe6d2bd59b1fe075	VISA 16 digit	39.5037589170277101	-119.779232627883928
9008	2020-01-10 10:28:17	2020-01-10	Dr. Ruffin Rath	dr.ruffin.rath@woohoo.com	Berkeley	California	869940077337669121	c4e0905205693855f5530e4acbeabe88	VISA 16 digit	37.8944380508474765	-122.217120426739442
9009	2020-01-10 10:55:35	2020-01-10	Mr. Kyree Emard	mr.kyree.emard@geemail.com	Jacksonville	Florida	3158310744776702456	62063a19d1852e781b460fe95b2869f7	JCB 16 digit	30.2788705909211195	-81.6514114826996007
9010	2020-01-10 11:27:47	2020-01-10	Georgie Carroll-McDermott	georgie.carroll.mcdermott@geemail.com	Oakland	California	55729219045732332	ace3f0ea9e341cfb7ab12ce2713e05ac	Voyager	37.7854396543570488	-122.272401237992398
9011	2020-01-10 12:25:10	2020-01-10	Dominic Effertz	dominic.effertz@geemail.com	Henderson	Nevada	501806909798677	31444fe021897b3d2bf538d9cababca2	Discover	36.10536908129491	-114.967377051680174
9012	2020-01-10 12:45:45	2020-01-10	Osbaldo Considine DDS	osbaldo.considine.dds@warmmail.com	Evansville	Indiana	4021195278291987	e78b51542d70970ffdb375a93078c523	VISA 16 digit	38.0292949460584637	-87.4713631886921803
9013	2020-01-10 13:02:47	2020-01-10	Mrs. Octavia Rosenbaum	mrs.octavia.rosenbaum@geemail.com	Milwaukee	Wisconsin	869995439098896521	2940f2609d796084c9085a24bb93b192	VISA 16 digit	42.9959216504443447	-87.9418293996814668
9014	2020-01-10 13:03:40	2020-01-10	Ms. Shanna Yost PhD	ms.shanna.yost.phd@geemail.com	Clearwater	Florida	4788222196215055	cbdbc37ac6d983986ff72d9bb511b38d	American Express	28.0317494130820037	-82.7850679966885536
9015	2020-01-10 13:31:24	2020-01-10	Miss Zillah Ebert DVM	miss.zillah.ebert.dvm@woohoo.com	Omaha	Nebraska	6011985298791396087	fb36965a50ea4b4dd45bfd235364b7f5	Maestro	41.1993084769841289	-96.122770980850234
9016	2020-01-10 13:38:03	2020-01-10	Kelley Rosenbaum	kelley.rosenbaum@geemail.com	Bakersfield	California	869936893178549800	1db228165b2478d5da9c12bbdd04a65f	Voyager	35.266558323445544	-119.000687102302166
9017	2020-01-10 14:13:58	2020-01-10	Nyah Corwin	nyah.corwin@woohoo.com	San Francisco	California	060410381311918	9605d1360548d7a634539dcb0ca8a7e2	American Express	37.7617433544978667	-122.465029207147992
9018	2020-01-10 14:14:40	2020-01-10	Melvin Schuppe	melvin.schuppe@geemail.com	Houston	Texas	3158162542801758116	83fb15c4ded34ea6d574087c408bef17	JCB 16 digit	29.7305631736837341	-95.4754381518825852
9019	2020-01-10 14:17:16	2020-01-10	Welton Feil-Hudson	welton.feil.hudson@woohoo.com	San Francisco	California	6011373278846728906	2ac491f7b128f82c182a76c6eb3e4749	JCB 16 digit	37.7636029095905528	-122.424346385751122
9020	2020-01-10 14:23:19	2020-01-10	Tory Grimes	tory.grimes@warmmail.com	San Francisco	California	4747153916388460	34fe01bafed0ae14ed91a361a63a8a78	JCB 16 digit	37.7824117825820665	-122.401594866885318
9021	2020-01-10 14:23:54	2020-01-10	Audy Cassin	audy.cassin@geemail.com	Las Vegas	Nevada	3057837970209738	3b9150dd2c98a0664afdcc67cb01a54d	Discover	36.2390338280338753	-115.285337214891229
9022	2020-01-10 14:32:25	2020-01-10	Cordero Schaefer	cordero.schaefer@geemail.com	Chicago	Illinois	4248925321247	3b6bd7ead96dff5b88bd01bb78cbb094	VISA 13 digit	41.8520821064081048	-87.7144932601164982
9023	2020-01-10 15:11:43	2020-01-10	Jefferey Green Sr.	jefferey.green.sr.@woohoo.com	Oakland	California	210041154356593588	1087c9340f4968df890cf8a622e7a5a3	VISA 16 digit	37.7792105892939674	-122.278233973358027
9024	2020-01-10 15:13:31	2020-01-10	Shanon Bergnaum	shanon.bergnaum@geemail.com	Miami	Florida	3158020824065727793	7139671b57e5245b76a676fe313b271d	American Express	25.7064342550605538	-80.2374663777522841
9025	2020-01-10 15:52:51	2020-01-10	Loria Frami	loria.frami@geemail.com	Pittsburgh	Pennsylvania	869974970931994052	0f778f08e2b84c4b2136b14dd7e8402b	JCB 15 digit	40.4208897113755299	-79.9390571578111491
9026	2020-01-10 16:22:40	2020-01-10	Johnie Heaney-Legros	johnie.heaney.legros@geemail.com	Fontana	California	3112759352755648274	dab08bcc7f9d6db0b1f088a49f866e50	JCB 16 digit	34.0360158398430812	-117.402853457703813
9027	2020-01-10 16:54:34	2020-01-10	Miss Latoya Raynor	miss.latoya.raynor@geemail.com	Las Vegas	Nevada	4382032338607113	939466dcf91c151648350b88418e51c8	JCB 16 digit	36.2238065081749099	-115.23422538919597
9028	2020-01-10 17:09:37	2020-01-10	Mrs. Sheila Satterfield	mrs.sheila.satterfield@woohoo.com	Vista	California	4536027353845858	61c33f21054180ace8e4376a60e43b62	Mastercard	33.1520821723137047	-117.234322213713455
9029	2020-01-10 17:14:29	2020-01-10	Ms. Evelyn VonRueden PhD	ms.evelyn.vonrueden.phd@geemail.com	Philadelphia	Pennsylvania	6011993189990034316	6592426523bdfda44d838357976d01f7	JCB 16 digit	39.9185935584787259	-75.194367651305356
9030	2020-01-10 17:19:50	2020-01-10	Meda Klein	meda.klein@geemail.com	San Diego	California	6011004553136852476	391ad539498b9f70f62a559195bc0231	JCB 15 digit	32.7441544523995347	-117.081915913186975
9031	2020-01-10 17:22:53	2020-01-10	Nila Mann-Goodwin	nila.mann.goodwin@geemail.com	Berkeley	California	676326130097681	868126d192182e68efc11c993c3e4a1a	JCB 16 digit	37.8537367140753886	-122.273884835127532
9032	2020-01-10 17:22:57	2020-01-10	Derwin Reilly	derwin.reilly@warmmail.com	San Francisco	California	869947794979074179	71815aa3731e20e79f22447855570e10	Mastercard	37.7461824065899876	-122.413249653420564
9033	2020-01-10 17:36:49	2020-01-10	Christi Schimmel DDS	christi.schimmel.dds@geemail.com	Philadelphia	Pennsylvania	869939481851455391	b1ca7f96bc7a06db35c6a495b1e7f143	Diners Club / Carte Blanche	39.9809515681542464	-75.1390788950391197
9034	2020-01-10 17:39:10	2020-01-10	Mr. Brannon Steuber	mr.brannon.steuber@woohoo.com	Garden Grove	California	3528488778681131134	316ff664779183a57594c9dc131253cf	JCB 16 digit	33.7530337807547269	-117.988396065171798
9035	2020-01-10 17:49:00	2020-01-10	Keshawn King	keshawn.king@woohoo.com	Oakland	California	210095846529988026	411c894a4cdeac8446ccffebd9e29fbf	Mastercard	37.8332785896210808	-122.287099027334477
9036	2020-01-10 17:49:08	2020-01-10	Chandler Zieme	chandler.zieme@geemail.com	Pasadena	California	501839835757848	dbf55137887c4701dc973792bf2a2fe5	JCB 16 digit	34.2505726346135191	-118.096942023821555
9037	2020-01-10 18:06:56	2020-01-10	Elena Schaden	elena.schaden@geemail.com	San Francisco	California	4234539319289406	6c1816da57e291ecd68609099a024448	JCB 16 digit	37.752381913425026	-122.414999469582725
9038	2020-01-10 18:35:37	2020-01-10	Lawerence Von	lawerence.von@geemail.com	Fremont	California	4634752449955	48213091407955404e7ef09fc9ef6b69	JCB 16 digit	37.5449717100877365	-121.866626857965059
9039	2020-01-10 19:05:43	2020-01-10	Marisa Spencer	marisa.spencer@woohoo.com	Sioux Falls	South Dakota	060496812466769	52027bc8bf4bb8ae6152eef72069ec1f	Diners Club / Carte Blanche	43.6062998107720148	-96.6522592885121696
9040	2020-01-10 19:34:18	2020-01-10	Burnice Hahn	burnice.hahn@geemail.com	San Francisco	California	4513248570195086	f89402697f3dd64a16e995eeca817e54	VISA 16 digit	37.7663189938180253	-122.419116471834997
9041	2020-01-10 19:37:47	2020-01-10	Benji Von V	benji.von.v@geemail.com	Murrieta	California	180075273660069967	1c40095415b75495ce6cdf2f3d0eaff7	VISA 13 digit	33.6616246357656976	-117.116697321682793
9042	2020-01-10 19:38:20	2020-01-10	Amina Blanda PhD	amina.blanda.phd@geemail.com	Lexington	Kentucky	3096515662407264337	6ac4d783db6bde921c8e3012975a2815	VISA 16 digit	38.0605884445242566	-84.4181587477114022
9043	2020-01-10 19:50:23	2020-01-10	Mr. Tavion Kunde	mr.tavion.kunde@geemail.com	San Francisco	California	869981928396884102	aed59e56a3709e3eb715ce57140123a7	JCB 16 digit	37.7787297228930399	-122.406884825509863
9044	2020-01-10 19:52:14	2020-01-10	Selmer Purdy DDS	selmer.purdy.dds@geemail.com	Fort Worth	Texas	180026897917286964	c0b20495a5a42eeeb8196538fade13f5	VISA 16 digit	32.6996886953767429	-97.2734158026807023
9045	2020-01-10 20:02:20	2020-01-10	Mose Schulist	mose.schulist@warmmail.com	San Francisco	California	3482661410407159	fda27b70a1c5129a748b775ffafed5be	Maestro	37.7909152902656942	-122.424954999021324
9046	2020-01-10 20:14:40	2020-01-10	Dr. Krish McDermott	dr.krish.mcdermott@geemail.com	San Antonio	Texas	3096695461339594404	3f2b46f92f81548fc9540a57eefbda87	Diners Club / Carte Blanche	29.3973707567505542	-98.4523850445006019
9047	2020-01-10 20:15:53	2020-01-10	Clarice Glover	clarice.glover@woohoo.com	San Francisco	California	3012515756310897	f07d9d06f34dca5c70b26ea1c093c427	Mastercard	37.7956510715503029	-122.42357004418615
9048	2020-01-10 21:00:08	2020-01-10	Fae Schaefer-Botsford	fae.schaefer.botsford@woohoo.com	Los Angeles	California	4208641577292320	0a15f3fc1fc073e80935da8d371615b7	Diners Club / Carte Blanche	34.0843093072861407	-118.390784009033069
9049	2020-01-10 21:37:41	2020-01-10	Joey Feeney	joey.feeney@warmmail.com	Houston	Texas	3528714401243019780	b68d006d53602f2e77fa72dd8bea79e3	Maestro	29.7223038459274917	-95.4829767397619804
9050	2020-01-10 21:57:54	2020-01-10	Tripp Lesch	tripp.lesch@warmmail.com	San Francisco	California	4879031390973629	952bae7895bc2c69d787d244080441ff	VISA 16 digit	37.7882444806932654	-122.460149190797466
9051	2020-01-10 22:02:21	2020-01-10	Essie Howe	essie.howe@geemail.com	Chicago	Illinois	3797435216723850	4bc4813cd25be57484b2370826981620	JCB 16 digit	41.8132175268907105	-87.6550071511912989
9052	2020-01-10 22:10:14	2020-01-10	Clydie Heaney-Runte	clydie.heaney.runte@geemail.com	San Antonio	Texas	3528989936919380618	6f31f6dcb1c2c18ac9da53f3fdcd8663	JCB 16 digit	29.5546002857923504	-98.4863224582117027
9053	2020-01-10 22:22:51	2020-01-10	Benjamin Graham-Sanford	benjamin.graham.sanford@geemail.com	San Francisco	California	52663625751133036	d52dfdb3b87854486c193897f80d17f2	Discover	37.7616285400874645	-122.439991480746045
9054	2020-01-10 22:34:21	2020-01-10	Mr. Kieth Prosacco	mr.kieth.prosacco@geemail.com	Oceanside	California	3112279365304871677	9287744ddb38b77fd63584ce0914a001	Maestro	33.3035236258413647	-117.289527135210861
9055	2020-01-10 22:45:34	2020-01-10	Terry Hahn	terry.hahn@geemail.com	San Francisco	California	180045440007713667	de0c8ff0f4504d400b50ec510ff40d6e	Voyager	37.7836261005937857	-122.386709270778212
9056	2020-01-10 23:17:57	2020-01-10	Adelynn Roob-Mertz	adelynn.roob.mertz@geemail.com	Santa Clarita	California	180082054452822735	5935e1c9011e8639f0f3f1403f9ee31c	Diners Club / Carte Blanche	34.3674236781634406	-118.465948155672095
9057	2020-01-10 23:42:21	2020-01-10	Tad Collins PhD	tad.collins.phd@warmmail.com	Oakland	California	3528619119753748707	bbf9dac62080c0e360b286879a3ff05d	Mastercard	37.800843667169346	-122.269358194683591
9058	2020-01-10 23:45:34	2020-01-10	Mr. Malvin O'Keefe Jr.	mr.malvin.o'keefe.jr.@geemail.com	West Covina	California	4545419950351	deee899100306caa3c270cfd820e8e12	Mastercard	34.0378714420009416	-117.810743342579897
9059	2020-01-10 23:59:18	2020-01-10	Kenyatta Schumm	kenyatta.schumm@geemail.com	Oakland	California	639049162797440	cc1278a84807269a8c5e50f9ac60cf9b	Maestro	37.8331485355102615	-122.271521502223024
9060	2020-01-11 00:12:43	2020-01-11	Alene Rowe-Thompson	alene.rowe.thompson@geemail.com	Oakland	California	4992263542564772	92ef5747bada322876ae62d802e5ccfe	Mastercard	37.7974418802369314	-122.279202251144312
9061	2020-01-11 00:37:54	2020-01-11	Darline McLaughlin	darline.mclaughlin@woohoo.com	San Francisco	California	3337792025420353665	9be03492fa4882fba0adea62279a5c25	JCB 15 digit	37.7594810464172923	-122.429211238940439
9062	2020-01-11 00:41:26	2020-01-11	Garey Gusikowski	garey.gusikowski@woohoo.com	Oklahoma City	Oklahoma	4988347752021775	6d83c31f6c27c10e3e79ab66acd96e65	JCB 16 digit	35.3956603796597591	-97.4268547562312364
9063	2020-01-11 00:45:46	2020-01-11	Tonda Bode-Hackett	tonda.bode.hackett@warmmail.com	Atlanta	Georgia	52438953547293110	f845c64275b51054d2673033d384635a	JCB 15 digit	33.8159590413138318	-84.5005060327284099
9064	2020-01-11 01:01:19	2020-01-11	Mr. Slade Murphy III	mr.slade.murphy.iii@geemail.com	Chesapeake	Virginia	55211852679520279	4318fdd63f1cc5910b73b934ed12e6f4	VISA 13 digit	36.7132337969966258	-76.3959260749008564
9065	2020-01-11 01:08:54	2020-01-11	Bilal Daniel	bilal.daniel@geemail.com	San Francisco	California	869945701759144652	379a283457b291c17fc1dbe2a2b78cfd	Voyager	37.7457370110926291	-122.43787136160762
9066	2020-01-11 01:15:25	2020-01-11	Roma Carroll	roma.carroll@geemail.com	New York	New York	4846472981297004	8387eef8d6ba0f589b2c98fb30d60194	VISA 13 digit	40.6385897175632422	-73.9467310096498522
9067	2020-01-11 01:22:51	2020-01-11	Marisela Murray	marisela.murray@warmmail.com	San Jose	California	3112452958959007776	63c57aa776d4ef03456b8b0f9f00225d	VISA 16 digit	37.2210965961039051	-121.748105096885567
9068	2020-01-11 01:43:33	2020-01-11	Meg Rau	meg.rau@geemail.com	Pittsburgh	Pennsylvania	3445554119221185	571b83214aef502bf6bacabd7b4ea59e	VISA 16 digit	40.3667202317111204	-80.0539358283098892
9069	2020-01-11 01:56:37	2020-01-11	Gonzalo Hyatt-Nolan	gonzalo.hyatt.nolan@geemail.com	New York	New York	210037461860788885	8938a879894ba630c2f1d12a87e93cf6	JCB 16 digit	40.5892737700361721	-74.0199303487677156
9070	2020-01-11 02:46:33	2020-01-11	Alyson Jenkins MD	alyson.jenkins.md@warmmail.com	Garland	Texas	3158177823503887756	c20d714498740315ca7e87bface799fa	VISA 13 digit	33.0028255833081872	-96.7164462927889161
9071	2020-01-11 03:16:32	2020-01-11	Miss Emilee Pfannerstill	miss.emilee.pfannerstill@geemail.com	Honolulu	Hawaii	210023441626163025	baa035d8b6595983754aa315a5845355	American Express	21.2357245848264569	-157.831123716311907
9072	2020-01-11 03:38:19	2020-01-11	Towanda Anderson	towanda.anderson@geemail.com	Evansville	Indiana	869937016606839218	458f5e44db9e9747bcee2b0a94f9624c	JCB 16 digit	38.0524161912172971	-87.5343980956289869
9073	2020-01-11 03:49:44	2020-01-11	Mr. Bret Dooley	mr.bret.dooley@geemail.com	San Francisco	California	55430567287312589	714acf8daeaa7e175c795712558a3a7e	JCB 16 digit	37.779624850568112	-122.451311499937603
9074	2020-01-11 03:56:01	2020-01-11	Flint Lockman	flint.lockman@warmmail.com	San Francisco	California	210081708675291876	7d4d31a886d13dac1c5429de1da858e1	American Express	37.7870712234323491	-122.438955901401428
9075	2020-01-11 04:21:08	2020-01-11	Lacey Kris MD	lacey.kris.md@warmmail.com	Mobile	Alabama	55291895033878258	2a376f8254753d4914034ebca042b7f8	JCB 15 digit	30.6107008418641975	-88.0338360449437118
9076	2020-01-11 04:22:49	2020-01-11	Cody Graham	cody.graham@geemail.com	Gresham	Oregon	3528614245745570738	5cec74a3f820580a37aed5f293742f07	Diners Club / Carte Blanche	45.549912612508237	-122.392251384657243
9077	2020-01-11 04:33:55	2020-01-11	Charleen Frami	charleen.frami@warmmail.com	Austin	Texas	869995986149225787	22f809f45a0a55ee5dde21818c01ffd2	Voyager	30.2170260601803662	-97.6929832284577202
9078	2020-01-11 05:00:53	2020-01-11	Jenni Yost	jenni.yost@geemail.com	Oakland	California	6011170123682995794	01fe54620ca391599de66310e3940820	VISA 16 digit	37.7825495792362034	-122.278940209559522
9079	2020-01-11 05:03:59	2020-01-11	Vena Hansen	vena.hansen@geemail.com	San Francisco	California	52919127664664696	53d497e8d3d778502d8daf1c6cbf810d	JCB 15 digit	37.7547552813900538	-122.441347342906766
9080	2020-01-11 05:11:54	2020-01-11	Isabela Mante	isabela.mante@geemail.com	Columbus	Ohio	502015454368851	ae7bceaf8f8a6e1c46365d9d750f8f22	Mastercard	39.9870332504201684	-82.9895447006683895
9081	2020-01-11 05:15:14	2020-01-11	Roxana Pagac DDS	roxana.pagac.dds@geemail.com	Washington	District of Columbia	3337407878458714027	e7849fb1996fa891972a0b5ece84fb9d	VISA 16 digit	38.9844463085554551	-76.9680242121897606
9082	2020-01-11 05:24:20	2020-01-11	Littie Becker PhD	littie.becker.phd@geemail.com	San Francisco	California	3096771441552643226	c42fbffd337d8b0da7dc7a079bd4cd16	JCB 16 digit	37.7916897818790645	-122.457016287814952
9083	2020-01-11 05:35:07	2020-01-11	Jerod Jones	jerod.jones@geemail.com	San Francisco	California	3112785830117138926	ba908971a86e1aa8cd5f542d1d4ff0b0	Diners Club / Carte Blanche	37.7963631949127929	-122.414610662796349
9084	2020-01-11 05:51:36	2020-01-11	Mrs. Viney Reichert MD	mrs.viney.reichert.md@geemail.com	Austin	Texas	3730384001274101	f627cae3347191f49d4d8ba4cf82c119	Mastercard	30.2777046450540404	-97.7694189647916687
9085	2020-01-11 06:24:28	2020-01-11	Alva Rau-Roberts	alva.rau.roberts@geemail.com	San Francisco	California	3018084255853208	493ad71a3b1206789830fdf2ff537f0d	American Express	37.7815497215291529	-122.447696849240373
9086	2020-01-11 06:27:31	2020-01-11	Wyatt White	wyatt.white@geemail.com	San Francisco	California	3779288115961457	42bca4c08e32dd94d1e7839d71fddeb5	Maestro	37.779187975719303	-122.414086172493867
9087	2020-01-11 07:01:55	2020-01-11	Selma Marks-Hilll	selma.marks.hilll@geemail.com	Indianapolis	Indiana	503889056305231	078dbdd14c2cecaab99a78aed9f420eb	Maestro	39.8191553046934317	-86.2004938917901313
9088	2020-01-11 07:04:57	2020-01-11	Saniyah Mueller	saniyah.mueller@geemail.com	Fayetteville	North Carolina	52336613979958456	402e8eaec3b1f8dac456b7c68da6b5a9	JCB 16 digit	35.0925512677777576	-78.9235068838242455
9089	2020-01-11 07:10:39	2020-01-11	Huey Dooley	huey.dooley@geemail.com	Omaha	Nebraska	51829234438174611	7d84e9df88443f66e201c8c752e99688	VISA 13 digit	41.3328026790782843	-96.0291052355080836
9090	2020-01-11 07:26:33	2020-01-11	Noreen Marvin	noreen.marvin@geemail.com	Glendale	California	3088565828566702727	57467e75ec9c01b10ff5035b2872500b	Discover	34.1290694260723839	-118.327284991172334
9091	2020-01-11 07:40:13	2020-01-11	Ms. Gwendolyn Oberbrunner	ms.gwendolyn.oberbrunner@geemail.com	Los Angeles	California	52541952953053707	1f53ccb260d6320e5a3cf6e2d139b666	VISA 13 digit	34.0320166073139703	-118.332638461095456
9092	2020-01-11 07:44:57	2020-01-11	Mrs. Isobel Cruickshank DVM	mrs.isobel.cruickshank.dvm@warmmail.com	Sparks	Nevada	4814658663693530	10dff4f5edd5c97aac85ca9beff1101e	VISA 16 digit	39.574233283778284	-119.816461652037134
9093	2020-01-11 08:06:38	2020-01-11	Randle Aufderhar	randle.aufderhar@geemail.com	San Francisco	California	3773328342010052	9d4b87d8bace113ddb7c22d938f5678d	JCB 16 digit	37.7717978014251088	-122.400270114447679
9094	2020-01-11 08:18:08	2020-01-11	Elsa Thompson-Nitzsche	elsa.thompson.nitzsche@woohoo.com	Austin	Texas	4975368803549312	71abd4c5b3a9c6061cc1cca3a05aacd4	JCB 15 digit	30.3447583766315105	-97.6871781251631717
9095	2020-01-11 08:32:43	2020-01-11	Mrs. Kari Franecki	mrs.kari.franecki@geemail.com	Cleveland	Ohio	4403591783359590	b4d4cde2b5357d3643d716d06b3fde80	JCB 15 digit	41.4528672112002923	-81.7513122316222649
9096	2020-01-11 08:32:49	2020-01-11	Jalynn Bayer PhD	jalynn.bayer.phd@geemail.com	Long Beach	California	6011016857222100971	c7ce2d311fa08f44f7d6ce4e9256e9e7	Maestro	33.8179895331438587	-118.086604875109344
9097	2020-01-11 08:34:44	2020-01-11	Diego Champlin	diego.champlin@geemail.com	San Francisco	California	6011450114268665472	846b7947512b81b9e52ec90767766d5d	JCB 15 digit	37.792732938845667	-122.459055916075911
9098	2020-01-11 08:40:06	2020-01-11	Verl Stark	verl.stark@geemail.com	Seattle	Washington	4825008996120859	0939fbe3165d53c9510d4a0283acf732	Maestro	47.7040844399407504	-122.393312916570892
9099	2020-01-11 08:45:38	2020-01-11	Kareem Lakin	kareem.lakin@geemail.com	Boston	Massachusetts	3112872530874667745	b7cea966262500dee66e723a3de210b1	Mastercard	42.3836345145180857	-70.989326728922137
9100	2020-01-11 08:51:06	2020-01-11	Dorthey Kemmer	dorthey.kemmer@geemail.com	Los Angeles	California	869941691675406802	e7b58dea827c3b76f80277d63cea4e6d	Diners Club / Carte Blanche	33.9781731414474493	-118.312723527615134
9101	2020-01-11 08:52:03	2020-01-11	Freida Barrows	freida.barrows@warmmail.com	St. Louis	Missouri	180073206862022683	d581d709a6593c0e3f29156562650cc0	JCB 16 digit	38.6385762062080218	-90.155964229489129
9102	2020-01-11 08:52:27	2020-01-11	Mr. Domingo Botsford PhD	mr.domingo.botsford.phd@geemail.com	Tulsa	Oklahoma	180013850098443800	fa1f87433be480e3f32d0ce5eb7b5236	VISA 16 digit	36.2141276704516244	-95.9737756486471767
9103	2020-01-11 09:06:58	2020-01-11	Alby McCullough	alby.mccullough@woohoo.com	San Diego	California	6011688440237466518	587eb5fb05c2988c027223b10a4e9e32	JCB 15 digit	32.9021904493283515	-117.055448493631559
9104	2020-01-11 09:13:00	2020-01-11	Pleasant Mann	pleasant.mann@geemail.com	San Francisco	California	3029283434149608	f94942a56985f081c0906d8df8fe03db	Discover	37.7707791382503402	-122.43488212738275
9105	2020-01-11 10:27:59	2020-01-11	Mindy Wunsch	mindy.wunsch@geemail.com	New York	New York	3112102347220325833	4da5dadb2382cc7b313f685502e55dcc	Maestro	40.6670665328148715	-74.0099072050664546
9106	2020-01-11 11:02:56	2020-01-11	Evelyne Hettinger	evelyne.hettinger@geemail.com	San Francisco	California	3748341086572361	a8d9c056149b777ca00309646b06da5d	JCB 16 digit	37.8259060931330495	-122.42073990999144
9107	2020-01-11 11:27:22	2020-01-11	Asbury Stiedemann	asbury.stiedemann@geemail.com	San Francisco	California	3337680842862825272	317102c16e2dbbf8bb946c72f3bd3ffd	Diners Club / Carte Blanche	37.7628632912786344	-122.436221119201505
9108	2020-01-11 11:34:41	2020-01-11	Mabel Kshlerin DDS	mabel.kshlerin.dds@woohoo.com	Springfield	Missouri	4809525687855	74fd8e1f534cf5dbabc0e22e97f67da8	Diners Club / Carte Blanche	37.146672326951105	-93.264615129475672
9109	2020-01-11 12:41:50	2020-01-11	Mason Dietrich-Cronin	mason.dietrich.cronin@warmmail.com	Mesa	Arizona	210060381392851797	c9858b2edf30615b9cab3740fb1df3b4	Mastercard	33.4200836000177972	-111.781035869184507
9110	2020-01-11 13:19:49	2020-01-11	Guilford Ryan	guilford.ryan@geemail.com	Jurupa Valley	California	3754568154896147	843d4a8b01391ae3939d17a5a5131917	American Express	34.1023538429219286	-117.488374082420393
9111	2020-01-11 13:34:14	2020-01-11	Redden Rolfson-Lubowitz	redden.rolfson.lubowitz@geemail.com	San Francisco	California	869997042159776224	260358eec2ff60f12414b094b0c90512	Diners Club / Carte Blanche	37.7805650874032821	-122.427917131280338
9112	2020-01-11 13:52:38	2020-01-11	Jeanmarie Balistreri-Conroy	jeanmarie.balistreri.conroy@woohoo.com	Berkeley	California	3049029928192632	e5ac65732906fd35e990e96c84051b4a	JCB 16 digit	37.8880121610646725	-122.307704930923123
9113	2020-01-11 13:53:37	2020-01-11	Burr Wehner DDS	burr.wehner.dds@geemail.com	Minneapolis	Minnesota	4692761088107149	32af05aca1ac04191d346002d8247dfa	Mastercard	44.9671282508961809	-93.2136964430838759
9114	2020-01-11 14:10:40	2020-01-11	Mr. Jemal Stark	mr.jemal.stark@geemail.com	Houston	Texas	4489221154762423	8a296e07d01a65b1ee523e5dda0470b2	American Express	29.7391571798905723	-95.3412539092373095
9115	2020-01-11 14:23:09	2020-01-11	Mr. Brenton Senger	mr.brenton.senger@warmmail.com	San Francisco	California	869948044527999223	e66860c2dbb90f97b852753761ded3a3	Mastercard	37.7892129392392704	-122.422465481646327
9116	2020-01-11 14:43:38	2020-01-11	Cristal Jacobson	cristal.jacobson@geemail.com	Oakland	California	6011982152019741876	c309addf0dfd2e0fb694428777339815	Maestro	37.8054570144641318	-122.265133849923487
9117	2020-01-11 14:45:12	2020-01-11	Immanuel Glover	immanuel.glover@geemail.com	Jacksonville	Florida	3049355229601157	c1b65c24508dd689a808058a872cb3e5	Discover	30.3789530320610837	-81.7171508047808004
9118	2020-01-11 15:05:29	2020-01-11	Mrs. Brianna Crooks PhD	mrs.brianna.crooks.phd@geemail.com	Los Angeles	California	869922964448703364	2d861f424f085d0b3deeae8ea0fced86	JCB 16 digit	34.0419490553770174	-118.500269521678973
9119	2020-01-11 15:07:51	2020-01-11	Alden Powlowski IV	alden.powlowski.iv@geemail.com	Omaha	Nebraska	3789157634104295	a29ab890b4a0eae17c1c66a770df5e9b	JCB 16 digit	41.2335927168984	-96.104704300279181
9120	2020-01-11 15:17:17	2020-01-11	Williard Pfeffer-Smitham	williard.pfeffer.smitham@geemail.com	Des Moines	Iowa	4247136208419676	8b4f8cbea3a1c6e55c50a6a140c8da1a	VISA 16 digit	41.6715526988472789	-93.5415119814731213
9121	2020-01-11 15:29:26	2020-01-11	Dr. Telly Gorczany I	dr.telly.gorczany.i@geemail.com	Glendale	California	639016398762829	daeef2e85b7c5a17ad7d547be327c897	JCB 15 digit	34.2228113659877309	-118.338926054154712
9122	2020-01-11 16:06:58	2020-01-11	Mrs. Stella Skiles DVM	mrs.stella.skiles.dvm@woohoo.com	Miami	Florida	3096276224104297505	7e9eff31be0bd45318b2c76f7f5f122c	VISA 16 digit	25.7622893514249505	-80.2675468457270398
9123	2020-01-11 16:47:07	2020-01-11	Dallas McClure PhD	dallas.mcclure.phd@geemail.com	Los Angeles	California	676212701898624	a4eeef9f40d3d5482aa16ee0bc193abd	JCB 15 digit	34.1120881356164816	-118.391473087760801
9124	2020-01-11 16:51:24	2020-01-11	Dr. Earley Goodwin	dr.earley.goodwin@geemail.com	New York	New York	4435551316286662	dd9cd3d2334330427de3dd63303adf80	Voyager	40.5792151606399543	-73.9303040180250974
9125	2020-01-11 16:52:17	2020-01-11	Mr. Giles Wilkinson I	mr.giles.wilkinson.i@geemail.com	San Francisco	California	3088430587188361170	32b6b54cbecaa09a8e5769d3d1bc85d5	JCB 15 digit	37.7645100102591584	-122.414752728443545
9126	2020-01-11 16:55:21	2020-01-11	Baby Cummerata-Walter	baby.cummerata.walter@geemail.com	San Francisco	California	54307948292793619	ad81279129ede8d0d412addce4479d2e	JCB 15 digit	37.781236515205741	-122.429816679305503
9127	2020-01-11 17:21:07	2020-01-11	Mrs. Tamya O'Connell DDS	mrs.tamya.o'connell.dds@geemail.com	Houston	Texas	869980337460749269	bf7bb4acd86aef85f5b6bb91cd5eae23	VISA 16 digit	29.7964090773448333	-95.3594994361993002
9128	2020-01-11 17:42:55	2020-01-11	Iverson Homenick	iverson.homenick@warmmail.com	Oakland	California	869942908831112069	cc600f4f4f39e22bee18d66bc852d398	Mastercard	37.8263798828995803	-122.268643042920289
9129	2020-01-11 17:54:19	2020-01-11	Blanchard Von	blanchard.von@warmmail.com	West Jordan	Utah	869977806538121516	479ea96f715e2074c9da7098be67592b	Mastercard	40.5365466769110441	-111.968486001351096
9130	2020-01-11 18:03:00	2020-01-11	Reynold Ortiz	reynold.ortiz@geemail.com	Scottsdale	Arizona	869988761845237553	67310997d01bea857c846c26ee2e9746	Discover	33.6811436740338834	-111.88008149764164
9131	2020-01-11 18:24:54	2020-01-11	Alma Hettinger	alma.hettinger@warmmail.com	Jurupa Valley	California	4411009401594985	6502ff0a42e235f67bc8db34775cfbc3	JCB 16 digit	33.936516019601747	-117.430772399345784
9132	2020-01-11 18:48:38	2020-01-11	Haywood Kautzer	haywood.kautzer@woohoo.com	Indianapolis	Indiana	4453222110828300	a0a3013996f23ff15daaabe9e7f78d8a	VISA 13 digit	39.7285745403271164	-86.1494335988737561
9133	2020-01-11 19:16:31	2020-01-11	Shirlee Reichel	shirlee.reichel@geemail.com	St. Louis	Missouri	180058852970298852	9904e89d586769b296e82d328c3893e3	Diners Club / Carte Blanche	38.5735455302678076	-90.1899536940272952
9134	2020-01-11 20:12:40	2020-01-11	Simon Hagenes	simon.hagenes@geemail.com	Lowell	Massachusetts	4940233267654	0eb9e920e6b7369b7ff77cc09d37400a	VISA 16 digit	42.7025146765969694	-71.4077701573599199
9135	2020-01-11 20:40:55	2020-01-11	Kloe Johnston	kloe.johnston@woohoo.com	New York	New York	869933762552885457	08d297f26402f132e42308a2c1334139	Discover	40.7422812497001132	-74.0375349288702012
9136	2020-01-11 20:49:47	2020-01-11	Dr. Chadrick Rau	dr.chadrick.rau@geemail.com	Virginia Beach	Virginia	3112416227141100989	0bf1505eea81b8a9f25de274208512ad	VISA 16 digit	36.7944198054913443	-75.9992514545701425
9137	2020-01-11 20:51:02	2020-01-11	Elyse Runte	elyse.runte@woohoo.com	San Francisco	California	54480489455265763	b430003b22c52eed30c1ee2562310f87	Diners Club / Carte Blanche	37.7729574197980469	-122.450925517528958
9138	2020-01-11 21:36:32	2020-01-11	Ms. Lillia Metz MD	ms.lillia.metz.md@geemail.com	San Francisco	California	3528939312422587126	0a98af35bab8a5c956be83e2ebb6d2be	VISA 16 digit	37.7744910710535891	-122.404246535613098
9139	2020-01-11 21:39:53	2020-01-11	Kasie Hamill-Schiller	kasie.hamill.schiller@woohoo.com	Columbus	Ohio	4093713363413077	a2d7cdb64f2773dee30210af317b9f67	Mastercard	39.9959834664639047	-82.8973856588129081
9140	2020-01-11 22:00:50	2020-01-11	Peggy Homenick DDS	peggy.homenick.dds@geemail.com	Birmingham	Alabama	54711313716096315	5306be9c186b60ddd1125e2d761c5ef6	VISA 16 digit	33.552556784383583	-86.822324608802802
9141	2020-01-11 22:13:26	2020-01-11	Billie Koelpin MD	billie.koelpin.md@geemail.com	Chicago	Illinois	4493708489042657	38743df771d436454511ec9220b95ed0	JCB 16 digit	41.9093990566045065	-87.6404060303729011
9142	2020-01-11 22:33:44	2020-01-11	April Smitham DDS	april.smitham.dds@geemail.com	San Diego	California	55885463007705239	8022594e933d538749148d48983e4e36	VISA 16 digit	32.8560881175167836	-117.15209103509784
9143	2020-01-11 22:35:18	2020-01-11	Mr. Blaise Zboncak	mr.blaise.zboncak@geemail.com	St. Louis	Missouri	4862652971753954	71203e9e0784cf6a4e7a456532469589	Voyager	38.5851284719694405	-90.2138211530637051
9144	2020-01-11 23:19:39	2020-01-11	Beckett Conroy	beckett.conroy@woohoo.com	Detroit	Michigan	180091410974294549	89800068a55645bd3ba06077e35aa9a4	Maestro	42.3535905861686928	-83.1954414101902415
9145	2020-01-12 00:00:08	2020-01-12	Mr. Darrin Hilll MD	mr.darrin.hilll.md@geemail.com	Omaha	Nebraska	3760473304055359	b5d1258432c5757d0569108ec423af7a	Voyager	41.2794566873606286	-96.1362768062971611
9146	2020-01-12 00:07:15	2020-01-12	Jabbar Hand	jabbar.hand@geemail.com	Pembroke Pines	Florida	3754497583376085	993d94796d256ed09fcfb2c7683e69f6	VISA 16 digit	26.0251061129886665	-80.2733498889390376
9147	2020-01-12 00:23:18	2020-01-12	Dan Murray	dan.murray@geemail.com	Las Vegas	Nevada	51974956036635048	ad45057a77a63ba5bafa75310d268c34	VISA 16 digit	36.1542055855140063	-115.322869754230965
9148	2020-01-12 00:40:13	2020-01-12	Babe Price III	babe.price.iii@geemail.com	West Jordan	Utah	630475239796446	8721bb81ec5e3dd3d4bfead848fc6da2	Mastercard	40.6088485370647163	-111.908738868599016
9149	2020-01-12 00:46:50	2020-01-12	Ansel Ritchie	ansel.ritchie@geemail.com	New York	New York	4653821820186	8a3881688eecd60dbd152dbd82ccf26f	JCB 16 digit	40.7193863663114612	-73.8875013095688047
9150	2020-01-12 01:10:18	2020-01-12	Vollie Kunze	vollie.kunze@geemail.com	Louisville	Kentucky	3031161498026854	ff9a8f25dc1eed1ab2826963e814c69f	VISA 13 digit	38.1131482452988593	-85.6713201573189451
9151	2020-01-12 01:10:45	2020-01-12	Jovita Luettgen-Braun	jovita.luettgen.braun@geemail.com	Clarksville	Tennessee	630480139580932	696b0715231276b74ceb0b6fdd6735ba	JCB 15 digit	36.6439593589060024	-87.3959610132917817
9152	2020-01-12 01:48:55	2020-01-12	Dr. Everette Schumm V	dr.everette.schumm.v@geemail.com	Escondido	California	3038725528717493	a6d9ac7254ae4048cdb968e721cfd8f1	Diners Club / Carte Blanche	33.1626775679405768	-117.033915671870105
9153	2020-01-12 01:52:22	2020-01-12	Joe Lindgren-O'Reilly	joe.lindgren.o'reilly@geemail.com	Cincinnati	Ohio	3042070383624666	43cf4a886459dd71b28220a02d1a44bb	Discover	39.1566753154851526	-84.4921722582347599
9154	2020-01-12 02:10:39	2020-01-12	Kiara Dietrich	kiara.dietrich@geemail.com	San Francisco	California	54933209347986613	ec4357588ddd682409c43a57204ba433	Voyager	37.7524441740382173	-122.440822355585311
9155	2020-01-12 02:30:15	2020-01-12	Dr. Gustave Hermann III	dr.gustave.hermann.iii@geemail.com	Las Vegas	Nevada	3448271740827747	a44df19ee453bd77d0e690da8dc256ff	Discover	36.2628160632781658	-115.309708596926555
9156	2020-01-12 02:37:36	2020-01-12	Lonzo Eichmann-Wunsch	lonzo.eichmann.wunsch@geemail.com	Denver	Colorado	210025659218372211	98143f9233ca856c4e04285202c5596c	JCB 16 digit	39.7044770239904494	-104.973608078133694
9157	2020-01-12 02:57:52	2020-01-12	Stephon Bogan	stephon.bogan@woohoo.com	Beaumont	Texas	4411467716886142	2eb43d5624b2b429843038776a7f76fc	Diners Club / Carte Blanche	30.1623083521217126	-94.2389618359293877
9158	2020-01-12 02:59:06	2020-01-12	Maricela Reynolds	maricela.reynolds@warmmail.com	Miami	Florida	3112143254856781282	46b87688e28e8fd36c2b6f458072a0a9	Discover	25.7250126093763889	-80.2720866872802361
9159	2020-01-12 03:03:31	2020-01-12	Clay Rohan	clay.rohan@geemail.com	Oakland	California	3337313974916833138	552647f0b419ebd8d32a5e28ff08e4e0	JCB 16 digit	37.8449986422381386	-122.259768468005021
9160	2020-01-12 04:17:43	2020-01-12	Harmon Dietrich-Cronin	harmon.dietrich.cronin@geemail.com	San Francisco	California	180067797975694994	cbc540955ede9b273f3af2b55459affe	VISA 13 digit	37.7600594698832737	-122.42997086096976
9161	2020-01-12 04:34:05	2020-01-12	Daja Emard-Heathcote	daja.emard.heathcote@geemail.com	Washington	District of Columbia	4613955447553979	961837e5f6b2af66a17f6392375b643f	VISA 16 digit	38.9237299359668043	-77.0428499441806309
9162	2020-01-12 04:39:57	2020-01-12	Kyson Kassulke	kyson.kassulke@warmmail.com	Cedar Rapids	Iowa	3769671037396633	ed48ac957305545ae0c0721d9bdd7ac1	Discover	42.0351885153055207	-91.678926868696891
9163	2020-01-12 05:04:27	2020-01-12	Dr. Libby Will	dr.libby.will@warmmail.com	Chicago	Illinois	630469318239360	39ee0b5bbb47ac8ed8099f6c5657b9a7	Voyager	41.7394309840932536	-87.6907544028043731
9164	2020-01-12 05:22:24	2020-01-12	Jolette Gleichner	jolette.gleichner@geemail.com	Houston	Texas	3158143252828369087	c8d887646201ac8900fd5fd5e9a5beac	VISA 16 digit	29.7159670289218418	-95.2931722082212644
9165	2020-01-12 05:23:00	2020-01-12	Mr. Tariq Morissette	mr.tariq.morissette@woohoo.com	Long Beach	California	3033598662432293	c186a0d398b761f6b231421933cf8eae	JCB 16 digit	33.8967997771043272	-118.242164083399999
9166	2020-01-12 05:25:42	2020-01-12	Leandro Hintz	leandro.hintz@geemail.com	Scottsdale	Arizona	180083550495455861	f92e933e24475c1118ede4727be006cb	VISA 16 digit	33.7359060537658664	-111.818364803210272
9167	2020-01-12 05:38:57	2020-01-12	Rylan Kozey	rylan.kozey@geemail.com	Santa Maria	California	3031432904482142	d0d136032758609ddc5df57a0d0152fc	VISA 13 digit	34.9964282855920459	-120.400283879731958
9168	2020-01-12 05:39:59	2020-01-12	Geo Welch-Bayer	geo.welch.bayer@geemail.com	Seattle	Washington	3112827792339714779	e80c023f2e4d8b88e635079f83492814	Discover	47.6766535059474421	-122.430133752517023
9169	2020-01-12 05:55:43	2020-01-12	Ms. Loyce Crona DDS	ms.loyce.crona.dds@geemail.com	Chicago	Illinois	210073042985578131	a4e7b6fe952de233b20ee0396ad13c5f	Diners Club / Carte Blanche	41.855569048162927	-87.7759957045812058
9170	2020-01-12 06:41:30	2020-01-12	Durrell Sporer DVM	durrell.sporer.dvm@warmmail.com	Victorville	California	52336766772026127	ae315bb841cd7213051a0a3e87badcf2	Voyager	34.4302281788315625	-117.262853990044817
9171	2020-01-12 06:57:18	2020-01-12	Kimball Cummings	kimball.cummings@geemail.com	Oakland	California	3088463001749450027	0106fe2a56037463d272d6ccaf6130fa	VISA 16 digit	37.7967861565957293	-122.258679843362287
9172	2020-01-12 07:12:46	2020-01-12	Dr. Alby Jacobs	dr.alby.jacobs@geemail.com	Thousand Oaks	California	6011313180856796166	506cc098e1038364f1b926a43ac625ad	Voyager	34.2881012881446665	-118.927043043766915
9173	2020-01-12 07:17:45	2020-01-12	Clarance Johnson	clarance.johnson@geemail.com	San Francisco	California	869914303684022108	bb988bcb84b6f27cd6234489338ab87c	VISA 13 digit	37.7626932539331648	-122.410273959069386
9174	2020-01-12 07:31:34	2020-01-12	Tariq Botsford-Lang	tariq.botsford.lang@warmmail.com	Baton Rouge	Louisiana	3477602008766207	d9e1e5eb7f053204e066f319231a672a	Diners Club / Carte Blanche	30.4880951664157216	-91.1812682896960496
9175	2020-01-12 07:39:44	2020-01-12	Dr. Donat Cronin PhD	dr.donat.cronin.phd@woohoo.com	Houston	Texas	630482933995175	aa69c99651c2370f9b662041a53919a5	VISA 13 digit	29.723491035502775	-95.4169667756665518
9176	2020-01-12 07:48:22	2020-01-12	Dr. Anthony Doyle I	dr.anthony.doyle.i@geemail.com	Norfolk	Virginia	55938283186699145	01c4d58f0ba13d9554fbcf301ce2fd92	Maestro	36.9234790371283879	-76.2941274198707191
9177	2020-01-12 08:34:33	2020-01-12	Porter Mitchell	porter.mitchell@woohoo.com	Berkeley	California	639078996199481	b4e95b21657f41a41e572cf3bff5f99b	VISA 13 digit	37.8584153959512903	-122.274909564489434
9178	2020-01-12 08:42:39	2020-01-12	Mrs. Breanne Bashirian	mrs.breanne.bashirian@geemail.com	San Francisco	California	4928514135451077	35c256b17601d9244436d705347df4b5	American Express	37.7768741206794303	-122.410409864419222
9179	2020-01-12 09:46:12	2020-01-12	Nehemiah Lakin MD	nehemiah.lakin.md@geemail.com	Waterbury	Connecticut	3096311138743263503	8e079fc9caafdfd7bacba517efb8a323	JCB 16 digit	41.487185198863969	-72.9803295517254611
9180	2020-01-12 09:47:13	2020-01-12	Rick Goldner	rick.goldner@woohoo.com	Yonkers	New York	3030373765126348	85d8c1f905e96545fe9a2c3862f3582c	American Express	40.8645313200741995	-73.8278584896005725
9181	2020-01-12 10:31:12	2020-01-12	Armin Gaylord IV	armin.gaylord.iv@geemail.com	Los Angeles	California	869900065342671545	738fa912197b6e75cfe3f13e606546a3	Maestro	34.0319437655951802	-118.358840235787625
9182	2020-01-12 10:31:57	2020-01-12	Gibson Aufderhar	gibson.aufderhar@geemail.com	New York	New York	4703619360831025	50da0a5c436297650fef12b33dd82e04	American Express	40.6449448711927985	-73.8389570211887332
9183	2020-01-12 10:52:15	2020-01-12	Ms. Marge Lueilwitz	ms.marge.lueilwitz@geemail.com	Seattle	Washington	3718584631209031	39bc95c9385788abd196bebc3fc1fbaa	Diners Club / Carte Blanche	47.5274650029297945	-122.293745936911179
9184	2020-01-12 10:52:21	2020-01-12	Herbert McCullough-Krajcik	herbert.mccullough.krajcik@geemail.com	Honolulu	Hawaii	639071080520761	eaa956e95cfebf27914c00c5b4487483	Diners Club / Carte Blanche	21.2705704575620587	-157.8124142978549
9185	2020-01-12 10:55:29	2020-01-12	Diamond Dickens	diamond.dickens@geemail.com	Minneapolis	Minnesota	3799194761557860	eec1aa2fd3e31225500f1207cbc4cd0c	VISA 13 digit	44.8680555848024767	-93.3629258463431171
9186	2020-01-12 11:07:38	2020-01-12	Severt Dickinson	severt.dickinson@geemail.com	Thornton	Colorado	4719390424464235	22e925c824bb8461dd6e45adb083d5e9	Voyager	39.9264242710877255	-105.017493250469869
9187	2020-01-12 11:15:11	2020-01-12	Zillah Reynolds	zillah.reynolds@geemail.com	El Paso	Texas	3088524809156255680	091a35ed3381512004d4b09590ac208b	Discover	31.852101938083397	-106.352731726689271
9188	2020-01-12 12:18:37	2020-01-12	Jocelynn Spinka	jocelynn.spinka@woohoo.com	Spokane	Washington	53309280506556162	47cfac5ab578e46fde045b2362290fc0	JCB 15 digit	47.5917072238638994	-117.442078334828096
9189	2020-01-12 12:22:32	2020-01-12	Donal Lockman	donal.lockman@geemail.com	Chesapeake	Virginia	3030321371427451	23b97448b495d833bff94fef3e8957e0	Maestro	36.6208230950642388	-76.3433163289289922
9190	2020-01-12 12:32:35	2020-01-12	Killian Osinski	killian.osinski@geemail.com	San Francisco	California	4020824770265	7d690be99d2523f73a53ca3c57dff260	Mastercard	37.778875111026359	-122.42163171683238
9191	2020-01-12 12:34:36	2020-01-12	Wilkie Bernhard	wilkie.bernhard@geemail.com	San Francisco	California	180068835662757101	145b665d56c5de62909c36f9d4c803e6	Discover	37.7908476569581353	-122.433782786581631
9192	2020-01-12 13:21:03	2020-01-12	Nicole Rodriguez	nicole.rodriguez@woohoo.com	Madison	Wisconsin	3703134835279062	7090d700acf2b982a6db768b103539a3	Mastercard	43.0391052266091094	-89.3785441324930616
9193	2020-01-12 13:38:44	2020-01-12	Lewis Torphy IV	lewis.torphy.iv@geemail.com	Berkeley	California	4293880668307334	6ed0e87850baee90d50405fa6607918d	Mastercard	37.8751595492428876	-122.305748103945291
9194	2020-01-12 13:40:34	2020-01-12	Dr. Novella Veum	dr.novella.veum@warmmail.com	Santa Maria	California	4960506918224480	73db77b2dad1396faac1fd279bc9d893	VISA 16 digit	35.0178699620597058	-120.406773179621624
9195	2020-01-12 13:58:48	2020-01-12	Edwin Kunde	edwin.kunde@geemail.com	Oakland	California	6011354261834563348	b02f4badf4863d8cf74bdfd483c63f26	Discover	37.7584913476225239	-122.259450884352148
9196	2020-01-12 14:01:16	2020-01-12	Zaiden Crooks	zaiden.crooks@geemail.com	Honolulu	Hawaii	3337209073329794677	a052e58b6d3ca52c2f498ac5a2d189f2	Mastercard	21.4238942215900892	-157.877984228983905
9197	2020-01-12 14:03:44	2020-01-12	Rocco Reilly-Renner	rocco.reilly.renner@woohoo.com	Salt Lake City	Utah	210080200140921452	74eb35f8daf7bd3ca187380751114326	Voyager	40.7046525275945612	-111.976251055015254
9198	2020-01-12 14:17:54	2020-01-12	Dr. Cathern Davis	dr.cathern.davis@geemail.com	San Francisco	California	6011873753634329047	148685e1289c226891a5a75c869381e0	VISA 16 digit	37.8189020792497388	-122.453346480525298
9199	2020-01-12 14:25:34	2020-01-12	Darby Wuckert	darby.wuckert@geemail.com	Clinton	Michigan	6011649325410842478	aa552d5e91b2e23532de5b19ac062f4b	Voyager	42.6750103688865892	-82.8976635400280344
9200	2020-01-12 14:35:03	2020-01-12	Okey Erdman III	okey.erdman.iii@warmmail.com	San Francisco	California	3158432499616207728	d75fbc542656d2dbdef9025540a29db9	Maestro	37.7842879432683887	-122.416895756932618
9201	2020-01-12 14:40:21	2020-01-12	Marcie Sanford	marcie.sanford@geemail.com	El Cajon	California	3088531705827659444	218ed5b50bca2edbfe1a1459324a1a64	Diners Club / Carte Blanche	32.7073953298859266	-116.941119607369984
9202	2020-01-12 14:40:37	2020-01-12	Mr. Simpson Beer V	mr.simpson.beer.v@geemail.com	San Francisco	California	4934237691483084	6fce7d524ee1f550575b24238eb194a5	JCB 15 digit	37.7710325640264344	-122.421813226425584
9203	2020-01-12 14:41:42	2020-01-12	Demond Hahn	demond.hahn@geemail.com	New York	New York	4670081364055938	244f6a4103743c365a484b995e52aae9	VISA 16 digit	40.7242569562271228	-73.9272336753446524
9204	2020-01-12 15:19:49	2020-01-12	Laverne Runolfsdottir	laverne.runolfsdottir@geemail.com	San Francisco	California	4846059400210344	5ebf0dfd20d79f674bad9df81691f80e	JCB 16 digit	37.7775900554135191	-122.454271800118264
9205	2020-01-12 15:42:00	2020-01-12	Dr. Donnie Cronin	dr.donnie.cronin@geemail.com	Grand Prairie	Texas	3480067171676218	bf99752c0f9c4888022444e5f65985db	VISA 16 digit	32.6703777099546073	-97.0905511490874034
9206	2020-01-12 15:42:45	2020-01-12	Darryll White	darryll.white@geemail.com	Lubbock	Texas	589371453003452	41766cbb8d2a6df86c0e4b419ed645b4	Discover	33.4784758794628132	-101.808318241816764
9207	2020-01-12 16:31:05	2020-01-12	Mr. Frank Murray	mr.frank.murray@warmmail.com	Tampa	Florida	3449362553727816	5f1554743488ad8303c2a57afdb383c0	Voyager	27.9287075778119238	-82.5568101875696243
9208	2020-01-12 16:43:53	2020-01-12	Thomasina Reichert	thomasina.reichert@woohoo.com	Berkeley	California	3158963422564524198	61773602541e98b46b4dc07f9888566f	VISA 13 digit	37.8499732654663603	-122.257044842771847
9209	2020-01-12 16:50:10	2020-01-12	Chin Cummings	chin.cummings@geemail.com	Nashville	Tennessee	3528478781775349408	2eb3b126de009fe4c3116bc695cf690a	American Express	36.1893511798355689	-86.6859550561197096
9210	2020-01-12 16:58:05	2020-01-12	Levi Bednar	levi.bednar@woohoo.com	Houston	Texas	6011514323127413693	4670a34abce4b63ace1c5909b6762353	Mastercard	29.8613502839658409	-95.3594694130603244
9211	2020-01-12 17:09:00	2020-01-12	Shyheim Bartell	shyheim.bartell@geemail.com	Irvine	California	060492826015825	a18f66debef82492ef94d18f05b1adac	Discover	33.7344586578678403	-117.756905763597416
9212	2020-01-12 17:14:43	2020-01-12	Regis Skiles	regis.skiles@woohoo.com	Columbus	Ohio	869945337151126987	b44f423ab7f12fcd1c004ecb24ac5388	JCB 15 digit	39.9445093733303267	-83.0694422392874969
9213	2020-01-12 17:22:51	2020-01-12	Ferrell Murphy	ferrell.murphy@geemail.com	Fresno	California	3528333914605480342	b0c5c638628b8bde96e3bf47aaaddf5e	Discover	36.7433227194812133	-119.749956883035239
9214	2020-01-12 17:24:46	2020-01-12	Leva Kozey	leva.kozey@woohoo.com	Boise	Idaho	869949288901783153	f9ab21c9b6aac042b4653b4cfa3281da	JCB 15 digit	43.6183101916357856	-116.315620499030501
9215	2020-01-12 17:28:06	2020-01-12	Wilmer Reinger	wilmer.reinger@geemail.com	Laredo	Texas	676229857285935	014b4d837e79d99367a5bb7748f8cb77	American Express	27.5323195211306242	-99.4233226617339909
9216	2020-01-12 17:29:02	2020-01-12	Lavera Kovacek	lavera.kovacek@woohoo.com	San Francisco	California	3337029463924969410	fffd698fc8eaf7bb4926a75b4bec72fa	Maestro	37.7724793082589088	-122.460356930439843
9217	2020-01-12 17:46:42	2020-01-12	Dr. Cristin Gottlieb DDS	dr.cristin.gottlieb.dds@geemail.com	High Point	North Carolina	676214898244356	540a638d2a2fe6df3b1aaedd236b102f	JCB 16 digit	36.0807927448861321	-80.0682537845075046
9218	2020-01-12 17:48:54	2020-01-12	Coley Wolf	coley.wolf@geemail.com	New Orleans	Louisiana	3728446069033135	91f43ff490046874d466ade0365da857	American Express	30.1366393102813497	-89.8894603843595803
9219	2020-01-12 17:56:08	2020-01-12	Hillard Balistreri	hillard.balistreri@geemail.com	Austin	Texas	4102151934630987	8aa1dbb5b90b20875b953ca0ea640fff	JCB 16 digit	30.26983767693266	-97.8259414805803544
9220	2020-01-12 17:57:53	2020-01-12	Exie Corwin	exie.corwin@warmmail.com	Oakland	California	210012162782339976	1f95fc021713ea031f7a8cb093e3264f	Voyager	37.7807045049187948	-122.276646162237199
9221	2020-01-12 18:37:14	2020-01-12	Martha Ortiz-Gislason	martha.ortiz.gislason@geemail.com	Reno	Nevada	676251540492603	e4573b79684b82869a0978fb659d1a66	VISA 16 digit	39.567668492075434	-119.845856826163455
9222	2020-01-12 18:44:25	2020-01-12	Alexis Rice MD	alexis.rice.md@geemail.com	New York	New York	3057548073060353	a92dfba06b3a8d845e6807ce3a5697ca	Maestro	40.736747395735236	-73.9004647490464066
9223	2020-01-12 18:48:59	2020-01-12	Areli Simonis	areli.simonis@geemail.com	Mobile	Alabama	4815726457774	05cfdf3b9167bd478fcaf09b059a5b5f	Voyager	30.7396037722114457	-88.0951966834392408
9224	2020-01-12 19:22:58	2020-01-12	Delos Wilderman-Goldner	delos.wilderman.goldner@geemail.com	Athens	Georgia	55949738383821443	aaa9c184fb255baaa4f2577abc3c3239	Diners Club / Carte Blanche	33.9134791120611112	-83.3243653808370226
9225	2020-01-12 19:23:58	2020-01-12	Miss Maegan Gleichner PhD	miss.maegan.gleichner.phd@woohoo.com	Oakland	California	3470851793245854	a33a788cba99c985520c8b3f696f4d51	Discover	37.818744323464891	-122.273739237657452
9226	2020-01-12 19:27:26	2020-01-12	Doreen Quigley	doreen.quigley@woohoo.com	Charlotte	North Carolina	6011226122304356579	f750d184a1fef29cc2aced27299456b9	Maestro	35.2419190641745885	-80.9026974352020858
9227	2020-01-12 19:34:20	2020-01-12	Darrel Towne	darrel.towne@geemail.com	El Monte	California	3033850598754062	d31206ec752720d8622c610a9fed38c6	Diners Club / Carte Blanche	34.0041096884947223	-117.929335271407297
9228	2020-01-12 19:48:21	2020-01-12	Alfonse Kunde	alfonse.kunde@geemail.com	New York	New York	3112132762267441679	9a49ff7b9be076cd7a0515e8a2d626bb	VISA 13 digit	40.7049709761738754	-73.9135697098810169
9229	2020-01-12 20:09:33	2020-01-12	Konner Stiedemann	konner.stiedemann@geemail.com	San Francisco	California	6011974703908964688	aff56d19da452d5422a567782415bf01	JCB 16 digit	37.7776736994140094	-122.418868490810539
9230	2020-01-12 20:27:02	2020-01-12	Lemmie Moore-Eichmann	lemmie.moore.eichmann@woohoo.com	Victorville	California	4706269048049	6b96d6948a35459719113f20310010d9	Mastercard	34.5354562419231996	-117.302887485331297
9231	2020-01-12 20:27:36	2020-01-12	Malinda Little-Hahn	malinda.little.hahn@geemail.com	Berkeley	California	4952418346206339	0e43b2c10e4a7361507a6c8c62df2350	JCB 16 digit	37.876683769689599	-122.27035956397259
9232	2020-01-12 20:46:16	2020-01-12	Lethia Weimann	lethia.weimann@woohoo.com	Philadelphia	Pennsylvania	4742317071025507	968121fec6c46edc206854dc1eeb6c08	Mastercard	40.0255738637834781	-75.0905381868027177
9233	2020-01-12 21:06:12	2020-01-12	Lyric Boehm	lyric.boehm@geemail.com	Los Angeles	California	869914618923551397	17c20e9c83bbdcda535d4385f0c0dab6	JCB 15 digit	34.0850965169124294	-118.446038452069459
9234	2020-01-12 21:21:53	2020-01-12	Mrs. Kizzie Schroeder	mrs.kizzie.schroeder@geemail.com	San Francisco	California	3088459304518852944	fd17313010be68cc610bf6ec348f9f47	JCB 15 digit	37.7494788817247979	-122.440347651431892
9235	2020-01-12 21:41:47	2020-01-12	Paxton Batz	paxton.batz@woohoo.com	Aurora	Illinois	676233685769557	f7735dad6eb0e2ca0d34c38e4cb6d9be	Mastercard	41.7992413680758332	-88.207937024293841
9236	2020-01-12 21:42:43	2020-01-12	Dr. Johnny McLaughlin	dr.johnny.mclaughlin@warmmail.com	San Jose	California	4644728020128581	c286d1bb99260d335cb213de16af8807	Maestro	37.3875179339021457	-121.772591106569024
9237	2020-01-12 21:52:57	2020-01-12	Pleasant Gibson	pleasant.gibson@warmmail.com	San Francisco	California	639038769740309	900019a98cd6e167775896cd73b647b2	VISA 13 digit	37.7647670163654112	-122.401829925596473
9238	2020-01-12 22:29:48	2020-01-12	Dr. Ayanna Grimes MD	dr.ayanna.grimes.md@geemail.com	Charlotte	North Carolina	3468180866695595	b486ef821de917ace0e87fbe11740490	Maestro	35.1201682296369242	-80.8914858069680633
9239	2020-01-12 23:02:52	2020-01-12	Kobe Treutel	kobe.treutel@geemail.com	Fort Wayne	Indiana	676296741865768	fe5f7a8494d8eab9af9102908d373fe6	JCB 16 digit	41.1716110064432002	-85.1695312206387598
9240	2020-01-12 23:08:05	2020-01-12	Osbaldo Schulist	osbaldo.schulist@woohoo.com	Las Cruces	New Mexico	53711482084601376	b485f81336038f21abae77e765a0cbc3	VISA 16 digit	32.3234035943668303	-106.871534050454201
9241	2020-01-12 23:26:45	2020-01-12	Jocelyn Bergstrom	jocelyn.bergstrom@geemail.com	San Francisco	California	4066734321954	373979f1185ece630698a31c1f703b86	American Express	37.7913113125406852	-122.434546710184506
9242	2020-01-12 23:38:59	2020-01-12	Stormy Considine MD	stormy.considine.md@woohoo.com	Colorado Springs	Colorado	6011272575054863214	a9e881f79fcae8358f0eac1010bcd32e	JCB 16 digit	38.7786655598368526	-104.769871923901889
9243	2020-01-12 23:54:54	2020-01-12	Mrs. Effie Medhurst	mrs.effie.medhurst@geemail.com	San Francisco	California	4594088670675542	b47d832aebc3ca2d19ff30acfdd4004f	American Express	37.7911742773877322	-122.422221184751507
9244	2020-01-13 00:07:21	2020-01-13	Luisa Lebsack	luisa.lebsack@geemail.com	Berkeley	California	4688626115931322	a78ca61054f9db97d5cd42775403484b	VISA 16 digit	37.8954476938811098	-122.268254138344915
9245	2020-01-13 00:09:14	2020-01-13	Miss Bryanna Wunsch DDS	miss.bryanna.wunsch.dds@geemail.com	San Francisco	California	4537249475600	04ff228426d8e4ac2dfc0a39eaeb5a87	VISA 16 digit	37.7741298123102638	-122.446756884236137
9246	2020-01-13 00:13:43	2020-01-13	Alissa Smith	alissa.smith@warmmail.com	Columbia	Missouri	6011188440238089918	3b743f89b39c97ae80e1372f7eb9f0a3	Voyager	38.9598325686410618	-92.2658102103096525
9247	2020-01-13 01:35:38	2020-01-13	Christopher Brown	christopher.brown@warmmail.com	Tacoma	Washington	869998871875962455	487c208d37bffef11caed0244fa06bac	JCB 16 digit	47.3474505061402908	-122.384408288938175
9248	2020-01-13 02:03:43	2020-01-13	Miss Darian Johns	miss.darian.johns@geemail.com	Indianapolis	Indiana	3158243669767731861	50b338f6b5c1f38a8ab63f2e1cf67b04	VISA 16 digit	39.794919560757279	-86.1159089220888916
9249	2020-01-13 03:00:57	2020-01-13	Mr. Durwood Hessel	mr.durwood.hessel@geemail.com	Pearland	Texas	4808986620086458	eb7b98e30566e0c01aa552932b08d4b0	Maestro	29.4788168188922128	-95.280547970425701
9250	2020-01-13 03:24:22	2020-01-13	Egbert Hyatt	egbert.hyatt@geemail.com	Berkeley	California	869938723737061492	cb12f870787b2b625c979462b4ecb840	VISA 13 digit	37.8568842140955084	-122.256670816711917
9251	2020-01-13 03:57:14	2020-01-13	Deirdre Wiza	deirdre.wiza@geemail.com	Los Angeles	California	4645020915895279	d61ea3c6aa667a5f3bf21368646b5121	Mastercard	34.0719666235014742	-118.357198399071763
9252	2020-01-13 04:22:50	2020-01-13	Mrs. Ana Murazik PhD	mrs.ana.murazik.phd@geemail.com	San Francisco	California	3096928750469156565	50df38264609998d572a682e05a1a1dd	Diners Club / Carte Blanche	37.7611594737752583	-122.448752060405383
9253	2020-01-13 04:35:54	2020-01-13	Adriel Wiegand	adriel.wiegand@geemail.com	San Francisco	California	4939878188837988	f34d32552ed88ed5d19473205f4a261c	JCB 16 digit	37.7745551764641618	-122.459434334369973
9254	2020-01-13 04:57:25	2020-01-13	Stephenie Frami	stephenie.frami@geemail.com	Winston–Salem	North Carolina	4451030220408349	663bbe35e2d652efc3a3afab68dc87fd	Discover	36.0971190124515431	-80.321783049976446
9255	2020-01-13 05:09:23	2020-01-13	Shane Reichert	shane.reichert@geemail.com	Surprise	Arizona	3096587333058849262	790a4ec1a0c3eeb39502cae80d2e85d4	Voyager	33.6673137263622166	-112.416247178357835
9256	2020-01-13 05:33:24	2020-01-13	Dr. Juan Brakus Jr.	dr.juan.brakus.jr.@geemail.com	Oakland	California	4042985496860	d3cabc6ac44fb2e5e431f77fbdd2709b	VISA 16 digit	37.7960496931327796	-122.306995320085264
9257	2020-01-13 06:15:48	2020-01-13	Hansel Jaskolski	hansel.jaskolski@geemail.com	Chicago	Illinois	6011585170367971680	5ade281c1cb706e6fc028d333853edda	VISA 13 digit	41.8801171697512302	-87.7172790952987924
9258	2020-01-13 06:15:58	2020-01-13	Dr. North Rolfson V	dr.north.rolfson.v@woohoo.com	San Diego	California	4037758528962434	d717ee6c7ca47d0089f09eced8d29fc7	VISA 13 digit	32.7269078877355923	-117.198794925948604
9259	2020-01-13 06:28:05	2020-01-13	Arno Hayes	arno.hayes@geemail.com	St. Petersburg	Florida	4908391805214950	7e6f200d2befc34f33d4399bb1e4e813	Discover	27.7329072439931323	-82.66820841076634
9260	2020-01-13 06:39:06	2020-01-13	Alfonse Kirlin Sr.	alfonse.kirlin.sr.@woohoo.com	New Orleans	Louisiana	3000335430087965	e7c7a65465fb701a4fad6ce2000fa654	Discover	30.0479176272653028	-89.9099591886419773
9261	2020-01-13 07:06:29	2020-01-13	Dr. Kody Bins	dr.kody.bins@geemail.com	Corona	California	4412172718741	9abaf2416c2b8fb1b9eff90f3f129e2f	Diners Club / Carte Blanche	33.9611375411395002	-117.480851156890395
9262	2020-01-13 07:17:31	2020-01-13	Miss Nealie Yost	miss.nealie.yost@geemail.com	Chicago	Illinois	210025835529638769	972a5f5c530d41a59241c9aa5f2589c8	VISA 16 digit	41.8356754460208151	-87.6683434317383927
9263	2020-01-13 07:37:30	2020-01-13	Dr. Lafe Rowe I	dr.lafe.rowe.i@geemail.com	Austin	Texas	3787806473107890	7cc63a078f615fc9e8491c35242534da	VISA 16 digit	30.2370890386529254	-97.8244480728875914
9264	2020-01-13 07:43:59	2020-01-13	Howell Kertzmann	howell.kertzmann@woohoo.com	Norfolk	Virginia	3452594282374924	468200f1337b972735918120d923b2d3	Discover	36.9955310092326286	-76.1483930510472504
9265	2020-01-13 07:55:38	2020-01-13	Helyn Harber MD	helyn.harber.md@geemail.com	San Francisco	California	3088606596538230439	e6837ffe455d45d7a826add413b1ce9e	JCB 16 digit	37.7814375828686195	-122.410429742818494
9266	2020-01-13 08:15:18	2020-01-13	Orion Marvin	orion.marvin@geemail.com	San Francisco	California	3088568637915004785	98c1ad3c8aeb6cf62b35d09b71206344	Discover	37.8025172054347323	-122.428371563742459
9267	2020-01-13 08:17:39	2020-01-13	Roddy Buckridge	roddy.buckridge@geemail.com	Corpus Christi	Texas	676263109851764	ec8fdaa1fd38330c9f593e95d25cb7b4	JCB 16 digit	27.7996857237007475	-97.1278631065335105
9268	2020-01-13 08:22:27	2020-01-13	Dr. Kendal Murphy	dr.kendal.murphy@geemail.com	Houston	Texas	180099978511854134	d3a44ffbdd8ba649b82db53dbd74fc1c	American Express	29.7312043414529406	-95.3239613271799016
9269	2020-01-13 08:58:29	2020-01-13	Ms. Presley Mayer	ms.presley.mayer@geemail.com	San Francisco	California	501813397262687	36c6b7bf1a534a07ec5358b6fb660f34	JCB 15 digit	37.7918936765235145	-122.418137829367112
9270	2020-01-13 09:23:28	2020-01-13	Judge Gulgowski	judge.gulgowski@warmmail.com	Houston	Texas	4924780169969060	14da56eedb37567215e25f1aeba232af	Mastercard	29.8663979246824987	-95.4030798276901209
9271	2020-01-13 09:29:40	2020-01-13	Miss Mari Graham	miss.mari.graham@geemail.com	Jacksonville	Florida	3088475889842158893	32591da02fa1f5ce3bb2d12eca9546b7	Maestro	30.2891332602646202	-81.5935976681843442
9272	2020-01-13 10:19:53	2020-01-13	Audrianna Conroy	audrianna.conroy@warmmail.com	St. Louis	Missouri	4245911500180	ea7e914f2515c04e614365b80c7d30f7	Discover	38.6682480161234707	-90.2452923139095304
9273	2020-01-13 10:21:05	2020-01-13	Albertus Barrows	albertus.barrows@geemail.com	Shreveport	Louisiana	51724718805270511	674abe2c0b8fc2f7b039a0c8a2c432bc	JCB 16 digit	32.5296984768245423	-93.7329012027222603
9274	2020-01-13 10:30:31	2020-01-13	Mr. Adrian Breitenberg	mr.adrian.breitenberg@warmmail.com	Washington	District of Columbia	3050891834798557	e66544434c965baf1b8df7b053ffc87b	Diners Club / Carte Blanche	38.8508783670406785	-77.09178138526417
9275	2020-01-13 10:35:29	2020-01-13	Miss Cherrelle Volkman DVM	miss.cherrelle.volkman.dvm@geemail.com	Milwaukee	Wisconsin	3337257913957795762	0f85300b35e65737a978be1b78541d6c	VISA 16 digit	43.0434064926199582	-87.9063180818323104
9276	2020-01-13 10:41:27	2020-01-13	Pate Funk	pate.funk@geemail.com	Berkeley	California	210010413906024297	d80c68d82ddef4678aa2f72ea7db82d0	Diners Club / Carte Blanche	37.8898052415280731	-122.280291376665417
9277	2020-01-13 10:42:59	2020-01-13	Crockett Homenick	crockett.homenick@warmmail.com	Philadelphia	Pennsylvania	180089297370013365	73592326615b3c16788e7105fdcea4f4	JCB 16 digit	39.9165560807060444	-75.14821207992658
9278	2020-01-13 10:56:55	2020-01-13	Gerry Ratke	gerry.ratke@geemail.com	Tacoma	Washington	210020360881742906	e9679e10d67a5a77f21e4cbcf4ee4d79	Maestro	47.2559883679848198	-122.41056833721251
9279	2020-01-13 11:07:20	2020-01-13	Artie Sipes DVM	artie.sipes.dvm@geemail.com	Norfolk	Virginia	3528122151612685341	992b90d35eaaae85c0455c3271681bb5	JCB 16 digit	36.9980207558739949	-76.2774257795423267
9280	2020-01-13 11:19:59	2020-01-13	Leeroy Cummerata	leeroy.cummerata@geemail.com	Oakland	California	060451981436739	244569f47c962125d8fc9e67c36b284f	Voyager	37.7767967726799725	-122.251803528568317
9281	2020-01-13 12:10:42	2020-01-13	Flossie Stark	flossie.stark@geemail.com	San Diego	California	3158402791070552268	2d3d944c190e64d4d644d3fbb001928e	JCB 16 digit	32.8973138214621699	-117.191435733521359
9282	2020-01-13 12:19:33	2020-01-13	Justine Dooley	justine.dooley@geemail.com	Surprise	Arizona	4847609746159149	3acefd388a188dd5014febb97d9e6009	Maestro	33.7164457087632243	-112.471441139024492
9283	2020-01-13 12:30:58	2020-01-13	Mallorie Prosacco	mallorie.prosacco@geemail.com	Daly City	California	6011829818155712247	ec2b89b22134c8a2f08a286e90cdb360	Mastercard	37.6394763269383432	-122.534354103831575
9284	2020-01-13 12:46:14	2020-01-13	Latisha Cruickshank	latisha.cruickshank@geemail.com	New York	New York	3158895798146302937	3de74258fbdea77a21a44d676fc424c3	Discover	40.6039129629954658	-73.9122402104444802
9285	2020-01-13 13:08:18	2020-01-13	Dianne Hane	dianne.hane@geemail.com	Raleigh	North Carolina	4371283717902145	3e53152f72f263a617580ef80cffa9f3	JCB 16 digit	35.8817337643489225	-78.5847126898292458
9286	2020-01-13 13:19:27	2020-01-13	Ms. Corine Botsford PhD	ms.corine.botsford.phd@geemail.com	Minneapolis	Minnesota	676261134483090	81ed01e9e931874af42135c50417a279	American Express	44.8925365413159128	-93.2808992937944765
9287	2020-01-13 13:20:42	2020-01-13	Ava Hintz	ava.hintz@warmmail.com	Austin	Texas	4462216326839829	ee665df2c05cb84d4e2709e5834d6269	JCB 16 digit	30.392099441879985	-97.6761221225611962
9288	2020-01-13 13:29:42	2020-01-13	Francesca Donnelly	francesca.donnelly@woohoo.com	Berkeley	California	6011606270569804690	59290d8e4a87f90eee4940a7cd5efc6a	Diners Club / Carte Blanche	37.8595501773983685	-122.299440065809776
9289	2020-01-13 13:47:14	2020-01-13	Cole Bechtelar-Sipes	cole.bechtelar.sipes@geemail.com	Jacksonville	Florida	6011805957003284385	5252054013f29268a4900f04d3e070d4	JCB 16 digit	30.2386381934914752	-81.6421826574098333
9290	2020-01-13 13:56:23	2020-01-13	Dr. Sing Conroy DVM	dr.sing.conroy.dvm@woohoo.com	Salt Lake City	Utah	52131884027368314	7a963c4b92afb515ffff43cd689d5e08	VISA 13 digit	40.8314471640769341	-111.979879308905453
9291	2020-01-13 14:03:35	2020-01-13	Glynn Rath	glynn.rath@geemail.com	San Francisco	California	6011736120777256014	be13a4960ce5b5a0202bc693ba156d5a	VISA 16 digit	37.7378962616690714	-122.433900087588839
9292	2020-01-13 14:05:33	2020-01-13	Beckham Windler	beckham.windler@geemail.com	Irving	Texas	4094100901543798	bb84025d228cd6e60645ce276fdd6bdd	JCB 15 digit	32.8833112462841015	-97.0502965919021534
9293	2020-01-13 14:07:27	2020-01-13	Ms. Demetra Cremin PhD	ms.demetra.cremin.phd@woohoo.com	Glendale	California	3096296883095810703	05fd3ce7304d938bd52dbfc3ddf64a4c	Maestro	34.1730302567347834	-118.165574499302735
9294	2020-01-13 15:31:53	2020-01-13	Kiel Kirlin	kiel.kirlin@geemail.com	Frisco	Texas	4788967773078	f25ac9fe23cc9dc7180527bacc053f78	American Express	33.0565416258756102	-96.9201448820274294
9295	2020-01-13 15:50:19	2020-01-13	Ivonne Bayer	ivonne.bayer@geemail.com	Berkeley	California	869913522657286850	58638465423342ffa9cbdf458b9cb226	JCB 15 digit	37.870845067537303	-122.271421837170465
9296	2020-01-13 16:00:39	2020-01-13	Hal Kunze I	hal.kunze.i@geemail.com	El Paso	Texas	4580110913001322	bef4bc6ead35305634e728c54252606d	JCB 16 digit	31.7896158585619197	-106.497441006310297
9297	2020-01-13 16:04:17	2020-01-13	Ms. Cyndi Larson	ms.cyndi.larson@geemail.com	Gilbert	Arizona	639085833530380	1c6304a069fec8eb91593712c23bd4dd	JCB 16 digit	33.2614885441839689	-111.749272017985959
9298	2020-01-13 16:37:12	2020-01-13	Tillie Conn-Wyman	tillie.conn.wyman@geemail.com	New York	New York	6011131632446813901	155f6dd957fc6cbef5a9a3790962666e	Maestro	40.6682407662961651	-73.9023842567939226
9299	2020-01-13 16:41:29	2020-01-13	Santo Sporer	santo.sporer@geemail.com	Downey	California	3059058507183282	4aded51daa2a81460772e2718d70a7c9	VISA 16 digit	34.0028319229155827	-118.087389000748843
9300	2020-01-13 17:38:00	2020-01-13	Ruthie Bergnaum-Powlowski	ruthie.bergnaum.powlowski@geemail.com	Oakland	California	3407407164992943	2727c2ed2f355d725cf622a65c43277a	Mastercard	37.8108093497292614	-122.294175299306858
9301	2020-01-13 17:57:55	2020-01-13	Lenon Runte	lenon.runte@geemail.com	San Francisco	California	6011866224061872809	882757baf11e030a305d47c1c68f70a9	Diners Club / Carte Blanche	37.7684785938141658	-122.408219338967271
9302	2020-01-13 18:08:50	2020-01-13	Dr. Gale VonRueden	dr.gale.vonrueden@geemail.com	Los Angeles	California	4255046906160	e71501b3cd841fbe02ec611c3f9fa489	JCB 15 digit	34.1063702904485169	-118.500600373045728
9303	2020-01-13 18:10:21	2020-01-13	Maceo Homenick	maceo.homenick@geemail.com	Oakland	California	4043912633839704	3a440e3013431736fb7f9570e50eae05	Diners Club / Carte Blanche	37.7937883500582075	-122.25945621486926
9304	2020-01-13 18:30:39	2020-01-13	Braylon Kuvalis	braylon.kuvalis@geemail.com	San Francisco	California	3158093189981015729	eb8b1a70beb739ff8cc4c9dda631a56d	American Express	37.7686534550513784	-122.428321284625341
9305	2020-01-13 18:46:08	2020-01-13	Miss Caldonia Stiedemann MD	miss.caldonia.stiedemann.md@warmmail.com	Minneapolis	Minnesota	4143405467133	0e189450b170bcdb0280cdc34222d30c	Mastercard	45.0484015501189958	-93.3662696327820356
9306	2020-01-13 18:49:15	2020-01-13	Gary Padberg	gary.padberg@geemail.com	Rochester	Minnesota	4416756612220	7f679f7079457b2c2b7559555b2bc9cb	VISA 13 digit	44.1143676953759041	-92.4726048920888388
9307	2020-01-13 19:03:27	2020-01-13	Mr. Omar Effertz	mr.omar.effertz@geemail.com	Lewisville	Texas	3337145160555513413	3d81765e19468e259b5c7cc27111e119	Voyager	32.982501296930387	-97.0632641698263683
9308	2020-01-13 19:49:31	2020-01-13	Rafael Kreiger	rafael.kreiger@geemail.com	San Francisco	California	4581144210358563	0ec14c71a3be8cc77439d7110d4602a7	Mastercard	37.7780175154889548	-122.445041181533952
9309	2020-01-13 20:15:56	2020-01-13	Dr. Woodroe Schmeler	dr.woodroe.schmeler@geemail.com	Chicago	Illinois	4384370361341640	764bdc6c9c2fe7418550fb82b0f22863	VISA 16 digit	41.8078508834190714	-87.6514995487436579
9310	2020-01-13 20:19:17	2020-01-13	Diandra Armstrong	diandra.armstrong@warmmail.com	Phoenix	Arizona	3096391928353984049	979ccaa99d83f26aff5e4ee137e69f13	Maestro	33.5694596333827846	-112.102070777204261
9311	2020-01-13 20:51:26	2020-01-13	Dr. Kaitlyn Balistreri DDS	dr.kaitlyn.balistreri.dds@geemail.com	Fort Worth	Texas	3727295867774643	214339c6100ed7bbcf32e64ad7cfcbf9	Maestro	32.751091671600939	-97.3173738234497563
9312	2020-01-13 21:23:47	2020-01-13	Mr. Braedon Bergstrom MD	mr.braedon.bergstrom.md@geemail.com	Kenosha	Wisconsin	3528009710780770439	2ac825cb18f8c862fccb93450b47ae8b	JCB 16 digit	42.5626478332400353	-87.9068330644857241
9313	2020-01-13 21:41:36	2020-01-13	Mrs. Iona Bailey DVM	mrs.iona.bailey.dvm@geemail.com	Hialeah	Florida	3415664278502808	37d3ade301c7c07c813f724af505ee20	VISA 13 digit	25.7709997627861824	-80.3139949109773994
9314	2020-01-13 21:44:39	2020-01-13	Kaylie Hamill PhD	kaylie.hamill.phd@geemail.com	San Francisco	California	869924855933169798	17e5aef82019d22f645144a4dbf792e5	VISA 16 digit	37.7803337288624306	-122.419354748472855
9315	2020-01-13 22:06:03	2020-01-13	Dr. Rae McLaughlin	dr.rae.mclaughlin@woohoo.com	Chicago	Illinois	3158955319077413770	14dcc1afea3ff3588f1aa94cd9ec67c5	VISA 16 digit	41.8069275635130708	-87.6304659645568478
9316	2020-01-13 22:30:45	2020-01-13	Posey Smith	posey.smith@geemail.com	Philadelphia	Pennsylvania	3007360219473460	327170c225cd81cc9295cae7d00b208b	JCB 15 digit	39.9557403992354878	-75.1249124080773498
9317	2020-01-13 22:46:33	2020-01-13	Ms. Mai Windler DVM	ms.mai.windler.dvm@geemail.com	Charleston	South Carolina	6011943163104046079	0b4122667aebaf930492e9456776a788	Mastercard	32.7257849927522244	-79.8915792346149658
9318	2020-01-13 23:19:59	2020-01-13	Bria Pfannerstill	bria.pfannerstill@geemail.com	Gilbert	Arizona	4132724038120081	821b6663786c116ae6d8dfe866f00222	VISA 16 digit	33.2689194965988406	-111.783754420154168
9319	2020-01-14 00:01:29	2020-01-14	Taina Thiel DDS	taina.thiel.dds@geemail.com	New York	New York	3019484423027454	e7e65fee74174f1c6e189240493636c2	VISA 16 digit	40.6930580078382036	-73.8861893142934889
9320	2020-01-14 00:07:17	2020-01-14	Mr. Algot Jakubowski DVM	mr.algot.jakubowski.dvm@geemail.com	San Francisco	California	675910798261714	ff0559bfb268764216261f92f910d5f2	Diners Club / Carte Blanche	37.7444211178237481	-122.438370100628831
9321	2020-01-14 01:36:59	2020-01-14	Francisco Quitzon	francisco.quitzon@geemail.com	Torrance	California	3052629758892578	e5f0bc793b3597fd994bfb5d534e844f	Diners Club / Carte Blanche	33.8824786689970665	-118.302297129680952
9322	2020-01-14 01:44:43	2020-01-14	Courtland Mayer-Brown	courtland.mayer.brown@geemail.com	Gainesville	Florida	4782376443938723	9dcd42e190e33921586afca820d29504	American Express	29.6530597170639787	-82.3505950055424165
9323	2020-01-14 01:49:32	2020-01-14	Clovis Block-Tromp	clovis.block.tromp@geemail.com	High Point	North Carolina	6011176922462325328	dce0979f65d18b29dac546d0f8a95b77	Diners Club / Carte Blanche	36.045376394791532	-80.0755085560698063
9324	2020-01-14 02:13:38	2020-01-14	Makayla Rippin DVM	makayla.rippin.dvm@warmmail.com	Omaha	Nebraska	3056056562476222	855c4021459e9be8002b62f0a4fe8a5d	VISA 13 digit	41.3390121997479341	-96.0274642938397847
9325	2020-01-14 03:19:50	2020-01-14	Stella Abernathy	stella.abernathy@warmmail.com	Houston	Texas	4999243500587026	42f6de85ae0c2da21e80aa7ac36ca4bd	American Express	29.8144871363960213	-95.3214520337540705
9326	2020-01-14 03:28:49	2020-01-14	Coleman Kshlerin-Bashirian	coleman.kshlerin.bashirian@woohoo.com	Philadelphia	Pennsylvania	869954744297667964	b30208441b7d42c6649bdca92bd58a1a	Voyager	40.0812968552537257	-75.1489420281622671
9327	2020-01-14 03:32:06	2020-01-14	Dr. Jamila Schiller DVM	dr.jamila.schiller.dvm@geemail.com	Newark	New Jersey	3528824515615672269	87ddd66b79783e8c0235d5eb5bba53a1	JCB 16 digit	40.7636732120912555	-74.0753081867214291
9328	2020-01-14 04:04:08	2020-01-14	Dr. Hector Quigley DDS	dr.hector.quigley.dds@geemail.com	Seattle	Washington	676165699301340	919e1f200c3ad70d2ecba541b9960dae	Diners Club / Carte Blanche	47.7057640506345777	-122.330120367828385
9329	2020-01-14 04:22:29	2020-01-14	Florance Kshlerin DVM	florance.kshlerin.dvm@geemail.com	San Francisco	California	503875983076151	98aeeb8c24217639f3c019560a96e756	JCB 15 digit	37.7643024472655497	-122.435506258792259
9330	2020-01-14 04:23:15	2020-01-14	Elmina Funk	elmina.funk@geemail.com	Oakland	California	210008802633104014	6a4168701ed0d045e52e4903938c6142	Diners Club / Carte Blanche	37.8025387924263896	-122.275171456799242
9331	2020-01-14 04:30:42	2020-01-14	Mr. Alexandre Dickinson Jr.	mr.alexandre.dickinson.jr.@geemail.com	San Francisco	California	4659233106572671	c98c152f597274ac8fcb81ae5cc8cee0	Discover	37.7986699520207097	-122.431918880106636
9332	2020-01-14 05:25:14	2020-01-14	Angelica Reichel	angelica.reichel@geemail.com	San Francisco	California	3158679245222549157	cec945944ccef9e7757c47ca1bfb87fc	Mastercard	37.749955042941842	-122.411430784927106
9333	2020-01-14 05:32:05	2020-01-14	Gage West	gage.west@geemail.com	Lubbock	Texas	51973378172211446	21e7a63f381bbeeed30a04382d904826	Maestro	33.5558675191406195	-101.807789469548325
9334	2020-01-14 05:56:48	2020-01-14	Dillion Reichert	dillion.reichert@geemail.com	Arvada	Colorado	589329302126676	f68961b0adbc7359537e68c75646db32	VISA 13 digit	39.9331751378893856	-105.148730552659558
9335	2020-01-14 06:03:03	2020-01-14	Kavon Ankunding	kavon.ankunding@geemail.com	Springfield	Illinois	54437730816049469	74f9c6ad3e98a9aedc69e916efea9712	JCB 16 digit	39.8358770491242424	-89.6205970685932698
9336	2020-01-14 06:09:38	2020-01-14	Tamara Doyle	tamara.doyle@geemail.com	San Francisco	California	869951007934949770	062da52dca85edfae60fc0826db0f4db	JCB 16 digit	37.8020199454328676	-122.414645021639217
9337	2020-01-14 06:14:43	2020-01-14	Mendy Bailey	mendy.bailey@geemail.com	San Francisco	California	4016377983920749	1e5f4b77835168ec44070db2eeec08b2	Maestro	37.7890918549033188	-122.427125743886677
9338	2020-01-14 06:19:56	2020-01-14	Ms. Carmel Konopelski	ms.carmel.konopelski@woohoo.com	San Angelo	Texas	3037464618512546	da0c9a1a848bd89391f66367bad370dd	Voyager	31.5097860810499633	-100.358087059214711
9339	2020-01-14 06:23:04	2020-01-14	Mrs. Georgette Goyette	mrs.georgette.goyette@geemail.com	San Francisco	California	4414733912474	c96bdc4815253bb18229118a7ce39806	Diners Club / Carte Blanche	37.7922703315486785	-122.435511039796566
9340	2020-01-14 06:45:49	2020-01-14	Dr. Imani Howell PhD	dr.imani.howell.phd@geemail.com	Austin	Texas	3158835999175273899	3dcf02cebb0a32564609189920413820	American Express	30.3507537766952069	-97.7863253633730096
9341	2020-01-14 06:52:59	2020-01-14	Paralee Macejkovic	paralee.macejkovic@geemail.com	Cedar Rapids	Iowa	55249875203114117	e4af02c22dcbb553493da1b77c559f67	JCB 15 digit	41.9246897595077712	-91.6870278217896839
9342	2020-01-14 07:37:23	2020-01-14	Burley Ondricka	burley.ondricka@geemail.com	Berkeley	California	180045142100122230	77dd420f4e5a010eace4091ea03c5283	Diners Club / Carte Blanche	37.8916504001160064	-122.234423631506729
9343	2020-01-14 07:47:53	2020-01-14	Linn Bode	linn.bode@warmmail.com	San Francisco	California	3088665214453975982	49ef7c36571650f261e05082b876eb9b	American Express	37.765957385013408	-122.438113474191212
9344	2020-01-14 08:01:44	2020-01-14	Ms. Macy Corkery	ms.macy.corkery@geemail.com	Las Vegas	Nevada	3528306725870432245	8d320b579951de94769f17d810a47c86	JCB 16 digit	36.1523723426841173	-115.347600958470622
9345	2020-01-14 08:14:44	2020-01-14	Veta Ritchie	veta.ritchie@warmmail.com	Plano	Texas	4407716694851932	14ad19fdf0a1bf4c28996b9f2df17c77	American Express	33.0257952537938948	-96.8054395170133546
9346	2020-01-14 08:32:43	2020-01-14	Bradly Mayert	bradly.mayert@geemail.com	Grand Prairie	Texas	4445179509622	6132a2753b3e9c3bd8ad7200cbd670bd	Voyager	32.7467399792797877	-96.9485151757359489
9347	2020-01-14 08:33:36	2020-01-14	Lon Moen MD	lon.moen.md@woohoo.com	New York	New York	3452925744597324	85afa02f6c6a8e0cf54c4df72695710c	JCB 16 digit	40.7410581253692499	-73.9049303376942817
9348	2020-01-14 08:39:43	2020-01-14	Ms. Mitzi Torp PhD	ms.mitzi.torp.phd@geemail.com	San Francisco	California	503885367312866	a1b3fdc3c4873acd4f4d237b6e0d5194	JCB 16 digit	37.7760719241296101	-122.415837003862649
9349	2020-01-14 09:04:13	2020-01-14	Ramona Larkin-Jaskolski	ramona.larkin.jaskolski@geemail.com	New York	New York	180073606305872752	bf890a7c99d421e5e0d668ac4c0dd88d	JCB 16 digit	40.7376078484337754	-73.9382180736295851
9350	2020-01-14 09:06:42	2020-01-14	Mr. Claudius Krajcik	mr.claudius.krajcik@geemail.com	Portland	Oregon	4756614948598960	8c2e3c51c70cba1dbf3c81a7ec19ccd2	American Express	45.504931463476268	-122.740467806858945
9351	2020-01-14 09:09:09	2020-01-14	Warren Larkin	warren.larkin@warmmail.com	Lancaster	California	51717790861911279	b640d72bedf7a0ea1c887af1b597234f	JCB 16 digit	34.672116892297197	-118.257727581865339
9352	2020-01-14 09:21:40	2020-01-14	Adlai Murray	adlai.murray@geemail.com	Los Angeles	California	4963044276778803	23d7430c201dbbafd7ab6921fcb31b39	VISA 16 digit	34.0800392488814836	-118.472160086128113
9353	2020-01-14 09:31:58	2020-01-14	Dr. Rayna Tremblay DVM	dr.rayna.tremblay.dvm@geemail.com	El Monte	California	180014474199854796	cb29f8e797499b60d77ab68941c78e54	Maestro	34.1180469292405988	-117.955909219084674
9354	2020-01-14 09:32:44	2020-01-14	Mr. Amari Huels	mr.amari.huels@geemail.com	San Francisco	California	55358938100863033	33ce12584fde897ba5fd700911782e11	Discover	37.7822273229240295	-122.443044844339184
9355	2020-01-14 09:35:29	2020-01-14	Curley Greenfelder-Anderson	curley.greenfelder.anderson@geemail.com	Berkeley	California	3775437834990982	47b4e9a19bfc79ec3f660f2873c0ae1a	JCB 16 digit	37.8707936721369833	-122.290836394005353
9356	2020-01-14 09:56:56	2020-01-14	Jarred Anderson	jarred.anderson@geemail.com	San Francisco	California	4421655806791374	f45e8607c9da9f6a5d231d1bbb52915e	VISA 13 digit	37.7348410062379997	-122.448606065940041
9357	2020-01-14 10:02:20	2020-01-14	Lila Becker	lila.becker@geemail.com	Lexington	Kentucky	210088536616447452	bc6a49c93269aa14cfa66af4896e67ac	VISA 16 digit	37.9527160303078617	-84.4110893729042147
9358	2020-01-14 10:08:44	2020-01-14	Royal Wunsch Jr.	royal.wunsch.jr.@warmmail.com	Berkeley	California	4906560081422	f4579cb5460333e8bec18392f0214163	VISA 16 digit	37.8477197354383321	-122.282949081999547
9359	2020-01-14 10:43:20	2020-01-14	Eliza Raynor	eliza.raynor@warmmail.com	Albuquerque	New Mexico	6011328576564036899	c5fcb0ac3e82fa1a853819602ef8cc4f	JCB 16 digit	35.0319134229462605	-106.564482354752357
9360	2020-01-14 10:55:30	2020-01-14	Verl Kohler DDS	verl.kohler.dds@geemail.com	McAllen	Texas	180053446221411557	1b893b7d379b6a738d159ac0082a0e74	VISA 16 digit	26.1450481657709908	-98.1650234719119936
9361	2020-01-14 11:16:10	2020-01-14	Sylvester Ernser	sylvester.ernser@geemail.com	Tulsa	Oklahoma	6011222112640745738	5c70c0fdc28b1256927916907ff88156	VISA 16 digit	36.1598763972889614	-95.925930551854151
9362	2020-01-14 11:42:45	2020-01-14	Margarito Weber	margarito.weber@geemail.com	Newark	New Jersey	4077308899767227	6471d9c1626afa0f4a1dab873e0d29f6	VISA 13 digit	40.6286480630662297	-74.1080273075703531
9363	2020-01-14 12:02:24	2020-01-14	Adline Boyer PhD	adline.boyer.phd@geemail.com	San Francisco	California	3026141343318339	d7585a0f8def3c1bb52353aebdf5a6bc	Discover	37.8144821075179252	-122.429537987973887
9364	2020-01-14 12:11:28	2020-01-14	Mr. Domenick Beatty	mr.domenick.beatty@geemail.com	Pembroke Pines	Florida	6011856675661548937	2efc519e73af8d24aebd2920e36f3fe3	Maestro	26.0261841872744277	-80.3541201921548662
9365	2020-01-14 12:16:11	2020-01-14	Jadyn Kub-Haag	jadyn.kub.haag@woohoo.com	Anaheim	California	4459407297905617	6f8020532656989b0d555ab123edbff1	JCB 16 digit	33.8128980166576767	-117.765025795132289
9366	2020-01-14 12:21:31	2020-01-14	Pamela Stokes PhD	pamela.stokes.phd@geemail.com	Saint Paul	Minnesota	4732727127910	e6a3d36b5c8cb3fe0aec5d0f4a71bb04	Diners Club / Carte Blanche	44.9552143859617459	-93.1338883355058726
9367	2020-01-14 12:24:28	2020-01-14	Tania Tromp	tania.tromp@woohoo.com	Killeen	Texas	4292758421575	f5ee2c2449cf86ef419fb7b5b463f5e3	Maestro	31.0324607594635324	-97.7742537832520924
9368	2020-01-14 12:29:06	2020-01-14	Shari Mayert	shari.mayert@geemail.com	Gilbert	Arizona	3096347554337710576	7a5ad37839ffc7124a04dd466467b0b5	Mastercard	33.2976799662571352	-111.808524362057824
9369	2020-01-14 12:47:33	2020-01-14	Vernita Von	vernita.von@geemail.com	El Paso	Texas	54788137082978014	c660e1898171cab9a1fd7761c7b082df	Maestro	31.9030684981323809	-106.382881184618924
9370	2020-01-14 12:52:44	2020-01-14	Dr. Philip Bednar DVM	dr.philip.bednar.dvm@warmmail.com	San Francisco	California	6011498153090794229	848cc1875dc36f96f7d2c1d8eab900ab	JCB 15 digit	37.777880693083091	-122.455173376393375
9371	2020-01-14 13:12:46	2020-01-14	Mannie Bergnaum	mannie.bergnaum@warmmail.com	Davenport	Iowa	3337047274629334125	8b490dcb8facfe515dc0aa8437d79ed6	Voyager	41.518664193552361	-90.659839356174686
9372	2020-01-14 13:29:14	2020-01-14	Obie Collier	obie.collier@geemail.com	New York	New York	3436454611005031	32dfd2192b7b5f5f4ea16fae8da670be	JCB 16 digit	40.6040143670272045	-73.8699278383411411
9373	2020-01-14 13:34:25	2020-01-14	Doctor Daniel DVM	doctor.daniel.dvm@warmmail.com	San Francisco	California	4915804474012696	263b9a37abb48dc9822eb29768cea5c8	Voyager	37.7824716293327043	-122.446065271647356
9374	2020-01-14 13:44:38	2020-01-14	Somer Schowalter	somer.schowalter@geemail.com	Portland	Oregon	51800847496161635	dda1a7541ab0ae4824fcb0820b17af6b	American Express	45.5312080043256273	-122.668602355849004
9375	2020-01-14 13:47:27	2020-01-14	Jettie Ledner DVM	jettie.ledner.dvm@geemail.com	San Francisco	California	869989415714823055	abc3d8e449814b4cfb6ce00896d1eb16	Voyager	37.7739950638514586	-122.435671771288469
9376	2020-01-14 14:41:35	2020-01-14	Catalina Buckridge-Luettgen	catalina.buckridge.luettgen@geemail.com	Arlington	Texas	53452424928518203	266c18fb4d5d39dc847ad959cbcb8c35	American Express	32.6247356251597367	-97.1650266740031583
9377	2020-01-14 14:55:32	2020-01-14	Cuba Bartell	cuba.bartell@woohoo.com	Springfield	Missouri	4675892960568578	88f4a074748e6eba3c836b84324dd3ac	VISA 16 digit	37.2288555599942796	-93.2466368650842554
9378	2020-01-14 15:10:38	2020-01-14	King McClure	king.mcclure@warmmail.com	Port St. Lucie	Florida	4637051876355169	fd954d49e9654778235da3b74f2a60c8	JCB 15 digit	27.2752389264427109	-80.4063126182269343
9379	2020-01-14 15:35:08	2020-01-14	Loretto Stracke	loretto.stracke@woohoo.com	Gainesville	Florida	210068358213225247	800f6ae14496eefcedace26d4209b75b	Mastercard	29.6750646119762216	-82.3008289959620782
9380	2020-01-14 15:46:51	2020-01-14	Janiah McCullough-Bauch	janiah.mccullough.bauch@woohoo.com	Warren	Michigan	3096755405343452668	3acb264dceadc97873e467567b661ef1	VISA 16 digit	42.5874598816964749	-83.0603129870258385
9381	2020-01-14 15:54:43	2020-01-14	Madelyn D'Amore	madelyn.d'amore@geemail.com	Thousand Oaks	California	639029277115084	2a347f3604f0bd147667b2db62f5cb40	Mastercard	34.1927503179565093	-118.892250833232708
9382	2020-01-14 16:18:00	2020-01-14	Zeno Stamm	zeno.stamm@woohoo.com	Chicago	Illinois	3337482681538699681	ba5c549967598737334b89726fdce675	JCB 15 digit	41.7660866018220815	-87.6684588563658309
9383	2020-01-14 16:34:06	2020-01-14	Gussie Hamill-Rau	gussie.hamill.rau@woohoo.com	Jacksonville	Florida	3528508214322510243	9eb631e6ebd9415359c7736b95a52b72	Mastercard	30.3788642436783753	-81.6716255401339453
9384	2020-01-14 16:56:10	2020-01-14	Loma Toy	loma.toy@geemail.com	Phoenix	Arizona	4274786631605949	e2388da2b15f4eb2ecf438da4fe29be7	JCB 15 digit	33.505459127056227	-111.9949311076127
9385	2020-01-14 17:34:34	2020-01-14	Mr. Bell Robel	mr.bell.robel@geemail.com	Joliet	Illinois	6011776893113903967	554e047ad75e64a7e56006af1f21f032	VISA 16 digit	41.4845029462918617	-88.0677510550349893
9386	2020-01-14 17:34:40	2020-01-14	Miss Astrid Hackett	miss.astrid.hackett@geemail.com	Columbus	Ohio	4571089767241633	c5fe264b63eb2cbb4f0b566d47ab99bb	Discover	39.9765447623606747	-82.9218473260525712
9387	2020-01-14 17:46:45	2020-01-14	Miss Josephine Ziemann	miss.josephine.ziemann@woohoo.com	San Francisco	California	503858593644873	a9687bc368101f83627d53722406cf22	Discover	37.7703898140350915	-122.412262527084451
9388	2020-01-14 17:55:30	2020-01-14	Charlie Oberbrunner	charlie.oberbrunner@woohoo.com	Frisco	Texas	6011039113881247643	74005345e27d178c22d9f7cd96fa7027	American Express	33.2080364719029504	-96.8236639448184491
9389	2020-01-14 19:46:15	2020-01-14	Loreen O'Keefe	loreen.o'keefe@geemail.com	Denver	Colorado	3158131121906436833	1b975575eb9a453ee07d70d0a1e4368d	VISA 16 digit	39.6895466331444666	-104.893190316135446
9390	2020-01-14 19:56:09	2020-01-14	Earl Hahn	earl.hahn@woohoo.com	Des Moines	Iowa	676310601044257	98002b8b37a0b87f2458d2b646f45f37	JCB 15 digit	41.5773946210950598	-93.6504730897069066
9391	2020-01-14 20:36:22	2020-01-14	Lenard Legros	lenard.legros@woohoo.com	Norfolk	Virginia	869938184215150580	67701a9d7662e02a3fcbc8728a61ed5b	Mastercard	36.9408993027657289	-76.1665829899258995
9392	2020-01-14 21:00:06	2020-01-14	Mr. Ezra McClure II	mr.ezra.mcclure.ii@geemail.com	San Francisco	California	3158931092741208780	8a18963144496c90ef768875cb486fc0	Maestro	37.7890748444933422	-122.468846569282491
9393	2020-01-14 21:42:07	2020-01-14	Sabastian Zulauf	sabastian.zulauf@geemail.com	Paterson	New Jersey	4479394745737	9c8e782d12bead655840618729a269d9	VISA 13 digit	40.9589428103484181	-74.161784232079242
9394	2020-01-14 21:53:57	2020-01-14	Nayely Carroll	nayely.carroll@geemail.com	San Francisco	California	51149504133714207	6ec2c8387555f410dbc45c2967ed90b1	JCB 16 digit	37.7672179254823206	-122.42114298974117
9395	2020-01-14 22:19:54	2020-01-14	Bruno Ledner	bruno.ledner@warmmail.com	San Jose	California	3528191339246716121	187a693f86e161f67e41d1e058c10e32	Diners Club / Carte Blanche	37.332440228556095	-121.895675622554123
9396	2020-01-14 22:39:43	2020-01-14	Cornelius Ryan I	cornelius.ryan.i@woohoo.com	Chandler	Arizona	3012554810309512	fd5ba4d0a6926b659081cc6895241a6b	JCB 15 digit	33.2720518278513069	-111.944908421009401
9397	2020-01-14 23:22:55	2020-01-14	Adams Labadie	adams.labadie@geemail.com	Los Angeles	California	6011902228731831562	0905ebf37d922aedbd0fa8760ca7b30d	VISA 13 digit	34.0352165748231101	-118.427617083861676
9398	2020-01-14 23:25:16	2020-01-14	Carleigh Weber	carleigh.weber@geemail.com	Scottsdale	Arizona	4269220410099097	593e3abd118e1ca5fd5e0ac56fa11910	Maestro	33.783019111597163	-111.793970256062593
9399	2020-01-14 23:28:26	2020-01-14	Eva Funk	eva.funk@geemail.com	Phoenix	Arizona	4695314555332	1521341ff9b3ce0ae3a855bdd4ddf970	Discover	33.6696895468447366	-112.052888356421519
9400	2020-01-14 23:42:01	2020-01-14	Reno Waelchi-Ryan	reno.waelchi.ryan@woohoo.com	Houston	Texas	4368743759714984	6742b88feff2d17d0db2f2b231b33e50	Discover	29.6922853405199945	-95.3644736659727954
9401	2020-01-14 23:52:24	2020-01-14	Joselyn Rempel DDS	joselyn.rempel.dds@geemail.com	Arvada	Colorado	3423530282735256	fd5cc852c0779a27b57577819f88ed84	Maestro	39.7517720535106989	-105.08412051959634
9402	2020-01-15 00:48:16	2020-01-15	Dr. Jaime Parker DDS	dr.jaime.parker.dds@geemail.com	San Francisco	California	6011618804914543730	2d10f2b20fedce1a3513e5b8d4134165	Voyager	37.798103103986648	-122.433096983154087
9403	2020-01-15 01:02:01	2020-01-15	Terell Koepp	terell.koepp@geemail.com	San Francisco	California	54793033553736200	34cd8dfb269c8297981efa67ac6face3	JCB 15 digit	37.7905236371456397	-122.421686634264404
9404	2020-01-15 01:03:17	2020-01-15	Marjorie Brekke	marjorie.brekke@warmmail.com	Berkeley	California	869940475015361419	30c2cb1d4346e2a933b198f79d7f2b24	Diners Club / Carte Blanche	37.8447391950321048	-122.259650109193913
9405	2020-01-15 01:06:34	2020-01-15	Tasha Zulauf	tasha.zulauf@geemail.com	Elizabeth	New Jersey	3000554380897450	bea351265c70a1a9f0dc4113cbce0301	Discover	40.6034996104553372	-74.1148531299959927
9406	2020-01-15 01:15:02	2020-01-15	Jerrilyn Stamm	jerrilyn.stamm@geemail.com	Berkeley	California	3030020138045081	afaa1518ffc0109a54f29588f8b787a3	Maestro	37.8906421456726292	-122.28603809955284
9407	2020-01-15 01:33:02	2020-01-15	Douglas Will	douglas.will@geemail.com	Hartford	Connecticut	4202664549815	ca3e9753391451bdc04edc6def1e9ff5	VISA 16 digit	41.6998086968917434	-72.6523496637012869
9408	2020-01-15 01:33:42	2020-01-15	Holland Will-Farrell	holland.will.farrell@geemail.com	Honolulu	Hawaii	6011496118211337572	3c827a59317f86feaf1b97c55d245c47	JCB 16 digit	21.2470348321117477	-157.928531505048653
9409	2020-01-15 01:44:28	2020-01-15	Dabney Kerluke	dabney.kerluke@warmmail.com	Los Angeles	California	53415790737925029	85f5acaaaf5d6cb5cc21b7fc66a21925	American Express	34.0898107229597827	-118.496457616052766
9410	2020-01-15 01:55:48	2020-01-15	Unnamed Wiegand	unnamed.wiegand@warmmail.com	New York	New York	210003698221152950	643bfc243670af1a35923dfd34228d41	Mastercard	40.7225644477400905	-73.8909219826001618
9411	2020-01-15 01:56:49	2020-01-15	Leonie Corkery	leonie.corkery@geemail.com	Fort Wayne	Indiana	3013341842840998	35a0772da1be4256ac71cbc72eb3f9e9	JCB 15 digit	41.1521799400698427	-85.1587661745712126
9412	2020-01-15 02:23:29	2020-01-15	Caldonia Moen	caldonia.moen@geemail.com	New York	New York	51733895093743257	f088abe59eec26837a04ad51eb376067	Diners Club / Carte Blanche	40.6947384533695882	-74.0082836387108927
9413	2020-01-15 02:44:58	2020-01-15	Miss Ima D'Amore DVM	miss.ima.d'amore.dvm@warmmail.com	Frisco	Texas	561204127236380	e990ca26e3e315345751616e5e499428	Voyager	33.1537925544656815	-96.8561684286896138
9414	2020-01-15 02:55:05	2020-01-15	Royce Hoeger	royce.hoeger@geemail.com	San Francisco	California	4593825388832	dc98c38130616af34747b1833473f934	JCB 16 digit	37.7693243606817575	-122.400519242682037
9415	2020-01-15 02:55:33	2020-01-15	Indiana Johnson	indiana.johnson@geemail.com	Anchorage	Alaska	3407936696134533	656ea9e0586bb03483d89247c59c95d8	VISA 16 digit	61.1551054509107033	-149.323784255155545
9416	2020-01-15 03:24:46	2020-01-15	Alwine Bergnaum	alwine.bergnaum@geemail.com	Portland	Oregon	3528148324384843410	8ade3af38aab0a80e5ce2a3473f19b2b	VISA 16 digit	45.515364866599441	-122.592460650531578
9417	2020-01-15 03:34:52	2020-01-15	Rylee Zieme	rylee.zieme@geemail.com	Denver	Colorado	3528478041581493910	1a9968ee9b6df74be7bcc1d9197fc7e9	Voyager	39.7980208409070926	-104.967333222624291
9418	2020-01-15 03:56:09	2020-01-15	Lester Hoeger	lester.hoeger@warmmail.com	Phoenix	Arizona	3044306617903569	28fcafe351898ce5de21837c98767546	JCB 16 digit	33.6711521735347858	-112.180259342065455
9419	2020-01-15 04:34:33	2020-01-15	Enos Dickinson II	enos.dickinson.ii@warmmail.com	Boulder	Colorado	4343618112002576	eeee5052162a9b444dfa742e0fc842ed	American Express	40.078129698753358	-105.187028499288118
9420	2020-01-15 05:08:36	2020-01-15	Elby Feil	elby.feil@geemail.com	San Francisco	California	4719720855196338	643132847a5d0eb984dcd9f81d631979	Diners Club / Carte Blanche	37.7992837251726712	-122.435395855713224
9421	2020-01-15 05:27:55	2020-01-15	Clementine Block	clementine.block@warmmail.com	San Francisco	California	3768041029933580	2b6af9074c76634f383d80119840feff	JCB 16 digit	37.7729138833852005	-122.440547221861834
9422	2020-01-15 05:37:52	2020-01-15	Carleigh Harvey PhD	carleigh.harvey.phd@geemail.com	Tampa	Florida	180009528550341045	220a0635d05f63c2ae04842d94ddb654	Voyager	27.9732444376800196	-82.4467245898887455
9423	2020-01-15 05:48:48	2020-01-15	Dr. Randolph Franecki PhD	dr.randolph.franecki.phd@geemail.com	San Francisco	California	3528571956355052343	905bf890754e7cf9f4a082ee2af9f372	Voyager	37.7836539309525179	-122.479678170979895
9424	2020-01-15 05:51:49	2020-01-15	Aura Bergnaum DDS	aura.bergnaum.dds@geemail.com	Macon	Georgia	3402313033450193	ab9e149862d681c5bc56a20df91788ff	VISA 13 digit	32.7298458103567356	-83.7730678305223506
9425	2020-01-15 06:33:09	2020-01-15	Tristin O'Kon	tristin.o'kon@warmmail.com	Frisco	Texas	4561491727260	64df14a2920ca2a2cc1c5b8cbd812396	VISA 16 digit	33.2322995413556725	-96.7732177281495183
9426	2020-01-15 07:22:30	2020-01-15	Edna Friesen	edna.friesen@warmmail.com	Seattle	Washington	3528198694506488701	33f0bcf8a5ea9db8c858531866c9c097	Diners Club / Carte Blanche	47.5687036145869655	-122.342374261181419
9427	2020-01-15 08:26:23	2020-01-15	Miss Gennie Jaskolski	miss.gennie.jaskolski@geemail.com	Montgomery	Alabama	54220388359843045	212ac262354634ff80f1e7aa503c5909	JCB 15 digit	32.2479681216113292	-86.1980932006765102
9428	2020-01-15 08:35:06	2020-01-15	Wilfredo Collins-Keebler	wilfredo.collins.keebler@warmmail.com	Santa Rosa	California	630444172953414	62d60d7f890182e3fcaa91a852b19f68	Maestro	38.5274608984712543	-122.725333130896473
9429	2020-01-15 08:39:16	2020-01-15	Tamatha Schowalter	tamatha.schowalter@geemail.com	San Antonio	Texas	6011808500878542813	e3fd9a6b7c9b692c9c2f4e1faeb38c4e	Maestro	29.4887820960093308	-98.5330794900957443
9430	2020-01-15 08:39:49	2020-01-15	Walter Hodkiewicz II	walter.hodkiewicz.ii@geemail.com	San Francisco	California	3047827484206585	d55e6dc3886461b651ca59bad88bdc78	Discover	37.7918345262536945	-122.431979046933492
9431	2020-01-15 08:53:48	2020-01-15	Dr. Jalen Cartwright	dr.jalen.cartwright@woohoo.com	San Francisco	California	3057744965474915	080ae915abba013a5d28488aa6a35a81	JCB 16 digit	37.7438216284420847	-122.391516838294464
9432	2020-01-15 09:02:31	2020-01-15	Chyna Cassin DVM	chyna.cassin.dvm@geemail.com	Stamford	Connecticut	3764590389317341	04314474c40ecb98d4a21e5aa60f6a43	Discover	41.1619865898393087	-73.5371293603479899
9433	2020-01-15 09:14:50	2020-01-15	Ms. Akeelah Hansen PhD	ms.akeelah.hansen.phd@geemail.com	New York	New York	4069218188600	e38019e6c2e3e61f4babc74aa894c26b	Mastercard	40.7005616863947353	-73.855987133401257
9434	2020-01-15 09:29:17	2020-01-15	Tracey Schroeder-Effertz	tracey.schroeder.effertz@geemail.com	Honolulu	Hawaii	3005297806639412	860b3dafab02c7bcfdd66b0ac0a14787	VISA 16 digit	21.4188104366168375	-157.773112469699612
9435	2020-01-15 09:48:36	2020-01-15	Karl Goodwin-Heidenreich	karl.goodwin.heidenreich@geemail.com	Tucson	Arizona	6011108669700948022	bae0745df65fcc3639ebd6f5d690de10	Maestro	32.1025298937730525	-110.809805460809173
9436	2020-01-15 10:20:40	2020-01-15	Brionna Aufderhar	brionna.aufderhar@geemail.com	Rancho Cucamonga	California	4132689767242457	1ed5acc349c5f5f71164ee2e1397546f	Mastercard	34.0851528286926424	-117.549766948680201
9437	2020-01-15 10:33:31	2020-01-15	Jensen Nicolas DVM	jensen.nicolas.dvm@geemail.com	Honolulu	Hawaii	6011906619617176294	6729800709ac9e20b514fb427e9a0296	JCB 16 digit	21.3414985135413708	-157.806918507276464
9438	2020-01-15 10:38:38	2020-01-15	Prentice Koss	prentice.koss@geemail.com	Tampa	Florida	630403709776706	297a496af0c7bd93e8bcb4557ab494a7	VISA 16 digit	28.0202016960479305	-82.5673783594023405
9439	2020-01-15 10:51:38	2020-01-15	Yael Pollich	yael.pollich@geemail.com	North Las Vegas	Nevada	3414794642826582	32116f51a28961d485b56dda37df5294	Discover	36.3106511259607956	-115.087357096023496
9440	2020-01-15 11:35:02	2020-01-15	Debrah Mitchell	debrah.mitchell@warmmail.com	Mesa	Arizona	869919825298700906	813b13a7b36560e7bfe6063d20a1c93c	VISA 16 digit	33.3695351184491074	-111.791196601640053
9441	2020-01-15 11:50:11	2020-01-15	Britton Weissnat	britton.weissnat@woohoo.com	San Francisco	California	3158818211581058406	fbe88dc882dd1f14cdb7b2c1ed80b62a	Mastercard	37.7988423799663451	-122.469368739545729
9442	2020-01-15 11:53:53	2020-01-15	Samuel Johns	samuel.johns@woohoo.com	San Francisco	California	869988135896145975	6e2810993df8d7ad461a9da9596d1eda	American Express	37.7506167177111394	-122.410995800386871
9443	2020-01-15 11:57:22	2020-01-15	Ashby Morar	ashby.morar@geemail.com	Santa Rosa	California	3088158773306651474	b815d22d11a435ffc4fba9a5b37b836a	Mastercard	38.5008443901903945	-122.707468235843265
9444	2020-01-15 12:18:56	2020-01-15	Jarrett Wyman	jarrett.wyman@geemail.com	Evansville	Indiana	060449718775908	d14928b89306bff3d2e88b09f5e65f40	JCB 16 digit	38.0203734582893489	-87.5819291741054542
9445	2020-01-15 12:39:01	2020-01-15	Elva Harvey	elva.harvey@woohoo.com	Philadelphia	Pennsylvania	54589731245524409	ca236965331beb9bf9c71e749cc494ee	Discover	39.9621986674569527	-75.2305301442176102
9446	2020-01-15 12:54:08	2020-01-15	Dr. Catalina Schroeder PhD	dr.catalina.schroeder.phd@geemail.com	Oklahoma City	Oklahoma	4870286226715755	6517fbfc3909a63c48272a45c5a6844b	VISA 13 digit	35.4271743213668486	-97.5019068951148569
9447	2020-01-15 13:02:15	2020-01-15	Mariana Rutherford	mariana.rutherford@geemail.com	Austin	Texas	210069206419011391	36c7a69d3bd14cbdf3a95362858da339	VISA 13 digit	30.245633854915944	-97.6859124948043416
9448	2020-01-15 13:35:53	2020-01-15	Ms. Alessandra Emmerich	ms.alessandra.emmerich@warmmail.com	Augusta	Georgia	630436842695649	29990cb89141f777c6511a983183669e	JCB 16 digit	33.3318974770344738	-81.9900039431933436
9449	2020-01-15 13:44:27	2020-01-15	Miss Gladyce Rogahn	miss.gladyce.rogahn@geemail.com	Kansas City	Missouri	180060400052923553	17c5fa5ba148526139962ae1e60bd57e	VISA 16 digit	39.1253882739994694	-94.5225432587545384
9450	2020-01-15 13:51:50	2020-01-15	Suzy Doyle	suzy.doyle@geemail.com	Hillsboro	Oregon	4385386972405	bb73272528ab44cb567bce3dd5f21751	VISA 16 digit	45.50268593958765	-123.026686085403711
9451	2020-01-15 13:56:57	2020-01-15	Signa Krajcik	signa.krajcik@geemail.com	San Jose	California	55064297165564951	b7c4681d2c2e7dea1eab8024d6a10db4	Maestro	37.3930141908403471	-121.75890455704517
9452	2020-01-15 13:58:15	2020-01-15	Miss Nikia Roob	miss.nikia.roob@woohoo.com	Hartford	Connecticut	3528033959094013669	294d62a56b2eca91bbd3f879168ad061	Voyager	41.8594332922264982	-72.6410314334448515
9453	2020-01-15 14:11:20	2020-01-15	Kavon Labadie	kavon.labadie@geemail.com	Indianapolis	Indiana	6011624124580362220	5b8ec7e7f669ac4397f49b15840ac00d	Mastercard	39.7932176787413638	-86.1585210941467352
9454	2020-01-15 14:26:53	2020-01-15	Ashely Rath	ashely.rath@warmmail.com	Louisville	Kentucky	53808100982176317	b57513696ba4444c4f302f8b04f9bdb4	Discover	38.105695437630267	-85.7306696291618096
9455	2020-01-15 14:59:12	2020-01-15	Mr. Berkley Mertz IV	mr.berkley.mertz.iv@geemail.com	Manchester	New Hampshire	6011906502779370642	fb021ff4d57dfdacb6dcc6e5d5fbd5e8	JCB 16 digit	43.0172894283734308	-71.3921427103582857
9456	2020-01-15 15:12:25	2020-01-15	Mrs. Isobel Schroeder DVM	mrs.isobel.schroeder.dvm@geemail.com	Philadelphia	Pennsylvania	3528611497595306878	018c9abe5adbcbf5d3e1263b661ccf10	Mastercard	40.071157353600114	-75.2006584215342997
9457	2020-01-15 15:26:30	2020-01-15	Javion Feeney	javion.feeney@geemail.com	New York	New York	3446270142908891	2a242c2408ead851a2849b5629306258	Voyager	40.6947616975046671	-73.8650339415192576
9458	2020-01-15 15:26:43	2020-01-15	Dr. Sonny Harber	dr.sonny.harber@woohoo.com	San Francisco	California	55715231057490630	8c409736db10aad1a42f74798bbbbbd8	VISA 16 digit	37.8057463285407422	-122.466980768796461
9459	2020-01-15 15:35:03	2020-01-15	Thresa Hilpert	thresa.hilpert@geemail.com	Denver	Colorado	869939510938216168	558ba438e3ead8c6a246af2317b0c7ea	Voyager	39.6840586254425318	-104.954131439539054
9460	2020-01-15 16:40:05	2020-01-15	Tyson Fay-Schaefer	tyson.fay.schaefer@woohoo.com	Kansas City	Missouri	3158629399452419424	91d5e55a0d6de5c494b2eef41b9b24fb	JCB 16 digit	39.0816924245864215	-94.5179182649347922
9461	2020-01-15 16:41:52	2020-01-15	Nathaniel Hoppe	nathaniel.hoppe@geemail.com	New York	New York	4691885611071216	a0a27409f675736371b91ede05df4270	Voyager	40.5709960822705185	-73.9720914918359398
9462	2020-01-15 16:42:29	2020-01-15	Lenord Jacobs	lenord.jacobs@geemail.com	Rancho Cucamonga	California	3096125496328440839	bffb64a991bf096df3951d40e58806e9	JCB 15 digit	34.074382659699026	-117.62246747785322
9463	2020-01-15 17:30:08	2020-01-15	Gustie Bogisich	gustie.bogisich@geemail.com	Tacoma	Washington	4792642183841825	692f8f584d1b7f70c4bed5388ce432a2	American Express	47.3012096286404926	-122.468814355204998
9464	2020-01-15 17:40:13	2020-01-15	Carmen Rath	carmen.rath@geemail.com	Irvine	California	3158399737761933536	5a9e345883809159ddebc0e0c3c9ed59	JCB 15 digit	33.6766894393615459	-117.846461721464237
9465	2020-01-15 18:00:33	2020-01-15	Kristy O'Kon DDS	kristy.o'kon.dds@woohoo.com	Kent	Washington	6011973679037407131	03d1d4445a07db2d4a17d9720602bf5a	JCB 16 digit	47.4876389554813514	-122.307842661361022
9466	2020-01-15 18:00:42	2020-01-15	Shirleyann Predovic	shirleyann.predovic@geemail.com	Oakland	California	3528165756528548710	653b6d377384256b005c0418eda37a69	JCB 16 digit	37.8388594804826965	-122.271934139071661
9467	2020-01-15 19:17:53	2020-01-15	Mrs. Zelma Russel	mrs.zelma.russel@geemail.com	Oakland	California	4965851267530037	adc3988324593ae03cbd58b4d157bd7d	JCB 16 digit	37.8421049895118742	-122.292524930427675
9468	2020-01-15 19:33:16	2020-01-15	Mr. Mitch Jenkins	mr.mitch.jenkins@geemail.com	Downey	California	180096177284876977	1f35536b6fe7f3ccbdd1934e821104aa	JCB 15 digit	33.9039745833508661	-118.059520323212809
9469	2020-01-15 19:47:33	2020-01-15	Jarrod Lindgren	jarrod.lindgren@geemail.com	San Francisco	California	676357315141028	c9d924b59fc53a7f61a608613c18de58	JCB 15 digit	37.7647628751140161	-122.4222017836059
9470	2020-01-15 20:00:32	2020-01-15	Cassondra Bins PhD	cassondra.bins.phd@geemail.com	Palmdale	California	3528462592034754751	bc7167ec1e0f68432fe76ff226fd0fad	VISA 16 digit	34.5622912590242919	-118.128639003214985
9471	2020-01-15 20:12:08	2020-01-15	Diane Leannon	diane.leannon@geemail.com	Oceanside	California	503835774350280	0443f379e1a9b12908f5dfc3ee7f7cf7	VISA 16 digit	33.3001588073447365	-117.261710016530756
9472	2020-01-15 20:12:13	2020-01-15	Moshe Howe MD	moshe.howe.md@woohoo.com	Phoenix	Arizona	3770505254254405	4ae2ba430c6afae96ed3031d558e7735	VISA 16 digit	33.5823595182437487	-112.125920321924994
9473	2020-01-15 20:19:43	2020-01-15	Edris Gleichner	edris.gleichner@geemail.com	San Jose	California	3528326716902940095	f886bcdb6c3829607597102dcbea14e2	Diners Club / Carte Blanche	37.3881764159359022	-121.726377779733014
9474	2020-01-15 20:29:25	2020-01-15	Arkie Fritsch	arkie.fritsch@warmmail.com	Chicago	Illinois	4942038014760	2ebd852971f031177409e8fb2f22e525	JCB 15 digit	41.8724203123547127	-87.7311103194516164
9475	2020-01-15 20:47:18	2020-01-15	Cass Walker-Beatty	cass.walker.beatty@woohoo.com	Oakland	California	53153057313852654	6b7ccae1f772bdd6765fa94eb9185f83	JCB 15 digit	37.7644550835777295	-122.28604058998306
9476	2020-01-15 21:00:38	2020-01-15	Cappie Klocko-Yundt	cappie.klocko.yundt@geemail.com	San Francisco	California	4163273514881	cabe3c6dfdd822ffa4181a51055ce48c	VISA 16 digit	37.798119226108625	-122.441463853991095
9477	2020-01-15 21:27:17	2020-01-15	Dr. Vernie Weissnat	dr.vernie.weissnat@geemail.com	Phoenix	Arizona	4477057740216597	2c0426581f541a48f6dd483f51aa2c9b	American Express	33.6468022918261624	-112.166162468858445
9478	2020-01-15 21:29:28	2020-01-15	Miss Janae Daniel DVM	miss.janae.daniel.dvm@geemail.com	Savannah	Georgia	180076409792471072	36f9544537ea19d4f4079e48606d7e70	Voyager	32.0694839928857931	-81.2134871618974898
9479	2020-01-15 21:30:58	2020-01-15	Mrs. Ouida Windler MD	mrs.ouida.windler.md@geemail.com	North Charleston	South Carolina	4386636972692938	42ef1ffc8167ee99bee6c209f3f1155b	VISA 16 digit	32.9492060333650585	-80.1432209873665045
9480	2020-01-15 22:15:48	2020-01-15	Mellie Abernathy	mellie.abernathy@geemail.com	Nashville	Tennessee	4146446086640356	d275336a42fb77ab00e3452c7cb8e364	Diners Club / Carte Blanche	36.1815836683038583	-86.7717120280861849
9481	2020-01-15 22:31:46	2020-01-15	Letta Gislason-White	letta.gislason.white@warmmail.com	Hillsboro	Oregon	4176600168635	6232843864eabfdb213653aca1d856eb	JCB 15 digit	45.472640066381544	-122.997013154082737
9482	2020-01-15 22:35:32	2020-01-15	Nylah Roob	nylah.roob@warmmail.com	San Francisco	California	54028292717175393	eb4d90b9413dd3cc0cb471a0553374ff	Voyager	37.7996977919027444	-122.450211700427644
9483	2020-01-15 22:53:58	2020-01-15	Miss Vallie Connelly	miss.vallie.connelly@geemail.com	Oakland	California	869927330344010897	4bb8dd3cc5222b4b3de70ce22499b531	VISA 16 digit	37.8202062187696271	-122.25160385892103
9484	2020-01-15 23:18:58	2020-01-15	Diane Bergstrom III	diane.bergstrom.iii@geemail.com	West Covina	California	3431104793036156	a17d499b4075fe4e3703d572ae519e71	Diners Club / Carte Blanche	34.1019679301060776	-117.814362122917174
9485	2020-01-15 23:24:51	2020-01-15	Heriberto Kohler	heriberto.kohler@warmmail.com	El Paso	Texas	060401094276381	de8ed16e02c9f688d407d2b1ed6411a7	American Express	31.9358391858466	-106.43100935602375
9486	2020-01-15 23:28:33	2020-01-15	Piper Klocko	piper.klocko@warmmail.com	El Paso	Texas	869952384477179225	aec7266050df5de16a2fd58bb1591fd9	JCB 16 digit	31.914169166639077	-106.353873058266942
9487	2020-01-16 00:20:43	2020-01-16	King Simonis	king.simonis@warmmail.com	Jacksonville	Florida	6011213482853595240	20a57a8b8ad202ff7f252f50e92c423a	JCB 15 digit	30.2871005877438932	-81.6909362819589688
9488	2020-01-16 01:00:28	2020-01-16	Misael Howell DDS	misael.howell.dds@geemail.com	Sioux Falls	South Dakota	501840859272672	c85ed70d2eeb1dadbde0505751afe898	VISA 16 digit	43.487641780459505	-96.7591194620523538
9489	2020-01-16 01:29:02	2020-01-16	Dollie Durgan	dollie.durgan@woohoo.com	Cedar Rapids	Iowa	4954893137099	6de62e14f47d2e8a8f1d7387cae6314b	Discover	41.9167857489623117	-91.6321860874138849
9490	2020-01-16 01:30:11	2020-01-16	Burney Kerluke	burney.kerluke@geemail.com	Austin	Texas	3406429237739615	e5ebaa8f288dbf3f41b611b81c49d325	JCB 16 digit	30.3849450642369661	-97.6791052131220709
9491	2020-01-16 01:45:45	2020-01-16	Tarik Kuphal PhD	tarik.kuphal.phd@warmmail.com	Oakland	California	3010376981349933	1bdb533b037e53cade00ba099b79b314	VISA 16 digit	37.7765040569112287	-122.294079982773866
9492	2020-01-16 01:47:14	2020-01-16	Norberto Schaden II	norberto.schaden.ii@geemail.com	Centennial	Colorado	3158183206803898172	0276497f806038a8467704531f3fdfe1	American Express	39.5337190145202015	-104.840205709951377
9493	2020-01-16 02:03:17	2020-01-16	Lela Considine	lela.considine@geemail.com	Knoxville	Tennessee	869937974062297257	732e04a7ea890513e9fda123303b23ec	VISA 13 digit	36.0541740094374887	-83.9044253015641033
9494	2020-01-16 02:10:22	2020-01-16	Keith Beatty	keith.beatty@geemail.com	New York	New York	3112340014889548244	5ed00c59cb48f6df1b422a607c108e94	Discover	40.7550790825150884	-74.0031031256902878
9495	2020-01-16 02:12:53	2020-01-16	Byrd Yundt	byrd.yundt@geemail.com	Cleveland	Ohio	3015038359543035	c6d8a2d2153b2094acee18e16222026f	VISA 13 digit	41.4831664881054252	-81.7160236339323234
9496	2020-01-16 02:25:31	2020-01-16	Lone Jakubowski III	lone.jakubowski.iii@geemail.com	Albuquerque	New Mexico	6011590800389504043	15b936f875f4cd5522573f2954610551	JCB 16 digit	35.0986602214299168	-106.622163080663981
9497	2020-01-16 02:34:44	2020-01-16	Adlai Rodriguez II	adlai.rodriguez.ii@woohoo.com	New York	New York	869974445790214421	a913cb31bdbab123cfea76c0795afd37	Mastercard	40.7556268958132719	-73.8755286083452347
9498	2020-01-16 02:53:15	2020-01-16	Gaylon Boyer	gaylon.boyer@geemail.com	Los Angeles	California	869906992623171479	617fac06aa605cc9e9ec4503cc7a1baf	JCB 16 digit	34.0481792425602663	-118.436020979005093
9499	2020-01-16 03:13:50	2020-01-16	Rosalia Weissnat-Lueilwitz	rosalia.weissnat.lueilwitz@woohoo.com	San Francisco	California	675997521948535	d42a08790d1de451acf20cf742e2fab0	VISA 13 digit	37.7423281878903225	-122.430783149225334
9500	2020-01-16 03:14:01	2020-01-16	Mellisa Corkery	mellisa.corkery@geemail.com	Meridian	Idaho	3158618461530736956	2a93e1512e22ad0dabe5d48a9d90bca3	JCB 16 digit	43.6518863470766689	-116.483287728990987
9501	2020-01-16 03:16:15	2020-01-16	Contina Mraz DDS	contina.mraz.dds@warmmail.com	Renton	Washington	4438405220505864	ae3db219c256f70e35f4ab8822d0be12	JCB 16 digit	47.4197670298688152	-122.148948680803173
9502	2020-01-16 03:34:41	2020-01-16	Lucile Grimes	lucile.grimes@geemail.com	Milwaukee	Wisconsin	6011046390116754376	abe122681b4a25217691ac4c75773238	VISA 16 digit	43.1196027597032483	-87.951850228952992
9503	2020-01-16 03:39:13	2020-01-16	Ms. Simone Ullrich PhD	ms.simone.ullrich.phd@geemail.com	Eugene	Oregon	3710905183114352	933ad5de118925adaf8abea009ed06a1	American Express	44.1032476178098491	-123.090872499578452
9504	2020-01-16 03:44:00	2020-01-16	Tarik Funk	tarik.funk@geemail.com	New York	New York	3788854125347802	a8632af3cca9d7b6d517517c0ef3a21a	Voyager	40.5967619047723716	-73.8708863782592147
9505	2020-01-16 04:15:52	2020-01-16	Kim Nolan	kim.nolan@geemail.com	San Francisco	California	6011843689656965770	3f1c21732d223672287b7a21909946a1	VISA 13 digit	37.7822697745780971	-122.447887786863348
9506	2020-01-16 04:16:21	2020-01-16	Erline Streich	erline.streich@woohoo.com	Tempe	Arizona	869902303980563148	b0a07c287a6adeacaf98ba3b87b7c71d	JCB 16 digit	33.4323743997994782	-111.993149911103018
9507	2020-01-16 04:22:20	2020-01-16	Dr. Philomena Skiles	dr.philomena.skiles@geemail.com	Jacksonville	Florida	3158339395756421448	aa64f3a91dd8b7bf3c199e4a6ed149d8	VISA 13 digit	30.3678170478489236	-81.5633194490879845
9508	2020-01-16 04:32:03	2020-01-16	Darold Mills-McGlynn	darold.mills.mcglynn@geemail.com	San Francisco	California	210058083583287062	c0ac6af78f508f4f75111d81007d43b9	Mastercard	37.8033133022373704	-122.471966470240929
9509	2020-01-16 04:55:24	2020-01-16	Mr. Beckham Pollich	mr.beckham.pollich@geemail.com	San Francisco	California	3480600842020166	90754e0d8cf792d2f6c80860235e7b27	VISA 16 digit	37.7725824315716849	-122.4284425836195
9510	2020-01-16 05:14:45	2020-01-16	Ms. Iesha Spinka PhD	ms.iesha.spinka.phd@geemail.com	Norman	Oklahoma	4588304908083740	0f234ecdd4c3f12740d0eb0d4fd1c0e8	American Express	35.2734094129916258	-97.3271374740891133
9511	2020-01-16 05:17:37	2020-01-16	Crawford Kiehn	crawford.kiehn@woohoo.com	Pueblo	Colorado	3756706585904761	d0d61feb62010d558e38667ca585d92f	Discover	38.1962176108710452	-104.518829830163355
9512	2020-01-16 05:48:08	2020-01-16	Tyreke Christiansen II	tyreke.christiansen.ii@geemail.com	Charlotte	North Carolina	3013092918195854	9ecb5d49fca152a130cbe94f1c028748	Mastercard	35.2910089246250678	-80.8199782717917117
9513	2020-01-16 06:10:44	2020-01-16	Trilby Rau	trilby.rau@warmmail.com	Milwaukee	Wisconsin	4468193820136578	f4666adb64926640df910d0ea2cdde14	Voyager	43.0190759599294523	-87.9989035272140114
9514	2020-01-16 06:26:06	2020-01-16	Shyanne Osinski DVM	shyanne.osinski.dvm@geemail.com	San Angelo	Texas	502005316044964	3d3ad510f0cd95dabd454fb4d9253e32	JCB 16 digit	31.4454565107509474	-100.364402336033066
9515	2020-01-16 06:31:30	2020-01-16	Hillary Gutmann	hillary.gutmann@geemail.com	Dallas	Texas	3112355402047751432	ab97236bb2c9bffce8d40976ef2a1fc3	American Express	32.8223504490025348	-96.6817207920327775
9516	2020-01-16 06:41:06	2020-01-16	Dalvin Hudson	dalvin.hudson@woohoo.com	Mobile	Alabama	180018443478852892	e62fea020aeb8dd794c39618c1d0cc5b	VISA 16 digit	30.6952964134156687	-88.0705702690545422
9517	2020-01-16 06:48:23	2020-01-16	Shane Greenholt	shane.greenholt@geemail.com	New York	New York	4537041048797563	796a34f233c916d52d6ed75604205f7e	Maestro	40.7605652453601337	-73.9917180903617293
9518	2020-01-16 07:10:50	2020-01-16	Trinidad Mertz	trinidad.mertz@warmmail.com	Cleveland	Ohio	630490658914362	da9b7fdfbd10346102427c51daa208b9	Voyager	41.4653069112766488	-81.75525650198162
9519	2020-01-16 07:13:58	2020-01-16	Kizzie Shanahan	kizzie.shanahan@warmmail.com	Memphis	Tennessee	4320207382731077	040d1bff9a4063b8104c6c5b30d0aa11	American Express	35.0984067397724857	-90.0258830309171287
9520	2020-01-16 07:58:13	2020-01-16	Gunnar Brakus-Green	gunnar.brakus.green@geemail.com	Hillsboro	Oregon	3112397709613365938	998cf49f380f99a0ac2e4fcfd2ee6155	American Express	45.4478694254737334	-122.926184650945288
9521	2020-01-16 08:03:54	2020-01-16	Velda Mraz	velda.mraz@geemail.com	Charlotte	North Carolina	210027355850124105	85de722adf48eb5ace5046b168c966a5	Discover	35.1974850514225679	-80.8612379820030185
9522	2020-01-16 08:52:49	2020-01-16	Dr. Kaye Koepp	dr.kaye.koepp@geemail.com	San Francisco	California	869907616803086822	0993d4db39beb32cd317f1cf38924550	Discover	37.7756273815491923	-122.427643357341253
9523	2020-01-16 09:02:31	2020-01-16	Mr. Shaquan Kohler V	mr.shaquan.kohler.v@geemail.com	San Francisco	California	3022977262849281	25f56f7d3dd1726308fdd95022e9055e	Diners Club / Carte Blanche	37.7899645447503332	-122.423155467384532
9524	2020-01-16 09:36:17	2020-01-16	Dr. Marianna Cole	dr.marianna.cole@woohoo.com	Berkeley	California	54439847190510623	e34a9a20849168a92bfa4831ef91807d	VISA 16 digit	37.850813593378021	-122.25082081946195
9525	2020-01-16 10:36:03	2020-01-16	Sammie D'Amore	sammie.d'amore@geemail.com	Ventura	California	4668378653806573	b43f25b883427554580a7106b11b7055	JCB 16 digit	34.1861504184242335	-119.3082420578327
9526	2020-01-16 10:37:17	2020-01-16	Brigette Weimann DVM	brigette.weimann.dvm@warmmail.com	Oakland	California	869982354132294663	cfe15c9450054d672b83d94a30cbaec1	Voyager	37.7709920111194535	-122.275016011924137
9527	2020-01-16 10:43:28	2020-01-16	Admiral Kirlin	admiral.kirlin@geemail.com	Austin	Texas	4810810343671758	e3052fe5f82d1097ce67f9da230e8fb7	Mastercard	30.282556776202842	-97.8138747850205732
9528	2020-01-16 10:58:59	2020-01-16	Harmon Koepp	harmon.koepp@geemail.com	San Francisco	California	869995025102940924	c37ba4b6a9f70d711dd1cbb86ed97a00	Mastercard	37.7634901354602519	-122.445498699067969
9529	2020-01-16 10:59:15	2020-01-16	Bryn Schulist	bryn.schulist@geemail.com	Hampton	Virginia	3021014704984020	97ee64a08b0ebce987025921ce8e356f	Voyager	37.1352786981984977	-76.385974587276948
9530	2020-01-16 11:21:07	2020-01-16	Ms. Siena Koss MD	ms.siena.koss.md@geemail.com	Springfield	Illinois	6011828789107826909	3073eaf03a3364f8ec6569032e0c5490	Mastercard	39.7029778395000861	-89.7353576894387572
9531	2020-01-16 11:21:43	2020-01-16	Ayla Dickens-Ondricka	ayla.dickens.ondricka@geemail.com	San Francisco	California	869958838334509506	0f70cec1c87e360c6f3e940d6ef00748	Discover	37.7752717241361111	-122.457483184064984
9532	2020-01-16 11:33:02	2020-01-16	Aleck Bailey	aleck.bailey@geemail.com	Omaha	Nebraska	51412518410004587	b09c6c4d206a5f90b714fcace5c717b5	Diners Club / Carte Blanche	41.2307617360405629	-96.0005321324918413
9533	2020-01-16 11:53:45	2020-01-16	Tatyana Torp	tatyana.torp@geemail.com	San Francisco	California	3443418468603645	8d51ed03ec130f305b9b1d76a3295be4	VISA 16 digit	37.8124527543532949	-122.420363556820732
9534	2020-01-16 12:10:27	2020-01-16	Janiah Frami	janiah.frami@woohoo.com	Los Angeles	California	4193638654807555	c14ccfad13ca19450f9e097ea43149a0	JCB 16 digit	33.9642637059889694	-118.351631558126954
9535	2020-01-16 12:13:57	2020-01-16	Treyvon Fahey-Herzog	treyvon.fahey.herzog@geemail.com	Newark	New Jersey	869975027972313533	87d4922681360383ca2cafe4532102c4	VISA 16 digit	40.6681466825220781	-74.1551470491312443
9536	2020-01-16 12:14:43	2020-01-16	Aaliyah Murray-Hagenes	aaliyah.murray.hagenes@geemail.com	Salt Lake City	Utah	210061125078855708	0c90abfc9d5b7c4d642babea77215f47	VISA 16 digit	40.7333062614925154	-111.84427649937011
9537	2020-01-16 12:49:47	2020-01-16	Bev Thompson	bev.thompson@geemail.com	Thornton	Colorado	869958729031038867	b1982d325436aaf170a63416611b57db	American Express	39.8875372713763312	-105.01273326554076
9538	2020-01-16 12:56:00	2020-01-16	Anitra Kuphal-Kshlerin	anitra.kuphal.kshlerin@geemail.com	San Francisco	California	180041726298008849	0fdacb9e735f7d5b8811f25f5a2d724a	VISA 16 digit	37.7645428122906708	-122.43392702882916
9539	2020-01-16 12:58:39	2020-01-16	Todd Hammes	todd.hammes@geemail.com	Cape Coral	Florida	6011073666713554095	69ba577016263fcb0022eb1ee036c9b4	VISA 13 digit	26.6523462473385031	-82.0841151217069438
9540	2020-01-16 13:13:01	2020-01-16	Victoriano Hilpert	victoriano.hilpert@geemail.com	Tampa	Florida	4670515944576459	908979fb39573f5b13884eb72c7efc0e	JCB 16 digit	27.8916393775142701	-82.5796282794073164
9541	2020-01-16 13:19:05	2020-01-16	Carroll Kiehn-Balistreri	carroll.kiehn.balistreri@woohoo.com	San Francisco	California	3158122850473915057	c16268e99a5f5903a5f00997bc994bca	Voyager	37.7607208237174774	-122.413545497091263
9542	2020-01-16 13:26:12	2020-01-16	Nicolle Terry PhD	nicolle.terry.phd@warmmail.com	San Francisco	California	869968265880443617	ec18a58486514ef08931b843dc749ddd	Maestro	37.7492175984463643	-122.403356895880464
9543	2020-01-16 14:04:00	2020-01-16	Darwyn Casper	darwyn.casper@geemail.com	Houston	Texas	3762152315198667	f67d0d5456779d5acf0a03b2e3923ead	VISA 16 digit	29.6979968287128955	-95.3997423144538033
9544	2020-01-16 14:32:11	2020-01-16	Eligah Douglas	eligah.douglas@woohoo.com	Broken Arrow	Oklahoma	869956218406944463	29332ddd1256dc5962224d78a36076f1	Maestro	36.0543992333821919	-95.7814745918326196
9545	2020-01-16 14:58:47	2020-01-16	Ms. Rosalie Durgan PhD	ms.rosalie.durgan.phd@geemail.com	Ontario	California	6011102390484744976	22f818724b6f854b894cf176ae69523e	VISA 13 digit	34.0161848112154743	-117.561519399807608
9546	2020-01-16 15:03:04	2020-01-16	Deric Larson	deric.larson@geemail.com	New York	New York	180065137712214966	509a24dfe766f584785254afe8b6ded5	Voyager	40.7471575308814664	-73.8438884112413945
9547	2020-01-16 15:12:34	2020-01-16	Mr. Frances Kling	mr.frances.kling@geemail.com	San Jose	California	3056068954511375	a26128bf48b914a3e603f484bdca3a74	VISA 16 digit	37.3864145290859042	-121.834075857022398
9548	2020-01-16 15:15:44	2020-01-16	Maverick Brekke	maverick.brekke@geemail.com	Atlanta	Georgia	3054400326386958	bdde975112ebf3413821cc5010c85566	Discover	33.7340751158814882	-84.3515348684553175
9549	2020-01-16 15:15:44	2020-01-16	Lu Wisoky	lu.wisoky@woohoo.com	Los Angeles	California	54900774776834336	0d31b467049614e9f65db7e9530df411	JCB 16 digit	34.0960065874136973	-118.423204069770122
9550	2020-01-16 15:56:19	2020-01-16	Cyrus Schiller-Beahan	cyrus.schiller.beahan@geemail.com	Pasadena	Texas	55600748379309725	e4223617f3208763e88cfa90b59020f5	VISA 16 digit	29.6366077967792734	-95.1050160726945819
9551	2020-01-16 16:14:45	2020-01-16	Minervia Lakin DVM	minervia.lakin.dvm@warmmail.com	San Jose	California	54761387537683666	44f2441a817180e5eaac2c6c741d8835	Maestro	37.3079950726877883	-121.899817619448157
9552	2020-01-16 17:02:02	2020-01-16	Brigitte Wisozk	brigitte.wisozk@warmmail.com	Eugene	Oregon	4410322928681	0dc897f65f026a1264d0391416e7e3db	Maestro	44.1285825342599267	-123.106471416166798
9553	2020-01-16 17:12:56	2020-01-16	Dr. Cletus Kuphal V	dr.cletus.kuphal.v@geemail.com	Jackson	Mississippi	6011442490987113320	01e078447017a3499c54fe6710b2548d	Diners Club / Carte Blanche	32.3711093618247716	-90.1608777219403521
9554	2020-01-16 17:32:22	2020-01-16	Alby Beatty	alby.beatty@geemail.com	Columbia	Missouri	502065532610212	2a8d01b8acaeaf9899983d3541c37378	American Express	38.9181835336957676	-92.2308952045214454
9555	2020-01-16 18:04:48	2020-01-16	Syed Batz	syed.batz@warmmail.com	San Francisco	California	4552885965135060	58ee3013283811745439ca23271c6d47	JCB 15 digit	37.8061035805710759	-122.426087264842465
9556	2020-01-16 18:31:13	2020-01-16	Mrs. Tiarra Fay MD	mrs.tiarra.fay.md@geemail.com	West Palm Beach	Florida	4439235021236842	60be94bcaca71641bd6966c5685df6bd	JCB 15 digit	26.7868528719838714	-80.189915444592387
9557	2020-01-16 18:48:42	2020-01-16	Mr. Dewitt Price	mr.dewitt.price@woohoo.com	New York	New York	210004137431310610	75e3809b2a1ddc62e81a59fcab58e16b	JCB 16 digit	40.6048314155302918	-73.9065747888654414
9558	2020-01-16 19:05:12	2020-01-16	Keri Kiehn	keri.kiehn@geemail.com	Anaheim	California	3000700777233623	40277ee511757e2aae8637e0ce04f81b	JCB 16 digit	33.866250953480602	-117.695846616497633
9559	2020-01-16 19:13:15	2020-01-16	Arlie Davis	arlie.davis@geemail.com	Knoxville	Tennessee	3112751568799193823	a112ebd63cf86cf0c3970490b8892a6a	VISA 13 digit	36.0673437096241898	-83.9817901043437303
9560	2020-01-16 19:23:06	2020-01-16	Chelsi Koepp	chelsi.koepp@warmmail.com	Gainesville	Florida	3466978091889624	f1fafcefc84b438b385467e5cebcc692	VISA 13 digit	29.7341065075073381	-82.3227430851537747
9561	2020-01-16 19:23:17	2020-01-16	Isidore Ankunding-Casper	isidore.ankunding.casper@geemail.com	Laredo	Texas	3337972156791586054	62a441b8122483bd0a963e4ac1d15ed6	Mastercard	27.5043660669304444	-99.4010888294789936
9562	2020-01-16 19:28:42	2020-01-16	Dr. Baylee Baumbach MD	dr.baylee.baumbach.md@geemail.com	San Francisco	California	3096775620644008136	3913d5a330179d39b3a86478ce5de24e	American Express	37.7507174832270636	-122.411362434706533
9563	2020-01-16 19:38:08	2020-01-16	Roland Mraz	roland.mraz@warmmail.com	Nashville	Tennessee	630477181094101	b1c4873f011c133786d549c7096b0d4a	Maestro	36.1759281636338628	-86.7780644409265278
9564	2020-01-16 20:07:44	2020-01-16	Dr. Cullen Torp	dr.cullen.torp@geemail.com	Austin	Texas	55715336990132718	88a4910ef93b88aa1975b8574284799f	American Express	30.2139309963803733	-97.7128642380010319
9565	2020-01-16 20:36:25	2020-01-16	Cassidy Schmeler	cassidy.schmeler@woohoo.com	Atlanta	Georgia	4466398431896211	f5b34297ac4e3f0868d100714933e724	VISA 16 digit	33.7847792808707794	-84.3542629810560527
9566	2020-01-16 20:41:41	2020-01-16	Davante Fahey-Hagenes	davante.fahey.hagenes@warmmail.com	San Francisco	California	55442195953096264	59441713b081f38d2e899da22c879e90	Discover	37.8110248432439846	-122.444058092776444
9567	2020-01-16 20:46:00	2020-01-16	Grady Conroy	grady.conroy@geemail.com	Omaha	Nebraska	4537975782997	cff112d15b25e032543d74282d3d5e80	Voyager	41.2603119586274047	-96.1400768657330502
9568	2020-01-16 20:48:16	2020-01-16	Starling Corkery	starling.corkery@warmmail.com	Plano	Texas	6011879541680309466	1086d47001115dacb152e066d72a11a7	VISA 16 digit	33.1492963464085051	-96.8432603324014707
9569	2020-01-16 20:54:21	2020-01-16	Seldon West PhD	seldon.west.phd@geemail.com	New York	New York	6011755325714278270	29fd92ff0a7a0be5fc7eef0c9ab2609f	Diners Club / Carte Blanche	40.7538453162405645	-73.9554071984615149
9570	2020-01-16 20:55:08	2020-01-16	Malcolm Kuphal-Schumm	malcolm.kuphal.schumm@geemail.com	Durham	North Carolina	869971732537457147	391d96719d7057393fae6ab2c0794d49	VISA 16 digit	35.9715851445928223	-78.8917307265471663
9571	2020-01-16 21:53:33	2020-01-16	Denita Schaefer	denita.schaefer@geemail.com	Norfolk	Virginia	6011841670348876007	e8d977836e9218f45ad6ca0352ca18d5	American Express	36.9434927797429253	-76.2215210577476796
9572	2020-01-16 22:38:57	2020-01-16	Mr. Edwardo Hayes	mr.edwardo.hayes@warmmail.com	San Francisco	California	180028508504159864	6d6d8b4db4c8daba1c55ca3fbe660e74	JCB 16 digit	37.7261453541273895	-122.445875784583905
9573	2020-01-16 22:44:29	2020-01-16	Rahsaan Nolan-Jaskolski	rahsaan.nolan.jaskolski@geemail.com	Berkeley	California	6011233934068918928	94346fe6f9ec9b14456a2a5268a2001f	JCB 15 digit	37.872230008157679	-122.287103438435921
9574	2020-01-16 22:49:42	2020-01-16	Meagan Stehr-Gerhold	meagan.stehr.gerhold@warmmail.com	Moreno Valley	California	4565650764522131	0e4b9000fba02442b75a47585d3895ed	JCB 16 digit	33.9247029569458221	-117.260319964212172
9575	2020-01-16 22:57:59	2020-01-16	Osa Harris MD	osa.harris.md@warmmail.com	Berkeley	California	675984712602766	f7fa5aed95225446f2adc97d16664e30	Maestro	37.8525840193593197	-122.325457664085221
9576	2020-01-16 23:10:49	2020-01-16	Acy McDermott	acy.mcdermott@geemail.com	Boise	Idaho	180063306191473714	2d8c261741c6abdc960be325a05f3caa	Voyager	43.5067601323731239	-116.200830977336324
9577	2020-01-17 00:29:12	2020-01-17	Sylvester Boyle	sylvester.boyle@woohoo.com	Knoxville	Tennessee	55831819417594999	076977a5338bcbc6d7932bd27f1877e2	JCB 15 digit	36.0468887768283466	-84.0122714618902648
9578	2020-01-17 00:36:21	2020-01-17	Rogelio McCullough	rogelio.mccullough@geemail.com	Hollywood	Florida	3041930947569320	3e0134e240c057ca1f0f711cf81b54b4	VISA 16 digit	25.9665721222236741	-80.2224105119522619
9579	2020-01-17 00:44:06	2020-01-17	Denice Kovacek	denice.kovacek@warmmail.com	Grand Prairie	Texas	6011274045355924618	0567abbe8ad9f1dbaab6bf800e57fc9d	Voyager	32.6457338084053248	-96.9857393436938509
9580	2020-01-17 01:07:29	2020-01-17	Dr. Maureen Block MD	dr.maureen.block.md@geemail.com	Los Angeles	California	3088597993121874734	b7ebd0485862a56127371013470a884a	VISA 16 digit	33.9756958834227163	-118.483038047700376
9581	2020-01-17 01:14:40	2020-01-17	Dr. Boston Lowe	dr.boston.lowe@geemail.com	Long Beach	California	3422350397907737	b4df39236d8e7d5ad962e06ff385330b	JCB 16 digit	33.8931050449430913	-118.153172081026426
9582	2020-01-17 01:25:15	2020-01-17	Tella Pagac	tella.pagac@geemail.com	Chicago	Illinois	869954311401491705	9e3c320d8d0a0b1de2a0934626170ce6	Voyager	41.7613765879835981	-87.7701202350232705
9583	2020-01-17 01:26:48	2020-01-17	Mr. Rand Yundt	mr.rand.yundt@geemail.com	Denton	Texas	3337494487238619581	e3b2aa44dca7013739c0acb85903f73d	Maestro	33.25680565156825	-97.0900722507514047
9584	2020-01-17 01:31:22	2020-01-17	Leighton Abbott	leighton.abbott@geemail.com	New York	New York	3046962356123187	f749c6160918003701dae997567a0d00	Mastercard	40.7579331739097839	-73.9344422423642129
9585	2020-01-17 01:31:38	2020-01-17	Eloy Medhurst	eloy.medhurst@geemail.com	Overland Park	Kansas	869924128041514051	e767f9ca6322ffc8359b0a20cfe6bb10	VISA 13 digit	38.8406764156986029	-94.7329503465950467
9586	2020-01-17 01:37:14	2020-01-17	Brittnay Osinski	brittnay.osinski@geemail.com	Chicago	Illinois	4756997792102108	8082c9e38716fab3a4105be31da73db7	VISA 13 digit	41.7457108837388446	-87.6023530663486554
9587	2020-01-17 01:38:58	2020-01-17	Juli Casper	juli.casper@geemail.com	Jacksonville	Florida	3088733707406458046	2a222ae4b49c8aefa07781582e268527	VISA 13 digit	30.2465393948886536	-81.7186985259488239
9588	2020-01-17 01:43:47	2020-01-17	Leda Feeney	leda.feeney@geemail.com	San Francisco	California	4980825513253629	b1e29252a05043c6a271f0b47f05ce59	Maestro	37.7740832953747656	-122.45535139925957
9589	2020-01-17 02:06:07	2020-01-17	Dillie Emmerich	dillie.emmerich@geemail.com	Philadelphia	Pennsylvania	4548797682927959	c3c2dc8c168f1a755295d4447958ad8c	VISA 16 digit	39.9652952676132287	-75.0333602310523418
9590	2020-01-17 02:13:06	2020-01-17	Clarissa Kovacek MD	clarissa.kovacek.md@geemail.com	Chicago	Illinois	51577319841835793	8c6f03204be4e24e2688febfbcae390e	Mastercard	41.8269870742060235	-87.5823916535388634
9591	2020-01-17 02:26:31	2020-01-17	Isidore Treutel	isidore.treutel@woohoo.com	Washington	District of Columbia	3762626929968763	3829d92a1fbb653158d1dcc81221a470	JCB 16 digit	38.8235712940137816	-77.0329574283424847
9592	2020-01-17 02:30:05	2020-01-17	Leamon Lemke	leamon.lemke@woohoo.com	Sacramento	California	4712847469619707	c779596124de0776b1eb6272851b3376	Discover	38.5584249771930274	-121.451593231061835
9593	2020-01-17 02:33:02	2020-01-17	Manilla Becker	manilla.becker@geemail.com	Berkeley	California	3096200120208808612	1678def642d24c04d00f4ed02d98dbb4	American Express	37.8863369569184059	-122.29464382290189
9594	2020-01-17 03:01:03	2020-01-17	Mr. Mauro Okuneva II	mr.mauro.okuneva.ii@geemail.com	Cedar Rapids	Iowa	4718753444226606	ee8d9f66b874c102768f0c071f6699b2	JCB 16 digit	42.0197262339834126	-91.7603695219449804
9595	2020-01-17 03:12:42	2020-01-17	Friend Stoltenberg	friend.stoltenberg@warmmail.com	Anchorage	Alaska	210057780391889507	43add295f7af15b9bca459e1058f6eb5	JCB 16 digit	61.2422913950152719	-149.342632107774904
9596	2020-01-17 03:16:13	2020-01-17	Ulises Tromp MD	ulises.tromp.md@geemail.com	San Francisco	California	6011876857753406648	bafe60ce59b85e212a236e454abace18	Discover	37.7784205179692236	-122.457566566337647
9597	2020-01-17 03:26:39	2020-01-17	Hershel Wisoky	hershel.wisoky@geemail.com	Buffalo	New York	180013761452304993	ea65eba9934e7354e347fcea32359264	Voyager	42.9622739501018032	-78.8559606419809143
9598	2020-01-17 03:40:42	2020-01-17	Miss Zelia Will DDS	miss.zelia.will.dds@woohoo.com	New York	New York	4431069231170	c68838771952ba15c533dbc055fe7c8b	Diners Club / Carte Blanche	40.6235746605545245	-73.9740312631603274
9599	2020-01-17 03:55:43	2020-01-17	Lakesha Langosh	lakesha.langosh@geemail.com	North Las Vegas	Nevada	3088203931421209108	f7f72415f0e893b4419f9b7753bbcca2	American Express	36.3202857976004481	-115.144373383348437
9600	2020-01-17 04:09:08	2020-01-17	Clifford Koss	clifford.koss@geemail.com	San Antonio	Texas	3027898320288525	25dc7fe8b018f91f2fa15dfaf803fd8f	Discover	29.4282200291357938	-98.5194262358196085
9601	2020-01-17 04:25:53	2020-01-17	Tamya O'Conner	tamya.o'conner@geemail.com	San Francisco	California	55222207817990883	b2a736ca773496390675700bf8645b82	Maestro	37.7815615062132721	-122.408502807154989
9602	2020-01-17 04:40:55	2020-01-17	Conard Streich Sr.	conard.streich.sr.@geemail.com	San Francisco	California	3337297327620839091	837dc30a523e5adedffdf2a4dbcc993a	Diners Club / Carte Blanche	37.7582601131602047	-122.436216485183436
9603	2020-01-17 04:50:07	2020-01-17	Miss Adelynn Kreiger	miss.adelynn.kreiger@geemail.com	San Francisco	California	4791889396523	a1e64ab897e14deb56eac2a07ad98277	American Express	37.791417022117173	-122.432698305320883
9604	2020-01-17 04:55:12	2020-01-17	Mossie Predovic	mossie.predovic@woohoo.com	Aurora	Colorado	6011459708473828287	e876d897d5e9db9e43e775248c6723a7	JCB 16 digit	39.6193154511153693	-104.613927798823269
9605	2020-01-17 05:04:27	2020-01-17	Pierre Carter	pierre.carter@geemail.com	Jacksonville	Florida	4159780867994	f00b1180dfe64afa98d14eb54520104b	JCB 16 digit	30.4073735612496741	-81.7314957830201934
9606	2020-01-17 05:38:08	2020-01-17	Theta Gutkowski	theta.gutkowski@woohoo.com	Cary	North Carolina	51715718358544016	986f49d857d1369f4bdad09c9f3cade6	JCB 15 digit	35.6980215482056167	-78.828087256810818
9607	2020-01-17 05:54:08	2020-01-17	Byron Turcotte-Koepp	byron.turcotte.koepp@geemail.com	Tulsa	Oklahoma	4982186912784351	f56af7faf17d2ac8724d7f887bfc9487	JCB 16 digit	36.2090982930637892	-95.8206061531744808
9608	2020-01-17 05:58:18	2020-01-17	Mr. Ewart Kiehn IV	mr.ewart.kiehn.iv@geemail.com	Los Angeles	California	060496724440076	858028baee9807cf3c180c07c021e05a	Discover	34.0705513282079195	-118.472683261194447
9609	2020-01-17 05:59:39	2020-01-17	Giana Kerluke	giana.kerluke@geemail.com	College Station	Texas	3096162219163428253	27368c4a96859f175e77e06195d5c0ef	JCB 15 digit	30.530195608646423	-96.362680413977813
9610	2020-01-17 06:38:13	2020-01-17	Gonzalo Williamson-Effertz	gonzalo.williamson.effertz@warmmail.com	San Francisco	California	4549764720294	8cc271956c2ae868ab0a575b02f6e7d3	American Express	37.8100326556206099	-122.415313606015232
9611	2020-01-17 06:41:43	2020-01-17	Lailah Haley	lailah.haley@geemail.com	Palmdale	California	3789207133647995	86ecaff8c073b9d994ff26beec361c9f	Diners Club / Carte Blanche	34.5045361230466554	-118.182070344779277
9612	2020-01-17 07:34:27	2020-01-17	Mr. Donal Kutch	mr.donal.kutch@geemail.com	Saint Paul	Minnesota	869953749585668229	579969a3009f1df0fb867327110f7429	Voyager	45.0448374478552509	-93.1416579363666557
9613	2020-01-17 07:35:14	2020-01-17	Dr. Shane Franecki Sr.	dr.shane.franecki.sr.@geemail.com	Yonkers	New York	210067902815220683	490091db4fcafd00fad7aacf98c1f00d	Mastercard	41.037016789588705	-73.8669599371846743
9614	2020-01-17 07:50:31	2020-01-17	Miss Vada Keeling	miss.vada.keeling@geemail.com	Springfield	Missouri	4579585718280614	63dd370328a29aaea5c76e5c7b5c21be	JCB 16 digit	37.2154833121418989	-93.2633780580770235
9615	2020-01-17 08:14:06	2020-01-17	Daja Terry PhD	daja.terry.phd@geemail.com	San Francisco	California	6011450514202633637	d2506903dda52ba3e680eaaffdf99923	Mastercard	37.7821165678678099	-122.468786304291513
9616	2020-01-17 08:25:26	2020-01-17	Estell Moen DDS	estell.moen.dds@woohoo.com	Gilbert	Arizona	4093469821669	680bbd604923aed2683b1db92bc68f1d	Voyager	33.3129394906453768	-111.771242009768628
9617	2020-01-17 08:53:49	2020-01-17	Delpha Bailey	delpha.bailey@geemail.com	Allentown	Pennsylvania	3528360999925938968	fe27d0aea3a26de91434863c4916a51a	Discover	40.597824375961352	-75.4685411513332269
9618	2020-01-17 09:01:05	2020-01-17	Miss Candace Terry DDS	miss.candace.terry.dds@woohoo.com	Oakland	California	3002632990909390	96201ed29b46655abd8309b46333ad68	Voyager	37.8123566396334354	-122.268267243949467
9619	2020-01-17 09:12:29	2020-01-17	Ken O'Conner	ken.o'conner@geemail.com	Garland	Texas	676146568134889	667a091540c1572a43beef01e273facb	VISA 16 digit	32.8341269160389899	-96.5874871613152379
9620	2020-01-17 09:18:03	2020-01-17	Rianna Wunsch-McCullough	rianna.wunsch.mccullough@geemail.com	Chicago	Illinois	3028593884875176	ba00d2120a2de83eb03090fa0a91d3e1	VISA 16 digit	41.8392622123308513	-87.5994788295153484
9621	2020-01-17 09:36:34	2020-01-17	Solomon Stokes	solomon.stokes@woohoo.com	New York	New York	53740384005382000	f0350a2606fa72266b9311d51cc5633a	Diners Club / Carte Blanche	40.6946957383528343	-73.9689208835724656
9622	2020-01-17 09:56:15	2020-01-17	Wenzel Brakus-Hettinger	wenzel.brakus.hettinger@geemail.com	Miami	Florida	3337618548025586514	36d250dca61cff534414b59124bb94c8	JCB 16 digit	25.8500592404183003	-80.1308405605949474
9623	2020-01-17 09:57:25	2020-01-17	Cristofer Wintheiser-Towne	cristofer.wintheiser.towne@geemail.com	New York	New York	589376687553008	6693afa0de786420c9380677934ad2bb	VISA 16 digit	40.6462205115929223	-74.0334911133523974
9624	2020-01-17 10:57:26	2020-01-17	Dr. Markel Mayer	dr.markel.mayer@geemail.com	Round Rock	Texas	4620555434582543	c345fa3a748b67747376da4625a463fc	Maestro	30.5822250423159474	-97.7645258037690041
9625	2020-01-17 11:28:21	2020-01-17	Carly Considine	carly.considine@geemail.com	San Francisco	California	3766577165848555	11d7071e3b2ac5015dfcb4f744b46db6	Voyager	37.7649467900950029	-122.393716081463594
9626	2020-01-17 11:49:12	2020-01-17	Casimiro Skiles Sr.	casimiro.skiles.sr.@woohoo.com	Fort Worth	Texas	3528603043165660623	4dd9d01e16754e679cda809a28db40f9	Maestro	32.7645096613150102	-97.3926765764884692
9627	2020-01-17 12:09:28	2020-01-17	Mr. Emmet Legros	mr.emmet.legros@geemail.com	San Francisco	California	4165768173221279	78d090a976511d984258ba8959149cda	Voyager	37.7699579923606947	-122.407223533376538
9628	2020-01-17 12:12:47	2020-01-17	Cherise Halvorson	cherise.halvorson@geemail.com	San Francisco	California	6011776152385148151	4780f0a82533038d556280fba71aea35	JCB 16 digit	37.8171831396081402	-122.420290022024332
9629	2020-01-17 12:17:41	2020-01-17	Metta Donnelly	metta.donnelly@geemail.com	San Francisco	California	180038809494100456	f50913edf192a7556214dd02ed93ccb6	Diners Club / Carte Blanche	37.7703294049790017	-122.437572605162487
9630	2020-01-17 12:25:31	2020-01-17	Edwardo Harber PhD	edwardo.harber.phd@geemail.com	San Diego	California	3528135934826093575	6e95a6eb8ca1e5be000f5bfcc2de2c6e	Discover	32.866371161124853	-117.19956042407081
9631	2020-01-17 12:32:55	2020-01-17	Velvet Luettgen-Watsica	velvet.luettgen.watsica@geemail.com	Berkeley	California	4125891387892211	c8dfa349d4b6de8df42cba82fd716d5a	Discover	37.8542532714213991	-122.285474108937336
9632	2020-01-17 12:37:49	2020-01-17	Abbott Schmidt-Buckridge	abbott.schmidt.buckridge@woohoo.com	Seattle	Washington	503811140510402	92dcffd2e5a7f72c7f04e456c175aef2	VISA 16 digit	47.6842037708889706	-122.445665891693523
9633	2020-01-17 12:43:34	2020-01-17	Beryl Wolf	beryl.wolf@warmmail.com	Honolulu	Hawaii	869987019715772410	d1df0b314c0103c21ee6763372c11f19	VISA 13 digit	21.3944715251430893	-157.85783871977813
9634	2020-01-17 12:44:09	2020-01-17	Aedan Kling	aedan.kling@woohoo.com	San Francisco	California	53442399550466603	b1ce05e449eb9edc080f4f37fb116d6d	VISA 13 digit	37.7813623143966879	-122.418736852477323
9635	2020-01-17 12:54:01	2020-01-17	Redmond O'Hara	redmond.o'hara@geemail.com	San Francisco	California	54647960835279385	85872623f485a7c6493e98e051a0ca52	Discover	37.7777055012660128	-122.444388409313717
9636	2020-01-17 13:12:43	2020-01-17	Dr. Perri Kub DVM	dr.perri.kub.dvm@geemail.com	San Francisco	California	4089037998364836	a8aee26793ceaf2141c24bf35728f4b3	VISA 13 digit	37.7395846082545177	-122.467469847821832
9637	2020-01-17 13:24:00	2020-01-17	Mrs. Janel Rutherford	mrs.janel.rutherford@geemail.com	Midland	Texas	3337930612729405438	45109c0ed9db7021c7f81bfcbe459a7e	VISA 16 digit	32.0179002094272533	-102.029277817694478
9638	2020-01-17 13:24:16	2020-01-17	Kaelynn Stiedemann	kaelynn.stiedemann@geemail.com	Pittsburgh	Pennsylvania	3030604022868847	bc74aa3e34f969210f5c5c6fe0a2bdf0	JCB 15 digit	40.5302722955543544	-79.9599467423915939
9639	2020-01-17 13:42:26	2020-01-17	Lasonya Beahan	lasonya.beahan@geemail.com	San Francisco	California	6011434583638692286	065a4a90f13f81e622c851431d7a802d	JCB 15 digit	37.8034775053172112	-122.442823730436885
9640	2020-01-17 13:55:06	2020-01-17	Shelby Fritsch-Adams	shelby.fritsch.adams@geemail.com	Berkeley	California	6011887161385162548	1e2da948469b22e3e699085abc6438ce	American Express	37.9132048893719258	-122.296599565347435
9641	2020-01-17 14:09:51	2020-01-17	Miss Beth Ritchie DVM	miss.beth.ritchie.dvm@warmmail.com	San Francisco	California	3158880322497108715	7309a4a80fb4538fd856f16b151b5857	VISA 16 digit	37.7859131806842186	-122.461720241234573
9642	2020-01-17 14:55:52	2020-01-17	Delora Koelpin	delora.koelpin@geemail.com	Lincoln	Nebraska	4107274525660125	e3e99d3622c71ed38598cceb11e16c8c	Diners Club / Carte Blanche	40.7942629179470231	-96.7611285663370069
9643	2020-01-17 15:56:12	2020-01-17	Dr. Zollie Doyle	dr.zollie.doyle@geemail.com	Houston	Texas	4031941659054892	fa51eb0613d1173db1e6d27ec2216a5c	Maestro	29.8373257230114177	-95.4763166522622129
9644	2020-01-17 16:07:11	2020-01-17	Elvia Roberts	elvia.roberts@warmmail.com	San Francisco	California	676379429822830	f3a65b88e04de09ad2c5e8d55cb39afb	JCB 16 digit	37.7760421857979622	-122.419179822595808
9645	2020-01-17 16:13:23	2020-01-17	Roselyn O'Keefe	roselyn.o'keefe@warmmail.com	New Haven	Connecticut	4511471001673	7b9fb6248ade8ea960fe67a7244c1ac7	VISA 16 digit	41.2587721394833196	-72.94320913529954
9646	2020-01-17 16:49:39	2020-01-17	Karlee Barton	karlee.barton@woohoo.com	New York	New York	4489417654824	9da4e86cadf0af63b1dc73ab9e2447fe	JCB 16 digit	40.7391543422583453	-73.8819215863838821
9647	2020-01-17 16:50:31	2020-01-17	Cherrelle Schuppe-Homenick	cherrelle.schuppe.homenick@woohoo.com	Scottsdale	Arizona	3046095564289746	03f96345f9b87fb623c290a8544019d8	VISA 16 digit	33.6307351217262465	-111.800921105496954
9648	2020-01-17 17:04:24	2020-01-17	Jaheem Kuhlman	jaheem.kuhlman@geemail.com	Albuquerque	New Mexico	4853062569622325	d2cc8d4b7dc2edc40760897b81e00a97	Diners Club / Carte Blanche	35.0799186937645118	-106.723321784387906
9649	2020-01-17 17:13:15	2020-01-17	Monroe Murphy PhD	monroe.murphy.phd@warmmail.com	Garden Grove	California	210083752160784548	ea410afed2e47f399ed9e11f88727fe7	VISA 16 digit	33.851292454107849	-117.960301082722836
9650	2020-01-17 17:15:05	2020-01-17	Joan Brakus	joan.brakus@geemail.com	Thousand Oaks	California	869904490477459670	eba169fa848c2ba8aee23934823fb230	JCB 16 digit	34.2638718955025112	-118.895886140634119
9651	2020-01-17 17:15:49	2020-01-17	Ms. Rae Kassulke	ms.rae.kassulke@geemail.com	Stamford	Connecticut	4139098487504571	d2d18f1673a5ea42b92484b5aa8fbd95	JCB 16 digit	41.1167221820332145	-73.5153944806233142
9652	2020-01-17 17:17:55	2020-01-17	Tilman Considine	tilman.considine@woohoo.com	Boston	Massachusetts	561291835117598	a35b9246b78cbde7ba99d03c1c4b9a5d	Discover	42.2614043366797247	-70.9484705563120599
9653	2020-01-17 17:34:50	2020-01-17	Mr. Kenyon Pacocha	mr.kenyon.pacocha@geemail.com	Riverside	California	869965960306576270	ca45913e93289d9fc0ff606e4154e50e	JCB 16 digit	33.9251001111179562	-117.302554020049783
9654	2020-01-17 17:35:56	2020-01-17	Teddie Feeney III	teddie.feeney.iii@woohoo.com	San Francisco	California	869936408820637398	c8e4db7379ad80d1517769999e86a3bf	VISA 13 digit	37.7784804841361108	-122.433721416172503
9655	2020-01-17 18:06:15	2020-01-17	Darren Ruecker	darren.ruecker@geemail.com	San Francisco	California	3158008567358189579	8081589968c5b0d88cfdd28fdaab63c1	Discover	37.7814096395688992	-122.420907685166128
9656	2020-01-17 18:06:17	2020-01-17	Dr. Dangelo Beer PhD	dr.dangelo.beer.phd@geemail.com	St. Louis	Missouri	675940469844522	cabcd94ebc2d9cf946aaddfbfed43a0e	Discover	38.6639442572526661	-90.2189156045675276
9657	2020-01-17 19:40:33	2020-01-17	Dr. Matie Hessel	dr.matie.hessel@geemail.com	Clarksville	Tennessee	3023811747142898	8ba96c8dd4ce4774ff8ef6c2f7fcfe83	American Express	36.6569698835384088	-87.4141525090158069
9658	2020-01-17 19:48:23	2020-01-17	Ms. Milan Gottlieb MD	ms.milan.gottlieb.md@geemail.com	Seattle	Washington	060412756359050	c45418aef2ff4c033b1d0d4181ef6b32	JCB 16 digit	47.557985473183912	-122.398812867087869
9659	2020-01-17 20:08:16	2020-01-17	Ms. Susie Barrows DDS	ms.susie.barrows.dds@geemail.com	Washington	District of Columbia	53455893773638265	d0e6fcb33c34127721cc37f2cbe60344	Mastercard	38.8730992031548155	-76.9724285037003426
9660	2020-01-17 20:46:07	2020-01-17	Dr. Sherrill Satterfield	dr.sherrill.satterfield@geemail.com	San Antonio	Texas	4458532886181	d81a76ef7097b3575f75ce1bf0b620e4	Maestro	29.4704436074081819	-98.4807960128247686
9661	2020-01-17 21:10:31	2020-01-17	Dr. Devontae Runte	dr.devontae.runte@geemail.com	Jacksonville	Florida	3482931431748943	80726a39bdf24e61865e3523306558f8	Mastercard	30.3823483397305019	-81.6135869135227097
9662	2020-01-17 21:19:19	2020-01-17	Janyce Lehner	janyce.lehner@warmmail.com	Allentown	Pennsylvania	52963245865650234	d28527380f863179545c505823bbdfef	VISA 13 digit	40.6215072620440267	-75.5443540346357878
9663	2020-01-17 21:30:54	2020-01-17	Kristal Lowe	kristal.lowe@geemail.com	Pittsburgh	Pennsylvania	3096499182042460513	af24f6a7e305ef973971d89e15f392dd	JCB 16 digit	40.353838912951943	-79.8926370868630755
9664	2020-01-17 21:53:39	2020-01-17	Cris Hoppe	cris.hoppe@warmmail.com	Indianapolis	Indiana	3337454021684002949	84edc63c0858c7470b7029fad12177d6	Discover	39.7784652433365551	-86.2203778641033836
9665	2020-01-17 22:31:28	2020-01-17	Ms. Tennille Bashirian MD	ms.tennille.bashirian.md@woohoo.com	Salinas	California	869972916767939747	73b7d1ec2b3c2570841e4ebed26f0896	American Express	36.667589195468274	-121.641056304209684
9666	2020-01-17 23:24:09	2020-01-17	Kason Hackett-Watsica	kason.hackett.watsica@geemail.com	San Francisco	California	3088297638576914252	4c126c816de8fc472c821b9d980d82ee	JCB 15 digit	37.810135454811352	-122.454358755606862
9667	2020-01-18 00:00:54	2020-01-18	Abby Grady	abby.grady@geemail.com	San Francisco	California	6011241981189361223	d2d5f419d42299dc90f7ac5615949bb3	Maestro	37.7432222139563933	-122.453840501817325
9668	2020-01-18 00:03:43	2020-01-18	Baker Collier	baker.collier@geemail.com	New York	New York	4533969129926509	03a7b4abc38e4ba9400921bddc30018f	JCB 16 digit	40.5817719707954652	-73.9819740863878224
9669	2020-01-18 00:18:45	2020-01-18	Carnell Hickle	carnell.hickle@warmmail.com	Philadelphia	Pennsylvania	3088810677538008025	6c9416b97ea1e5c972c235a2e885f853	Diners Club / Carte Blanche	40.0000270460225664	-75.2177677228946351
9670	2020-01-18 01:08:55	2020-01-18	Alberto Ebert	alberto.ebert@geemail.com	Houston	Texas	210068098692554309	7b6e2deb452faa2696882a9c9dc298ed	JCB 15 digit	29.7337083932556219	-95.3924363177284675
9671	2020-01-18 01:38:47	2020-01-18	Michale Parisian	michale.parisian@geemail.com	Los Angeles	California	869954044241390031	6a7912775de37581bc34a79ff592bf0f	Discover	34.0451997756823843	-118.492295876470578
9672	2020-01-18 01:57:39	2020-01-18	Easter Lynch	easter.lynch@warmmail.com	Chicago	Illinois	4249042541417666	094beb5213f679af1082b3eada2f7872	VISA 16 digit	41.7709153330720966	-87.7808886077750401
9673	2020-01-18 02:18:15	2020-01-18	Jammie Turcotte	jammie.turcotte@geemail.com	Ontario	California	4424961603620	16bdd30fe6d94c774e015265e1ee47f3	VISA 16 digit	34.0847442930709548	-117.655411783243352
9674	2020-01-18 02:19:06	2020-01-18	Mr. Wirt Tremblay	mr.wirt.tremblay@geemail.com	Newark	New Jersey	630450823956623	02f6e596556a6a898bc23e0a3345cab4	VISA 13 digit	40.7262372078754069	-74.2340449489861811
9675	2020-01-18 02:23:40	2020-01-18	Dr. Niles Dibbert Sr.	dr.niles.dibbert.sr.@warmmail.com	Modesto	California	3158699320499206918	334676db303e2370996bdfb71f561c62	JCB 16 digit	37.6899012281559465	-121.016421188015485
9676	2020-01-18 02:29:42	2020-01-18	Joshuah Gottlieb V	joshuah.gottlieb.v@geemail.com	Portland	Oregon	630491572460607	08b527388140166a86614eea6ab8904e	VISA 13 digit	45.5234134924486256	-122.739559503924113
9677	2020-01-18 02:34:12	2020-01-18	Irena Blick	irena.blick@geemail.com	Chicago	Illinois	4109071173346868	94cafab28b9b494836ee988209ed8af1	Diners Club / Carte Blanche	41.8495139313697848	-87.7107604871999484
9678	2020-01-18 02:35:45	2020-01-18	Burns Collier	burns.collier@geemail.com	Wichita	Kansas	3734470510961043	6391ca72ef7edf8cb5c031fe124ba5d5	VISA 13 digit	37.7378776163671148	-97.2465279978435433
9679	2020-01-18 02:37:59	2020-01-18	Nathaly McClure	nathaly.mcclure@geemail.com	San Francisco	California	869956730350982265	0f3e1d99fd2129e9e598cf1bffb3459d	Voyager	37.756675757344297	-122.415446475199872
9680	2020-01-18 03:00:45	2020-01-18	Mr. Gregg Lakin	mr.gregg.lakin@woohoo.com	Houston	Texas	3732967600250494	188084b3915c276815666e1de7194d3e	VISA 16 digit	29.7838045110538587	-95.3633072011653411
9681	2020-01-18 03:28:38	2020-01-18	Mr. Santiago DuBuque II	mr.santiago.dubuque.ii@woohoo.com	Spokane	Washington	869996028893139564	42cb2bf7ee9176f6b11484456e3c7a55	Discover	47.7623562902450516	-117.505339992827928
9682	2020-01-18 04:06:10	2020-01-18	Keegan Beier	keegan.beier@geemail.com	San Francisco	California	3422329038868193	86dccb447b8a77f92c822faf3a205eb8	VISA 13 digit	37.7296350291300442	-122.468532302098552
9683	2020-01-18 04:07:13	2020-01-18	Tasia Mann-Haag	tasia.mann.haag@geemail.com	Concord	California	210012454030832005	65af35622167f81afa6f5bfacb450414	Discover	38.0038765575204067	-122.091954172233486
9684	2020-01-18 04:21:25	2020-01-18	Areli Mertz	areli.mertz@geemail.com	Mesa	Arizona	4499052756418835	4796e9a87a9f89552733ed4c4dd8fd38	Diners Club / Carte Blanche	33.3761018542252472	-111.641055210994182
9685	2020-01-18 04:31:53	2020-01-18	Claude Gulgowski	claude.gulgowski@warmmail.com	New York	New York	3088166805420067425	65ac1be0f272912828ce37e9eb3422b8	Maestro	40.7212783327549701	-74.0370674760442142
9686	2020-01-18 04:42:40	2020-01-18	Parrish Wiza-Hilpert	parrish.wiza.hilpert@geemail.com	Newport News	Virginia	54606280854626062	4130380effa3dcf618ca653d8b01e355	JCB 15 digit	37.1008782329864815	-76.5683901073671933
9687	2020-01-18 05:03:43	2020-01-18	Mr. Quincy Aufderhar	mr.quincy.aufderhar@geemail.com	San Francisco	California	4633643592576914	ee7b8c80bc33ccabfd6f4f9559ad8e3f	VISA 16 digit	37.800908899897685	-122.389475526572454
9688	2020-01-18 05:12:59	2020-01-18	Jaylynn Smith	jaylynn.smith@geemail.com	San Francisco	California	3088976427290778955	07a235fa4a9eb7606a3404e2c0e75a61	VISA 16 digit	37.7828501830395425	-122.470428629468671
9689	2020-01-18 05:15:56	2020-01-18	Cheryle Wyman	cheryle.wyman@geemail.com	Fort Collins	Colorado	4106708842059462	073cd2baa3c7f5f545e822107447f87d	Mastercard	40.4954230350598721	-105.099368386338654
9690	2020-01-18 05:34:49	2020-01-18	Jamey Price-Rath	jamey.price.rath@woohoo.com	Omaha	Nebraska	3729409601370877	66c77a949f3781259106cca61c7d8d7c	Voyager	41.1676467387616682	-96.1218562343273391
9691	2020-01-18 05:42:28	2020-01-18	Gaylon Beier	gaylon.beier@geemail.com	San Francisco	California	3096473341582516197	2ab92677f1f4ace9d0ca1c0242e8364c	Diners Club / Carte Blanche	37.7601094576790004	-122.440722762071346
9692	2020-01-18 05:43:02	2020-01-18	Miss Jailene Lueilwitz	miss.jailene.lueilwitz@geemail.com	Berkeley	California	502000006230080	0512b4acc5213c17f5e5d47278a1a585	JCB 16 digit	37.8461476157057533	-122.26968353325681
9693	2020-01-18 05:52:36	2020-01-18	Jaycob Green	jaycob.green@warmmail.com	San Francisco	California	3481009745632904	a2d919cbdd3e1bdb6433f7e242826c1e	American Express	37.7684526023353229	-122.452948823692822
9694	2020-01-18 05:53:15	2020-01-18	Derl Spinka	derl.spinka@geemail.com	Chicago	Illinois	6011191957554766881	eddc808d5878a3f9070fae2a73f4abaf	VISA 16 digit	41.7742919315420096	-87.6472434851836368
9695	2020-01-18 06:12:09	2020-01-18	Lurana Upton	lurana.upton@geemail.com	Cleveland	Ohio	4843766551425843	8c2e488390613b932a83b996093b7344	Diners Club / Carte Blanche	41.4709788596574214	-81.7209175395552023
9696	2020-01-18 06:49:32	2020-01-18	Sally O'Kon	sally.o'kon@geemail.com	Sacramento	California	4564596554555	da271265081f530c837e1821c57650ad	VISA 13 digit	38.5978147258780879	-121.394835113013528
9697	2020-01-18 07:09:01	2020-01-18	Loney Boehm-Williamson	loney.boehm.williamson@warmmail.com	Colorado Springs	Colorado	869948090719738606	677a9d48b131a059123afd1c783c15ea	Voyager	38.9665395996581765	-104.670194818001988
9698	2020-01-18 07:24:03	2020-01-18	Eda Lind-Mayer	eda.lind.mayer@warmmail.com	Austin	Texas	4973416290177675	d2e148a2fab85901a8f0bc453440e3e9	VISA 13 digit	30.2751779325433077	-97.6570118306908768
9699	2020-01-18 07:29:09	2020-01-18	Cheryl Rempel	cheryl.rempel@geemail.com	San Francisco	California	869912170939705833	f309ed46907642d481e6a9dced3e2ed3	VISA 16 digit	37.7741434934675198	-122.453812943976772
9700	2020-01-18 07:29:16	2020-01-18	Lyndsay Russel	lyndsay.russel@geemail.com	Olathe	Kansas	210057183030935627	a17f731cb2a411a49fc13fec24be1ae5	American Express	38.8691913960158857	-94.8271815204694946
9701	2020-01-18 07:36:38	2020-01-18	Dr. Nelle Gusikowski	dr.nelle.gusikowski@geemail.com	Knoxville	Tennessee	3783430272687533	2543e295e82cd5110abb559f6640cd99	Maestro	35.9612909639317522	-83.8658450234897401
9702	2020-01-18 07:41:12	2020-01-18	Javen Murray	javen.murray@woohoo.com	Beaumont	Texas	53994560043330191	e3585d8729d4fb7eedf814d822e65961	Maestro	30.0420940265595924	-94.2186594554942189
9703	2020-01-18 08:13:30	2020-01-18	Nana Leffler PhD	nana.leffler.phd@geemail.com	Edison	New Jersey	3096546299636560897	f60d039b3e32d444c562cf74738f1a92	JCB 16 digit	40.5006655368916668	-74.3568283748399494
9704	2020-01-18 08:17:05	2020-01-18	Kaeden Lynch PhD	kaeden.lynch.phd@geemail.com	San Francisco	California	3096121708729089518	a82720279703cf9e9360054baf296f59	VISA 16 digit	37.7983588015698473	-122.436016464956126
9705	2020-01-18 08:30:43	2020-01-18	Paola Kuphal	paola.kuphal@warmmail.com	Charlotte	North Carolina	4138299158128879	b06a552ec874bca87b2ed694f8461463	VISA 16 digit	35.2639151417437944	-80.8077258878797267
9706	2020-01-18 08:43:38	2020-01-18	Gerald Wisozk Jr.	gerald.wisozk.jr.@warmmail.com	San Francisco	California	3158936780780680720	2e4993080ad77204d0b7f5d2fb686695	Diners Club / Carte Blanche	37.7994624120756342	-122.413377539152137
9707	2020-01-18 09:17:02	2020-01-18	Casimiro Bednar	casimiro.bednar@geemail.com	San Francisco	California	52089963388828520	0c32889aee51d1f2eaed47701158b0d5	Mastercard	37.7848390407014989	-122.403250668515469
9708	2020-01-18 09:57:55	2020-01-18	Vollie Hahn	vollie.hahn@warmmail.com	New York	New York	4859557942579	2c47542828d6c04426e8069b87cda422	American Express	40.6488750646580002	-74.0046933796618163
9709	2020-01-18 10:10:14	2020-01-18	Charlee Mraz	charlee.mraz@geemail.com	Chicago	Illinois	4872715041929892	a6f58c53d62011a70a3f85587082d225	JCB 15 digit	41.9032493491027509	-87.636296701667078
9710	2020-01-18 10:18:32	2020-01-18	Anwar Zieme	anwar.zieme@geemail.com	San Jose	California	3435889053778648	94abad8ca7fd8d4f6a82e1614a7936ff	Mastercard	37.2366472654331488	-121.911309789888193
9711	2020-01-18 10:36:41	2020-01-18	Dr. Agustin Hodkiewicz IV	dr.agustin.hodkiewicz.iv@woohoo.com	Arlington	Texas	3463048996247386	0c4092750717f1caf4a1e2ab3d6be3f1	JCB 16 digit	32.7014095237262552	-97.1771082136340425
9712	2020-01-18 10:37:40	2020-01-18	Allen Harris	allen.harris@geemail.com	Columbus	Ohio	3096914553931902434	c7b29a883471ecb9fc72579a6878e08b	VISA 16 digit	39.9771801974203456	-83.0179584102474166
9713	2020-01-18 10:54:39	2020-01-18	Ms. Aleena Wolf DDS	ms.aleena.wolf.dds@woohoo.com	Fresno	California	869948391273600483	e7368af7af4390e3f7279f190d22fffb	VISA 16 digit	36.8665652360174789	-119.832167193444079
9714	2020-01-18 11:12:28	2020-01-18	Darryn Brekke Jr.	darryn.brekke.jr.@geemail.com	San Francisco	California	4712612013707659	edcae983af80d96dc2f75e64496efea9	Voyager	37.7748036193754828	-122.388317902310405
9715	2020-01-18 11:44:11	2020-01-18	Dr. Foster Zemlak	dr.foster.zemlak@geemail.com	San Jose	California	3337888126709083174	22505d7b641d9febf0d24da82fea1ab7	JCB 16 digit	37.3896928248282521	-121.867593675035607
9716	2020-01-18 11:52:17	2020-01-18	Linzy Nicolas	linzy.nicolas@geemail.com	San Francisco	California	869996780380833261	e9dedd9b22fe659e5ac3ed48bab7de38	Mastercard	37.7776178022362146	-122.414342065287812
9717	2020-01-18 12:14:45	2020-01-18	Erik Mayert	erik.mayert@geemail.com	New York	New York	3766396983022313	1e85e62b811f0dda5e3afa89268e1a7a	American Express	40.570671158259735	-73.9610915563896327
9718	2020-01-18 12:17:25	2020-01-18	Dr. Garvin Langosh V	dr.garvin.langosh.v@geemail.com	Jacksonville	Florida	51422838152975366	188f47d0bc788caecef1c20d082ae607	Voyager	30.4286572590988129	-81.570786183568103
9719	2020-01-18 12:21:34	2020-01-18	Mark Trantow	mark.trantow@geemail.com	Santa Ana	California	210087990925712364	9a5eca0d1162af47014405020f335d8f	VISA 16 digit	33.7235123569715753	-117.973270486380898
9720	2020-01-18 12:30:11	2020-01-18	Natasha Dach	natasha.dach@geemail.com	Concord	California	53279850257821027	3ce2c04e8a51c750b39ebb026b14e698	Mastercard	38.0214808493785554	-121.905459558608385
9721	2020-01-18 12:32:40	2020-01-18	Juelz Jenkins-Mills	juelz.jenkins.mills@warmmail.com	Eugene	Oregon	4179537997936	edf5a91a2a34655c455577427dd66a83	VISA 13 digit	44.0790169610835605	-123.040623082405702
9722	2020-01-18 12:45:50	2020-01-18	Chester Daniel	chester.daniel@geemail.com	Salem	Oregon	54050641683353015	4bb3e3f572b5b71d6098610ba0bb35b4	Diners Club / Carte Blanche	45.0018075245235067	-123.084636573555699
9723	2020-01-18 12:52:59	2020-01-18	Starling Oberbrunner	starling.oberbrunner@geemail.com	Cincinnati	Ohio	4165521448335568	c4caf1f083a724eecd3203bd47e6660e	American Express	39.106288828956707	-84.5928115602854547
9724	2020-01-18 14:09:02	2020-01-18	Jolie O'Conner	jolie.o'conner@woohoo.com	Indianapolis	Indiana	3096239935990683492	c1c5f753a2d4747ee559832b10c2811e	JCB 16 digit	39.8157425794292195	-86.1158959994293696
9725	2020-01-18 14:14:00	2020-01-18	Torry Cummings	torry.cummings@geemail.com	Cambridge	Massachusetts	676231798243833	93287e745b2230fa5e954b16e9b49e95	JCB 16 digit	42.4260975215341887	-71.1238808337680979
9726	2020-01-18 14:28:53	2020-01-18	Leatrice Hansen	leatrice.hansen@geemail.com	Tempe	Arizona	4679715462408819	7d84a96a03b38ef5fe2559302c1c6e3f	VISA 16 digit	33.422630290260166	-112.019349187894903
9727	2020-01-18 14:30:18	2020-01-18	Mr. Caswell Deckow	mr.caswell.deckow@geemail.com	Peoria	Illinois	869911072856430661	6b92810363510c872172307986023735	VISA 16 digit	40.8489992195144325	-89.6759351710207824
9728	2020-01-18 14:32:45	2020-01-18	Edwin Casper V	edwin.casper.v@geemail.com	San Francisco	California	3010865962488215	fd8e9c546562d1af066c7f8d9642266f	Diners Club / Carte Blanche	37.7504827060053216	-122.409839542346774
9729	2020-01-18 14:50:51	2020-01-18	Manila Lebsack PhD	manila.lebsack.phd@geemail.com	Los Angeles	California	3039665228366192	3c46b8e36e9933a819a0a41a2eaea9fb	VISA 13 digit	34.0816872105799575	-118.338964113592354
9730	2020-01-18 14:55:24	2020-01-18	Hasan Jerde	hasan.jerde@geemail.com	Baton Rouge	Louisiana	3337715764389283208	d745ae83e24ee41b17edee79d2269162	Mastercard	30.5176332680255165	-91.2305330928523119
9731	2020-01-18 15:01:44	2020-01-18	Mr. Domenic Schneider I	mr.domenic.schneider.i@geemail.com	Raleigh	North Carolina	4215541451992675	2f0cab817512a843169ba016207bcf90	Mastercard	35.7525909332226917	-78.7351064759708947
9732	2020-01-18 15:12:58	2020-01-18	Patience Brown	patience.brown@geemail.com	San Francisco	California	54077822467653866	e87504d93e352a9ef05a763e5f30c2a7	JCB 15 digit	37.7665323578803935	-122.412438810291931
9733	2020-01-18 15:23:22	2020-01-18	Ashli Tremblay	ashli.tremblay@warmmail.com	Houston	Texas	869985408247638995	236a9e18543b4be6f96998638babbf60	Mastercard	29.8158480089236058	-95.4494766804870238
9734	2020-01-18 15:33:29	2020-01-18	Brain Heathcote	brain.heathcote@geemail.com	Oakland	California	6011128826372787783	4d0c0a9c81dca4627690a1f0bc9224bb	JCB 15 digit	37.8318058678078799	-122.260699122756421
9735	2020-01-18 15:36:53	2020-01-18	Sandra West	sandra.west@geemail.com	Gilbert	Arizona	4967944124437	a2d68bb6302384e32460fb9920974fc1	American Express	33.3506257986065009	-111.802095680417864
9736	2020-01-18 15:42:50	2020-01-18	Nayely Lindgren	nayely.lindgren@geemail.com	Columbus	Ohio	6011943716468862777	b65fd0565250654571fb472e3f35e721	Discover	39.9438851493455473	-83.0544796606760514
9737	2020-01-18 15:55:03	2020-01-18	Ms. Josefa Homenick DVM	ms.josefa.homenick.dvm@geemail.com	New York	New York	869941258405431938	766768cbd5163aa20d025654cff13388	JCB 16 digit	40.6860649108178904	-73.9703835532896221
9738	2020-01-18 15:58:18	2020-01-18	Alexina Champlin-Feest	alexina.champlin.feest@geemail.com	San Francisco	California	3112042203636781247	121d11dfe5fefbe2f2afed5013504345	VISA 16 digit	37.7744022393918968	-122.431899527367875
9739	2020-01-18 16:16:02	2020-01-18	Tai Moen-Emmerich	tai.moen.emmerich@geemail.com	San Francisco	California	3337391799228386946	7885ce767ca15beb3f1686306806da66	VISA 16 digit	37.7849791825295469	-122.390394224619243
9740	2020-01-18 16:32:06	2020-01-18	Ashanti Schinner	ashanti.schinner@geemail.com	Fayetteville	North Carolina	3112886157410369612	d68a63789f2c5bcddfa64cc3c12ad9c3	Mastercard	35.0650741782292741	-78.8750663502272289
9741	2020-01-18 16:36:11	2020-01-18	Gustavus Tromp V	gustavus.tromp.v@geemail.com	Buffalo	New York	53973897372943243	c52d7ccbd92071f855a8acb1da537069	American Express	42.8865307009965164	-78.8662930366516122
9742	2020-01-18 16:42:03	2020-01-18	Elvia Kuhlman	elvia.kuhlman@geemail.com	Kansas City	Kansas	060438874360472	dd59b71ed7d50824593b1dd8d931918e	JCB 16 digit	39.0884260998945692	-94.7646856086730907
9743	2020-01-18 17:22:47	2020-01-18	Noreta Haag	noreta.haag@geemail.com	Fontana	California	4208641494154629	ef5a09126d8e517eadf3403eeedbe09b	Diners Club / Carte Blanche	34.0435053472090559	-117.433894368707769
9744	2020-01-18 17:34:37	2020-01-18	Ainsley Grant	ainsley.grant@geemail.com	Dallas	Texas	210072363783578201	3dcca220f9c2c236b987ff35d51602e2	JCB 16 digit	32.8694839704122401	-96.6702292918655957
9745	2020-01-18 17:41:14	2020-01-18	Francisquita Cassin	francisquita.cassin@woohoo.com	Vancouver	Washington	4187265796879595	e6f47824203062434910e81621e44a7f	American Express	45.7155353901512953	-122.553702188382658
9746	2020-01-18 18:42:05	2020-01-18	Dr. Daren Vandervort Sr.	dr.daren.vandervort.sr.@woohoo.com	New York	New York	4909613874587	bf56abc1de42831af517f1bc0938f667	Diners Club / Carte Blanche	40.6362465884294366	-74.0155441652413373
9747	2020-01-18 18:42:23	2020-01-18	Roxanna Olson PhD	roxanna.olson.phd@geemail.com	Boston	Massachusetts	4024609791430887	9c622e91b009fb06de0d3b5f5052f38b	JCB 15 digit	42.2733409402128331	-70.9253825852133417
9748	2020-01-18 18:52:20	2020-01-18	Jovita Bergnaum	jovita.bergnaum@geemail.com	San Francisco	California	3337911458031698291	c2dbab9aac50e287f228b3379018f7cd	American Express	37.7819417605404766	-122.390907459383271
9749	2020-01-18 18:55:46	2020-01-18	Fulton Wilderman	fulton.wilderman@geemail.com	San Francisco	California	6011265870688047402	9346afc4d64310f39ca8694a08cfec41	JCB 16 digit	37.7735122727149175	-122.430119732322694
9750	2020-01-18 18:59:53	2020-01-18	Graham Sporer	graham.sporer@geemail.com	San Francisco	California	4690565416417	5614d8475a09ec1b2ce7957a8bfa1301	JCB 15 digit	37.7774321731699274	-122.410752897746164
9751	2020-01-18 19:23:15	2020-01-18	Jackie Witting	jackie.witting@warmmail.com	San Francisco	California	4128913926647	792dc34e64260c1383c2ab5c353f2847	JCB 15 digit	37.7874256652841254	-122.37439524191295
9752	2020-01-18 19:31:37	2020-01-18	Caitlyn Haag DDS	caitlyn.haag.dds@woohoo.com	Billings	Montana	3000334676221206	7f27ebb1424ce9d27cd1f92a1648f473	VISA 16 digit	45.7061140748430006	-108.559310886745891
9753	2020-01-18 19:47:27	2020-01-18	Wood Hamill	wood.hamill@woohoo.com	Boise	Idaho	502035075784906	b984b2fec87f246182743dfdf27bc142	VISA 16 digit	43.5383666808854812	-116.199398837630454
9754	2020-01-18 20:03:34	2020-01-18	Maceo Mosciski	maceo.mosciski@geemail.com	Los Angeles	California	3528133918322557581	eb3f6022ad2b42d23b25abc76fc0b988	Discover	34.1154311026312413	-118.356900977016608
9755	2020-01-18 20:15:07	2020-01-18	Danny Roberts DVM	danny.roberts.dvm@geemail.com	Fremont	California	869933257396842277	7bd537992f3e2fc86e3a4f1b67965e45	Voyager	37.5925842300690718	-121.908011108821995
9756	2020-01-18 20:29:53	2020-01-18	Loria Huels	loria.huels@woohoo.com	Orlando	Florida	3112003372173391707	ef93c2094a257bb8df5cf85a173008ba	Maestro	28.4989154572863121	-81.2929442623596685
9757	2020-01-18 20:40:28	2020-01-18	Ebony Ratke	ebony.ratke@geemail.com	New York	New York	3088751675688453810	b1495a808a7b259d8e80ed2c62e0dacf	Maestro	40.5980142598729543	-73.9853584636364161
9758	2020-01-18 20:44:16	2020-01-18	Trevion Smitham	trevion.smitham@geemail.com	Fresno	California	3707904223357555	f1c4594401cef32da4cea8987325fd7b	Diners Club / Carte Blanche	36.7692871740426881	-119.707944093050074
9759	2020-01-18 20:55:01	2020-01-18	Shep Morissette	shep.morissette@geemail.com	Syracuse	New York	869987808443740974	eb54892371371a8bb988f7049a69bf07	Maestro	43.0140896099936185	-76.1977514535434608
9760	2020-01-18 21:03:38	2020-01-18	Mr. Wilfrid Leannon DVM	mr.wilfrid.leannon.dvm@geemail.com	Colorado Springs	Colorado	4219108480729019	ae81260f270f3d0e04e18964d9a40e68	JCB 16 digit	38.8000667362522336	-104.856975806939232
9761	2020-01-18 21:14:38	2020-01-18	Dollye Halvorson	dollye.halvorson@geemail.com	New York	New York	3096453081889705846	65e6b934bb5dcd102d16b2d77380ec27	American Express	40.644861164618284	-74.0091870583955114
9762	2020-01-18 21:18:36	2020-01-18	Angeles Sipes	angeles.sipes@geemail.com	Charlotte	North Carolina	3096372412330479038	6bc305b362a7caefca8b1921e1214299	Voyager	35.2195657417897152	-80.8077468547914179
9763	2020-01-18 21:27:53	2020-01-18	Mr. Beckham Renner	mr.beckham.renner@geemail.com	Downey	California	55064227348058126	85b37ba6bad678149fffceb2364cbafc	VISA 16 digit	33.9836721843358163	-118.120755530718341
9764	2020-01-18 22:46:14	2020-01-18	Kody Bartell	kody.bartell@geemail.com	Oxnard	California	4658825609352872	ae3638503d1b467def47089bfac76cd5	VISA 13 digit	34.1971061712086239	-119.295196363181248
9765	2020-01-18 23:10:44	2020-01-18	Farrah Johnson DDS	farrah.johnson.dds@warmmail.com	Washington	District of Columbia	6011744370677575563	1ba6901aa69abcc6df5a9f5e02ba5db8	Maestro	38.9204883341010657	-76.9439974990885673
9766	2020-01-18 23:11:33	2020-01-18	Mammie O'Reilly	mammie.o'reilly@geemail.com	Berkeley	California	51101031676592192	de9ad1cd0780a27529e5c296dd3e8e09	JCB 16 digit	37.882955933456401	-122.261006911398482
9767	2020-01-18 23:12:28	2020-01-18	Lorine Botsford	lorine.botsford@geemail.com	Wichita	Kansas	4667406616137496	840d84d6949b62175c3ae73408744871	VISA 13 digit	37.6569912655621764	-97.305190866227818
9768	2020-01-18 23:22:07	2020-01-18	Corrina Murazik	corrina.murazik@warmmail.com	San Francisco	California	3096993485225706102	32b2420f714ebd8f028316320b1a0f3e	VISA 16 digit	37.7499846813345385	-122.442488076396941
9769	2020-01-18 23:39:53	2020-01-18	Odie Moen	odie.moen@woohoo.com	Hialeah	Florida	4602428176426786	e4781ec53e14458ee5f526d560a2923f	Diners Club / Carte Blanche	25.7745014133840797	-80.3296056372482212
9770	2020-01-18 23:40:56	2020-01-18	Vince Lindgren	vince.lindgren@woohoo.com	Fort Collins	Colorado	4413290349388213	b58519b615790e8619ca0b714eb7a782	Voyager	40.5362401832517278	-105.125809173095234
9771	2020-01-18 23:54:33	2020-01-18	Abdiel Batz	abdiel.batz@geemail.com	Vista	California	675913259696485	3a2db42ffe0e3a71afd0b28dd78fe97c	JCB 15 digit	33.2350527041573116	-117.320087797433516
9772	2020-01-19 01:12:55	2020-01-19	Braxton Dickinson	braxton.dickinson@geemail.com	Berkeley	California	51537590317833962	20a41bfd00207f535df23e022e831657	VISA 16 digit	37.8977510315382773	-122.278433739371778
9773	2020-01-19 01:26:41	2020-01-19	Efrem Beer Sr.	efrem.beer.sr.@geemail.com	Moreno Valley	California	589322031608494	d5204ecde4a30aa4a889368decdf7c71	Voyager	33.9119822739615984	-117.18243398908227
9774	2020-01-19 01:53:08	2020-01-19	Rudy Kiehn	rudy.kiehn@warmmail.com	New York	New York	3528229108182465050	b7226de8ecc1ec65b74fef50e1f135f6	Mastercard	40.7182422553878283	-73.8710273252695799
9775	2020-01-19 01:54:57	2020-01-19	Evalena Schiller	evalena.schiller@geemail.com	Jurupa Valley	California	180015755031771860	92033a88ea95359ec80c40ab3d934282	Discover	33.9055136863537143	-117.527327688878785
9776	2020-01-19 02:02:18	2020-01-19	Chestina Von-Roob	chestina.von.roob@geemail.com	Boise	Idaho	180018500941231382	1586e18df6a39bf777ec95b16f85b888	JCB 16 digit	43.5863942294985094	-116.171843386786804
9777	2020-01-19 02:05:39	2020-01-19	Camisha Wisozk	camisha.wisozk@woohoo.com	San Francisco	California	869986937258275155	92c2e6724e14757117b6b852ab6f6c0f	Voyager	37.7833490183273142	-122.435752187021734
9778	2020-01-19 02:27:13	2020-01-19	Elma Smith	elma.smith@geemail.com	Houston	Texas	630409656242022	6b7dfbc547336386b7b9848980c56f46	Mastercard	29.8613595143970088	-95.3487617553226698
9779	2020-01-19 02:56:31	2020-01-19	Whitley Hermiston-Halvorson	whitley.hermiston.halvorson@woohoo.com	New York	New York	4579423792418407	53d4e57bfe7ae3750ab54705d4c146fe	Mastercard	40.5686127130165701	-73.8433950031537591
9780	2020-01-19 03:39:02	2020-01-19	Sheri Ryan	sheri.ryan@geemail.com	El Paso	Texas	3112240132602211014	5c885453c5d517099e40ed894ea2daac	Mastercard	31.7831175157163308	-106.36543627045863
9781	2020-01-19 03:42:10	2020-01-19	Sherron Senger	sherron.senger@geemail.com	Lubbock	Texas	4470835842954778	ddd72d871360899ad04cc434963319ae	Voyager	33.4670212942216594	-101.850368966572731
9782	2020-01-19 04:31:44	2020-01-19	Ciera Hirthe	ciera.hirthe@geemail.com	Oakland	California	3088196905765180645	2a015f36f3e3ca0289e7ed2b5f255862	JCB 16 digit	37.7657732410549158	-122.27701869245881
9783	2020-01-19 06:07:54	2020-01-19	Miss Marni O'Conner	miss.marni.o'conner@woohoo.com	Lakewood	New Jersey	52492648419478749	7a2eaa8574207505559681c9d777ac57	VISA 16 digit	40.165351650333406	-74.1798655562844118
9784	2020-01-19 06:12:12	2020-01-19	Dr. Leslee Goodwin DVM	dr.leslee.goodwin.dvm@warmmail.com	Woodbridge	New Jersey	180080005112703725	e611fe36b409d0c255d2a6ac6427d6a0	JCB 16 digit	40.4770919811602639	-74.2920828093167387
9785	2020-01-19 06:18:20	2020-01-19	Maranda Kub	maranda.kub@woohoo.com	San Diego	California	869903043311517707	66da3e8c7ead9793f2dae960217314d7	Discover	32.7855141433954245	-117.148039969187238
9786	2020-01-19 06:33:37	2020-01-19	Ms. Dyan Stracke DVM	ms.dyan.stracke.dvm@geemail.com	Long Beach	California	4388619275527397	a8f4aa42396c4c91783d983064312b16	Voyager	33.7868884956751003	-118.087995862743995
9787	2020-01-19 07:05:18	2020-01-19	Ambrose McKenzie	ambrose.mckenzie@warmmail.com	Fairfield	California	4826358271495271	a9372035b023d02dc881b9ab6ba200c3	VISA 16 digit	38.2337980058632851	-121.934988810867438
9788	2020-01-19 07:07:24	2020-01-19	Essie McGlynn	essie.mcglynn@geemail.com	San Francisco	California	53339295939837553	62dab219b9e904fdfd25e05e40915111	JCB 16 digit	37.7642515349833943	-122.425912935959985
9789	2020-01-19 07:16:00	2020-01-19	Mr. Joesph Feest	mr.joesph.feest@warmmail.com	Las Vegas	Nevada	501832206550322	68e5d54adae9c00cf8a2a4d8ccb240b8	JCB 16 digit	36.250163206188752	-115.2188152655702
9790	2020-01-19 08:18:34	2020-01-19	Mr. Reynolds Mills	mr.reynolds.mills@geemail.com	Akron	Ohio	180099117916474541	a1927bad58c9de3f42e269841d746f6c	VISA 13 digit	41.1362072118390358	-81.4520489754002597
9791	2020-01-19 08:35:39	2020-01-19	Corey Osinski DVM	corey.osinski.dvm@geemail.com	Austin	Texas	4516988379871729	931c009f1e29f64a3f161fe9fbee8948	American Express	30.2219299492087217	-97.8429879470966739
9792	2020-01-19 08:48:10	2020-01-19	Camren Botsford II	camren.botsford.ii@geemail.com	San Francisco	California	4929143308740	01a55925d8b8f1041405bb5b9dcbf6dd	Voyager	37.7576134219714987	-122.38867875799653
9793	2020-01-19 08:49:06	2020-01-19	Junior Ratke	junior.ratke@geemail.com	Berkeley	California	210092695237966110	6ec78101a99a55ccd645bac45344083b	VISA 16 digit	37.8853214077650762	-122.272178922904644
9794	2020-01-19 08:52:32	2020-01-19	Abraham Lind	abraham.lind@geemail.com	Fort Lauderdale	Florida	4441099097997521	3e7531c4fd533cfdc85a553c59794ced	VISA 16 digit	26.1712568558741374	-80.1212513037778393
9795	2020-01-19 08:58:02	2020-01-19	Laurene Rohan	laurene.rohan@geemail.com	Chula Vista	California	3033340670602801	564659100edfeda4a8f9494bc7a2b2d9	VISA 16 digit	32.656119589716937	-117.009030083729698
9796	2020-01-19 09:16:26	2020-01-19	Miss Cory Glover	miss.cory.glover@geemail.com	Oakland	California	503818492095486	0ee65bb275c8ef0380fbbd27ac974973	JCB 16 digit	37.791600996774342	-122.283988433307158
9797	2020-01-19 09:34:32	2020-01-19	Mr. Tavaris Lemke	mr.tavaris.lemke@geemail.com	New York	New York	3477746164081552	72cd03bca6b3cd1d8d44102007515f00	VISA 16 digit	40.6330400284603215	-74.0222095662623616
9798	2020-01-19 09:49:12	2020-01-19	Ms. Phoebe Schimmel	ms.phoebe.schimmel@geemail.com	Charlotte	North Carolina	4031033767501202	1fb5803bc9706c0a29ce8bfb70b8926c	VISA 13 digit	35.2458757390987145	-80.9160559124723164
9799	2020-01-19 10:06:20	2020-01-19	Matthias Ullrich DDS	matthias.ullrich.dds@geemail.com	Dallas	Texas	561215947375406	40ae6798e2e4fff7288767aa4b29d0d6	American Express	32.7548049233660095	-96.6929125614892655
9800	2020-01-19 10:24:23	2020-01-19	Mrs. London Morar DDS	mrs.london.morar.dds@woohoo.com	Independence	Missouri	4278949678736	eab18a3bb898703d542164dce481204c	JCB 16 digit	39.0886677250750409	-94.2958224773690006
9801	2020-01-19 10:27:30	2020-01-19	Carin Gislason-Hammes	carin.gislason.hammes@geemail.com	Santa Ana	California	3088679190337243850	c2dd7d8d2d8c4391eb82938b71b9387b	JCB 16 digit	33.7075632528506191	-117.87538086505792
9802	2020-01-19 10:28:11	2020-01-19	Brinda Waters-Hegmann	brinda.waters.hegmann@geemail.com	San Francisco	California	3096339219961342175	898d092f1676fa562b9c79f1370f1679	JCB 16 digit	37.7615278762933428	-122.447726257008568
9803	2020-01-19 10:28:25	2020-01-19	Marchello Keeling-Rutherford	marchello.keeling.rutherford@geemail.com	Oakland	California	4544925427904397	e81364d95f2a39960a789b3028107b9a	VISA 13 digit	37.8101686230329008	-122.226411723335744
9804	2020-01-19 10:32:26	2020-01-19	Miss Ally Bruen	miss.ally.bruen@woohoo.com	San Francisco	California	3012470911059627	237d3b44360dc610ada981b3a4d050e0	American Express	37.7657810385979573	-122.392908037528812
9805	2020-01-19 10:43:39	2020-01-19	Konnor Rice	konnor.rice@geemail.com	Antioch	California	3158469724338343535	0a06e80b353eb05accdae5ad3e1a587f	VISA 13 digit	37.9066805124081725	-121.704540164273979
9806	2020-01-19 11:18:00	2020-01-19	Volney Bechtelar	volney.bechtelar@geemail.com	Nashville	Tennessee	4182036978514085	de0d83cee978f5bd32e85703ee5f5362	JCB 16 digit	36.0855291912920748	-86.8587290889956023
9807	2020-01-19 11:47:40	2020-01-19	Kiarra Beatty-Kautzer	kiarra.beatty.kautzer@geemail.com	Charleston	South Carolina	869976252242493902	3c3896764dcc4fc0df33f873ae806a1a	JCB 15 digit	32.8343852609857905	-79.9467853577956618
9808	2020-01-19 11:58:02	2020-01-19	Savon Lang-Cole	savon.lang.cole@geemail.com	Cincinnati	Ohio	53210830973670694	74c3fd2ab1555c6a0e383f6c03aae120	Discover	39.1108959815695911	-84.5201722029868421
9809	2020-01-19 12:06:57	2020-01-19	Galilea West	galilea.west@geemail.com	San Francisco	California	4689272424618141	d4a2e231fe7f206f383bafe8d5990146	JCB 16 digit	37.7498109200263912	-122.455463730457424
9810	2020-01-19 12:19:26	2020-01-19	Emiliano Bode	emiliano.bode@geemail.com	Lafayette	Louisiana	4177039404288255	936a67272c8970a14f0d2c8ddfe2e01e	VISA 16 digit	30.2093705016631624	-91.9505843801274807
9811	2020-01-19 12:34:22	2020-01-19	Signa Balistreri	signa.balistreri@geemail.com	San Francisco	California	3021751199606325	0989334481a556d537472a23141dfc89	Maestro	37.7897115819193132	-122.439569486888047
9812	2020-01-19 12:45:34	2020-01-19	Portia Streich-Ullrich	portia.streich.ullrich@geemail.com	New York	New York	4634740159752000	cd38692d919875d95be0ad407f32aa98	Mastercard	40.6952944606300449	-73.8593463265232657
9813	2020-01-19 12:46:52	2020-01-19	Mr. Misael Hackett	mr.misael.hackett@geemail.com	Berkeley	California	6011679384504783711	e9460f95253291104154c05ec93fe4c8	Discover	37.8692897714334009	-122.294874481151084
9814	2020-01-19 13:00:58	2020-01-19	Alba Zemlak	alba.zemlak@geemail.com	Baton Rouge	Louisiana	6011353766272748129	8a9105c37a27502cf9e41685363cc1da	VISA 16 digit	30.3820920706007627	-91.0607349664546462
9815	2020-01-19 13:02:08	2020-01-19	Hays Roberts DDS	hays.roberts.dds@geemail.com	Seattle	Washington	4986813583726264	dbe212139581dcd626e09d2137097f4e	Diners Club / Carte Blanche	47.6164788077045245	-122.320684647878252
9816	2020-01-19 13:10:53	2020-01-19	Deidre Dickinson	deidre.dickinson@geemail.com	Oakland	California	3337220881356345238	2f9fb52f369f005f992d21fc0d958703	VISA 16 digit	37.7744163387119301	-122.240615178766305
9817	2020-01-19 13:17:41	2020-01-19	Zavion Simonis	zavion.simonis@geemail.com	San Francisco	California	180096256079974294	a93144edba48c5e315204a4657222904	JCB 16 digit	37.7468456409187709	-122.409954557264911
9818	2020-01-19 13:47:48	2020-01-19	Hailey Wuckert PhD	hailey.wuckert.phd@geemail.com	New Orleans	Louisiana	4400227426700246	05de92c9013074e6fd39eaa3551b2e56	Discover	30.0627542736955	-89.8412958028055755
9819	2020-01-19 13:50:00	2020-01-19	Dr. Tyler Marquardt	dr.tyler.marquardt@geemail.com	Dallas	Texas	4026149487345	252d93fd7644af2fda77945134689185	VISA 16 digit	32.7176049242068103	-96.7366498082838859
9820	2020-01-19 13:54:10	2020-01-19	Karel Maggio DVM	karel.maggio.dvm@geemail.com	Berkeley	California	869948976088282038	b44b65557a9ff90de0808eddb806f2f3	Maestro	37.8454472900889414	-122.262921059975255
9821	2020-01-19 14:24:23	2020-01-19	Mr. Ansel Schumm	mr.ansel.schumm@geemail.com	Bridgeport	Connecticut	3737438118276285	47fdfb01e853736079590a51c5ae68de	VISA 16 digit	41.1244712998323081	-73.2248124931838476
9822	2020-01-19 14:34:08	2020-01-19	Gordon Torphy-Pagac	gordon.torphy.pagac@geemail.com	Bellevue	Washington	3528065735754615048	91fb267d464c030f95db44c33f47b7ad	Mastercard	47.5927193482123343	-122.180043096147472
9823	2020-01-19 14:34:11	2020-01-19	Lonny Leffler-Heller	lonny.leffler.heller@warmmail.com	San Francisco	California	869934633809807561	a9831ca14459d892b7b29e29ba0776e7	American Express	37.7837944210849201	-122.42439478302974
9824	2020-01-19 15:11:51	2020-01-19	Hosea Mayert	hosea.mayert@woohoo.com	Garden Grove	California	869901267217613821	0edeea69c44de578ff75d42b7a1f2aff	Discover	33.7781166859727335	-117.926567959135397
9825	2020-01-19 15:21:33	2020-01-19	Jazlene Russel	jazlene.russel@geemail.com	Jersey City	New Jersey	4112514346975	e32dcbc0e2a46105265a78e77666760e	JCB 16 digit	40.7293438321385537	-74.077792825545373
9826	2020-01-19 15:40:59	2020-01-19	Maxim Durgan-Abshire	maxim.durgan.abshire@woohoo.com	San Francisco	California	3528714070949148944	8795e6a1acd4735cc9cdec44423b6b2c	Maestro	37.7918475727957599	-122.412954137635523
9827	2020-01-19 15:47:50	2020-01-19	Kimball Borer	kimball.borer@geemail.com	Worcester	Massachusetts	3020668942348644	c4156a0f258acddce05d8689fbbabe6d	American Express	42.2144015433900037	-71.9041908018544262
9828	2020-01-19 16:41:45	2020-01-19	Flem Thompson Sr.	flem.thompson.sr.@warmmail.com	Boston	Massachusetts	180042999798825249	3bfa0db6013d0c90455bd0f770fdea26	Mastercard	42.4140804439950756	-70.9276086637236176
9829	2020-01-19 16:46:02	2020-01-19	Kade O'Hara	kade.o'hara@geemail.com	San Francisco	California	4583283749942972	5ab2c1a6b67655810f7e54e7bcbb9868	American Express	37.7620118112156078	-122.421300845452791
9830	2020-01-19 17:10:04	2020-01-19	Arra Blanda	arra.blanda@woohoo.com	San Francisco	California	3112830571551781640	4d5189f9f15d72afbd77b7e614a5efa1	VISA 13 digit	37.778386634223601	-122.448909611563678
9831	2020-01-19 17:15:51	2020-01-19	Norton Predovic	norton.predovic@geemail.com	Santa Ana	California	3337716447065121384	216beec3713a31dbfb9aba1ea14a41da	JCB 16 digit	33.747018203708528	-117.88214043792523
9832	2020-01-19 17:24:21	2020-01-19	Miss Glenn Grady MD	miss.glenn.grady.md@geemail.com	Los Angeles	California	4283148198658085	06ce9168245b14cb0e97898a242d5d6c	American Express	34.0464208001136726	-118.381333419353879
9833	2020-01-19 17:48:09	2020-01-19	Ollie Ryan-Auer	ollie.ryan.auer@geemail.com	Newark	New Jersey	4750794260166582	2c1f5712d7d1758f973b379902f4912b	JCB 15 digit	40.6736050279259729	-74.2015563586469824
9834	2020-01-19 17:56:08	2020-01-19	George D'Amore	george.d'amore@geemail.com	Killeen	Texas	180090466470914387	4256faf22db702c5a7cfbfe1bf681871	VISA 13 digit	31.0196402847997845	-97.7197635692246251
9835	2020-01-19 19:18:20	2020-01-19	Alejandro Goldner	alejandro.goldner@geemail.com	Columbus	Ohio	51396725961579319	edf973bc8c7c412e7ed5fd3341db3b99	American Express	40.0364571835424741	-83.0289129813902207
9836	2020-01-19 20:10:48	2020-01-19	Miss Phyllis Toy	miss.phyllis.toy@geemail.com	Santa Rosa	California	3471840639401515	4b5036d2f472ca9395f5e0eb82026b26	JCB 16 digit	38.4518908127799648	-122.780178529514373
9837	2020-01-19 20:12:32	2020-01-19	Ms. Kati Gislason DDS	ms.kati.gislason.dds@warmmail.com	San Francisco	California	3096249217211898409	95b1f2f4d336235fe8f871ed05ceeee5	VISA 16 digit	37.7786545192594829	-122.417613207365278
9838	2020-01-19 20:46:33	2020-01-19	Thresa Yost	thresa.yost@geemail.com	Los Angeles	California	6011133833605748205	0a6af096488eb7c34ff4e2b0a2e6732f	Discover	34.0741742568422055	-118.377203619060282
9839	2020-01-19 21:08:55	2020-01-19	Mamie Upton	mamie.upton@geemail.com	Olathe	Kansas	180034919516228823	4ce5e8e559f508a1c3ba50672126438c	Mastercard	38.7956045094534758	-94.8566864437125616
9922	2020-01-20 19:08:38	2020-01-20	Adron Bosco	adron.bosco@woohoo.com	San Francisco	California	675998317733685	26f2f4a37e1de939ee91922390b6809a	JCB 15 digit	37.7810670587959549	-122.438637507033363
9840	2020-01-19 21:33:39	2020-01-19	Mistie Jacobs-Koss	mistie.jacobs.koss@woohoo.com	Gainesville	Florida	3088057069491921463	1572ef0f0fe47939848f8e3df56f441d	JCB 16 digit	29.6853429011359786	-82.3588904208842791
9841	2020-01-19 21:34:11	2020-01-19	Miss Karlee Wyman	miss.karlee.wyman@geemail.com	Bakersfield	California	180072963222438618	27bcc019e465c76ffffbbfaef2aeaa97	JCB 15 digit	35.313421778118979	-119.062889761923998
9842	2020-01-19 22:48:04	2020-01-19	Darryll Franecki	darryll.franecki@geemail.com	San Antonio	Texas	503850692119352	5dbba072a0b4735b7dad717ea1b07a2e	Maestro	29.4085377956345688	-98.5851121974013722
9843	2020-01-19 22:54:54	2020-01-19	Dr. Dwane Ondricka I	dr.dwane.ondricka.i@geemail.com	San Jose	California	3015781266856160	090b1337d424e5b45afe6014fe140b86	VISA 16 digit	37.2004210195325342	-121.750238406540447
9844	2020-01-19 22:56:55	2020-01-19	Mr. Deon Borer I	mr.deon.borer.i@geemail.com	Saint Paul	Minnesota	4625047722961675	66d0b233392d0a05a94adee1e9f72e33	Diners Club / Carte Blanche	45.0484822643861165	-93.1002406945716672
9845	2020-01-19 22:57:36	2020-01-19	Eboni Breitenberg	eboni.breitenberg@geemail.com	Dallas	Texas	4829832107178076	45762d8844d7f6888e15ee394974e27a	JCB 16 digit	32.8767776822011939	-96.857281183680513
9846	2020-01-19 23:03:27	2020-01-19	Mr. Mcarthur Waters PhD	mr.mcarthur.waters.phd@woohoo.com	San Francisco	California	630465487797410	2d223be724e38f73575815f7aa46cd32	JCB 16 digit	37.7250556597297972	-122.428399689345028
9847	2020-01-19 23:25:43	2020-01-19	Gavin Strosin-Hamill	gavin.strosin.hamill@geemail.com	San Francisco	California	3044380250347129	206a31b1d9e34d4ce8c0526c32f096a4	Voyager	37.7856139872286718	-122.457630184480308
9848	2020-01-19 23:27:50	2020-01-19	Jannette McCullough	jannette.mccullough@woohoo.com	Tempe	Arizona	4316371516748344	e485da38f5d9b529f24f7285ad22b7a6	Mastercard	33.4237418052662107	-111.887933267562829
9849	2020-01-19 23:31:10	2020-01-19	Dr. Cash Dickinson Jr.	dr.cash.dickinson.jr.@geemail.com	New York	New York	676206147543547	066683b544e9b9ea50b684082479f471	Diners Club / Carte Blanche	40.7610658608600502	-73.8470435336593454
9850	2020-01-19 23:51:05	2020-01-19	Lucien Romaguera	lucien.romaguera@warmmail.com	Washington	District of Columbia	6011446627281298002	69947ae04e75a9b63afe0538e12b8034	Maestro	38.9181659346710873	-77.0809750268913803
9851	2020-01-19 23:52:50	2020-01-19	Velva Murazik	velva.murazik@geemail.com	Elizabeth	New Jersey	4338652151790	4e62296c5d5e1a5b963aa0c2087ccc39	VISA 13 digit	40.674215147517252	-74.24090102798678
9852	2020-01-19 23:53:50	2020-01-19	Benton Wehner	benton.wehner@geemail.com	San Francisco	California	3037648853661154	af02aad03829150c7939fcad3884bc41	JCB 16 digit	37.7983348061586852	-122.436211369940253
9853	2020-01-19 23:54:55	2020-01-19	Cas Christiansen	cas.christiansen@geemail.com	San Diego	California	4750492827740037	d6c0cd74224b1612d2c58174c727ed9a	Diners Club / Carte Blanche	32.8955536931354544	-117.182029564157133
9854	2020-01-20 00:16:56	2020-01-20	Polly Breitenberg PhD	polly.breitenberg.phd@geemail.com	San Francisco	California	060494612379084	432b9d2aa6241c50f5306e7994baed5a	Mastercard	37.7610519247085819	-122.432436329289217
9855	2020-01-20 00:41:33	2020-01-20	Isamar Anderson	isamar.anderson@geemail.com	Sioux Falls	South Dakota	3337614514611467992	1788cc2aa9fba569ac9149c9934bdf23	Maestro	43.5852181745313132	-96.7760572696272305
9856	2020-01-20 00:52:23	2020-01-20	Lani Graham	lani.graham@woohoo.com	San Francisco	California	4838560016534217	628e0152006a7b760a0f598d67992dd4	Discover	37.7494524613569951	-122.468973642330354
9857	2020-01-20 00:55:50	2020-01-20	Harmon Bins-Koelpin	harmon.bins.koelpin@warmmail.com	San Francisco	California	4532827128168	ed18db01ac6af894a9f5778f5a594b5a	JCB 15 digit	37.7727358135682678	-122.446969200521039
9858	2020-01-20 01:11:40	2020-01-20	Ewald Kozey	ewald.kozey@warmmail.com	Knoxville	Tennessee	55168414111886421	945f24c66fae19252c60674727a73635	Maestro	35.9712177732557095	-83.941417340909311
9859	2020-01-20 01:15:43	2020-01-20	Seldon Cole	seldon.cole@woohoo.com	San Francisco	California	675941877524003	2ca5dcf249869e0bf73ae4808437cae4	Voyager	37.7702218886909336	-122.419422898922818
9860	2020-01-20 01:49:57	2020-01-20	Mr. Maxie Wisoky	mr.maxie.wisoky@geemail.com	Anaheim	California	3088999017923403924	4ffa1af8ea9ea6a6c120206614b1f858	Diners Club / Carte Blanche	33.8293227097783245	-117.765315725302685
9861	2020-01-20 02:04:52	2020-01-20	Ms. Orrie Hills	ms.orrie.hills@warmmail.com	Dallas	Texas	210041066332942152	1832686cd1b5f2ac41c9bb71f162cc00	Voyager	32.8299520913783454	-96.7752009591050353
9862	2020-01-20 02:11:22	2020-01-20	Ms. Azaria Hane DVM	ms.azaria.hane.dvm@woohoo.com	San Francisco	California	3421431435839024	b7b27a189d18c99ef5c08e936a459e69	Voyager	37.7557341458930438	-122.453918106730256
9863	2020-01-20 02:23:47	2020-01-20	Mr. Titus Bartell	mr.titus.bartell@warmmail.com	Tulsa	Oklahoma	3011140648519273	b17ffcd9434200333981b54e4cf1676a	JCB 16 digit	36.1710798238307234	-95.9717738338701452
9864	2020-01-20 02:42:23	2020-01-20	Danielle Hermiston	danielle.hermiston@geemail.com	Norman	Oklahoma	3008631018083117	49bdbc555e1f07029e88decde8b105aa	Discover	35.3150783366099006	-97.3981105430770668
9865	2020-01-20 02:55:47	2020-01-20	Ms. Dulcie Kihn	ms.dulcie.kihn@warmmail.com	Denton	Texas	3455372650184911	f600cb24ce05d9370b1c0ceacb3b2d0c	Diners Club / Carte Blanche	33.1614599058203368	-97.1214872915890055
9866	2020-01-20 03:33:54	2020-01-20	Hamp Ortiz	hamp.ortiz@geemail.com	Jersey City	New Jersey	4833982462634660	32862a572e338d9381833756edbd0e23	American Express	40.6854078154485634	-73.9867229343347361
9867	2020-01-20 03:42:16	2020-01-20	Mr. Hezekiah Funk	mr.hezekiah.funk@geemail.com	Honolulu	Hawaii	3096821098913270923	cf73920f5a0fc9be4f76c5737686aeb5	Voyager	21.3192628456961373	-157.779881640730792
9868	2020-01-20 03:57:34	2020-01-20	Ashley Simonis-Bartoletti	ashley.simonis.bartoletti@geemail.com	New York	New York	3096481883497492204	e255713853432a87d08850df7bfbb79e	Maestro	40.59432664399408	-73.8903700432635873
9869	2020-01-20 03:58:11	2020-01-20	Ms. Ursula Schmitt	ms.ursula.schmitt@geemail.com	San Antonio	Texas	869917047236438646	e9b7baa497d0e560b5176241e3594b8b	Diners Club / Carte Blanche	29.4237205634430055	-98.605143996730817
9870	2020-01-20 04:06:55	2020-01-20	Pershing Roob-Murphy	pershing.roob.murphy@woohoo.com	Greensboro	North Carolina	4524986830010804	0d4d4d8a6a0be011b948058d70af0176	VISA 16 digit	36.0302662178058171	-79.9160816401690255
9871	2020-01-20 04:19:13	2020-01-20	Audley Thompson	audley.thompson@geemail.com	Savannah	Georgia	4251990457316170	a53064b8a76cb6968d00c0ff71ec564d	JCB 16 digit	31.9316774437762767	-81.1979529673386367
9872	2020-01-20 04:23:26	2020-01-20	Dr. Shan Wilderman	dr.shan.wilderman@geemail.com	Gainesville	Florida	4129616916694515	256644dc6244c658e117609edf792059	Discover	29.7695542932312911	-82.3335354404397322
9873	2020-01-20 04:31:16	2020-01-20	Jett Nikolaus II	jett.nikolaus.ii@woohoo.com	Jacksonville	Florida	3473465398848850	ea83c34c4a9c513c526e06eab59f5db9	Mastercard	30.3172136710077531	-81.6483275502998396
9874	2020-01-20 05:06:50	2020-01-20	Valorie O'Hara-Sauer	valorie.o'hara.sauer@warmmail.com	Philadelphia	Pennsylvania	4642405977800957	5e03a9722008c5a4c2f2145edcb007a2	JCB 16 digit	40.0162027094472208	-75.0886746033459929
9875	2020-01-20 05:09:32	2020-01-20	Rexford Prohaska-Kovacek	rexford.prohaska.kovacek@geemail.com	Oakland	California	210026104912161742	430c3a964c85977d58954ed259c9f3c3	JCB 16 digit	37.8322288989198157	-122.325521628498564
9876	2020-01-20 05:12:01	2020-01-20	Sam Stark	sam.stark@warmmail.com	Greeley	Colorado	52363212753670100	3f9dcf4d748443eea6811c67eb561068	Mastercard	40.411352074572072	-104.852683789918942
9877	2020-01-20 05:41:15	2020-01-20	Lilyanna Kautzer	lilyanna.kautzer@geemail.com	New York	New York	3054237728830096	ee819b3767d50e27c49119a33ac0a51b	Discover	40.6020854289401285	-74.0260817143496155
9878	2020-01-20 05:57:08	2020-01-20	Enoch Waelchi	enoch.waelchi@geemail.com	Orange	California	4298485590098368	7549bc2c59a7e8fdb86bcf50dc6f6c40	Mastercard	33.8106024392768703	-117.940128184958553
9879	2020-01-20 06:48:49	2020-01-20	Mena Hilpert	mena.hilpert@geemail.com	Louisville	Kentucky	3492091971344997	d6b224787a298b8a3a5b15b942e6bfb6	JCB 16 digit	38.1924139911677685	-85.7043209318608064
9880	2020-01-20 06:53:50	2020-01-20	Eldon Ferry IV	eldon.ferry.iv@geemail.com	San Francisco	California	4596825378968	635f416349aa9739550ce94ed883b2e6	Discover	37.7757414886212715	-122.436915209745308
9881	2020-01-20 06:56:14	2020-01-20	Dyan Reichel-Witting	dyan.reichel.witting@warmmail.com	El Paso	Texas	869901033221041981	55f978852812105805d4ecab7c7a064a	VISA 16 digit	31.7484173777341852	-106.350034551367173
9882	2020-01-20 07:01:14	2020-01-20	Tristian Volkman-Gleichner	tristian.volkman.gleichner@geemail.com	Lincoln	Nebraska	6011348542855151710	10409a29002acb131a496d3bcde5c4a0	Maestro	40.7460963813140964	-96.7634395066808963
9883	2020-01-20 07:48:42	2020-01-20	Bishop Nader	bishop.nader@geemail.com	Mesa	Arizona	4287019237305721	f0db072df5f2c349f343cbd4ca7088ee	Maestro	33.4856316078599505	-111.642903986934201
9884	2020-01-20 07:59:05	2020-01-20	Jammie Schaefer	jammie.schaefer@geemail.com	Oakland	California	51384435033692363	b55e042539fdd450d328989295cc5b11	VISA 16 digit	37.8133348892407923	-122.258052257984744
9885	2020-01-20 08:01:39	2020-01-20	Miss Bulah Bruen DVM	miss.bulah.bruen.dvm@warmmail.com	Norman	Oklahoma	676243280634726	b4735c6c22ff5ba32b184fb9a83ddc4c	Mastercard	35.2172223127953714	-97.3716272027019301
9886	2020-01-20 08:07:25	2020-01-20	Rian Bergstrom	rian.bergstrom@geemail.com	San Francisco	California	4325163771561580	d4e400403440100f286a7565baa530bd	JCB 15 digit	37.7745254669360193	-122.427760496859037
9887	2020-01-20 08:08:30	2020-01-20	Sedrick Collins	sedrick.collins@geemail.com	Richmond	Virginia	502058694228626	2b087fa092e89c8b30c70cd6de9e79a3	Discover	37.5283988765194962	-77.4841285205204002
9888	2020-01-20 08:16:36	2020-01-20	Thurman Ledner	thurman.ledner@geemail.com	Athens	Georgia	503878838702435	57db6e92d647c04967ccb53160667e8d	VISA 16 digit	33.8615549836963368	-83.3328335437107768
9889	2020-01-20 08:25:54	2020-01-20	Tennille Terry	tennille.terry@geemail.com	Murfreesboro	Tennessee	4216379856215098	960cd5d137564f0213dda40caf579501	JCB 15 digit	35.9327546568706637	-86.5056510395687042
9890	2020-01-20 08:29:43	2020-01-20	Dr. Reagan Bode	dr.reagan.bode@warmmail.com	Colorado Springs	Colorado	6011668254105410290	a7b314fc1f994cf53251aa60abbd89f1	JCB 16 digit	38.8044893787756564	-104.812836970451102
9891	2020-01-20 08:36:14	2020-01-20	Helga Leannon	helga.leannon@geemail.com	Philadelphia	Pennsylvania	180055256542951373	ba7433376195c04af39217fccde4284d	JCB 16 digit	40.0270542987581308	-75.0672476223103757
9892	2020-01-20 10:05:44	2020-01-20	Mr. Donny Daniel	mr.donny.daniel@geemail.com	Tempe	Arizona	4418965425550	6d0af3acab3c0175ed0a5a8b12e940e3	Voyager	33.2962528008889365	-112.005364883461212
9893	2020-01-20 10:12:04	2020-01-20	Harris Gerlach	harris.gerlach@geemail.com	New York	New York	869966701197386901	d517ceec84e2f7073c78b5bb662e8473	JCB 15 digit	40.6268191384375115	-73.9290209358453723
9894	2020-01-20 10:17:55	2020-01-20	Gena Kreiger	gena.kreiger@geemail.com	Charlotte	North Carolina	502092224272747	7a2dacabad528cf9bcde3d88c2cee8f5	JCB 16 digit	35.1742418340660592	-80.8172834918312759
9895	2020-01-20 10:40:21	2020-01-20	Dr. Emmons Smitham Sr.	dr.emmons.smitham.sr.@geemail.com	Oakland	California	6011134744158064701	7cbc84d5079fb8d25371af5f02b0b538	VISA 16 digit	37.8192642066635401	-122.225043030305329
9896	2020-01-20 10:43:08	2020-01-20	Tate Carter	tate.carter@warmmail.com	Detroit	Michigan	3112806831732442532	c7a520b0d72fde946ebd1d16b71f2735	Mastercard	42.3506529752556276	-83.0757446398146442
9897	2020-01-20 10:50:25	2020-01-20	Ermine Streich	ermine.streich@geemail.com	San Diego	California	4400189871728629	fd814eb761fad82f53884ce0f542d4f2	Mastercard	32.7527390644486971	-117.058330925311893
9898	2020-01-20 10:53:34	2020-01-20	Kaley Bradtke	kaley.bradtke@warmmail.com	San Francisco	California	55452777706324643	168793d9148a5d89cb4d5cc41180c271	VISA 13 digit	37.7918357172992074	-122.440016878904871
9899	2020-01-20 11:03:17	2020-01-20	Everette McClure	everette.mcclure@geemail.com	Columbus	Ohio	210022271259461102	470ac63b80edcea7a15456a3799a2f4e	JCB 16 digit	39.9856399555269633	-82.9960359583843541
9900	2020-01-20 12:36:06	2020-01-20	Tianna Marks	tianna.marks@geemail.com	Miami Gardens	Florida	51505737363408292	51b0ced32479a85aef3e156df30aba59	VISA 13 digit	25.9507975127022696	-80.2653591237742461
9901	2020-01-20 13:06:02	2020-01-20	Gale Bogisich	gale.bogisich@woohoo.com	Warren	Michigan	060446172359435	6c4939272390132006b852f9763c5e53	JCB 16 digit	42.4227225635662677	-82.9955223926808685
9902	2020-01-20 13:06:15	2020-01-20	Deon Jast	deon.jast@geemail.com	Baltimore	Maryland	52917892446406300	605df9dca8ba5183173a6791cb0137ad	JCB 15 digit	39.2544927579350755	-76.6189421720821429
9903	2020-01-20 13:08:10	2020-01-20	Mr. Cedric Doyle II	mr.cedric.doyle.ii@geemail.com	Chicago	Illinois	4326313281842942	ad5dc3e5e5a3bbbf9394b91ff846b42f	VISA 16 digit	41.9348907743882435	-87.7303019021201891
9904	2020-01-20 13:08:52	2020-01-20	Wallace Armstrong	wallace.armstrong@geemail.com	San Francisco	California	4355406612646	a5d5f0f37472ded639508f54f921c8bb	VISA 16 digit	37.7587902967334585	-122.43173784567422
9905	2020-01-20 13:09:07	2020-01-20	Bird Effertz-Hamill	bird.effertz.hamill@geemail.com	Vacaville	California	4568102985724333	1a07bfbe898cd3c955cbccd82fe1ef57	JCB 16 digit	38.3996326722797008	-121.942331668815768
9906	2020-01-20 13:21:54	2020-01-20	Mrs. Berdie Wilderman	mrs.berdie.wilderman@geemail.com	Oklahoma City	Oklahoma	51925727783585870	c937a896970593b8ea09e624fc91302b	JCB 15 digit	35.5393204691730489	-97.4959131007909718
9907	2020-01-20 13:40:49	2020-01-20	Jadyn Abbott-Smitham	jadyn.abbott.smitham@geemail.com	Berkeley	California	869980507670034286	764ffa2f76f82a6623724502dd014449	Discover	37.8554156103720345	-122.305602733551609
9908	2020-01-20 13:42:10	2020-01-20	Valentin Zemlak	valentin.zemlak@geemail.com	Little Rock	Arkansas	180026468028563525	914cf9f23b1d9075581a49930d5459e5	VISA 13 digit	34.6359240543838567	-92.3519420090470362
9909	2020-01-20 14:31:36	2020-01-20	Lucy Kulas-Fisher	lucy.kulas.fisher@geemail.com	Paterson	New Jersey	6011455996429482457	c3be6d1839ff507804e06ef44258e72f	JCB 16 digit	40.8219331253275257	-74.1848681965351204
9910	2020-01-20 14:37:41	2020-01-20	Vassie Tromp	vassie.tromp@geemail.com	Columbia	Missouri	639087029802490	21fe6a3715a7e1507dd924455a2f5969	VISA 13 digit	38.9477104856513989	-92.3609326206200905
9911	2020-01-20 15:06:54	2020-01-20	Paulette Marvin	paulette.marvin@geemail.com	Lakeland	Florida	51724672890855894	34a12f34409af22faeb5049c5421b6f3	American Express	27.9722833534069331	-81.9712638713769621
9912	2020-01-20 15:18:16	2020-01-20	Araceli Jacobs	araceli.jacobs@geemail.com	Oakland	California	869914939544142071	7ee0ec52507835f26225d55fcfa5e209	Discover	37.8446790484783833	-122.279116171692436
9913	2020-01-20 15:29:30	2020-01-20	Casey Heidenreich	casey.heidenreich@geemail.com	San Francisco	California	4553529694411041	fda5393d64bec13a694519c9368d078c	Maestro	37.7839240311479543	-122.431487893372321
9914	2020-01-20 15:44:44	2020-01-20	Dominga Hahn DDS	dominga.hahn.dds@geemail.com	New York	New York	4591511196308622	e3a5345ee8d1cd9b59fe854918d7e55c	American Express	40.7025582217834909	-73.9389030267845868
9915	2020-01-20 16:06:12	2020-01-20	Mrs. Antoinette Veum MD	mrs.antoinette.veum.md@geemail.com	Memphis	Tennessee	6011077149533581453	735b6337254724d5254736eb6231c437	JCB 16 digit	35.1820473289184292	-89.9466768141161737
9916	2020-01-20 16:18:28	2020-01-20	Ms. Karyn Grimes DDS	ms.karyn.grimes.dds@geemail.com	Chicago	Illinois	3040861083981667	aff9360c867a80242ba8e7f0a5a38821	Diners Club / Carte Blanche	41.8569214077502494	-87.6549377295684025
9917	2020-01-20 17:09:55	2020-01-20	Beaulah O'Hara	beaulah.o'hara@geemail.com	Miramar	Florida	6011085935777606349	88e9dbb494908a7709f6805078ec6df3	VISA 16 digit	25.9554157801419514	-80.2555551431600094
9918	2020-01-20 17:32:34	2020-01-20	Kiarra Dickinson	kiarra.dickinson@geemail.com	Huntsville	Alabama	53872758478807207	ef203987f32a9885a149fdd08bc57690	Discover	34.6633964268732768	-86.6177061694692867
9919	2020-01-20 17:32:51	2020-01-20	Judyth Lebsack DDS	judyth.lebsack.dds@geemail.com	Dallas	Texas	4629395983686341	3ba9275905d70a2f63052b317fa800dc	Discover	32.8559891633495695	-96.7350162203852051
9920	2020-01-20 18:31:49	2020-01-20	Mila Koch	mila.koch@geemail.com	San Francisco	California	3088007617429516408	b4d164be6ca5fd11cfa7acf7781149b8	VISA 16 digit	37.777990645026776	-122.418550860661611
9921	2020-01-20 18:51:36	2020-01-20	Isaias Simonis Jr.	isaias.simonis.jr.@warmmail.com	Berkeley	California	4573407883756	f152056490021be636cb5cc02f13d9ff	JCB 15 digit	37.8724579364319283	-122.266018368118765
9923	2020-01-20 19:16:07	2020-01-20	Kyla Borer	kyla.borer@geemail.com	Vallejo	California	4388266534430474	13c91ecdfa948701e5b0d32df99f99a0	Voyager	38.0216555265333511	-122.171760448707261
9924	2020-01-20 19:23:13	2020-01-20	Noma Schroeder	noma.schroeder@geemail.com	Chicago	Illinois	869994148203330315	2fe32670d60b37e9cf724740a53aefa1	VISA 16 digit	41.8461424705408547	-87.6822217330831961
9925	2020-01-20 19:28:19	2020-01-20	Myrtis Hammes-Lowe	myrtis.hammes.lowe@geemail.com	Salt Lake City	Utah	4825424709566	2ec84a36bfe1ac3057f169c56acde268	Maestro	40.7293679728783644	-111.987655424321062
9926	2020-01-20 20:00:52	2020-01-20	Blaine Gibson	blaine.gibson@geemail.com	Houston	Texas	6011393724543682389	a980678cad44ab2f2747cceac67688b5	Voyager	29.7753350280769169	-95.3881402666229832
9927	2020-01-20 20:33:08	2020-01-20	Kamryn Hyatt	kamryn.hyatt@geemail.com	Oxnard	California	869947381370416603	8ffc836ed848ee4613fc1e195d255cfb	VISA 13 digit	34.1351353806398805	-119.125870887460565
9928	2020-01-20 20:41:43	2020-01-20	Bettyjane Mraz	bettyjane.mraz@geemail.com	Indianapolis	Indiana	3088401173665701611	d47dff9ebb3a194de341e33272592a18	American Express	39.8376382551163388	-86.0827258427362807
9929	2020-01-20 20:42:46	2020-01-20	Mona Hauck MD	mona.hauck.md@woohoo.com	Buffalo	New York	3337788895909192800	e41728d3114ba32b9a6d62208df41c0c	JCB 16 digit	42.9219883995782538	-78.8115047627527332
9930	2020-01-20 21:33:31	2020-01-20	Roy Botsford-Strosin	roy.botsford.strosin@geemail.com	Los Angeles	California	630451994524232	83cb3b45b8cd9fbf678a268df618d2bd	Mastercard	34.0426404739130248	-118.475817038816587
9931	2020-01-20 21:42:17	2020-01-20	Kimberley Cummerata-Dare	kimberley.cummerata.dare@geemail.com	San Francisco	California	4824577946125	50662ef1920615c8a3765ea7b93f7f71	VISA 13 digit	37.8071700893026943	-122.423313472593662
9932	2020-01-20 21:48:53	2020-01-20	Trevor Durgan	trevor.durgan@woohoo.com	Houston	Texas	6011930120305357106	a83f20511be035a1d335fccfa77c7e56	Diners Club / Carte Blanche	29.8602798108089722	-95.430455404614662
9933	2020-01-20 21:57:06	2020-01-20	Doyle Casper-Heller	doyle.casper.heller@warmmail.com	Los Angeles	California	6011452809307528072	1e4ff0c0c7308b4aba6978a15a85f933	Maestro	34.0712207551911419	-118.358634580158807
9934	2020-01-20 22:55:53	2020-01-20	Adella Hudson	adella.hudson@geemail.com	Berkeley	California	3337996757882995831	c81423f65dae951680764db1dfe08283	JCB 15 digit	37.8451560087326868	-122.273094160187583
9935	2020-01-20 23:01:33	2020-01-20	Dr. Hayes Thiel	dr.hayes.thiel@geemail.com	San Diego	California	6011234127077003209	a795db7640aaba26c43713810c71f9ce	VISA 16 digit	32.8513456200316583	-117.172048873445021
9936	2020-01-20 23:06:46	2020-01-20	Albertina Gibson	albertina.gibson@geemail.com	San Francisco	California	3096045544822573303	cd012a37d8b5189c6badbc64ee85be34	Diners Club / Carte Blanche	37.7890629076092921	-122.435311740001708
9937	2020-01-20 23:31:34	2020-01-20	Lannie Kuhlman	lannie.kuhlman@geemail.com	Los Angeles	California	4386595382743840	bc67a113b1e16f4c4d7c95a29892e5f9	JCB 16 digit	33.9503874873142664	-118.497640055696664
9938	2020-01-20 23:39:04	2020-01-20	Jermey Cole	jermey.cole@geemail.com	El Paso	Texas	3490310973833324	79f6ee96454eba9c8b46bfe21008f14c	Mastercard	31.921687308542058	-106.335083371026442
9939	2020-01-20 23:45:00	2020-01-20	Bryon Lesch	bryon.lesch@woohoo.com	Huntsville	Alabama	4744259568977618	80612cde812be203b2956afba682d09a	Mastercard	34.7086490417607081	-86.6097821949534108
9940	2020-01-21 00:10:27	2020-01-21	Mrs. Dorathea Hegmann MD	mrs.dorathea.hegmann.md@geemail.com	Houston	Texas	4174046844877	4b5d547ce796b8fde9d8d768288db586	Discover	29.7973166930567466	-95.3635613509003122
9941	2020-01-21 00:10:34	2020-01-21	Shep Marquardt	shep.marquardt@woohoo.com	San Francisco	California	630434818172222	11114fc7210a44cf0988ed6497c27bcb	American Express	37.7156909470079214	-122.43206345091636
9942	2020-01-21 00:13:54	2020-01-21	Miss Wende Kuhic PhD	miss.wende.kuhic.phd@warmmail.com	Mesa	Arizona	869910188684530174	f1e55142b370a5e67c700ff94f48464e	Maestro	33.3120473096758118	-111.731111485685773
9943	2020-01-21 00:49:24	2020-01-21	Alwina Hagenes	alwina.hagenes@woohoo.com	Berkeley	California	3088551073171054588	fb59132c79dd97f393da0f3b0fe12d3d	JCB 15 digit	37.8499502645181707	-122.28700043320633
9944	2020-01-21 00:52:06	2020-01-21	Raymon Christiansen-Gibson	raymon.christiansen.gibson@geemail.com	Lubbock	Texas	3005822968804684	2f1039d372e27df94cfcd36bc380cd27	American Express	33.5198710131034261	-101.823181028562416
9945	2020-01-21 00:58:01	2020-01-21	Dr. Ryley Waters	dr.ryley.waters@geemail.com	Denver	Colorado	4114805016934957	72b42d9ad0795f4b5233d254e1a7f1e2	JCB 16 digit	39.7073184115864279	-104.886625011057035
9946	2020-01-21 01:56:37	2020-01-21	Corliss Beatty	corliss.beatty@geemail.com	Greensboro	North Carolina	4308695302555616	2acc260d33e509d7a24e11ed8b625804	VISA 16 digit	36.1666558507014102	-79.8481962573230248
9947	2020-01-21 02:05:08	2020-01-21	Antoinette Crist	antoinette.crist@geemail.com	San Francisco	California	4800188443012393	d684c5b879b0fca46acc193eeeeddf14	JCB 15 digit	37.7450481164759637	-122.412081191160226
9948	2020-01-21 02:17:59	2020-01-21	Raymon Mitchell	raymon.mitchell@warmmail.com	Cape Coral	Florida	6011241751490678817	cf7d95f8025e47674b79c44ea8aa3455	JCB 16 digit	26.5600013557791712	-81.9135726996768199
9949	2020-01-21 02:54:13	2020-01-21	Dr. Reno Zboncak IV	dr.reno.zboncak.iv@warmmail.com	Kenosha	Wisconsin	52442701788107042	c4a251e6c8bffab166f0ad2350d1bca1	VISA 13 digit	42.5623882744766746	-87.7758730788011121
9950	2020-01-21 03:02:04	2020-01-21	Justice Donnelly-Heller	justice.donnelly.heller@geemail.com	Akron	Ohio	3528679563320948240	24bc4429e3b59cce28bc109fe8b747ad	American Express	41.0853332219477778	-81.5354358544420421
9951	2020-01-21 03:17:48	2020-01-21	Renard Prohaska	renard.prohaska@woohoo.com	Chicago	Illinois	3337164606572885305	941c657d28ecccadb9c4507b60a5eb99	JCB 16 digit	41.8399693261668091	-87.6285716571874929
9952	2020-01-21 03:27:24	2020-01-21	Remington Olson	remington.olson@geemail.com	Austin	Texas	6011347002153731987	65347cb938777f61b824eb17222af102	Maestro	30.3555889340244214	-97.7112527473136794
9953	2020-01-21 03:28:06	2020-01-21	Mackenzie Feeney DDS	mackenzie.feeney.dds@warmmail.com	Fresno	California	3024154842917958	ecc5e0602cfb9835c0835979a7e34fd5	Mastercard	36.7816754949618101	-119.696305772766109
9954	2020-01-21 04:01:05	2020-01-21	Ronin Dietrich	ronin.dietrich@geemail.com	Ontario	California	3035918365913688	bdc18f8d9e5934ae7d0d01097a7eb863	VISA 16 digit	34.0277384047541744	-117.535661365008735
9955	2020-01-21 04:02:16	2020-01-21	Simpson Tremblay	simpson.tremblay@geemail.com	New York	New York	3042005895002225	02494a1de1fccf498c6ebf6bf3021ed4	JCB 16 digit	40.7328581260275087	-73.9725602768257176
9956	2020-01-21 04:05:41	2020-01-21	Kimber Rohan	kimber.rohan@warmmail.com	Raleigh	North Carolina	4458757278347515	bc7163b60743659570b76a6c2ff2218a	Voyager	35.8545976560231239	-78.5432342975802698
9957	2020-01-21 04:06:55	2020-01-21	Lillianna Swift-Medhurst	lillianna.swift.medhurst@geemail.com	Los Angeles	California	869904764828751328	1d96272b87818642c01c5017fabc4968	Mastercard	33.919512180039284	-118.478583616017545
9958	2020-01-21 05:01:21	2020-01-21	Lovell Sporer	lovell.sporer@woohoo.com	Boston	Massachusetts	4715698525906910	95b6f3c27f4abe020b0f59d6e12d4163	VISA 13 digit	42.3422563326712691	-71.0601444435257434
9959	2020-01-21 06:14:18	2020-01-21	Maye VonRueden	maye.vonrueden@woohoo.com	Oklahoma City	Oklahoma	3096315744244386655	86187773737583f0ed7b5f74bb62c633	JCB 16 digit	35.5510583382476142	-97.4917920092947838
9960	2020-01-21 06:24:33	2020-01-21	Loreen Frami	loreen.frami@woohoo.com	San Francisco	California	4227056916919664	a12bfb036fffd1e698ccbc4f0e5201e3	Maestro	37.7809464314837413	-122.43251354301735
9961	2020-01-21 06:25:49	2020-01-21	Jaylen Hoeger-Collier	jaylen.hoeger.collier@geemail.com	Richmond	Virginia	3337962487357141089	d666126cc9ee588807e23ee688fb30d3	JCB 16 digit	37.561420000459627	-77.479297963133078
9962	2020-01-21 06:44:23	2020-01-21	Flo Upton	flo.upton@geemail.com	San Francisco	California	3032066679723303	2657bb7fc4777e6387cb6813bde40ee7	VISA 16 digit	37.7965312940960487	-122.404502509687603
9963	2020-01-21 06:59:32	2020-01-21	Darion Beahan	darion.beahan@geemail.com	Louisville	Kentucky	3792822289202018	da84e94182c693d2e3c94295c1791768	JCB 16 digit	38.2116391263805326	-85.5692851563520804
9964	2020-01-21 07:42:35	2020-01-21	Chaim Herzog	chaim.herzog@geemail.com	Houston	Texas	210057973817863582	ba70cc407b863972207a54c9ca15a1ae	JCB 16 digit	29.7778817685399204	-95.3379665385946709
9965	2020-01-21 07:57:39	2020-01-21	Rae Kautzer	rae.kautzer@geemail.com	Baltimore	Maryland	3751600827162889	996bf2a33c3f9128630afb9ca34101a6	VISA 16 digit	39.3773398961406187	-76.5295455107484059
9966	2020-01-21 07:58:12	2020-01-21	Shanna Hansen	shanna.hansen@geemail.com	San Francisco	California	210051748773914991	985d5ab176f3132c392fc81f6fb67701	JCB 16 digit	37.7643789354936104	-122.434098099977746
9967	2020-01-21 08:54:54	2020-01-21	Glennie Lakin DDS	glennie.lakin.dds@geemail.com	Providence	Rhode Island	210062913357212165	f390a7bc86b325e6f3bed12266590a06	VISA 16 digit	41.7711509294196901	-71.3648271559655711
9968	2020-01-21 08:56:20	2020-01-21	Zona Gleason	zona.gleason@woohoo.com	Columbus	Ohio	675917257653406	09b70fe0894c616e4fa4a102d1152df1	Diners Club / Carte Blanche	40.0472653744321292	-82.9790961507942626
9969	2020-01-21 09:01:19	2020-01-21	Josue Beatty	josue.beatty@warmmail.com	Oakland	California	180090226415793217	4ade23c41059d54c4c8a66ed5810edc0	Diners Club / Carte Blanche	37.8081713135562723	-122.305271567128656
9970	2020-01-21 09:18:42	2020-01-21	Kirstin Sporer	kirstin.sporer@geemail.com	Philadelphia	Pennsylvania	3040897612984574	cb6dc1af206bd30d5be2036f78ffadbc	VISA 16 digit	40.0582346169237056	-75.1354933644544332
9971	2020-01-21 09:21:09	2020-01-21	Bryan Senger	bryan.senger@geemail.com	Philadelphia	Pennsylvania	3158781628708639631	aba0dcf3177c4c14855714d014fc00fc	JCB 16 digit	39.9443212904460694	-75.226892195864778
9972	2020-01-21 09:22:55	2020-01-21	Dr. Dale Stark III	dr.dale.stark.iii@geemail.com	Jacksonville	Florida	4963115092222	2b54806960f73cfec20486ae3fcae6a5	Voyager	30.3662598504271344	-81.6887714152768325
9973	2020-01-21 09:23:14	2020-01-21	Burdette McKenzie	burdette.mckenzie@geemail.com	Chicago	Illinois	630454185643258	e423ab945570efe9e3a6a23a992c8f0f	JCB 16 digit	41.9170948008842785	-87.7639255953516795
9974	2020-01-21 10:44:13	2020-01-21	Madge Daniel	madge.daniel@geemail.com	Newark	New Jersey	3528459511504103393	2c9a185790e46b3467908de19e9f5d7e	JCB 15 digit	40.7082123904868993	-74.1902598272751987
9975	2020-01-21 11:08:25	2020-01-21	Deidra Steuber	deidra.steuber@woohoo.com	San Francisco	California	4463123180630	14e4aac411294b0a04294458e18cb67d	JCB 16 digit	37.7811914009381908	-122.447754061750899
9976	2020-01-21 11:21:02	2020-01-21	Demian Bogan	demian.bogan@geemail.com	Syracuse	New York	869916607465054561	54c71af1dba10afb5a150b565dc7a077	Discover	42.9461944201812145	-76.137330987841267
9977	2020-01-21 11:26:08	2020-01-21	Ruthann Heaney	ruthann.heaney@warmmail.com	Oakland	California	589335243409238	cb646c5765cf402fa1ca0ba519e545bd	Voyager	37.7849610737323403	-122.281747103018887
9978	2020-01-21 11:44:16	2020-01-21	Mrs. Tristan Lebsack	mrs.tristan.lebsack@geemail.com	Garland	Texas	6011011788233810792	cfb057d9f29e378f5174faa823fd2779	VISA 13 digit	32.9235702187057555	-96.6286062713872695
9979	2020-01-21 11:56:58	2020-01-21	Milford Steuber	milford.steuber@woohoo.com	San Antonio	Texas	3096489758676156865	db4558e9808d4ea552eee844d12ee72c	JCB 16 digit	29.5486161824852225	-98.4683426043786056
9980	2020-01-21 12:07:01	2020-01-21	Delmer Gutkowski Jr.	delmer.gutkowski.jr.@warmmail.com	New Haven	Connecticut	503893932353548	91e96e964d3bfd21aeba80ba7d90e9fa	Voyager	41.3826334115575989	-73.0000711620785268
9981	2020-01-21 12:10:08	2020-01-21	Tina Hane	tina.hane@geemail.com	Chicago	Illinois	3158607223308063192	a4bc6689347fdb73c4956846555d3972	Maestro	41.8232004037894356	-87.6484846021078425
9982	2020-01-21 12:18:22	2020-01-21	Betsey Schmeler-Yost	betsey.schmeler.yost@geemail.com	Fayetteville	North Carolina	3025188007621194	4fcc82478a95d5ed10114942bb7f69bb	American Express	35.0789146195419121	-78.9083831145558463
9983	2020-01-21 12:47:46	2020-01-21	Jaydon Haag	jaydon.haag@geemail.com	Oakland	California	4330576270160	74df30f6ae064d42f1723885fe9fa852	Voyager	37.8008838616152758	-122.280918914388764
9984	2020-01-21 12:49:23	2020-01-21	Selene Pouros MD	selene.pouros.md@geemail.com	Knoxville	Tennessee	210093989653959546	3e4f6c7a7da6d0ae6c4e42eede4dbc69	Mastercard	35.9301116325955832	-84.0397912065714507
9985	2020-01-21 13:00:36	2020-01-21	Ms. Miah O'Connell	ms.miah.o'connell@geemail.com	Berkeley	California	3037860607344801	4dda55b3b80402c258fecbe59ae14a53	Voyager	37.8715165316090605	-122.260572756830499
9986	2020-01-21 13:40:16	2020-01-21	Dr. Glover Trantow	dr.glover.trantow@geemail.com	Spokane	Washington	6011369547055884592	0a72c741984b5cabef187daed3bea4f9	American Express	47.6695714865118276	-117.373424472649774
9987	2020-01-21 13:46:07	2020-01-21	Dalia Altenwerth	dalia.altenwerth@geemail.com	San Francisco	California	3054022503952251	aa55f32a3856d9d6a0b642eb41427a63	VISA 13 digit	37.7949780444962187	-122.444641952616706
9988	2020-01-21 14:21:53	2020-01-21	Aurilla Yundt DVM	aurilla.yundt.dvm@warmmail.com	Houston	Texas	4825889602769	84f1db32616a92eecdef4064c7d0bd47	JCB 16 digit	29.7311989032275967	-95.3909359536614261
9989	2020-01-21 14:23:51	2020-01-21	Mahalie Beier	mahalie.beier@geemail.com	San Francisco	California	55897618151602856	0bff931d0a8a45003d1847bef1a99a19	VISA 16 digit	37.8043032552497706	-122.423340258807997
9990	2020-01-21 14:47:11	2020-01-21	Meagan Donnelly	meagan.donnelly@geemail.com	San Francisco	California	4866388222888481	958d0eaa3dd9fbe2c2c663d24b3c9fa2	Discover	37.8043760128627824	-122.438619724465653
9991	2020-01-21 15:06:08	2020-01-21	Ms. Debora Parker	ms.debora.parker@geemail.com	Tucson	Arizona	3337610178682489709	36106e9eb9469725bd5b93a4a3e9e3c9	Voyager	32.1352427694056217	-110.826930843362959
9992	2020-01-21 15:16:34	2020-01-21	Gust Gusikowski	gust.gusikowski@woohoo.com	Oakland	California	3745179977026490	398546c179fa7f4f313170b1a58e7177	JCB 15 digit	37.7883356763381144	-122.241550761755704
9993	2020-01-21 15:36:06	2020-01-21	Dahlia Bins	dahlia.bins@warmmail.com	Joliet	Illinois	630491720135721	266a30c600cd2ae48f4cba65d8e53652	American Express	41.4335206048887201	-88.1929421620547771
9994	2020-01-21 16:03:47	2020-01-21	Mabell Kemmer	mabell.kemmer@geemail.com	San Jose	California	3007363284039927	318b3da4c636f648ddaa9da7691b50b3	Discover	37.3581855518098962	-121.786012083686515
9995	2020-01-21 17:01:11	2020-01-21	Stasia Koch	stasia.koch@warmmail.com	San Francisco	California	4887910274224	71b1b2fc06cc6852cba2d80cad23f523	Mastercard	37.7653806886701489	-122.406935928086028
9996	2020-01-21 17:15:38	2020-01-21	Mattye Ruecker	mattye.ruecker@geemail.com	Cary	North Carolina	869963602426520059	fcade27bda0bbc22ae353e80643d93a7	JCB 16 digit	35.8740170171592396	-78.7598139093808811
9997	2020-01-21 17:25:09	2020-01-21	Keifer Bruen MD	keifer.bruen.md@warmmail.com	Glendale	Arizona	4025351809984782	cf5ee591f927e7a7adf6bb77db8daf15	JCB 16 digit	33.4971516171231869	-112.230514191861815
9998	2020-01-21 17:30:05	2020-01-21	Demian Lowe-Barton	demian.lowe.barton@geemail.com	San Antonio	Texas	3032422663265886	b153ded8abd994087b05a6513e6ae5e4	Discover	29.4238899619854983	-98.5687409291811178
9999	2020-01-21 17:31:25	2020-01-21	Aretha Osinski-Gutkowski	aretha.osinski.gutkowski@geemail.com	Hollywood	Florida	4507598337206	48f49c59676d7a8ee59efee9b3c35397	Diners Club / Carte Blanche	25.9726445610579084	-80.2533545528355887
10000	2020-01-21 18:01:43	2020-01-21	Saundra Sporer	saundra.sporer@geemail.com	Allen	Texas	4934454660143	9bf8b51e6cee7990a3d90b7192738198	Voyager	33.0471400411825584	-96.6515430205449491
10001	2020-01-21 18:04:04	2020-01-21	Clarence Cartwright	clarence.cartwright@woohoo.com	Nashville	Tennessee	060491354162223	3a3164f45f894afe3eae0eb655576968	Voyager	36.1891354864586106	-86.8504814351815639
10002	2020-01-21 19:09:44	2020-01-21	Larue Feest-Herman	larue.feest.herman@woohoo.com	Warren	Michigan	210046068505858236	c2ada87df06ff36f4910f973f281574b	Mastercard	42.5496853273823845	-83.0540748754982019
10003	2020-01-21 19:30:09	2020-01-21	Ryann Erdman	ryann.erdman@geemail.com	San Antonio	Texas	3488607840954074	c5c28188af62588f0f0df46a6dad153f	JCB 15 digit	29.5425758536510159	-98.590430699738107
10004	2020-01-21 19:52:56	2020-01-21	Dr. Leta Wiza PhD	dr.leta.wiza.phd@geemail.com	San Francisco	California	3439720510947169	d2bbb3bb965242eea3623b4676aec842	Voyager	37.7674837427527379	-122.442437217838091
10005	2020-01-21 20:18:09	2020-01-21	Ozella Shanahan DVM	ozella.shanahan.dvm@warmmail.com	Springfield	Massachusetts	4016961171358	129759987573bc2de092b17d65a10245	Voyager	42.1767107537221122	-72.48818332046271
10006	2020-01-21 20:19:13	2020-01-21	Mazie Moen	mazie.moen@geemail.com	Baltimore	Maryland	3448218667137808	56d9efae4d55799578c1c115a94210c3	American Express	39.2851267928723189	-76.557026101417847
10007	2020-01-21 20:23:18	2020-01-21	Vlasta Lind	vlasta.lind@geemail.com	San Francisco	California	3715120686256966	dd99377411543698a5e130f575efbe00	VISA 13 digit	37.7751667235322017	-122.380984827413641
10008	2020-01-21 20:26:14	2020-01-21	Mr. Damond Hamill DDS	mr.damond.hamill.dds@woohoo.com	San Francisco	California	869963739338805879	f340b40791be41cb8e5861a71a1d5946	VISA 16 digit	37.7525494940976927	-122.441825016380704
10009	2020-01-21 20:30:55	2020-01-21	Estela Bergstrom	estela.bergstrom@geemail.com	Houston	Texas	3033288761587193	90cf38faf9ef1165861260c3c77f9854	VISA 13 digit	29.6954087848387651	-95.3294792211629414
10010	2020-01-21 20:48:16	2020-01-21	Brigette Prosacco	brigette.prosacco@geemail.com	Oakland	California	6011449339865291489	c740369ba7cd950c4a4032158a296bb3	Mastercard	37.7990561359273087	-122.268103261834952
10011	2020-01-21 21:07:05	2020-01-21	Treyton Treutel	treyton.treutel@geemail.com	Fayetteville	North Carolina	639066947193695	5956e408f8e8987f2f0ce8da9d021ce3	VISA 13 digit	35.1375368112485873	-78.9967687170617268
10012	2020-01-21 21:47:34	2020-01-21	Miss Media Beier DVM	miss.media.beier.dvm@warmmail.com	Garland	Texas	3443122878433748	ea6aa921dd434dc10f8c9b4e268977b0	Maestro	32.9210214638385921	-96.6619490715835354
10013	2020-01-21 22:03:35	2020-01-21	Tod Ebert	tod.ebert@geemail.com	Los Angeles	California	869936939780580152	19fdd3069f1248ee03b7691868bbbafe	JCB 16 digit	33.9569841228291338	-118.494897939077759
10014	2020-01-21 22:21:56	2020-01-21	Roderic Rau-Nader	roderic.rau.nader@geemail.com	Durham	North Carolina	503811425813935	d8eee63c2b6e2e958b1e2f50a655b50d	Discover	35.9047158452928059	-78.9936407791353759
10015	2020-01-21 22:36:09	2020-01-21	Ms. Bethann Roberts	ms.bethann.roberts@geemail.com	Columbus	Ohio	52821978509718585	2319f4d659db3cc468b660e0b2ad392e	JCB 16 digit	39.9808698938738516	-83.0528976201314606
10016	2020-01-21 22:37:14	2020-01-21	Miss Clarabelle Rempel DDS	miss.clarabelle.rempel.dds@warmmail.com	San Francisco	California	51173356548391470	7b8a1946af12bfb870934db5de3ac5c5	Mastercard	37.8068926324153551	-122.422960550644547
10017	2020-01-21 23:35:04	2020-01-21	Dr. Deondre Kiehn DVM	dr.deondre.kiehn.dvm@geemail.com	Baltimore	Maryland	4114130468850605	e11b2856bba6492c045f0ccd8f85d41c	Maestro	39.2618322526104748	-76.5180268705375539
10018	2020-01-21 23:39:50	2020-01-21	Drew Barton	drew.barton@geemail.com	New York	New York	869994757288304969	9d238d6a0a802cc1aa84e35fbf0100d7	Voyager	40.6617090598903559	-74.0276350343495579
10019	2020-01-21 23:56:21	2020-01-21	Savanah Volkman	savanah.volkman@geemail.com	Oakland	California	4627682464073210	0299dda75bff952a32f2118ce1c3f5de	VISA 16 digit	37.7958649033909069	-122.286792948028449
10020	2020-01-21 23:57:04	2020-01-21	Jerrell Tillman	jerrell.tillman@geemail.com	Austin	Texas	3005105861886945	b09b4aed9da4ea4004591b1fb8013f81	American Express	30.3662748967424037	-97.6899162772815686
10021	2020-01-22 00:04:29	2020-01-22	Wynona Cormier	wynona.cormier@geemail.com	Milwaukee	Wisconsin	180067493961607683	b054e268ccf1579d0fd1a0cdca2abf18	VISA 16 digit	42.9900102557700095	-88.066130542020133
10022	2020-01-22 00:09:16	2020-01-22	Huy Swaniawski-Wiegand	huy.swaniawski.wiegand@geemail.com	El Paso	Texas	3034445450277903	75071746cc991406266847f0e216f883	Mastercard	31.8489157217849055	-106.41580219422282
10023	2020-01-22 00:35:16	2020-01-22	Dessie Altenwerth PhD	dessie.altenwerth.phd@geemail.com	Kent	Washington	3032360319025801	796cddb30f90f4c7981429c336ff9f28	VISA 16 digit	47.4196883620805991	-122.236570322247971
10024	2020-01-22 00:50:08	2020-01-22	Heidy Sanford	heidy.sanford@warmmail.com	Chicago	Illinois	3788836883698724	dc5cae630741b82e3a214c6ee99c5110	Diners Club / Carte Blanche	41.8998718681581366	-87.6004983007006359
10025	2020-01-22 01:28:26	2020-01-22	Belen Bartell PhD	belen.bartell.phd@woohoo.com	Baltimore	Maryland	6011779830382671435	2da103c9c9001a9054f19ea766a33b00	Maestro	39.3016540157608674	-76.6256187174953567
10026	2020-01-22 01:47:45	2020-01-22	Algie Hermann-O'Hara	algie.hermann.o'hara@geemail.com	Meridian	Idaho	180019160555725879	0b8d069edd1690a857f01f3a6b8f7a31	VISA 16 digit	43.6067958780106153	-116.495448821358011
10027	2020-01-22 01:55:54	2020-01-22	Jamar Jones-Dickens	jamar.jones.dickens@geemail.com	Mesa	Arizona	53654109979782834	045eafcb8344157104adc69b59fa987b	JCB 15 digit	33.4796366856578729	-111.811195407423753
10028	2020-01-22 02:30:11	2020-01-22	Jettie Rutherford	jettie.rutherford@geemail.com	San Francisco	California	54504375311583931	98d3585543c8142678b61423c1829541	Maestro	37.7725155004288098	-122.450376759236335
10029	2020-01-22 02:42:28	2020-01-22	Memphis Huels	memphis.huels@geemail.com	New Orleans	Louisiana	060428221190383	bb16609093277f79dc59342021bc4995	JCB 16 digit	30.15116328653097	-89.9650995927657959
10030	2020-01-22 02:44:22	2020-01-22	Iza Parker	iza.parker@geemail.com	San Francisco	California	210003235848033899	b9504f5f83becb2c3f1f353f9c9adc27	Maestro	37.760790780426035	-122.418943673922456
10031	2020-01-22 02:54:48	2020-01-22	Jean Nicolas-Oberbrunner	jean.nicolas.oberbrunner@geemail.com	Wilmington	North Carolina	3778842338396262	dbd84a58581103bdae45b2a83ccfb0a3	VISA 16 digit	34.275932724569742	-77.9141790423534815
10032	2020-01-22 03:11:58	2020-01-22	Dr. Alek Will IV	dr.alek.will.iv@geemail.com	Kent	Washington	55766599930508333	e4b1e767bbd09f25386daac58e9ae19d	Diners Club / Carte Blanche	47.4360294722132352	-122.170875959112124
10033	2020-01-22 03:51:15	2020-01-22	Dr. Easton Tromp	dr.easton.tromp@warmmail.com	New York	New York	3762051890551102	5ea9775d386213be8dff52ee33921044	Voyager	40.7216563852727376	-74.0002878440905363
10034	2020-01-22 03:58:45	2020-01-22	Eustace Macejkovic	eustace.macejkovic@geemail.com	Houston	Texas	4941299863673455	3ad5cd6d780a143ec8bbc39d4d247cd2	VISA 16 digit	29.7938543004062026	-95.4746432247120964
10035	2020-01-22 04:03:49	2020-01-22	Matt Bruen IV	matt.bruen.iv@geemail.com	Berkeley	California	4724153790770657	f4167aad64ee5cbda1458e690973db87	Diners Club / Carte Blanche	37.8494640830007896	-122.264839580567667
10036	2020-01-22 05:52:15	2020-01-22	Magen Monahan	magen.monahan@geemail.com	El Paso	Texas	4071669607112	be81d12b3d7bfea04aa7184780c7a891	Mastercard	31.7951270639725045	-106.403438268506903
10037	2020-01-22 06:03:31	2020-01-22	Mrs. Marlys Murazik	mrs.marlys.murazik@geemail.com	Dallas	Texas	3337280761558922777	90885fe49912a537b9d101b210703a15	JCB 16 digit	32.8266139655645972	-96.6752570763658667
10038	2020-01-22 06:11:44	2020-01-22	Jayne Zboncak	jayne.zboncak@geemail.com	Berkeley	California	3053796436033831	e1b3ba0d2044b0f64b0209752b95b399	Maestro	37.8616605425803954	-122.234154304170886
10039	2020-01-22 06:24:40	2020-01-22	Dr. Kelley Kemmer	dr.kelley.kemmer@geemail.com	San Francisco	California	3759704072161208	1330ff554d29876c8b32cd7ea8bf119a	JCB 15 digit	37.7396674303817292	-122.408661797401336
10040	2020-01-22 06:26:54	2020-01-22	Capitola Howe DDS	capitola.howe.dds@woohoo.com	San Francisco	California	180075658605879456	435919f537022c7d53c8cfc5787b1f98	VISA 13 digit	37.7583858672157859	-122.444092456341352
10041	2020-01-22 06:35:26	2020-01-22	Dr. Mikeal Schulist	dr.mikeal.schulist@geemail.com	San Francisco	California	3158394310157264950	5d33a5d94b12955d4de93c9a8a01f3b3	VISA 16 digit	37.8048568401373402	-122.443594549229346
10042	2020-01-22 06:37:01	2020-01-22	Kurtis Funk	kurtis.funk@geemail.com	San Francisco	California	3434330973034086	e4c5d348844d0f9a9f9065856f22ff72	Diners Club / Carte Blanche	37.7804758885528003	-122.410730922242237
10043	2020-01-22 06:59:51	2020-01-22	Ronna Swaniawski	ronna.swaniawski@geemail.com	Irvine	California	3112704132188367460	97ee403c376ee0f1460cc7da1592e2fc	Voyager	33.6383540673196322	-117.829175813869753
10044	2020-01-22 07:01:50	2020-01-22	Quinn Daniel	quinn.daniel@geemail.com	Berkeley	California	3001721437311905	290002d908215dbdacfaf02df8ef5dfc	Discover	37.8644211486800017	-122.264730774131351
10045	2020-01-22 07:08:42	2020-01-22	Miss Lailah Tillman DDS	miss.lailah.tillman.dds@geemail.com	Oklahoma City	Oklahoma	3528782512114429507	512f2886d135345f43f24f4055381423	JCB 16 digit	35.5623691783662892	-97.4417050186440292
10046	2020-01-22 07:48:06	2020-01-22	Karl Ferry	karl.ferry@geemail.com	Chicago	Illinois	4154526337709	17b85b83a10c14b3e8a221547cf037b5	Discover	41.8316791476517906	-87.7033985597111183
10047	2020-01-22 07:52:05	2020-01-22	Dr. Daniele Streich DDS	dr.daniele.streich.dds@geemail.com	Tallahassee	Florida	6011547705231562764	3ce22002e0ed27f5d2500b4a672795da	Voyager	30.525258955268562	-84.310852999614184
10048	2020-01-22 08:07:47	2020-01-22	Rey Ritchie	rey.ritchie@geemail.com	San Francisco	California	4400114008321239	424d9cbdd0dd33dd40e3a890065a6006	VISA 16 digit	37.7809269505111089	-122.425024755281427
10049	2020-01-22 08:34:53	2020-01-22	Ama Dickens	ama.dickens@geemail.com	Berkeley	California	3468072991661248	16fc8302e57a3c6ec94280320c2ad3e1	VISA 13 digit	37.9136697982050208	-122.249518169216188
10050	2020-01-22 08:45:27	2020-01-22	Zana Donnelly-Fadel	zana.donnelly.fadel@geemail.com	Berkeley	California	54429582108765272	5a57906d36dc2f945a94c886ea337d68	Maestro	37.8858773104124111	-122.286860031642959
10051	2020-01-22 09:04:08	2020-01-22	Rachelle Mosciski	rachelle.mosciski@geemail.com	Los Angeles	California	3764432987818927	931e3cea10fba4ae321474958511d86e	JCB 16 digit	33.9944324329826983	-118.489388503133497
10052	2020-01-22 09:17:38	2020-01-22	Jessika Heathcote	jessika.heathcote@woohoo.com	Anchorage	Alaska	3029568328652653	a16b6b348c9883d8ce111d97517bc738	VISA 16 digit	61.192659827902169	-149.261194408371296
10053	2020-01-22 10:23:37	2020-01-22	Jair Nikolaus-Hayes	jair.nikolaus.hayes@woohoo.com	San Diego	California	3048025444158264	b48398cec91f517d97bce6ba48e0bd12	Voyager	32.8206535241633688	-117.200100097283723
10054	2020-01-22 10:35:37	2020-01-22	Rubi Quigley	rubi.quigley@geemail.com	Atlanta	Georgia	4833831364977703	514497e27788f946c73c056890dec064	Discover	33.699440978867564	-84.4776255242105663
10055	2020-01-22 10:35:51	2020-01-22	Halsey Fay	halsey.fay@geemail.com	San Francisco	California	3405002312174676	aa6bceb12accd89db7391c1d801f1294	JCB 15 digit	37.7692344244604286	-122.436987658041119
10056	2020-01-22 11:08:12	2020-01-22	Collins Klein DVM	collins.klein.dvm@warmmail.com	Jacksonville	Florida	180022926224154385	5131ddbb20020fc8d60247a549058b8a	JCB 16 digit	30.3173643841926008	-81.6508672306392356
10057	2020-01-22 11:17:17	2020-01-22	Dr. Ingram Ziemann Sr.	dr.ingram.ziemann.sr.@geemail.com	Downey	California	3088732233903122945	f122469cffc01b204d7586b4ca8a7ded	American Express	33.9816225494973381	-118.102764981250829
10058	2020-01-22 11:21:14	2020-01-22	Willa Monahan MD	willa.monahan.md@woohoo.com	Miami Gardens	Florida	210044575998464985	ddfb77b49db667afb8801ab579377047	Maestro	25.9436641392238414	-80.2065568413831329
10059	2020-01-22 11:32:56	2020-01-22	Dr. Etna Rohan MD	dr.etna.rohan.md@geemail.com	Oklahoma City	Oklahoma	3088228090778663788	bbd44dc09faf1a9d20945672cdfe4a70	Mastercard	35.4751247486941566	-97.6005191077839527
10060	2020-01-22 11:34:50	2020-01-22	Dylon Kessler	dylon.kessler@geemail.com	Buffalo	New York	589352239190417	fb433d0b695f0d16deed76a629c25f00	VISA 13 digit	42.9201769625488652	-78.7951152972344318
10061	2020-01-22 11:39:43	2020-01-22	Sheldon Monahan	sheldon.monahan@geemail.com	Philadelphia	Pennsylvania	869995035111953685	0399cf8a3cbbb5215498a05c8912fa9e	JCB 15 digit	39.9273197741206758	-75.178445306922498
10062	2020-01-22 11:46:35	2020-01-22	Dr. Lashonda Morissette DVM	dr.lashonda.morissette.dvm@geemail.com	San Francisco	California	210087471619519290	aa2a94e0bdb6f4f1b440adde28337354	VISA 13 digit	37.777141962650596	-122.409767545451089
10063	2020-01-22 11:52:56	2020-01-22	Edith Bayer	edith.bayer@warmmail.com	Berkeley	California	630494831844629	b56aaf13444af3f6613d7e94ef6eb6d7	Mastercard	37.875418871760516	-122.267690829028481
10064	2020-01-22 11:54:08	2020-01-22	Jerimy Windler	jerimy.windler@woohoo.com	Winston–Salem	North Carolina	869902207452850604	050aa24ff5c08bef7a94a53125039537	Mastercard	36.0698835334971548	-80.3260531975552396
10065	2020-01-22 12:26:31	2020-01-22	Jalissa Frami PhD	jalissa.frami.phd@warmmail.com	Honolulu	Hawaii	4051893651484764	a754247d8b7fbeab1e178d61bb92907f	VISA 16 digit	21.3744650316175075	-157.912187933290738
10066	2020-01-22 12:40:04	2020-01-22	Meggan Willms	meggan.willms@woohoo.com	Spokane	Washington	3482650532259325	80e72771114850360b4bc81f7a5e4de0	American Express	47.756536150654405	-117.44657969706617
10067	2020-01-22 13:29:11	2020-01-22	Davin Muller PhD	davin.muller.phd@geemail.com	San Francisco	California	3158468411863842112	9c0125da9673fe2ba16aa49ef89cb477	American Express	37.8059051514090569	-122.4160935222489
10068	2020-01-22 13:47:14	2020-01-22	Hedwig Stoltenberg	hedwig.stoltenberg@geemail.com	Los Angeles	California	3096295462110383268	7d82f4f14ccbd8e087d5760e7bc4636e	Maestro	34.1108574550464709	-118.336333514004195
10069	2020-01-22 13:49:43	2020-01-22	Attilio Prosacco	attilio.prosacco@geemail.com	Los Angeles	California	6011794987098184656	ddc1267deed1db2664c33a475fdd75ef	Maestro	33.977233130052312	-118.343150338995457
10070	2020-01-22 14:02:28	2020-01-22	Dr. Benjamine Heller	dr.benjamine.heller@warmmail.com	Chicago	Illinois	6011750576413891343	cdba95a980934fe31ead7760161b28fa	JCB 16 digit	41.8490113188348758	-87.7195633315045313
10071	2020-01-22 14:11:30	2020-01-22	Alvera Bartell	alvera.bartell@geemail.com	Atlanta	Georgia	3088996541427226518	599e71012bc5908204d8f41bb67e608c	JCB 16 digit	33.69302912832201	-84.4111195569437029
10072	2020-01-22 14:36:58	2020-01-22	Mrs. Kanisha Pagac	mrs.kanisha.pagac@geemail.com	Chicago	Illinois	4508767507634229	8c6e620756575b4db3d99beddac8454f	Mastercard	41.7792638560127472	-87.6811326622061387
10073	2020-01-22 14:59:19	2020-01-22	Lilburn Kilback	lilburn.kilback@geemail.com	San Francisco	California	3337202204330391768	d49f3828cf962f70ea01ee6ae500ac35	American Express	37.8062635185547862	-122.432498663699519
10074	2020-01-22 15:02:53	2020-01-22	Mr. Nunzio Moore	mr.nunzio.moore@warmmail.com	Miami	Florida	3724859388649536	82ff4f820836f0232f58e63d401edcb5	JCB 16 digit	25.6945627640139342	-80.2356923779346118
10075	2020-01-22 15:19:02	2020-01-22	Hortencia Brown	hortencia.brown@geemail.com	West Covina	California	3088706854127286372	70da52402a80a345419a7e12c51672af	JCB 16 digit	34.0411631039451805	-117.872138229718047
10076	2020-01-22 16:12:07	2020-01-22	Dr. Mikeal Shanahan	dr.mikeal.shanahan@woohoo.com	New York	New York	4218960754557679	f23e19500d0416da70b0b2b98410eb6d	VISA 13 digit	40.5769045915212487	-74.0359879530396228
10077	2020-01-22 16:26:20	2020-01-22	Dr. Vito Kris V	dr.vito.kris.v@warmmail.com	Phoenix	Arizona	3432451920205322	8f1bb574b790febc65aa99cd1c731920	Voyager	33.5623633369736396	-112.0193203095276
10078	2020-01-22 16:54:27	2020-01-22	Foster Yost	foster.yost@geemail.com	West Palm Beach	Florida	4250603837774601	de60d393800fe7a1900fc958de922cd1	VISA 13 digit	26.7888806187395012	-80.14711106105932
10079	2020-01-22 17:23:43	2020-01-22	Blanche Kuvalis PhD	blanche.kuvalis.phd@woohoo.com	Richmond	Virginia	676103821244138	8699f11d1287a822ed2bf18b9b183372	VISA 16 digit	37.5807033781182014	-77.3781256064996086
10080	2020-01-22 18:06:46	2020-01-22	Gurney Morissette	gurney.morissette@geemail.com	Louisville	Kentucky	3454690596357007	12397b8900008a2d2be76be987ebcb05	Voyager	38.1758177996516181	-85.6158788679238398
10081	2020-01-22 18:33:21	2020-01-22	Willy Braun-Zulauf	willy.braun.zulauf@geemail.com	Augusta	Georgia	676103343171397	a3a318b48bdf194bdfa19c6082b95cc1	VISA 16 digit	33.3054158549960704	-82.1682015495669162
10082	2020-01-22 18:38:26	2020-01-22	Yvette Koss	yvette.koss@woohoo.com	Los Angeles	California	4112319733211436	10aedf350a589103c940e6e15bab6fee	JCB 16 digit	34.0629460254549983	-118.385414005070174
10083	2020-01-22 18:57:40	2020-01-22	Jillian Treutel	jillian.treutel@geemail.com	Phoenix	Arizona	4120598648999777	2b03ef5a17ba1e5e653f1ba31ac8894b	VISA 13 digit	33.542879918257519	-112.087357051104689
10084	2020-01-22 18:57:56	2020-01-22	Krish Blanda	krish.blanda@geemail.com	Plano	Texas	4644541794730858	ff509600305df069dc1fc191cc83581d	American Express	32.9616435176778637	-96.7368348542783423
10085	2020-01-22 19:22:37	2020-01-22	Gerry O'Keefe	gerry.o'keefe@geemail.com	San Francisco	California	561244099683136	1ea2128c0c000c9cdd34cfd5923049d4	JCB 16 digit	37.7864218140757231	-122.429827949063565
10086	2020-01-22 19:35:27	2020-01-22	Rasheed Nicolas	rasheed.nicolas@geemail.com	Mesa	Arizona	4919186470415875	8f3320eca3bf04ce32b00369427be095	Discover	33.3417053066339335	-111.764132798963786
10087	2020-01-22 19:48:38	2020-01-22	Grecia Dooley DVM	grecia.dooley.dvm@geemail.com	San Francisco	California	3767401314963455	455082ed310b3fdc6a577d869f8d16b0	Mastercard	37.7757406555004422	-122.408833366275729
10088	2020-01-22 19:52:50	2020-01-22	Marvel Goodwin-Beier	marvel.goodwin.beier@geemail.com	Salinas	California	3528946719120087186	85bccfa301976deec0e430296de8b1cf	Discover	36.6897731246192009	-121.728331145056345
10089	2020-01-22 20:47:55	2020-01-22	Mame McCullough	mame.mccullough@geemail.com	St. Louis	Missouri	180008809746289103	4bb9d84bf51c1901abfa67e125c16af8	Voyager	38.6356272063840152	-90.203252665698912
10090	2020-01-22 20:49:28	2020-01-22	Jamila Abbott MD	jamila.abbott.md@woohoo.com	Buffalo	New York	3337789801931544843	9d1951f84c76e01ee39720b72abe7f87	American Express	42.9794167027529284	-78.8318235295292027
10091	2020-01-22 20:50:27	2020-01-22	Claud Purdy	claud.purdy@warmmail.com	Indianapolis	Indiana	4944810986827	ecc5db6e145bae8038083a12a98bc0d1	Discover	39.7259282949388037	-86.1688048671200875
10092	2020-01-22 20:54:17	2020-01-22	Aubrey Muller MD	aubrey.muller.md@geemail.com	Sunnyvale	California	676245600369701	b318fdb8656e9e07a5e08836fcec80d8	Maestro	37.3367755215141983	-121.957611541236943
10093	2020-01-22 21:07:55	2020-01-22	Shawnee Heaney	shawnee.heaney@woohoo.com	Madison	Wisconsin	3337464829599702520	c50d24621f71b1c3f3eeba4a9fe180f7	American Express	43.0071022156599909	-89.5207006045036024
10094	2020-01-22 21:48:04	2020-01-22	Pierce Bartell	pierce.bartell@woohoo.com	Honolulu	Hawaii	676245764805060	00d9d3b3f682fc317d299afc6c581acb	VISA 16 digit	21.3145305318508314	-157.887295382909855
10095	2020-01-22 21:48:58	2020-01-22	Mr. Amarion Wiza Sr.	mr.amarion.wiza.sr.@geemail.com	Centennial	Colorado	3158753223808051525	bdba5438d2d71aedd478bf7fc9b96a5d	American Express	39.6088916112244149	-104.935952681199097
10096	2020-01-22 21:49:18	2020-01-22	Gilmer Treutel	gilmer.treutel@geemail.com	Baltimore	Maryland	4541825629046919	dc158712227f48c161933503468746d4	VISA 16 digit	39.3439967236947226	-76.5980261683948385
10097	2020-01-22 22:02:53	2020-01-22	Marley Willms	marley.willms@woohoo.com	San Francisco	California	4076052601957780	10f6bb52951c281cb37e31b58a4b8a45	JCB 16 digit	37.7713883951110887	-122.446943903926496
10098	2020-01-22 22:09:53	2020-01-22	Tollie Volkman	tollie.volkman@woohoo.com	San Francisco	California	561230150395413	4a5b145574c00e58cd56b664e7361ac2	VISA 16 digit	37.784281133532005	-122.437080655701195
10099	2020-01-22 22:11:35	2020-01-22	Victoria Krajcik	victoria.krajcik@woohoo.com	Chicago	Illinois	4295794010746297	4a3bd6d68d56502a69178d69f62b70ad	VISA 13 digit	41.8271285072736489	-87.631944022842859
10100	2020-01-22 22:18:23	2020-01-22	Leatha Wisozk MD	leatha.wisozk.md@geemail.com	San Francisco	California	6011339414917071677	fae5fe85ec5bdd5112a9f36d6c10d0dc	JCB 16 digit	37.7429674574519396	-122.429793395061793
10101	2020-01-22 22:38:25	2020-01-22	Dr. Clora Kautzer	dr.clora.kautzer@woohoo.com	Reno	Nevada	3158561317661775527	eb783a048a70f691d5151f8a8006c63d	Discover	39.5505862626325353	-119.921530948036917
10102	2020-01-22 22:39:22	2020-01-22	Marylouise Adams	marylouise.adams@woohoo.com	New York	New York	4528224962811	0e105e87ab354887305747db9e7eb399	Maestro	40.754754149330779	-73.8888946898177181
10103	2020-01-22 22:41:26	2020-01-22	Mr. Travis Parker DVM	mr.travis.parker.dvm@geemail.com	Louisville	Kentucky	3158445496136132258	a60d7ca686ec06648601b42a4c5e5a32	VISA 16 digit	38.2504179893895966	-85.6515157460771519
10104	2020-01-22 22:50:19	2020-01-22	Dennie Stanton-Yundt	dennie.stanton.yundt@warmmail.com	Athens	Georgia	3431894257695410	b6949f4d959c4af2e0af55e1a9394c05	JCB 16 digit	34.0014581219017487	-83.4324794525861648
10105	2020-01-23 00:17:50	2020-01-23	Maricela Wunsch	maricela.wunsch@geemail.com	Las Vegas	Nevada	6011265333799817213	9ac70e8080a9965d0596b06b0262087c	VISA 13 digit	36.1696027666430879	-115.174370153129473
10106	2020-01-23 00:23:15	2020-01-23	Mr. Paxton Hyatt	mr.paxton.hyatt@woohoo.com	Berkeley	California	4594016821346200	a1b62a7284c0710fd2cd726bdf0b9707	Diners Club / Carte Blanche	37.8715441218434492	-122.232509454887094
10107	2020-01-23 00:39:56	2020-01-23	Yahir Schuppe-Durgan	yahir.schuppe.durgan@warmmail.com	San Jose	California	3096848227484721639	2e9ae3d6ec8f736096fe4704b3abd151	JCB 16 digit	37.3399030447293114	-121.761386575432127
10108	2020-01-23 00:55:47	2020-01-23	Auguste Wyman-Gleason	auguste.wyman.gleason@geemail.com	San Bernardino	California	869952379162901347	ae33c7f6c0c6e88581b39e7ae2063938	Diners Club / Carte Blanche	34.1989564694728685	-117.255810734467957
10109	2020-01-23 00:56:36	2020-01-23	Yadiel Howell	yadiel.howell@geemail.com	San Antonio	Texas	3019197440113046	78191ecfc01c500402f6fd9a73afebeb	Discover	29.4028561236873287	-98.4712061643436556
10110	2020-01-23 01:05:08	2020-01-23	Dr. Alana Crona	dr.alana.crona@woohoo.com	San Francisco	California	561205054828842	575dc573a0433c6bce53c004014e13d6	VISA 16 digit	37.809447411441603	-122.441615611289933
10111	2020-01-23 01:43:08	2020-01-23	Maryjane Schroeder-Heaney	maryjane.schroeder.heaney@geemail.com	New York	New York	180023627841169736	9580aa438e9dc14cce08091b26d97e8d	JCB 16 digit	40.6229039671123004	-73.8647375012643579
10112	2020-01-23 01:56:09	2020-01-23	Hardy Jacobson DDS	hardy.jacobson.dds@geemail.com	El Cajon	California	501893801197455	70387b7f15e14e8589e543a70716e7fc	VISA 16 digit	32.7038351652685506	-117.005828018365065
10113	2020-01-23 02:02:38	2020-01-23	Mollie Renner	mollie.renner@geemail.com	Madison	Wisconsin	3720182756284933	121d74f3a2e97d2b27870261152be56d	Discover	43.1735872622553245	-89.4130981272436713
10114	2020-01-23 02:05:10	2020-01-23	Indiana Pacocha	indiana.pacocha@geemail.com	Chicago	Illinois	060464499102636	13d15fc72e92bce13df86a6e06eef082	Diners Club / Carte Blanche	41.9306631897877935	-87.7225140646595491
10115	2020-01-23 02:26:06	2020-01-23	Mr. Casimer Breitenberg II	mr.casimer.breitenberg.ii@geemail.com	San Francisco	California	4400747974832570	908b380f566d06dfbc3d614c6ea68f7a	Maestro	37.8003933835743311	-122.412730246645395
10116	2020-01-23 02:26:07	2020-01-23	Dot Doyle	dot.doyle@warmmail.com	San Jose	California	3453474789489146	a07397ae8b78869fa29a35865e673946	Maestro	37.342069233749811	-121.752741951517393
10117	2020-01-23 02:58:58	2020-01-23	Aline Pollich PhD	aline.pollich.phd@geemail.com	San Francisco	California	4336881114472366	130a255d86558fb15f20e1dbc2b6fb48	VISA 16 digit	37.7530167825438809	-122.440576237545287
10118	2020-01-23 03:09:05	2020-01-23	Lempi Davis MD	lempi.davis.md@geemail.com	Madison	Wisconsin	3528226824942037624	57e5a5e88915ef553c81ece399757552	VISA 16 digit	43.1260316264789552	-89.4935713126208725
10119	2020-01-23 03:52:04	2020-01-23	Clarinda Daugherty	clarinda.daugherty@warmmail.com	San Francisco	California	3337153302706380024	129cfbbc8fff9beb84475c3b07ec206d	Maestro	37.7867489345581546	-122.422301010484873
10120	2020-01-23 03:54:37	2020-01-23	Justine Conn	justine.conn@geemail.com	Wilmington	North Carolina	3745062679421377	1e40582236f9aaf6664517c747ce33fc	VISA 13 digit	34.1765820802010651	-77.9154388470567767
10121	2020-01-23 04:56:27	2020-01-23	Althea Stanton	althea.stanton@geemail.com	Anchorage	Alaska	4288832264205	0f973c3a90656921539f2c76a260d465	Maestro	61.0866465908225678	-149.362262870988985
10122	2020-01-23 05:23:01	2020-01-23	Mr. Kyan Lakin	mr.kyan.lakin@warmmail.com	Murfreesboro	Tennessee	3337474098486085161	73e0a7a7d0cd353ef735fe12699d9d05	Diners Club / Carte Blanche	35.7675116867411944	-86.4628587472569166
10123	2020-01-23 05:27:41	2020-01-23	Sherree Stiedemann	sherree.stiedemann@warmmail.com	New York	New York	180061853035066552	d86d015cb6dbc8daac8482abefbc35eb	JCB 16 digit	40.7234162146449066	-73.9658177530754273
10124	2020-01-23 05:55:33	2020-01-23	Prentice Huels	prentice.huels@warmmail.com	Denton	Texas	3438984840168059	8263fb8b9c8b306e46735bd5de84a888	Diners Club / Carte Blanche	33.1760903886783893	-97.1781124854587119
10125	2020-01-23 06:18:32	2020-01-23	Fuller Runte	fuller.runte@geemail.com	Omaha	Nebraska	561242351284031	6245f395b063a9ad6b8223ba2d0aaf62	Mastercard	41.2502824899420162	-96.1377527810283112
10126	2020-01-23 06:36:31	2020-01-23	Tressie Block	tressie.block@geemail.com	Raleigh	North Carolina	3528194500424156144	e9d6cf8bc83c0486ec451b2b7bfa7e0e	VISA 13 digit	35.8787291289906918	-78.5473848727934154
10127	2020-01-23 06:53:46	2020-01-23	River Waelchi DVM	river.waelchi.dvm@warmmail.com	Columbus	Ohio	210063895794122645	1853a94d000a07a089be508119bbe1bd	VISA 13 digit	40.0823872117370357	-82.9237528995379876
10128	2020-01-23 07:05:19	2020-01-23	Geralyn Frami	geralyn.frami@geemail.com	Chandler	Arizona	55026072670674208	24f22eddaf0179b87e4caff4554e81d2	VISA 16 digit	33.2262542466722408	-111.851405163796244
10129	2020-01-23 07:43:24	2020-01-23	Nim Lynch	nim.lynch@woohoo.com	Brownsville	Texas	4537860169004941	8101e269a0a5bea0e01c90b76b2f8718	VISA 16 digit	26.0076803077090517	-97.405213846564294
10130	2020-01-23 07:47:40	2020-01-23	Brandin Kuvalis	brandin.kuvalis@geemail.com	Arlington	Texas	3096193241693372804	6551b31c958eb707b96e64ace2ab5736	American Express	32.7830451714124536	-97.1015013481050744
10131	2020-01-23 08:16:01	2020-01-23	Dean Miller	dean.miller@geemail.com	New York	New York	53194461119545796	639664333df437f6d5d6b46be5441f9f	JCB 16 digit	40.6025137430746099	-73.8709712586726965
10132	2020-01-23 08:21:08	2020-01-23	Dr. Evette Ernser DVM	dr.evette.ernser.dvm@geemail.com	Berkeley	California	6011867493808901473	63ee903328e574d3a40685d473410882	VISA 16 digit	37.8369325255981437	-122.265047764675728
10133	2020-01-23 08:24:15	2020-01-23	Luisa Beatty	luisa.beatty@geemail.com	New York	New York	4556504520983999	e68a88e837a1e873994a29c7dd096c4f	Maestro	40.7509606966041034	-73.9381771745521519
10134	2020-01-23 08:28:56	2020-01-23	Ann Schaden-Rippin	ann.schaden.rippin@geemail.com	Burbank	California	501858127778957	0b37639996b828b755df94c8d52b15a9	VISA 13 digit	34.1923572986781608	-118.338592666251216
10135	2020-01-23 08:28:58	2020-01-23	Randall Erdman-Leffler	randall.erdman.leffler@geemail.com	Lowell	Massachusetts	3528894732630128335	a0cee0f6e4e2ee9578fceabe55ccac4c	Diners Club / Carte Blanche	42.6813705665394707	-71.2216487618036638
10136	2020-01-23 09:38:23	2020-01-23	Ruffin O'Reilly	ruffin.o'reilly@geemail.com	Sterling Heights	Michigan	3022079375955327	6266dca03e3362bbfc69545455b1b440	American Express	42.6600119308184844	-83.0399474475227208
10137	2020-01-23 09:46:12	2020-01-23	Elle Pfeffer	elle.pfeffer@geemail.com	Des Moines	Iowa	3088398034886327849	8c1851fe0ec9bfcc4debe7b251c66c8e	American Express	41.5755871917329713	-93.5856602006170988
10138	2020-01-23 10:28:50	2020-01-23	Baron Pfeffer-Graham	baron.pfeffer.graham@geemail.com	Tucson	Arizona	4417400024382	6e7db4012397d284b325288e88e935dc	VISA 13 digit	32.1615686835296444	-110.779259942774104
10139	2020-01-23 10:31:05	2020-01-23	Madonna Schoen	madonna.schoen@warmmail.com	Berkeley	California	3112379864241169939	fbce463d60fda80f33b08e16c4bae142	VISA 16 digit	37.8484518347934653	-122.277747278627317
10140	2020-01-23 10:42:49	2020-01-23	Eugene Lang	eugene.lang@warmmail.com	Berkeley	California	52514500033994003	1aea53696808c790359688e99e97503f	VISA 16 digit	37.825484874083358	-122.277900570938442
10141	2020-01-23 10:46:09	2020-01-23	Kenisha Ullrich-Larson	kenisha.ullrich.larson@woohoo.com	Mesquite	Texas	3337878931371136172	ba6b79f9019477eb44c2dce50266fed9	American Express	32.6850870425622944	-96.4912008333683104
10142	2020-01-23 10:48:19	2020-01-23	Hyman Rutherford III	hyman.rutherford.iii@geemail.com	Berkeley	California	6011848916011362665	3167e2e89cecb8a92a510b66935d3faa	JCB 16 digit	37.8905379410681249	-122.293051095574114
10143	2020-01-23 11:20:42	2020-01-23	Alessandro Anderson III	alessandro.anderson.iii@geemail.com	New York	New York	676394308864779	322283cfb4196a94a2121cad40a56423	Maestro	40.6426014522779724	-74.0099819573935065
10144	2020-01-23 11:26:38	2020-01-23	Sonya Waelchi	sonya.waelchi@geemail.com	New York	New York	3045610195217162	61e4526eae32f71ff5f24badd6739c02	VISA 16 digit	40.6858510598298153	-73.8682448668766796
10145	2020-01-23 11:54:07	2020-01-23	Modena Walker	modena.walker@geemail.com	Centennial	Colorado	6011446711816362101	9b1c500ca63ea4974d8e758f91df1357	Mastercard	39.6213951210532329	-104.908442079870412
10146	2020-01-23 12:05:45	2020-01-23	Carissa Considine	carissa.considine@warmmail.com	Shreveport	Louisiana	6011933775268549226	95c5dbd7caa55c6a9e237f3e5fb1737d	Maestro	32.4378769863169651	-93.7202908338725535
10147	2020-01-23 12:41:59	2020-01-23	Hollis Doyle	hollis.doyle@geemail.com	Oakland	California	869919640214593222	129a5382b93ad8898972dbc29833994d	VISA 16 digit	37.8295972283832498	-122.29919868045215
10148	2020-01-23 12:49:42	2020-01-23	Rebecca Wilkinson-Moore	rebecca.wilkinson.moore@geemail.com	New York	New York	3443549587766481	9fd85d510b3f7baa5673b8c381644bc6	Maestro	40.6043677378669372	-73.8918815979164094
10149	2020-01-23 14:17:25	2020-01-23	Everette Franecki MD	everette.franecki.md@woohoo.com	Los Angeles	California	210066128197069586	57f4cf5e22aea345bd4edef0f96ad513	VISA 13 digit	33.9674204761959615	-118.390818870253113
10150	2020-01-23 15:38:44	2020-01-23	Lenord Schaefer	lenord.schaefer@geemail.com	San Francisco	California	4864680023321890	0f0e4a167c62e870f5e897b427396e0a	Mastercard	37.7773682133691011	-122.421681338030226
10151	2020-01-23 15:53:37	2020-01-23	Dr. Laverne Little Jr.	dr.laverne.little.jr.@geemail.com	Oakland	California	3158354794418341780	d1f1f144d430adc2bddef35de38822d6	JCB 16 digit	37.8171524569987412	-122.278024485869324
10152	2020-01-23 15:56:08	2020-01-23	Athena Mraz	athena.mraz@geemail.com	Berkeley	California	210043407874156934	22325ea2c308be56ec13292b4998cd37	Diners Club / Carte Blanche	37.8413111617899958	-122.225242325612186
10153	2020-01-23 16:06:34	2020-01-23	Ahmad McGlynn	ahmad.mcglynn@woohoo.com	San Francisco	California	4745563258612735	c250dd791f3ce5dcb89e5712881a60ed	Diners Club / Carte Blanche	37.8010391515837654	-122.458692049505515
10154	2020-01-23 16:19:33	2020-01-23	Mrs. Lenore Cruickshank	mrs.lenore.cruickshank@woohoo.com	Grand Rapids	Michigan	3448955313589250	74ec99e76b6312ba3ff76e95a6b85cd4	Diners Club / Carte Blanche	42.9779929190210979	-85.5652558149904081
10155	2020-01-23 16:31:20	2020-01-23	Dr. Mary O'Keefe	dr.mary.o'keefe@warmmail.com	San Francisco	California	4575072684534	b35c589d7f2d81dc07d6eb622ce6d035	Mastercard	37.7759547098866193	-122.493319698753837
10156	2020-01-23 17:41:48	2020-01-23	Memphis Bins	memphis.bins@geemail.com	Baltimore	Maryland	55784954154191233	a974e7a73aff6e0fe83e10e8bdf20826	Maestro	39.308861125539984	-76.5120052377712057
10157	2020-01-23 18:00:20	2020-01-23	Kazuko Goyette PhD	kazuko.goyette.phd@geemail.com	Rancho Cucamonga	California	4998488396805682	35f0212e80bca28952be23b7d11b3ae9	American Express	34.1645294656038274	-117.616035990184912
10158	2020-01-23 18:44:57	2020-01-23	Faron Toy	faron.toy@geemail.com	Chula Vista	California	3744649837823576	27e26c01af434baddf5af67d5ee2d69a	VISA 16 digit	32.6326584073014558	-117.083566020685055
10159	2020-01-23 19:08:21	2020-01-23	Jakob Kulas	jakob.kulas@geemail.com	Antioch	California	869968656658782204	3335ce561fda404acd25164143435775	VISA 16 digit	37.9676231077671105	-121.855126452929156
10160	2020-01-23 19:17:09	2020-01-23	Laci Smith DDS	laci.smith.dds@geemail.com	New York	New York	6011700206910998356	37ea32a1aa0bf4fd0ba6110739823c5d	Discover	40.643004186334089	-73.8676139617234497
10161	2020-01-23 19:32:07	2020-01-23	Adria Olson-Mann	adria.olson.mann@woohoo.com	Indianapolis	Indiana	3528192307105304528	35931f03d966040a23471e3048023683	VISA 16 digit	39.8088379084140058	-86.0778225543178621
10162	2020-01-23 20:03:52	2020-01-23	Brock Nicolas III	brock.nicolas.iii@geemail.com	Port St. Lucie	Florida	4248756701937004	369b1537bab2f8368a72dd534bd60616	VISA 13 digit	27.306070678973942	-80.4425295162100298
10163	2020-01-23 20:11:54	2020-01-23	Etna Mueller	etna.mueller@geemail.com	San Francisco	California	869972402664355931	79d3eeb3eea937cd1f54b6e8f601952b	VISA 13 digit	37.7897613345091514	-122.41664060839588
10164	2020-01-23 20:14:59	2020-01-23	Nicolette Shanahan	nicolette.shanahan@geemail.com	Montgomery	Alabama	3796156183038434	cf4a2f394094b95fc084fe27aa4bae4c	Diners Club / Carte Blanche	32.385657799470053	-86.270763598816842
10165	2020-01-23 20:24:47	2020-01-23	Felicitas Schuster-Denesik	felicitas.schuster.denesik@geemail.com	Eugene	Oregon	4208168663265150	1e94e4e125bfc2efc12fba4fe806bd19	Voyager	44.1158818352695548	-123.144928494420654
10166	2020-01-23 20:41:04	2020-01-23	Schuyler Lueilwitz-Spencer	schuyler.lueilwitz.spencer@geemail.com	Raleigh	North Carolina	4264469550301103	955c5e3283f8300f991bd09a36ff0826	Maestro	35.7965043517895012	-78.5974362809147777
10167	2020-01-23 20:47:07	2020-01-23	Cora Bernier	cora.bernier@geemail.com	Tampa	Florida	6011653588474239039	bd330477447d2cd49c56e1181d05fb74	JCB 15 digit	28.0104501743916394	-82.420534162570533
10208	2020-01-24 04:26:18	2020-01-24	Ennis Koepp III	ennis.koepp.iii@geemail.com	Seattle	Washington	639010961789798	442b3a9a9b3c34f0a3d35322cae98740	VISA 16 digit	47.7094690626412614	-122.298044449641921
10168	2020-01-23 21:18:17	2020-01-23	Jean Hammes-Pfannerstill	jean.hammes.pfannerstill@geemail.com	San Francisco	California	6011593427354881128	6b8956f0f9e28fbb75e37f3f12f82a45	JCB 16 digit	37.8059982716241691	-122.366014418999868
10169	2020-01-23 21:35:54	2020-01-23	Ms. June Dietrich DDS	ms.june.dietrich.dds@geemail.com	Montgomery	Alabama	3454231099500296	7cd81fdb35a378bafae3ccc1bda66dcd	JCB 16 digit	32.4184936044670664	-86.3286694623216988
10170	2020-01-23 21:36:59	2020-01-23	Ivanna Kub PhD	ivanna.kub.phd@warmmail.com	Long Beach	California	4260717996585083	c705e8ca0166f4c57347b55ebb0510da	JCB 15 digit	33.7901654058422878	-118.09894745286293
10171	2020-01-23 21:38:12	2020-01-23	Celestino Conroy	celestino.conroy@woohoo.com	San Francisco	California	3034961070009393	2413a22247318583a5e00fe8ade08405	Maestro	37.8150778803430541	-122.443956814046629
10172	2020-01-23 21:39:25	2020-01-23	Lorenzo Kuhic	lorenzo.kuhic@geemail.com	Charlotte	North Carolina	4202011980113743	88cf33626aa39c181f491ade65ca0d6c	VISA 16 digit	35.1414337384767848	-80.8850859275497527
10173	2020-01-23 21:43:44	2020-01-23	Clemente Schulist	clemente.schulist@geemail.com	Austin	Texas	52956122768914059	132244153e3c1841a47c68d3387d10f6	VISA 13 digit	30.2890743417792017	-97.8342350390046818
10174	2020-01-23 22:20:16	2020-01-23	Mr. Douglas Upton	mr.douglas.upton@geemail.com	San Francisco	California	4137867961496674	3db03c282fc1e9e50f892927ce879be0	Discover	37.7928508602494873	-122.427216135615012
10175	2020-01-23 22:49:30	2020-01-23	Giancarlo Hartmann	giancarlo.hartmann@geemail.com	Bridgeport	Connecticut	6011922857321526491	c7f49667217437f1d3cc1b7cfa34aa1b	American Express	41.1303288961924594	-73.1229707742475057
10176	2020-01-23 22:52:17	2020-01-23	Kristofer Gorczany	kristofer.gorczany@geemail.com	Rancho Cucamonga	California	6011155465441410535	e71a2d38f6e35eb7c8723c63b91aa7d1	Mastercard	34.1099907460615057	-117.507708125888186
10177	2020-01-23 22:58:40	2020-01-23	Miss Shanequa Shields	miss.shanequa.shields@geemail.com	San Francisco	California	3754360100172165	247722a42288748d8df8cd7bec99f925	JCB 16 digit	37.7964982379211563	-122.413692654476804
10178	2020-01-23 23:10:37	2020-01-23	Mr. Laurence Halvorson V	mr.laurence.halvorson.v@warmmail.com	Irving	Texas	503816109942355	5ac40fec4d3a7494e9533554cdd95266	Voyager	32.8964494880240395	-96.9630866491049517
10179	2020-01-23 23:24:17	2020-01-23	Dr. Lera Roberts PhD	dr.lera.roberts.phd@woohoo.com	Abilene	Texas	4309297885298380	263f112135f9c56d5ccc4ad91c10d17f	Diners Club / Carte Blanche	32.3998975784126699	-99.7359363741189213
10180	2020-01-23 23:27:03	2020-01-23	Britt Brown	britt.brown@geemail.com	New York	New York	4943641650612147	94cd03ee4481df3cbc6f1157df3aad2e	VISA 13 digit	40.6161025926694279	-73.9119621402945342
10181	2020-01-23 23:48:22	2020-01-23	Harlen Jones	harlen.jones@woohoo.com	Macon	Georgia	4920282008138407	87f02d4ceabd1fae88681b4f45d595c3	JCB 15 digit	32.8797493401925962	-83.7661926480669479
10182	2020-01-24 00:01:18	2020-01-24	Elyssa Murazik	elyssa.murazik@geemail.com	San Francisco	California	869939582130955562	7e1f244ef20ddb2e25fcf4bc64569e4c	Mastercard	37.7549184402334248	-122.42609777537912
10183	2020-01-24 00:01:50	2020-01-24	Cordie O'Hara PhD	cordie.o'hara.phd@geemail.com	San Francisco	California	502009189810626	43bc0da33ac21f6a6aaa7b7cabf6c36e	JCB 16 digit	37.7822032327187145	-122.397130522814706
10184	2020-01-24 00:02:37	2020-01-24	Laurene Swaniawski	laurene.swaniawski@geemail.com	New York	New York	3039614601471740	ded8e081708cd0a66c20719895db062d	Diners Club / Carte Blanche	40.5795091619472927	-73.888891180035472
10185	2020-01-24 00:10:55	2020-01-24	Treva Barton	treva.barton@geemail.com	San Francisco	California	3158299134114496620	4a4d07d35a704a28cb3a1f971e9e7fa9	American Express	37.7720210710434543	-122.433550948863342
10186	2020-01-24 00:11:00	2020-01-24	Ms. Blossom Schulist DDS	ms.blossom.schulist.dds@geemail.com	St. Louis	Missouri	4401628131327416	68504af78c12fc4a4ec215bcb210c0f3	JCB 15 digit	38.7354304324526311	-90.2049140289429658
10187	2020-01-24 00:16:18	2020-01-24	Mr. Dandre Goldner I	mr.dandre.goldner.i@warmmail.com	San Francisco	California	55747035760359244	144ef777a7a11b4c52b2992d3d23389a	JCB 15 digit	37.7895371211774247	-122.426283499716618
10188	2020-01-24 00:34:28	2020-01-24	Verla Koepp	verla.koepp@geemail.com	Los Angeles	California	3158457214635276822	db26bcef859e73c34c8fa1806aed9b4b	Maestro	34.0377887592516828	-118.426572543009371
10189	2020-01-24 00:38:01	2020-01-24	Johnson Wyman	johnson.wyman@geemail.com	Oakland	California	502049624670797	726e42fd976148dd5b113c3baec5cc0b	JCB 16 digit	37.7803736430859232	-122.284417220509894
10190	2020-01-24 00:39:45	2020-01-24	Lindsay Larson-Weissnat	lindsay.larson.weissnat@geemail.com	Clovis	California	869936062094135827	17a37f779f07be706c67460b2f0c7bcb	VISA 16 digit	36.7408499955076735	-119.735164794379472
10191	2020-01-24 00:56:50	2020-01-24	Dr. Yahir Adams	dr.yahir.adams@geemail.com	Jersey City	New Jersey	3410644467543164	ce0eb2c5b214660d1ca4b15c495abd99	Mastercard	40.7890473048608726	-74.1496148857243469
10192	2020-01-24 01:06:35	2020-01-24	Mel Wyman	mel.wyman@woohoo.com	Detroit	Michigan	060458401160708	be04a32899ad5bfc3cff9801b28a62e9	Maestro	42.3246720906272529	-83.1275772931639096
10193	2020-01-24 01:10:58	2020-01-24	Cap Herzog	cap.herzog@woohoo.com	New York	New York	3112588290058275808	34c7b3bb6aa93660a639a8fd79277565	Discover	40.7348482792023532	-73.9626385833498006
10194	2020-01-24 01:16:29	2020-01-24	Ressie Schroeder DDS	ressie.schroeder.dds@geemail.com	San Francisco	California	210085216763321056	a4a420e8ebad466660e3fc79268a06b8	Maestro	37.7875848764028675	-122.43539862678189
10195	2020-01-24 01:27:00	2020-01-24	Mrs. Unique Armstrong DDS	mrs.unique.armstrong.dds@woohoo.com	Portland	Oregon	210087509230820215	dfd5ec5f190e21605b9a1646683bb1ff	JCB 15 digit	45.5515119444932779	-122.678638928802684
10196	2020-01-24 02:03:27	2020-01-24	Benson Towne	benson.towne@geemail.com	Kansas City	Missouri	54791584063973156	869fd9b2849a0b173af56ae0af225298	Mastercard	39.1194234044127214	-94.6221836060043415
10197	2020-01-24 02:19:33	2020-01-24	Mauricio Keebler	mauricio.keebler@geemail.com	Vallejo	California	3337242601661101587	f8c4a9af87fde7941be3a9f5339cf368	JCB 15 digit	38.0901829949203901	-122.269163454497232
10198	2020-01-24 02:27:11	2020-01-24	Jelani Swift	jelani.swift@warmmail.com	San Francisco	California	54840161775656436	2e147b02792a09b9524d20943a3d5b1d	VISA 13 digit	37.7827992981887633	-122.427227591323557
10199	2020-01-24 02:34:52	2020-01-24	Mr. Garret Fadel MD	mr.garret.fadel.md@geemail.com	Fort Worth	Texas	3418546089152310	ee2e43f032b6d0f04da5059d13a552a1	VISA 16 digit	32.7911168509684501	-97.2771023939650519
10200	2020-01-24 02:38:48	2020-01-24	Kellee Barton	kellee.barton@geemail.com	Berkeley	California	180069011974974318	a94931cf42a9e551e0f46ff2aa9bee42	Diners Club / Carte Blanche	37.8603036346929258	-122.25820062271174
10201	2020-01-24 02:50:55	2020-01-24	Marshall Heidenreich PhD	marshall.heidenreich.phd@warmmail.com	San Francisco	California	4201909554721	68b288bbc7dbcf237a87034f21331f57	VISA 13 digit	37.7524101313894107	-122.437247045014843
10202	2020-01-24 02:59:02	2020-01-24	Trevon Bernier	trevon.bernier@geemail.com	Norfolk	Virginia	589345475955675	ad011aead009b9b6780e72db1e05e4bf	Maestro	36.9268627193775032	-76.337520755455273
10203	2020-01-24 03:01:25	2020-01-24	Miss Vernell Emard	miss.vernell.emard@geemail.com	San Francisco	California	3499047101267089	992c5f382adaca9da05533c21f800030	American Express	37.7733439959784576	-122.432103091756858
10204	2020-01-24 03:20:08	2020-01-24	Hurley Davis	hurley.davis@geemail.com	New York	New York	3009502600735027	fab8f4227ea8fec0a7305b082e5b222c	VISA 16 digit	40.7288603181708595	-74.0313055938471081
10205	2020-01-24 03:35:41	2020-01-24	Pollie Bailey	pollie.bailey@warmmail.com	San Francisco	California	180072057252886117	797269c8d1a9444e28f5792a86a308f1	VISA 13 digit	37.7761059728818438	-122.394106577653929
10206	2020-01-24 03:47:49	2020-01-24	Mrs. Sandy Hane DDS	mrs.sandy.hane.dds@geemail.com	Washington	District of Columbia	3088561361378838400	f88a0bcf3ea9da5780b7d631c36a6a7a	JCB 15 digit	38.951919077363236	-76.9477097652133608
10207	2020-01-24 04:18:38	2020-01-24	Obe Stanton	obe.stanton@geemail.com	Tacoma	Washington	6011856920632398883	882737f67a72e6ed23fc2caee34bafe2	Voyager	47.1901412743262938	-122.450763895665489
10209	2020-01-24 05:23:19	2020-01-24	Carnell Baumbach IV	carnell.baumbach.iv@geemail.com	San Francisco	California	3528782354406791041	caa741157494e2cecc24db99b1258cbd	American Express	37.7921218040960909	-122.480800886407707
10210	2020-01-24 05:38:29	2020-01-24	Docia Kuhn-Steuber	docia.kuhn.steuber@warmmail.com	Phoenix	Arizona	639065461299847	e1d3a7a00150fe782cecf1cad6416726	Discover	33.6250535472694807	-112.135268054429815
10211	2020-01-24 06:08:17	2020-01-24	Alivia Hagenes	alivia.hagenes@geemail.com	Las Vegas	Nevada	589351094371633	b6129997bc40825cc4ac2421279ee6eb	VISA 16 digit	36.2004634583003835	-115.349082394104812
10212	2020-01-24 06:27:09	2020-01-24	Arvil Pacocha-White	arvil.pacocha.white@geemail.com	San Francisco	California	3481549957995713	b66af24e25e3bf9b4303bfe157d003e2	VISA 16 digit	37.799061976087863	-122.427137902876638
10213	2020-01-24 06:41:58	2020-01-24	Ms. Joell Wilderman	ms.joell.wilderman@woohoo.com	San Francisco	California	561216000155966	de4edd89641fb6e0c4125a930a576eb7	JCB 16 digit	37.7670211625692005	-122.420511239754646
10214	2020-01-24 06:44:53	2020-01-24	Sharron Kilback	sharron.kilback@woohoo.com	Wilmington	North Carolina	869942480925595443	09a60af163c72a8eac1ce8f4e74ca136	JCB 16 digit	34.1200478188514751	-77.835518389147893
10215	2020-01-24 07:07:07	2020-01-24	Hurley Greenfelder	hurley.greenfelder@geemail.com	Pembroke Pines	Florida	4316896639010	65cc48fa31261706e2ca083bb6a22467	American Express	25.981441069258377	-80.3673338554702781
10216	2020-01-24 07:08:03	2020-01-24	Jeremie McKenzie	jeremie.mckenzie@geemail.com	Anaheim	California	3052524692740837	970eebac2ef799e68d683d48fd20a3a6	JCB 16 digit	33.848877868644891	-117.856121986566478
10217	2020-01-24 07:16:59	2020-01-24	Jayce Bernier-Halvorson	jayce.bernier.halvorson@geemail.com	Providence	Rhode Island	3096672988045863019	dac4dbd263df103c402712599884548e	Mastercard	41.8719426927011398	-71.362057372453819
10218	2020-01-24 07:23:35	2020-01-24	Carrie McKenzie-Hackett	carrie.mckenzie.hackett@geemail.com	Columbus	Georgia	502026251739574	c9222872034b70d5f44b84caec1c3b9c	Maestro	32.4835467627316703	-84.9170507097314982
10219	2020-01-24 07:40:41	2020-01-24	Amie Conroy	amie.conroy@geemail.com	McKinney	Texas	3047629598208782	010ca63854037f6100a365d63c7c2abc	Maestro	33.2818672496024561	-96.6348900101911283
10220	2020-01-24 07:52:58	2020-01-24	Miss Daniele Gerhold	miss.daniele.gerhold@geemail.com	San Diego	California	3337408365423220115	1b1a1e2e836021a6afacf81f2165489b	VISA 13 digit	32.8885055275700964	-117.099453267632057
10221	2020-01-24 07:55:16	2020-01-24	Docia Russel	docia.russel@warmmail.com	Ventura	California	675971001517540	40b5c1a6d719028f6695a53e74c21672	VISA 16 digit	34.2402305691663216	-119.252570569711551
10222	2020-01-24 08:04:40	2020-01-24	Gabriela Macejkovic	gabriela.macejkovic@woohoo.com	Cedar Rapids	Iowa	4322091615148939	6406ae0e39f2cb9351ce737cd1716b9f	Mastercard	41.9779107200987625	-91.7145205252405304
10223	2020-01-24 08:21:53	2020-01-24	Jalissa Lowe DVM	jalissa.lowe.dvm@geemail.com	San Francisco	California	3404321050916135	dd0f421badb5381c6777f0fb4d2b4f32	Maestro	37.7809159817635631	-122.428727033680318
10224	2020-01-24 08:25:08	2020-01-24	Dr. Orra Labadie DVM	dr.orra.labadie.dvm@geemail.com	San Francisco	California	503856854846161	1316966890a4a6799176f412c0d4fdf0	VISA 16 digit	37.8170965474031107	-122.441332069173498
10225	2020-01-24 08:30:03	2020-01-24	Lenon Murazik	lenon.murazik@geemail.com	Cleveland	Ohio	3112034175542496500	14ab66a77fdeb879c09a7d1bb7a8eb7e	Diners Club / Carte Blanche	41.4670270668659313	-81.767157894815881
10226	2020-01-24 08:32:54	2020-01-24	Cary Langosh PhD	cary.langosh.phd@geemail.com	Montgomery	Alabama	4483296869544833	c406e86976a8daf8241dbb0927fcaf25	Voyager	32.4205145644888262	-86.2742500952132048
10227	2020-01-24 08:41:54	2020-01-24	Miss Viridiana Yundt PhD	miss.viridiana.yundt.phd@geemail.com	San Francisco	California	3528345380522565803	f51143e7c07b1e1601033d4c930c44cf	Diners Club / Carte Blanche	37.755222465411471	-122.434773671933613
10228	2020-01-24 08:52:48	2020-01-24	Harris Ratke	harris.ratke@warmmail.com	Winston–Salem	North Carolina	4557950590049949	4485a26cbe43c86e0137d7c23db9db69	Diners Club / Carte Blanche	36.0268661543957904	-80.3161993733737631
10229	2020-01-24 09:12:20	2020-01-24	Beulah Rippin DVM	beulah.rippin.dvm@geemail.com	Elizabeth	New Jersey	3158648564407099558	5f93693d8e48c4bf32aad013e07d0d9c	Voyager	40.7377586984667985	-74.1993408713433951
10230	2020-01-24 09:12:52	2020-01-24	Leonce Prohaska	leonce.prohaska@warmmail.com	Los Angeles	California	869967309335247115	8e2e4b475de7baf3a07e5fffbf714b88	Diners Club / Carte Blanche	34.0145005022507121	-118.322176823997125
10231	2020-01-24 09:15:41	2020-01-24	Dr. Kiefer King	dr.kiefer.king@geemail.com	Lancaster	California	4118111694667	677f2f992c11a5b788f16b7ecb7f4e63	JCB 15 digit	34.7272680109146989	-118.119493421257658
10232	2020-01-24 10:20:23	2020-01-24	Mr. Esco Yundt II	mr.esco.yundt.ii@geemail.com	Oakland	California	4537573371985878	bd27e46392809d525fa86618b65d60ee	JCB 16 digit	37.7999206595120967	-122.280160002285342
10233	2020-01-24 10:20:58	2020-01-24	Rose Wintheiser DDS	rose.wintheiser.dds@warmmail.com	Los Angeles	California	6011083064917598514	c7262bde124ceb876389bfdd0afdf82c	VISA 16 digit	34.0050726611964365	-118.315149019285286
10234	2020-01-24 11:06:19	2020-01-24	Bree Jenkins	bree.jenkins@geemail.com	Odessa	Texas	3158426376930995881	2fcbc6a7d4cf88a235ec2906b63cb226	American Express	31.9350466321699322	-102.375166757885737
10235	2020-01-24 11:13:01	2020-01-24	Mr. Jermain Wiza Sr.	mr.jermain.wiza.sr.@geemail.com	Lakeland	Florida	3088566983254966610	ba5ea60c871b711bbde8a1d13411f697	Diners Club / Carte Blanche	28.0999098435342312	-81.8901626563515492
10236	2020-01-24 11:56:40	2020-01-24	Jerrica Orn	jerrica.orn@geemail.com	Houston	Texas	3528878736111442396	5e24c2fc0f1c196b8c3113a4a80dbe51	JCB 16 digit	29.8823431904971599	-95.3267381323516361
10237	2020-01-24 11:59:49	2020-01-24	Yaakov Mitchell	yaakov.mitchell@geemail.com	Charlotte	North Carolina	3763839802768767	6e53dfd97615baa12b17a8b9301558d2	JCB 16 digit	35.1603153935886894	-80.7533043488338649
10238	2020-01-24 12:39:12	2020-01-24	Mr. Gladstone Marks	mr.gladstone.marks@woohoo.com	Irvine	California	869934662047933350	7fffdd518ebf68b513019ceb1ff8d6b9	Maestro	33.6360227496378172	-117.826346541104087
10239	2020-01-24 13:21:49	2020-01-24	Florencio Collins-Kling	florencio.collins.kling@warmmail.com	Salinas	California	3112126143213962480	6bb374c481a435778d1bec715ab45e03	Voyager	36.6298065277047442	-121.69246479768195
10240	2020-01-24 13:40:21	2020-01-24	Mrs. Lyn Abernathy	mrs.lyn.abernathy@woohoo.com	New Haven	Connecticut	869945387947076863	0062f1104c550b6a29902ba8a4b4f507	American Express	41.3919223207972919	-72.9744329052977179
10241	2020-01-24 13:44:41	2020-01-24	Laquan Bergnaum	laquan.bergnaum@woohoo.com	Lakewood	New Jersey	3767912358865554	e5a8da2f0e8bbe09180447e43fa2e5b5	VISA 16 digit	40.0163109734006213	-74.2738627015422992
10242	2020-01-24 14:02:40	2020-01-24	Malissie Mayert-Gibson	malissie.mayert.gibson@woohoo.com	New York	New York	4554806820599	317054bd7dac2ea07853964956b4b9eb	Mastercard	40.6697677974347016	-73.9899294793501525
10243	2020-01-24 14:14:44	2020-01-24	Caydence Braun-Huel	caydence.braun.huel@geemail.com	Los Angeles	California	210077100269699530	d298bbda89aae27a909b192635960f4e	American Express	34.1011834679037307	-118.37626116448007
10244	2020-01-24 14:25:03	2020-01-24	Marylyn Hermiston	marylyn.hermiston@warmmail.com	San Francisco	California	4438197030475780	b60ad1a9bcaf4f00743b99cbb605b53c	VISA 13 digit	37.7880955248048735	-122.415543478641055
10245	2020-01-24 14:33:37	2020-01-24	Phillip Tromp-Ernser	phillip.tromp.ernser@woohoo.com	San Antonio	Texas	4978971586521999	34355dbb09fc8c11173e2f23a0ebe1c8	VISA 13 digit	29.4222390407767165	-98.4525573056027241
10246	2020-01-24 14:36:46	2020-01-24	Mr. Max Effertz	mr.max.effertz@warmmail.com	Phoenix	Arizona	55729500084942399	fd81de6c5ab0c288eb371b9492f3d71c	JCB 16 digit	33.5369785925772064	-112.039137155555565
10247	2020-01-24 15:11:23	2020-01-24	Kamilah Gibson	kamilah.gibson@geemail.com	New York	New York	210060474983685938	da8a8d1e955bfb5b3a5b9e6726316829	JCB 15 digit	40.6596296570487326	-73.8998181234940859
10248	2020-01-24 15:13:44	2020-01-24	Colette Kuvalis	colette.kuvalis@geemail.com	Worcester	Massachusetts	3088918886289146352	4a1521a068cf882ee5b71ccc41f20675	JCB 15 digit	42.3528854229655138	-71.7533278562381867
10249	2020-01-24 15:19:27	2020-01-24	Lucindy Cronin-Krajcik	lucindy.cronin.krajcik@geemail.com	New York	New York	869902868020958896	725b17f248de88532a019330756e1114	American Express	40.6793347914926713	-74.0082090586785171
10250	2020-01-24 15:26:44	2020-01-24	Emery Corwin	emery.corwin@geemail.com	Irvine	California	4852527818230618	55092680b8270cc42f838ccbb8451c02	Maestro	33.7109846476946089	-117.848734149198236
10251	2020-01-24 15:34:32	2020-01-24	Renaldo Kertzmann	renaldo.kertzmann@woohoo.com	Dallas	Texas	3112558236951010954	c907b3c9eba11176f355dc905ac10b58	Diners Club / Carte Blanche	32.7430824074234863	-96.7371750993616786
10252	2020-01-24 15:47:09	2020-01-24	Hobert Dibbert	hobert.dibbert@geemail.com	Atlanta	Georgia	3029163829094876	4f8b635d74bc5336b58164c806263646	Voyager	33.6801412555199136	-84.3771159707147689
10253	2020-01-24 16:04:15	2020-01-24	Mr. Michial Bergstrom DDS	mr.michial.bergstrom.dds@geemail.com	San Francisco	California	210065073323528710	1572b08d94344269a691b7a42914df15	JCB 15 digit	37.7798454453589727	-122.415889683692143
10254	2020-01-24 16:14:08	2020-01-24	Marinda Parisian	marinda.parisian@warmmail.com	Lexington	Kentucky	180027553037170112	718a432f84f3b57a33e3988839e23f2e	JCB 16 digit	38.0619422587443168	-84.4793984791628958
10255	2020-01-24 16:40:28	2020-01-24	Dr. Landen Howe	dr.landen.howe@geemail.com	San Antonio	Texas	4671148320474	1012c1d50bbb313f77bef63cb9c2fb55	VISA 16 digit	29.5154041438899952	-98.5850233089480525
10256	2020-01-24 16:45:25	2020-01-24	Christopher Abbott Sr.	christopher.abbott.sr.@woohoo.com	Houston	Texas	210009520929177473	cb4bfd7483dc996401d94c6dd71151b1	American Express	29.8536518251601599	-95.4568370452165595
10257	2020-01-24 16:58:18	2020-01-24	Kadyn Ankunding	kadyn.ankunding@geemail.com	San Diego	California	4614571220704	7bede1bd4f81cc7cdb45a68876b71964	JCB 15 digit	32.7259642362196033	-117.084419113667693
10258	2020-01-24 17:00:23	2020-01-24	Kareen Schoen-Weber	kareen.schoen.weber@geemail.com	San Francisco	California	3029520732777584	25ca7eed53dffe9f086d9e0f578b1018	Mastercard	37.7743571067197763	-122.42875131285119
10259	2020-01-24 17:15:28	2020-01-24	Mateo Brekke PhD	mateo.brekke.phd@geemail.com	Huntsville	Alabama	3158771232520579000	45e8b6d6bd37027b5b951aaf6ad46cb0	JCB 15 digit	34.6104049614407074	-86.5915270637739525
10260	2020-01-24 17:18:33	2020-01-24	Harlow Fisher	harlow.fisher@woohoo.com	Philadelphia	Pennsylvania	869919456121749603	fbd362c9980fc85901afc0b615754797	Maestro	39.969293763391299	-75.2003963815879075
10261	2020-01-24 17:29:55	2020-01-24	Ernst Hermann	ernst.hermann@geemail.com	Albuquerque	New Mexico	4489675838571205	c5f78fdbf6ba87796fecf30d35732b2e	JCB 16 digit	35.0596657586883751	-106.557775567339363
10262	2020-01-24 19:01:34	2020-01-24	Mrs. Kasandra Vandervort	mrs.kasandra.vandervort@warmmail.com	Houston	Texas	3158862911305921970	2e840e75ee177e40bb54b77af1af0fba	Mastercard	29.7184288026377565	-95.3726186892032644
10263	2020-01-24 19:01:59	2020-01-24	Maximillian Lemke	maximillian.lemke@geemail.com	Charlotte	North Carolina	4726866161977308	274c346882ab524f5e067994cd36ab8d	Mastercard	35.2207744659177919	-80.8861255483646033
10264	2020-01-24 19:30:57	2020-01-24	Mrs. Rosena Quitzon MD	mrs.rosena.quitzon.md@geemail.com	Oakland	California	4795272202313197	94872d965062740324e4d054224df4d8	Voyager	37.8133051607857311	-122.244753961560733
10265	2020-01-24 19:31:10	2020-01-24	Melissa Bradtke	melissa.bradtke@warmmail.com	Los Angeles	California	3158920425950317632	db3eb58df7b35fecb89417090358b8db	VISA 13 digit	34.1015146389003831	-118.365950715587658
10266	2020-01-24 19:41:39	2020-01-24	Evangeline Schumm DVM	evangeline.schumm.dvm@geemail.com	New Haven	Connecticut	210021602073024133	f38f943e5b214c83caae37c8707de929	VISA 13 digit	41.3427165215827515	-72.9591721524950145
10267	2020-01-24 20:11:37	2020-01-24	Rayfield Christiansen	rayfield.christiansen@geemail.com	Albuquerque	New Mexico	869931677296743865	bcf4fd59e0a1abe7ef77ddec6bd473e4	VISA 16 digit	35.1706678322184843	-106.729643687333549
10268	2020-01-24 20:35:04	2020-01-24	Josue Mayer-Kunze	josue.mayer.kunze@geemail.com	Fargo	North Dakota	503857584626394	40ebb66547741a01904a08bd68070147	American Express	46.9464079374678462	-96.8144599140584461
10269	2020-01-24 20:37:55	2020-01-24	Glennis Deckow	glennis.deckow@warmmail.com	Charlotte	North Carolina	060443056010135	1b018e77023cce81a9e4c970155729e9	Voyager	35.1315097215373058	-80.8852293709237102
10270	2020-01-24 20:38:50	2020-01-24	Shannon Johnston	shannon.johnston@warmmail.com	San Francisco	California	3158672328537667521	4ed46abdc44ee58209447d4d6c7d0c27	Voyager	37.7527761567066591	-122.444051133644948
10271	2020-01-24 20:39:38	2020-01-24	Celeste Abbott-Hilpert	celeste.abbott.hilpert@warmmail.com	New York	New York	55671264363011511	5c71a6ea97043a946698583576ead0b1	Maestro	40.6291778215430668	-73.846723246005169
10272	2020-01-24 20:42:31	2020-01-24	Dr. Kamya Tromp DDS	dr.kamya.tromp.dds@geemail.com	Raleigh	North Carolina	52550717310317485	6a80bbbc5a7d6ce5304c33e04a8dd3bb	Maestro	35.8233692766301317	-78.7027409058932221
10273	2020-01-24 22:17:47	2020-01-24	Almus Hackett	almus.hackett@geemail.com	San Francisco	California	869946161535096370	62dba8d3139ec16068313dfcd945718b	VISA 16 digit	37.7387768444278819	-122.407517431955227
10274	2020-01-24 23:01:28	2020-01-24	Ama Kling-Kessler	ama.kling.kessler@geemail.com	San Jose	California	6011033038373335430	c1d4f4bbc3c775da1703f1e964cd760c	JCB 15 digit	37.2045311981167686	-121.881017285747077
10275	2020-01-24 23:01:37	2020-01-24	Annette Satterfield	annette.satterfield@geemail.com	San Francisco	California	180045079731810298	beee26f91a50c447fc7b441f8622654e	Maestro	37.8061265038749923	-122.420979395103501
10276	2020-01-24 23:02:01	2020-01-24	Shanda Mraz	shanda.mraz@geemail.com	Indianapolis	Indiana	210020063876765938	471f8143b51829d208f210220e95ee32	JCB 15 digit	39.875479476294295	-86.0523085679128741
10277	2020-01-24 23:10:26	2020-01-24	Daneen Weber	daneen.weber@warmmail.com	Columbus	Ohio	869906692085496287	5b430c79658c81dcb577748bbbd8ed53	JCB 16 digit	40.0770346226681013	-83.0217007335975836
10278	2020-01-24 23:24:23	2020-01-24	Shayna Lowe MD	shayna.lowe.md@geemail.com	Indianapolis	Indiana	210014067864823276	c13cb82945530406fcbfe573e23cc1d2	Diners Club / Carte Blanche	39.847511626827341	-86.0829915963314392
10279	2020-01-24 23:27:36	2020-01-24	Hank Von-Marquardt	hank.von.marquardt@warmmail.com	Oakland	California	3720672213599238	6c4d09f2fae16b85975f51a90e7090ce	JCB 16 digit	37.8099840704063723	-122.307369359435896
10280	2020-01-24 23:59:53	2020-01-24	Lilian O'Reilly	lilian.o'reilly@geemail.com	Lincoln	Nebraska	4426441189305123	77f806c9b3a63cbad468efbe5996b36a	VISA 16 digit	40.897566468456759	-96.5861598367497294
10281	2020-01-25 00:07:54	2020-01-25	Eola Abernathy-Kub	eola.abernathy.kub@geemail.com	San Francisco	California	3419637416586426	a86b1f0af229ff030a64b8b961473441	JCB 15 digit	37.7679644005834305	-122.41487369982147
10282	2020-01-25 00:24:44	2020-01-25	Darin Sanford-Rath	darin.sanford.rath@geemail.com	Boise	Idaho	4986153823173351	88c7432b2b76048fb0fbc4a8904f618f	JCB 16 digit	43.669593046479676	-116.271572533967728
10283	2020-01-25 00:28:01	2020-01-25	Nichelle Wuckert MD	nichelle.wuckert.md@geemail.com	San Francisco	California	3704411868649000	9d51e3e38893cea73361370f3fa5ec2e	Maestro	37.7773959014197089	-122.441639612453088
10284	2020-01-25 00:36:22	2020-01-25	Joselin VonRueden MD	joselin.vonrueden.md@geemail.com	St. Louis	Missouri	4686844196874293	dbcb76a3ce9f2436c52677666e9c4ed6	JCB 16 digit	38.6280761667683734	-90.2791789860468441
10285	2020-01-25 00:51:08	2020-01-25	Isadore Leffler	isadore.leffler@geemail.com	Indianapolis	Indiana	210094695244290056	652abdd0738259a2d0c773dea8134b3e	American Express	39.871127384249867	-86.0946934979610177
10286	2020-01-25 01:00:13	2020-01-25	Brendon DuBuque	brendon.dubuque@woohoo.com	New York	New York	4398971365459652	8627ec0e8cb3d030bdb2780681287f6d	VISA 16 digit	40.7139678144119657	-73.978281425720823
10287	2020-01-25 01:06:55	2020-01-25	Vessie Muller	vessie.muller@geemail.com	Berkeley	California	3711275059861109	764815927de9247c4e59c84473bc5f37	Diners Club / Carte Blanche	37.8757398478313689	-122.280826907476623
10288	2020-01-25 01:07:30	2020-01-25	Karyl Altenwerth	karyl.altenwerth@warmmail.com	Gilbert	Arizona	3493158824614899	bc60b378e32da83ce100a85fdbf39283	Maestro	33.3457014083743104	-111.696315765021737
10289	2020-01-25 02:01:12	2020-01-25	Khadijah Hudson	khadijah.hudson@geemail.com	Chesapeake	Virginia	53071404526597529	b57ff8346def2a4040ecc45add7ce327	VISA 16 digit	36.7656340073566881	-76.2590800761554419
10290	2020-01-25 02:19:38	2020-01-25	Mr. Verlon Stoltenberg Jr.	mr.verlon.stoltenberg.jr.@geemail.com	Oakland	California	3088130585692457073	0a1b37810f0ba9ce6b05e12df349faa4	American Express	37.8138060020599553	-122.251597845710137
10291	2020-01-25 02:21:12	2020-01-25	Electa Braun	electa.braun@warmmail.com	Virginia Beach	Virginia	869978912132284376	6852a2729bcf90c335978df5ef2291c1	JCB 15 digit	36.8742231839057055	-75.9869636570706888
10292	2020-01-25 02:22:03	2020-01-25	Mr. Rahsaan Lubowitz DVM	mr.rahsaan.lubowitz.dvm@geemail.com	McKinney	Texas	869952265273595047	eef570c858a4a57f66cc74cb3a060abd	American Express	33.2645755272023393	-96.7265266526788565
10293	2020-01-25 02:45:59	2020-01-25	Loyce Lemke	loyce.lemke@geemail.com	Santa Ana	California	3337839570348927780	7c500aebf57fa2b7498d0b1a2a6328bb	Diners Club / Carte Blanche	33.7050376352492691	-117.981905553668739
10294	2020-01-25 03:17:59	2020-01-25	Kasey Bradtke	kasey.bradtke@geemail.com	Springfield	Illinois	060481696209279	0fc991d7584f5979f2d687f7efe31e09	JCB 16 digit	39.7125728823397282	-89.7044843719810245
10295	2020-01-25 03:30:40	2020-01-25	Concha Lindgren	concha.lindgren@woohoo.com	Charleston	South Carolina	4792342809957333	fe35b70c663200510528c8fb496c6cfa	JCB 15 digit	32.8924780859142558	-79.9181739805880937
10296	2020-01-25 03:30:51	2020-01-25	Jajuan Stanton	jajuan.stanton@geemail.com	Los Angeles	California	4720770422825	01604c7bc932c072b3c00661aeb1aac1	JCB 15 digit	33.9459855981968346	-118.372047985437504
10297	2020-01-25 03:39:03	2020-01-25	Miss Harlene Effertz PhD	miss.harlene.effertz.phd@geemail.com	Dayton	Ohio	869991796183418709	17779cf74ba1abee59cd014f23ec73d4	VISA 13 digit	39.7864742425527425	-84.2929802101295422
10298	2020-01-25 03:41:22	2020-01-25	Ms. Zelma Hartmann DDS	ms.zelma.hartmann.dds@geemail.com	Albuquerque	New Mexico	51519804447287169	22013cc5ddaa4169e8f22860124f569d	Maestro	35.0780321303423506	-106.72159206318446
10299	2020-01-25 04:06:23	2020-01-25	Ms. Leda Lueilwitz	ms.leda.lueilwitz@geemail.com	San Francisco	California	4765678750018994	938daa13c1593db68cd9f4ef2f0107ac	VISA 13 digit	37.7637103751928862	-122.433556431429011
10300	2020-01-25 04:14:31	2020-01-25	Carri Lubowitz	carri.lubowitz@woohoo.com	Riverside	California	869967487684949802	480a4c99489f36446f72733e0688dc12	VISA 16 digit	33.8882649445854085	-117.478957066449141
10301	2020-01-25 04:17:33	2020-01-25	Jaret Orn	jaret.orn@geemail.com	San Francisco	California	6011731518904690218	7e30730af81342973f700d0414f3406d	Discover	37.7779952178805658	-122.447029101753699
10302	2020-01-25 04:17:41	2020-01-25	Joseluis Armstrong	joseluis.armstrong@geemail.com	San Jose	California	676388543502541	8216799cbaff977d7a8333ca081d5eba	Mastercard	37.3432967179741695	-121.74194477221333
10303	2020-01-25 05:06:10	2020-01-25	Jaslyn Muller	jaslyn.muller@geemail.com	Roseville	California	3096740552608608738	0b323fbdff0b7e5bf2fceb69bc8491a5	Discover	38.7302326597329198	-121.235879723609983
10304	2020-01-25 05:09:53	2020-01-25	Jarrad Orn-Buckridge	jarrad.orn.buckridge@geemail.com	New York	New York	6011242057519189003	24f4ee1cee396ff0d8725e572f05b179	Maestro	40.5995831403173497	-73.9891617690108632
10305	2020-01-25 05:48:12	2020-01-25	Roslyn Bednar	roslyn.bednar@geemail.com	Phoenix	Arizona	4034370562705936	f8ac628a972cf3311659f3e6ad44392f	VISA 16 digit	33.6296390263762319	-112.041462393610189
10306	2020-01-25 06:25:49	2020-01-25	Brooklynn Dach DDS	brooklynn.dach.dds@geemail.com	Newport News	Virginia	52427943721325831	d298734d48204d6087a602f533ad222a	Mastercard	37.0894014851085814	-76.6140286352280526
10307	2020-01-25 06:29:04	2020-01-25	Fredie Torphy	fredie.torphy@geemail.com	Saint Paul	Minnesota	869911867152898341	e431dc22b62ded78a0737a610fad7b19	VISA 16 digit	44.8784169763732734	-93.1898479775790207
10308	2020-01-25 07:20:16	2020-01-25	Markell Hartmann-Hilpert	markell.hartmann.hilpert@geemail.com	Columbus	Ohio	869998101313380890	45197e50f7300b6fea7229b94d7f8812	VISA 13 digit	39.9671182329345456	-83.0714550628561597
10309	2020-01-25 07:39:41	2020-01-25	Tammy Bartell	tammy.bartell@geemail.com	Elk Grove	California	4426164363035	93237a9dc4e131c1f3a496dae48def6a	Diners Club / Carte Blanche	38.4480489733912023	-121.399873907109722
10310	2020-01-25 07:47:44	2020-01-25	Miss Vicky Schumm	miss.vicky.schumm@geemail.com	Indianapolis	Indiana	4792982872073524	5fe144a251210c2ae1c9ccdf1e7abe04	JCB 15 digit	39.7639253410983784	-86.0957699278105082
10311	2020-01-25 07:51:14	2020-01-25	Myrl Romaguera	myrl.romaguera@geemail.com	Oceanside	California	869997183619220575	96be726c76c2836d4091fa81a36394d0	JCB 15 digit	33.2276314101535846	-117.39966632878297
10312	2020-01-25 07:54:01	2020-01-25	Saige Hirthe	saige.hirthe@geemail.com	Waterbury	Connecticut	3337830195200159279	aace8f2191c3b5c40f517b3b4f1151f0	Discover	41.4755329909771717	-73.0127552817024252
10313	2020-01-25 08:16:51	2020-01-25	Ilda Weimann	ilda.weimann@geemail.com	McAllen	Texas	3001785219392151	0a5ac7b19e1455df844386ffa06508de	JCB 16 digit	26.2341070697948311	-98.2752418454117986
10314	2020-01-25 08:46:53	2020-01-25	Almira Wunsch	almira.wunsch@geemail.com	Murrieta	California	4153464923587342	2181caba80d2565b3474b865b0dafd33	American Express	33.4906656133107816	-117.203601860431576
10315	2020-01-25 09:19:45	2020-01-25	Johney Hamill	johney.hamill@geemail.com	Oakland	California	3454496142782148	e612edc3b9a0f721c909a5a2da3d987a	JCB 16 digit	37.8019252055401864	-122.277636553058571
10316	2020-01-25 09:39:52	2020-01-25	Leonel Cassin	leonel.cassin@woohoo.com	Albuquerque	New Mexico	4316845290985750	d7afd102fb430b58e120655138e0da55	Discover	35.0119286826480192	-106.633633832035216
10317	2020-01-25 09:41:47	2020-01-25	Kelsie Hodkiewicz	kelsie.hodkiewicz@geemail.com	Pittsburgh	Pennsylvania	3021337064005148	b6bb11e5fa6f7f7814c7df08946b9a0a	American Express	40.3960317847274197	-79.9141928126741306
10318	2020-01-25 09:56:29	2020-01-25	Lavonia Raynor	lavonia.raynor@geemail.com	Houston	Texas	52807542103112922	2a6bf4187d1fccf9c9227bb518687c45	JCB 16 digit	29.8115379154294722	-95.4235893290039172
10319	2020-01-25 09:59:28	2020-01-25	Mr. Farrell Nitzsche DDS	mr.farrell.nitzsche.dds@geemail.com	Oakland	California	3096465562350835010	590d4a8e682db7def94b1067f5b2665c	Discover	37.805156313180774	-122.228084666088975
10320	2020-01-25 10:01:38	2020-01-25	Harriette Braun	harriette.braun@warmmail.com	Palm Bay	Florida	4601264315784	6e2df135caec3ff2875c57fed2abeef1	JCB 15 digit	27.8914376923203484	-80.6694679176270881
10321	2020-01-25 10:06:40	2020-01-25	Mr. Dejuan Orn	mr.dejuan.orn@warmmail.com	San Diego	California	210017365767758277	c941a019bf2a4fdae55d8738ad7ecf45	JCB 16 digit	32.8627328880663967	-117.08215926605277
10322	2020-01-25 10:13:09	2020-01-25	Kane Schamberger-Emard	kane.schamberger.emard@woohoo.com	West Valley City	Utah	869991970166177851	f429cf8f11cbacc275efb451725027a4	JCB 16 digit	40.6220544346366026	-111.982955008207995
10323	2020-01-25 10:15:32	2020-01-25	Debra Adams	debra.adams@geemail.com	New York	New York	4282425449810876	4c3635d5300f82797d812c234976f832	American Express	40.625774834699925	-73.9520072294294835
10324	2020-01-25 10:34:52	2020-01-25	Linnie Hessel DDS	linnie.hessel.dds@woohoo.com	Carlsbad	California	4983632711466822	dedcb8d38b49df4af352891a56f3512e	VISA 16 digit	33.2235393191628177	-117.210215173687033
10325	2020-01-25 10:38:56	2020-01-25	Belia Bogisich	belia.bogisich@geemail.com	San Francisco	California	51420431849937916	0ab3418d0152bff60a05515b20a5dd3b	Mastercard	37.7683214766718081	-122.401304465667948
10326	2020-01-25 10:53:36	2020-01-25	Marianne Johnson MD	marianne.johnson.md@geemail.com	San Francisco	California	55835354806950764	a07dfdffb4c1a9ba43c405f295919f0c	VISA 13 digit	37.7896345676046863	-122.458174345442131
10327	2020-01-25 10:58:44	2020-01-25	Ms. Leann Blanda	ms.leann.blanda@geemail.com	Knoxville	Tennessee	6011420725573036708	56609ddf0b5ecf1d1c1dd801586a49aa	Discover	36.0694123988103144	-83.9648418442096443
10328	2020-01-25 11:05:28	2020-01-25	Rhoda Kassulke DVM	rhoda.kassulke.dvm@geemail.com	San Antonio	Texas	180027180688159028	f23641bbabe1092844796217410d9225	Diners Club / Carte Blanche	29.5355418483797472	-98.5189928407616833
10329	2020-01-25 11:24:26	2020-01-25	Antwan Lind	antwan.lind@geemail.com	Berkeley	California	3337977038012180435	2d68b1c3b1827dbe1d0fc846e9b1d110	VISA 16 digit	37.8479806638038241	-122.257643020301344
10330	2020-01-25 11:54:29	2020-01-25	Mrs. Eleonore Lesch PhD	mrs.eleonore.lesch.phd@geemail.com	San Francisco	California	630435149782159	e8eeb4db116c922f98ca413d98c79de9	Maestro	37.7700254350679003	-122.410892758460704
10331	2020-01-25 11:54:56	2020-01-25	Dr. Isaac Douglas I	dr.isaac.douglas.i@geemail.com	San Francisco	California	210075660417200004	c94aa81ad3a5dfec9656084916fe360c	Voyager	37.7788567870132255	-122.461566177782913
10332	2020-01-25 12:04:45	2020-01-25	Geoffrey Pollich-Marks	geoffrey.pollich.marks@geemail.com	Berkeley	California	180080856130198128	8196dfd2852ffe6a1cb930f57923d109	JCB 15 digit	37.8748560374226955	-122.275659704371861
10333	2020-01-25 12:18:00	2020-01-25	Kamora Little MD	kamora.little.md@woohoo.com	Nashville	Tennessee	3022195691716100	b557250c40951d66e374c0f6a634929a	VISA 16 digit	36.1991632290773069	-86.7951871632970864
10334	2020-01-25 12:26:23	2020-01-25	Mr. North Abernathy	mr.north.abernathy@geemail.com	Tulsa	Oklahoma	4463093728285771	40d3031cf2e9bec46cb42083648f9861	Maestro	36.0448662357773628	-95.8757684834256736
10335	2020-01-25 13:23:44	2020-01-25	Mrs. Aggie Goyette	mrs.aggie.goyette@geemail.com	Fremont	California	3472725071333749	2e2955a3df51f0aa4bf5fc418e832471	VISA 13 digit	37.5224304062481977	-121.98803536738157
10336	2020-01-25 13:37:38	2020-01-25	Mrs. Anabella Ritchie	mrs.anabella.ritchie@geemail.com	Santa Maria	California	6011381228116323011	b380eadb67c4b20fcfba8a1848bb9169	VISA 16 digit	35.0019540269922445	-120.438296953347688
10337	2020-01-25 13:41:23	2020-01-25	Blanche Zulauf-Morissette	blanche.zulauf.morissette@geemail.com	El Paso	Texas	6011882302481655101	f2e0e6d8f725d9861c8452a8d644e76f	Mastercard	31.9315311531830588	-106.483490781251348
10338	2020-01-25 13:43:17	2020-01-25	Waverly Denesik	waverly.denesik@warmmail.com	New York	New York	4082576628158	453cf6daa675a443d2e2e1c7ceadfd7a	Diners Club / Carte Blanche	40.6288371068183309	-73.8925279512431388
10339	2020-01-25 13:58:38	2020-01-25	Mrs. Kathrine Doyle	mrs.kathrine.doyle@geemail.com	New York	New York	3088628362314147147	20f02f3dd3ae1f347deee860e862e021	JCB 15 digit	40.7066029906030735	-73.874677765731505
10340	2020-01-25 14:04:12	2020-01-25	Mr. Raymon Stiedemann V	mr.raymon.stiedemann.v@warmmail.com	Port St. Lucie	Florida	3015426385119195	41aa17d5c28c6ade09c4b31b6ea45409	Maestro	27.3140364537149658	-80.3184340442616502
10341	2020-01-25 14:25:25	2020-01-25	Mrs. Presley Frami DDS	mrs.presley.frami.dds@geemail.com	Milwaukee	Wisconsin	4040977694094443	546cfcebcbe0ed7746342842fe8bdf32	Maestro	43.1297450007956442	-87.9066417167529437
10342	2020-01-25 14:31:06	2020-01-25	Hollie Rice	hollie.rice@geemail.com	Berkeley	California	869905527605049706	c3257fcf8f4227fb7214e34306501171	VISA 13 digit	37.8630361969947273	-122.261240054854909
10343	2020-01-25 14:40:06	2020-01-25	Dr. Claudio Herman	dr.claudio.herman@warmmail.com	San Francisco	California	6011425610424212192	819f914c5d2348f910a7bd7526cfb41d	Voyager	37.8087013101363283	-122.429931822972122
10344	2020-01-25 14:43:38	2020-01-25	Miss Chantel Pagac	miss.chantel.pagac@geemail.com	Gilbert	Arizona	3795602111001342	595727eb5ad57a0e49ddf2cfaa0f8b44	Diners Club / Carte Blanche	33.3840872841302314	-111.810642655952279
10345	2020-01-25 14:44:19	2020-01-25	Ms. Irene Lehner DDS	ms.irene.lehner.dds@warmmail.com	San Francisco	California	6011869978132588663	f02711c62b7f3ed886b552de561e2b59	JCB 16 digit	37.7661404080599397	-122.413080658025706
10346	2020-01-25 14:44:52	2020-01-25	Zula Schowalter	zula.schowalter@woohoo.com	Norman	Oklahoma	6011475085792013952	159c1b045b04814c177fd17ae2e43935	JCB 15 digit	35.3380612025078378	-97.3393578351728621
10347	2020-01-25 14:54:26	2020-01-25	Dr. Katlin Block	dr.katlin.block@geemail.com	San Francisco	California	6011742756028067353	9c8062469c7ce732f8a18d3ff7561552	VISA 16 digit	37.8150561093908806	-122.42834285886309
10348	2020-01-25 15:00:04	2020-01-25	Solon Howe Jr.	solon.howe.jr.@geemail.com	Memphis	Tennessee	3337766720540326623	1182ef492a6a9a1c93cb3365f3e1ad96	VISA 16 digit	35.1689192919127649	-89.9719535752456636
10349	2020-01-25 15:14:30	2020-01-25	Tenisha Douglas	tenisha.douglas@geemail.com	Washington	District of Columbia	869943525016720018	b405837abf76a97fe3ecc21a5f43d26d	Mastercard	38.9324827204257247	-77.0441345250912093
10350	2020-01-25 15:44:31	2020-01-25	Julianne Lebsack	julianne.lebsack@geemail.com	Santa Maria	California	6011923758157091635	ab3826288256c6d81fdd1e90d779b5a3	Mastercard	34.8399311367951299	-120.46485198288336
10351	2020-01-25 16:07:35	2020-01-25	Mignon Lebsack-Hilll	mignon.lebsack.hilll@warmmail.com	New York	New York	4501135279575	ed3941689f0889766d862a6bcfa1be0a	VISA 13 digit	40.6325134283620883	-73.9701466166775674
10352	2020-01-25 16:56:30	2020-01-25	Gregorio Ebert	gregorio.ebert@geemail.com	Midland	Texas	4983263737584	9e2714f3e750a5cd0136ecf4821359f3	VISA 16 digit	32.0229776720240693	-102.133179107144471
10353	2020-01-25 17:02:09	2020-01-25	Merlene Hilll	merlene.hilll@woohoo.com	New York	New York	210000995192047570	aaae94cb2d0c607c366a4a873342b4ef	Diners Club / Carte Blanche	40.5843614814095162	-73.9227543284546584
10354	2020-01-25 17:04:24	2020-01-25	Dr. Konnor Jast	dr.konnor.jast@geemail.com	Milwaukee	Wisconsin	676167932034548	c67a1a9435f65bc8bf59a266b610b96c	American Express	43.0872095078781214	-88.008560454902053
10355	2020-01-25 17:34:45	2020-01-25	Ms. Delta Ondricka DDS	ms.delta.ondricka.dds@geemail.com	Berkeley	California	3462617299991543	68589e7a412d030435a2d592566af23d	Diners Club / Carte Blanche	37.8473942695235905	-122.252830682958376
10356	2020-01-25 18:25:56	2020-01-25	Leslie Gerhold	leslie.gerhold@geemail.com	Richmond	California	4062781106344260	13738dfa54e9e49a18f35ebc8ea8d9d8	JCB 16 digit	37.861403348804636	-122.445406734463205
10357	2020-01-25 18:40:27	2020-01-25	Mr. Kayson Walter	mr.kayson.walter@woohoo.com	Oakland	California	503854242250428	7f3cce4b6048c49f4a3fcb842bc4a4d3	JCB 16 digit	37.8024384155576385	-122.255152023930378
10358	2020-01-25 19:07:18	2020-01-25	Joellen Yundt-Goodwin	joellen.yundt.goodwin@warmmail.com	Berkeley	California	4774800826037605	fed306e8f7896b69daeffc90e5146d6c	VISA 16 digit	37.8609290641967959	-122.271411850268535
10359	2020-01-25 19:10:48	2020-01-25	Miss Deidra Stark	miss.deidra.stark@geemail.com	Des Moines	Iowa	51997046765600836	d28ebf92ce95667582799ee2f61700dc	VISA 16 digit	41.5696184867270304	-93.7090542315550152
10360	2020-01-25 19:15:46	2020-01-25	Glenda Sporer-Reynolds	glenda.sporer.reynolds@geemail.com	San Jose	California	869920863545990985	6dbf8f222673c28d42a7c35b71efe298	JCB 16 digit	37.2580068522419765	-121.731749146360528
10361	2020-01-25 19:44:10	2020-01-25	Dr. Aletha Wisoky MD	dr.aletha.wisoky.md@woohoo.com	Akron	Ohio	51545988488507029	4931d9f3e4af6930b86781d175ecff76	Maestro	40.9854083575606367	-81.4844610295571385
10362	2020-01-25 19:45:29	2020-01-25	Roland Farrell-Ebert	roland.farrell.ebert@geemail.com	Yonkers	New York	869915343856436065	538e749abdeb6242f786d3c96a12ca74	Discover	41.0329719463564473	-73.8650397870574125
10363	2020-01-25 20:16:21	2020-01-25	Miss Rikki VonRueden	miss.rikki.vonrueden@woohoo.com	San Francisco	California	3337181094079634758	c118d89b8baf5282090e79ab00a4916a	Mastercard	37.7639383745405794	-122.44725349407004
10364	2020-01-25 20:17:57	2020-01-25	Dr. Landyn Kreiger	dr.landyn.kreiger@geemail.com	Wichita	Kansas	3528548688985259416	3cdc15b17598bc2b67e958eb60198b79	JCB 16 digit	37.7388091029942032	-97.3934927977822724
10365	2020-01-25 20:22:51	2020-01-25	Georgiana Rempel	georgiana.rempel@geemail.com	Louisville	Kentucky	676368100945960	53f5e2ecda622c114871dc2c6020f38c	JCB 16 digit	38.2240238976102304	-85.6568195711426483
10366	2020-01-25 20:32:55	2020-01-25	Polk Kautzer	polk.kautzer@geemail.com	Birmingham	Alabama	4115021717027005	c1f7fc38425923d29ef6d0da29175d60	JCB 16 digit	33.5484921995807426	-86.7213427480086807
10367	2020-01-25 20:52:00	2020-01-25	Mrs. Jamie Boyle DDS	mrs.jamie.boyle.dds@geemail.com	Jersey City	New Jersey	3112622261542215823	46f72bc38c075b7c7815cbfee2ab1bd6	Voyager	40.6985365537401265	-74.0454798370089406
10368	2020-01-25 21:07:58	2020-01-25	Deven Altenwerth	deven.altenwerth@geemail.com	Chandler	Arizona	4951056501226006	d5ccf437ba0a418c3b4b2517665e2052	VISA 13 digit	33.288636086098478	-111.781455768493558
10369	2020-01-25 21:13:04	2020-01-25	Ms. Sharleen Cummings DDS	ms.sharleen.cummings.dds@geemail.com	San Francisco	California	4053629102003680	75aa48ebd7a2e393b3093e7d4015b1d6	Discover	37.768996444173915	-122.447856256796982
10370	2020-01-25 21:45:59	2020-01-25	Jayne Waelchi-Windler	jayne.waelchi.windler@geemail.com	Oklahoma City	Oklahoma	6011857339313547826	1b1c1cf5286195dd03c60c732f33a0c8	Mastercard	35.4917293619275114	-97.4615251451160702
10371	2020-01-25 21:50:43	2020-01-25	Acy Stokes	acy.stokes@geemail.com	Oakland	California	210091615282975981	8a8cdfb8e8ce5304de9cd5b7306399bb	VISA 16 digit	37.8141528705949952	-122.267669881632429
10372	2020-01-25 21:53:10	2020-01-25	Alize Conn DDS	alize.conn.dds@geemail.com	Gilbert	Arizona	4345642235476	728a4219df14f30f40a722c2eb2e0df6	VISA 13 digit	33.2759240222975592	-111.832175466291972
10373	2020-01-25 22:41:50	2020-01-25	Dr. Braylon Trantow II	dr.braylon.trantow.ii@geemail.com	Honolulu	Hawaii	060416749991143	4fe6d9e1f72912ff111dfbc01fd7aba3	JCB 16 digit	21.25610498876609	-157.827994809646526
10374	2020-01-25 22:43:34	2020-01-25	Samir Jast-Mayert	samir.jast.mayert@geemail.com	San Francisco	California	4856148356861783	4a262cdcad3a73f6c0c2d4b10b6253e8	Voyager	37.7819948663140437	-122.454575965516412
10375	2020-01-25 22:57:10	2020-01-25	Dr. Pallie Runolfsson	dr.pallie.runolfsson@woohoo.com	Rochester	Minnesota	210083608372708651	af1d795ae96f44d47ab4453507c8ed33	JCB 16 digit	43.9935400349456813	-92.3777370959639512
10376	2020-01-25 22:58:26	2020-01-25	Otto Torp	otto.torp@geemail.com	Chicago	Illinois	4861980693382575	7d1ef330b6dcd6801abb32e7e2e6ee46	JCB 15 digit	41.7718700695153373	-87.7365929888591154
10377	2020-01-25 23:03:36	2020-01-25	Asbury Ferry	asbury.ferry@geemail.com	Oklahoma City	Oklahoma	869996840769980990	4503f8ca577257dc7507d6ac7836b33e	VISA 16 digit	35.4322225112378604	-97.4685891610931634
10378	2020-01-25 23:14:15	2020-01-25	Daniele Goodwin	daniele.goodwin@geemail.com	Albuquerque	New Mexico	3026537269241563	3723466fb85b9a98b52d76c57088d9f1	JCB 16 digit	35.0844613175507689	-106.729678121914716
10379	2020-01-25 23:38:59	2020-01-25	Ennis Lynch	ennis.lynch@woohoo.com	Burbank	California	4684192253656142	66faf5522fa551e85ee24502b19e7c50	Diners Club / Carte Blanche	34.2319151475954797	-118.411421859267733
10380	2020-01-25 23:57:03	2020-01-25	Solon Kiehn	solon.kiehn@geemail.com	Oceanside	California	180023262075160795	6955370b6883fc130c8edf8672a0e9e7	VISA 16 digit	33.3235716595668308	-117.328286465638129
10381	2020-01-26 00:11:31	2020-01-26	Kaci Schamberger	kaci.schamberger@woohoo.com	Oakland	California	4203152676587953	cdb32e8e06bdc035b1138122044ec3e5	VISA 16 digit	37.7852676933893079	-122.284510954631472
10382	2020-01-26 00:24:34	2020-01-26	Thekla Reinger	thekla.reinger@geemail.com	Oakland	California	210078116356017351	9522a68672b0b9ad3d9fd929233b5424	Discover	37.7769751808934231	-122.245377833107653
10383	2020-01-26 00:25:20	2020-01-26	Nelle West	nelle.west@geemail.com	Oakland	California	3008477182389553	8b61b7db2962344db0ddb2aa271b6f1a	VISA 16 digit	37.8184775513549098	-122.30185042672386
10384	2020-01-26 00:55:18	2020-01-26	Kobe Boehm	kobe.boehm@geemail.com	San Francisco	California	55868898104120421	a34a9ed1ed6744115e4a370dcd0e97b9	VISA 13 digit	37.7949865477039424	-122.432435219467536
10385	2020-01-26 01:28:54	2020-01-26	Dr. Clarance Conn	dr.clarance.conn@geemail.com	San Francisco	California	3088205076405711444	e1d1f963a0640b14b98a0c26117866fd	VISA 13 digit	37.7836176203683536	-122.445720615479999
10386	2020-01-26 02:16:36	2020-01-26	Kegan Weber	kegan.weber@geemail.com	Fort Worth	Texas	55007529220179858	e792ee9205930b17356522b40650af93	VISA 16 digit	32.7762173403576043	-97.4077890109091982
10387	2020-01-26 02:16:41	2020-01-26	Vanesa Welch	vanesa.welch@geemail.com	Oakland	California	869955890211162712	5f5b4f67c733329cf6c96886ee619cbd	Discover	37.8209076309496552	-122.280338437281657
10388	2020-01-26 02:25:09	2020-01-26	Jabez Paucek	jabez.paucek@geemail.com	Fremont	California	4840302577250362	af9c61e93317a395ae5b826b50cf0f89	VISA 16 digit	37.471681820664557	-121.923225704951946
10389	2020-01-26 02:32:13	2020-01-26	Floy Schaefer	floy.schaefer@geemail.com	Oakland	California	561213096379683	28cb577385de4567c90c3962f41c7781	Voyager	37.8075892739254869	-122.311720261638925
10390	2020-01-26 02:32:50	2020-01-26	Mr. George Mayer	mr.george.mayer@geemail.com	Philadelphia	Pennsylvania	54721669104436092	8d7a45cab041521187e4c54197f639c7	Voyager	39.9760798472404488	-75.1279474082767962
10391	2020-01-26 02:35:24	2020-01-26	Jerilyn Strosin	jerilyn.strosin@geemail.com	Durham	North Carolina	4988438709211872	15edb0df3e1a5548dbdcc39354962895	American Express	36.0477938257869326	-78.9704575308036141
10392	2020-01-26 03:02:13	2020-01-26	Sammy Barton-Wiza	sammy.barton.wiza@geemail.com	Lewisville	Texas	589389624143338	02cac0913855e04cceab605213cfc1ba	JCB 16 digit	33.1270163916967775	-97.079383032445989
10393	2020-01-26 03:04:44	2020-01-26	Kiara Bartoletti	kiara.bartoletti@geemail.com	San Francisco	California	6011523895576509229	c658e1f36f6def382c98ee750347aa7f	Voyager	37.7704687937093126	-122.427606019090405
10394	2020-01-26 03:10:35	2020-01-26	Haley Deckow	haley.deckow@geemail.com	San Francisco	California	180028236827658608	3172e6d81e739d68c672ad10fc39e953	VISA 13 digit	37.778176184001353	-122.43038662292318
10395	2020-01-26 03:21:44	2020-01-26	Shae Labadie	shae.labadie@warmmail.com	Salt Lake City	Utah	3528452808325588886	21551ba4c7be0101234c225a90f80f90	Discover	40.7392408228158942	-111.948071731341997
10396	2020-01-26 03:31:03	2020-01-26	Daryn Dibbert	daryn.dibbert@geemail.com	Berkeley	California	3096029580301463798	91d686b4eb8848cc42ea07ccf5fcafc7	JCB 16 digit	37.855541863403964	-122.241293272277673
10397	2020-01-26 03:45:33	2020-01-26	Zona Berge	zona.berge@geemail.com	San Francisco	California	3112170863277016395	f2b09f39730a1a1457c60a574151b2bd	Mastercard	37.748872058895202	-122.458422751212694
10398	2020-01-26 03:48:58	2020-01-26	Geno West MD	geno.west.md@geemail.com	Chattanooga	Tennessee	561203624106500	0a0e29773b7eaceedc00c289c574e772	American Express	35.0958621824011203	-85.2690645558588187
10399	2020-01-26 04:13:22	2020-01-26	Darrien Dooley I	darrien.dooley.i@woohoo.com	Chicago	Illinois	4021162219378	f623625aee0f01435a7648f293fc8131	VISA 13 digit	41.7450315364938263	-87.6164740301232712
10400	2020-01-26 04:16:35	2020-01-26	Delta McGlynn	delta.mcglynn@geemail.com	San Francisco	California	180012906381538192	d4569bbf6f6a6d5006f774573417d348	VISA 16 digit	37.7337213772905358	-122.388886857331229
10401	2020-01-26 04:22:45	2020-01-26	Frankie Yundt	frankie.yundt@geemail.com	New York	New York	4682438967875235	879d7823c7e43c98567e4311e9137a13	VISA 13 digit	40.5929412678107582	-73.9985453763406724
10402	2020-01-26 04:24:52	2020-01-26	Cari Bogisich DDS	cari.bogisich.dds@woohoo.com	Greensboro	North Carolina	3337470342298010643	3eaae039954902e2ef79b52c9cf7a301	VISA 16 digit	36.0767866807173974	-79.9003633943367788
10403	2020-01-26 04:42:04	2020-01-26	Perri Raynor	perri.raynor@geemail.com	San Francisco	California	4455287493601	392f5b54b026ae69c9347bc7cbfbf404	JCB 16 digit	37.7521971657601938	-122.37011431338442
10404	2020-01-26 04:47:32	2020-01-26	Dr. Derl Kertzmann	dr.derl.kertzmann@geemail.com	Springfield	Missouri	6011896757306317258	fa2c10b81751441642aae1cc76f0228c	JCB 15 digit	37.2656716111775523	-93.3368244095064767
10405	2020-01-26 04:48:03	2020-01-26	Hyman VonRueden	hyman.vonrueden@woohoo.com	Reno	Nevada	869990607072154852	d22284acb5d0bc47bb103a428857050e	VISA 16 digit	39.5937248364634868	-119.843840189061694
10406	2020-01-26 05:01:35	2020-01-26	Dema Gerhold-Tillman	dema.gerhold.tillman@geemail.com	Berkeley	California	6011376319063999502	f6fd51a165296e4c99e938de3ef3e4e3	VISA 16 digit	37.8518980752439802	-122.272799372048937
10407	2020-01-26 05:16:15	2020-01-26	Durwood Quitzon-Blick	durwood.quitzon.blick@geemail.com	Bakersfield	California	6011246576427913739	bcfec7d9a1b5cd6abd29ad1363827226	Mastercard	35.3332815391186585	-118.994154590907684
10408	2020-01-26 05:43:13	2020-01-26	Judge Hamill	judge.hamill@warmmail.com	Portland	Oregon	3088158118749955845	33299dc737277561c5e1695b47878218	VISA 16 digit	45.5605471303109084	-122.609244520124051
10409	2020-01-26 05:55:55	2020-01-26	Yaretzi Ebert	yaretzi.ebert@warmmail.com	Athens	Georgia	3792185484868342	4357ec96e3929253bacc3bf31f3bd5f5	American Express	33.960052828602862	-83.4399590707033809
10410	2020-01-26 06:18:18	2020-01-26	Shirlee Corkery MD	shirlee.corkery.md@geemail.com	San Francisco	California	3468534749657794	4e6b56182d64f1127efd6831a8d21846	Maestro	37.8056727020951797	-122.462551458986866
10452	2020-01-26 16:56:16	2020-01-26	Mila Armstrong	mila.armstrong@warmmail.com	Oakland	California	3049556280408669	8e2c18ca58d0d9bd3eaf4c709a4b33bf	VISA 13 digit	37.7932117441487421	-122.266190574227252
10411	2020-01-26 06:20:30	2020-01-26	Chelsey Thiel-Harvey	chelsey.thiel.harvey@geemail.com	Raleigh	North Carolina	3445091995775596	3102f1988804a49d8111ac3981750707	Mastercard	35.7819114815112158	-78.583719741686437
10412	2020-01-26 06:26:28	2020-01-26	Lauretta Dickinson	lauretta.dickinson@warmmail.com	San Francisco	California	53790304819823691	948500225a17ded0e400f9e011bba62b	JCB 16 digit	37.7943579999777981	-122.431951756405411
10413	2020-01-26 06:31:43	2020-01-26	Dr. Zeta Harvey	dr.zeta.harvey@geemail.com	Hampton	Virginia	502008866173761	31b9b1dae98dddc3abe000da8bedb75c	Maestro	37.0248131812568744	-76.2907643664259467
10414	2020-01-26 06:56:58	2020-01-26	Val Sawayn-Abbott	val.sawayn.abbott@warmmail.com	Philadelphia	Pennsylvania	4868137036778	cf3bc4ec7f38ccb06a852bd1d222d293	Mastercard	40.019722631988671	-75.2306050480242874
10415	2020-01-26 06:57:13	2020-01-26	Arietta Sporer-Moore	arietta.sporer.moore@geemail.com	San Francisco	California	869980000040865720	28f4c6d9fe5bc178769a230e1063d342	Maestro	37.752748835242592	-122.38952011817095
10416	2020-01-26 06:58:43	2020-01-26	Wilhelmine Tromp	wilhelmine.tromp@geemail.com	San Francisco	California	180043403602133568	35a0eb6d1894582587044930017a4ff3	VISA 16 digit	37.746587147715978	-122.440555230432352
10417	2020-01-26 07:00:44	2020-01-26	Raven Daugherty	raven.daugherty@geemail.com	Moreno Valley	California	180013403792792997	9fad744a4ec6daf05a3b5cffe67fd86a	VISA 13 digit	33.8253136768463989	-117.179892708265029
10418	2020-01-26 07:09:37	2020-01-26	Iesha Hagenes	iesha.hagenes@geemail.com	Riverside	California	6011264514300026599	63692851a7bb571b3cb5e8f41961177d	JCB 16 digit	33.9360736720677423	-117.415556160217889
10419	2020-01-26 07:18:10	2020-01-26	Dr. Jayden Larkin	dr.jayden.larkin@geemail.com	Columbus	Ohio	4927570493171435	efb16b0d01aa3928fd2456777458ceda	VISA 16 digit	39.8875783913347846	-82.9044852625813462
10420	2020-01-26 07:34:59	2020-01-26	Dr. Ferd Wunsch PhD	dr.ferd.wunsch.phd@warmmail.com	Amarillo	Texas	3337442491972241332	18ae66e33270c30f0e80154a68abe1da	Maestro	35.1232080641832169	-101.760968427485608
10421	2020-01-26 07:45:20	2020-01-26	Arthor Ebert V	arthor.ebert.v@geemail.com	New Orleans	Louisiana	3096834682522223392	f6b683af36dfaf87e732ed351bd6ce85	Discover	30.008675745643302	-90.0205529445577355
10422	2020-01-26 07:51:44	2020-01-26	Cherrie Dibbert	cherrie.dibbert@woohoo.com	Houston	Texas	51068964438053338	e8dc3d8552861ff8619374784746fa74	Voyager	29.7215924908485256	-95.3614139012075981
10423	2020-01-26 07:53:36	2020-01-26	Dema Daugherty	dema.daugherty@warmmail.com	Fayetteville	North Carolina	3444097652722335	7918e7ac8dd6e6b8d2252c6664bc94ef	JCB 15 digit	35.018387272280826	-79.0444497067146017
10424	2020-01-26 07:54:56	2020-01-26	Desmond Waelchi	desmond.waelchi@warmmail.com	Anchorage	Alaska	4766924390377856	2dd4a8d287cca9bbc90e7c9051d5af1f	Voyager	61.2004386922095023	-149.34644102129451
10425	2020-01-26 08:32:59	2020-01-26	Erick Marquardt	erick.marquardt@geemail.com	San Francisco	California	4553283902400905	c497751299df26cbb7aaae891988d5c2	Voyager	37.7900052689063273	-122.438230990538059
10426	2020-01-26 09:35:02	2020-01-26	Mr. Eber Stanton DDS	mr.eber.stanton.dds@geemail.com	Mesa	Arizona	4353584049649540	a30e517fa2ef30ca04ee40a3cd96e44e	Mastercard	33.4178866884816443	-111.658054397662724
10427	2020-01-26 10:11:12	2020-01-26	Phillip Kunde	phillip.kunde@woohoo.com	Indianapolis	Indiana	3337615149557844372	2bc337418c0b4eb8959d438584a7ba7c	Discover	39.7585949353415486	-86.1224075412578856
10428	2020-01-26 10:15:26	2020-01-26	Mr. Rex Gleason	mr.rex.gleason@warmmail.com	Boston	Massachusetts	3027572072812267	ad45c907c38b0943f98bc37b4f78c79e	Diners Club / Carte Blanche	42.2822830748911969	-70.9814272467929896
10429	2020-01-26 10:42:04	2020-01-26	Malissa Pacocha	malissa.pacocha@woohoo.com	San Diego	California	3088727299124827296	4fdc03eaf48bae746e350b2ca4898656	JCB 15 digit	32.9149736703906228	-117.197318347999826
10430	2020-01-26 10:44:11	2020-01-26	Saverio Schroeder	saverio.schroeder@geemail.com	Salem	Oregon	55858288599369380	2aac890b06db88c3fa17189b1c0c77b5	Mastercard	44.9038332200411645	-122.961869260358441
10431	2020-01-26 11:02:42	2020-01-26	Sena Stracke	sena.stracke@geemail.com	Stamford	Connecticut	3158946144238818804	609d440e38aef48da2e238b148a11bf1	VISA 16 digit	41.1466116243392221	-73.5672279040832109
10432	2020-01-26 11:15:48	2020-01-26	Clevie Veum	clevie.veum@geemail.com	Honolulu	Hawaii	4073236375002047	497c62a9a229e48e612f63b95583271b	JCB 16 digit	21.2656401036523306	-157.929890051551524
10433	2020-01-26 11:20:34	2020-01-26	Michial Wilderman-Krajcik	michial.wilderman.krajcik@warmmail.com	Dallas	Texas	3032366816987088	e743ae162a341cea8c9327a8ad750724	American Express	32.8128104608777917	-96.7199643989056312
10434	2020-01-26 11:29:07	2020-01-26	Dr. Harrell Wilkinson	dr.harrell.wilkinson@geemail.com	Los Angeles	California	676354154595653	44ff64193513e172b1bf497218591649	VISA 16 digit	34.1007317309133668	-118.459337979600946
10435	2020-01-26 11:34:02	2020-01-26	Guthrie Ziemann	guthrie.ziemann@geemail.com	Philadelphia	Pennsylvania	3406376234919197	ce3162ce54b19c6b7ca9f0c82c4474c3	Mastercard	39.9452964028768207	-75.1448777845960194
10436	2020-01-26 11:35:25	2020-01-26	Mr. Florian Oberbrunner	mr.florian.oberbrunner@geemail.com	San Francisco	California	3112053661416185689	d65749174fa31101534aa07cd6142fcb	Mastercard	37.7595161204151637	-122.443486285608003
10437	2020-01-26 12:09:44	2020-01-26	Nanna Murphy	nanna.murphy@geemail.com	New York	New York	3463239110523204	8aca52414da3998b12256c0fdb150fed	JCB 15 digit	40.6268970131166256	-73.8570601865079226
10438	2020-01-26 12:13:51	2020-01-26	Nolie Dickinson	nolie.dickinson@geemail.com	Clearwater	Florida	4280174425809	2cb2515dc863404de027b1a555ce75fd	Voyager	28.0184597782917315	-82.7140399799946664
10439	2020-01-26 12:31:16	2020-01-26	Augustus Hoeger	augustus.hoeger@woohoo.com	San Francisco	California	180077237293302580	20548990330425c2f1c0f42c909f171a	VISA 16 digit	37.7902310585741006	-122.425779337547851
10440	2020-01-26 13:11:14	2020-01-26	Nikolas Graham	nikolas.graham@geemail.com	Providence	Rhode Island	3158517840367580698	6b3c162259489f6c5ee4ff937a06efbc	American Express	41.8435947000835071	-71.4440509324345783
10441	2020-01-26 13:16:01	2020-01-26	Yasmine Lynch	yasmine.lynch@geemail.com	San Francisco	California	53198488159759082	0cf7f0621c09a0c4ae692e61a13f0bd3	VISA 13 digit	37.760633999120877	-122.409998835269207
10442	2020-01-26 13:21:42	2020-01-26	Mr. Tommie McKenzie	mr.tommie.mckenzie@warmmail.com	New York	New York	52908906895222967	5c829384c3ccfff0da7f00c91d26035c	JCB 16 digit	40.6176693170089251	-74.0029995420377702
10443	2020-01-26 13:31:10	2020-01-26	Davian Beer	davian.beer@geemail.com	Detroit	Michigan	52536698348240411	cce3bb697d4483ef10ac687dd847f6e9	JCB 15 digit	42.3059512209538369	-83.1197866089295587
10444	2020-01-26 14:25:10	2020-01-26	Ms. Zelma Miller	ms.zelma.miller@geemail.com	Richmond	Virginia	210072489286723570	c52e73a3750a69d503e7ca458b1160a0	Voyager	37.4534206469763049	-77.4992592500746298
10445	2020-01-26 14:34:14	2020-01-26	Lue Carroll	lue.carroll@geemail.com	Henderson	Nevada	3464911964907407	7a62b51b982197646652b2b913d89807	Mastercard	35.9503935325358057	-115.054773891919112
10446	2020-01-26 15:04:00	2020-01-26	Natosha Lowe	natosha.lowe@woohoo.com	Boise	Idaho	869962656170734747	fe793043a277b4625d694437390251c1	VISA 16 digit	43.6108783516705074	-116.228534158478311
10447	2020-01-26 15:39:01	2020-01-26	Rosalie Larson PhD	rosalie.larson.phd@geemail.com	New York	New York	3785447094058014	cfc792a9fb76590c144486863031ab57	VISA 16 digit	40.6962216631267211	-73.984937361291415
10448	2020-01-26 15:40:56	2020-01-26	Juli Kessler	juli.kessler@warmmail.com	Reno	Nevada	869903272407106253	8af9653e923c0523a47ba9a81a9ed8a3	VISA 16 digit	39.5875436828549994	-119.846315042132147
10449	2020-01-26 16:04:11	2020-01-26	Pinkey Trantow	pinkey.trantow@geemail.com	Nashville	Tennessee	3710629928378482	d557790e1bc2991d7adf5eaaaf759253	VISA 13 digit	36.1254275038029959	-86.7241467324923718
10450	2020-01-26 16:20:01	2020-01-26	Dr. Almira Kovacek DDS	dr.almira.kovacek.dds@geemail.com	New York	New York	180065724460044941	2822886259173e256491d98777f01be5	VISA 16 digit	40.7099411832857854	-74.0003018885746542
10451	2020-01-26 16:46:09	2020-01-26	Destini Friesen-Funk	destini.friesen.funk@warmmail.com	Oakland	California	3528837582878011093	152c63394d71cbd285330f41375e972a	VISA 16 digit	37.8241596676764686	-122.265685364433878
10453	2020-01-26 17:13:08	2020-01-26	Avah Windler	avah.windler@geemail.com	Orlando	Florida	3158756354910022281	97d63f08d40cd6978c217501c8bdffd5	Discover	28.3924752633351822	-81.3328584635131051
10454	2020-01-26 17:26:14	2020-01-26	Ferris Predovic	ferris.predovic@geemail.com	Fort Worth	Texas	54394957065290053	6702fcd34178a96e824f460885f8a87f	VISA 16 digit	32.8660473516732452	-97.3027502067208303
10455	2020-01-26 18:06:38	2020-01-26	Bryan Jaskolski	bryan.jaskolski@geemail.com	Madison	Wisconsin	4196085494769	3f0d2b87e9deed1a4fae26b58a301bfe	VISA 13 digit	43.0366278027158273	-89.4930870439276163
10456	2020-01-26 18:20:37	2020-01-26	Jenni Stokes	jenni.stokes@geemail.com	New York	New York	4444870909690638	b466e67c9ace8b09131acfdde4611840	JCB 16 digit	40.6907638188209404	-73.9059322169411956
10457	2020-01-26 18:36:11	2020-01-26	Jarrad Nikolaus	jarrad.nikolaus@geemail.com	Garden Grove	California	503811921980535	807b8d67d4e15c6d650b871134b2ff57	JCB 16 digit	33.8324099168471975	-117.991327939882865
10458	2020-01-26 18:53:05	2020-01-26	Ignacio Johnston	ignacio.johnston@geemail.com	Hillsboro	Oregon	6011664336091444773	5da0f537da90929b41b7097860759a3e	Diners Club / Carte Blanche	45.4885603734496939	-122.995898879474765
10459	2020-01-26 19:07:24	2020-01-26	Ethelbert Schoen	ethelbert.schoen@geemail.com	Plano	Texas	180078976834790212	ec3eaf0c0658823f2cd571b4660dbf83	Maestro	33.1198285977907503	-96.7480640021801008
10460	2020-01-26 19:14:53	2020-01-26	Lucian Wisozk	lucian.wisozk@geemail.com	Long Beach	California	3528531236667728305	9734bf586b3fc9dc7b6558ea34ff68c8	American Express	33.7689854714840649	-118.201034784752125
10461	2020-01-26 19:29:01	2020-01-26	Tobin Streich-Denesik	tobin.streich.denesik@geemail.com	New York	New York	3018577409988093	46d8bc6c791d9c1f20a06f092e501ed0	JCB 16 digit	40.653701905881988	-73.9739265486028046
10462	2020-01-26 19:34:34	2020-01-26	Lilyan Ratke	lilyan.ratke@warmmail.com	Boston	Massachusetts	4933156663627729	32772e572431cb2bf1bc07623e37002d	Voyager	42.4293819361999667	-70.9793718969866632
10463	2020-01-26 19:36:41	2020-01-26	Iris Schaden-Cummings	iris.schaden.cummings@geemail.com	Albuquerque	New Mexico	52599131344407358	46ff6e898137765040f3c883e859b55b	JCB 16 digit	35.1762039270851758	-106.701338059136276
10464	2020-01-26 20:03:54	2020-01-26	Lula Watsica	lula.watsica@geemail.com	Waco	Texas	3088233585126959104	033a9470abcf0a3165bfd1358f2c0626	American Express	31.6261203997045754	-97.2552684288136788
10465	2020-01-26 20:14:58	2020-01-26	Kieran McDermott	kieran.mcdermott@geemail.com	New York	New York	4377887585588	7419c1dcbea413309970d1e228772b31	JCB 16 digit	40.6430678846538029	-73.8983985234413296
10466	2020-01-26 20:37:06	2020-01-26	Lola Dach MD	lola.dach.md@geemail.com	New York	New York	869930048842557681	6ec8c122557a27d12563fb9e04bcc91f	Diners Club / Carte Blanche	40.730381402907895	-73.9944357664685697
10467	2020-01-26 21:05:54	2020-01-26	Brianne Ward	brianne.ward@geemail.com	Memphis	Tennessee	4114388484565744	80a9c2711773f97fc17d9ce7dee95289	American Express	35.0289916415300269	-90.0472082605376869
10468	2020-01-26 21:25:04	2020-01-26	Clytie Ledner DVM	clytie.ledner.dvm@geemail.com	Oakland	California	6011460328878037637	b71f461e3be90fc4076357869d483ade	JCB 15 digit	37.8029001335900645	-122.311693014025735
10469	2020-01-26 21:52:26	2020-01-26	Liam Schinner	liam.schinner@geemail.com	Long Beach	California	3723544163754948	9fea90682913a3b6dca49e0d0318b09f	American Express	33.7175437901455908	-118.155329916549093
10470	2020-01-26 21:56:19	2020-01-26	Brittnee Hintz	brittnee.hintz@geemail.com	San Francisco	California	3050787641806098	517b7f7ac0f44fe51bce4acf707b96bc	VISA 16 digit	37.780013219064756	-122.459364749126706
10471	2020-01-26 22:01:36	2020-01-26	Levy Quigley	levy.quigley@geemail.com	Los Angeles	California	4714539578407	28ed3581944a2570f6f29047f0b74786	Discover	33.9772162744175645	-118.468613048269589
10472	2020-01-26 22:32:54	2020-01-26	Neveah Blanda	neveah.blanda@woohoo.com	Kent	Washington	3158910395953479907	e241eaa624cf05ab4a7d1c5039d70658	Discover	47.3056099539734376	-122.153186584091557
10473	2020-01-26 22:54:48	2020-01-26	Dimple Schroeder	dimple.schroeder@geemail.com	Cape Coral	Florida	180031469706607348	7472732c8ebc4fc745e0c6015ad1e787	VISA 16 digit	26.7410271713946024	-82.0337160814158608
10474	2020-01-26 23:04:49	2020-01-26	Floy Kemmer	floy.kemmer@geemail.com	Detroit	Michigan	180084731962487392	d9f4c4ec537066f9834ccc7043bb74d4	VISA 16 digit	42.478159258274367	-83.0061940448943432
10475	2020-01-26 23:12:50	2020-01-26	Cass Hettinger	cass.hettinger@woohoo.com	Austin	Texas	3486420115156140	846787a15a07f255c28974837690eba4	American Express	30.3631789045069347	-97.7800953859701849
10476	2020-01-26 23:28:01	2020-01-26	Frona Grimes	frona.grimes@geemail.com	Lewisville	Texas	3112746109088928153	3c83e6f78f655d30045776016742a06a	JCB 16 digit	33.0710321381207564	-97.036922221400971
10477	2020-01-27 00:00:36	2020-01-27	Telly Bednar	telly.bednar@geemail.com	San Francisco	California	503896698847025	2e4a20d0773df55b17a967273a8623da	Maestro	37.7663954237122681	-122.435166721149841
10478	2020-01-27 00:21:10	2020-01-27	Carlos Dibbert	carlos.dibbert@warmmail.com	New York	New York	3045774042989181	acbf297d50998b01d9ee055ae12271be	Maestro	40.5777610925249732	-73.8555758804909885
10479	2020-01-27 00:36:28	2020-01-27	Carter Hoppe	carter.hoppe@geemail.com	Oakland	California	53373035642209873	06fe916f1298150a7192edd8ade1de4d	VISA 16 digit	37.8210050589697886	-122.273225412640429
10480	2020-01-27 00:47:12	2020-01-27	Haleigh Nicolas	haleigh.nicolas@geemail.com	Oakland	California	3158826842063524315	362f5c7c3c2c9ab137d20faf082cf563	American Express	37.797218398592932	-122.276616013206109
10481	2020-01-27 01:18:42	2020-01-27	Mr. Perley Nitzsche DVM	mr.perley.nitzsche.dvm@geemail.com	Madison	Wisconsin	3112064658890083700	f4307ba764c13a7dd1789cbd0e9b637c	Discover	43.088528549575436	-89.3861725602183554
10482	2020-01-27 01:24:01	2020-01-27	Jalyn Rosenbaum MD	jalyn.rosenbaum.md@geemail.com	Oakland	California	060449278919490	7f938461e34cc8e0d06b8d1661586cb9	VISA 16 digit	37.8219197505667211	-122.267353593715114
10483	2020-01-27 01:58:50	2020-01-27	Dr. Winnifred Daugherty	dr.winnifred.daugherty@geemail.com	San Francisco	California	3012610460786969	feec3c4b1a21591fd04b00a199eb3bfc	American Express	37.8332930998426633	-122.394945751257268
10484	2020-01-27 02:02:39	2020-01-27	Brigette Rohan	brigette.rohan@geemail.com	New Orleans	Louisiana	4927865802698544	aafc701de9ea4e58c2884fe89b6f14e2	Voyager	29.9625211402788771	-89.8731954870540619
10485	2020-01-27 02:12:04	2020-01-27	Kaila Adams	kaila.adams@warmmail.com	Detroit	Michigan	4970630239703820	1ffc782e465df66eaa92ded563b1a2aa	Voyager	42.364477632513271	-83.1602768140498512
10486	2020-01-27 02:15:51	2020-01-27	Terrell Haag	terrell.haag@warmmail.com	Louisville	Kentucky	51739792322923855	043dceda8553d5ec73923ef0f136dac1	Diners Club / Carte Blanche	38.1724896290242626	-85.6871352543659555
10487	2020-01-27 02:21:48	2020-01-27	Kaiden Bosco Jr.	kaiden.bosco.jr.@woohoo.com	Oceanside	California	3014986039709056	289d24627fc4585ae8bdbbe1001509b7	Voyager	33.274715054117145	-117.26401020275317
10488	2020-01-27 03:31:02	2020-01-27	Stanton McCullough-Ritchie	stanton.mccullough.ritchie@geemail.com	Los Angeles	California	53013410929566038	089e84f8a96403c16132bd7eab7b5931	Diners Club / Carte Blanche	34.0246837942726899	-118.507635286356503
10489	2020-01-27 03:45:36	2020-01-27	Kendrick Considine	kendrick.considine@woohoo.com	San Antonio	Texas	501878543101030	99e4f0bd64626b57faee04d23fe228c9	JCB 16 digit	29.4346411896474649	-98.4710716107696271
10490	2020-01-27 03:50:37	2020-01-27	Kimberli Mante	kimberli.mante@geemail.com	Abilene	Texas	6011424843409553246	7ce75ed673e695f41977f91b6bdf660e	Maestro	32.402848504770553	-99.831587808899954
10491	2020-01-27 03:57:39	2020-01-27	Mrs. Nila Abbott	mrs.nila.abbott@geemail.com	Tuscaloosa	Alabama	3770043576138387	9cf718a298c537281d76a672c200afe2	Maestro	33.2456828148160142	-87.5861943416394269
10492	2020-01-27 04:06:42	2020-01-27	Verlie Wilkinson	verlie.wilkinson@geemail.com	McAllen	Texas	4976867992103277	c694027af063ad90edab484f394c6904	VISA 13 digit	26.1744718245070409	-98.2159206176955166
10493	2020-01-27 04:21:28	2020-01-27	Dr. Sherryl Friesen DDS	dr.sherryl.friesen.dds@geemail.com	Birmingham	Alabama	3088460589705681745	961e4871f586c5bd625a218e03f5c64d	Diners Club / Carte Blanche	33.4801813520748155	-86.8964175398703702
10494	2020-01-27 04:27:04	2020-01-27	Aidyn Leffler	aidyn.leffler@warmmail.com	Tallahassee	Florida	3112867317382136083	103a323828f9af5580df0cd7ed06e6f7	Diners Club / Carte Blanche	30.3865225843641937	-84.326782333759212
10495	2020-01-27 04:28:14	2020-01-27	Jasmyn Gorczany	jasmyn.gorczany@geemail.com	Worcester	Massachusetts	53770942525455615	c27f4dc9cf18998ede878e37d105a2c3	VISA 16 digit	42.3629015795122825	-71.8635567767333185
10496	2020-01-27 04:39:45	2020-01-27	Kasey Jerde	kasey.jerde@geemail.com	Oakland	California	676316799702051	96c160bb4272317212478ab9182586b2	Diners Club / Carte Blanche	37.8369878578184142	-122.2825309379636
10497	2020-01-27 05:11:11	2020-01-27	Trayvon Lockman	trayvon.lockman@geemail.com	Baton Rouge	Louisiana	869977363098775711	eeb6b74ad4315f81be5fda8b90f1fd57	Diners Club / Carte Blanche	30.5346435757566255	-91.0972582547567811
10498	2020-01-27 06:03:06	2020-01-27	Asa Altenwerth-Schaefer	asa.altenwerth.schaefer@geemail.com	New York	New York	3458973061481403	fea8f20afe3b358b415932ad24770b42	JCB 16 digit	40.6000823192521949	-73.9055713184539229
10499	2020-01-27 06:03:41	2020-01-27	Otelia Considine-Dickens	otelia.considine.dickens@geemail.com	Lansing	Michigan	6011784941575573834	b27fd2e42e60ca800b9e07c5ba716e88	American Express	42.7364431410405814	-84.6100554061245163
10500	2020-01-27 06:37:08	2020-01-27	Collin Marvin	collin.marvin@geemail.com	Tampa	Florida	4248993888731922	c80a21bc21073b075d6e3815dc008384	VISA 16 digit	27.9398566248476499	-82.4063084341332228
10501	2020-01-27 06:37:23	2020-01-27	Selene Boyle	selene.boyle@geemail.com	Los Angeles	California	3112757590289680469	23ccabc4db93ce0c1797d69c6db04e7a	Mastercard	34.1119300016533558	-118.490503690716992
10502	2020-01-27 07:30:50	2020-01-27	Mr. Eligah Haag	mr.eligah.haag@geemail.com	Worcester	Massachusetts	4527879389982563	c4bf461d4a38176649ba332d0e8bbc92	VISA 16 digit	42.3130619983356482	-71.8724025106776452
10503	2020-01-27 07:51:15	2020-01-27	Dr. Ronna Terry MD	dr.ronna.terry.md@geemail.com	Carlsbad	California	869951797637685594	84144f58fbb8cd9b7dae1fb30879baad	JCB 15 digit	33.1154838524233526	-117.18453030016012
10504	2020-01-27 07:53:17	2020-01-27	Mr. Tavares Stiedemann DDS	mr.tavares.stiedemann.dds@woohoo.com	Allentown	Pennsylvania	869925650172110200	a96a415583cba6cb791e803890d70208	JCB 15 digit	40.5369621770702295	-75.5358770476203318
10505	2020-01-27 07:56:01	2020-01-27	Alyssia Keeling DDS	alyssia.keeling.dds@geemail.com	Providence	Rhode Island	4450530443644761	80a01354f4adc39c23088eca7b4e8cf6	Diners Club / Carte Blanche	41.9154403135035167	-71.5072081427939281
10506	2020-01-27 08:54:22	2020-01-27	Kieran Corkery II	kieran.corkery.ii@warmmail.com	San Francisco	California	869940834729714976	64425cf75397ac8d67fdc47b0ab69b8d	Diners Club / Carte Blanche	37.766467378208425	-122.399605136562656
10507	2020-01-27 08:55:41	2020-01-27	Dr. Vernon Sporer MD	dr.vernon.sporer.md@geemail.com	Chesapeake	Virginia	3434989541920538	32542320dc662188764151d7a0f62a1c	JCB 15 digit	36.7671516353502881	-76.3791422080557822
10508	2020-01-27 09:02:51	2020-01-27	Carleen Kautzer	carleen.kautzer@geemail.com	South Bend	Indiana	53628248797806327	94678f7616e1f341fed0526107ee8d70	VISA 13 digit	41.7688014707207742	-86.3616417569629959
10509	2020-01-27 09:08:12	2020-01-27	Herlinda Reinger	herlinda.reinger@geemail.com	New York	New York	3715583071831679	04c22d3c8d39f665b4f7abe95982e7aa	VISA 16 digit	40.6421530304700127	-73.9560593056853861
10510	2020-01-27 09:14:31	2020-01-27	Suzan Reilly-Zemlak	suzan.reilly.zemlak@warmmail.com	Lansing	Michigan	53627830957014197	d8feb1a255f02ff26bedfc634cce5f08	VISA 13 digit	42.8070466590423138	-84.5796442026860973
10511	2020-01-27 09:16:08	2020-01-27	Davian Steuber V	davian.steuber.v@geemail.com	Seattle	Washington	6011197708152658986	cd1a647680fbc9bee5db8a6590b75c30	American Express	47.7040298105142995	-122.263835233488678
10512	2020-01-27 09:18:57	2020-01-27	Beverley Ziemann-Bins	beverley.ziemann.bins@geemail.com	Laredo	Texas	869990226906713880	31a53855d63cccaba3e870a43f925473	JCB 16 digit	27.5120946477815522	-99.5650785505779083
10513	2020-01-27 09:30:48	2020-01-27	Edie Denesik	edie.denesik@warmmail.com	Tampa	Florida	4460297933455	505506f72e223bc5d7c0619b7b539b96	JCB 15 digit	27.8913094065267586	-82.5739613057326522
10514	2020-01-27 11:24:16	2020-01-27	Mckenna Keeling	mckenna.keeling@geemail.com	New York	New York	060455525954909	b00742f6f822bafd1a3d652792a1c816	VISA 16 digit	40.5987304413448982	-73.9580525665439694
10515	2020-01-27 11:33:22	2020-01-27	Carroll Schaefer PhD	carroll.schaefer.phd@warmmail.com	Denver	Colorado	3483490221877874	c3a0b81859e9ddde3fb9b361a4c1bddb	Diners Club / Carte Blanche	39.8548695818573222	-104.93568941576072
10516	2020-01-27 11:45:37	2020-01-27	Martez Effertz	martez.effertz@woohoo.com	Atlanta	Georgia	869901777299321879	cf7def7ea5d7df77a95b24ce974d21e1	JCB 15 digit	33.765141435600448	-84.5219446585092697
10517	2020-01-27 11:54:07	2020-01-27	Benedict Goldner	benedict.goldner@woohoo.com	Akron	Ohio	3528293198796325312	c043f8b04d32aaac271a7400534a0d24	Mastercard	40.9866826126184307	-81.5763300474114743
10518	2020-01-27 12:06:31	2020-01-27	Felicie Kuhic	felicie.kuhic@woohoo.com	Newark	New Jersey	869938496916412642	7c4acaede304291291b032a49f857249	VISA 16 digit	40.7455897675275835	-74.1788923910561948
10519	2020-01-27 12:17:33	2020-01-27	Aldo O'Connell	aldo.o'connell@geemail.com	Salem	Oregon	210052506991690234	314a8fdb64592b9abc9717073ac35953	Diners Club / Carte Blanche	44.8985216782230836	-123.105822137852016
10520	2020-01-27 12:22:02	2020-01-27	Herbert Pollich DDS	herbert.pollich.dds@geemail.com	Thornton	Colorado	4894836478773092	bd853edba72b92973f848b8273ba2de4	Mastercard	39.8808137442782566	-104.996233731850239
10521	2020-01-27 12:35:22	2020-01-27	Miss Marcella Sawayn	miss.marcella.sawayn@geemail.com	Oakland	California	3337736192593646074	9e321e34cb142f1f07af09825b2396a8	VISA 16 digit	37.7849029278377699	-122.288826128753556
10522	2020-01-27 12:47:05	2020-01-27	Vicky Beatty-Krajcik	vicky.beatty.krajcik@geemail.com	New York	New York	52420101925223909	f7ee429aa989f9c78b367f07803738ed	American Express	40.7572763022724516	-73.85139548744894
10523	2020-01-27 13:28:03	2020-01-27	Ryan Fadel I	ryan.fadel.i@geemail.com	Oakland	California	4342932414910605	1ae3dc045b4a6cd277532de67a2c41aa	VISA 16 digit	37.7869122014335161	-122.301576667492995
10524	2020-01-27 13:28:27	2020-01-27	Alycia Welch-Shanahan	alycia.welch.shanahan@geemail.com	Honolulu	Hawaii	4523391653549312	b2beb09b6266bc947e3473cdb593373c	Maestro	21.2500412000559287	-157.758970686534781
10525	2020-01-27 13:38:26	2020-01-27	Fenton Waelchi	fenton.waelchi@geemail.com	San Francisco	California	4883637938134	e7fa2e1887602382636aaf140a116c90	Maestro	37.7760525375101608	-122.4415483506383
10526	2020-01-27 13:55:01	2020-01-27	Mr. Carrol Medhurst DDS	mr.carrol.medhurst.dds@woohoo.com	Oakland	California	4249228414225860	f4176c85ad3aa03240a94f6ab73001d4	American Express	37.8176731272100071	-122.298015562187857
10527	2020-01-27 14:25:41	2020-01-27	Santino Hagenes-Cormier	santino.hagenes.cormier@geemail.com	Aurora	Colorado	6011805208033837309	493a8d3c2dab3ff9fafbfe491e21e49c	American Express	39.6458139354009234	-104.788700089429327
10528	2020-01-27 14:33:33	2020-01-27	Jaslyn Walter	jaslyn.walter@geemail.com	Garden Grove	California	4223973693884891	376d87528cc23a3a53bf39ff4754c5cb	JCB 16 digit	33.7183369449630348	-117.970599541442468
10529	2020-01-27 14:58:34	2020-01-27	Virgel Lueilwitz	virgel.lueilwitz@geemail.com	Richmond	California	676214929460906	b4f6d9d25731332ef04102964c223002	VISA 16 digit	37.9360554865982422	-122.460572631782298
10530	2020-01-27 15:17:20	2020-01-27	Mr. Clive Weber	mr.clive.weber@warmmail.com	Lexington	Kentucky	3158857186810019928	002ab8b51a8c5278b0b0aa2282433abf	JCB 16 digit	38.0440842139877375	-84.5409650178991257
10531	2020-01-27 15:26:05	2020-01-27	Miss Texas Bartoletti MD	miss.texas.bartoletti.md@geemail.com	Long Beach	California	6011442395884660069	df53bd642c1780957839a7c2fb3f93fc	Voyager	33.7187577257685334	-118.109098130154607
10532	2020-01-27 15:28:37	2020-01-27	Dr. Dyan Ritchie	dr.dyan.ritchie@geemail.com	Concord	California	3158552020016709362	9891438c838ec1e8b76797117fe8fe16	Maestro	37.9603071125157214	-121.922952310525247
10533	2020-01-27 15:31:25	2020-01-27	Ama Morissette MD	ama.morissette.md@geemail.com	Fort Collins	Colorado	6011351120277429545	07931ab42233d49ff3b2e85c87f58337	JCB 15 digit	40.4926643375463797	-105.154285342567789
10534	2020-01-27 15:53:59	2020-01-27	Hollie Moen	hollie.moen@geemail.com	San Angelo	Texas	3528429890020004641	685edf261b3530c3f7ce5f094d16f152	Voyager	31.4937546754874269	-100.52448693440482
10535	2020-01-27 16:41:15	2020-01-27	Dr. Myrtle O'Keefe	dr.myrtle.o'keefe@geemail.com	Louisville	Kentucky	4720266039982885	36b4816e533b4ff82978520c91fd6405	Discover	38.260109943840277	-85.5763181353058684
10536	2020-01-27 18:04:29	2020-01-27	Stonewall Shanahan	stonewall.shanahan@geemail.com	Jacksonville	Florida	4876511604686904	ba325805467ee1bf5a264f89d15b23c3	American Express	30.4229670809168375	-81.625231843402986
10537	2020-01-27 18:16:54	2020-01-27	Antonia Schaefer	antonia.schaefer@geemail.com	San Francisco	California	561200982399230	61c326067e3d640075c8b112b97e094f	Maestro	37.7678269037540773	-122.425736685629388
10538	2020-01-27 18:16:55	2020-01-27	Iva Gaylord	iva.gaylord@geemail.com	Kenosha	Wisconsin	6011725908528003906	896df10e1104507e062295d626151e10	American Express	42.6802877821799385	-87.9089228295017051
10539	2020-01-27 18:18:29	2020-01-27	Shanice Bailey	shanice.bailey@geemail.com	San Francisco	California	869995986927261087	ff47a335632ab671e63d568ad2b00671	Discover	37.7900797305100369	-122.446143289629447
10540	2020-01-27 18:34:26	2020-01-27	Liller Mayert-Torphy	liller.mayert.torphy@geemail.com	Lakewood	New Jersey	4570930695345759	3e15bc730131402baad6c91a1cfb6572	VISA 13 digit	40.1101720234662338	-74.2540616768222321
10541	2020-01-27 18:48:00	2020-01-27	Miss Brandie Hauck	miss.brandie.hauck@woohoo.com	Berkeley	California	3088986813203573112	4ed9cf7f656e686b7312f8481bdccf8f	JCB 16 digit	37.8397051914101681	-122.276888501763423
10542	2020-01-27 19:10:20	2020-01-27	Dewayne Dietrich	dewayne.dietrich@woohoo.com	New York	New York	869959957348142317	93e0e2e60d70078ed8bba0b6bcb29766	JCB 16 digit	40.5923420907221697	-73.8781500600174041
10543	2020-01-27 19:12:04	2020-01-27	Kieth Rau	kieth.rau@geemail.com	San Mateo	California	180057567717012850	0ef89ddd142f7b7e2f38e12011df918a	Diners Club / Carte Blanche	37.5391650951348197	-122.325185619186982
10544	2020-01-27 19:13:22	2020-01-27	Aldona Johnson	aldona.johnson@geemail.com	Philadelphia	Pennsylvania	3096177652317958887	1b74407e564cbc9182f1f1fa1d5407b8	Voyager	39.9617723830468918	-75.0791210546523331
10545	2020-01-27 19:14:17	2020-01-27	Ladonna Hickle	ladonna.hickle@geemail.com	Lansing	Michigan	4818161810499	375823596a375296e8e333a6b32a741c	Diners Club / Carte Blanche	42.6269982727553725	-84.6159127645783116
10546	2020-01-27 19:20:46	2020-01-27	Rhoda Kuhlman	rhoda.kuhlman@warmmail.com	Philadelphia	Pennsylvania	869945339943496363	bf42b5c01af9c3f2b0cd2998e1a71609	Discover	40.1005906301509611	-75.2190142849825349
10547	2020-01-27 19:44:11	2020-01-27	Ms. Vesta Tromp	ms.vesta.tromp@warmmail.com	Sacramento	California	869924389326558508	b6f573ffb0c787b11ed98567d3afd2b4	Discover	38.6019086998220544	-121.409979908937956
10548	2020-01-27 19:51:56	2020-01-27	Willene Bergstrom DVM	willene.bergstrom.dvm@warmmail.com	Berkeley	California	6011641926612054487	076f87d5d5a568ae897d5c654e814507	Voyager	37.8967254977049848	-122.306325660006721
10549	2020-01-27 19:55:49	2020-01-27	Rodrigo Raynor	rodrigo.raynor@geemail.com	San Jose	California	180095247589103756	b15111973ee74c537eda7a75a4ba472a	Maestro	37.3251700016956818	-121.782841885018726
10550	2020-01-27 19:59:26	2020-01-27	Clarance Kohler PhD	clarance.kohler.phd@warmmail.com	New York	New York	3042319201346709	79f8db9061e9149b0bf2578a05d9e5ba	Diners Club / Carte Blanche	40.584461500797417	-73.988760100434348
10551	2020-01-27 20:10:02	2020-01-27	Thalia Lehner-Ruecker	thalia.lehner.ruecker@woohoo.com	San Francisco	California	589336344547892	d2bbff7ff3b602873f4820e479a88225	Discover	37.7671888061762289	-122.449039408671126
10552	2020-01-27 20:17:33	2020-01-27	Jamiya Fadel-McClure	jamiya.fadel.mcclure@geemail.com	Jersey City	New Jersey	6011964547843567417	db699c79fb3ff7ad9ffe8cff1302b4a0	American Express	40.7882022902309842	-74.0469641433518433
10553	2020-01-27 21:28:13	2020-01-27	Lee Swift-Beer	lee.swift.beer@warmmail.com	Berkeley	California	4852649159804825	4aeae4e4c87f6e73c1ea53a6e8f45639	Mastercard	37.8910610945859645	-122.27660413081
10554	2020-01-27 21:48:09	2020-01-27	Ora Vandervort MD	ora.vandervort.md@geemail.com	Los Angeles	California	4255642977727362	06886f0408162829c827a2d81633e80b	Discover	33.9338280405249435	-118.46469635716565
10555	2020-01-27 22:11:46	2020-01-27	Miss Kendra Fadel	miss.kendra.fadel@warmmail.com	San Francisco	California	3528223426823969066	0c9abfd72aee580b541c0acec78c3236	Discover	37.778378854426343	-122.450197406012947
10556	2020-01-27 22:12:47	2020-01-27	Levar Boyle Jr.	levar.boyle.jr.@warmmail.com	San Francisco	California	4306015350375977	bdf7e9ec475ea819acdad6e08b9aae27	American Express	37.786023413213627	-122.447915681282396
10557	2020-01-27 22:19:50	2020-01-27	Ova Moore MD	ova.moore.md@geemail.com	Chicago	Illinois	4423838940440334	b6a694e00d9c9a493e230d769e89db89	Voyager	41.8609121634926638	-87.6631009881880061
10558	2020-01-27 22:23:10	2020-01-27	Lindsey Cassin	lindsey.cassin@geemail.com	Austin	Texas	4613362357911018	e551a67dd6b7f99e6f4b7e89b1ee916d	VISA 16 digit	30.258810576064139	-97.8441921223193418
10559	2020-01-27 22:48:23	2020-01-27	Adda West-Aufderhar	adda.west.aufderhar@geemail.com	Centennial	Colorado	3088543510387147145	a226f32ea4428ae9491a7c90fa8b4e37	Discover	39.5962586084887391	-104.778485762317104
10560	2020-01-27 22:57:23	2020-01-27	Carmelita Jast	carmelita.jast@woohoo.com	Stockton	California	4089376070800683	4a6bffb5668c5118d09d537388adb33f	Voyager	38.0230268848326105	-121.3840127366215
10561	2020-01-27 22:58:01	2020-01-27	Miss Brandi Ernser	miss.brandi.ernser@geemail.com	New York	New York	210025617418159382	e16a907a6380e28eb929821d42b37b8c	VISA 13 digit	40.5894965740144258	-73.971485472040996
10562	2020-01-27 23:34:14	2020-01-27	Carly Runolfsdottir DDS	carly.runolfsdottir.dds@geemail.com	San Francisco	California	3789799055417969	106142bdefd34beff394223e69c144fc	Discover	37.7558219867211875	-122.425475201949808
10563	2020-01-27 23:53:05	2020-01-27	Vikki Hammes	vikki.hammes@geemail.com	Kansas City	Kansas	4678408925520	84c163c712089f0256cb909e5918fe4b	VISA 16 digit	39.0410240161139512	-94.7353078993905342
10564	2020-01-28 00:00:14	2020-01-28	Patrica White	patrica.white@geemail.com	Oklahoma City	Oklahoma	6011843294032250102	d1472bd402e3a757d55d1d97fca0c4b7	JCB 15 digit	35.4598058329340091	-97.5073289850622444
10565	2020-01-28 00:18:03	2020-01-28	Zita Borer-Russel	zita.borer.russel@geemail.com	El Paso	Texas	3499179218635773	75a0f2d8aced166b8d497ede71a5db15	VISA 16 digit	31.9248154616743349	-106.497655619073669
10566	2020-01-28 00:39:48	2020-01-28	Foster Von	foster.von@geemail.com	Seattle	Washington	4609038656828287	951370790dbfab2e7bb547297bb1d161	JCB 15 digit	47.6544042553678153	-122.273909366588668
10567	2020-01-28 00:52:18	2020-01-28	Bliss Stokes	bliss.stokes@geemail.com	Davie	Florida	4230233915019	fa0334e5d2385962423c9dd62a18c5c6	JCB 16 digit	26.1488919348720472	-80.3566820755507791
10568	2020-01-28 01:28:59	2020-01-28	Admiral Ryan V	admiral.ryan.v@geemail.com	Aurora	Colorado	3016364007496171	0685cd6fe19fc347c1a4c2fc5d9a5205	JCB 16 digit	39.6875085445232685	-104.589707494632151
10569	2020-01-28 02:25:22	2020-01-28	Miller Borer-Parker	miller.borer.parker@geemail.com	New York	New York	54721415308155892	c91194630dbcf57222ec81a1d04ce655	Discover	40.6093501257468006	-73.8779890534363659
10570	2020-01-28 02:32:38	2020-01-28	Ms. Gigi Kovacek MD	ms.gigi.kovacek.md@woohoo.com	Louisville	Kentucky	4460814847269393	8608f83a7889886b12f698067fe16855	JCB 16 digit	38.1765322932410953	-85.6693782222062339
10571	2020-01-28 02:36:21	2020-01-28	Mauricio Cormier	mauricio.cormier@geemail.com	Chesapeake	Virginia	4635167567137534	46c09a2d708e393bf97aa9c4efcb6188	VISA 13 digit	36.7181210309039798	-76.2152231715463131
10572	2020-01-28 02:43:14	2020-01-28	Dr. Arther Price DDS	dr.arther.price.dds@woohoo.com	Minneapolis	Minnesota	4771468942614625	996b9addd997b90f1ac5dd1386c3b1d2	Mastercard	44.8811275743499394	-93.3207659720249438
10573	2020-01-28 03:10:25	2020-01-28	Patrick Kulas DDS	patrick.kulas.dds@geemail.com	Tallahassee	Florida	210082968081075219	5d8958cbbddf987c732c149b414cc6a4	VISA 16 digit	30.4561379618499437	-84.2712858101833575
10574	2020-01-28 03:22:28	2020-01-28	Violette Herman	violette.herman@geemail.com	Irving	Texas	51448367290097990	7008e2dd941ab66348107bd4837e7ac0	Voyager	32.8904153137419399	-96.9260366540681559
10575	2020-01-28 04:09:55	2020-01-28	Mr. Simmie Kerluke DDS	mr.simmie.kerluke.dds@woohoo.com	New York	New York	3784529950461878	261fff45c7e6771683f1d5c9c1d18d3b	Diners Club / Carte Blanche	40.735115692833439	-73.9346430921822702
10576	2020-01-28 04:11:35	2020-01-28	Dr. Jessy Toy PhD	dr.jessy.toy.phd@geemail.com	Torrance	California	869982080473783762	3304a2036b0fe218b816870da578144d	JCB 15 digit	33.7982389097940157	-118.284849645768844
10577	2020-01-28 04:19:52	2020-01-28	Zayne Berge-Predovic	zayne.berge.predovic@geemail.com	Bellevue	Washington	3158794519896831657	e456d50434c6c31efd93cb03f3223b2e	JCB 15 digit	47.5583208527598558	-122.076767369598144
10578	2020-01-28 05:06:01	2020-01-28	Orah McLaughlin	orah.mclaughlin@geemail.com	San Antonio	Texas	51990246833346217	f639d72a8ec960ca768039dd22b5d0b8	Discover	29.5617259708303948	-98.4403711698319768
10579	2020-01-28 06:22:38	2020-01-28	Merrily Abernathy	merrily.abernathy@woohoo.com	San Francisco	California	4262491924367	0cdfc266f13ffa5b5476afe7ff0a3b40	Maestro	37.7531205267555379	-122.427003287673202
10580	2020-01-28 06:23:44	2020-01-28	Oline Quitzon	oline.quitzon@geemail.com	San Francisco	California	3485831645389640	c5bf5a2318adb9a797bcedecf3e7c4fb	Discover	37.7574238204712174	-122.412553573652488
10581	2020-01-28 06:25:14	2020-01-28	Nils Harvey	nils.harvey@geemail.com	Detroit	Michigan	4818193548960777	076f720a868c76aae6fd4cfc24ff5a99	VISA 16 digit	42.397660575194287	-83.0220217694181883
10582	2020-01-28 07:22:54	2020-01-28	Debrah Feeney	debrah.feeney@geemail.com	Philadelphia	Pennsylvania	4946246707837130	2566093fd6b193b962cae522add98e23	Discover	39.9547722896985675	-75.1383768549554105
10583	2020-01-28 07:47:09	2020-01-28	Shaneka Bode-Bartoletti	shaneka.bode.bartoletti@geemail.com	Scottsdale	Arizona	3112202366970747342	1fc3bd1bc079a338f90df01ef2461a10	Diners Club / Carte Blanche	33.6393436677876849	-111.923095607754206
10584	2020-01-28 08:00:44	2020-01-28	Gabe Heathcote	gabe.heathcote@geemail.com	Portland	Oregon	6011831286892496233	3c8b80261abcac1a6436807448cecd8f	Diners Club / Carte Blanche	45.5542854104079282	-122.644431358436123
10585	2020-01-28 08:19:19	2020-01-28	Hattie Weber DDS	hattie.weber.dds@geemail.com	Chattanooga	Tennessee	6011755180242398888	4c53175ede4f94fa3126f350b8c5986e	VISA 16 digit	35.0890760175734755	-85.1492118489757246
10586	2020-01-28 08:22:54	2020-01-28	Jeremie Franecki	jeremie.franecki@geemail.com	San Francisco	California	6011035195449542940	b6d7c90c09ac0ce69e5a21f8ddb5f2b8	Discover	37.7709360365882105	-122.393129124983034
10587	2020-01-28 08:50:50	2020-01-28	Bo Runolfsdottir	bo.runolfsdottir@woohoo.com	Chula Vista	California	4085098366637	2e7fb1b577638b2f2321d196aa35339a	VISA 16 digit	32.6597855696219952	-117.095267337863135
10588	2020-01-28 09:28:46	2020-01-28	Robb Williamson	robb.williamson@geemail.com	Port St. Lucie	Florida	4790413473763463	d9ef2cb2c1dc2098a25107698ffe3196	Discover	27.2081218718219553	-80.31975766388625
10589	2020-01-28 09:33:22	2020-01-28	Blanchard Sanford	blanchard.sanford@geemail.com	San Francisco	California	3787684837022612	0f9614069d4c3c715cec0bd145489842	Maestro	37.7537512758314406	-122.396287122290744
10590	2020-01-28 09:55:19	2020-01-28	Richelle Weimann	richelle.weimann@geemail.com	San Francisco	California	4873144041738	172d2c64ae456471c0789075bac61b17	JCB 15 digit	37.7722316332114403	-122.431639671650956
10591	2020-01-28 10:17:03	2020-01-28	Kylene Cole	kylene.cole@geemail.com	Fort Wayne	Indiana	4418550332716	c7d276569f12298f17ebd2a284bd25ca	VISA 16 digit	41.1157477106682947	-85.179654630342128
10592	2020-01-28 10:44:36	2020-01-28	Tempie Lebsack	tempie.lebsack@geemail.com	San Francisco	California	210056428652131653	acbf6b8113daa985c26c243896dd4b47	JCB 16 digit	37.7908265073845797	-122.470160633163133
10593	2020-01-28 10:47:18	2020-01-28	Cailyn Mayert-Denesik	cailyn.mayert.denesik@geemail.com	Berkeley	California	6011871702254398917	88ab8a9a66736b9399b17d7cb4db3b33	VISA 16 digit	37.8738327127110281	-122.257833298637038
10594	2020-01-28 11:01:34	2020-01-28	Melany Casper	melany.casper@woohoo.com	Dayton	Ohio	869906002015627003	cb581fa43f368fc66899720f2786ea82	VISA 16 digit	39.7227109738416999	-84.2020986973032421
10595	2020-01-28 11:05:03	2020-01-28	Tamala Medhurst	tamala.medhurst@geemail.com	Orlando	Florida	3158701575630775412	b1e45a467d54969635952eebbfa55a61	VISA 13 digit	28.4095708678740984	-81.3670711351059452
10596	2020-01-28 11:23:09	2020-01-28	Ms. Onnie Steuber	ms.onnie.steuber@warmmail.com	San Francisco	California	502006059872090	e65678a59e69d589842fb96ed22118fd	American Express	37.7758278730474402	-122.436445790687813
10597	2020-01-28 11:29:34	2020-01-28	Rahn McLaughlin	rahn.mclaughlin@geemail.com	Philadelphia	Pennsylvania	4247504586254728	2e247153d2f2f378eddaf88d6d990f56	JCB 16 digit	39.9992890826851095	-75.1382630812834975
10598	2020-01-28 11:38:56	2020-01-28	Draven Klein	draven.klein@woohoo.com	San Francisco	California	502019194873220	4211d64fe1f94c619568ea520c4315df	Voyager	37.7444479749180886	-122.419223822558337
10599	2020-01-28 11:52:01	2020-01-28	Keena Lesch	keena.lesch@geemail.com	Washington	District of Columbia	4667671906192	ec8f9fd628bf6093f29b3812bf336ac5	Mastercard	38.9324472076058399	-77.0482231731273259
10600	2020-01-28 12:08:40	2020-01-28	Philip Kuvalis DVM	philip.kuvalis.dvm@woohoo.com	Jersey City	New Jersey	3463454388098975	b5b1d60f5f8e5306f35fed33d4fad683	JCB 16 digit	40.6625965766083439	-74.1533060288477799
10601	2020-01-28 12:27:58	2020-01-28	Ezzard McGlynn	ezzard.mcglynn@geemail.com	New York	New York	3048045144699995	1496ff7498a3ba6c222840b297e1b72a	Mastercard	40.7395892593301809	-73.908048219688979
10602	2020-01-28 12:35:48	2020-01-28	Derald Williamson	derald.williamson@woohoo.com	Grand Prairie	Texas	869918214195857237	86ef2d78b1b0f45152ce2daed7b5b31a	VISA 13 digit	32.6839118355006022	-96.9993764326315357
10603	2020-01-28 12:43:28	2020-01-28	Ricci Brakus-Goodwin	ricci.brakus.goodwin@geemail.com	Frisco	Texas	4470188228026989	b35d8f7071aefbadf5fd21aef1c3e41e	JCB 16 digit	33.1380612939592467	-96.8758966702710751
10604	2020-01-28 12:49:29	2020-01-28	Tamica Simonis	tamica.simonis@warmmail.com	Winston–Salem	North Carolina	869906525815238993	91f746817e1756338b914e90c1fc0d41	American Express	36.1721890219252558	-80.316840079858892
10605	2020-01-28 13:01:02	2020-01-28	Ms. Brinda Gaylord	ms.brinda.gaylord@woohoo.com	Phoenix	Arizona	4175264832544564	98eae58d6125a4ce605c61950bf1f280	Voyager	33.5835356139510921	-112.097208989404521
10606	2020-01-28 13:33:33	2020-01-28	Maria Carter-Rice	maria.carter.rice@geemail.com	San Francisco	California	676210261360563	d9c6e92c04d8b0580676463e1cb6e482	JCB 16 digit	37.7358345042961503	-122.440594182968113
10607	2020-01-28 14:20:09	2020-01-28	Marilou Mayert	marilou.mayert@geemail.com	Antioch	California	180018083534750159	c73a7c817916961f2be0ec036df1886c	Mastercard	37.9037574386488672	-121.833778999064862
10608	2020-01-28 15:16:59	2020-01-28	Shantell Tillman	shantell.tillman@woohoo.com	San Francisco	California	869933986242696525	9b8b1569307b6efb980f19dc126502ce	VISA 16 digit	37.7817130573293625	-122.450426670073554
10609	2020-01-28 15:19:00	2020-01-28	Ms. Gennie Rohan DDS	ms.gennie.rohan.dds@warmmail.com	New York	New York	4786415149736027	0864326f81260c67734c4f7fb410f19b	Discover	40.5903405875191083	-73.9508544332243503
10610	2020-01-28 15:33:38	2020-01-28	Dr. Gerald Mayer	dr.gerald.mayer@geemail.com	Sterling Heights	Michigan	3088069079969677337	f8526295de74104cbb8d9beaa43cbebf	JCB 16 digit	42.5310588305432375	-83.1132050762113153
10611	2020-01-28 15:46:07	2020-01-28	Elon Reichert	elon.reichert@woohoo.com	Dallas	Texas	3757116759430842	a14d5dd9ca9afab4b4d19cdad4abc050	Diners Club / Carte Blanche	32.8007117418844274	-96.8216269269082659
10612	2020-01-28 15:47:36	2020-01-28	Dr. Cassidy Murray IV	dr.cassidy.murray.iv@geemail.com	Centennial	Colorado	6011661131645923734	0f9283428c30cdbb5ff92a7164d54065	Diners Club / Carte Blanche	39.5178018787451109	-104.922559973353898
10613	2020-01-28 15:52:31	2020-01-28	Larkin Balistreri	larkin.balistreri@warmmail.com	Columbus	Ohio	4777950785094159	d04ace39028add002186ecab899cb9a8	Maestro	40.0127408825371376	-83.0670394508868526
10614	2020-01-28 15:55:15	2020-01-28	Earley Cole-Dietrich	earley.cole.dietrich@geemail.com	Henderson	Nevada	3096434842844318700	8d03d7d87274912f01f1b4b7d583c60f	VISA 13 digit	35.9543684113238058	-114.974460977471253
10615	2020-01-28 16:25:24	2020-01-28	Cristi Swaniawski	cristi.swaniawski@woohoo.com	San Francisco	California	210056564882130139	8cec10eddd4a7957f44a99e4435e2a0a	JCB 15 digit	37.7542115649318291	-122.459444692809527
10616	2020-01-28 17:08:38	2020-01-28	Mrs. Makayla Howell DVM	mrs.makayla.howell.dvm@warmmail.com	Long Beach	California	54687098692734290	6612678285599963cd37e3ee2d9aa3c7	JCB 16 digit	33.8695385838214307	-118.090985224691408
10617	2020-01-28 17:53:18	2020-01-28	Kamila Auer	kamila.auer@geemail.com	San Francisco	California	210025863442103489	1a1e0d0535bf6247f2ffc22ee2275e9a	JCB 15 digit	37.771947665378363	-122.422732352691469
10618	2020-01-28 17:58:48	2020-01-28	Germaine Monahan	germaine.monahan@woohoo.com	Denver	Colorado	502087260779373	0cc96dccecc40ff3e594072ad146decc	Diners Club / Carte Blanche	39.7227125822618561	-104.917989220820743
10619	2020-01-28 18:19:13	2020-01-28	Elinore Daniel DDS	elinore.daniel.dds@geemail.com	Tulsa	Oklahoma	3088492077024170691	4f4c1c60b771f02cfcde286bcc5b55ba	VISA 16 digit	36.1409054863169743	-95.9430716396730361
10620	2020-01-28 18:34:11	2020-01-28	Cristin Harber	cristin.harber@woohoo.com	Los Angeles	California	4364439644072241	9a547fcec8761fc83882e84d5ef2db75	American Express	34.1106534534465524	-118.470649405102421
10621	2020-01-28 18:35:50	2020-01-28	Jenny Zieme	jenny.zieme@geemail.com	Denton	Texas	3337505263999502168	3f796347cc4fc832e7eff5384f084738	Diners Club / Carte Blanche	33.2604521269708897	-97.144820714568354
10622	2020-01-28 19:13:03	2020-01-28	Lugenia Rosenbaum-Greenfelder	lugenia.rosenbaum.greenfelder@warmmail.com	San Francisco	California	4675191267432574	9d8ac24851335e9f532b07fe00b48e13	VISA 13 digit	37.8101273185083215	-122.421506586285616
10623	2020-01-28 19:40:35	2020-01-28	Eric Jakubowski	eric.jakubowski@geemail.com	Fresno	California	210041528454014623	395f660f291e9c1bd2d06d24077ba894	Mastercard	36.7838467106096445	-119.739774727459633
10624	2020-01-28 19:56:08	2020-01-28	Jaleesa Hessel	jaleesa.hessel@geemail.com	Glendale	Arizona	3054997214250139	0a606cb8c9b10477cc7cdb4aef384d2d	JCB 16 digit	33.5893217262573529	-112.176528757882863
10625	2020-01-28 20:10:48	2020-01-28	Rhoda Simonis	rhoda.simonis@geemail.com	San Antonio	Texas	6011913539508596536	e73bc11d36d8caf11546beb67958655c	Diners Club / Carte Blanche	29.4863811587985616	-98.5814195879571145
10626	2020-01-28 20:25:19	2020-01-28	Felicitas Feest MD	felicitas.feest.md@geemail.com	Berkeley	California	3021668548257636	317eb1c1b517f90ba68e090999f801e6	VISA 13 digit	37.8209564394256148	-122.280024042032153
10627	2020-01-28 20:28:56	2020-01-28	Kody Beer	kody.beer@geemail.com	Phoenix	Arizona	210003333870104074	33c309dd9f4a616fdba32d893fe8c494	Voyager	33.6597191719736912	-112.101150486657772
10628	2020-01-28 20:31:55	2020-01-28	Mrs. Genevieve Reynolds	mrs.genevieve.reynolds@geemail.com	New Haven	Connecticut	501839226251484	96ce3372cdff021e19dd5ecf104987e2	JCB 16 digit	41.219050796096397	-72.9632526390720102
10629	2020-01-28 20:41:23	2020-01-28	Nevaeh Borer	nevaeh.borer@geemail.com	San Francisco	California	3337947146385623951	a0f9922d47bb785dfb0a8c8fdd51634a	Discover	37.7827203536033096	-122.439984385225031
10630	2020-01-28 21:04:29	2020-01-28	Dr. Newell Predovic	dr.newell.predovic@geemail.com	Hayward	California	3158218414401793220	0c853eef684ec818487744cb5ba3c1d9	Discover	37.6376918833691647	-122.064373112728447
10631	2020-01-28 21:06:51	2020-01-28	Dr. Shelley Bode	dr.shelley.bode@geemail.com	San Francisco	California	4810718625058	af32813866ba5e40b65dff61198e912b	JCB 16 digit	37.7903502057596512	-122.433214541988818
10632	2020-01-28 21:14:32	2020-01-28	Darcy Bins	darcy.bins@geemail.com	San Francisco	California	4520351908948316	2cb9852dd479b62a81cc38c638158cf1	Mastercard	37.7875087198417674	-122.443747993127246
10633	2020-01-28 21:15:08	2020-01-28	Hasan Crooks	hasan.crooks@warmmail.com	Honolulu	Hawaii	52028490400932605	8d34046e4050bc09e56610e8f6d6e152	Mastercard	21.2425053851429375	-157.766421063917136
10634	2020-01-28 21:18:29	2020-01-28	Dr. Ladarius Denesik IV	dr.ladarius.denesik.iv@woohoo.com	Fremont	California	4037260073871177	14f44a8ff2d1330cb32bd01e4bd4c075	VISA 16 digit	37.5725089535284837	-122.004736539813493
10635	2020-01-28 21:21:46	2020-01-28	Ernst Morar	ernst.morar@woohoo.com	Lewisville	Texas	180038795936661397	5ad815de4b318d5b9177cedf01567225	JCB 16 digit	32.99331144741587	-96.9940319603804539
10636	2020-01-28 21:36:23	2020-01-28	Zetta Waelchi	zetta.waelchi@geemail.com	Virginia Beach	Virginia	3096882976103813220	335a9d6747033f0014cde4806817d68d	Maestro	36.7076407540310186	-75.9303909775938877
10637	2020-01-28 21:37:10	2020-01-28	Fremont Armstrong	fremont.armstrong@woohoo.com	Salt Lake City	Utah	3045025932512173	dd3a6a5174a69660f0106d26c0857df0	Voyager	40.7876561029959461	-111.996094484342265
10638	2020-01-28 21:48:47	2020-01-28	Arden Wuckert	arden.wuckert@geemail.com	New York	New York	3030398689805727	020d9d4e262460d3136bcd89f89ef8c5	JCB 16 digit	40.7281188020706182	-74.023803278467426
10639	2020-01-28 22:19:37	2020-01-28	Golden Botsford DDS	golden.botsford.dds@warmmail.com	Montgomery	Alabama	6011483032900444570	bfbdaad42d73a0f4acc43bdbb5bae249	VISA 16 digit	32.4447277434568875	-86.3546333470068816
10640	2020-01-28 22:24:24	2020-01-28	Fredrick Muller	fredrick.muller@geemail.com	San Francisco	California	6011967888778896752	5da9e8c221abd78126c5e53ec64a900c	VISA 13 digit	37.7759724171038798	-122.426475812076234
10641	2020-01-28 22:35:38	2020-01-28	Dr. Lorenza Volkman	dr.lorenza.volkman@geemail.com	San Francisco	California	4418826431660285	31b0721dd80176b7ad5cc41c8c6e2a93	JCB 15 digit	37.7808070029448473	-122.413226241532811
10642	2020-01-28 22:42:31	2020-01-28	Belva Fritsch DVM	belva.fritsch.dvm@woohoo.com	Plano	Texas	3494352417949882	fe31b5cc20a458783af788b1465f80e5	VISA 16 digit	33.063022410878169	-96.6701935843281461
10643	2020-01-28 23:12:40	2020-01-28	Young Krajcik-Goyette	young.krajcik.goyette@geemail.com	Aurora	Colorado	6011704105103669061	6cf71c1203c5660a2a17fc2a78aa78ce	Mastercard	39.5890911568999329	-104.701141667983308
10644	2020-01-28 23:19:01	2020-01-28	Juliana Braun	juliana.braun@geemail.com	St. Louis	Missouri	6011610895785032611	d199f109490b9872ef4138004bab5ecb	JCB 16 digit	38.6254433796431869	-90.2796824972614758
10645	2020-01-28 23:31:43	2020-01-28	Myron Pacocha	myron.pacocha@warmmail.com	New York	New York	869910396432229755	74431bf8fb918422b78ac3d75f9373d3	Discover	40.6124651977550215	-74.0222886215791078
10646	2020-01-28 23:34:27	2020-01-28	Mr. Green Turner	mr.green.turner@geemail.com	Huntsville	Alabama	3096040900910662009	d54495c97a7b7b7e9463c3fea667bc34	Mastercard	34.6377029807083261	-86.6517765539251315
10647	2020-01-28 23:37:43	2020-01-28	Mr. Rodolfo Kreiger DDS	mr.rodolfo.kreiger.dds@geemail.com	San Antonio	Texas	869917753079991431	c8ecf90762d59e83ade8fad02a7aa0ca	Diners Club / Carte Blanche	29.5154061133112755	-98.497221405974031
10648	2020-01-28 23:50:20	2020-01-28	Dr. Nira Murazik	dr.nira.murazik@geemail.com	Oakland	California	4128224868194179	b46fc1008799abf76e02172fc4dba93f	American Express	37.8244292068412733	-122.261396175809907
10649	2020-01-28 23:52:09	2020-01-28	Ike Wolf	ike.wolf@woohoo.com	San Francisco	California	676310651126947	9791acf1a8f9f8701fa7032c60f9eadf	VISA 13 digit	37.7331497744529898	-122.426256837017746
10650	2020-01-29 00:01:00	2020-01-29	Mikaila Wolff	mikaila.wolff@woohoo.com	Denver	Colorado	3158320760898259553	63d6762fec3763eb2c0f9ea0c2897401	VISA 16 digit	39.8459888507664175	-104.926003484266261
10651	2020-01-29 00:12:15	2020-01-29	Emmer O'Reilly	emmer.o'reilly@woohoo.com	San Jose	California	3471554372940148	fabc79d10f65fda9378c45b58adf6008	JCB 15 digit	37.3224419819012283	-121.864770463177564
10652	2020-01-29 00:17:17	2020-01-29	Verna Kris	verna.kris@geemail.com	Chula Vista	California	3440369729116500	5a4a468d5c7df7138912c254155c1d92	Diners Club / Carte Blanche	32.5385081043232205	-117.055943359038594
10653	2020-01-29 00:17:32	2020-01-29	Mr. Jaden Effertz	mr.jaden.effertz@geemail.com	Columbus	Ohio	3112319513426402655	4beadafd14321c7204692b55c968e041	VISA 16 digit	39.9673158997714495	-83.077296620537723
10654	2020-01-29 00:21:16	2020-01-29	Mr. Joeseph Green	mr.joeseph.green@geemail.com	San Francisco	California	3158616225667860091	509f003763c6d05fefa1c56de31eabda	American Express	37.7914711330748929	-122.448772591773292
10655	2020-01-29 00:25:11	2020-01-29	Kegan Quitzon	kegan.quitzon@geemail.com	Fort Worth	Texas	210017428635809043	e6683589b478748d946b9a27e8a8b05b	American Express	32.8813208265285937	-97.3339395972721206
10656	2020-01-29 00:26:22	2020-01-29	Vennie Douglas	vennie.douglas@geemail.com	Austin	Texas	4429440536447833	90fc8cde2db9b4250a455d9e32573d72	JCB 15 digit	30.3443359371867025	-97.809870717186115
10657	2020-01-29 00:38:49	2020-01-29	Joy Luettgen V	joy.luettgen.v@geemail.com	Mesa	Arizona	51207999850032933	0bba200cba61801027b336c9e202ed1c	Voyager	33.3532591516297288	-111.749859617452699
10658	2020-01-29 00:51:12	2020-01-29	Asha Ryan	asha.ryan@woohoo.com	San Francisco	California	4023215980455049	235f0bdce594da9319977b44c55b51fb	VISA 16 digit	37.7710474067351711	-122.447406492788645
10659	2020-01-29 01:14:22	2020-01-29	Tracy Runolfsson-Kreiger	tracy.runolfsson.kreiger@geemail.com	San Francisco	California	210098810174034525	49a96f319a701179609328f0df87c860	JCB 15 digit	37.806882833240337	-122.402504280696476
10660	2020-01-29 01:28:56	2020-01-29	Thurman Abbott	thurman.abbott@geemail.com	San Angelo	Texas	869941488016213280	d6ae9fea9cc116bebe17add045acb956	American Express	31.4762762635167661	-100.41819202756696
10661	2020-01-29 01:38:14	2020-01-29	Miss Shante Hickle	miss.shante.hickle@woohoo.com	Oxnard	California	4334426597614837	82eccf45e883fec18374f491ceddd1c3	Maestro	34.1130491352129752	-119.274605739387127
10662	2020-01-29 01:50:52	2020-01-29	Kacy Nienow-Altenwerth	kacy.nienow.altenwerth@geemail.com	Plano	Texas	3044063599595067	6d441c41ef54bd2b65ac3670ed21c8c4	Diners Club / Carte Blanche	33.0470242607492963	-96.6994379668679045
10663	2020-01-29 01:59:58	2020-01-29	Mr. Berkley Nicolas V	mr.berkley.nicolas.v@geemail.com	San Francisco	California	503899604619959	760d92617d6b4667d16609ef9af6b120	VISA 13 digit	37.7636396754795172	-122.444202594110394
10664	2020-01-29 02:08:02	2020-01-29	Ms. Shanon Muller DVM	ms.shanon.muller.dvm@geemail.com	Kent	Washington	4729408439627329	7127caa99869724d0ebe88afaa9e0b3d	JCB 16 digit	47.403547336312009	-122.221206988873703
10665	2020-01-29 02:22:29	2020-01-29	Nickolas Daniel-Schinner	nickolas.daniel.schinner@geemail.com	San Francisco	California	869994668480000331	75be13f171c463f9f15440dcc83e1c5b	American Express	37.7548520416123097	-122.441948919376856
10666	2020-01-29 02:38:45	2020-01-29	Chelsy Cartwright-Gorczany	chelsy.cartwright.gorczany@geemail.com	Seattle	Washington	4721645473365	f929bb10a7ce8b8872ec094be6c3a29a	VISA 16 digit	47.5877624205704777	-122.353636382419239
10667	2020-01-29 03:01:33	2020-01-29	Jean Ward	jean.ward@geemail.com	Baltimore	Maryland	6011089591104718913	a8faf6296c8c0aff86d84ee206408a4e	JCB 16 digit	39.2830384067259715	-76.5301316555142392
10668	2020-01-29 03:04:26	2020-01-29	Arminda Little-Hessel	arminda.little.hessel@warmmail.com	Fort Worth	Texas	4470123476367439	8836aab30f3463c1249ba322e8adc095	Diners Club / Carte Blanche	32.8416432824973015	-97.3395775192238375
10669	2020-01-29 03:05:14	2020-01-29	Blair Miller	blair.miller@geemail.com	Wichita	Kansas	869923149233619269	e1f9307d46ef2f3ca8fa1dfc7b2a856a	JCB 15 digit	37.7890085061423449	-97.3441245148625285
10670	2020-01-29 03:20:43	2020-01-29	Dr. Gideon Buckridge II	dr.gideon.buckridge.ii@geemail.com	Brownsville	Texas	4887878107994003	b543f97d71e3be58d996441cc205d5b7	JCB 16 digit	26.0257075312159927	-97.4243596409633739
10671	2020-01-29 03:40:12	2020-01-29	Mr. Jerold Wilkinson V	mr.jerold.wilkinson.v@geemail.com	Alexandria	Virginia	869992159052787945	7b4c985f770ec7edf9078e19a8bdda3b	Discover	38.7802330509409288	-77.0592225644256956
10672	2020-01-29 04:03:51	2020-01-29	Ms. Vira Stehr MD	ms.vira.stehr.md@warmmail.com	Henderson	Nevada	3002313494625978	17f96a8320f044dbbcfb5ba29e009feb	Mastercard	36.0839741513065988	-115.131719263518974
10673	2020-01-29 04:23:27	2020-01-29	Dawne Herzog	dawne.herzog@geemail.com	New York	New York	4688900535830897	167d2348d0f7c0f51476ce4a1f8278b6	VISA 16 digit	40.6546389171145819	-73.9095563718944817
10674	2020-01-29 04:43:02	2020-01-29	Flossie Heaney	flossie.heaney@warmmail.com	San Francisco	California	4896933698942629	4994398d4f4ce80bf14b6a5eea07e53b	Discover	37.808419688959539	-122.428170853332503
10675	2020-01-29 04:58:45	2020-01-29	Clevie Hane	clevie.hane@geemail.com	Tucson	Arizona	3158297215251619538	91a60b85af4d868f81aab37d3470dc59	Mastercard	32.1581942394882461	-110.84775018289163
10676	2020-01-29 05:04:57	2020-01-29	Cherish Heidenreich	cherish.heidenreich@geemail.com	Green Bay	Wisconsin	4320499542451502	a3868e053b6141c490d1bcb7c7e72280	JCB 16 digit	44.4905788063135006	-88.0104956850696425
10677	2020-01-29 05:05:26	2020-01-29	Dr. Melva Gerlach DDS	dr.melva.gerlach.dds@woohoo.com	Arlington	Texas	4833050391706940	2203271314b568c98c5965c8ba8ded4f	Diners Club / Carte Blanche	32.6116421378932841	-97.1045988989088755
10678	2020-01-29 05:12:27	2020-01-29	Cael Crona DVM	cael.crona.dvm@geemail.com	Berkeley	California	3096356916208331915	feca5fdbd99b39bf40f9d2b986833ba3	VISA 16 digit	37.8830093232992979	-122.27452557368575
10679	2020-01-29 05:25:57	2020-01-29	Dr. Dana Rodriguez	dr.dana.rodriguez@geemail.com	San Francisco	California	869925035633006926	05de2017e3f8755b5a0f0490695e2a5a	Mastercard	37.7518807840350732	-122.436821617996571
10680	2020-01-29 05:47:53	2020-01-29	Marlene Nikolaus	marlene.nikolaus@geemail.com	Tampa	Florida	589356822853869	494837917487211acd547903852d986e	Voyager	28.0168060396447771	-82.5610117100391534
10681	2020-01-29 05:50:37	2020-01-29	Madaline Williamson-Hermann	madaline.williamson.hermann@geemail.com	Dallas	Texas	4160050976631094	20d714def09fbc527f3be58e1fe19a3b	Mastercard	32.7692130904916681	-96.6925994664859019
10682	2020-01-29 06:26:49	2020-01-29	Mr. Malaki Klein IV	mr.malaki.klein.iv@woohoo.com	Chicago	Illinois	210074513257716145	0113596a469b48531113f11001e36a29	JCB 16 digit	41.8644636371940422	-87.6436710491340563
10683	2020-01-29 06:36:59	2020-01-29	Dr. Alphonso Trantow DVM	dr.alphonso.trantow.dvm@geemail.com	San Antonio	Texas	4271604681905	08a248591d6f45eb351b9fe46dc02dfe	Voyager	29.4327990592528153	-98.6010081880561984
10684	2020-01-29 06:44:38	2020-01-29	Cordia Zboncak	cordia.zboncak@geemail.com	Chicago	Illinois	53207732690168744	9980f51a6fdb6852fe9e3b40a09146c0	Discover	41.9215939949568366	-87.59457759051881
10685	2020-01-29 07:10:01	2020-01-29	Edythe Bradtke	edythe.bradtke@geemail.com	Philadelphia	Pennsylvania	869927972086975520	f11fe9235a516f1b0733f1d09de8d2c9	JCB 16 digit	39.9371690898627065	-75.1297159419294474
10686	2020-01-29 07:17:46	2020-01-29	Lannie Tromp	lannie.tromp@woohoo.com	Riverside	California	180013369231138284	d4271615ef8a91f5e35b54dd77bed1fd	Discover	33.9425683567248271	-117.398321987126764
10687	2020-01-29 07:19:44	2020-01-29	Cheryll Schimmel-Heller	cheryll.schimmel.heller@woohoo.com	San Francisco	California	3158458518659936726	cb8d525c935b85b7400a54c79b8984e9	Diners Club / Carte Blanche	37.771291168729114	-122.411113124586407
10688	2020-01-29 07:29:01	2020-01-29	Dr. Hiroshi Goyette	dr.hiroshi.goyette@geemail.com	Saint Paul	Minnesota	210017243820790878	00c1deddd2ba447705ae5121f9f5f01d	Mastercard	45.0321953878212753	-93.0243692488208467
10689	2020-01-29 07:43:05	2020-01-29	Rudy Klein	rudy.klein@geemail.com	Milwaukee	Wisconsin	6011400860553820997	e8a5d2fb48db4239688386acec8fb2e9	VISA 16 digit	43.0901426512833652	-88.0132679612942042
10690	2020-01-29 08:04:04	2020-01-29	Katelin Kihn	katelin.kihn@geemail.com	Cleveland	Ohio	4462672574948052	3c8c0732b412e378d32a50a98115db16	VISA 16 digit	41.412841457672414	-81.7624684520304186
10691	2020-01-29 08:12:42	2020-01-29	Milan Bode-Wilkinson	milan.bode.wilkinson@warmmail.com	Greeley	Colorado	210021648425961332	d2f90d373c2d438320a71184b29de19e	VISA 16 digit	40.4473375669747597	-104.750891406724975
10692	2020-01-29 08:43:10	2020-01-29	Dr. Jamar Littel Sr.	dr.jamar.littel.sr.@geemail.com	San Francisco	California	180019419468713616	b77a1dfcf8e141c7b02dcd30316f88da	JCB 16 digit	37.804674392458935	-122.45568890165957
10693	2020-01-29 08:44:02	2020-01-29	Malik Russel	malik.russel@geemail.com	Houston	Texas	210008904760376207	1e182cf6ad7fc5e4e857b47dfbfb46c5	Voyager	29.8695645830672234	-95.3596317765783539
10694	2020-01-29 08:45:30	2020-01-29	Mr. Clifton Kutch Sr.	mr.clifton.kutch.sr.@geemail.com	San Francisco	California	4640129054918290	a9bad5bf4a99c6fe20244a7d87f5bb31	JCB 16 digit	37.759768167139768	-122.461254399194104
10695	2020-01-29 09:05:45	2020-01-29	Mr. Kirby Kassulke Sr.	mr.kirby.kassulke.sr.@geemail.com	Sparks	Nevada	4362083459156434	f987c574c28dc60d8a90378e5f9bae98	JCB 16 digit	39.6102896422851813	-119.637496561402827
10696	2020-01-29 09:19:08	2020-01-29	Dr. Red Mosciski	dr.red.mosciski@geemail.com	Chicago	Illinois	675928873251137	3069b363978d2979f098b1124bbd6e74	VISA 16 digit	41.8739028309308026	-87.6141045677505446
10697	2020-01-29 09:19:09	2020-01-29	Cooper Lynch-Quigley	cooper.lynch.quigley@geemail.com	Oakland	California	3046326580368531	b0488b0bdbebbaa47f2f46b9163ea8ec	JCB 16 digit	37.832112739574761	-122.259959577330264
10698	2020-01-29 09:42:13	2020-01-29	Landin Ledner III	landin.ledner.iii@geemail.com	Miami	Florida	3158902220004026301	212fa748fb40c0313240f34c0eaf8980	Voyager	25.8520176061101274	-80.136227653442333
10699	2020-01-29 09:43:52	2020-01-29	Ishaan Kiehn	ishaan.kiehn@geemail.com	Cape Coral	Florida	4834050580418835	182e1deb3517449ffeea2ac849ba5c1c	American Express	26.7236424830246726	-82.0358656704496525
10700	2020-01-29 09:49:47	2020-01-29	Drew Buckridge	drew.buckridge@woohoo.com	Pembroke Pines	Florida	6011837237066271328	472457bea7da40005ef0a2ea5346237f	Maestro	26.0974625653158867	-80.3742706391863493
10701	2020-01-29 11:08:24	2020-01-29	Mrs. Nathalie Cronin DVM	mrs.nathalie.cronin.dvm@geemail.com	San Francisco	California	3528364889113732578	a4e1015249724197d92489e9c692eef1	JCB 16 digit	37.7979581652570573	-122.451999336516195
10702	2020-01-29 11:28:59	2020-01-29	Phoenix Hessel-Hoppe	phoenix.hessel.hoppe@geemail.com	Cincinnati	Ohio	4259408066528020	f93b677db1adf87c60479ae6a2d6d212	VISA 16 digit	39.1128079047657522	-84.5234216050051117
10703	2020-01-29 11:34:36	2020-01-29	Koen Klein	koen.klein@woohoo.com	Chicago	Illinois	3337968660424166206	02120632127eb69e4e4f78c61a14da31	Discover	41.7711524251684594	-87.7088538116339578
10704	2020-01-29 11:37:00	2020-01-29	Joni Boyle	joni.boyle@geemail.com	Sugar Land	Texas	869911708118383376	5fd900212889b93ba2d54d91f9f4347d	JCB 15 digit	29.5467369656130678	-95.5746808981996026
10705	2020-01-29 11:59:57	2020-01-29	Mr. Mario Collins	mr.mario.collins@geemail.com	Berkeley	California	6011477774083638944	d705b9a339c27ad1e7cf0f86f4a839c2	VISA 16 digit	37.8618367420949582	-122.283673017241171
10706	2020-01-29 12:48:59	2020-01-29	Zoa Hills DVM	zoa.hills.dvm@geemail.com	San Francisco	California	869944382427899141	00dfc825d50ffbcd0fbc5c9d2a821a87	Discover	37.7817649186203823	-122.436974774583447
10707	2020-01-29 12:56:08	2020-01-29	Lorenza McKenzie	lorenza.mckenzie@warmmail.com	Phoenix	Arizona	3096105483857035036	4522d58c0adb0cd52692b209202b619f	Diners Club / Carte Blanche	33.6371698110297359	-112.111284582030407
10708	2020-01-29 13:02:13	2020-01-29	Tanja Price MD	tanja.price.md@geemail.com	Oakland	California	3528101319905553279	f40a3a2a9562c4639c490acc5e838671	JCB 15 digit	37.791065236633564	-122.247832642600244
10709	2020-01-29 13:03:33	2020-01-29	Rayford Wiza II	rayford.wiza.ii@geemail.com	Louisville	Kentucky	630449736726933	90f5b5b4b6d5d6cc051f51db6863cb50	VISA 16 digit	38.0778093735590559	-85.5932368558902397
10710	2020-01-29 13:15:31	2020-01-29	Hollis Pouros	hollis.pouros@geemail.com	Cambridge	Massachusetts	3700009880167367	c9b5902b5d1d53471d92eca2dd13f9f6	VISA 13 digit	42.4317538061868404	-71.1135558623436879
10711	2020-01-29 13:20:14	2020-01-29	Mckenzie Frami	mckenzie.frami@geemail.com	Jacksonville	Florida	869962933521705910	75f5feeec0b2b030f7dea20b95de23a1	VISA 16 digit	30.349068027181179	-81.6664583248164604
10712	2020-01-29 14:40:39	2020-01-29	Chandra Erdman	chandra.erdman@geemail.com	Concord	California	3452629915888302	a571d3ab6e0e7826b9b160dcf158c71b	Diners Club / Carte Blanche	38.071573172875496	-121.999890688637635
10713	2020-01-29 14:43:36	2020-01-29	Miss Dixie Simonis DVM	miss.dixie.simonis.dvm@geemail.com	New York	New York	639062418085288	4f98aaaa65214b4d80ecc63f8727c8bf	JCB 15 digit	40.6658344766814253	-73.8717617520026835
10714	2020-01-29 15:11:12	2020-01-29	Meta Stracke	meta.stracke@woohoo.com	Colorado Springs	Colorado	4520754940743084	b5934c99a3a24803716ce9268e94b09c	VISA 16 digit	38.9177618380684436	-104.833141280633214
10715	2020-01-29 15:25:39	2020-01-29	Mrs. Meg Walsh MD	mrs.meg.walsh.md@geemail.com	Amarillo	Texas	3495768007755604	a9716ac5ec9ad74b399d6fb6d9c999ce	VISA 16 digit	35.2099527273491049	-101.827567037832736
10716	2020-01-29 15:32:54	2020-01-29	Dr. Clella Hane	dr.clella.hane@geemail.com	Washington	District of Columbia	3750609576789876	a902e25d55b3cfc41730f7db2dbb9347	Voyager	38.9056745468903316	-77.0357222940519506
10717	2020-01-29 15:54:17	2020-01-29	Amey Koch	amey.koch@geemail.com	San Francisco	California	6011770412438868379	684e3c887e69a85aab116a62d56c4a5d	American Express	37.7607675358291601	-122.442062639147139
10718	2020-01-29 15:56:55	2020-01-29	Barney Baumbach	barney.baumbach@geemail.com	Jackson	Mississippi	6011086582862664673	0646ba438779318f7723d418d8ecd2c6	Maestro	32.2231485305532814	-90.2317704146236252
10719	2020-01-29 15:57:55	2020-01-29	Keshawn Bayer	keshawn.bayer@geemail.com	Los Angeles	California	4918095710524	d12b6e4cde5708534a4cf24f0363b61b	VISA 13 digit	34.1144989572796931	-118.46614355803392
10720	2020-01-29 15:58:10	2020-01-29	Mabelle Towne	mabelle.towne@geemail.com	Seattle	Washington	3528322184547677107	5326cebfe90d22384c1ee0cbbac9a3fa	American Express	47.6768225061632691	-122.416895945408939
10721	2020-01-29 16:00:58	2020-01-29	Sammie Gislason	sammie.gislason@geemail.com	New York	New York	676371551814651	5f1cc81c4f788dd4abe587a86ce05d79	VISA 16 digit	40.5960578622519961	-73.8916615268576891
10722	2020-01-29 16:03:09	2020-01-29	Reynold Thompson	reynold.thompson@geemail.com	Fresno	California	3528035139564667363	705d3133f5152c2327fc864259b1dea3	JCB 16 digit	36.8348416753452241	-119.746317665988215
10723	2020-01-29 16:30:49	2020-01-29	Julie McLaughlin	julie.mclaughlin@geemail.com	Huntsville	Alabama	4455072064225740	c5fddb40b79193460ca7979a0ca50709	VISA 16 digit	34.7554279050566208	-86.6299620630703942
10724	2020-01-29 16:52:14	2020-01-29	Elden Muller	elden.muller@geemail.com	New York	New York	3337080383017515399	b4d1c494d8f7334f5a4555a5caef4e9f	Voyager	40.6247799612339549	-73.8462363792944672
10725	2020-01-29 16:54:50	2020-01-29	Miss Willie Kohler	miss.willie.kohler@woohoo.com	Santa Clarita	California	3528810053119745882	90da6854561c1de9eab8c0d9ea8b8020	Diners Club / Carte Blanche	34.3755735035724896	-118.494935382912672
10726	2020-01-29 17:17:49	2020-01-29	Val Gibson	val.gibson@geemail.com	Chicago	Illinois	6011140535802999827	f6d4689bd12fd4c1798daa18c1fb3db1	VISA 16 digit	41.8446737812668133	-87.7731623855914904
10727	2020-01-29 17:27:55	2020-01-29	Ms. Mindy Jacobs	ms.mindy.jacobs@geemail.com	San Francisco	California	3716780656583852	d3c8069fdf07e2ad5d512e604b41dec9	Voyager	37.8045886278697978	-122.452152742068876
10728	2020-01-29 17:38:31	2020-01-29	Casey Kerluke	casey.kerluke@geemail.com	San Francisco	California	503808042078165	fabb000f97fdbdbddeda39d0c3455db1	Discover	37.7554378663856411	-122.438171178800943
10729	2020-01-29 17:51:36	2020-01-29	Carry McKenzie	carry.mckenzie@geemail.com	Phoenix	Arizona	180036773330255977	5ee28daabd9e695dfb8b4939538d14fa	Discover	33.6534482894398295	-111.997388220291967
10730	2020-01-29 17:57:28	2020-01-29	Signe Grimes	signe.grimes@geemail.com	Long Beach	California	3528819857693351680	e38bdff9496df203d0c4a1cfe9728c33	Discover	33.9031581370446773	-118.089129314121976
10731	2020-01-29 18:03:54	2020-01-29	Dr. Robbie Parisian DDS	dr.robbie.parisian.dds@woohoo.com	Colorado Springs	Colorado	210056229688596699	bde2050fd35169fa7fd68b8b71ca4c4a	JCB 15 digit	38.9361364042900533	-104.846458399683982
10732	2020-01-29 18:18:00	2020-01-29	Lani Padberg-Rath	lani.padberg.rath@woohoo.com	Yonkers	New York	4806400883070	818a9d5347e3b31e5aa2d3ef4dc8b1ba	Voyager	40.9573908738061832	-73.8533653648454731
10733	2020-01-29 18:20:09	2020-01-29	Shanequa Larkin DVM	shanequa.larkin.dvm@warmmail.com	Atlanta	Georgia	6011815068007086392	772bbce66c8e807c47473ef90fb1798d	Maestro	33.8316294659670476	-84.3604830988261938
10734	2020-01-29 18:35:27	2020-01-29	Newman Luettgen	newman.luettgen@geemail.com	Indianapolis	Indiana	4519199654432842	41589154ba3d344b4652ccdebdef0706	JCB 15 digit	39.7414381728515025	-86.1221511609587793
10735	2020-01-29 18:41:53	2020-01-29	Alabama Reichert	alabama.reichert@woohoo.com	Berkeley	California	676325822683857	c38a7958609f1db5778843b5ab2eaa6c	Mastercard	37.85205935226994	-122.250507278565493
10736	2020-01-29 18:46:49	2020-01-29	Little Harvey	little.harvey@geemail.com	New York	New York	676144440479804	293d27c4fb6347f4fecaa6e307c3921e	VISA 16 digit	40.6705776211563474	-74.0224832508608728
10737	2020-01-29 18:52:26	2020-01-29	Mr. Ferris Graham I	mr.ferris.graham.i@geemail.com	Washington	District of Columbia	3050420304704760	90c32605b0c80821b64472a4abbe47a8	VISA 16 digit	38.8487153509896217	-77.0434749839574096
10738	2020-01-29 18:57:36	2020-01-29	Ida Keebler-Barton	ida.keebler.barton@geemail.com	Berkeley	California	3528850030932897422	5bd924599d889822f91621fff6c1ac32	VISA 16 digit	37.9014647150958552	-122.253742356298744
10739	2020-01-29 19:06:57	2020-01-29	Dr. Joann Veum	dr.joann.veum@geemail.com	Eugene	Oregon	3337064007082309582	3919e31029868111f8de2871f1d94e6c	VISA 16 digit	44.1403493588983977	-123.020644891866297
10740	2020-01-29 19:23:41	2020-01-29	Mrs. Abbigail McLaughlin DVM	mrs.abbigail.mclaughlin.dvm@geemail.com	Scottsdale	Arizona	3033077928871933	29af7cc8cca2324b72c70b312171dbb2	Diners Club / Carte Blanche	33.6733947293955822	-111.86130180866121
10741	2020-01-29 19:47:11	2020-01-29	Mazie Wuckert	mazie.wuckert@geemail.com	San Francisco	California	3088572265530653689	93ceabdb8db0a445eb1569bd8b7e74df	American Express	37.7489563234676524	-122.438928200839612
10742	2020-01-29 20:11:03	2020-01-29	Kylah Beer	kylah.beer@geemail.com	San Jose	California	3054795665772761	302ea0b8b482b3ab7df6482db733558a	JCB 15 digit	37.3320366725612445	-121.752517547666656
10743	2020-01-29 20:32:27	2020-01-29	Gasper Schiller	gasper.schiller@geemail.com	Springfield	Missouri	210043970128063859	82cca80b456d13c672469826f4f69579	VISA 16 digit	37.224068211178114	-93.3792956732504109
10744	2020-01-29 20:32:45	2020-01-29	Killian Bins	killian.bins@geemail.com	Milwaukee	Wisconsin	4396688701426	0cdd4bd1b8c4330bda2086a949aa2013	JCB 16 digit	43.0014723948754352	-87.9557392136294425
10745	2020-01-29 20:51:28	2020-01-29	Aretha Nitzsche	aretha.nitzsche@geemail.com	Norfolk	Virginia	3337166885279450666	01daad3bc3d104ce87f895166e365909	Mastercard	36.9869699432067591	-76.3331213352274176
10746	2020-01-29 20:55:12	2020-01-29	Mrs. Marcy Watsica PhD	mrs.marcy.watsica.phd@warmmail.com	Augusta	Georgia	3088318194631620927	1f368668e7f8c23e301a4c709b36334e	JCB 16 digit	33.4161902226712542	-82.1408902668222822
10747	2020-01-29 21:17:56	2020-01-29	Mrs. Cleta Purdy	mrs.cleta.purdy@geemail.com	Oceanside	California	3042147520016756	37a6c59c4f91115a1b3e33f324f495f0	VISA 16 digit	33.172912784561511	-117.319824033890669
10748	2020-01-29 21:23:19	2020-01-29	Dr. Emil Bogisich Jr.	dr.emil.bogisich.jr.@geemail.com	Broken Arrow	Oklahoma	52656693500767206	0dd38c7c633165dd0b800aaca60d76ce	VISA 16 digit	36.0605369183477009	-95.8357240331303331
10749	2020-01-29 21:56:15	2020-01-29	Marlo Aufderhar	marlo.aufderhar@geemail.com	St. Petersburg	Florida	3337312679431156177	7959a52a5ae18082d2caad446bc6f51d	JCB 16 digit	27.858069544646888	-82.595565613674367
10750	2020-01-29 22:05:52	2020-01-29	Rosanne Nikolaus	rosanne.nikolaus@geemail.com	New York	New York	3112687491005231221	3cc5dd5cc924ca469b471402f0390791	Voyager	40.6712008898835649	-73.9860509985022219
10751	2020-01-29 22:07:00	2020-01-29	Darion Baumbach	darion.baumbach@warmmail.com	New York	New York	869916131576635218	706fce470b69ebd1a59dd956da9f6ca6	Voyager	40.617859581694006	-73.925501432119674
10752	2020-01-29 22:15:46	2020-01-29	Carlos Larson	carlos.larson@geemail.com	Honolulu	Hawaii	180023118661275027	0b0c5a495526bda398c9d48548ae4429	Diners Club / Carte Blanche	21.319383298720421	-157.863534635233123
10753	2020-01-29 22:23:23	2020-01-29	Eloisa Beer MD	eloisa.beer.md@geemail.com	Philadelphia	Pennsylvania	4931535009029736	84dbf8a657a11fe5b48451aeece4221d	VISA 16 digit	40.0808662512298639	-75.0516168011251921
10754	2020-01-29 22:26:48	2020-01-29	Levin Kautzer	levin.kautzer@woohoo.com	Mobile	Alabama	180077621964590286	4ddde68b71be4f910974b67d9d4f4ce5	VISA 16 digit	30.6677177630472926	-88.0657483182519627
10755	2020-01-29 23:04:16	2020-01-29	Richelle Schoen-Douglas	richelle.schoen.douglas@geemail.com	San Francisco	California	55519347012687322	c6755dca6bb895dd5e12658b962269dc	American Express	37.7595520602894936	-122.44329016953921
10756	2020-01-29 23:21:48	2020-01-29	Marcellus Stoltenberg MD	marcellus.stoltenberg.md@warmmail.com	San Francisco	California	639022882734688	8d1c6fbcd7abdd3c705775ec37b3f373	Discover	37.7209022681572037	-122.453609381799495
10757	2020-01-29 23:22:04	2020-01-29	Purl Spinka I	purl.spinka.i@geemail.com	New York	New York	6011414824196433745	3fd67a6bf055fb5a0d92290479c72941	Mastercard	40.743467287695033	-73.8515019480965975
10758	2020-01-29 23:58:06	2020-01-29	Caydence Weber	caydence.weber@geemail.com	Pasadena	California	4475649503863	fffff8178029eb01f5f23d45fcb770bb	JCB 15 digit	34.2556550003442908	-118.19240849067495
10759	2020-01-30 00:03:33	2020-01-30	Ms. Jaelynn Senger MD	ms.jaelynn.senger.md@geemail.com	Baltimore	Maryland	3088965602867803617	3f5b67f64e723eeb86c57cbe7142f108	JCB 16 digit	39.243442098703234	-76.6654273259006516
10760	2020-01-30 00:08:01	2020-01-30	Vivien Schulist	vivien.schulist@geemail.com	Berkeley	California	3158898378943789276	175af94e0a9d250dd70c12b036b2f08d	JCB 16 digit	37.8524564872908371	-122.275908701407729
10761	2020-01-30 00:21:43	2020-01-30	Miss Tonja Howe	miss.tonja.howe@geemail.com	Berkeley	California	210071135028970414	9245bcb8e97db783a2ec9918b5298a57	Diners Club / Carte Blanche	37.8424094265779303	-122.261452313427398
10762	2020-01-30 00:45:34	2020-01-30	Samir Renner Sr.	samir.renner.sr.@woohoo.com	Philadelphia	Pennsylvania	561219832627087	f6f0769c80cfb66f951724f9464ca033	JCB 16 digit	39.9904285078361639	-75.0587886042792434
10763	2020-01-30 00:56:34	2020-01-30	Kylie Schultz	kylie.schultz@geemail.com	Durham	North Carolina	180088073819095417	6b72d8932bd79e83d421c80ebc849294	Mastercard	36.0094760036341839	-78.9516625995185279
10764	2020-01-30 01:11:52	2020-01-30	Andy Stracke	andy.stracke@geemail.com	Fort Worth	Texas	55557570737575729	95097327582587d579e1989485f4d867	Voyager	32.8235883770100756	-97.3706236546680373
10765	2020-01-30 01:15:35	2020-01-30	Coletta Rohan	coletta.rohan@geemail.com	Austin	Texas	6011687632832632624	c41fbdff246d042b225f0f693f75b7ce	JCB 16 digit	30.2615080425176757	-97.831437053974355
10766	2020-01-30 01:23:10	2020-01-30	Mrs. Rita Skiles MD	mrs.rita.skiles.md@geemail.com	San Bernardino	California	869916865845653771	dfef98d16320262795fe1c664d9a3d83	VISA 16 digit	34.0907966847330286	-117.312269795664022
10767	2020-01-30 01:28:26	2020-01-30	Mr. Hiroshi Ondricka	mr.hiroshi.ondricka@warmmail.com	San Francisco	California	180098259956425354	ce102e7955054bc5fbcb5c58da5f82e5	JCB 16 digit	37.7852967191687981	-122.396418530220444
10768	2020-01-30 02:14:00	2020-01-30	Ms. Allyson McDermott PhD	ms.allyson.mcdermott.phd@woohoo.com	Midland	Texas	3405768318402317	da7f131409b8614c853a8f9de0ccc5e6	American Express	32.0725239945765566	-102.063791778007527
10769	2020-01-30 02:14:54	2020-01-30	Elmore Daugherty-Heathcote	elmore.daugherty.heathcote@woohoo.com	San Francisco	California	51432953874178914	93d3ef873816dcd43ccba62215788a45	Maestro	37.791858719878384	-122.419240899050692
10770	2020-01-30 02:40:24	2020-01-30	Mr. Luka Daniel III	mr.luka.daniel.iii@geemail.com	Houston	Texas	869984306331241414	baa60f2e264099f3d47e5f7782bcad44	JCB 16 digit	29.7440549086391925	-95.3129236927736514
10771	2020-01-30 03:17:37	2020-01-30	Isaac McCullough	isaac.mccullough@geemail.com	Winston–Salem	North Carolina	3497505489307472	af0b5a7c899ef0b9e716561e799a6717	VISA 16 digit	36.1047242596045095	-80.3187683162875459
10772	2020-01-30 03:40:54	2020-01-30	Ms. Isabella Huel	ms.isabella.huel@geemail.com	San Francisco	California	3088162956279976341	bdd89b229f93ae3d793150f7a7c6cba4	VISA 16 digit	37.7550800064974084	-122.393214390938766
10773	2020-01-30 03:41:57	2020-01-30	Felisha Doyle	felisha.doyle@warmmail.com	Philadelphia	Pennsylvania	6011561805874186896	ee3cc25389288d91d915bc09d0a62cb7	JCB 16 digit	39.9220242699101533	-75.2040222996745342
10774	2020-01-30 04:32:40	2020-01-30	Elisa Beier DVM	elisa.beier.dvm@geemail.com	Plano	Texas	180070586680062430	369e8ce6a511c0e79e110d4d452c7a65	Discover	33.0991945549000093	-96.8164905773658262
10775	2020-01-30 05:13:45	2020-01-30	Latrina Klocko MD	latrina.klocko.md@warmmail.com	Austin	Texas	502096679329324	1a11cd97b38928963aa920c86c88a43a	VISA 13 digit	30.2183781716633568	-97.7990062921080749
10776	2020-01-30 05:19:40	2020-01-30	Elmore Schaefer	elmore.schaefer@woohoo.com	Los Angeles	California	869905007524200813	de3d7b21085cd4976afab888418c8de1	VISA 16 digit	34.0845229730807233	-118.462712488183001
10777	2020-01-30 05:28:12	2020-01-30	Helaine Kuhic MD	helaine.kuhic.md@geemail.com	North Las Vegas	Nevada	3096268169115414807	4161f2e24eb09b131bf18e645f4c2529	Voyager	36.3399832281906114	-115.136540787083661
10778	2020-01-30 05:43:54	2020-01-30	Rubie Champlin	rubie.champlin@geemail.com	San Francisco	California	4835830410693494	cbaa2735a7d1c18edb81efe9ce238abb	Maestro	37.7577323821034412	-122.403162845837358
10779	2020-01-30 06:16:15	2020-01-30	Mona Armstrong	mona.armstrong@geemail.com	Irvine	California	060430784635218	351897b9ae3cf9a5975ccdae885acfe0	JCB 16 digit	33.6301843937035656	-117.710777648260063
10780	2020-01-30 06:35:49	2020-01-30	Pennie Bins	pennie.bins@warmmail.com	Oakland	California	3045657888711613	8c558695bc651cc583c1d977bc892018	JCB 16 digit	37.7626691411056967	-122.245984943679304
10781	2020-01-30 06:36:31	2020-01-30	Allyson Kerluke	allyson.kerluke@geemail.com	Henderson	Nevada	3096563972087482054	e316a3598546293925ff9201822db298	JCB 16 digit	36.0369094679065043	-115.031276967904347
10782	2020-01-30 06:40:03	2020-01-30	Delfina Fadel	delfina.fadel@geemail.com	New York	New York	210004620099804693	0841b82de04a51a932d8f1f429f55cac	Mastercard	40.5896648491024976	-74.0068153650395573
10783	2020-01-30 07:00:09	2020-01-30	Marshal Feeney	marshal.feeney@woohoo.com	Oakland	California	869918800173281307	74f61930203dacb3434bbd1c5c776ed0	VISA 13 digit	37.8273738149133152	-122.28264139604012
10784	2020-01-30 07:04:46	2020-01-30	Taft Batz	taft.batz@geemail.com	San Francisco	California	210058439386416862	4f8ebd798c2e136ae05adb99537d682f	JCB 15 digit	37.7675494144054511	-122.504948455332212
10785	2020-01-30 07:16:13	2020-01-30	Ignacio VonRueden	ignacio.vonrueden@geemail.com	Berkeley	California	52261820692106912	416df1a12198b768ea5bc215c02a5163	JCB 16 digit	37.9020441353264346	-122.290451021298693
10786	2020-01-30 07:28:53	2020-01-30	Liza Aufderhar	liza.aufderhar@geemail.com	El Paso	Texas	210044086015197624	5e0cfeeebd1a4746ed4a7e600d319e0f	JCB 16 digit	31.8750605732496837	-106.459977384794513
10787	2020-01-30 07:32:55	2020-01-30	Desiree Senger	desiree.senger@woohoo.com	Indianapolis	Indiana	4748444537256	ac9e512fbf4d925b21a06ce107f92bcf	Diners Club / Carte Blanche	39.7779449498288287	-86.1267917574584487
10788	2020-01-30 07:33:00	2020-01-30	Refugio Borer	refugio.borer@geemail.com	San Francisco	California	3337599185593561166	bb78c7a92abd670512d48f6b03de611a	VISA 13 digit	37.7631440910417524	-122.436184483865347
10789	2020-01-30 07:34:36	2020-01-30	Dr. Stefani Hirthe MD	dr.stefani.hirthe.md@warmmail.com	New York	New York	4802268178279728	f95100a8aef3bc6629005ac80f27e8ba	JCB 16 digit	40.7346850078776441	-73.9367600214563225
10790	2020-01-30 07:46:27	2020-01-30	Cloyd Reynolds MD	cloyd.reynolds.md@geemail.com	Oakland	California	4367223660419	c24ed3b6fe3642e1e275e3ba700c0853	VISA 16 digit	37.809292138326974	-122.253679132320059
10791	2020-01-30 08:06:41	2020-01-30	Belia Jast	belia.jast@geemail.com	Philadelphia	Pennsylvania	4007457205616365	b2048b64c7f9a769126efb6a77ef180a	JCB 15 digit	39.9720147839706357	-75.2058380967371249
10792	2020-01-30 08:46:43	2020-01-30	Wyman Abshire-Romaguera	wyman.abshire.romaguera@geemail.com	Fairfield	California	3528576937638488335	95f06fdaa92789b82c1a966a0f66411d	American Express	38.2899372544262562	-122.087539355596903
10793	2020-01-30 09:04:52	2020-01-30	Angie Parker	angie.parker@geemail.com	San Francisco	California	4999423750242	bba4894389ee8146c1f2602b970c9af2	JCB 16 digit	37.7895603748909679	-122.414068219732954
10794	2020-01-30 09:20:25	2020-01-30	Kenji Considine	kenji.considine@woohoo.com	Cleveland	Ohio	3528876233726168790	2291ca221a1d2d3f08c7617f38a93ad5	Maestro	41.4202933064978538	-81.7214217770151805
10795	2020-01-30 09:25:08	2020-01-30	Barbra Kling	barbra.kling@geemail.com	San Francisco	California	4717011814547155	e1536a5bc2fcb754469242678cd21806	JCB 16 digit	37.7469371283112167	-122.419340255961728
10796	2020-01-30 09:39:23	2020-01-30	Mrs. Precious Crooks	mrs.precious.crooks@woohoo.com	New York	New York	6011194062628845717	14dca84c787732aa02226fb0bad32c2f	JCB 15 digit	40.7334942539446061	-73.8798883744876775
10797	2020-01-30 09:40:27	2020-01-30	Dondre Brekke	dondre.brekke@geemail.com	Pearland	Texas	869921548957128765	88ca8889ea559d1c5f917c33f320de15	Discover	29.5343408508963883	-95.3861239665042575
10798	2020-01-30 09:45:02	2020-01-30	Jerad Dietrich-Bradtke	jerad.dietrich.bradtke@warmmail.com	San Francisco	California	55490442343136967	ea838c06af512e15bbb668d252058025	VISA 13 digit	37.7544874154834602	-122.432463881566676
10799	2020-01-30 10:16:40	2020-01-30	Mabel Bergstrom	mabel.bergstrom@geemail.com	Fort Wayne	Indiana	869954510552968680	b34efc5fa71580ac37fb60c14e0ed2cf	Discover	41.0152745850168188	-85.0688987054616206
10800	2020-01-30 10:29:33	2020-01-30	Treyton Schaden-Dietrich	treyton.schaden.dietrich@geemail.com	San Francisco	California	501834472459733	31318d5862ace358746e4512ea6ecd5a	VISA 13 digit	37.8014918711422254	-122.431602775129406
10801	2020-01-30 10:38:31	2020-01-30	Lani Greenholt	lani.greenholt@geemail.com	Oakland	California	3112637762872231440	deac5c5637fe5b4d03283263b3158890	VISA 16 digit	37.7633427997824995	-122.290695409819008
10802	2020-01-30 11:12:02	2020-01-30	Lemon Schowalter-Langworth	lemon.schowalter.langworth@geemail.com	Newport News	Virginia	4319391907121288	8040713433e804b7a201621100c028ea	Voyager	37.0459397871874287	-76.6066660539973583
10803	2020-01-30 11:35:53	2020-01-30	Alisa Koss	alisa.koss@warmmail.com	Elk Grove	California	6011872120366248541	b82bb52c2e8d0cfc1c5771e0c995cbce	VISA 13 digit	38.3596812849216136	-121.355180139970045
10804	2020-01-30 12:15:42	2020-01-30	Addyson Orn-Heller	addyson.orn.heller@geemail.com	San Antonio	Texas	3096073699658416293	e6fb55a0b1a0f92da82042c4f5232852	JCB 15 digit	29.4147069119453448	-98.5678732510957758
10805	2020-01-30 12:18:30	2020-01-30	Belva Mraz	belva.mraz@geemail.com	San Diego	California	4263318296589318	8ca20c6033736f2cf8b4607a79cdb52f	Diners Club / Carte Blanche	32.9086788699097923	-117.156071251994007
10806	2020-01-30 12:28:33	2020-01-30	Dr. Chance Kshlerin I	dr.chance.kshlerin.i@geemail.com	New York	New York	4552098362122	8a9d82ba4689661c1f3298938995452a	Maestro	40.6451119046881786	-73.8671791672602325
10807	2020-01-30 13:00:38	2020-01-30	Shaylee Schultz	shaylee.schultz@woohoo.com	Berkeley	California	3002855539966569	51036182a8e60152bab2cbca5a796bab	Maestro	37.8997770988077534	-122.25648675375426
10808	2020-01-30 13:47:11	2020-01-30	Mrs. Eleonora Gutmann DDS	mrs.eleonora.gutmann.dds@woohoo.com	Houston	Texas	3158208037813742964	78237116ab45936e1d2f9d86c1674a84	American Express	29.7511373860839754	-95.4692163328655141
10809	2020-01-30 14:39:46	2020-01-30	Nathen Crooks V	nathen.crooks.v@warmmail.com	Phoenix	Arizona	3059003754143969	da28714f7a9a4c56fbca00efa8aa0541	Mastercard	33.5714559475824288	-112.181142418172584
10810	2020-01-30 14:40:12	2020-01-30	Vanesa Stokes	vanesa.stokes@geemail.com	San Francisco	California	3158396337821752621	38963693e5ca3bf41c63e96a892c4584	Diners Club / Carte Blanche	37.7775867739101159	-122.41794960485116
10811	2020-01-30 14:41:53	2020-01-30	Melodie Rutherford	melodie.rutherford@geemail.com	Philadelphia	Pennsylvania	3048896362465539	26d9b27ea5abdac1c34c5f9d1129b7ad	Mastercard	40.0006518259137849	-75.2115170308288299
10812	2020-01-30 14:43:16	2020-01-30	Corinne Gulgowski	corinne.gulgowski@geemail.com	Oklahoma City	Oklahoma	4315764339298565	d40bc2652da7e9597e8dd8d230943343	JCB 15 digit	35.5298321115694975	-97.4872429379623355
10813	2020-01-30 14:47:02	2020-01-30	Marianna Zboncak MD	marianna.zboncak.md@geemail.com	San Antonio	Texas	4144689012670565	8c52c3f940ee2525a0d5d5600af611ea	JCB 16 digit	29.5164904825460184	-98.5032338799279188
10814	2020-01-30 14:56:41	2020-01-30	Sophronia Skiles	sophronia.skiles@geemail.com	New York	New York	3528779758371259021	7bb1475950b27bcd58cc453cb090eb1b	VISA 13 digit	40.6565291027761972	-73.8739518949657707
10815	2020-01-30 15:04:38	2020-01-30	Finley Graham-Hickle	finley.graham.hickle@geemail.com	Yonkers	New York	676390927322942	8b4ed433a9fdeb32f01fd081e84403ce	American Express	40.8927130226712663	-73.8958106599167053
10816	2020-01-30 16:07:56	2020-01-30	Kaydence Kautzer-Stamm	kaydence.kautzer.stamm@woohoo.com	West Valley City	Utah	3474205304237502	18e6f4e44efd95eb8bd6406994adf6fc	JCB 16 digit	40.6345252428892962	-111.93575032751373
10817	2020-01-30 16:10:03	2020-01-30	Dr. Jillian Jakubowski MD	dr.jillian.jakubowski.md@geemail.com	Gainesville	Florida	6011069418022137782	bd8194c18e26dbe9cc4ca340aed253b8	American Express	29.7560304316516948	-82.2773964383978438
10818	2020-01-30 16:57:12	2020-01-30	Tex Hauck	tex.hauck@geemail.com	Grand Rapids	Michigan	4665135742879612	64416c92aa40a4be2b44ae60ad0b8e73	JCB 16 digit	42.9329680326662952	-85.634621569062034
10819	2020-01-30 17:21:53	2020-01-30	Dax Purdy IV	dax.purdy.iv@warmmail.com	San Francisco	California	4319264889480	d3dea0eb0c35b9081d53e76695d2e18d	VISA 16 digit	37.7847396159967204	-122.389326156833761
10820	2020-01-30 18:33:15	2020-01-30	Hank Cronin-Ruecker	hank.cronin.ruecker@geemail.com	Albuquerque	New Mexico	4977651481099975	10edc01b0b45cc6aa99712dbef8b7942	JCB 16 digit	35.2014095107227618	-106.584918222536899
10821	2020-01-30 18:38:24	2020-01-30	Edw VonRueden	edw.vonrueden@geemail.com	Phoenix	Arizona	630476639397652	3b50966d4573226a361e150188c21be9	VISA 13 digit	33.602896805892513	-112.081567637941248
10822	2020-01-30 19:36:13	2020-01-30	Ednah Orn-Gaylord	ednah.orn.gaylord@geemail.com	New York	New York	4057932413849627	96c32744f2f03691b90cd5a74ef59d9a	JCB 15 digit	40.5747039580009883	-73.9544090289052605
10823	2020-01-30 20:05:54	2020-01-30	Cielo Klocko	cielo.klocko@geemail.com	Buffalo	New York	180097527812816615	e3c457476404a9e4def7039827a96bdb	JCB 16 digit	42.8520365480054153	-78.9051475938342577
10824	2020-01-30 20:29:39	2020-01-30	Mrs. Mari Padberg	mrs.mari.padberg@geemail.com	Austin	Texas	869937369547492583	5bb7839f5278d4a72927355bff1af485	VISA 16 digit	30.2345553422473365	-97.7083455610793123
10825	2020-01-30 20:49:03	2020-01-30	Nelda Ortiz	nelda.ortiz@warmmail.com	Long Beach	California	3112901144319982332	9d286f5b5fa9d0db1d9b60c03214597c	VISA 13 digit	33.7309553679365663	-118.090235949137437
10826	2020-01-30 20:52:49	2020-01-30	Regan Walsh	regan.walsh@geemail.com	Houston	Texas	4587837292443013	7a0c6b3b822d49455cc3bff93b4425a1	JCB 15 digit	29.7729317963201545	-95.4491875400781709
10827	2020-01-30 21:06:23	2020-01-30	Cherie Wolf	cherie.wolf@geemail.com	Indianapolis	Indiana	4686277309320989	842dbfb06041a2765724c496ef616dac	JCB 16 digit	39.7429447885610116	-86.1526057968117271
10828	2020-01-30 21:09:45	2020-01-30	Ms. Lyric Lynch DVM	ms.lyric.lynch.dvm@woohoo.com	San Francisco	California	502046500891620	e61f4f97989a8e84928b91edb9f9de9c	JCB 16 digit	37.7591555199007658	-122.436551009771705
10829	2020-01-30 22:06:16	2020-01-30	Elizbeth Herman	elizbeth.herman@woohoo.com	San Francisco	California	3088613364162485220	064630d339d1db46abe9cd97fb5b29a5	Voyager	37.7655496975894494	-122.43833002549988
10830	2020-01-30 22:23:58	2020-01-30	Knute Pfeffer	knute.pfeffer@geemail.com	Glendale	California	3031930609157893	9a6e5f6d9a8dd2c250421cc4a4bd5ff5	Voyager	34.2478999975357183	-118.313674610144645
10831	2020-01-30 22:42:11	2020-01-30	Lavelle Rodriguez	lavelle.rodriguez@geemail.com	Columbus	Ohio	3088527902299270786	8e19cfce98173f36d00bf1e7c6d06fe9	American Express	39.9409825461961319	-82.8857763043839526
10832	2020-01-30 23:54:25	2020-01-30	Loda Stark	loda.stark@geemail.com	Riverside	California	6011493417903391936	2d5d7045fd87eb6720bfb27799fc29af	Mastercard	33.853124642739445	-117.336764014462744
10833	2020-01-31 00:26:25	2020-01-31	Buelah Jaskolski DVM	buelah.jaskolski.dvm@woohoo.com	Houston	Texas	4553479849455	235660f5bd6c94e3b518046b9ef628cc	JCB 16 digit	29.7790382185097791	-95.3622301989249905
10834	2020-01-31 00:27:55	2020-01-31	Denzell Padberg	denzell.padberg@woohoo.com	Little Rock	Arkansas	3158569647254062202	d6f24bb7f71054f8959a53f7edf7ce12	VISA 16 digit	34.8137555567357708	-92.3592380277685834
10835	2020-01-31 00:30:09	2020-01-31	Diane Treutel	diane.treutel@warmmail.com	Austin	Texas	869901209015269422	c72166bcc83e32ae24aa4c561ea6d6dc	Mastercard	30.3674364686604576	-97.7543325437005706
10836	2020-01-31 00:32:51	2020-01-31	Hart Stanton	hart.stanton@geemail.com	Columbus	Georgia	4631295373429	79c44072a15fcbcbdacce6973262970e	Mastercard	32.6073759133972203	-84.8902612060937969
10837	2020-01-31 00:49:16	2020-01-31	Darrell Graham	darrell.graham@geemail.com	Berkeley	California	3112060936715036564	18ce9493dcf2a5211d7b65a157fd85f4	JCB 15 digit	37.8828016743171005	-122.27393860784413
10838	2020-01-31 01:05:29	2020-01-31	Shoji Harvey	shoji.harvey@geemail.com	Cleveland	Ohio	869939065594919233	b722c3377f1867ba1ff46066061285e2	JCB 16 digit	41.5379842639286068	-81.6585188079398137
10839	2020-01-31 01:14:19	2020-01-31	Kevin Runolfsdottir-Feest	kevin.runolfsdottir.feest@geemail.com	Oakland	California	676227997369072	1bdbe4c21bcc6431a329186438d0cb23	JCB 16 digit	37.7763727307473829	-122.277568853566365
10840	2020-01-31 01:26:43	2020-01-31	Matthias Ullrich	matthias.ullrich@geemail.com	Oakland	California	52863744723764584	84811627c06fbf00e25dfcef33521e64	Mastercard	37.7966488319975369	-122.242714834710583
10841	2020-01-31 01:37:28	2020-01-31	Wayman Hammes	wayman.hammes@woohoo.com	Fairfield	California	54701590578129639	2abf64a425d20d5b1833f08d942f9525	VISA 16 digit	38.284702193283664	-121.989871222805604
10842	2020-01-31 01:42:08	2020-01-31	Mrs. Brittani Kautzer DVM	mrs.brittani.kautzer.dvm@woohoo.com	San Francisco	California	3158428071754219124	7070e32652cdab303bd0121e9f4aa3f7	American Express	37.7508873072124231	-122.448649833976361
10843	2020-01-31 01:43:05	2020-01-31	Roseann Cronin	roseann.cronin@geemail.com	Peoria	Illinois	210014106785748913	8259ed831756a6315ba3f1faf5426624	American Express	40.8492316221687943	-89.7112878726214262
10844	2020-01-31 01:49:41	2020-01-31	Tinnie Wisoky DVM	tinnie.wisoky.dvm@woohoo.com	Oakland	California	502080373374562	722a1f0999dbb0245f4d906baf212fd9	VISA 13 digit	37.8074437663364051	-122.307739974223324
10845	2020-01-31 02:17:06	2020-01-31	Alfonzo Rowe	alfonzo.rowe@geemail.com	San Francisco	California	6011894857960581603	13fe7b214f46e40d44d125965acb5a17	JCB 16 digit	37.7860045724534359	-122.450060169698176
10846	2020-01-31 02:19:51	2020-01-31	Marita Rodriguez	marita.rodriguez@warmmail.com	San Antonio	Texas	210075204442864581	e71826f3f4835955c82aae8f02d6c739	JCB 16 digit	29.3758818911924955	-98.584900675092257
10847	2020-01-31 02:24:04	2020-01-31	Hubbard Larkin-Turcotte	hubbard.larkin.turcotte@geemail.com	San Francisco	California	869969745618195109	faaf1aa95343f1c7290a476dfb4f4123	JCB 15 digit	37.756784410166226	-122.437676513413606
10848	2020-01-31 02:32:09	2020-01-31	Dr. Leana Bednar PhD	dr.leana.bednar.phd@geemail.com	Chicago	Illinois	3732755618995543	a0d827bb020c08fe0e4bce6413d7c610	Discover	41.8891013021416967	-87.5955541662435877
10849	2020-01-31 02:52:57	2020-01-31	Nathan Fadel	nathan.fadel@geemail.com	New York	New York	589354430524915	cd0f3e9362ae73a64a5c06ec46224826	Voyager	40.6478164230696848	-74.007382673154396
10850	2020-01-31 02:57:23	2020-01-31	Lexus Stamm	lexus.stamm@geemail.com	San Francisco	California	4888276054150	e1cc5f1ed9ecb82c15275c40e248eb2a	Discover	37.7666758370020972	-122.417165057657044
10851	2020-01-31 03:05:01	2020-01-31	Racheal Stanton	racheal.stanton@geemail.com	Los Angeles	California	630467460047003	e815c2aee390ec27c2865bbf2e7dd172	JCB 16 digit	33.9664677300356317	-118.464262156234298
10852	2020-01-31 03:16:51	2020-01-31	Emmett Windler	emmett.windler@geemail.com	San Francisco	California	3528799950526756474	b08bacedc99f7face7b2ea4cbfd7cfbf	JCB 16 digit	37.8018390461708194	-122.440411477348036
10853	2020-01-31 03:39:26	2020-01-31	Tracie Renner	tracie.renner@geemail.com	San Francisco	California	210076029297607879	8d5121fc809f8f382ed66381821906a8	JCB 16 digit	37.7861585705566654	-122.404600436404337
10854	2020-01-31 04:01:15	2020-01-31	Blain Bahringer-Ryan	blain.bahringer.ryan@woohoo.com	Austin	Texas	210025588260302109	700962f6ead7db79a4021b711b37cfeb	JCB 16 digit	30.2892311291895808	-97.7619702524743985
10855	2020-01-31 04:12:29	2020-01-31	Paola Lebsack DDS	paola.lebsack.dds@geemail.com	Berkeley	California	210069846351293414	db143397d354f7066209faee1fd7fb03	JCB 15 digit	37.8756757711472289	-122.269666519376557
10856	2020-01-31 04:16:23	2020-01-31	Mr. Newt Abernathy	mr.newt.abernathy@woohoo.com	Houston	Texas	3337889167197678165	d5ca9305bbdb0c97e3ac44fbca5afe03	Voyager	29.7425387598186717	-95.4007270033020518
10857	2020-01-31 04:42:55	2020-01-31	Reinaldo Walter	reinaldo.walter@geemail.com	Oakland	California	4338441280913376	ed68c8423db6c795df424df2dfc0af45	VISA 13 digit	37.8424506314475551	-122.290663309513448
10858	2020-01-31 04:55:01	2020-01-31	Belton Ruecker-Mayert	belton.ruecker.mayert@warmmail.com	New York	New York	52094717171986264	a3300f8b07b85a1a9674f2c0e369734d	JCB 16 digit	40.6872282174639395	-73.9681050541240666
10859	2020-01-31 05:15:38	2020-01-31	Lossie Brakus-Wintheiser	lossie.brakus.wintheiser@geemail.com	San Francisco	California	869991917983109096	8880e5a2b20359a9cc63dd04e78a812e	Mastercard	37.7692873408308216	-122.414586891383948
10860	2020-01-31 05:27:33	2020-01-31	Alyce Mohr	alyce.mohr@geemail.com	Louisville	Kentucky	180053169622696598	d8975824a29259f0781eb0f5107048ef	American Express	38.2287485954254862	-85.6158450618457039
10861	2020-01-31 05:42:14	2020-01-31	Marlena Strosin	marlena.strosin@geemail.com	San Francisco	California	53421705245160234	1a3696e42370000e21f51c32cb2ed3e7	Discover	37.7621871951780008	-122.449549486299688
10862	2020-01-31 06:16:46	2020-01-31	Madison Schuppe Jr.	madison.schuppe.jr.@geemail.com	Oakland	California	4895558034701602	20ea445aa6fc851d00335b8c57bca136	JCB 15 digit	37.7584853003563623	-122.246769741132468
10863	2020-01-31 07:25:24	2020-01-31	Mr. Caiden Kris	mr.caiden.kris@geemail.com	Riverside	California	3337082126501774008	1920e190737eda8f3afd619155639dc1	JCB 16 digit	33.9515562512859717	-117.293743832965191
10864	2020-01-31 07:28:19	2020-01-31	Helaine Hane	helaine.hane@geemail.com	Seattle	Washington	3158768802500408902	e4bcbd9c7d8eb713d725c3fb33c116bf	Mastercard	47.610993332315239	-122.310859093341605
10865	2020-01-31 07:45:49	2020-01-31	Verl Wisozk	verl.wisozk@warmmail.com	Killeen	Texas	3005205030070791	61681db56f489a5e35e2e509c6c6f160	Voyager	31.1118964099556194	-97.8152147717941602
10866	2020-01-31 07:47:15	2020-01-31	Mr. Lanny Armstrong	mr.lanny.armstrong@geemail.com	Washington	District of Columbia	3002656915369646	051aa59e2c441adc483d8d541827ce27	Maestro	38.8406779409185035	-76.9340857719749209
10867	2020-01-31 07:50:25	2020-01-31	Jodi Mitchell-Larson	jodi.mitchell.larson@geemail.com	Berkeley	California	4803864222986	159ee360f4022a609ab7246e41b9b1f8	VISA 13 digit	37.8334294512196792	-122.239860195499347
10868	2020-01-31 08:07:10	2020-01-31	Evangeline Rodriguez	evangeline.rodriguez@warmmail.com	Rockford	Illinois	3746600230302807	218bb379eaf5f3a5d01e5dab8834e8b3	JCB 16 digit	42.3097000988677152	-89.0045752260185736
10869	2020-01-31 08:08:49	2020-01-31	Grady Reichert-Mayer	grady.reichert.mayer@geemail.com	New York	New York	3088427769694656187	2436ea2bc440d4eebbcbee19089501fe	VISA 13 digit	40.6365251186992964	-73.915180870367962
10870	2020-01-31 08:22:46	2020-01-31	Lashawn Nicolas	lashawn.nicolas@warmmail.com	Berkeley	California	180045901088542861	c0b18b27e4fc77fb8f82aac8eb65960e	Mastercard	37.8813001264907143	-122.280427670680311
10871	2020-01-31 08:33:07	2020-01-31	Toma Olson Sr.	toma.olson.sr.@geemail.com	Los Angeles	California	3158840539479973605	c23bf5ee1d9eb5bd5af4fdf14f179857	Voyager	33.9435415611933919	-118.420462635577834
10872	2020-01-31 08:41:41	2020-01-31	Cortney Homenick	cortney.homenick@geemail.com	Pasadena	Texas	4522560823489	176b94f435c2963807daba4d6f077710	VISA 16 digit	29.7130735036790377	-95.1625547253474622
10873	2020-01-31 08:46:20	2020-01-31	Verlene Watsica	verlene.watsica@geemail.com	San Diego	California	501829311564040	d9502d25a91e2f5cde6121f09f12725e	VISA 16 digit	32.8476116361163548	-117.233280265834182
10874	2020-01-31 09:23:16	2020-01-31	Katlynn Glover PhD	katlynn.glover.phd@geemail.com	Los Angeles	California	869999779677042799	8523c1ed521124aa3561b4ed368ae2db	Mastercard	33.9836989719752225	-118.362344836629177
10875	2020-01-31 09:37:16	2020-01-31	Mathias Hagenes	mathias.hagenes@woohoo.com	San Francisco	California	3528884098141900550	9ec3e469fd3e412a399891a03a638de4	JCB 16 digit	37.7992395764995663	-122.429838093424834
10876	2020-01-31 09:38:49	2020-01-31	Guido Conn-Maggio	guido.conn.maggio@geemail.com	New York	New York	3051931050350326	4711e0e6533b181b7acd03449f2e9832	VISA 16 digit	40.5934951702821962	-74.0179727117426722
10877	2020-01-31 09:43:13	2020-01-31	Dr. Robbie Kub Sr.	dr.robbie.kub.sr.@warmmail.com	Richmond	Virginia	180004754409404603	c69ec157a84baa3e49e75d3b385063fa	JCB 15 digit	37.5174427055973538	-77.4851795992571795
10878	2020-01-31 10:02:12	2020-01-31	Amari Murphy PhD	amari.murphy.phd@geemail.com	Columbia	Missouri	869912101739692160	c83850e9d24ca3844889b1eff6b6dfd9	Discover	38.9127814422242935	-92.3867342333362558
10879	2020-01-31 10:27:29	2020-01-31	Benson Friesen	benson.friesen@geemail.com	Los Angeles	California	3337290337269536707	9961637995cd605ed9621292062833a9	JCB 16 digit	34.0204361440945391	-118.471918571506805
10880	2020-01-31 10:52:17	2020-01-31	Felicia Welch-Stiedemann	felicia.welch.stiedemann@geemail.com	Oakland	California	210005240378461054	ff34c5a0dd6376e51122c90873dd050c	Maestro	37.8042784872593813	-122.254790689788933
10881	2020-01-31 11:00:55	2020-01-31	Roxanne Pagac-Leannon	roxanne.pagac.leannon@geemail.com	New York	New York	3057954253519053	41fab2fa062da797ffbf96883aac842a	JCB 16 digit	40.5852106967698774	-73.9436004426225963
10882	2020-01-31 11:24:30	2020-01-31	Gee Farrell	gee.farrell@geemail.com	Berkeley	California	53863404284964939	6f98b77ee11f7b211aaab52e754343b5	VISA 13 digit	37.8219658028688954	-122.290308991123155
10883	2020-01-31 11:33:23	2020-01-31	Trudie Marvin	trudie.marvin@geemail.com	College Station	Texas	3716925155767288	af12ecabe40f51e56c39ea0424aa038e	VISA 13 digit	30.5486627012535941	-96.2207998101912523
10884	2020-01-31 12:27:31	2020-01-31	Ellie Ullrich	ellie.ullrich@geemail.com	Moreno Valley	California	4469453877521	768b8ca86ff45995cb98dfab17d9d6b0	VISA 16 digit	33.8328934575423546	-117.150438685386248
10885	2020-01-31 13:36:02	2020-01-31	Carmel Mosciski	carmel.mosciski@woohoo.com	Frisco	Texas	3096919126129821487	8fda64d6fac29c3156a35ff2da528062	VISA 16 digit	33.2545179238539177	-96.9014935706484977
10886	2020-01-31 13:59:21	2020-01-31	Luvenia Ratke	luvenia.ratke@woohoo.com	Phoenix	Arizona	561257534516208	cf240dc022240705aa6e7da61e601958	American Express	33.5924632861677566	-112.180550121648622
10887	2020-01-31 14:25:31	2020-01-31	Dr. Anthony Von	dr.anthony.von@warmmail.com	El Paso	Texas	4796919631490181	4bd00d74bd56a8553ddc0d4b0bc9cc29	VISA 13 digit	31.8176158053629123	-106.435977267332376
10888	2020-01-31 14:47:12	2020-01-31	Miss Tennessee Reichel PhD	miss.tennessee.reichel.phd@geemail.com	San Antonio	Texas	180002866342574656	bb7eeecb5412ad89294a1449d7b6faf4	JCB 15 digit	29.4470056536678229	-98.6172335094608314
10889	2020-01-31 15:21:24	2020-01-31	Noreta Feeney	noreta.feeney@geemail.com	Detroit	Michigan	3096694243979186811	45962d04f21851ae641394811b3bbc19	Diners Club / Carte Blanche	42.4324980033952741	-83.1394713617049064
10890	2020-01-31 15:37:38	2020-01-31	Seamus Wyman	seamus.wyman@geemail.com	Oakland	California	210045601225853714	377543f17ae437bd449f3aabb663eba9	VISA 16 digit	37.755732315423451	-122.276609214378794
10891	2020-01-31 15:46:29	2020-01-31	Mr. Vincenzo Kunze	mr.vincenzo.kunze@geemail.com	New York	New York	4134703443363	2738aef45a65947c834d3ec6d2b74be7	Discover	40.6225472031384669	-73.8991228624142735
10892	2020-01-31 15:57:45	2020-01-31	Marissa Bayer DDS	marissa.bayer.dds@geemail.com	Chicago	Illinois	210029210065193668	27f93d5064f47972f1311198f2f2ed5b	VISA 13 digit	41.8290027995895599	-87.6944104336231902
10893	2020-01-31 16:16:12	2020-01-31	Dr. Demarion Anderson	dr.demarion.anderson@woohoo.com	San Francisco	California	3058231554797376	b3e37d63ff362401228db62507759728	American Express	37.7988032155319686	-122.402241899902307
10894	2020-01-31 16:20:38	2020-01-31	Ms. Chantel Monahan MD	ms.chantel.monahan.md@warmmail.com	Richardson	Texas	3051123861183274	86034ac24142f6dc8a57d2ce7a852a5b	JCB 15 digit	32.9013000929497181	-96.8026083488710185
10895	2020-01-31 16:22:43	2020-01-31	Aloys Ziemann DDS	aloys.ziemann.dds@warmmail.com	Oakland	California	3037285058414582	a2e652af17e94adde419bf18acf445e9	VISA 16 digit	37.8069673402306918	-122.279326696234307
10896	2020-01-31 16:34:55	2020-01-31	Dr. Unknown Schmitt	dr.unknown.schmitt@geemail.com	Murfreesboro	Tennessee	4657400347545	c4f0c7045327a5604e940f226d6ba0d0	Diners Club / Carte Blanche	35.933732416865233	-86.3706343576628655
10897	2020-01-31 16:39:00	2020-01-31	Ms. Imani Conroy MD	ms.imani.conroy.md@woohoo.com	Minneapolis	Minnesota	869956766309801255	7f0eee00456329b557689205c712af63	JCB 16 digit	44.8692240162838232	-93.2739347758974873
10898	2020-01-31 16:41:12	2020-01-31	Liz Stracke	liz.stracke@geemail.com	Albuquerque	New Mexico	869976701842235139	8b53621f2f5af0357a654db803e922fd	Mastercard	35.1352713976189506	-106.639304455609619
10899	2020-01-31 16:44:43	2020-01-31	Dr. Newton Nolan III	dr.newton.nolan.iii@geemail.com	Salt Lake City	Utah	3027313593274137	f2540a3cee213eff2d35b870e56d0a71	Mastercard	40.7108602603111365	-111.856729839364064
10900	2020-01-31 17:25:06	2020-01-31	Mr. Collie Gleason MD	mr.collie.gleason.md@geemail.com	San Jose	California	180026133726556029	714b5235068641c2ca0e043897cdb96c	VISA 16 digit	37.3850018649648916	-121.89105731223114
10901	2020-01-31 17:27:51	2020-01-31	Misael Greenfelder	misael.greenfelder@geemail.com	Lincoln	Nebraska	4526382016682491	f4d78e293ecf7e25fe961c4412348719	JCB 16 digit	40.8715788439400498	-96.6700131490521102
10902	2020-01-31 17:47:29	2020-01-31	Mr. Brett Abshire V	mr.brett.abshire.v@geemail.com	Indianapolis	Indiana	180024168603709707	10a536764a763dd42d9968fac739850f	VISA 16 digit	39.813162879087777	-86.1129510980300523
10903	2020-01-31 17:52:09	2020-01-31	Isabelle Bartell	isabelle.bartell@woohoo.com	Hartford	Connecticut	4875163736320	562eb3c28e9adb9d5c474aab1ed895b9	Mastercard	41.6996328040041035	-72.6461102825015814
10904	2020-01-31 17:53:15	2020-01-31	Barnett Haley	barnett.haley@woohoo.com	South Bend	Indiana	3096657763470327312	6296496cce5601c5bf15542af37478c8	VISA 16 digit	41.7662179981969359	-86.1719993370175388
10905	2020-01-31 17:58:26	2020-01-31	Enos O'Reilly	enos.o'reilly@woohoo.com	Vista	California	675934381921989	ff9b30d08072b44e3aaf328a3a268858	JCB 16 digit	33.1152639281917374	-117.243761211593082
10906	2020-01-31 18:10:01	2020-01-31	Margurite Dooley	margurite.dooley@geemail.com	Gresham	Oregon	6011770489685726146	234e84419861332e3db8c76e994e2c31	JCB 16 digit	45.5718704461075319	-122.36263859344497
10907	2020-01-31 18:13:42	2020-01-31	Falon Hills	falon.hills@geemail.com	Temecula	California	52643701983804242	4aa9f9b7db1c24438066aec6d6e47b57	Diners Club / Carte Blanche	33.4360785941261796	-117.069828150114787
10908	2020-01-31 18:24:34	2020-01-31	Mr. Bradyn King DDS	mr.bradyn.king.dds@geemail.com	Elk Grove	California	3337248149750343987	4bdc7f8fd660e8d1ef0f26d4ac0e51ac	VISA 13 digit	38.3594106638621568	-121.393309505321085
10909	2020-01-31 19:17:57	2020-01-31	Andre Rau	andre.rau@geemail.com	Alexandria	Virginia	3414634186095451	976925f1ad04e0d5ac3d3d8945e759c5	Voyager	38.7793848136089707	-77.1391295638851915
10910	2020-01-31 19:19:48	2020-01-31	Harvy Senger	harvy.senger@warmmail.com	Nashville	Tennessee	4732790156986557	994eeca3afaa98ae01eab127b8b3ef9f	VISA 13 digit	36.1163759018883113	-86.7058818716462696
10911	2020-01-31 19:27:51	2020-01-31	Shelba Stracke	shelba.stracke@geemail.com	Chicago	Illinois	51172456408651285	d11d520218024dea577dbdca4ca7c7fa	JCB 15 digit	41.7585161732811514	-87.6610331652715757
10912	2020-01-31 19:32:52	2020-01-31	Glynda Turner-Dare	glynda.turner.dare@woohoo.com	Oakland	California	4308844438053837	4bbbdaf4528f8e5d17d398fba0777218	VISA 13 digit	37.8117255065085089	-122.260140549237335
10913	2020-01-31 19:46:09	2020-01-31	Bryson Mann II	bryson.mann.ii@geemail.com	Los Angeles	California	6011915555719746437	a5bc502a8943fe9497e55c06c8965def	JCB 16 digit	34.0599169671867017	-118.384881962835038
10914	2020-01-31 19:46:42	2020-01-31	Allyson Wolff-Sawayn	allyson.wolff.sawayn@warmmail.com	Houston	Texas	3158326337882799284	92a368af80a3c3ae2864695744ef7789	American Express	29.6953156263645752	-95.3470964160297143
10915	2020-01-31 20:09:25	2020-01-31	Mellissa Kerluke DDS	mellissa.kerluke.dds@woohoo.com	Omaha	Nebraska	3020982932236408	6fd3610822367ceb0d4ffadfe766142d	Diners Club / Carte Blanche	41.3559595225524177	-95.9854098595794341
10916	2020-01-31 20:10:54	2020-01-31	Mr. Hubert O'Hara	mr.hubert.o'hara@warmmail.com	San Francisco	California	3432185255949837	bfa149adc4045ba622a51b9a2385c8e3	Maestro	37.7573161240241362	-122.441317736513412
10917	2020-01-31 20:11:42	2020-01-31	Carolee Hills	carolee.hills@geemail.com	Spokane	Washington	210057997497173277	35d2600d3786ff23102252efd0083677	Mastercard	47.6579536227282148	-117.513081944770363
10918	2020-01-31 20:59:41	2020-01-31	London Walsh	london.walsh@geemail.com	San Francisco	California	55558437163303852	788441ccae5f484dddce05e886340366	VISA 16 digit	37.7690484543374154	-122.451267032280583
10919	2020-01-31 21:45:55	2020-01-31	Jalyn Smith	jalyn.smith@geemail.com	Montgomery	Alabama	3096116054169305693	cbfa4e6955dfda7858ed6c82b66a2aab	JCB 16 digit	32.3304431352231632	-86.3579943167198394
10920	2020-01-31 21:55:22	2020-01-31	Dona Kirlin	dona.kirlin@geemail.com	Charlotte	North Carolina	869945923954931101	e742760c94c727658ce316b59d19d59a	JCB 15 digit	35.1382348749108573	-80.915421894233674
10921	2020-01-31 21:56:30	2020-01-31	Miss Etna Wisoky MD	miss.etna.wisoky.md@geemail.com	Sacramento	California	3337981357030220633	945361316e785cbf694ec2a7aba0cf23	VISA 13 digit	38.544999354871365	-121.543951485330609
10922	2020-01-31 22:18:45	2020-01-31	Margurite Mayer	margurite.mayer@geemail.com	Sioux Falls	South Dakota	675979830008664	bde77a750f339f2e1ff876969b338270	Maestro	43.4723901163406694	-96.7650885725095833
10923	2020-01-31 22:28:38	2020-01-31	Keandre O'Kon	keandre.o'kon@geemail.com	Huntsville	Alabama	3735903861439598	3bd22d32aa96561b32ab5d19348fecf4	American Express	34.7512239092271784	-86.6476168192941714
10924	2020-01-31 22:43:17	2020-01-31	Ms. Joanne O'Connell	ms.joanne.o'connell@geemail.com	New York	New York	210064421254132534	af213cbc0f554e316f8e81c82547add1	JCB 15 digit	40.6555482864137758	-73.8493027687434136
10925	2020-01-31 23:25:01	2020-01-31	Harvy Schultz	harvy.schultz@geemail.com	San Francisco	California	4870166085673974	45bf8cc6c2911b7e526116455955954c	VISA 16 digit	37.7548492350159677	-122.448445320793937
10926	2020-01-31 23:29:30	2020-01-31	Dr. Hurbert Goyette DVM	dr.hurbert.goyette.dvm@geemail.com	Austin	Texas	3022539708657627	c360be2377dab4d3dcfbcedd7e59dd8f	Diners Club / Carte Blanche	30.3757708973377945	-97.7967243411816725
10927	2020-01-31 23:43:57	2020-01-31	Rosemary Brakus	rosemary.brakus@geemail.com	New York	New York	869974559429738475	44f402188a415a5ce6c4dab293fefb88	VISA 16 digit	40.7328459845148032	-73.921971010825402
10928	2020-01-31 23:53:52	2020-01-31	Letta Labadie	letta.labadie@geemail.com	San Francisco	California	4545871060230014	83093e2170ebeac46900b5cfe2f2a0b5	Mastercard	37.7561526973743469	-122.411956292065852
10929	2020-02-01 00:15:41	2020-02-01	Chace Flatley	chace.flatley@geemail.com	Tacoma	Washington	4078058450970	05b894d0219de58740b6dd3fe5df8e21	Maestro	47.1827891109630499	-122.42355109283254
10930	2020-02-01 00:23:43	2020-02-01	Mr. Captain Thompson I	mr.captain.thompson.i@woohoo.com	San Francisco	California	4373418261063310	d77626ce1bf98aba96455db4907d9f58	VISA 13 digit	37.7686900979055764	-122.433757921889111
10931	2020-02-01 01:36:57	2020-02-01	Keven Steuber	keven.steuber@warmmail.com	New York	New York	180090254224821276	92c5e4112d08853cdf9ef8174b0290c1	JCB 16 digit	40.6485584960076949	-73.8607647612120957
10932	2020-02-01 01:47:03	2020-02-01	Olaf Greenholt	olaf.greenholt@woohoo.com	Denver	Colorado	6011187602274334059	c768a0bf8dc6b995aae6151910122c09	JCB 16 digit	39.7543940271303029	-104.818452159665895
10933	2020-02-01 01:48:54	2020-02-01	Dr. Deegan Price II	dr.deegan.price.ii@geemail.com	Vallejo	California	3337718658414053577	f55c7c0397431715651c57f4057ab024	Discover	38.0448945895858088	-122.357863020278515
10934	2020-02-01 02:17:47	2020-02-01	Lillie Wiza	lillie.wiza@geemail.com	Overland Park	Kansas	52597938240200592	8eb2cb6256eb0607713ec5a1b4762cd2	Diners Club / Carte Blanche	38.8092496662270321	-94.7731697011314367
10935	2020-02-01 03:58:52	2020-02-01	Ermine Hills	ermine.hills@woohoo.com	San Francisco	California	6011727340048777264	0767f32121490fad4a4f3195887c3c4a	Diners Club / Carte Blanche	37.7670291222308876	-122.423123842936064
10936	2020-02-01 04:25:59	2020-02-01	Aaden Hintz-Konopelski	aaden.hintz.konopelski@geemail.com	Thornton	Colorado	6011716367118383940	03f1fe1ed16b57d6084c6582b1f5f04e	Mastercard	40.0126535184547336	-104.937335027351239
10937	2020-02-01 04:26:38	2020-02-01	Ishaan Nikolaus	ishaan.nikolaus@woohoo.com	Portland	Oregon	3337229430623891615	5392962afeca7e7b95cce7d262ae4cf3	Voyager	45.4504747161064273	-122.609080005902797
10938	2020-02-01 04:27:35	2020-02-01	Tamie Hickle DVM	tamie.hickle.dvm@geemail.com	San Francisco	California	869910861662729329	7199288471ecc6ed801144ca09b34866	Mastercard	37.8030949911612524	-122.45111236402542
10939	2020-02-01 04:34:29	2020-02-01	Aspen Price	aspen.price@geemail.com	San Francisco	California	4737109780192372	e22338bfd1777cd207ab12f4da8e3135	VISA 16 digit	37.7615940036724069	-122.414416833332211
10940	2020-02-01 04:34:50	2020-02-01	Dr. Kaylene McCullough DVM	dr.kaylene.mccullough.dvm@geemail.com	San Francisco	California	3112484672323283615	90b9f52337a7f20d90a565429ce87004	VISA 13 digit	37.7877147442479853	-122.449899001024363
10941	2020-02-01 04:42:12	2020-02-01	Mr. Demarcus Denesik DDS	mr.demarcus.denesik.dds@geemail.com	Wichita	Kansas	3112538798324468552	7ddef65aef699d86ca4306173e723f74	Voyager	37.6698397370863702	-97.3477204872962147
10942	2020-02-01 04:49:00	2020-02-01	Eddie Rohan	eddie.rohan@warmmail.com	San Francisco	California	210066688035283731	d68ddf2c0aa5ff292981d3500436dd1b	Voyager	37.7645311291537524	-122.39613188902446
10943	2020-02-01 04:50:14	2020-02-01	Ronan Anderson	ronan.anderson@woohoo.com	Vallejo	California	3112564413391299578	d6d0309fcbfcb05f4a39a00ce38cf19f	Diners Club / Carte Blanche	38.1247671119026847	-122.26472944178245
10944	2020-02-01 04:52:54	2020-02-01	Dr. Cyrus Koch Sr.	dr.cyrus.koch.sr.@geemail.com	Washington	District of Columbia	3528279532492463944	c9badd2d226172174e9b7e705173f9e0	Discover	38.9084833841104043	-77.0417427997782909
10945	2020-02-01 04:58:29	2020-02-01	Mr. Ewart Sauer	mr.ewart.sauer@warmmail.com	Kent	Washington	676196197339763	833e106f8b84f49e8bfe8185b69faf4f	VISA 16 digit	47.342079925827683	-122.177226918716727
10946	2020-02-01 04:59:02	2020-02-01	Dr. Rosco Daniel	dr.rosco.daniel@warmmail.com	Orlando	Florida	51351280061226208	c73b76cb48e1fa1898e4d95490edc906	American Express	28.3983428474314508	-81.2892402931083069
10947	2020-02-01 05:05:42	2020-02-01	Marquise Wiza	marquise.wiza@geemail.com	San Francisco	California	180002206537911746	a483309e103257b196ee4d367a1e77d1	JCB 16 digit	37.8137406896343293	-122.415885380994013
10948	2020-02-01 05:10:27	2020-02-01	Edwardo Hodkiewicz	edwardo.hodkiewicz@geemail.com	Berkeley	California	6011079223515696858	84cabec7833f31f560ef78a59852e8ac	Diners Club / Carte Blanche	37.8689262685450529	-122.242829044722683
10949	2020-02-01 05:14:55	2020-02-01	Miss Carmel Prohaska DVM	miss.carmel.prohaska.dvm@woohoo.com	Miramar	Florida	3337946101796742073	17631c23e8a7a859297623765cf75b02	JCB 16 digit	25.9933492638152082	-80.2505336936090146
10950	2020-02-01 05:55:51	2020-02-01	Matias Wolf Jr.	matias.wolf.jr.@woohoo.com	Fort Wayne	Indiana	52154297382298376	cc63410cc91ad5db80c0fa030b5975a6	JCB 15 digit	41.0812633003823464	-85.1287598008975408
10951	2020-02-01 06:02:18	2020-02-01	Darci Hammes	darci.hammes@geemail.com	San Francisco	California	3444714691737021	26c2ea9cb045424b5223a4ac8f4321f1	Discover	37.7816984063637449	-122.470090271317162
10952	2020-02-01 06:09:55	2020-02-01	Callie Larson	callie.larson@geemail.com	New York	New York	3337422742120184749	9eea371d48ec3d6e3fbab120128d0e0a	Maestro	40.5871068804282658	-73.870004664537305
10953	2020-02-01 06:24:42	2020-02-01	Bethany Ryan	bethany.ryan@geemail.com	Newport News	Virginia	6011209317733868837	724252c51a4615d4bebc86b2ba1ad562	Diners Club / Carte Blanche	37.035565895390512	-76.4927333904691125
10954	2020-02-01 07:01:00	2020-02-01	Conrad Lang	conrad.lang@geemail.com	Berkeley	California	3007089081640399	2e73dc61d35733284f75dd53034c0c06	Maestro	37.8616986317388466	-122.282547717273175
10955	2020-02-01 07:09:51	2020-02-01	Delwin Jenkins	delwin.jenkins@geemail.com	Seattle	Washington	3112434819376463906	10dcfad7eac46767bd2921fcf94d3375	JCB 16 digit	47.6802407068125902	-122.426345997994389
10956	2020-02-01 07:10:51	2020-02-01	Alphonsine Glover-Kunde	alphonsine.glover.kunde@geemail.com	Oakland	California	4499311502730	bd2bbd38c09dc9810e41678a5e8d6cec	Diners Club / Carte Blanche	37.8267246296165283	-122.255731711274464
10957	2020-02-01 07:12:31	2020-02-01	Jaime Champlin	jaime.champlin@geemail.com	Newport News	Virginia	869904877496891380	7a3b9f5be18d2df8833410329bf374ac	VISA 16 digit	37.0180453411199153	-76.6004938154276545
10958	2020-02-01 07:14:54	2020-02-01	Jarad Grant	jarad.grant@woohoo.com	San Francisco	California	4930758191264	c1d838805b235a980946a1a533ed7379	Mastercard	37.7615507568313902	-122.414647344723036
10959	2020-02-01 08:09:54	2020-02-01	Dereck Jacobson	dereck.jacobson@geemail.com	Washington	District of Columbia	3112608545202441259	cdc95b507fc129ad5a88bdfef672d169	VISA 13 digit	38.8256514834970261	-76.986126696106794
10960	2020-02-01 08:24:26	2020-02-01	Makai Kautzer	makai.kautzer@geemail.com	Knoxville	Tennessee	6011363094387079068	8498ef200c861afb40e69bad50da732a	JCB 15 digit	35.949086505879464	-84.0368026901252563
10961	2020-02-01 08:27:57	2020-02-01	Dr. Moshe Botsford Sr.	dr.moshe.botsford.sr.@geemail.com	Moreno Valley	California	3012726200442844	e627665f51491c649e1d843b11b64359	Discover	33.9965145802583493	-117.22820079899094
10962	2020-02-01 08:39:03	2020-02-01	Paulo Stamm	paulo.stamm@geemail.com	Oakland	California	4456271393446923	c598ee421ee93ec474f0966a0992d2a3	VISA 16 digit	37.779895598110933	-122.255945270262643
10963	2020-02-01 08:51:02	2020-02-01	Gennaro Fritsch	gennaro.fritsch@geemail.com	Columbus	Ohio	4332465520580	5aaba6ae79a62ecfaad5d9ecefd41d1f	JCB 16 digit	40.0154534142509064	-82.9758898600239405
10964	2020-02-01 08:57:33	2020-02-01	Irene Muller	irene.muller@geemail.com	San Jose	California	4802444530686	42553b3bdcee5b2dd1dc0693f98754e1	JCB 15 digit	37.3426082564804744	-121.723325168130543
10965	2020-02-01 09:16:09	2020-02-01	Elex Douglas	elex.douglas@warmmail.com	New York	New York	210012303919429963	bf36712c8e65d9f19d598ec423617da1	Diners Club / Carte Blanche	40.6448440385740213	-73.9214169470023279
10966	2020-02-01 09:36:53	2020-02-01	Mr. London Wolff	mr.london.wolff@warmmail.com	Los Angeles	California	4788545448182685	afba9383ec1d045c8929e8db6020232a	Mastercard	33.9713019193481642	-118.412356692412118
10967	2020-02-01 09:37:39	2020-02-01	Ms. Anika Becker	ms.anika.becker@geemail.com	North Charleston	South Carolina	4754314281751	16547ccef31374a9422dd0ca51f8dd31	VISA 16 digit	32.9898563775394109	-80.0106357866060023
10968	2020-02-01 09:56:00	2020-02-01	Miss Winnifred Wiza PhD	miss.winnifred.wiza.phd@geemail.com	San Francisco	California	3723464560955669	137b28c459970f18d9f488ae36435373	JCB 15 digit	37.7463156035958747	-122.455338709427878
10969	2020-02-01 10:07:58	2020-02-01	Siobhan Daugherty DVM	siobhan.daugherty.dvm@warmmail.com	New York	New York	3528714969660446942	ee06a4ea99a79bed21d69b5dcc87e6d4	VISA 16 digit	40.7258156797140813	-73.9501022039808333
10970	2020-02-01 10:42:27	2020-02-01	Phoenix Grant	phoenix.grant@woohoo.com	San Antonio	Texas	869988688725487281	f621be6a58f4d56510f0d51619cc62fc	Voyager	29.3737122105970982	-98.4607381619349127
10971	2020-02-01 10:50:15	2020-02-01	Salomon Carroll I	salomon.carroll.i@geemail.com	San Francisco	California	6011299435818113522	f82626ffa2ac0c549a5840f82edb868d	Mastercard	37.7817833492653889	-122.43964010897011
10972	2020-02-01 11:00:53	2020-02-01	Miss Celena Luettgen DDS	miss.celena.luettgen.dds@geemail.com	Tallahassee	Florida	3435334184180042	896a20c3e58e331ee545e06deca4ac76	Discover	30.3809907030336568	-84.286337509799381
10973	2020-02-01 11:08:36	2020-02-01	Miss Dimple Greenfelder DDS	miss.dimple.greenfelder.dds@geemail.com	Allen	Texas	54140820635498043	bdebd1546960fb0e41f4a2f59e1b68b9	VISA 16 digit	33.1768808780729785	-96.7422559532750341
10974	2020-02-01 11:14:50	2020-02-01	Dr. Junious Ankunding	dr.junious.ankunding@geemail.com	Evansville	Indiana	4725333019158	2865927d0e15e2c21f237d90362e091f	VISA 16 digit	37.9923111462637735	-87.5900467083722418
10975	2020-02-01 11:26:43	2020-02-01	Dr. Eber Spinka V	dr.eber.spinka.v@geemail.com	Atlanta	Georgia	3007968706373942	70a156b991e168537469f41bdd71c526	JCB 16 digit	33.7710195560283992	-84.4073912985667647
10976	2020-02-01 11:30:27	2020-02-01	Ilene Maggio-Casper	ilene.maggio.casper@warmmail.com	San Francisco	California	4198695244311	4bb897701c5c2f5948ca3309aa40ddda	JCB 16 digit	37.7718467335652264	-122.448020646314319
10977	2020-02-01 11:30:48	2020-02-01	Ason Waelchi	ason.waelchi@geemail.com	San Francisco	California	4841055385397499	3be95e33cc4d2c3281619b7a2a11eeec	Mastercard	37.7607396536705124	-122.46171759901172
10978	2020-02-01 11:38:26	2020-02-01	Lakendra Medhurst	lakendra.medhurst@warmmail.com	San Francisco	California	3528289976803211492	f2f33ede1812387e6a573c5155038c4a	VISA 16 digit	37.814409078633453	-122.441457334712993
10979	2020-02-01 11:43:05	2020-02-01	Francis Botsford-Ortiz	francis.botsford.ortiz@geemail.com	Lafayette	Louisiana	4345892175385578	4c7b760f76e569e7253a5e5738a5d76e	VISA 16 digit	30.1107075958024701	-92.1013588692378136
10980	2020-02-01 12:02:39	2020-02-01	Donal Zemlak	donal.zemlak@warmmail.com	Hialeah	Florida	210086010206295236	8f5a87b01a03026314b093ea1f69811c	VISA 16 digit	25.78048165994473	-80.3868778699446409
10981	2020-02-01 12:05:51	2020-02-01	Deb Effertz	deb.effertz@geemail.com	Los Angeles	California	4175996030440612	ccb4521505e3699d08ef692130706500	VISA 13 digit	34.0333436563942584	-118.36293741390034
10982	2020-02-01 12:31:34	2020-02-01	Mr. Gary Fisher	mr.gary.fisher@woohoo.com	Yonkers	New York	180047439477481738	9b40530d9b3f000724932546667b3aa0	VISA 13 digit	41.0321412202637674	-73.8826313597500359
10983	2020-02-01 13:05:46	2020-02-01	Reyes Mohr	reyes.mohr@woohoo.com	Berkeley	California	180044192258465742	baaf347481d9778e3706b2f4009df946	VISA 16 digit	37.8797058902250399	-122.267810924287531
10984	2020-02-01 13:22:42	2020-02-01	Bertie Huels	bertie.huels@geemail.com	San Francisco	California	3029254240132641	288f8b7950058872f664b4620c1817a6	Mastercard	37.7739376680950443	-122.455130137664185
10985	2020-02-01 13:32:21	2020-02-01	Kimberlee Gleason	kimberlee.gleason@warmmail.com	San Francisco	California	869904268983834614	9f9358b921124b49dad9744673c8f6da	JCB 16 digit	37.7481602557511167	-122.413386210610611
10986	2020-02-01 13:42:06	2020-02-01	Georgeanna Jast	georgeanna.jast@warmmail.com	Seattle	Washington	4711411377783088	0cd94e9a08fd3640bdb9a0e7e1f347d7	JCB 15 digit	47.5561272243428945	-122.319225584568073
10987	2020-02-01 14:08:14	2020-02-01	Mr. Roll Beer MD	mr.roll.beer.md@woohoo.com	Tulsa	Oklahoma	4641140668634	df7fa52e467a01afc9a379aecc475f1e	VISA 16 digit	36.0571455981019824	-95.8602372275620667
10988	2020-02-01 15:29:04	2020-02-01	Bena Dickens MD	bena.dickens.md@geemail.com	Berkeley	California	676161072242623	500153f84f215245dff70efc6dabc333	JCB 15 digit	37.898797604372028	-122.29281526987306
10989	2020-02-01 15:44:14	2020-02-01	Brigitte Corkery	brigitte.corkery@geemail.com	San Francisco	California	3016977385293611	3b26356f5b220bc533b7c03faab29013	JCB 16 digit	37.7734613440258187	-122.414793980653656
10990	2020-02-01 16:05:44	2020-02-01	Jetta Waelchi	jetta.waelchi@warmmail.com	Oakland	California	3096834034177614543	6b7070a11263f555e69b4d68f03d1882	JCB 16 digit	37.8115066802851842	-122.277496690432756
10991	2020-02-01 16:20:13	2020-02-01	Miss Marnita Carroll	miss.marnita.carroll@woohoo.com	St. Petersburg	Florida	4999924769880315	baceed3841ce202246f089cf260d4b8a	VISA 16 digit	27.7457380836717782	-82.6732457893326824
10992	2020-02-01 16:34:38	2020-02-01	Arlo Strosin IV	arlo.strosin.iv@woohoo.com	Los Angeles	California	4127611338949	15c063ae66018a368e122664af6f94cc	Mastercard	33.9543957952275832	-118.478269830904154
10993	2020-02-01 16:49:11	2020-02-01	Ebba DuBuque	ebba.dubuque@geemail.com	Salt Lake City	Utah	3048276393947757	73ac4891edb99ee3d24619ce76cdf70c	VISA 13 digit	40.7084931583289062	-111.971534799313176
10994	2020-02-01 16:51:49	2020-02-01	Jeromy Borer DVM	jeromy.borer.dvm@geemail.com	El Monte	California	561214801480410	a1d554cad60d12dd810d32f7e786b12d	VISA 13 digit	34.0339988914042664	-117.986348275913301
10995	2020-02-01 16:52:58	2020-02-01	Dawna Jacobi MD	dawna.jacobi.md@warmmail.com	Brownsville	Texas	3528848407267332875	8ef5c00f7130cf5f8969d4be836af23b	Discover	25.919824475150925	-97.4255365615431259
10996	2020-02-01 17:05:55	2020-02-01	Jadon Stoltenberg	jadon.stoltenberg@geemail.com	Colorado Springs	Colorado	55655718200107899	30c8d7b525650a818ece348dcc56ab3d	JCB 15 digit	38.8841289189226913	-104.824230495809388
10997	2020-02-01 17:09:51	2020-02-01	Ms. Gladys Welch	ms.gladys.welch@geemail.com	Port St. Lucie	Florida	4382148312279842	fe50cc47c22f6c18e6858f0b14dbeaee	JCB 16 digit	27.2329160347715025	-80.4092594946820327
10998	2020-02-01 17:31:22	2020-02-01	Chrissy Ondricka	chrissy.ondricka@geemail.com	New York	New York	6011295951635193491	fb0dde225070c91414a0b170de223356	JCB 16 digit	40.7282642693482302	-73.9377817990153972
10999	2020-02-01 17:38:01	2020-02-01	Ms. Latoyia Prosacco PhD	ms.latoyia.prosacco.phd@woohoo.com	Denver	Colorado	4332578394774	842ba7a53b506395e4e1f2452d039081	JCB 16 digit	39.7022070900123509	-104.911042811327064
11000	2020-02-01 17:58:29	2020-02-01	Elyssa Ankunding	elyssa.ankunding@warmmail.com	Henderson	Nevada	4656186814009	6ae23c254a945301126bdb9d2acf419a	Maestro	36.0877133590102233	-115.121131437660011
11001	2020-02-01 18:30:46	2020-02-01	Camren Kub-Boyer	camren.kub.boyer@geemail.com	Berkeley	California	4157893085215	68fa42bb3dfa593a18b2155c792015c3	VISA 16 digit	37.8564663085779358	-122.274143343905763
11002	2020-02-01 18:35:47	2020-02-01	Mr. Gunner Price Jr.	mr.gunner.price.jr.@geemail.com	Pasadena	California	3749493958373706	2c76214e4264cb6245aceee6f1d6da65	Mastercard	34.1366247149504716	-118.049376191553108
11003	2020-02-01 18:45:03	2020-02-01	Kristin Anderson-Berge	kristin.anderson.berge@geemail.com	Dallas	Texas	561253162604549	deb79e434610f817a0cc0b2952f0fbb4	Maestro	32.7097473426528325	-96.8417565595786982
11004	2020-02-01 19:01:20	2020-02-01	Romello Blick	romello.blick@geemail.com	Burbank	California	4708435367909036	5889014b9c98c82b43c36036e1f05f2f	Diners Club / Carte Blanche	34.2769808054830918	-118.381594990569738
11005	2020-02-01 19:31:38	2020-02-01	Lyndsey Harvey	lyndsey.harvey@warmmail.com	San Francisco	California	3009982952985349	60970202878bdb2e4cb7bd11fab2361b	JCB 15 digit	37.8037365764026987	-122.398467219616862
11006	2020-02-01 20:43:08	2020-02-01	Efrem Fay V	efrem.fay.v@woohoo.com	Yonkers	New York	3734994532722315	26f180513c6afcf1e19c0383a6a0e7fa	Diners Club / Carte Blanche	41.0096241315096606	-73.9563629991725122
11007	2020-02-01 20:43:21	2020-02-01	Chantal Ryan	chantal.ryan@geemail.com	Thornton	Colorado	3718270632939723	29a396b6909648b055efc598572fb546	VISA 16 digit	39.9311848130874338	-104.988124876438832
11008	2020-02-01 21:50:47	2020-02-01	Lorelei Stiedemann	lorelei.stiedemann@geemail.com	New York	New York	869980769682308161	051b048444f95f7bf0e6970a347b2ada	JCB 16 digit	40.6020531794279833	-73.880627536437288
11009	2020-02-01 22:53:17	2020-02-01	Shemar King V	shemar.king.v@woohoo.com	New York	New York	4052781642785036	005e63402418067e83eaf5e11706af05	Mastercard	40.6765633303429937	-73.9780651273101597
11010	2020-02-01 22:56:44	2020-02-01	Lindbergh Harris	lindbergh.harris@geemail.com	San Francisco	California	3058523335521152	46fd8d3b94029d9c5ed233182cf1efae	Diners Club / Carte Blanche	37.789149447841254	-122.440571398844213
11011	2020-02-01 23:12:32	2020-02-01	Julissa Bayer	julissa.bayer@warmmail.com	Abilene	Texas	3444864649174338	34f23879448d862379e3bd3e1f6ded1e	Discover	32.4908108269870297	-99.750779392099389
11012	2020-02-01 23:25:37	2020-02-01	Mitch Harris	mitch.harris@woohoo.com	Fort Wayne	Indiana	4296302016401	a1bae7d171d28a8f77d175282abc67c6	VISA 13 digit	41.1129253328561788	-85.0953419332612384
11013	2020-02-01 23:34:16	2020-02-01	Verne Dach	verne.dach@geemail.com	Virginia Beach	Virginia	4842736438507593	d2845889b3ca0f84e794d6729eb0a182	VISA 13 digit	36.7086565409041938	-75.9778406351011171
11014	2020-02-01 23:48:08	2020-02-01	Octavio Renner	octavio.renner@woohoo.com	Pittsburgh	Pennsylvania	4561167318590039	661102cc9d6733de0127338b28e88490	JCB 15 digit	40.4059152822896834	-79.9241750945042924
11015	2020-02-02 00:25:12	2020-02-02	Dr. Dannie Quitzon	dr.dannie.quitzon@geemail.com	Augusta	Georgia	6011326552413829059	5b887e3bb9aad98b9958253e40f75e8e	VISA 16 digit	33.2813483778592172	-82.0862176986239973
11016	2020-02-02 00:29:32	2020-02-02	Oneta Mosciski-Blick	oneta.mosciski.blick@geemail.com	Albuquerque	New Mexico	6011942250072152731	6e0f65931ad37a4e17e4069b1fcfc1d2	VISA 16 digit	35.1363136962190268	-106.62081503961943
11017	2020-02-02 01:06:38	2020-02-02	Mercedes Cremin	mercedes.cremin@geemail.com	Riverside	California	4901784780803432	4abe3476a146b648cb223896696127ce	Maestro	33.9213531386986347	-117.434776536837958
11018	2020-02-02 01:30:57	2020-02-02	Phebe Gislason DDS	phebe.gislason.dds@geemail.com	Cleveland	Ohio	3032460062586825	1bc54e3a86e1677ea5b85cd95d785d12	JCB 16 digit	41.515665919318792	-81.6554234831832417
11019	2020-02-02 02:00:14	2020-02-02	Kenny Leffler	kenny.leffler@woohoo.com	Lakeland	Florida	3158221792190866421	e54193ae9b234d887e0e0a7b256e1bcd	VISA 13 digit	28.0288169157989309	-81.9031632378581804
11020	2020-02-02 02:26:36	2020-02-02	Daryn McGlynn	daryn.mcglynn@geemail.com	Denver	Colorado	6011703430127409935	fadb72741dad5faf5ec1ca94ac8eea49	VISA 16 digit	39.680596552561596	-104.955820246624199
11021	2020-02-02 02:28:24	2020-02-02	Dr. Mykel Borer PhD	dr.mykel.borer.phd@geemail.com	New York	New York	3488193929390696	d1c4b109ba6f6a45399a0b7b006c86ec	Maestro	40.6049596929680519	-73.9563235547754942
11022	2020-02-02 02:29:47	2020-02-02	Talen Parisian	talen.parisian@geemail.com	Oakland	California	4935958860865	3a9d1bbc9e319386c5c17535bb3c0141	VISA 16 digit	37.8000242331248089	-122.288503378863325
11023	2020-02-02 02:38:19	2020-02-02	Miss Princess Tremblay DDS	miss.princess.tremblay.dds@geemail.com	San Francisco	California	589357872431929	9c6241148d4aba2b508b838d1de62e05	VISA 16 digit	37.7516270583557798	-122.400688292593856
11024	2020-02-02 02:52:29	2020-02-02	Ms. Ellamae Bahringer	ms.ellamae.bahringer@geemail.com	New York	New York	3475975037061044	1282091b87c197d194323a3ec48236bc	Diners Club / Carte Blanche	40.6300180283598564	-73.9501737784955679
11025	2020-02-02 02:52:41	2020-02-02	Jermey Mosciski	jermey.mosciski@geemail.com	Philadelphia	Pennsylvania	3158901881212446978	ddc1c9d11ca64792b9d68d6614c1bc28	American Express	40.062596746623143	-75.1524445300355666
11026	2020-02-02 02:55:11	2020-02-02	Corliss Bechtelar	corliss.bechtelar@geemail.com	San Francisco	California	3337217032373496100	4e498d8be1299883966b87eb9b4b4385	JCB 15 digit	37.774816570925303	-122.466172028022214
11027	2020-02-02 02:56:14	2020-02-02	Mr. Tomie Gusikowski Jr.	mr.tomie.gusikowski.jr.@geemail.com	San Diego	California	210053772685594210	044d4076b377c18283405ac0a14786d2	Diners Club / Carte Blanche	32.7759072857044629	-117.135158452847975
11028	2020-02-02 03:02:51	2020-02-02	Clemmie O'Keefe	clemmie.o'keefe@geemail.com	San Francisco	California	4326804328692449	0b52f43bbf0848e8557f0693861f965a	JCB 15 digit	37.7420242825758976	-122.416672243161727
11029	2020-02-02 03:03:23	2020-02-02	Mrs. Maiya Keebler	mrs.maiya.keebler@geemail.com	Los Angeles	California	180055779575078947	e07e701aa0e432c3621bcb110ae4fbba	Maestro	33.9370038811914583	-118.46832444746903
11030	2020-02-02 03:12:44	2020-02-02	Raekwon Bradtke	raekwon.bradtke@geemail.com	Santa Ana	California	4348496253934	02436bd18b9b8c7395e08e910d8da017	VISA 16 digit	33.8127046437107026	-117.951851056136192
11031	2020-02-02 03:19:53	2020-02-02	Oda Goldner-Rohan	oda.goldner.rohan@geemail.com	Killeen	Texas	4103972114292408	b1f9c8242dd8f79c4a5c9e8fa4265de3	Mastercard	31.0575178138677046	-97.6623659336175791
11032	2020-02-02 03:19:55	2020-02-02	Lisbeth Romaguera-Nicolas	lisbeth.romaguera.nicolas@geemail.com	Charlotte	North Carolina	4271673750279354	d9bb097d6ea0a526e5f9904efa9a025a	VISA 16 digit	35.2111225585240888	-80.8353694541789594
11033	2020-02-02 03:27:36	2020-02-02	Courtney Beier	courtney.beier@warmmail.com	Providence	Rhode Island	4029827418113232	1f7d8edd51fa65e019ae692a426b7f75	Diners Club / Carte Blanche	41.8267890057381209	-71.4566601351752979
11034	2020-02-02 03:44:45	2020-02-02	Shemar Schiller-Mann	shemar.schiller.mann@geemail.com	San Francisco	California	4048893120096	2fd99bf5f91f7df14f2200c5d03151b8	Mastercard	37.8132306751810177	-122.45354280327787
11035	2020-02-02 03:49:38	2020-02-02	Hallie D'Amore	hallie.d'amore@woohoo.com	San Francisco	California	210000197381982283	ce5ee5f0b18cf30d1c6b264a79313ed9	Mastercard	37.7793579529120365	-122.460351679432478
11036	2020-02-02 04:05:28	2020-02-02	Lorelai Deckow	lorelai.deckow@woohoo.com	El Paso	Texas	4984174503693	eb444e112ee3423a6981a6a85aec732c	Mastercard	31.8236271486446292	-106.496585360819481
11037	2020-02-02 04:18:38	2020-02-02	Tye Jones	tye.jones@warmmail.com	New York	New York	6011396474504711358	2d9c1f8e120b6fe9e08897cb088af926	VISA 16 digit	40.744100869003681	-73.9411057170376154
11038	2020-02-02 04:31:00	2020-02-02	Tiffani Skiles	tiffani.skiles@geemail.com	New York	New York	3528004637649300162	cd165ce119b9bdebda13ae98888900db	Voyager	40.5736751199457757	-73.9852475703123957
11039	2020-02-02 04:32:44	2020-02-02	Linnea Orn-Lind	linnea.orn.lind@geemail.com	New York	New York	180091219228725988	db0aa6c1ad62911ffb49d8be8e2b9252	Voyager	40.7429429935514946	-73.9066779336322099
11040	2020-02-02 04:42:18	2020-02-02	Creola Marquardt	creola.marquardt@geemail.com	San Francisco	California	4108294343459087	5a168da6f464c290515a0bb38c9cf55f	Maestro	37.7499058697224896	-122.455447762196101
11041	2020-02-02 04:50:39	2020-02-02	Okey Romaguera	okey.romaguera@warmmail.com	Chicago	Illinois	676255306448808	98428fcdfe0eb5e195c5cda4d5feeb55	VISA 16 digit	41.8776525318924371	-87.6970497381437468
11042	2020-02-02 04:51:24	2020-02-02	Kasie Goodwin DVM	kasie.goodwin.dvm@geemail.com	Yonkers	New York	6011319111756590486	e1e2f23efc05235f956432bee1f88c43	JCB 16 digit	40.8516399665471184	-73.8358736799914368
11043	2020-02-02 05:02:31	2020-02-02	Jodi Kilback-Cremin	jodi.kilback.cremin@geemail.com	San Francisco	California	6011632400120177397	82afde114aee404efa6568928fd52fde	Mastercard	37.8077614043264774	-122.455114519102779
11044	2020-02-02 05:04:57	2020-02-02	Mrs. Penni Rippin DVM	mrs.penni.rippin.dvm@geemail.com	Aurora	Colorado	3434356589525811	ec2b3fd9c5f8880ce060634eb99d70bd	JCB 15 digit	39.6123769142776752	-104.778521316696711
11045	2020-02-02 05:18:45	2020-02-02	Andra Dach	andra.dach@geemail.com	Santa Rosa	California	676338139853709	530f74bd700cd9a33cb53f598004b28f	American Express	38.3571872880805316	-122.637317961572123
11046	2020-02-02 05:56:39	2020-02-02	Vonda Turcotte	vonda.turcotte@geemail.com	Chesapeake	Virginia	210079264704241718	a812787b27297d73669caeb656def9de	Discover	36.6847358272649373	-76.2232959412813216
11047	2020-02-02 06:46:05	2020-02-02	Montie Jacobi-Keebler	montie.jacobi.keebler@geemail.com	Los Angeles	California	3028942136711152	4c1655b091ff5f545d1ec439a0ac7da8	VISA 13 digit	34.0594338473264102	-118.45158068542294
11048	2020-02-02 07:23:03	2020-02-02	Dr. Corinna Sipes	dr.corinna.sipes@geemail.com	Sunnyvale	California	4281484915817320	4b7bf333fdac0eb59b560c2a593f1c37	Discover	37.4635004263363811	-122.078788498063759
11049	2020-02-02 07:45:26	2020-02-02	Carrie Eichmann	carrie.eichmann@woohoo.com	Chicago	Illinois	52413056196012903	3be5ecf035974407a1cb74974c191669	Maestro	41.7672940091531757	-87.6590455424535975
11050	2020-02-02 08:19:07	2020-02-02	Nanette Buckridge-Paucek	nanette.buckridge.paucek@geemail.com	San Francisco	California	3021675223362284	c811a5baf837f77d7ba351c189bdd582	VISA 13 digit	37.7755727209193921	-122.422069833269774
11051	2020-02-02 08:23:45	2020-02-02	Miss Philomena Swaniawski MD	miss.philomena.swaniawski.md@geemail.com	Oakland	California	3158293903924085252	9f69c53751c083b1cab1dcd62c9c3eda	JCB 16 digit	37.8179659841943447	-122.237775180262929
11052	2020-02-02 08:50:14	2020-02-02	Montgomery Lakin MD	montgomery.lakin.md@geemail.com	San Diego	California	3528798321907976456	a65e8a8f11e65f4c66c096e6557cdcfb	Voyager	32.7833531729944028	-117.080867294259377
11053	2020-02-02 09:13:09	2020-02-02	Dennie Dibbert	dennie.dibbert@geemail.com	Houston	Texas	6011898238436298203	8f3622e7661117f5a9da1068c2724170	VISA 16 digit	29.7142873075868934	-95.4334183951854698
11054	2020-02-02 09:20:14	2020-02-02	Mr. Whit Gottlieb	mr.whit.gottlieb@woohoo.com	Newark	New Jersey	4924138123549488	4c77078f068d3580ae37571b090f6991	Voyager	40.736088611549512	-74.2610040142875221
11055	2020-02-02 09:28:30	2020-02-02	Atha Boyer-Mohr	atha.boyer.mohr@geemail.com	El Paso	Texas	4696569252254811	366af3b8a1d3fb8f2f5249c02c74b4ce	American Express	31.8532969842959197	-106.410701712824405
11056	2020-02-02 10:45:43	2020-02-02	Dr. Luke Stiedemann	dr.luke.stiedemann@woohoo.com	San Francisco	California	676160649705211	d0b5d71a65936198d44794e8db546d97	American Express	37.7777944015138871	-122.40296330249825
11057	2020-02-02 10:54:57	2020-02-02	Murray Larson-McCullough	murray.larson.mccullough@geemail.com	New Orleans	Louisiana	4716107061575	11800b9777a32a97e88f66356227955d	JCB 16 digit	30.0607886782862259	-89.8582367404159186
11058	2020-02-02 10:55:36	2020-02-02	Mr. Micah Mills MD	mr.micah.mills.md@geemail.com	Washington	District of Columbia	4405319726700417	0b73d9a5e783eefb040ce97816d1406d	VISA 13 digit	38.8621455383285905	-77.0671649838078849
11059	2020-02-02 11:17:09	2020-02-02	Miss Glinda Mann	miss.glinda.mann@geemail.com	Moreno Valley	California	4426884543387	fa2107080c014c5aeafd28627f1c8c85	American Express	33.869164939922463	-117.210003483944377
11060	2020-02-02 11:28:44	2020-02-02	Butler Raynor	butler.raynor@warmmail.com	San Francisco	California	3337470218638035682	48946cb936722a16064496fe98959772	Mastercard	37.73420441857931	-122.427012173577424
11061	2020-02-02 11:31:58	2020-02-02	Avah Strosin PhD	avah.strosin.phd@geemail.com	Oakland	California	3008493293563762	fe82938c7944bc293dd9df808caffd50	JCB 16 digit	37.7927630041593261	-122.254324634505977
11062	2020-02-02 11:45:21	2020-02-02	Reggie Metz	reggie.metz@geemail.com	Fairfield	California	4349367832783115	9be5676064c0593641be6bc3f26f3e66	Diners Club / Carte Blanche	38.3073383091606203	-121.939599763183296
11063	2020-02-02 11:57:02	2020-02-02	Lizbeth Waelchi-Conroy	lizbeth.waelchi.conroy@warmmail.com	Los Angeles	California	3112501336505829269	f135a52d490d6bc48964d6e26391504b	Discover	34.1097512195218329	-118.449742820345975
11064	2020-02-02 12:15:15	2020-02-02	Ronald Schroeder	ronald.schroeder@warmmail.com	Meridian	Idaho	4755813211132	566314ec16f76b0b3077114fff87666f	Discover	43.6621393805842786	-116.325059541308875
11065	2020-02-02 12:17:47	2020-02-02	Lupe Stamm	lupe.stamm@geemail.com	Albuquerque	New Mexico	180065399290124237	daf7852137c6d12ff40cc2f87a4ccaf5	VISA 16 digit	35.1995377869013737	-106.682344680193438
11066	2020-02-02 12:19:46	2020-02-02	Dr. Ernest Champlin	dr.ernest.champlin@woohoo.com	Oakland	California	3713698793358918	598b56d2ee0e52cf77d0096da06df693	JCB 15 digit	37.832400179917208	-122.27545333891743
11067	2020-02-02 13:14:41	2020-02-02	Nicole Cassin	nicole.cassin@woohoo.com	Colorado Springs	Colorado	3528036086181856532	793888ce0da3eca01b60ef22f32082fd	Diners Club / Carte Blanche	38.9542770987890634	-104.675675995058199
11068	2020-02-02 13:16:24	2020-02-02	Margene Rogahn	margene.rogahn@geemail.com	Denver	Colorado	3088254848925042595	8bb5f1e6d28797680cca1fa51eb6820f	Maestro	39.7308530734438392	-104.802774998244274
11069	2020-02-02 13:54:05	2020-02-02	Emerald Hackett	emerald.hackett@geemail.com	Costa Mesa	California	6011655281813917709	d292178bf7b5454d0e02c0e8a4bd48b8	Diners Club / Carte Blanche	33.7063276180081104	-117.970241438816487
11070	2020-02-02 14:04:55	2020-02-02	Mr. Armand Gibson MD	mr.armand.gibson.md@geemail.com	San Francisco	California	3735453378201404	2a3410278ff3115408567abf050259f3	Diners Club / Carte Blanche	37.7858577474541875	-122.422284660940917
11071	2020-02-02 14:09:34	2020-02-02	Naoma O'Reilly	naoma.o'reilly@geemail.com	San Francisco	California	4897451667497052	1f355079fb3c294f7f1db7b397b6d332	Discover	37.7889924323566788	-122.449825072326192
11072	2020-02-02 14:10:19	2020-02-02	Dickie Gusikowski IV	dickie.gusikowski.iv@warmmail.com	Cincinnati	Ohio	3096066813319188303	51cf241ff23e74f7fcda93a06b452929	Diners Club / Carte Blanche	39.2326919449258611	-84.4566357541169879
11073	2020-02-02 14:16:58	2020-02-02	Billy Hudson	billy.hudson@geemail.com	San Francisco	California	3158628294145245495	3df0bb0d7314c983100110af92671130	Voyager	37.7892662419548699	-122.410440081711911
11074	2020-02-02 14:32:47	2020-02-02	Beula Ondricka	beula.ondricka@warmmail.com	San Francisco	California	210040146665957554	26c473a496bc3c3445c1bbf4e5a90da6	JCB 16 digit	37.7974314614394231	-122.423044444439967
11075	2020-02-02 14:35:56	2020-02-02	Mrs. Nelie Barton DVM	mrs.nelie.barton.dvm@geemail.com	Cedar Rapids	Iowa	869950663901763718	9d1f2306dd52936dce1db10e8897798f	Mastercard	41.948376445060596	-91.7340656126450824
11076	2020-02-02 14:36:00	2020-02-02	Toivo O'Kon	toivo.o'kon@woohoo.com	Austin	Texas	4428921441351	4785e3ee565ef2800b743c2a171b5431	VISA 16 digit	30.267323002557827	-97.7587227519374409
11077	2020-02-02 15:57:05	2020-02-02	Lou VonRueden	lou.vonrueden@warmmail.com	Jacksonville	Florida	502005855506381	d99d2250faa626f5f429efdd3eece4d2	VISA 13 digit	30.2747845540806644	-81.5913430913429778
11078	2020-02-02 16:00:53	2020-02-02	Dimitrios Bradtke	dimitrios.bradtke@warmmail.com	San Jose	California	869932415702070170	ac7b7e8966a9c52684bc49b876141160	Mastercard	37.3402993570834383	-121.774534065344923
11079	2020-02-02 16:05:28	2020-02-02	Jaiden Koch	jaiden.koch@geemail.com	Surprise	Arizona	51928161003780821	739548469cd6e8eee6ba52d6ec765819	Discover	33.7515380569960897	-112.518481584847706
11080	2020-02-02 16:25:40	2020-02-02	Joe Gutmann	joe.gutmann@geemail.com	Berkeley	California	4004256944701378	321b6a23ef7934e6dbaf6b9c543c4e61	Maestro	37.8823482692914268	-122.288663795850312
11081	2020-02-02 16:28:30	2020-02-02	Ms. Devyn Bruen	ms.devyn.bruen@geemail.com	Los Angeles	California	3112386076030179125	2b7dff04cd44293c9cc0e5ff4b93def8	Mastercard	34.0664057872123962	-118.509360104798517
11082	2020-02-02 16:34:04	2020-02-02	Irvin Gislason II	irvin.gislason.ii@woohoo.com	New York	New York	6011612220713672438	4dfba0c6b1025b2eb3bac8b4b3582574	VISA 16 digit	40.7212598502393774	-73.9437219053402544
11083	2020-02-02 16:42:54	2020-02-02	Alyvia Feest	alyvia.feest@geemail.com	San Francisco	California	3487832868878432	6f4f7196bdfb5770152386f44d9d58f3	Voyager	37.776434192569269	-122.438865333202301
11084	2020-02-02 16:44:50	2020-02-02	Mrs. Cappie Berge	mrs.cappie.berge@geemail.com	Charlotte	North Carolina	3017527507458037	7e0521780f46f2c06a2819265cfa537c	American Express	35.2880529773674922	-80.8635677826069355
11085	2020-02-02 17:51:49	2020-02-02	Tristen Mayert	tristen.mayert@geemail.com	San Francisco	California	060443437987639	1b51fd55c074f95379a6f98b6bae93d2	JCB 15 digit	37.7742251456171232	-122.455608470431059
11086	2020-02-02 17:54:46	2020-02-02	Dock Luettgen	dock.luettgen@woohoo.com	Santa Ana	California	54761254327430460	29cc6b10bb304e044f84b3dcda2e6960	VISA 16 digit	33.7362728794209659	-117.78557955063134
11087	2020-02-02 18:10:18	2020-02-02	Lillia Strosin	lillia.strosin@geemail.com	Raleigh	North Carolina	3053571518568396	c8612869cb51691a5f7c1220626cc801	JCB 16 digit	35.8670658577367618	-78.6597217073600774
11088	2020-02-02 18:28:44	2020-02-02	Frazier Kutch	frazier.kutch@warmmail.com	San Francisco	California	4380882217069435	a4c66d2af0ba30f638c6c3c4e0bbf1a7	JCB 15 digit	37.7697526630806806	-122.4180689539387
11089	2020-02-02 18:30:09	2020-02-02	Casey Towne-Keeling	casey.towne.keeling@warmmail.com	Oakland	California	3017753485660325	164b35747026ad6cece00126691b203e	VISA 13 digit	37.7896688679849078	-122.226066211615318
11090	2020-02-02 18:48:46	2020-02-02	Marty Barrows DVM	marty.barrows.dvm@warmmail.com	Oakland	California	3337522424326573293	8f8904a5d90aa9212847653451848b5b	Maestro	37.7620717025063328	-122.239726354655033
11091	2020-02-02 18:59:41	2020-02-02	Milan Farrell-Schmeler	milan.farrell.schmeler@geemail.com	Berkeley	California	3722499103181101	0236d27aa76c725dac38de3946d32bff	American Express	37.896818502909511	-122.250443317873575
11092	2020-02-02 19:09:49	2020-02-02	Mr. Emery Rogahn I	mr.emery.rogahn.i@geemail.com	Jacksonville	Florida	4118959042029922	fd7f53f72e226b6d9d407d1234b7cde1	Diners Club / Carte Blanche	30.2531521541118629	-81.6651449312999915
11093	2020-02-02 19:11:25	2020-02-02	Lorelei Stokes DVM	lorelei.stokes.dvm@geemail.com	Memphis	Tennessee	3765409574705682	ddecc5acd53454c5847899c8f6513173	Maestro	35.150353270123901	-90.0305635625287977
11094	2020-02-02 20:14:21	2020-02-02	Keith Hand	keith.hand@woohoo.com	Los Angeles	California	6011939965263419400	7cd08ce1b3fcf73626ad167b05a54f97	Voyager	33.9313116452522578	-118.469643515301115
11095	2020-02-02 20:19:32	2020-02-02	Kelley Shanahan	kelley.shanahan@geemail.com	Savannah	Georgia	3023391806156378	f8d6b542a8df22cf0d475fe2efc3bb84	Diners Club / Carte Blanche	32.0089497486688188	-81.1185102287366959
11096	2020-02-02 20:19:40	2020-02-02	Mr. Hamp Brakus	mr.hamp.brakus@geemail.com	Yonkers	New York	869905812399793499	cf49ef4c38ad1843b9cb26cbb27b046a	Diners Club / Carte Blanche	40.9072477283157454	-73.8015055046766975
11097	2020-02-02 20:30:18	2020-02-02	Stafford Rutherford	stafford.rutherford@geemail.com	Riverside	California	4700402144930	1e75246e56508cd02ddc77f5ab467119	VISA 16 digit	33.8639416253142045	-117.42394303437024
11098	2020-02-02 20:31:44	2020-02-02	Chessie O'Connell	chessie.o'connell@geemail.com	Moreno Valley	California	3051605676971794	614cad670f9173651594ba55e3b3bae4	JCB 16 digit	33.9962881045408523	-117.147682456855463
11099	2020-02-02 20:43:40	2020-02-02	Dr. Amarion Denesik II	dr.amarion.denesik.ii@warmmail.com	Austin	Texas	4777177740894	f46c43ec585295582dd92e4140626b5d	Maestro	30.2521678761705743	-97.8285944635287024
11100	2020-02-02 20:48:31	2020-02-02	Billy Walsh	billy.walsh@geemail.com	Elgin	Illinois	3528946082240625116	a00536e4766202a82708e67804e7800f	Voyager	41.9736425043366879	-88.3060835435342142
11101	2020-02-02 20:48:52	2020-02-02	Mrs. Essence Mills	mrs.essence.mills@geemail.com	Fresno	California	180036369793210839	3d0137872d08dfe91681b1cc5e00559e	VISA 13 digit	36.7545187673404783	-119.709023694006362
11102	2020-02-02 21:42:48	2020-02-02	Olene Quitzon	olene.quitzon@woohoo.com	Lancaster	California	52582202406606937	84b77f3e6290397ebd9b0b030e26a557	Mastercard	34.7222337655968971	-118.208612734914936
11103	2020-02-02 21:44:23	2020-02-02	Gearldine Considine	gearldine.considine@geemail.com	Olathe	Kansas	4720530378994	36c87f54db15f2664e11a5b850a167c9	VISA 16 digit	38.8048938935745511	-94.8484846327621511
11104	2020-02-02 21:44:30	2020-02-02	Adison Wiza DDS	adison.wiza.dds@woohoo.com	Phoenix	Arizona	3035030172617484	22a9c0dd3a0892fa1bae108d9fd8a5cd	JCB 15 digit	33.5352238581914506	-112.061491261927785
11105	2020-02-02 22:18:36	2020-02-02	Faith Smith	faith.smith@geemail.com	Austin	Texas	210085689538933993	d377249a05015638c7e398aeb1c0bd17	JCB 16 digit	30.2343788722191	-97.6692751882370658
11106	2020-02-02 22:24:42	2020-02-02	Miss Nyree Hermann MD	miss.nyree.hermann.md@geemail.com	Elk Grove	California	6011631200947023464	9067e831ee15a2715f03a2c2be250a31	Voyager	38.3921218879804016	-121.45021786958911
11107	2020-02-02 22:32:42	2020-02-02	Montie Torphy-Bashirian	montie.torphy.bashirian@geemail.com	Santa Maria	California	3112517412004626886	593e3ee041fee5a933b75a64b1f6b813	Mastercard	34.8762526570882656	-120.349627748123552
11108	2020-02-02 23:19:36	2020-02-02	Jorge Skiles-Goodwin	jorge.skiles.goodwin@warmmail.com	Stockton	California	869948848968945804	d6fa76acc1aed1267452acadc36c16f0	Diners Club / Carte Blanche	37.8787110168218604	-121.272101480568949
11109	2020-02-02 23:24:01	2020-02-02	Mrs. Ashli Nader	mrs.ashli.nader@geemail.com	New York	New York	4421525822028913	38b1f175cca42cebe4387c71fb6cde32	JCB 16 digit	40.6279244403578303	-73.9867712925549625
11110	2020-02-02 23:24:58	2020-02-02	Miss Shardae Carroll	miss.shardae.carroll@geemail.com	Newport News	Virginia	4514859059448611	65cf550e3d581d428602031dcbef7df7	JCB 16 digit	37.1647409024544046	-76.5402603721041288
11111	2020-02-02 23:28:27	2020-02-02	Nim Nienow	nim.nienow@warmmail.com	San Francisco	California	4274102174866783	468949fc0e0f7a3500f1c0e974c6ad5e	Diners Club / Carte Blanche	37.7563121403246598	-122.446302482841759
11112	2020-02-02 23:34:26	2020-02-02	Jovan Kautzer-Hammes	jovan.kautzer.hammes@geemail.com	Laredo	Texas	53366526062627213	809663c52dd8dae638d18a9fc31145b2	JCB 16 digit	27.5410903414428248	-99.5286313854165314
11113	2020-02-02 23:37:57	2020-02-02	Young Bashirian	young.bashirian@warmmail.com	San Francisco	California	6011003379642385707	10a8f53ae6e7da88522b0334f2b2ce9c	VISA 13 digit	37.7594725066537578	-122.467610009313461
11114	2020-02-02 23:48:16	2020-02-02	Carlo Schaefer	carlo.schaefer@geemail.com	San Francisco	California	51588076943722363	5ee4382e19c45b98667ff73ce0686350	JCB 15 digit	37.787681524793733	-122.432966181731047
11115	2020-02-03 00:11:44	2020-02-03	Manly Kulas	manly.kulas@geemail.com	Orlando	Florida	4426244876964	1e9e23c4d7a2263d7dea09d78225ab40	Maestro	28.4712149538364265	-81.1868514842320224
11116	2020-02-03 00:23:05	2020-02-03	Miss Ashanti O'Reilly DDS	miss.ashanti.o'reilly.dds@geemail.com	Berkeley	California	4666138095402221	d50d13f720c0e2875fc4239ab512bba1	JCB 15 digit	37.8853414829156137	-122.293860090163534
11117	2020-02-03 00:28:40	2020-02-03	Sheree Fadel	sheree.fadel@geemail.com	Huntsville	Alabama	3528975688746992398	e78af507fc0d3c4ea4e80c75a597bfc6	Diners Club / Carte Blanche	34.6475980738420049	-86.6285571598466504
11118	2020-02-03 00:56:11	2020-02-03	Augustina Rosenbaum PhD	augustina.rosenbaum.phd@woohoo.com	Chula Vista	California	4651436783176926	3208ec187cabed221a29e894d48488ca	Mastercard	32.6179902137953732	-116.997330128610869
11119	2020-02-03 01:04:04	2020-02-03	Ava Erdman	ava.erdman@woohoo.com	Tampa	Florida	4623165495135	03281acdf02d463ebff7cc7573a6d609	JCB 16 digit	27.9120487986713641	-82.4346544187728227
11120	2020-02-03 01:20:13	2020-02-03	Maria Rippin	maria.rippin@geemail.com	San Francisco	California	6011567503516446323	0bb1c7b3336804ecb24dfaa9eab44b91	Voyager	37.7719825100780398	-122.4432457479204
11121	2020-02-03 01:34:43	2020-02-03	Ms. Chyna Mosciski	ms.chyna.mosciski@geemail.com	Los Angeles	California	869929945385344182	db6a0d4f7745e384a75854c97773caba	VISA 13 digit	33.9285949034016525	-118.381243502906699
11122	2020-02-03 02:17:31	2020-02-03	Alex Hauck	alex.hauck@woohoo.com	Tallahassee	Florida	4138107287301350	f0da8c7f7fc819d616363eea887e09ae	VISA 16 digit	30.4767811083722862	-84.1886624870371065
11123	2020-02-03 03:13:12	2020-02-03	Zeke Kessler	zeke.kessler@geemail.com	Arlington	Texas	589341961782202	0c7b87bf617bbc24c65c4b56de1b254c	VISA 16 digit	32.6784107685338654	-97.1310666887115701
11124	2020-02-03 04:01:27	2020-02-03	Young Roberts-Franecki	young.roberts.franecki@warmmail.com	San Francisco	California	3112835045759640713	023267b832f2e4b44c45ef2bd74a762c	JCB 15 digit	37.7811833160516315	-122.426309364829592
11125	2020-02-03 04:04:05	2020-02-03	Sylvia Lebsack	sylvia.lebsack@geemail.com	San Antonio	Texas	4298107023175270	93b1b94467c56178e4e3aced17d4d0df	Discover	29.4879949189327668	-98.6128261284273009
11126	2020-02-03 04:06:31	2020-02-03	Devon Kozey	devon.kozey@geemail.com	Chicago	Illinois	4671344312722630	7a05a68d93ff9cd86aec8409ab75071b	JCB 16 digit	41.8946203138515401	-87.668000306517996
11127	2020-02-03 04:16:53	2020-02-03	Rance Bogan MD	rance.bogan.md@geemail.com	San Francisco	California	3096621447614805838	b9c20c9ef674d0cab9a2c8f98b4b48b0	VISA 16 digit	37.732770816198915	-122.418997358255723
11128	2020-02-03 04:23:16	2020-02-03	Dr. Sigurd Kuphal Jr.	dr.sigurd.kuphal.jr.@geemail.com	Oakland	California	4035842195868264	0d7f0c15a969f0240de854c7050290bb	JCB 16 digit	37.8454833506696247	-122.288857525202502
11129	2020-02-03 04:40:09	2020-02-03	Dr. Melvyn Dickinson	dr.melvyn.dickinson@warmmail.com	Philadelphia	Pennsylvania	869918399302230467	b20cfcc052d09081070d474763315830	VISA 16 digit	40.0800285933498301	-75.0892018783271311
11130	2020-02-03 04:53:36	2020-02-03	Treyvon Casper MD	treyvon.casper.md@geemail.com	McKinney	Texas	675932151097444	3ddb41ab61905307104ba5a2749adf6b	JCB 16 digit	33.2222771528307348	-96.582170102076617
11131	2020-02-03 05:16:19	2020-02-03	Mr. Broderick Quitzon	mr.broderick.quitzon@warmmail.com	Berkeley	California	3035159065990706	754a4c85dbdaba6e5a211c9558c4cb02	Discover	37.852502768044296	-122.271673452269269
11132	2020-02-03 05:21:38	2020-02-03	Moe Carter Sr.	moe.carter.sr.@woohoo.com	Aurora	Colorado	869952403670147522	33faf90d4e05f626066adfa6f327eaa5	VISA 13 digit	39.7033127417899721	-104.755809021427112
11133	2020-02-03 05:28:31	2020-02-03	Mr. Landen Kreiger II	mr.landen.kreiger.ii@geemail.com	Sacramento	California	3528039291233327717	b60f1830ae64792e71d1e29f1911b393	Mastercard	38.6297431069225112	-121.535287311744312
11134	2020-02-03 05:45:53	2020-02-03	Michal Heidenreich-Mertz	michal.heidenreich.mertz@woohoo.com	West Jordan	Utah	180088261226176645	57846e2082ba299c0b02014039c9aa79	Voyager	40.6927508731164096	-112.026689429077507
11135	2020-02-03 06:01:36	2020-02-03	Wellington Ankunding PhD	wellington.ankunding.phd@geemail.com	Kent	Washington	3096862110725206134	28aca3197a7743914bcc6bf692aa2ea8	JCB 15 digit	47.4473519179616119	-122.147512751365824
11136	2020-02-03 06:06:39	2020-02-03	Caitlynn Lesch	caitlynn.lesch@geemail.com	Columbia	Missouri	210049614145528429	d4b9e9c2de974aec6b2392b9615d218f	Voyager	38.8874829199046488	-92.3590774795559355
11137	2020-02-03 06:08:53	2020-02-03	Durell Bergnaum-Mertz	durell.bergnaum.mertz@warmmail.com	San Francisco	California	3405027079674113	6b6dc13981cbb9351f4dc22c25dc50e9	JCB 16 digit	37.7748388323511577	-122.46774800805008
11138	2020-02-03 06:59:51	2020-02-03	Mechelle Turner	mechelle.turner@geemail.com	Seattle	Washington	3040031172480134	2a846fb262ab2da7efc78282494ae7af	JCB 16 digit	47.6443358897622673	-122.419242477874832
11139	2020-02-03 06:59:54	2020-02-03	Washington Jacobson	washington.jacobson@warmmail.com	Los Angeles	California	3050269769702524	650f16bfb40c96a80b5eff3f31a0802b	Discover	34.0489378317125144	-118.470603934628144
11140	2020-02-03 07:03:22	2020-02-03	Alwilda Anderson-Hessel	alwilda.anderson.hessel@woohoo.com	Tallahassee	Florida	4542194011069800	14708930fb600c99d7109078a17140ff	Mastercard	30.360460102653505	-84.1975365230362911
11141	2020-02-03 07:08:26	2020-02-03	Levin Corkery	levin.corkery@geemail.com	Madison	Wisconsin	3755790868109489	a8588edefd9a9cc1c0c4adb3624fb03b	Voyager	43.0051256050329656	-89.4903738441295928
11142	2020-02-03 07:09:08	2020-02-03	Cleo Schulist PhD	cleo.schulist.phd@woohoo.com	Killeen	Texas	503824567984224	36955a82b698db62dfa7527bc3c8372b	VISA 16 digit	31.078317538532243	-97.810458336181938
11143	2020-02-03 07:13:58	2020-02-03	Orlando Wehner I	orlando.wehner.i@geemail.com	Syracuse	New York	4944970930537157	7f47cf6c2eae54443d0ffb68349f3c1d	Mastercard	43.1094297261759607	-76.0751692831762227
11144	2020-02-03 08:06:22	2020-02-03	Oris Mertz	oris.mertz@geemail.com	New York	New York	6011556295347893210	b3aad6bf98f0f4a6e5516e104325e53e	JCB 16 digit	40.737655987380073	-73.8931292024336699
11145	2020-02-03 08:22:32	2020-02-03	Selma Heaney	selma.heaney@warmmail.com	Orange	California	630492818647643	af71d46dfff01c44ad265393a4f892e7	American Express	33.8227875355985006	-117.872700043172756
11146	2020-02-03 08:32:35	2020-02-03	Georganna Weber	georganna.weber@geemail.com	Oakland	California	3451894193174657	e31066bbe505659cdf4b5999cd524233	Mastercard	37.7805257072824716	-122.255818335014965
11147	2020-02-03 09:02:40	2020-02-03	Ardith Lueilwitz-Hartmann	ardith.lueilwitz.hartmann@warmmail.com	Cleveland	Ohio	3337718810361957215	70b00549891db12fd01b4db91ea8401e	Mastercard	41.4832653845045698	-81.5894438647903542
11148	2020-02-03 09:04:28	2020-02-03	Dr. Derl Crona	dr.derl.crona@geemail.com	Chandler	Arizona	6011351241845697478	5c15e5ce557b8151b15863a61cd209ff	Diners Club / Carte Blanche	33.203969064596663	-111.941257676982886
11149	2020-02-03 09:07:34	2020-02-03	Pamala Mayer	pamala.mayer@warmmail.com	Washington	District of Columbia	869990837479839579	7c2dce66bac78dd5b10774f4bb2af4ad	JCB 16 digit	38.8806591272618647	-76.936509751782566
11150	2020-02-03 09:18:49	2020-02-03	Mr. Lawrence Crooks Sr.	mr.lawrence.crooks.sr.@geemail.com	Sacramento	California	4233052026447	1b612a157483b8b21298a39bd506ad21	JCB 16 digit	38.6270962137993408	-121.452059133375428
11151	2020-02-03 09:31:56	2020-02-03	Mrs. Lavon Fisher	mrs.lavon.fisher@warmmail.com	Albuquerque	New Mexico	4297517313733615	1ac14bcd99a0ad22907b045b2a44e676	JCB 15 digit	35.1002995421312747	-106.606473256514974
11152	2020-02-03 09:42:19	2020-02-03	Karlee Stehr	karlee.stehr@warmmail.com	Tulsa	Oklahoma	6011410951990582825	e50bebe1ce57d2f1208fda81eb871eb4	VISA 13 digit	36.1193065245538918	-95.8498043878890513
11153	2020-02-03 10:33:25	2020-02-03	Bebe Botsford	bebe.botsford@geemail.com	Victorville	California	4441058453442654	72b2dec7d78f29488ed29a37e8ef585f	JCB 16 digit	34.5484938956562431	-117.328118969189376
11154	2020-02-03 10:33:40	2020-02-03	Rosco Braun-Sipes	rosco.braun.sipes@warmmail.com	Greeley	Colorado	869934882489056722	01c217250e92891a1166150af0e8635b	VISA 13 digit	40.4627845862016073	-104.816361651460454
11155	2020-02-03 10:43:12	2020-02-03	Juliana Gleichner	juliana.gleichner@geemail.com	Albuquerque	New Mexico	503807619273035	36fc81dc6173b45f6ad01504a122a06d	Mastercard	35.0436120696965645	-106.698790703674405
11156	2020-02-03 10:48:25	2020-02-03	Ty Ferry-Deckow	ty.ferry.deckow@geemail.com	Berkeley	California	3528011586017944112	e4a97ea7ce8ae8c3fe3d4ea4ceb82a8e	JCB 16 digit	37.8713336456229186	-122.23452025099941
11157	2020-02-03 11:01:24	2020-02-03	Rosie Auer	rosie.auer@warmmail.com	San Antonio	Texas	4449852242317561	f58b95ed38bb79171ba6bfc6c4e5b9df	Diners Club / Carte Blanche	29.4394563826803122	-98.4374749291524296
11158	2020-02-03 11:11:34	2020-02-03	Abelardo Herzog	abelardo.herzog@geemail.com	Aurora	Illinois	4199057310272779	acf5d82b5ce0d24a316cc135f25da390	American Express	41.8538271420858834	-88.3343523427773221
11159	2020-02-03 11:14:51	2020-02-03	Gaynell Johnston-Turner	gaynell.johnston.turner@woohoo.com	San Diego	California	4802047244883	c032de8d84de83ae8e91b511e9b1fc24	Voyager	32.7473259440690256	-117.097498780759054
11160	2020-02-03 11:20:59	2020-02-03	Paulina Weissnat-Fritsch	paulina.weissnat.fritsch@warmmail.com	San Diego	California	630466779532655	ffdf32a7e60c7635f37d384cb10bbcba	Mastercard	32.7394611691657431	-117.189722699476405
11161	2020-02-03 11:26:37	2020-02-03	Jerome Raynor-Keeling	jerome.raynor.keeling@woohoo.com	Springfield	Illinois	6011367092264098876	852a8edffd955d2231804a892eff8409	VISA 13 digit	39.7990529201611878	-89.581794048566735
11162	2020-02-03 11:37:25	2020-02-03	Ms. Karyn Christiansen	ms.karyn.christiansen@warmmail.com	New York	New York	53385240960139910	99ef43dd65e66432f09237999a984f5a	Maestro	40.6951127498634122	-73.8476034385979148
11163	2020-02-03 11:37:33	2020-02-03	Ammie Conn-Bins	ammie.conn.bins@geemail.com	Kansas City	Missouri	4505452732513752	fffb7f22d5e9aa0fbf830cc3d48426e6	American Express	39.0806506925564321	-94.5941341448333191
11164	2020-02-03 11:39:32	2020-02-03	Benjiman Macejkovic	benjiman.macejkovic@geemail.com	San Jose	California	639076643556525	601e66788450a1d4bde16f57a1d913eb	VISA 13 digit	37.2348275231950012	-121.904060487936803
11165	2020-02-03 11:43:13	2020-02-03	Derwin Pacocha V	derwin.pacocha.v@geemail.com	Houston	Texas	3088971836837055039	38546fc145dd43180738b3975dab1e68	Discover	29.8251685540270053	-95.3921810543645137
11166	2020-02-03 12:00:37	2020-02-03	Kymani DuBuque	kymani.dubuque@geemail.com	San Francisco	California	4592430379118683	c029797a738ee225e4e9a3e87609ecd2	American Express	37.7898959319429935	-122.422022892648613
11167	2020-02-03 12:13:17	2020-02-03	Nakia Hermiston	nakia.hermiston@geemail.com	Tulsa	Oklahoma	53635074512615988	d1ae0711ee5ec0cf7446f524701f7b37	VISA 13 digit	36.1624149429515001	-95.94959206892662
11168	2020-02-03 12:56:22	2020-02-03	Kaleb Rath	kaleb.rath@woohoo.com	New York	New York	6011446855976516996	266cde3482fa0f2464dbb92e0881ec98	Mastercard	40.741491511858996	-73.9957766661316185
11169	2020-02-03 13:12:12	2020-02-03	Dr. Darl Padberg	dr.darl.padberg@geemail.com	Antioch	California	3112941882478487567	ab849ddb2d543b8db9f784d4704f95d9	JCB 15 digit	37.9555790310990062	-121.886952095449715
11170	2020-02-03 13:19:51	2020-02-03	Artis Gutmann	artis.gutmann@geemail.com	Springfield	Illinois	3019833719038684	b5420cc352dc1326cc0836c810a76ab1	Discover	39.8265339320678251	-89.6654362834062368
11171	2020-02-03 13:21:40	2020-02-03	Eartha Leuschke	eartha.leuschke@woohoo.com	Oklahoma City	Oklahoma	53662957638063370	ee34c019eec7c0d859270ddc847bc782	Maestro	35.5315301173742881	-97.528980407620594
11172	2020-02-03 13:35:28	2020-02-03	Sally Price	sally.price@geemail.com	Mobile	Alabama	3158246937739269873	3953eef4893d4c9c89aa6681f4d11f02	Discover	30.7650042111627755	-88.088879327722637
11173	2020-02-03 13:55:35	2020-02-03	Ab Herman	ab.herman@geemail.com	San Francisco	California	639079053720680	7bc0685298f414e5272d955b162ed651	Mastercard	37.7627655321884745	-122.420542298001735
11174	2020-02-03 13:57:55	2020-02-03	Maggie Jaskolski-McCullough	maggie.jaskolski.mccullough@warmmail.com	Henderson	Nevada	4239712919179013	e7c1c523bbd22edcc6135d8c66d4407c	VISA 16 digit	35.9652929718539127	-115.059431653066355
11175	2020-02-03 14:01:26	2020-02-03	Ms. Burnice Gerlach DVM	ms.burnice.gerlach.dvm@warmmail.com	Toledo	Ohio	54884092001647831	4e95903f77b728af26be50038aab9ff6	VISA 16 digit	41.68082517461702	-83.5287760559801029
11176	2020-02-03 14:05:16	2020-02-03	Eustace Jacobs	eustace.jacobs@warmmail.com	San Francisco	California	6011350249244974894	93ea29ce28726332b9439f23fc4b6a02	VISA 16 digit	37.7950960010101369	-122.425399522632247
11177	2020-02-03 14:18:47	2020-02-03	Dr. Kia Rowe MD	dr.kia.rowe.md@warmmail.com	Houston	Texas	3158140142548962795	12c1e986a0592249b689d764af550e23	Voyager	29.6882477483790375	-95.4804681023132105
11178	2020-02-03 14:25:59	2020-02-03	Mr. Galen Shanahan	mr.galen.shanahan@warmmail.com	San Francisco	California	3528211048471652473	05283da58e4002732695c8f8efaea634	VISA 16 digit	37.7882019878802282	-122.43332977123903
11179	2020-02-03 14:30:27	2020-02-03	Janiya Stroman PhD	janiya.stroman.phd@warmmail.com	Portland	Oregon	4796506037392	9b3375998441b61337b3cf8c328bda71	American Express	45.6128154697716255	-122.708143031410884
11180	2020-02-03 14:34:13	2020-02-03	Reuben Rohan	reuben.rohan@woohoo.com	Austin	Texas	4810815597622	67335db6b01dbe58c41eb9ae31dd4c38	VISA 16 digit	30.2661786301653812	-97.6762969452194909
11181	2020-02-03 14:37:41	2020-02-03	Katheryn Moen-Runolfsdottir	katheryn.moen.runolfsdottir@geemail.com	San Mateo	California	3048035981467523	0c1cdd1651ab598f5bf4587a94789c26	Discover	37.5795097663413742	-122.385903047522902
11182	2020-02-03 14:42:21	2020-02-03	Pat Senger-Daugherty	pat.senger.daugherty@geemail.com	Saint Paul	Minnesota	54029027350646410	d7c7a9b943b13f94058674285985a912	VISA 16 digit	44.8619476088263127	-93.1355001908991511
11183	2020-02-03 14:45:25	2020-02-03	Reynolds Streich	reynolds.streich@geemail.com	Oakland	California	4305823810521	20fb0108af145ab71a9835ba2dcebd15	American Express	37.7828066180719304	-122.260937008129375
11184	2020-02-03 15:00:27	2020-02-03	Mr. Timmie Zieme III	mr.timmie.zieme.iii@geemail.com	Los Angeles	California	4603034291626	115a5b0cc690ec4416a2577584b02deb	Diners Club / Carte Blanche	34.1113115517754082	-118.323832408058635
11185	2020-02-03 15:07:05	2020-02-03	Dillon Barton DDS	dillon.barton.dds@geemail.com	Houston	Texas	3021308339951929	cd68efbbe5e4ee1b0d8445150402202a	Voyager	29.87870535362363	-95.415445258656149
11186	2020-02-03 15:07:18	2020-02-03	Felicia Kling	felicia.kling@woohoo.com	Los Angeles	California	210096755499033508	551e5064a963a715d90e6cbfdd8a7c60	JCB 15 digit	34.0599535787809629	-118.316190565050761
11187	2020-02-03 15:22:13	2020-02-03	Mose Hilll-Murphy	mose.hilll.murphy@warmmail.com	Lubbock	Texas	4215838761332372	5297611fcd1be295c4a2f2c3cffc68c8	Maestro	33.4978763449046824	-101.798527758327126
11188	2020-02-03 15:22:20	2020-02-03	Abdullah Kutch	abdullah.kutch@woohoo.com	Columbus	Ohio	210064349453406724	5f14fd910671a5cfe6608a5cf77808cc	JCB 16 digit	39.953630684972552	-82.9975009623684059
11189	2020-02-03 15:30:12	2020-02-03	Precious Hand MD	precious.hand.md@geemail.com	San Francisco	California	3038154686968147	960e831310df88bf0e12e31441c99505	Mastercard	37.7789798585966281	-122.461295901847251
11190	2020-02-03 15:46:18	2020-02-03	Augustin Wuckert	augustin.wuckert@geemail.com	San Francisco	California	52122409510819226	5f56f6b9ceeb07a00ab0767b5a890cea	Maestro	37.7416241894909419	-122.428189460383066
11191	2020-02-03 15:49:22	2020-02-03	Khalil D'Amore	khalil.d'amore@woohoo.com	San Francisco	California	6011589315219356996	441e5146995b265ba73dce2d62dd9041	Voyager	37.7667002346767617	-122.448537705833587
11192	2020-02-03 15:58:57	2020-02-03	Chandra Aufderhar	chandra.aufderhar@woohoo.com	Macon	Georgia	4410845617303450	2fb414d6096d6c1467b10ced8838b815	JCB 16 digit	32.8103614992473283	-83.6349854816410669
11193	2020-02-03 16:23:24	2020-02-03	Thalia Torphy	thalia.torphy@woohoo.com	Hialeah	Florida	4316219329638	7b09fee8c8e98527952ce944a3975513	Discover	25.7799336831528692	-80.3864442799609122
11194	2020-02-03 16:24:15	2020-02-03	Hedwig Runolfsdottir	hedwig.runolfsdottir@woohoo.com	Jersey City	New Jersey	869949149913511109	f46a031a55fd21439e8ded30617e2982	Diners Club / Carte Blanche	40.7695895930692558	-73.9871079370334854
11195	2020-02-03 16:31:37	2020-02-03	Merrily Herman-Carroll	merrily.herman.carroll@warmmail.com	Oakland	California	6011029481437508780	f1d04a8a0eff31cfbd4b710ce2be8cb5	Discover	37.8047905121953463	-122.259554658184726
11196	2020-02-03 16:50:04	2020-02-03	Tera Bailey DVM	tera.bailey.dvm@woohoo.com	New York	New York	4142874706070	ab3a4e201b9e21918185c7b4788db2c5	VISA 13 digit	40.7304639523141105	-74.0005197844363778
11197	2020-02-03 17:00:37	2020-02-03	Dr. Loyd Ferry	dr.loyd.ferry@warmmail.com	Tampa	Florida	502043523996932	c82105c502482f8d75a5b8def2a7069b	VISA 13 digit	27.9436626718029366	-82.5788838649380921
11198	2020-02-03 17:03:02	2020-02-03	Jefferey Fisher	jefferey.fisher@geemail.com	San Francisco	California	3158830196608926053	295f477440c25204ed8291096b18d64f	Mastercard	37.8003483794190487	-122.470181004197627
11199	2020-02-03 17:15:21	2020-02-03	Dr. Maliah Beahan	dr.maliah.beahan@woohoo.com	Oakland	California	4423760650345224	b3e604e963acfdfdb5e620c7918cf0eb	VISA 16 digit	37.8262976332445362	-122.268621844858927
11200	2020-02-03 17:45:27	2020-02-03	Texas Johnson	texas.johnson@geemail.com	Oklahoma City	Oklahoma	676210052456638	574072252f7c172af81efc1303a90e02	Voyager	35.3789048906326329	-97.5833030921768341
11201	2020-02-03 17:46:04	2020-02-03	Karl Berge	karl.berge@geemail.com	San Francisco	California	869972956684506005	f39df014c41c46fba8f085a815113954	VISA 13 digit	37.7604413586468297	-122.413503330998608
11202	2020-02-03 18:07:01	2020-02-03	Mr. Olaf Lindgren	mr.olaf.lindgren@geemail.com	Glendale	Arizona	4723828827367954	bd2a327f8d56586ab9a2040765e9ecf3	Voyager	33.5017645713169117	-112.136828732655943
11203	2020-02-03 18:38:58	2020-02-03	Barbra Altenwerth DVM	barbra.altenwerth.dvm@geemail.com	Sacramento	California	180008911649246766	45dec4909a7cd33e2523e6c5c1419413	Diners Club / Carte Blanche	38.4937247392985995	-121.503825373040883
11204	2020-02-03 18:48:28	2020-02-03	Aurthur Runte	aurthur.runte@geemail.com	Houston	Texas	3485550394136115	2aa92d46e66c63eda7d789aa6373352d	JCB 16 digit	29.8783641338892281	-95.462539096317812
11205	2020-02-03 18:53:10	2020-02-03	Delma Zieme	delma.zieme@geemail.com	Winston–Salem	North Carolina	54770470971645265	c50d4e580df3cba49e509133a14cc5d6	JCB 16 digit	36.0648574931312353	-80.1658100182320936
11206	2020-02-03 19:14:19	2020-02-03	Mr. Anson D'Amore Sr.	mr.anson.d'amore.sr.@woohoo.com	San Antonio	Texas	869918970631173808	b838dec3cb3d962c033061a9b199694a	Mastercard	29.5536472009100031	-98.5935833950363048
11207	2020-02-03 19:16:13	2020-02-03	Dr. Tommy Kilback V	dr.tommy.kilback.v@geemail.com	San Francisco	California	3721290068660556	bf0a55fcca7d445a1850d83c7e3502de	VISA 16 digit	37.736849672685679	-122.446509326119354
11208	2020-02-03 19:32:17	2020-02-03	Salvatore Cruickshank	salvatore.cruickshank@geemail.com	Hialeah	Florida	180021595266310782	76560e7c1c810ec7f747d6131e92e1fc	VISA 13 digit	25.8256894147932528	-80.3101701697237758
11209	2020-02-03 19:33:14	2020-02-03	Chynna Yost	chynna.yost@woohoo.com	Santa Clarita	California	3732434451616562	03f6111a4e7d7da64922abf30ed1f616	JCB 16 digit	34.4162301473524437	-118.565111782272155
11210	2020-02-03 19:57:54	2020-02-03	Kimberly Johnston-Wolff	kimberly.johnston.wolff@warmmail.com	Pearland	Texas	503831864079533	054172febe478753f77bea16f4a48719	VISA 16 digit	29.6231847292549908	-95.3909204467520055
11211	2020-02-03 20:17:18	2020-02-03	Rae Fritsch	rae.fritsch@woohoo.com	El Paso	Texas	869940403996720411	5ea39f3936134a66896fca7ae7e4999c	Mastercard	31.8800439890768388	-106.340371455995367
11212	2020-02-03 20:17:35	2020-02-03	Moises Farrell	moises.farrell@woohoo.com	Santa Ana	California	4510138630097096	11e64b45a7f91871d80214614778f303	JCB 16 digit	33.6990147783990963	-117.941820085180922
11213	2020-02-03 20:21:52	2020-02-03	Dr. Bradyn Thompson	dr.bradyn.thompson@geemail.com	Fontana	California	6011650894252191613	4479599d230ff5dd320883e13d1a2186	Voyager	34.0807245297506469	-117.40360047242568
11214	2020-02-03 20:30:42	2020-02-03	Casandra Nader	casandra.nader@woohoo.com	San Jose	California	4937835583041	7c8c733881772acf7814c312ced5f9b9	JCB 16 digit	37.3681323615189669	-121.757710794614255
11215	2020-02-03 20:54:45	2020-02-03	Dorr Zemlak	dorr.zemlak@geemail.com	Greeley	Colorado	4495116979404	269941a835bda6f252bdb4984e7da874	JCB 16 digit	40.3918395058318964	-104.693958667975664
11216	2020-02-03 20:57:21	2020-02-03	Louisiana Gerlach	louisiana.gerlach@geemail.com	New York	New York	4138093165361	608ffe955a42688adc124e9223414434	JCB 16 digit	40.6760864938367135	-73.9689214808762046
11217	2020-02-03 21:40:35	2020-02-03	Mrs. Charisse Shields	mrs.charisse.shields@warmmail.com	Cleveland	Ohio	3007424218652357	72b3e8134f31547940c52f25bfcee7c5	VISA 16 digit	41.4136963023655085	-81.694824688439823
11218	2020-02-03 21:48:12	2020-02-03	Cameron Stiedemann	cameron.stiedemann@geemail.com	Fort Lauderdale	Florida	6011828991054720677	1aea8cb03b0e4a232723d62cbd491f67	VISA 13 digit	26.2317094339977963	-80.1942831871852206
11219	2020-02-03 21:50:38	2020-02-03	Mr. Manly Lind	mr.manly.lind@woohoo.com	San Jose	California	3158413157270086142	02288de246fe68dce2aef19052d0ca72	VISA 13 digit	37.2674279618363826	-121.788347797536844
11220	2020-02-03 22:22:51	2020-02-03	Nedra Bergnaum	nedra.bergnaum@geemail.com	Modesto	California	4922565396650720	038f5435ef42a785e0bce403b3e48c31	Voyager	37.5764655663166209	-121.014324366228649
11221	2020-02-03 22:27:50	2020-02-03	Val Breitenberg	val.breitenberg@geemail.com	New York	New York	3158840310995050157	e144d5ac2f8db9d4dc56267b13634730	Diners Club / Carte Blanche	40.7206184651460461	-73.8394418355904492
11222	2020-02-03 22:33:15	2020-02-03	Paulina Kozey DDS	paulina.kozey.dds@geemail.com	St. Louis	Missouri	4123841689376654	7bda9274cb14beb205aba6d078b10ff3	JCB 16 digit	38.6577971268136054	-90.2487627367027159
11223	2020-02-03 22:38:20	2020-02-03	Demetric Orn-Stark	demetric.orn.stark@geemail.com	San Francisco	California	676112810229943	0a1e38290832b9cc267d5919d4b31674	VISA 16 digit	37.7869777599303944	-122.424877566925318
11224	2020-02-03 22:54:40	2020-02-03	Rolla Mayer	rolla.mayer@geemail.com	Bellevue	Washington	869916987750372930	79a7a87b1deedb5421a2462f902916d0	American Express	47.6095841853130608	-122.149545100243756
11225	2020-02-03 23:29:35	2020-02-03	Armani Monahan	armani.monahan@geemail.com	San Francisco	California	3112436010853307547	368d63bbc49b3df0f1672753143bbd78	American Express	37.7856990796462853	-122.403644415807662
11226	2020-02-04 00:02:57	2020-02-04	Mellissa Gutkowski	mellissa.gutkowski@geemail.com	Chicago	Illinois	3112985174724861549	8724c95dab8590ba1c5607502013c34a	Maestro	41.740526081791522	-87.5850636794727251
11227	2020-02-04 01:01:49	2020-02-04	Levar Hane	levar.hane@geemail.com	Berkeley	California	3088366469172873551	89b4696b31c37f930b4a2864d056732e	VISA 13 digit	37.8921382414766725	-122.285913209925624
11228	2020-02-04 01:03:45	2020-02-04	Mrs. Winnifred Murazik	mrs.winnifred.murazik@warmmail.com	Tacoma	Washington	4184461053623	dc8829e7e189530899c26e51aae2a107	JCB 16 digit	47.3229936937455093	-122.400638235942651
11229	2020-02-04 01:35:20	2020-02-04	Koby Simonis	koby.simonis@warmmail.com	Clearwater	Florida	869999236639907973	12738cca378580cac6af1961b27b9d02	VISA 16 digit	27.9420338289938854	-82.8076500482190312
11230	2020-02-04 02:14:54	2020-02-04	Gwenda Kulas	gwenda.kulas@geemail.com	Concord	California	4656731819602	49ea2af50803d429b727fb48f26a4a1d	VISA 16 digit	37.9229473261095578	-122.087861135246598
11231	2020-02-04 02:21:14	2020-02-04	Trudie McDermott	trudie.mcdermott@warmmail.com	New York	New York	4778683419932	41609b46eb40b20498b43ad4d42bb9e2	VISA 16 digit	40.5946056317295856	-73.9338388210058213
11232	2020-02-04 02:41:43	2020-02-04	Mrs. Consuelo Sporer	mrs.consuelo.sporer@warmmail.com	San Francisco	California	180078132513381051	6ce10654698d7699107b529a7322e26b	VISA 13 digit	37.7737712715444616	-122.467174623946562
11233	2020-02-04 02:43:43	2020-02-04	Alexande White	alexande.white@geemail.com	San Antonio	Texas	3337920129104145853	7b518e2ad74393335f09338db877d68a	JCB 15 digit	29.4035801175121208	-98.5329212080988981
11234	2020-02-04 03:25:18	2020-02-04	Mame Torp-McLaughlin	mame.torp.mclaughlin@geemail.com	Wichita	Kansas	4882869860844035	dfcf2dfe8490d0b4305001f0e336857d	JCB 16 digit	37.787914881470428	-97.4273814967568939
11235	2020-02-04 03:36:12	2020-02-04	Eliga Bailey	eliga.bailey@geemail.com	Kenosha	Wisconsin	4436046294829	0fc9a18138565040dcf36fcffd2bfa01	JCB 15 digit	42.6037860406402515	-87.9417478761862981
11236	2020-02-04 03:38:09	2020-02-04	Aleck Flatley-Ratke	aleck.flatley.ratke@geemail.com	San Antonio	Texas	4288793108181655	51cbf92fd0fd93d48525539ccc97eba2	JCB 16 digit	29.4321950978670266	-98.4672997130848415
11237	2020-02-04 03:45:17	2020-02-04	Catherine Welch	catherine.welch@geemail.com	New York	New York	3465255517150969	84a51707934bb81fc0cc630845849526	Discover	40.667509349364785	-74.0009211575508061
11238	2020-02-04 04:18:50	2020-02-04	Mrs. Valeria Conn PhD	mrs.valeria.conn.phd@geemail.com	New York	New York	4690538902166093	3cce2a55074eb0622182a15f54adb185	VISA 16 digit	40.5850268657077109	-73.8722592431481928
11239	2020-02-04 04:19:33	2020-02-04	Pasquale Casper	pasquale.casper@woohoo.com	San Francisco	California	210045135971534517	578eb9fb9653da3f0659eac65a8957ea	Diners Club / Carte Blanche	37.7834532601383941	-122.446916379757468
11240	2020-02-04 04:36:17	2020-02-04	Mima Muller	mima.muller@geemail.com	Glendale	Arizona	4384219218698	47c3f4b64e7687326a9d80e57288f90e	Discover	33.4684265670128127	-112.171741984018681
11241	2020-02-04 04:39:26	2020-02-04	Pepper Dare	pepper.dare@geemail.com	Davenport	Iowa	6011159573982108438	3af69fe15a9df6fdce9e946a59562252	JCB 16 digit	41.6473924708817123	-90.5710194811653366
11242	2020-02-04 05:27:34	2020-02-04	Jeffery Lowe	jeffery.lowe@geemail.com	Wichita	Kansas	3088853648402516581	564126803def2d64eb921162ccc08d2d	JCB 16 digit	37.6985329233452688	-97.3596587507720983
11243	2020-02-04 05:32:45	2020-02-04	Gil Davis Sr.	gil.davis.sr.@geemail.com	Baton Rouge	Louisiana	53202496283280747	69e121c12b76f16813ad234145db5a72	JCB 16 digit	30.5417186039712263	-91.1952722611479487
11244	2020-02-04 05:45:51	2020-02-04	Tatyanna Stracke	tatyanna.stracke@geemail.com	Berkeley	California	4170859401019016	bbb1fa95022594f313bca10e312a6582	VISA 16 digit	37.8966325363802099	-122.29360430435753
11245	2020-02-04 05:46:26	2020-02-04	Barnett Hoppe	barnett.hoppe@warmmail.com	Waterbury	Connecticut	210015771867576695	90f40af942a8dd19a124482d1aa89153	American Express	41.6101506555024585	-73.111095969882598
11246	2020-02-04 06:15:49	2020-02-04	Ashtyn Sporer-Fay	ashtyn.sporer.fay@geemail.com	Berkeley	California	3112804034927311172	906ad09ccfbf1e06d923ad7165722615	VISA 13 digit	37.8409471980617553	-122.2353106195349
11247	2020-02-04 06:22:12	2020-02-04	Miss Debra Conroy	miss.debra.conroy@geemail.com	San Francisco	California	3112706557757110735	fd727cb0f80ab82ce722106b9cd52460	JCB 16 digit	37.7798205058827747	-122.444636855753672
11248	2020-02-04 06:23:21	2020-02-04	Jonna Toy DDS	jonna.toy.dds@warmmail.com	Seattle	Washington	3337430736149706342	ddf4e72c4a0d932ec321cb38007dc0a3	Mastercard	47.6715070903692393	-122.308759667018052
11249	2020-02-04 07:01:30	2020-02-04	Quincy Marvin	quincy.marvin@geemail.com	Jacksonville	Florida	869935076088727291	a71565903a490dea2d6ad2594c856e3a	VISA 16 digit	30.2527774506300702	-81.6844094697929961
11250	2020-02-04 07:42:00	2020-02-04	Dr. Camila Metz	dr.camila.metz@warmmail.com	Philadelphia	Pennsylvania	4086558088046283	c52f8adb4d42775476eac2da04402206	American Express	39.9894631508696818	-75.03426459593625
11251	2020-02-04 07:52:31	2020-02-04	Karan Casper	karan.casper@geemail.com	Charlotte	North Carolina	3337934448591287844	a8caf8925bfd08a4b095c392ed1f6b1d	American Express	35.1205111715264593	-80.9075593933407191
11252	2020-02-04 08:08:18	2020-02-04	Tallie Simonis	tallie.simonis@geemail.com	Broken Arrow	Oklahoma	3036627065892915	b49405284312f0109da7a2496e84b6c8	Discover	35.9435548519957777	-95.8085893893558591
11253	2020-02-04 08:17:09	2020-02-04	Mina Rippin	mina.rippin@geemail.com	Oakland	California	6011091672276549215	3d2d87734a3284119c8fbd82b5f257ec	Mastercard	37.8049266221633715	-122.269588309015489
11254	2020-02-04 08:21:29	2020-02-04	Mr. Rolando Hartmann II	mr.rolando.hartmann.ii@geemail.com	New York	New York	4688190418188	400f2d4179efbdf1e4b7bfc4492aed3d	VISA 16 digit	40.6212689720317712	-73.8808755546703964
11255	2020-02-04 08:34:06	2020-02-04	Ura Hane	ura.hane@geemail.com	Detroit	Michigan	3158714173844578122	974e4c83d74635ea2905fa55deb1d4fe	VISA 16 digit	42.3471352646984158	-83.0940775420635873
11256	2020-02-04 09:13:45	2020-02-04	Dock Considine	dock.considine@warmmail.com	Las Vegas	Nevada	3088665567491208504	3b1aab3687b29248071dcd32b92f39d5	Voyager	36.1435070570658894	-115.317765972271928
11257	2020-02-04 09:21:00	2020-02-04	Mr. Charles Cole	mr.charles.cole@geemail.com	Laredo	Texas	3466258405382602	8d265a04bfd1311008c70386f70e094d	Voyager	27.605055168056488	-99.5881763755816962
11258	2020-02-04 09:35:29	2020-02-04	Darla Mueller	darla.mueller@geemail.com	McKinney	Texas	4066957096812	864d2213819018b6843aaa1c29cc8177	Diners Club / Carte Blanche	33.2821667151656015	-96.7643308492209826
11259	2020-02-04 09:43:24	2020-02-04	Yahaira Doyle	yahaira.doyle@geemail.com	San Francisco	California	180085403756583187	fd68c9a59267723304723073d89f8f27	Mastercard	37.7710543643301833	-122.430289266598905
11260	2020-02-04 09:44:37	2020-02-04	Dr. Leon Hudson III	dr.leon.hudson.iii@woohoo.com	San Francisco	California	3158036041547250847	d472d60f343b5d705948da864870377f	Voyager	37.7631001612134156	-122.451264039757234
11261	2020-02-04 09:45:35	2020-02-04	Eileen Powlowski DVM	eileen.powlowski.dvm@geemail.com	Houston	Texas	51170087805365112	05dfd41359943991262a4305f5d7de4f	Mastercard	29.8788780342400067	-95.4574474289562573
11262	2020-02-04 09:56:00	2020-02-04	Karyme Witting	karyme.witting@woohoo.com	Berkeley	California	4218872410648802	cd6bfe9fde07254d42f5ee3dcc93f0b7	JCB 16 digit	37.9074799188590674	-122.234775647068062
11263	2020-02-04 09:59:43	2020-02-04	Gisselle Johnston	gisselle.johnston@geemail.com	Brownsville	Texas	55644968675934335	70640b0d7fd1faaebffdd03cb6613e63	Mastercard	25.9255265611302086	-97.5509455621894404
11264	2020-02-04 10:03:40	2020-02-04	Jameel Johnson-Haley	jameel.johnson.haley@geemail.com	Minneapolis	Minnesota	4811768296006	7206cfe7465996cc97f18b3ef4ac8c6c	VISA 16 digit	44.9026718826584457	-93.3267740103222394
11265	2020-02-04 10:08:03	2020-02-04	Parker Witting	parker.witting@woohoo.com	Jersey City	New Jersey	4388489145624695	edd82621f8e57b6f29bac823a11b34c9	JCB 16 digit	40.6760856680512433	-74.1458439677443408
11266	2020-02-04 10:49:39	2020-02-04	Erykah Renner	erykah.renner@geemail.com	Houston	Texas	3448817920190874	cc0eb0e87bd5a9bc75a3d1d63c122d42	VISA 13 digit	29.8123767245173461	-95.3615437335349583
11267	2020-02-04 10:59:11	2020-02-04	Davion Mayert Sr.	davion.mayert.sr.@geemail.com	Charleston	South Carolina	869934116463250203	10b0a4f3ea67482d679daa5a559cc18b	Discover	32.7427069099150643	-79.8748931382466196
11268	2020-02-04 11:04:19	2020-02-04	Julie Carroll	julie.carroll@geemail.com	Santa Clarita	California	3001914290584227	4b195fc40709e9a808f032188b282862	American Express	34.3495701535809772	-118.542132082638147
11269	2020-02-04 11:04:39	2020-02-04	Joshuah Wilkinson-Rolfson	joshuah.wilkinson.rolfson@warmmail.com	Oakland	California	3421532597278255	4eb641c1c4d5ffc73f0f7ed5594768eb	JCB 15 digit	37.8163330354047957	-122.253404367549535
11270	2020-02-04 11:12:09	2020-02-04	Hellen Beer	hellen.beer@geemail.com	Lancaster	California	54691042632922353	d24358ebe465ce6ddcfb42309fbd0d26	Diners Club / Carte Blanche	34.603779408220575	-118.172666384044277
11271	2020-02-04 11:24:26	2020-02-04	Adriane Hahn	adriane.hahn@geemail.com	Lexington	Kentucky	4296286613359825	f64fd5eba68ceaa2d6901e0df6b3004e	Voyager	38.0929638087160924	-84.4963828692112031
11272	2020-02-04 11:26:59	2020-02-04	Everette Altenwerth	everette.altenwerth@geemail.com	Berkeley	California	6011192327019328421	00c4335fa93388b99916d10f111bc90d	JCB 15 digit	37.8859785882045088	-122.323349579798332
11273	2020-02-04 11:31:24	2020-02-04	Tamela McKenzie	tamela.mckenzie@woohoo.com	Los Angeles	California	3528750279767379300	fe7b44d15e7651d066d5300f399d1cf1	JCB 15 digit	33.9378554835315782	-118.460025165229283
11274	2020-02-04 11:41:28	2020-02-04	Wes Watsica	wes.watsica@geemail.com	Garland	Texas	3096070252800202360	195d01971f5215f859baae8972f79f8c	JCB 16 digit	32.8975973558846846	-96.6395945714481286
11275	2020-02-04 11:46:04	2020-02-04	Kirstin Goodwin	kirstin.goodwin@geemail.com	New York	New York	4488285258882	71e93d1a9939076b000fb624afe2cf16	JCB 16 digit	40.6727682360205804	-73.9380757527321606
11276	2020-02-04 12:00:52	2020-02-04	Shellie Cassin	shellie.cassin@geemail.com	San Francisco	California	4722592026545	a8bae519995bf852d02429f50463d725	American Express	37.7555452843201778	-122.393275911260574
11277	2020-02-04 12:05:35	2020-02-04	Mr. Tahj DuBuque III	mr.tahj.dubuque.iii@geemail.com	Jacksonville	Florida	4200548441332	2262cef6edda1f5e12f5776ed521f41b	Discover	30.3899035413336023	-81.6181522205084633
11278	2020-02-04 12:21:37	2020-02-04	Christina Ryan	christina.ryan@warmmail.com	San Francisco	California	180054364861368129	35a705a01149fcc619ae6fcce85e0b5d	JCB 16 digit	37.7916925370717536	-122.467419063553578
11279	2020-02-04 12:43:17	2020-02-04	Thad Bartell	thad.bartell@warmmail.com	Cape Coral	Florida	6011628203690655610	b849b58aa8eeb85f6e5a1bb56ff79831	Discover	26.5598935127228515	-82.0356006571628171
11280	2020-02-04 13:03:19	2020-02-04	Allene Murphy	allene.murphy@woohoo.com	Los Angeles	California	589363975869569	e513c145c2614e6020a62bc9f2b47abe	VISA 16 digit	34.0825841741036584	-118.498910932940618
11281	2020-02-04 13:09:28	2020-02-04	Doretha Gorczany	doretha.gorczany@woohoo.com	San Francisco	California	4411643029050	13bdfec85f9d0798fde23409265df66d	JCB 15 digit	37.7461968218855617	-122.445218767807305
11282	2020-02-04 13:18:05	2020-02-04	Lane Gottlieb	lane.gottlieb@geemail.com	Virginia Beach	Virginia	869906818452572786	346bfa27260b7fc165d2d44a32bdf9aa	JCB 16 digit	36.7491729752812546	-76.1202800926424601
11283	2020-02-04 14:08:49	2020-02-04	Elie Bernier	elie.bernier@warmmail.com	Los Angeles	California	4214624366905494	c9127efc3b883f331f322463888e45fd	American Express	33.9407459209073323	-118.458561325584725
11284	2020-02-04 14:15:44	2020-02-04	Dr. Vashon Schneider	dr.vashon.schneider@geemail.com	Portland	Oregon	869905068511278683	1e4a186cb7e20e1f4113b47f67f6fbeb	JCB 15 digit	45.5988700831197207	-122.709437422547495
11285	2020-02-04 14:16:40	2020-02-04	Koda Kuhlman	koda.kuhlman@woohoo.com	Port St. Lucie	Florida	53543614657928752	a995d88428657019f4c0f267ec251ac1	JCB 15 digit	27.2468211227696386	-80.3088802752170778
11286	2020-02-04 14:54:47	2020-02-04	Jovan Bogan Sr.	jovan.bogan.sr.@warmmail.com	Chicago	Illinois	6011741278589940051	507af1015d4bfd9b258778d07e45c493	VISA 16 digit	41.9321795226842156	-87.7231880085106894
11287	2020-02-04 15:02:13	2020-02-04	Ms. Marlo Morissette PhD	ms.marlo.morissette.phd@geemail.com	San Francisco	California	4974273088602078	2ad4ff4217bd4d8755f6078f4177a2e6	VISA 13 digit	37.7934406218555026	-122.423384368578226
11288	2020-02-04 15:15:31	2020-02-04	Silvester Hane	silvester.hane@woohoo.com	Atlanta	Georgia	180040767592684712	490b96d99d1a84c0277ba0961d27d69c	VISA 16 digit	33.8170006135288617	-84.4246885624293242
11289	2020-02-04 15:15:56	2020-02-04	Marylin Wiza	marylin.wiza@geemail.com	Berkeley	California	3038543211991030	0a29b17599d3a9b287e21a967cff9d5c	Voyager	37.8496603224907915	-122.26014786556135
11290	2020-02-04 15:29:58	2020-02-04	Rene Baumbach	rene.baumbach@geemail.com	Reno	Nevada	3112884848396386263	e9cc5589955eed6d641031682ea25a0a	JCB 16 digit	39.4911933794230237	-119.825741082306578
11291	2020-02-04 15:36:08	2020-02-04	Monserrat Schoen-Maggio	monserrat.schoen.maggio@geemail.com	Oklahoma City	Oklahoma	54919583243101974	58187ad5f46dd9cac47303e7cfa352b7	Discover	35.528988711526992	-97.4867850981082711
11292	2020-02-04 15:38:15	2020-02-04	Sarah Lemke	sarah.lemke@woohoo.com	New York	New York	3719498472153613	83554e7f556e0a7edd76cd9a25c09872	VISA 16 digit	40.6453128731101714	-73.9796149120561779
11293	2020-02-04 15:40:39	2020-02-04	Brittany Roob	brittany.roob@geemail.com	Berkeley	California	3476384850485233	5e501829fc055323fe8ee393e9301e13	Mastercard	37.8877944298587153	-122.293917504959609
11294	2020-02-04 15:45:44	2020-02-04	Graves Mosciski	graves.mosciski@geemail.com	Cary	North Carolina	4408323293491068	892913ac07cb5b47bf84ce27f176805f	Diners Club / Carte Blanche	35.7930136459056314	-78.8476728334177324
11295	2020-02-04 15:55:17	2020-02-04	Tia Feil	tia.feil@geemail.com	Chicago	Illinois	3401563949964312	d8261b5796d50c2815048cb26546cb21	Maestro	41.8176579547882099	-87.6362692659750593
11296	2020-02-04 15:58:56	2020-02-04	Latricia Corkery	latricia.corkery@geemail.com	New York	New York	210014773873823732	2d22392c4124abcb22de54a73d5ddf18	JCB 16 digit	40.5827012906540148	-74.0080303905427428
11297	2020-02-04 16:28:29	2020-02-04	Almond Glover-Crooks	almond.glover.crooks@warmmail.com	Allen	Texas	4273329534286	895a439e0cd861d74e4d4a18372c34cb	Diners Club / Carte Blanche	33.0080445440512165	-96.6036368397012382
11298	2020-02-04 17:03:30	2020-02-04	Loyd Frami	loyd.frami@geemail.com	Lafayette	Louisiana	869977556030765043	9bef51c8edb4d720647e3670f7684498	Maestro	30.1372030059784635	-92.0380449841115507
11299	2020-02-04 18:20:48	2020-02-04	Kelley Cummerata	kelley.cummerata@geemail.com	Oakland	California	3112395580166586507	2cb50eba90734b44a5cc47d3cc0785ce	JCB 16 digit	37.7921881037210952	-122.262831590928968
11300	2020-02-04 18:45:06	2020-02-04	Marci Kling DVM	marci.kling.dvm@warmmail.com	Dallas	Texas	4158757527932045	0ddd33725279bffb69e08c89b054e2fa	JCB 16 digit	32.8855523711342386	-96.6926785658541945
11301	2020-02-04 18:48:11	2020-02-04	Devonta Christiansen	devonta.christiansen@geemail.com	Long Beach	California	6011562874038371694	34e5c27a72759fbe978c0369a89f2a13	Discover	33.9020004716057315	-118.141744240575647
11302	2020-02-04 19:25:32	2020-02-04	Misty Kautzer-Morissette	misty.kautzer.morissette@geemail.com	San Antonio	Texas	6011578534292564416	ef95c4ed8dd811b84c014ed6e72edac4	VISA 13 digit	29.5236056936975579	-98.4826164077337722
11303	2020-02-04 20:02:26	2020-02-04	Fidencio Boyer	fidencio.boyer@woohoo.com	Minneapolis	Minnesota	6011165976764186260	a049f8be65cd83b4a76f0654cff18f6a	VISA 16 digit	44.9722868380222423	-93.3033386349018627
11304	2020-02-04 20:08:37	2020-02-04	Ms. Vernice Bayer MD	ms.vernice.bayer.md@warmmail.com	Oakland	California	3088909637374821669	d730be8f750cfb68cedb3125625caf3b	JCB 16 digit	37.8083195344389793	-122.302472885533717
11305	2020-02-04 20:17:52	2020-02-04	Dr. Lawrence Weber II	dr.lawrence.weber.ii@warmmail.com	San Francisco	California	3046875161408843	ad193e3f3822af97bccc691c71c3f9a0	JCB 16 digit	37.7843768978344556	-122.422688384878029
11306	2020-02-04 21:10:16	2020-02-04	Bunk Spencer	bunk.spencer@geemail.com	New York	New York	869983717037657904	8ed28ddb3cecd7318f74e509259ff1ef	VISA 13 digit	40.6167670645043231	-73.898931932345775
11307	2020-02-04 21:26:42	2020-02-04	Gerri Schaden	gerri.schaden@geemail.com	San Francisco	California	3088365348966487292	d64e0a677493a471b7c0a070fc892075	VISA 13 digit	37.738953728684379	-122.43078036921743
11308	2020-02-04 21:51:11	2020-02-04	Hung Mosciski	hung.mosciski@geemail.com	Cleveland	Ohio	4648686148051455	610c149042332a922476fb99395c9ea6	JCB 16 digit	41.3805012826658754	-81.6288497546460547
11309	2020-02-04 22:48:11	2020-02-04	Georgene Leffler	georgene.leffler@geemail.com	Frisco	Texas	869997146089610054	5f79997615369e77a54905a7e9b59916	VISA 16 digit	33.1178195120297403	-96.782344173102075
11310	2020-02-04 23:13:11	2020-02-04	Hailee Smitham DVM	hailee.smitham.dvm@geemail.com	Clovis	California	6011982659800706181	3e04056dbdd999eb0c1a8c48ab903dd2	Voyager	36.7951879091437917	-119.706175994041928
11311	2020-02-04 23:13:56	2020-02-04	Joette Doyle	joette.doyle@geemail.com	Laredo	Texas	869968233906058066	b187f0524ba50e9fccfe91490a7ee7f1	Mastercard	27.6466109372857964	-99.5422388444196429
11312	2020-02-04 23:38:23	2020-02-04	Dr. Eugenio Reichel	dr.eugenio.reichel@geemail.com	Syracuse	New York	4660047176284943	5966423411e34ae267b0f855a60ae385	JCB 15 digit	43.0128137298244937	-76.1132139391511799
11313	2020-02-04 23:49:14	2020-02-04	April Goodwin	april.goodwin@woohoo.com	Riverside	California	4186904141451	44cc953a0ace83bdc91f5672e5a9f5ac	JCB 16 digit	33.929258981481567	-117.29364424086809
11314	2020-02-05 00:24:42	2020-02-05	Adella Batz	adella.batz@warmmail.com	Oakland	California	6011131750211878717	9ba440ffff6548e15bb1a6e776e0939f	Mastercard	37.8051321318235196	-122.293214939371538
11315	2020-02-05 00:41:31	2020-02-05	Judson Nicolas	judson.nicolas@woohoo.com	Minneapolis	Minnesota	6011544315357211247	f4088ae00ce55d6ed955f3fee0f43a2e	JCB 16 digit	44.8867709991142121	-93.2473029514115268
11316	2020-02-05 01:08:32	2020-02-05	Codey Langworth	codey.langworth@geemail.com	Wichita	Kansas	675940014976019	2f71b2bfa91b25ebd57bf235093d6752	Diners Club / Carte Blanche	37.7258866506040107	-97.4150800870467037
11317	2020-02-05 01:31:28	2020-02-05	Jalon Ferry	jalon.ferry@woohoo.com	Norfolk	Virginia	4865452807071201	ec962100b5dd97f4cd590c8c1ff5bb16	Diners Club / Carte Blanche	36.9342693767994632	-76.3244456804826967
11318	2020-02-05 01:44:18	2020-02-05	Prentiss Dicki	prentiss.dicki@warmmail.com	San Francisco	California	4133782502134656	00ec4b8379667ee623e8622562242d58	VISA 16 digit	37.7768009853236251	-122.408527886018732
11319	2020-02-05 01:50:04	2020-02-05	Pearlie Lang	pearlie.lang@geemail.com	Billings	Montana	3337937056820343457	a0694906e1bb47b1f7fae19d93d6ecc4	VISA 16 digit	45.79293647853099	-108.627848578121132
11320	2020-02-05 01:57:13	2020-02-05	Chesley Gleichner	chesley.gleichner@geemail.com	Irving	Texas	4726686247240004	e6cdf4dbe8d4e12784dc128bcea1358a	JCB 16 digit	32.873283921968941	-97.0236152272950818
11321	2020-02-05 02:16:12	2020-02-05	Miss Flor McDermott	miss.flor.mcdermott@geemail.com	Virginia Beach	Virginia	3030999261585528	7193b6bd895b7244ea4ad0cb96f228fd	JCB 16 digit	36.8145193360000889	-75.9327492563657387
11322	2020-02-05 02:21:10	2020-02-05	Mr. Kaye Watsica	mr.kaye.watsica@geemail.com	South Bend	Indiana	3005766173794125	8ff8903dc545cf06f23d9a59587adbf2	Mastercard	41.7670903461199288	-86.3422205644249914
11323	2020-02-05 02:36:51	2020-02-05	Chandler Cartwright	chandler.cartwright@geemail.com	San Francisco	California	6011805134133332282	a8f702ed2ac3ee6ef6cbcc4666c54453	Diners Club / Carte Blanche	37.7508058625119531	-122.425575216648653
11324	2020-02-05 03:02:13	2020-02-05	Shane Breitenberg MD	shane.breitenberg.md@warmmail.com	San Francisco	California	4505542630973	8509306fcaa02d5c6bc828c62a67d8c3	Mastercard	37.7333525711838931	-122.408199021466885
11325	2020-02-05 03:06:32	2020-02-05	Phyllis Bins DDS	phyllis.bins.dds@geemail.com	New York	New York	3001290186384893	ed2213f9f64d848bcbd253a1032b6005	JCB 16 digit	40.5908318396881214	-73.8816882814642071
11326	2020-02-05 03:34:59	2020-02-05	Carina O'Kon	carina.o'kon@geemail.com	San Francisco	California	3036815363716650	c442c52aa029c4077cf6475cc5da47aa	Mastercard	37.7676078588156869	-122.437845494761021
11327	2020-02-05 03:40:52	2020-02-05	Clell Dibbert	clell.dibbert@geemail.com	Greeley	Colorado	53778096560970368	e2c38207b730d575e368e3805e92f6ba	VISA 16 digit	40.3834673155166257	-104.754170771392808
11328	2020-02-05 03:50:06	2020-02-05	Deon Funk	deon.funk@geemail.com	Hampton	Virginia	675982065460766	88523c4425f0c2903794e6a51def22e4	JCB 16 digit	37.1268645966909858	-76.3375923832975332
11329	2020-02-05 04:09:40	2020-02-05	Nichole Kub MD	nichole.kub.md@warmmail.com	San Francisco	California	210072173734395021	8ba2a0eaf24709cdfeb0ab7050acd587	JCB 16 digit	37.736298690503574	-122.417563741949891
11330	2020-02-05 04:48:23	2020-02-05	Dr. Darrell Schimmel	dr.darrell.schimmel@geemail.com	Glendale	Arizona	180054969716990784	1b98e33b6061f6b341c5532a33712d1f	JCB 15 digit	33.5619812301121598	-112.099260698889935
11331	2020-02-05 05:11:50	2020-02-05	Carmine Hettinger	carmine.hettinger@geemail.com	San Antonio	Texas	52718652498923474	c67baec150207b8376fce63918965ec1	JCB 15 digit	29.4010795648280521	-98.4587535881273368
11332	2020-02-05 05:12:20	2020-02-05	Donat Cole	donat.cole@geemail.com	San Francisco	California	4287746499227454	8fc7eb9fc1f63b754740cd0cf6caefe9	JCB 15 digit	37.7707176025646802	-122.436571381527557
11333	2020-02-05 05:38:45	2020-02-05	Merritt Bergnaum	merritt.bergnaum@woohoo.com	Irvine	California	4330787828657	b9499da7c398686268958a9cb4fd3cce	Voyager	33.5971937784008716	-117.814868747956297
11334	2020-02-05 05:39:34	2020-02-05	Dr. Draven Konopelski	dr.draven.konopelski@woohoo.com	San Francisco	California	6011829249520041114	fb210424fad43edd8b187913613cd075	JCB 16 digit	37.7527699851656138	-122.427533337694058
11335	2020-02-05 05:59:02	2020-02-05	Thursa Leffler	thursa.leffler@geemail.com	Oklahoma City	Oklahoma	3477184130691124	62fe0ac2a67b2a5853893d13dda4c2d5	American Express	35.4990836659822619	-97.4570194802608398
11336	2020-02-05 06:10:45	2020-02-05	Nallely Lang	nallely.lang@geemail.com	Honolulu	Hawaii	3045513462043222	2c9dae9dfc8cd5cc0321de50058cc22d	VISA 16 digit	21.4131940895907604	-157.873610790234437
11337	2020-02-05 06:15:01	2020-02-05	Brain Cronin	brain.cronin@geemail.com	Detroit	Michigan	4408847077534958	6490d067e57375f72501cdf7955c1757	VISA 16 digit	42.3698838238529873	-83.0884045838497514
11338	2020-02-05 06:16:40	2020-02-05	Berdie Strosin	berdie.strosin@geemail.com	San Francisco	California	6011353787434655747	181e8cbd45754fd3bdf2569e781b7170	JCB 16 digit	37.7796584593346907	-122.41940958121279
11339	2020-02-05 06:45:43	2020-02-05	Odessa Reynolds	odessa.reynolds@geemail.com	Chicago	Illinois	4772326861745987	ef733b60d5df547f7aa317765ef0a26b	Voyager	41.8082147055607294	-87.6017808326549812
11340	2020-02-05 07:07:22	2020-02-05	Dr. Burrel Fisher MD	dr.burrel.fisher.md@geemail.com	San Francisco	California	3096583225765395072	3aff97561abf42568a7a05a7ddab1f4b	JCB 16 digit	37.7562191656944677	-122.436346486483117
11341	2020-02-05 07:34:40	2020-02-05	Gabriella Stoltenberg DDS	gabriella.stoltenberg.dds@geemail.com	Philadelphia	Pennsylvania	4752266435115776	4442fb0b656d2ed22538fef53279be20	Maestro	39.9260809755843127	-75.1752822483789203
11342	2020-02-05 07:37:10	2020-02-05	Luberta Dickinson	luberta.dickinson@geemail.com	Pittsburgh	Pennsylvania	3011723477669564	f09241b9c855ee14941cdbdfa266c250	VISA 16 digit	40.4423034514255804	-80.0255578431006569
11343	2020-02-05 08:02:43	2020-02-05	Marleen Carroll	marleen.carroll@geemail.com	San Francisco	California	3740075749400333	db22a8165f29f27afe955ecc93c7cbec	American Express	37.7798076545831023	-122.439431292923004
11344	2020-02-05 08:17:03	2020-02-05	Percival Boyer Sr.	percival.boyer.sr.@geemail.com	Billings	Montana	52173890894776801	8dcdb3e933d942178cc135380ab03368	Diners Club / Carte Blanche	45.8207256898507467	-108.525677423195532
11345	2020-02-05 08:22:52	2020-02-05	Ivana Schulist	ivana.schulist@geemail.com	Detroit	Michigan	3096546713062398184	aa2e4a23a404a1185baf11f4c0e7695e	JCB 15 digit	42.4077068321332362	-83.1230223077934198
11346	2020-02-05 08:56:34	2020-02-05	Ethyl Padberg	ethyl.padberg@geemail.com	Jacksonville	Florida	4143836974171311	ff2b66950f84466f4d4a1b7f14a0b25c	Maestro	30.4308879128709435	-81.6063660461533829
11347	2020-02-05 08:59:43	2020-02-05	Wendel Bode	wendel.bode@geemail.com	Chicago	Illinois	4967138597484780	578cab7c5a3a468f463948f6d139950b	JCB 15 digit	41.831360639335962	-87.6950112103514385
11348	2020-02-05 09:17:15	2020-02-05	Garvin Grady	garvin.grady@geemail.com	New York	New York	869927625562245046	939488b321a9fe4f28054b5293c02dc9	Maestro	40.7032015411406718	-74.0376724511746289
11349	2020-02-05 09:27:41	2020-02-05	Daulton Jones	daulton.jones@geemail.com	Lincoln	Nebraska	3528354174616594417	de97e5083210651acf038e15feb7469a	VISA 16 digit	40.7318382880669034	-96.64639320230782
11350	2020-02-05 09:30:53	2020-02-05	Miss Nedra McClure PhD	miss.nedra.mcclure.phd@geemail.com	Greensboro	North Carolina	4233695517226920	62e456902dce942105622ff4ee421610	Diners Club / Carte Blanche	36.1825331246595852	-79.7743099044524087
11351	2020-02-05 09:36:39	2020-02-05	Jaqueline Marquardt	jaqueline.marquardt@geemail.com	San Francisco	California	3088815839934479961	ef15571d9313f140e781f8679e6c3534	JCB 16 digit	37.7610186569862947	-122.411561370584224
11352	2020-02-05 09:51:29	2020-02-05	Sammie Terry-Gulgowski	sammie.terry.gulgowski@geemail.com	Austin	Texas	4904162046133	99ddc5bf0c800abafe4148827525a8c5	Discover	30.2404801390726092	-97.8542188754078097
11353	2020-02-05 09:57:35	2020-02-05	Roman Jenkins	roman.jenkins@geemail.com	Sugar Land	Texas	3777873556012928	5d955627e52ad76b9f923119e47fac20	Voyager	29.6192124691378318	-95.5208564437933205
11354	2020-02-05 10:02:13	2020-02-05	Dawne Gusikowski	dawne.gusikowski@geemail.com	Detroit	Michigan	676304326129568	32a0afec8ec2729790b6ed9a41929fd0	Maestro	42.4763464734349441	-83.1645013434000333
11355	2020-02-05 10:14:02	2020-02-05	Alberto Hartmann-Cassin	alberto.hartmann.cassin@geemail.com	Chicago	Illinois	3023333635149497	94d5b10f7c25f4d14e385caf102959be	American Express	41.8723784608602543	-87.7709246745828437
11356	2020-02-05 10:21:04	2020-02-05	Maryellen Friesen	maryellen.friesen@geemail.com	Oakland	California	3035995169952302	f5bb4e2b2005198af5011cf6de5d05af	JCB 16 digit	37.7977123953046998	-122.246703709227802
11357	2020-02-05 10:22:58	2020-02-05	Marcelo Rogahn	marcelo.rogahn@woohoo.com	Oakland	California	180028403061482497	6400a3f957f50e99532447d65c777fb5	JCB 16 digit	37.7938182938763063	-122.263432685670537
11358	2020-02-05 11:37:25	2020-02-05	Herma Rippin	herma.rippin@warmmail.com	New York	New York	180018185278745590	5a7367b8d6c07538a0460c855814190d	Voyager	40.6498726390991365	-73.891188581137726
11359	2020-02-05 11:50:31	2020-02-05	Kipp Bartoletti	kipp.bartoletti@geemail.com	San Francisco	California	4389890976522	5a045c250cefdee2035d0aab35d97473	Voyager	37.7677397401192181	-122.420296433351126
11360	2020-02-05 11:55:06	2020-02-05	Randal Collins	randal.collins@geemail.com	Richmond	California	6011245594446691617	f7331c4a0472410079e15ff6714ccf45	American Express	37.8777555274732407	-122.446535312835508
11361	2020-02-05 12:49:44	2020-02-05	Dr. Rhea Langosh	dr.rhea.langosh@geemail.com	Hialeah	Florida	3041675824798340	01b9880d45905622f2722a7324a5d09e	American Express	25.9159279354359953	-80.336145900692415
11362	2020-02-05 12:50:36	2020-02-05	Reuben Haley	reuben.haley@geemail.com	Berkeley	California	210036072779355913	cdb932034d72e219b4ff8e87251aea2d	VISA 16 digit	37.8652164861809197	-122.244839264267441
11363	2020-02-05 13:29:18	2020-02-05	Glendon Bartell Sr.	glendon.bartell.sr.@geemail.com	New York	New York	4816859884644	25b395c33c4e1ba4b997f72a12309240	Diners Club / Carte Blanche	40.743481922218578	-73.8485377768881648
11364	2020-02-05 13:29:52	2020-02-05	Julio Shields	julio.shields@geemail.com	Los Angeles	California	3528504420594528888	4d5d4f52fe83dc613723e359052d53df	JCB 15 digit	34.1157827108964327	-118.487132338945941
11365	2020-02-05 13:34:34	2020-02-05	Griffin Nikolaus-Marquardt	griffin.nikolaus.marquardt@geemail.com	New York	New York	3783616717221801	c5d3f7e0c95d94597e2d774657916120	VISA 13 digit	40.573010694211348	-73.9900075515162143
11366	2020-02-05 14:02:58	2020-02-05	Mrs. Lexi Frami MD	mrs.lexi.frami.md@geemail.com	New York	New York	4642793425774480	6e908950ead8e574eca6f1ec521aca03	American Express	40.6282999031469245	-73.999755548489091
11367	2020-02-05 14:10:26	2020-02-05	Roosevelt Durgan	roosevelt.durgan@geemail.com	Houston	Texas	3096596966642420634	e9df6dfeb1a8dc230a4bcfa3ff26a741	Voyager	29.7745837688989923	-95.4808256381206206
11368	2020-02-05 14:14:25	2020-02-05	Delpha Gibson	delpha.gibson@geemail.com	San Francisco	California	3528945070042468851	f42e1aa7be8af43a9459c740c1c3dfca	VISA 13 digit	37.7448230520469252	-122.417451395381548
11369	2020-02-05 15:10:31	2020-02-05	Mr. Fenton Volkman Jr.	mr.fenton.volkman.jr.@geemail.com	Elk Grove	California	6011491289684752921	175cf9f2b28ac3f37361bcf211dcd203	American Express	38.4920082422256442	-121.292648236723622
11370	2020-02-05 15:22:06	2020-02-05	Ples Hills	ples.hills@geemail.com	San Francisco	California	4928657718161	c6620df6291b49378a3c4c5d9cdd6795	Discover	37.781703561536176	-122.432873672462506
11371	2020-02-05 16:28:31	2020-02-05	Carleigh Murazik	carleigh.murazik@geemail.com	Lakewood	Colorado	3759158436346833	ebce8959bb1362bf7cf18166f9fbb882	Discover	39.6801615040224078	-105.079828357046836
11372	2020-02-05 16:36:43	2020-02-05	Miss Clementina Will DVM	miss.clementina.will.dvm@geemail.com	Tacoma	Washington	4408803596303433	66b5f8db8fdcfb2e215cfa706270a9a4	JCB 16 digit	47.2883517847050001	-122.527041741763426
11373	2020-02-05 16:43:50	2020-02-05	Floyd Ullrich DDS	floyd.ullrich.dds@geemail.com	Louisville	Kentucky	6011151222396249549	b07fb91b47975307476755bd88ae918c	Discover	38.127294448753446	-85.7216677121888893
11374	2020-02-05 16:52:01	2020-02-05	Chaney Robel-Will	chaney.robel.will@geemail.com	Fort Worth	Texas	4895926898090612	a31735f3ef05964a22c8a3c4aa118c83	Maestro	32.6951589943897005	-97.3109994234338416
11375	2020-02-05 16:58:10	2020-02-05	Ramsey Weissnat Jr.	ramsey.weissnat.jr.@geemail.com	Aurora	Illinois	869954983753430471	0e1859b51b0fbe62420e5cff0cab5b74	JCB 15 digit	41.6920025476478031	-88.2625643901921819
11376	2020-02-05 17:05:15	2020-02-05	Quentin Thompson	quentin.thompson@woohoo.com	Chicago	Illinois	3016793310074095	335eeae4bd3f26aef5100da64a946a63	Mastercard	41.8041702287107739	-87.5998106081534189
11377	2020-02-05 17:56:49	2020-02-05	Blane Tromp	blane.tromp@woohoo.com	Virginia Beach	Virginia	3112258340360930605	420996a15c9f53f91808f076b65e8676	Voyager	36.846952883079652	-75.9513775623075702
11378	2020-02-05 18:05:45	2020-02-05	Ana Jerde	ana.jerde@geemail.com	Huntington Beach	California	6011918064031365098	113eda52aaa570ac6641f638644ebbe6	VISA 16 digit	33.6566118424799328	-117.913555434451624
11379	2020-02-05 18:12:37	2020-02-05	Anabel Grady	anabel.grady@geemail.com	Oakland	California	3096502094708537119	941c26187cb9be1f657909305c6c92a3	JCB 16 digit	37.8156133628395992	-122.28683058141425
11380	2020-02-05 18:36:34	2020-02-05	Averi Wilkinson	averi.wilkinson@geemail.com	San Francisco	California	3729658557889724	03eebcb708c374fbc09e0d6dacb4de3f	Diners Club / Carte Blanche	37.7698094529288682	-122.409964531594241
11381	2020-02-05 18:37:41	2020-02-05	Argie Hirthe	argie.hirthe@woohoo.com	Pompano Beach	Florida	6011941603179591600	2ccda247a099e3f8dfeae9c1fb16fd75	VISA 16 digit	26.3375527577273516	-80.1756786926496687
11382	2020-02-05 18:42:31	2020-02-05	Muhammad Kihn	muhammad.kihn@geemail.com	Augusta	Georgia	3337551674414966288	b34d3c2781748077c42d23de61e4b4f2	JCB 16 digit	33.4172504408955575	-82.0335744653191483
11383	2020-02-05 20:32:27	2020-02-05	Dandre Kuhlman	dandre.kuhlman@geemail.com	San Francisco	California	3158574718225692683	640dc34f0467966279f9850f8e143234	JCB 16 digit	37.79306872942783	-122.448731111515642
11384	2020-02-05 20:38:55	2020-02-05	Dannie Beahan	dannie.beahan@warmmail.com	Memphis	Tennessee	52902404965198610	f2a54fe9c1538d3770481c188390073f	Maestro	35.1265033177632873	-89.9058027082379994
11385	2020-02-05 20:40:20	2020-02-05	Lilyana Quitzon	lilyana.quitzon@geemail.com	San Francisco	California	3051188331623563	f1fbea1655cd4102ba1d5c8c84450f35	Diners Club / Carte Blanche	37.7877035104525376	-122.424796814973021
11386	2020-02-05 21:08:33	2020-02-05	Mr. Dimitri Hackett	mr.dimitri.hackett@warmmail.com	Chicago	Illinois	4380443349168	be1cd0311f03d462653f6eb63b7a4c4a	Voyager	41.8639758031651397	-87.6417496818613273
11387	2020-02-05 21:32:12	2020-02-05	Sheridan Champlin V	sheridan.champlin.v@geemail.com	Boston	Massachusetts	4508775293225151	40802a85b80203bb89249c02d07d9300	Discover	42.3672044011000537	-70.9249609446570304
11388	2020-02-05 21:37:04	2020-02-05	Dr. Jayda Nicolas	dr.jayda.nicolas@geemail.com	Austin	Texas	3026337636083602	bf193b8812eb2b0257fee0ed8c869da1	Maestro	30.2863417614378037	-97.8510107275337049
11389	2020-02-05 22:05:34	2020-02-05	Mr. Bartholomew Effertz	mr.bartholomew.effertz@geemail.com	Boston	Massachusetts	3003900053479158	a75b824b57e8fbbad4c2532d9e8eb851	Mastercard	42.3774092280939243	-71.059482584143808
11390	2020-02-05 22:12:11	2020-02-05	Dr. Julian Torphy PhD	dr.julian.torphy.phd@geemail.com	San Francisco	California	3777928387538838	0fc49caeb6aefe8f71568559f9c592a7	VISA 13 digit	37.7739553578412881	-122.444094867997578
11391	2020-02-05 22:24:37	2020-02-05	Arsenio Kulas	arsenio.kulas@geemail.com	Louisville	Kentucky	4748548116614046	17e116c0b2a987081718150d8e3403e3	Voyager	38.1421289311625031	-85.7022602702096208
11392	2020-02-06 00:09:51	2020-02-06	Velia Hilpert	velia.hilpert@geemail.com	Hialeah	Florida	4889716510772301	587d4cccf9bab2b3f7704929a4c4a78f	Voyager	25.9528964279662837	-80.2358522753600027
11393	2020-02-06 00:16:30	2020-02-06	Mr. Kale Maggio	mr.kale.maggio@geemail.com	San Diego	California	180088147577792546	00fa0fa15498c0e6fb888b852da20fea	VISA 13 digit	32.8651436855152284	-117.110842938385915
11394	2020-02-06 00:24:05	2020-02-06	Wilton Hickle MD	wilton.hickle.md@woohoo.com	Berkeley	California	4775919342028309	888603ec2edd1cb5c9ca9eeea1e1042e	Voyager	37.8812708025536864	-122.262452756728663
11395	2020-02-06 00:26:49	2020-02-06	Evette VonRueden DDS	evette.vonrueden.dds@geemail.com	Oakland	California	4312609432633007	1aa724c7f003d1a96665e216f0e7d66f	Maestro	37.8142233482677597	-122.283013695586988
11396	2020-02-06 00:48:55	2020-02-06	Kenyatta Mertz	kenyatta.mertz@warmmail.com	Indianapolis	Indiana	180011742121917524	7b375325fdfd0445d73a783ac4ecb677	Maestro	39.755266360287365	-86.1520759158503182
11397	2020-02-06 00:49:35	2020-02-06	Shea Hessel V	shea.hessel.v@geemail.com	Henderson	Nevada	4148921218903086	956a1e8127ebd8514eda144034e34622	American Express	35.9223912260893741	-115.00358002415561
11398	2020-02-06 00:54:26	2020-02-06	Avis Runolfsson	avis.runolfsson@geemail.com	Oakland	California	4266164166917	4cd304dd6cee5999ff7eb686137fd836	JCB 15 digit	37.8238061869884419	-122.276632192938109
11399	2020-02-06 00:56:22	2020-02-06	Thomas Luettgen	thomas.luettgen@geemail.com	Port St. Lucie	Florida	4180366191333498	8b9cf24eee6ce06aad804ef480b9b5d1	Discover	27.2741267909895626	-80.343805016306419
11400	2020-02-06 01:20:08	2020-02-06	Ota Funk	ota.funk@warmmail.com	Dayton	Ohio	3112573583454464928	3537f89785f64a5358bf518933d04a70	VISA 16 digit	39.6859383383557187	-84.1321129764620252
11401	2020-02-06 01:31:41	2020-02-06	Jeffie Stehr	jeffie.stehr@geemail.com	Berkeley	California	55621297299806571	a23a88f71aaa0990a73930aebc7c63c4	American Express	37.8703367226838168	-122.271939259302584
11402	2020-02-06 01:49:28	2020-02-06	Curtis Schulist	curtis.schulist@woohoo.com	New York	New York	3041422050715478	c1ec904cfd22247249a3ec799fdc8df1	Mastercard	40.7130243427809333	-73.9806109440408619
11403	2020-02-06 02:27:54	2020-02-06	Kelli Hintz DDS	kelli.hintz.dds@warmmail.com	Des Moines	Iowa	3096522141612196239	e554b5f42c47f9ba6fde22034c138756	Diners Club / Carte Blanche	41.6692300820466173	-93.6379775745838998
11404	2020-02-06 02:29:51	2020-02-06	Scarlett Roberts	scarlett.roberts@geemail.com	Santa Rosa	California	180091272826430147	17808bf7bbd7a6741172cc88b205b60e	VISA 16 digit	38.4042070772156166	-122.638262781013182
11405	2020-02-06 02:35:57	2020-02-06	Hyman Stanton	hyman.stanton@geemail.com	Philadelphia	Pennsylvania	3404010771356529	6affabedcb6a3ff7001b4d9c43ad1fa7	American Express	40.0627317074645291	-75.1636679045289782
11406	2020-02-06 03:17:47	2020-02-06	Annika Nicolas	annika.nicolas@geemail.com	Lincoln	Nebraska	6011665924618244948	61dc4f071f08bfb3a594a1d078af18db	JCB 16 digit	40.8319720817282743	-96.7088833501257028
11407	2020-02-06 03:27:29	2020-02-06	Dwight Lueilwitz-Schultz	dwight.lueilwitz.schultz@geemail.com	Berkeley	California	4108727865025	1f0e2d0097ead3685959349df4886886	JCB 15 digit	37.8849750067030584	-122.281122286759242
11408	2020-02-06 03:36:52	2020-02-06	Elaine Wyman	elaine.wyman@geemail.com	Santa Rosa	California	3042639108533582	e24c1f9454c2593716c0cebd38940e36	VISA 16 digit	38.4285729013972031	-122.757017787896473
11409	2020-02-06 03:39:39	2020-02-06	Dr. Dameon Gleason II	dr.dameon.gleason.ii@woohoo.com	New York	New York	501841564017188	b0a2f57a72ad5c62bbf0e9ce4203de30	Voyager	40.7178020813725894	-73.9472956444498095
11410	2020-02-06 04:18:29	2020-02-06	Adolf Padberg	adolf.padberg@geemail.com	New York	New York	3480812902163220	8f34583b74f65615db5695b545ae3431	JCB 16 digit	40.6094552256390458	-73.8696065716806771
11411	2020-02-06 04:38:43	2020-02-06	Emaline Dietrich	emaline.dietrich@woohoo.com	Garden Grove	California	52791324641870420	6365b833abfb982eeab5cd2c9b412ef4	Maestro	33.7958193908270417	-117.939290688142179
11412	2020-02-06 04:54:44	2020-02-06	Preston Murray	preston.murray@geemail.com	Dallas	Texas	676391336107650	88cff959f8a7fdd6475b8ad47972ceb0	JCB 15 digit	32.7545413499038673	-96.7950350032616313
11413	2020-02-06 05:45:29	2020-02-06	Vida McClure	vida.mcclure@woohoo.com	San Jose	California	4115678458684011	5fc50c628b086533ace5809758bcef3b	Mastercard	37.2342150118954507	-121.910491832553973
11414	2020-02-06 05:51:09	2020-02-06	Clevie McLaughlin	clevie.mclaughlin@geemail.com	Fresno	California	210083475206663241	a52c69f628510d5eccda32948dd9e893	American Express	36.7394057772461338	-119.890833995967739
11415	2020-02-06 06:16:16	2020-02-06	Virgle Cremin-Kreiger	virgle.cremin.kreiger@warmmail.com	Concord	California	4671816398005667	33d4118a3926caf20d573bb396ef6dfd	Diners Club / Carte Blanche	38.0319523085307338	-122.014579020085179
11416	2020-02-06 06:20:24	2020-02-06	Darrel Witting	darrel.witting@geemail.com	Eugene	Oregon	4104082824993128	ba94cbaf8219f685cbe3eb346ece7e66	VISA 13 digit	44.0907399888344074	-123.214415908044955
11417	2020-02-06 06:31:11	2020-02-06	Alease VonRueden PhD	alease.vonrueden.phd@geemail.com	Visalia	California	3029841043701380	537822ca5abda0b6373a56e612540742	Maestro	36.3755977376319493	-119.383735876449947
11418	2020-02-06 06:32:09	2020-02-06	Aliza Jakubowski DDS	aliza.jakubowski.dds@geemail.com	Gresham	Oregon	3051732278789406	1d1d4980a3735c12d36cf44e867b40c4	JCB 15 digit	45.4890038020398464	-122.412263985051212
11419	2020-02-06 06:32:49	2020-02-06	Laraine Dicki	laraine.dicki@geemail.com	Charlotte	North Carolina	180029984017596091	1cbe96fd73d10195507533369ad5fddf	VISA 16 digit	35.2083213165190045	-80.7598582430221228
11420	2020-02-06 06:57:00	2020-02-06	Fanny O'Conner	fanny.o'conner@geemail.com	New York	New York	55043082069731302	225f98e9237c09520b0f67a8819d48fe	JCB 15 digit	40.6521591515969476	-73.9893256447173684
11421	2020-02-06 07:15:30	2020-02-06	Offie Luettgen	offie.luettgen@geemail.com	Memphis	Tennessee	869963647629990906	7c98601554fc26229bd4a055f6987aa2	American Express	35.1562186069853624	-89.9580313883513298
11422	2020-02-06 07:22:25	2020-02-06	Mr. Mervyn Spinka	mr.mervyn.spinka@geemail.com	Chicago	Illinois	3528759266254289275	8505899803fa462368bfe1d06ffba1ce	American Express	41.8274294521495733	-87.7006436964061038
11423	2020-02-06 07:23:34	2020-02-06	Kaylan Kihn	kaylan.kihn@geemail.com	Las Vegas	Nevada	3489134859328586	23fd89e0bd8fb11f5c115144521ebdfa	JCB 16 digit	36.2056850385021392	-115.192618375990904
11424	2020-02-06 07:26:06	2020-02-06	Chauncy Hammes	chauncy.hammes@geemail.com	Oakland	California	4108630065137247	fdcc6be7ef03771e523b17feca5ebd89	JCB 15 digit	37.8121632051905792	-122.257861715614681
11425	2020-02-06 07:29:22	2020-02-06	Hansel Fritsch	hansel.fritsch@woohoo.com	Indianapolis	Indiana	869910374190980711	d5c2aab027d9f95e2a40cfffcf8a6edb	Diners Club / Carte Blanche	39.8625213041908992	-86.1342711454924199
11426	2020-02-06 08:05:45	2020-02-06	Silvester VonRueden	silvester.vonrueden@geemail.com	Charlotte	North Carolina	3054064514904665	2f81ae340d4385f9607a793af91054ba	Voyager	35.1906691144939501	-80.8896596047040077
11427	2020-02-06 08:19:33	2020-02-06	Maudie Schmeler-Graham	maudie.schmeler.graham@warmmail.com	Indianapolis	Indiana	676108354974704	b20290a16813ff5e5a0ab2fe292da5ef	VISA 13 digit	39.7456106145873633	-86.0846313618324643
11428	2020-02-06 08:21:25	2020-02-06	Rosanna Stokes	rosanna.stokes@geemail.com	Atlanta	Georgia	52081842939985187	5fbe0a123dc5e0194ca16f13a20054cd	Maestro	33.6647343530595293	-84.4106240727052182
11429	2020-02-06 08:26:57	2020-02-06	Mr. Guss Crist I	mr.guss.crist.i@geemail.com	Richmond	California	4477679995359242	a60de491f9a175be26deca4354939524	American Express	37.9228721929669419	-122.296821534525975
11430	2020-02-06 09:36:31	2020-02-06	Adah Oberbrunner	adah.oberbrunner@geemail.com	Los Angeles	California	676319180372807	79c4e2800238537a091cc11a08257720	VISA 16 digit	34.0705522434651797	-118.32287756241783
11431	2020-02-06 09:52:02	2020-02-06	Assunta Smith-Roberts	assunta.smith.roberts@woohoo.com	Pasadena	Texas	4305575216737	1e43f92c447784793ce2c2ac32c0724f	VISA 16 digit	29.726490420090407	-95.0616229984857171
11432	2020-02-06 10:10:00	2020-02-06	Bethel Bogan	bethel.bogan@geemail.com	Oakland	California	6011068459413079614	7e2449bb231845d6bd4e6ee603bbed83	JCB 15 digit	37.7987485498575424	-122.302183239334724
11433	2020-02-06 10:21:08	2020-02-06	Dr. Levar Morissette	dr.levar.morissette@woohoo.com	Aurora	Colorado	3088319824842664772	625be684e4288ace80d66f7b64713181	Maestro	39.6970418088715533	-104.781657960883152
11434	2020-02-06 10:39:12	2020-02-06	Kwame Mante DVM	kwame.mante.dvm@geemail.com	Tempe	Arizona	4146643966605273	3019fbf8fc57c2c5c5f8472c5b43cc1d	Voyager	33.3597411067612413	-111.850180527198305
11435	2020-02-06 10:43:05	2020-02-06	Tena Monahan	tena.monahan@geemail.com	Berkeley	California	3337862001684685287	6315a22b6abf35c8e8ff4c14fc75783d	Diners Club / Carte Blanche	37.8946676464711558	-122.270519137180202
11436	2020-02-06 10:49:51	2020-02-06	Tula Kulas	tula.kulas@warmmail.com	Fayetteville	North Carolina	502028107214109	a373330b0c69bbeab7f9e02d2f08ed0c	JCB 16 digit	35.0276487840592878	-78.927123510850592
11437	2020-02-06 11:27:58	2020-02-06	Bethel Wehner	bethel.wehner@geemail.com	Philadelphia	Pennsylvania	4620383933246274	c678b9064678a9278c96b88e167a1c3b	JCB 16 digit	39.9940837832592422	-75.1882800896085826
11438	2020-02-06 11:34:06	2020-02-06	Lionel Altenwerth	lionel.altenwerth@warmmail.com	Houston	Texas	3112088881329078016	9870c2a9b9198c4c80ea88e16eaee4e3	Diners Club / Carte Blanche	29.7991426830723896	-95.4703038416352143
11439	2020-02-06 12:31:02	2020-02-06	Elvis Littel	elvis.littel@geemail.com	Berkeley	California	6011449409447785371	47669dc5089cd31e8bb990691d9be243	VISA 13 digit	37.8728850152846235	-122.283750492901746
11440	2020-02-06 12:33:23	2020-02-06	Dorris Kiehn	dorris.kiehn@geemail.com	Peoria	Illinois	3158040473251036928	30f5fe099f213d1b40e1e1255c3f5852	JCB 16 digit	40.7552807032000288	-89.6550886892598129
11441	2020-02-06 12:47:17	2020-02-06	Sylva McKenzie DVM	sylva.mckenzie.dvm@geemail.com	Lincoln	Nebraska	3012397036544367	b71353fc14e1fac95f31dcbdbfb481fb	JCB 15 digit	40.7844852312486594	-96.6425406677808638
11442	2020-02-06 13:08:11	2020-02-06	Wash Yundt	wash.yundt@geemail.com	New Orleans	Louisiana	210018524168398260	abb0f8c471017c3b4b3c997098de21d6	JCB 16 digit	30.0642343600761137	-89.8536276125609845
11443	2020-02-06 13:11:19	2020-02-06	Jude Abshire	jude.abshire@geemail.com	New York	New York	639054404096908	dafca76b2ba16e0c55f0e7edb287318f	JCB 16 digit	40.6947646726146317	-73.9372070470720502
11444	2020-02-06 13:19:57	2020-02-06	Mrs. Hermina Schinner	mrs.hermina.schinner@geemail.com	San Francisco	California	4246793451342335	a58a9eb18a640d5899e92e290a50a6c4	JCB 15 digit	37.7786058468811135	-122.423039641724841
11445	2020-02-06 13:21:20	2020-02-06	Emaline Rowe-Runolfsson	emaline.rowe.runolfsson@geemail.com	Peoria	Illinois	3337377789043748089	726e3aea862574093703d1e45da52fc8	VISA 13 digit	40.7700585675761076	-89.7073202470202062
11446	2020-02-06 13:33:16	2020-02-06	Signa Schaden DDS	signa.schaden.dds@geemail.com	San Francisco	California	55436011889943115	3d295f107abaaddbb7cdfeb8af582b07	VISA 13 digit	37.7742810292348778	-122.43085720652256
11447	2020-02-06 13:35:09	2020-02-06	Dr. Winnifred Conn DVM	dr.winnifred.conn.dvm@woohoo.com	Eugene	Oregon	3012602763238970	6b0d20e3078b3010f081fd847960e5a0	JCB 16 digit	44.0262486458018429	-123.119043110356486
11448	2020-02-06 14:16:46	2020-02-06	Analia Oberbrunner	analia.oberbrunner@woohoo.com	North Las Vegas	Nevada	3158360912779000694	d69417c547240a21764cf732dd94a80e	JCB 16 digit	36.3478483940631136	-115.001941307004174
11449	2020-02-06 14:26:23	2020-02-06	Miss Frieda Maggio	miss.frieda.maggio@warmmail.com	Oakland	California	52437728335038435	1e3611b30addcf5e929a6f03996c9af0	VISA 16 digit	37.8170375389763436	-122.27188499726428
11450	2020-02-06 14:30:22	2020-02-06	Tarah Prosacco	tarah.prosacco@warmmail.com	Syracuse	New York	501890396968647	05d3d934e2b867c15773da07d629386b	Maestro	43.0976478596068873	-76.1064858272917633
11451	2020-02-06 14:57:54	2020-02-06	Leah Turner MD	leah.turner.md@geemail.com	Detroit	Michigan	180051364862504816	36a0192a3c0c3da44355177adc86df8c	American Express	42.4444299591630738	-83.1235784409221168
11452	2020-02-06 16:05:37	2020-02-06	Santino Bayer	santino.bayer@geemail.com	San Francisco	California	4257668677883476	9e757983034aa729aa62e75c7014d1af	Discover	37.7808222637127713	-122.395506212957841
11453	2020-02-06 16:09:43	2020-02-06	Birtie Boyer	birtie.boyer@geemail.com	San Diego	California	3764535175213170	31759f3a5ddcc0303b50bee2b997788b	Maestro	32.8598174032822286	-117.102105520283814
11454	2020-02-06 16:12:42	2020-02-06	Mr. Porter Kunde IV	mr.porter.kunde.iv@geemail.com	San Francisco	California	3057755404038558	0f05ff63c62781291e00b0e0096c4b5a	JCB 15 digit	37.7603547280726559	-122.4605932821556
11455	2020-02-06 16:23:57	2020-02-06	Tyron Ratke	tyron.ratke@geemail.com	Henderson	Nevada	869901870684788750	87357837b8659658f9a7bcceacfab8ac	Mastercard	36.0640647203594469	-115.128791448303318
11456	2020-02-06 16:33:25	2020-02-06	Verner Jacobson	verner.jacobson@warmmail.com	San Francisco	California	54415787685404502	a181a8e0fb2358b68349b34971fe4c5a	Diners Club / Carte Blanche	37.7332012100363414	-122.445597558505185
11457	2020-02-06 16:33:25	2020-02-06	Dr. Selena Stroman	dr.selena.stroman@geemail.com	Huntington Beach	California	3499208326019123	a99938849c25fc289f968b438b143002	Maestro	33.6971306951291893	-117.932574968704202
11458	2020-02-06 16:51:19	2020-02-06	Bud Ferry	bud.ferry@geemail.com	Berkeley	California	3044313513336829	de90675484767dc1aed3e0c7d7bad3f4	JCB 16 digit	37.8544053007858778	-122.242438776513296
11459	2020-02-06 17:36:02	2020-02-06	Dr. Merry Konopelski PhD	dr.merry.konopelski.phd@geemail.com	San Francisco	California	4670792669010036	14811f552a6e1d159dae4028486f980f	VISA 16 digit	37.7720514413366999	-122.479674004442572
11460	2020-02-06 18:05:02	2020-02-06	Helen Greenholt-Davis	helen.greenholt.davis@woohoo.com	San Francisco	California	3096004802583634261	b4ec0f8ece9a5d16eedec5226ff9eab5	VISA 16 digit	37.753786122470018	-122.42363142393306
11461	2020-02-06 19:27:53	2020-02-06	Oralia Hagenes	oralia.hagenes@geemail.com	Norman	Oklahoma	3046743794343607	a80767273098779bb1d37aca81c497c4	JCB 15 digit	35.1582782398484639	-97.3179427167188322
11462	2020-02-06 19:30:17	2020-02-06	Mr. Jamarcus Pouros Jr.	mr.jamarcus.pouros.jr.@woohoo.com	San Francisco	California	210089991964290377	686da0751316625c48ccb0f33c07c9d9	Voyager	37.7833147467613202	-122.429241718335817
11463	2020-02-06 19:37:01	2020-02-06	Delilah Stiedemann	delilah.stiedemann@geemail.com	Columbus	Ohio	180079525732485018	ab2f4e83f9451bdb8030ad0616e4ab79	JCB 15 digit	40.0255007825836557	-82.8880045822590716
11464	2020-02-06 19:40:45	2020-02-06	Alcie Champlin	alcie.champlin@geemail.com	San Jose	California	4304032729542858	81bf51cfe56874d88e700e609a59d68d	Mastercard	37.3790609985876827	-121.885696759841963
11465	2020-02-06 19:58:18	2020-02-06	Gene Wehner	gene.wehner@warmmail.com	San Francisco	California	3337584916989865440	db733878a6de15ae2987408f59a97d4e	VISA 13 digit	37.7684763654491178	-122.409543300645694
11466	2020-02-06 20:07:52	2020-02-06	Arlie Stracke-Hahn	arlie.stracke.hahn@warmmail.com	Colorado Springs	Colorado	6011556894848591727	b2e8fa74c3acefdfadf63b7a30425bc9	JCB 16 digit	38.78714991142526	-104.777619196303931
11467	2020-02-06 20:25:33	2020-02-06	Mr. Rome Schuster	mr.rome.schuster@geemail.com	Jacksonville	Florida	6011709528959917281	96210fb8e0df74bff2a8e23e69bcaf11	JCB 16 digit	30.3892813907057047	-81.677336505202959
11468	2020-02-06 20:32:14	2020-02-06	Jemima Beier	jemima.beier@geemail.com	Los Angeles	California	4506951362231	69c50bbe5049bb2cd4981a57ff961c2a	JCB 15 digit	34.0032153832126411	-118.372201985120029
11469	2020-02-06 21:07:04	2020-02-06	Oliver Sauer DDS	oliver.sauer.dds@geemail.com	Detroit	Michigan	6011919115455804308	b16e7c92c2213b4d5019d82281d9d2da	VISA 16 digit	42.4587459892891346	-83.1348982823200515
11470	2020-02-06 21:07:33	2020-02-06	Cora Keebler MD	cora.keebler.md@geemail.com	Oakland	California	51357739008327183	97bcd91cd3da42f6cb102dbc9af0e0d1	Diners Club / Carte Blanche	37.8051379970373134	-122.239157282221285
11471	2020-02-06 21:10:10	2020-02-06	Dr. Aurelio Feest II	dr.aurelio.feest.ii@woohoo.com	Seattle	Washington	3425022797704991	8386a7730c9ef9d29ba208d1bad199ed	Mastercard	47.5391211702413869	-122.408588350370152
11472	2020-02-06 21:34:36	2020-02-06	Eli Jast	eli.jast@geemail.com	New York	New York	3096460236348142921	1dcaf8a618112e248baa6a77a15e56f2	VISA 13 digit	40.661256974725049	-73.9003894857026609
11473	2020-02-06 21:34:54	2020-02-06	Hermann McClure	hermann.mcclure@warmmail.com	New York	New York	6011002340666073919	08d8333a8b53aa28b16f1fe63e978fb2	VISA 13 digit	40.5978796523753545	-74.0023443869210809
11474	2020-02-06 21:39:05	2020-02-06	Alena Borer	alena.borer@geemail.com	Oxnard	California	869991530825453745	16beb3a614649daf8fe6e1b7875de79f	VISA 16 digit	34.1217433072581926	-119.139356672754886
11475	2020-02-06 21:55:29	2020-02-06	Charity Littel	charity.littel@geemail.com	San Jose	California	210013989498410140	1437106cd5f72082d4b39639586acb43	Mastercard	37.1970831149078904	-121.901124864372989
11476	2020-02-06 22:37:17	2020-02-06	Dr. Tex Muller I	dr.tex.muller.i@woohoo.com	Oakland	California	503898306267026	e1cb8bbc9f1a5593caac3ac01cda7e81	Discover	37.7920915981914334	-122.289232378583577
11477	2020-02-06 22:41:30	2020-02-06	Mr. Ewald Marquardt	mr.ewald.marquardt@geemail.com	Minneapolis	Minnesota	4584257983056078	a635bc69e35d81c0861697430b9876a0	American Express	44.9541526034094332	-93.3594118814256007
11478	2020-02-06 23:01:24	2020-02-06	Lorrie Runolfsdottir	lorrie.runolfsdottir@geemail.com	Boston	Massachusetts	4858027811857933	3122456c86d768287f08247f3291ad96	VISA 16 digit	42.430935604514552	-71.0562556805506347
11479	2020-02-06 23:03:42	2020-02-06	Gennie Kub-Kuphal	gennie.kub.kuphal@geemail.com	New York	New York	4089779796513482	55438c520b7a127ab84cf0d7d3b0630e	VISA 16 digit	40.7167523531466742	-74.0040509522322481
11480	2020-02-06 23:25:52	2020-02-06	Elizah Pagac	elizah.pagac@geemail.com	San Antonio	Texas	561292272089944	f47d4e2cafbe317f45c9621ca6d213cc	Voyager	29.5094776880066831	-98.512448075909532
11481	2020-02-06 23:38:26	2020-02-06	Geary Marquardt	geary.marquardt@geemail.com	Chicago	Illinois	869963229852760759	5fe07c2254f3da90ace0205b83279329	Diners Club / Carte Blanche	41.7805796930402522	-87.7323830741953117
11482	2020-02-07 00:03:51	2020-02-07	Arlena Pacocha	arlena.pacocha@woohoo.com	Oceanside	California	6011191835619775974	02a7704f6e6f5c566e6b3d8027ab7863	Discover	33.2331115787271401	-117.245055208316828
11483	2020-02-07 00:11:14	2020-02-07	Lawrance Gleichner-Boehm	lawrance.gleichner.boehm@warmmail.com	Philadelphia	Pennsylvania	4695809960582603	5d00676089e4f73c4fbbe1c08c03360d	JCB 15 digit	40.0250686631962651	-75.094294834033775
11484	2020-02-07 00:27:39	2020-02-07	Ivah Nader-Abbott	ivah.nader.abbott@geemail.com	Arlington	Texas	4049162088980	c4381d0c66a152e9543d7f7510e7a437	JCB 16 digit	32.7426806010089777	-97.138550821228705
11485	2020-02-07 00:51:02	2020-02-07	Miss Cassidy Satterfield	miss.cassidy.satterfield@geemail.com	Torrance	California	630476394699193	99e0d3fed79551336e2df013de2ad571	Mastercard	33.8749758930783713	-118.404725061090289
11486	2020-02-07 01:07:58	2020-02-07	Marc Rutherford	marc.rutherford@woohoo.com	San Bernardino	California	3711362782480900	44a28c0135e431386ba13d9a80556279	JCB 16 digit	34.1386186615362703	-117.332823955431948
11487	2020-02-07 01:09:37	2020-02-07	Dr. Harlan Renner II	dr.harlan.renner.ii@geemail.com	Broken Arrow	Oklahoma	3158999451727375980	ced0964a6ac04e429192d3fc21ac29b5	JCB 16 digit	36.0675015021357623	-95.7703518730532437
11488	2020-02-07 01:14:04	2020-02-07	Kyle Wintheiser	kyle.wintheiser@geemail.com	Yonkers	New York	3096358926891139077	7b95578bd95a1a417437e829138e9d33	JCB 16 digit	41.0108810675531643	-73.8945877709776227
11489	2020-02-07 01:39:03	2020-02-07	Kenzie Windler	kenzie.windler@warmmail.com	Chula Vista	California	676135922147646	5a73bf3f07c4988bc424522e8f17dda1	JCB 16 digit	32.6897699450839312	-117.040697337803238
11490	2020-02-07 01:47:24	2020-02-07	Amir Boehm	amir.boehm@woohoo.com	Fresno	California	3008320382110710	c5cd7d966a8dcc924537aead83a2adce	VISA 16 digit	36.8539036770690203	-119.738324868736427
11491	2020-02-07 02:19:50	2020-02-07	Wilfred Zemlak-Rau	wilfred.zemlak.rau@geemail.com	San Francisco	California	3158770499555887423	6a31271a02bd985ade40204a21e34c6e	JCB 16 digit	37.7909942387115407	-122.451367270976561
11492	2020-02-07 02:31:26	2020-02-07	Sonny Torphy	sonny.torphy@geemail.com	San Francisco	California	4077845373131	02e48706cf15e7975f78dacb2bbc5c67	VISA 16 digit	37.7517264703695616	-122.420986202999018
11493	2020-02-07 02:32:52	2020-02-07	Blanche Feeney	blanche.feeney@geemail.com	San Francisco	California	3717192133959177	44452c088a4c1e3cb24b9c37c8191812	VISA 13 digit	37.7698160552569249	-122.44834830263548
11494	2020-02-07 03:06:34	2020-02-07	Dr. Trena Brekke	dr.trena.brekke@warmmail.com	San Francisco	California	210069180252241391	feb2d438f2610ab571e1fee20d872150	Mastercard	37.8063163481750593	-122.399676877764307
11495	2020-02-07 03:23:55	2020-02-07	Alfred Parker	alfred.parker@geemail.com	San Francisco	California	4547839250354	bd00c09ebc1fa7b35689e98632c12e4e	Maestro	37.7468709049723046	-122.437777424458432
11496	2020-02-07 03:29:05	2020-02-07	Jessee Dooley-Bogisich	jessee.dooley.bogisich@woohoo.com	Indianapolis	Indiana	6011184530797968637	a4e10108519b6e767f880c9b7ca37944	American Express	39.7730614840526115	-86.0911881400939052
11497	2020-02-07 03:33:17	2020-02-07	Corliss Leffler	corliss.leffler@geemail.com	Chicago	Illinois	4437788652812945	4915f43fb512c0af10c769bfdbfed263	Discover	41.8529494277037699	-87.6553437199007703
11498	2020-02-07 03:50:09	2020-02-07	Edie Blick	edie.blick@geemail.com	Kent	Washington	180008592361414715	131634577612326a838852b6bddff1c6	Maestro	47.4264115222375793	-122.250792235149817
11499	2020-02-07 04:11:45	2020-02-07	Kole Aufderhar PhD	kole.aufderhar.phd@warmmail.com	San Francisco	California	210068567737209509	cfec13d786d7fdbf96e0e30cb161a418	VISA 13 digit	37.7635506737236781	-122.408209607601478
11500	2020-02-07 05:20:15	2020-02-07	Kasen Muller	kasen.muller@woohoo.com	San Francisco	California	4854383716858888	41cef304a659343d2bdf2afeb27a84a1	Maestro	37.8082140056011227	-122.393792760766601
11501	2020-02-07 05:24:29	2020-02-07	Drake Gislason	drake.gislason@geemail.com	San Jose	California	53925838687195185	7de12230cf211293e709588a056ae405	Voyager	37.244533068436013	-121.835713318291681
11502	2020-02-07 05:31:06	2020-02-07	Joshuah Stokes I	joshuah.stokes.i@geemail.com	Denver	Colorado	3337003121311437983	96f9381c2d48aa59cc245191a047361a	JCB 15 digit	39.6807248272519502	-104.806781317457933
11503	2020-02-07 05:53:34	2020-02-07	Vance Kemmer	vance.kemmer@warmmail.com	Beaumont	Texas	869912691439013089	6cb32c1e32c7d4189331ce14709f1366	VISA 16 digit	29.9854132802296434	-94.2450175894677642
11504	2020-02-07 05:55:17	2020-02-07	Lexi Strosin	lexi.strosin@geemail.com	San Francisco	California	869978556589584133	4526c806aa1a98615dad3bf3dc34acc8	JCB 16 digit	37.7497181362341223	-122.44440130859391
11505	2020-02-07 06:00:39	2020-02-07	Mr. Isaak Howe	mr.isaak.howe@woohoo.com	Corpus Christi	Texas	180062446404631806	bdbdae935bcbabcce48fe606c8a47063	Maestro	27.7784656845901168	-97.2659905411131689
11506	2020-02-07 06:02:18	2020-02-07	Gonzalo Wolf	gonzalo.wolf@geemail.com	Phoenix	Arizona	676119209444835	5331225f401f884013468643c5a784d3	Voyager	33.6154054492179313	-112.061517956426741
11507	2020-02-07 06:04:33	2020-02-07	Danyel Champlin	danyel.champlin@woohoo.com	Toledo	Ohio	3337522452263188676	b97bd7f99693a2c3ee83e4496bada662	VISA 16 digit	41.7314289137426755	-83.5265600964758619
11508	2020-02-07 06:22:17	2020-02-07	Marilla Casper-White	marilla.casper.white@geemail.com	Phoenix	Arizona	180071907305663213	80ec843bb46eb016e793b18e705a0545	JCB 16 digit	33.5334101041711889	-112.15377545928807
11509	2020-02-07 07:41:46	2020-02-07	Mrs. Signa Hettinger PhD	mrs.signa.hettinger.phd@warmmail.com	San Francisco	California	3158888124092082804	b97268edf6abcf64909d7fbd2fda96ab	VISA 13 digit	37.7919352943447464	-122.431228955208141
11510	2020-02-07 07:57:25	2020-02-07	Clarabelle Schaefer	clarabelle.schaefer@geemail.com	Pittsburgh	Pennsylvania	4427454151513474	f9ddfc46a202c979b4330a300cb28bf3	VISA 16 digit	40.3514975362412613	-80.0437614497900114
11511	2020-02-07 08:27:50	2020-02-07	Howard Smitham	howard.smitham@geemail.com	Berkeley	California	3050175904064664	d3e2cdbf9b211ca90ad3b7e5fa206188	Voyager	37.8852501257689269	-122.270632536197098
11512	2020-02-07 08:44:08	2020-02-07	Harris Larson V	harris.larson.v@geemail.com	Santa Ana	California	869905129422141863	fa2dd1010208d8d9015043715a872bdd	Maestro	33.7000714325450375	-117.931965971730648
11513	2020-02-07 09:21:23	2020-02-07	Mr. Gustaf Wehner	mr.gustaf.wehner@warmmail.com	Los Angeles	California	54845472773345947	35c86917f81d139ac19ad2aa9768aa9c	VISA 16 digit	34.0435744845639903	-118.451665270607165
11514	2020-02-07 09:26:06	2020-02-07	Shannan Pacocha PhD	shannan.pacocha.phd@geemail.com	Memphis	Tennessee	3793468278684615	e393b83b4b2224b2aa7c900fa54bb755	Mastercard	35.0734448885146577	-89.9961520703300835
11515	2020-02-07 09:41:53	2020-02-07	Buffy Denesik	buffy.denesik@geemail.com	Hillsboro	Oregon	3717372391944745	7a6c2b3e023bdc80367528f1eab6ef89	JCB 16 digit	45.4549738584291205	-122.906570114397255
11516	2020-02-07 09:54:06	2020-02-07	Hillary Schoen	hillary.schoen@geemail.com	San Francisco	California	6011847391037986775	7b94cb1fb1c7290b1c824dddd9e1210e	Maestro	37.7852114247117044	-122.432076792682381
11517	2020-02-07 09:57:00	2020-02-07	Caylee Langosh	caylee.langosh@warmmail.com	Baltimore	Maryland	4516675188793380	2ad3d1f8272c4ae133af96fe7ac067f9	JCB 16 digit	39.2806943754665525	-76.5273102316092775
11518	2020-02-07 09:58:25	2020-02-07	Arther Champlin Jr.	arther.champlin.jr.@geemail.com	San Francisco	California	3721412285643161	82388a51a5728e844e724ba6888e8fd9	VISA 13 digit	37.7923486168252438	-122.456407926465232
11519	2020-02-07 09:59:03	2020-02-07	Marcia Cartwright	marcia.cartwright@geemail.com	San Francisco	California	869994635847921574	82b416141052e63ed0196692bc425ddf	Diners Club / Carte Blanche	37.7620704674713963	-122.376152284072717
11520	2020-02-07 10:20:31	2020-02-07	Lovisa Mante DVM	lovisa.mante.dvm@warmmail.com	Portland	Oregon	4041225559087543	eb8c36a518a56f66e32425c342e87ada	JCB 16 digit	45.4446724123209691	-122.572866676328715
11521	2020-02-07 10:28:56	2020-02-07	Sing Jerde	sing.jerde@geemail.com	San Francisco	California	3058733644069047	dfc981934f200e31cb4af3e39b7de2eb	Diners Club / Carte Blanche	37.787140606819861	-122.45340676943475
11522	2020-02-07 10:50:54	2020-02-07	Mr. Wally Schultz I	mr.wally.schultz.i@geemail.com	San Francisco	California	6011482188989685425	28b02abdf03a61b010ead92f73fc1af4	JCB 16 digit	37.7840463479467488	-122.459933187605003
11523	2020-02-07 10:55:29	2020-02-07	Jenna Wunsch	jenna.wunsch@geemail.com	Irvine	California	51448189243738730	94b2e1afd4400f7c80c9901059b6a962	Voyager	33.6765794835999657	-117.763521010243522
11524	2020-02-07 11:07:10	2020-02-07	Ms. Dovie Corwin DVM	ms.dovie.corwin.dvm@geemail.com	New York	New York	210069231663366226	aae5bf8ca3750b4cdce690c6f9c8083a	JCB 16 digit	40.5781974034607416	-73.8920898738212912
11525	2020-02-07 11:11:28	2020-02-07	Mr. Gurney Wolff	mr.gurney.wolff@geemail.com	Mesquite	Texas	3003286838781641	ac6533d01c1a6b6e4c42432b1fae9c4a	Maestro	32.8365407354939762	-96.582713848139349
11526	2020-02-07 11:15:37	2020-02-07	Madilynn Zieme	madilynn.zieme@geemail.com	Philadelphia	Pennsylvania	3034942999399701	c9a5a4d638730e7fb26164e3b339952c	JCB 15 digit	40.084797073663772	-75.1225971480265287
11527	2020-02-07 12:07:38	2020-02-07	Burnell Kuhn	burnell.kuhn@geemail.com	New York	New York	52138853120601445	5b92913adc071fd51871a4c4083c6ba2	VISA 13 digit	40.7401661880072226	-73.9510502479400458
11528	2020-02-07 12:12:42	2020-02-07	Tommie Murray	tommie.murray@geemail.com	Houston	Texas	6011385561024051001	2711d875476f0ace2e484e5f9e50b566	VISA 16 digit	29.8651825813189156	-95.3678999732729125
11529	2020-02-07 12:27:40	2020-02-07	Landin Howell	landin.howell@geemail.com	Abilene	Texas	3158825118899736535	cfb5fd14c642135ab428fa730357d1fc	VISA 16 digit	32.4645148242898287	-99.7043103260401722
11530	2020-02-07 12:48:21	2020-02-07	Jayson Stehr	jayson.stehr@geemail.com	New York	New York	53692423641979775	50d8342bdba84385ec13d4bd38a85e59	VISA 16 digit	40.7475638509485876	-73.8965349728137255
11531	2020-02-07 13:07:52	2020-02-07	Kennedy Armstrong	kennedy.armstrong@warmmail.com	San Francisco	California	4362552444134540	8a56e05442b5c2c6d6e76fbc625b3e2b	Diners Club / Carte Blanche	37.8004877735051892	-122.458181384707487
11532	2020-02-07 13:27:49	2020-02-07	Kunta Volkman	kunta.volkman@geemail.com	San Francisco	California	4593529201190	7d6c3c85b29ab665e638f4719080feec	VISA 13 digit	37.7582118382133913	-122.412252823858225
11533	2020-02-07 13:37:49	2020-02-07	Loraine Grant	loraine.grant@geemail.com	Kenosha	Wisconsin	3400142265744318	ee2f29d27f424b653ccc07321c2a1b56	VISA 16 digit	42.6722581751484427	-87.8367415321752532
11534	2020-02-07 13:39:50	2020-02-07	Cory Satterfield PhD	cory.satterfield.phd@geemail.com	San Francisco	California	3158713024839077508	d51590c46e81c7d13355424389c1c19f	Maestro	37.7878454539127873	-122.423322371420483
11535	2020-02-07 14:06:11	2020-02-07	Dr. Addison Gulgowski DVM	dr.addison.gulgowski.dvm@warmmail.com	Toledo	Ohio	060464181251881	6cf1bc9ddad0bff00d43e86f4fa56395	Diners Club / Carte Blanche	41.7555867105893768	-83.537172850627087
11536	2020-02-07 14:17:59	2020-02-07	Amani Rice	amani.rice@geemail.com	Raleigh	North Carolina	4661080752543514	4e39a80f69faf69733942906d220e729	VISA 16 digit	35.7359528677206484	-78.6980765081878815
11537	2020-02-07 14:22:13	2020-02-07	Kasandra Kunze	kasandra.kunze@geemail.com	Fullerton	California	3158821131837133529	489945f7c3a9e53b517f0accc7cc39f3	JCB 15 digit	33.9000472555093495	-117.837958904376251
11538	2020-02-07 14:29:41	2020-02-07	Nicole Ferry-Runolfsdottir	nicole.ferry.runolfsdottir@geemail.com	Kansas City	Missouri	3158299877325057884	e0e38366e5d5d2b50c65f8c4ce96a868	JCB 16 digit	39.1160848360344815	-94.5378470592424236
11539	2020-02-07 14:38:30	2020-02-07	Markita Beahan	markita.beahan@geemail.com	San Francisco	California	4355639238170514	bc7eaed7b87c960e301668852c96340f	Mastercard	37.7644843792895344	-122.425248161241853
11540	2020-02-07 14:44:57	2020-02-07	Erik Tillman	erik.tillman@geemail.com	Lincoln	Nebraska	4482368614189668	e6134ee3c7a8eda037b20c66171cc78a	Voyager	40.8272453589849178	-96.7318675360802587
11541	2020-02-07 15:10:39	2020-02-07	Ashly Kris	ashly.kris@woohoo.com	Garland	Texas	4392114172845	4d12dd13b11f8b5ec1bea2be5ef7a7a3	JCB 16 digit	32.8715760682944165	-96.5806043004777308
11542	2020-02-07 15:42:48	2020-02-07	Alvan Mayer	alvan.mayer@geemail.com	Los Angeles	California	3010551042671315	4d6930c54712c03fa947f88ecd4221ea	JCB 15 digit	34.1089649683661733	-118.509210406708718
11543	2020-02-07 15:50:04	2020-02-07	Mavis Rodriguez	mavis.rodriguez@woohoo.com	Los Angeles	California	4566161848552044	a87f37c30ab18e0fc53de3d80c0e6f34	Maestro	34.0330666502337849	-118.425494297593076
11544	2020-02-07 16:23:41	2020-02-07	Osa Rosenbaum	osa.rosenbaum@geemail.com	Oakland	California	3451115099772695	66a7d3a78040f2a13cbbda2e9e24b85d	VISA 13 digit	37.7933408184850705	-122.258946433923697
11545	2020-02-07 16:30:50	2020-02-07	Sharif Huel	sharif.huel@geemail.com	Winston–Salem	North Carolina	4032793336629359	f08e53247abebe0712795bb848950b78	JCB 16 digit	36.1374706407774227	-80.336437365379183
11546	2020-02-07 16:31:14	2020-02-07	Earnestine Schaefer	earnestine.schaefer@woohoo.com	Baltimore	Maryland	3528626081612105704	6d0e0f34d2d3ca0e9ebbd5c022aba623	Maestro	39.2459535486996174	-76.665893978534271
11547	2020-02-07 16:34:23	2020-02-07	Mr. Estill Treutel V	mr.estill.treutel.v@warmmail.com	Los Angeles	California	4477035485570022	e4036f3be0dc7b4813ba7b743a488643	VISA 13 digit	34.061618462284649	-118.479665190725768
11548	2020-02-07 16:54:42	2020-02-07	Rashad Durgan	rashad.durgan@geemail.com	Jersey City	New Jersey	210023062758313574	ee3d6d3814a1334c786c375f951e985d	Discover	40.6729341487806266	-74.1354338662654158
11549	2020-02-07 16:56:36	2020-02-07	Silas Stracke DVM	silas.stracke.dvm@geemail.com	Manchester	New Hampshire	3039840514675743	e3ce02eeacfc2994ff3b8affeff67223	JCB 16 digit	42.8932252057433132	-71.4022913692876813
11550	2020-02-07 17:04:54	2020-02-07	Rosaline Dickinson	rosaline.dickinson@geemail.com	Boston	Massachusetts	589302923577072	ffb5d9989f102bea5bffefdcbaf4170e	Maestro	42.3516942709851989	-71.0754994151599675
11551	2020-02-07 17:07:27	2020-02-07	Kane Little	kane.little@geemail.com	Winston–Salem	North Carolina	3478405780517874	2f9a42a8a8a771ba6ad0dcbce1fcf891	Mastercard	36.0385511042315514	-80.1976658866871048
11552	2020-02-07 17:09:36	2020-02-07	Jazmin Brekke-Stokes	jazmin.brekke.stokes@geemail.com	Tacoma	Washington	3017936466124946	6535164775232c4d59bb2905fc7b3c7f	Voyager	47.3083875269748262	-122.548039194825293
11553	2020-02-07 17:17:08	2020-02-07	Mrs. Adalyn Bruen	mrs.adalyn.bruen@woohoo.com	Oakland	California	53669859548064428	854bd09e5a7a9275fb08935624451f7c	VISA 13 digit	37.7830542180518023	-122.260553045109063
11554	2020-02-07 17:17:29	2020-02-07	Jemima Stroman	jemima.stroman@woohoo.com	Oakland	California	3112184609716326836	d307ba9a39a6e51c30dc141dd6177d43	VISA 16 digit	37.821625415514923	-122.264612481965969
11555	2020-02-07 17:20:13	2020-02-07	Emaline Beier	emaline.beier@geemail.com	Orlando	Florida	4697710190268096	055ac1e25af5f7c584c9509f5273c85d	JCB 16 digit	28.3864821353726065	-81.2381022452808992
11556	2020-02-07 17:21:56	2020-02-07	Stacia Nicolas	stacia.nicolas@geemail.com	Tacoma	Washington	3440825503878607	203c9b7b9184197fee6b6a37c92f4ccb	Maestro	47.2054127093989422	-122.41597505749688
11557	2020-02-07 17:29:19	2020-02-07	Violetta Osinski	violetta.osinski@geemail.com	Sioux Falls	South Dakota	4834416015340052	60293f6f1c7f3dcf5dae36789570f9f8	JCB 16 digit	43.5071331213314068	-96.697419857949015
11558	2020-02-07 17:33:34	2020-02-07	Kobe Roberts	kobe.roberts@woohoo.com	New Orleans	Louisiana	869916594693635330	5706528d350a3acf7d592a099cb0f96d	Mastercard	30.0811504578232771	-89.9844107822310235
11559	2020-02-07 18:16:20	2020-02-07	Andreas Kuphal	andreas.kuphal@geemail.com	Washington	District of Columbia	4924270379103494	3ff767d6b7f28f510c97126119f9ecf7	Mastercard	38.8142397147402178	-76.9637239808429001
11560	2020-02-07 18:33:44	2020-02-07	Vilma O'Keefe	vilma.o'keefe@geemail.com	Virginia Beach	Virginia	55840041524459599	e90cdb36103c9bd476f91707b69229aa	JCB 15 digit	36.7457834819518041	-76.0144784850206179
11561	2020-02-07 18:37:00	2020-02-07	Miss Irva Frami	miss.irva.frami@woohoo.com	New York	New York	6011560887948136918	9d91eb95ec742ba270f862460cc9524a	JCB 16 digit	40.6452375136539317	-73.8860314970731764
11562	2020-02-07 18:37:10	2020-02-07	Courtland Prohaska	courtland.prohaska@geemail.com	Aurora	Colorado	3028911254479306	237a609f8ede66affbc776af6ca14daf	JCB 15 digit	39.6480119715090851	-104.708527601801606
11563	2020-02-07 18:48:56	2020-02-07	Hezzie Daugherty	hezzie.daugherty@geemail.com	West Valley City	Utah	6011507556850427500	85c53502f6a3a66182b3e1098c14f650	American Express	40.6821058398336177	-111.92067370756827
11564	2020-02-07 19:04:50	2020-02-07	Jelani Kiehn	jelani.kiehn@geemail.com	Kansas City	Missouri	869993434909205097	fddbf1d7e7ddc5360af8a8af6c97ec38	JCB 16 digit	39.0887347878724398	-94.6119348996542442
11565	2020-02-07 19:13:24	2020-02-07	Eden Rutherford	eden.rutherford@warmmail.com	Abilene	Texas	180062208548216831	f3891ef9ac875f33105889369035c88e	Voyager	32.5390758918672844	-99.741265020467722
11566	2020-02-07 19:43:25	2020-02-07	Muhammad Abernathy	muhammad.abernathy@woohoo.com	Columbia	South Carolina	3337101859729384443	bb3adba3962c8fed799bcb8b9b12f9d9	American Express	33.9867389271300269	-80.8201672474872339
11567	2020-02-07 20:19:35	2020-02-07	Miss Albina Nicolas MD	miss.albina.nicolas.md@geemail.com	Sioux Falls	South Dakota	3337645330283273631	e6b8b5893455e9190ac850d66da1d4b0	VISA 16 digit	43.5235001068647946	-96.8177151031959795
11568	2020-02-07 20:19:39	2020-02-07	Dr. Ayaan Casper V	dr.ayaan.casper.v@geemail.com	Berkeley	California	51870628520903001	3c027ad6efbbefbe8488fdf748c5c0c6	VISA 16 digit	37.9107483698769272	-122.262605813253515
11569	2020-02-07 20:41:10	2020-02-07	Christian Dibbert-Dickinson	christian.dibbert.dickinson@woohoo.com	Huntington Beach	California	4639654811582744	327ce42ec9dc6897d6903fc37f2c7c6f	Diners Club / Carte Blanche	33.6165010950569112	-118.012791117618974
11570	2020-02-07 20:43:07	2020-02-07	Dorman Schroeder-Padberg	dorman.schroeder.padberg@geemail.com	San Francisco	California	3088023967440924077	fc5c1ef1e62f803fd8d475d98e0efecf	Discover	37.7964096178189024	-122.431253239849298
11571	2020-02-07 20:46:39	2020-02-07	Lula Block	lula.block@geemail.com	Oakland	California	3497600338533442	c639731541df08b81a70953e25f48c3f	VISA 13 digit	37.804875869289944	-122.297806686586242
11572	2020-02-07 21:10:25	2020-02-07	Davonta Runolfsdottir	davonta.runolfsdottir@geemail.com	New York	New York	3088276989604307323	1f90b2d8294dd2cff11ce235d808ff37	JCB 15 digit	40.5931285543125142	-74.0133892355382415
11573	2020-02-07 21:28:17	2020-02-07	Lacy Nader	lacy.nader@geemail.com	San Francisco	California	55850690785367276	0fee63e4a0682f0dcf64f8f28c5a72fe	Mastercard	37.7446233126409325	-122.437471364881517
11574	2020-02-07 21:58:15	2020-02-07	Celena Feest	celena.feest@geemail.com	Oakland	California	676273480821963	45b9e84e2c0f20f591f9509d488027e1	American Express	37.7654362255153089	-122.280520250810852
11575	2020-02-07 22:13:39	2020-02-07	Ms. Missy Goodwin DVM	ms.missy.goodwin.dvm@geemail.com	Gilbert	Arizona	180029240812922473	448019e484405c1b2f6a435a929bbb41	Maestro	33.376998047146202	-111.764066441696514
11576	2020-02-07 22:18:58	2020-02-07	Mr. Mervyn Hintz III	mr.mervyn.hintz.iii@warmmail.com	Raleigh	North Carolina	3158507995951118271	e53b4272cff346f0fa00be0fa989b9e8	Voyager	35.7875251349195835	-78.7078168422386142
11577	2020-02-07 22:23:50	2020-02-07	Dr. Pate Skiles Jr.	dr.pate.skiles.jr.@geemail.com	Oakland	California	55215423766438670	feec0c0f7dd2f45543888431d052e3cf	Maestro	37.8009766963519098	-122.24643981888768
11578	2020-02-07 22:24:55	2020-02-07	Gail Mueller-Hansen	gail.mueller.hansen@geemail.com	New York	New York	3791746163314519	86cb9636f59b8de6ad0c4b8ef8481902	Discover	40.5899927680138504	-73.9786693181738286
11579	2020-02-07 22:32:58	2020-02-07	Hildred Zemlak	hildred.zemlak@warmmail.com	Eugene	Oregon	4758521639412	79686600553dec8f17cdc52bef6d1510	American Express	44.1008661775577835	-123.119794429465017
11580	2020-02-07 22:43:34	2020-02-07	Mikal Wilkinson	mikal.wilkinson@woohoo.com	San Francisco	California	210071749664248545	434545bf6ef21857b389238c0e95bbe1	VISA 16 digit	37.7835582961585317	-122.456545715290474
11581	2020-02-07 22:54:42	2020-02-07	Yuridia Klocko	yuridia.klocko@geemail.com	Houston	Texas	3112780537516535967	bfafdeed4d34e7286d9186129f63be5e	Voyager	29.7019225077316165	-95.4576551691178281
11582	2020-02-07 23:14:26	2020-02-07	Laureen Swift-Murray	laureen.swift.murray@warmmail.com	Arlington	Texas	4090619819585	ac62329a7cb93a08ab8efb4492f67348	American Express	32.7238086176354415	-97.157271930065761
11583	2020-02-07 23:59:46	2020-02-07	Judyth Stokes	judyth.stokes@geemail.com	Los Angeles	California	3337194810935705705	f3de668a89d581254f3f6247ed9aa68f	VISA 13 digit	34.0262806261755486	-118.447382913575694
11584	2020-02-08 00:04:58	2020-02-08	Yadira Torphy	yadira.torphy@geemail.com	Tacoma	Washington	4857716091403	65004c47f0edf22ac05e8eaf5a9b24db	American Express	47.193229660077769	-122.475086825411026
11585	2020-02-08 00:05:02	2020-02-08	Tre Eichmann	tre.eichmann@warmmail.com	Hillsboro	Oregon	3088174329568379518	ee31879caeecc2cac1784fc50eef2a26	Mastercard	45.5620549505781369	-122.9526057002291
11586	2020-02-08 00:09:13	2020-02-08	Darwin Jakubowski	darwin.jakubowski@geemail.com	Fort Lauderdale	Florida	4354834870683871	b89295a37ca73f89e37b52f7daa1f539	VISA 16 digit	26.1220335555251708	-80.1135608439620484
11587	2020-02-08 00:24:35	2020-02-08	Truman Lockman	truman.lockman@warmmail.com	Oakland	California	4070974903976	5fc88a46517d5d041a675f3134b38f85	Mastercard	37.7937733389743613	-122.288541376874761
11588	2020-02-08 01:24:48	2020-02-08	Junius Terry	junius.terry@geemail.com	Pasadena	California	676337248831390	d25d0a404c6be8f9b016c2e1d1d438a3	Voyager	34.1246821159817273	-118.144742138572411
11589	2020-02-08 01:27:30	2020-02-08	Winthrop Hickle	winthrop.hickle@geemail.com	Tampa	Florida	4847907117637481	bbc4083c50de76534e1fad5c04cc00a8	Maestro	27.8850368676822633	-82.4301974110983195
11590	2020-02-08 01:28:09	2020-02-08	Dr. Ezell Olson	dr.ezell.olson@warmmail.com	Laredo	Texas	3112558090584430158	92d8048ab9d563bfca3253f3d780b404	Voyager	27.5388168533515199	-99.5888601167134908
11591	2020-02-08 01:32:46	2020-02-08	Rhona McDermott	rhona.mcdermott@geemail.com	New York	New York	869973451437452805	9262ccc6cc4a28108b2d84173a310fac	Voyager	40.5983992181476196	-73.9351625163469492
11592	2020-02-08 01:55:05	2020-02-08	Mrs. Cori Ruecker	mrs.cori.ruecker@geemail.com	San Francisco	California	3003393350640781	e572d03d37d4cbecd95bd94f1d234c80	JCB 16 digit	37.7961437261224233	-122.43744159838235
11593	2020-02-08 02:03:13	2020-02-08	Arnett Conroy	arnett.conroy@geemail.com	San Francisco	California	3088580267867608450	e101af49dfc17735c8ec6d045db67ca1	American Express	37.7685437568194047	-122.422944817178475
11594	2020-02-08 02:23:00	2020-02-08	Miss Ellie Kuvalis DDS	miss.ellie.kuvalis.dds@geemail.com	Concord	California	589378593814490	27320c0868ecd1f860765b5950726a88	American Express	38.0328608442496545	-121.930492864147197
11595	2020-02-08 02:28:32	2020-02-08	Mildred Cormier DDS	mildred.cormier.dds@warmmail.com	San Jose	California	4834782439576	38f9d24d4c7a11b4eac40e24a40a7bb4	Mastercard	37.3719454100176733	-121.879711477480456
11596	2020-02-08 02:40:22	2020-02-08	Lonnie Conroy-Hirthe	lonnie.conroy.hirthe@warmmail.com	Houston	Texas	55122028678588074	e242c6a621d6fb582d70b1396921205d	Diners Club / Carte Blanche	29.761544294104354	-95.4339344688240487
11597	2020-02-08 02:53:19	2020-02-08	Ula Simonis	ula.simonis@woohoo.com	San Francisco	California	4126477495231	d7d9e62db348384e9bfb024b7ed96ebf	Mastercard	37.7874532159308885	-122.445141254741685
11598	2020-02-08 03:27:20	2020-02-08	Jovani Emard	jovani.emard@warmmail.com	Austin	Texas	502021176611545	cb4dc87eb13d7372075d7af72fa51099	JCB 16 digit	30.3849722658876331	-97.6980695756390674
11599	2020-02-08 03:34:51	2020-02-08	Dr. Paris Bernhard I	dr.paris.bernhard.i@geemail.com	Riverside	California	4134046614043	ab18140910f2eb8494bb7c2b4326128f	Diners Club / Carte Blanche	33.999757956475392	-117.328553033570572
11600	2020-02-08 03:58:07	2020-02-08	Dr. Ferrell Howe MD	dr.ferrell.howe.md@woohoo.com	Vallejo	California	060446510817516	d1df3bf1dc07809c09347eaf6e0762f9	JCB 15 digit	38.1575811172924944	-122.348958411427205
11601	2020-02-08 04:04:58	2020-02-08	Lucile Hauck	lucile.hauck@woohoo.com	San Francisco	California	4507267691219771	444851ddadac58da75735191c97e05a6	VISA 16 digit	37.7845132247951625	-122.458896127271657
11602	2020-02-08 04:33:31	2020-02-08	Liam Hirthe	liam.hirthe@geemail.com	Jackson	Mississippi	6011967916700634874	4a05c27fa565b42bd6418eb0857a52cf	Mastercard	32.4151842781055777	-90.1831818557784004
11603	2020-02-08 04:52:01	2020-02-08	Mr. Terrell Upton	mr.terrell.upton@warmmail.com	Palmdale	California	3032258432037408	13eada472c0ce19fb9ac401229768f8a	VISA 16 digit	34.5106833050809811	-118.13903802451641
11604	2020-02-08 04:57:09	2020-02-08	Clifton Renner I	clifton.renner.i@geemail.com	Oakland	California	54170519009471619	a84febdacf5411b928a409ca4f0dc114	VISA 16 digit	37.8116748604691324	-122.299889861465587
11605	2020-02-08 05:02:11	2020-02-08	Dr. Rueben Skiles	dr.rueben.skiles@geemail.com	Baltimore	Maryland	3017870823924203	b70a0677f78da521f202393a45dd9a9e	Maestro	39.2609933218453051	-76.5516299898754795
11606	2020-02-08 05:32:50	2020-02-08	Carson Blick-Kihn	carson.blick.kihn@geemail.com	San Francisco	California	6011747875440320151	cde445f814e47d0a11bc38996773ab22	JCB 16 digit	37.8033299644026854	-122.395533016404016
11607	2020-02-08 05:37:14	2020-02-08	Dr. Theda Rodriguez	dr.theda.rodriguez@woohoo.com	El Paso	Texas	869996646741598051	6e68125f5f77d2e6c7f912484887f63b	JCB 16 digit	31.8837972497861841	-106.348859569055961
11608	2020-02-08 05:42:51	2020-02-08	Dr. Shelton Goldner IV	dr.shelton.goldner.iv@geemail.com	Tampa	Florida	3763121108563303	eafaa7a64c8608930cde776b28150b42	American Express	28.0391447025001028	-82.3959321744486601
11609	2020-02-08 05:46:39	2020-02-08	Peggy Beatty	peggy.beatty@woohoo.com	Irvine	California	6011724470657186888	1b2c82c747851c95fe07b37806959427	VISA 13 digit	33.7540319192238201	-117.85714196399897
11610	2020-02-08 05:46:39	2020-02-08	Miss Kaitlynn Jacobson MD	miss.kaitlynn.jacobson.md@warmmail.com	Beaumont	Texas	3493188566261153	ec26298ee36150b428dd4ff7eb880f36	VISA 13 digit	30.1148497731961307	-94.0902479901697575
11611	2020-02-08 05:59:52	2020-02-08	Carlie Abshire Sr.	carlie.abshire.sr.@geemail.com	Toledo	Ohio	53910206785582265	64b13cebb6f1c6f786c59ba2eb4b3f0a	Maestro	41.6954298869878031	-83.5651623829599544
11612	2020-02-08 06:16:31	2020-02-08	Taniya McGlynn	taniya.mcglynn@geemail.com	Houston	Texas	676341981987658	c4c24f258ceddcb74de6d9d8ef4700bd	VISA 16 digit	29.7626769199579968	-95.4672751931022816
11613	2020-02-08 06:18:22	2020-02-08	Geovanni Carroll	geovanni.carroll@geemail.com	Houston	Texas	3465303193600475	bdf1627812aa8ea59b54a77751945cc7	Mastercard	29.805454265101254	-95.3393034847933762
11614	2020-02-08 06:48:49	2020-02-08	Felix O'Kon	felix.o'kon@geemail.com	San Francisco	California	3489038491972729	c6ff3bf75b71982a1010495ffbb74740	JCB 16 digit	37.8113837408866615	-122.401034463746612
11615	2020-02-08 06:58:01	2020-02-08	Minnie Schulist	minnie.schulist@geemail.com	San Francisco	California	6011327024979577331	a33307823527129d222fae5bf4377d35	Diners Club / Carte Blanche	37.7932141934665182	-122.437453124703879
11616	2020-02-08 07:01:30	2020-02-08	Lavonia Koch	lavonia.koch@geemail.com	Dallas	Texas	3088495836065953969	3e2032170af77e3924e416a32678d153	VISA 16 digit	32.7827787786994165	-96.7053468474615272
11617	2020-02-08 07:42:11	2020-02-08	Jamarion Abbott	jamarion.abbott@geemail.com	San Francisco	California	3025591288867776	726d72d809f78ef8a8505a275d6f552a	American Express	37.7713843377866709	-122.391448381541565
11618	2020-02-08 07:53:13	2020-02-08	Jeanna Schowalter	jeanna.schowalter@warmmail.com	Overland Park	Kansas	6011064093422102754	220f2504f0478cd09f5a43401207ca17	JCB 15 digit	38.9535941972266926	-94.7177421681623883
11619	2020-02-08 08:12:58	2020-02-08	Zaiden Hamill	zaiden.hamill@geemail.com	Oakland	California	210082812007714867	ff50ac6f795d5e1e63fbcf1d12d2e32c	Discover	37.8364336113013735	-122.26231704748119
11620	2020-02-08 08:17:00	2020-02-08	Jennie Collins-Hand	jennie.collins.hand@woohoo.com	Scottsdale	Arizona	3158962044919915540	5247be5f2fe69ddc66503fe90a225e10	Maestro	33.6572349641595068	-111.870119178152081
11621	2020-02-08 08:42:16	2020-02-08	Mrs. Janay Smith	mrs.janay.smith@warmmail.com	Los Angeles	California	3158376040745890691	5e0e1ed19c64be2ab2522abf9f0a0b03	VISA 13 digit	34.0338089626613964	-118.343404084908954
11622	2020-02-08 08:53:58	2020-02-08	Ms. Carleen Oberbrunner	ms.carleen.oberbrunner@geemail.com	New York	New York	6011905763767483786	c47f88cdefd5de211ce9ae668461fb95	JCB 15 digit	40.6018503351826183	-73.8439895249798894
11623	2020-02-08 09:01:39	2020-02-08	Tawanda Johns	tawanda.johns@geemail.com	Saint Paul	Minnesota	51406152255487158	499eab09ef2d6b7e6b9d769b6876c8f6	VISA 13 digit	44.9458194584991801	-93.0148725610025195
11624	2020-02-08 09:01:45	2020-02-08	Leatrice Swift	leatrice.swift@woohoo.com	Augusta	Georgia	869988913669575481	92f0eacbf0b40524c4bab2f03f3f5f81	VISA 13 digit	33.382306957637887	-82.0046567227520171
11625	2020-02-08 09:11:07	2020-02-08	Miss Rozella Schoen	miss.rozella.schoen@geemail.com	San Francisco	California	4138115190786211	f750cd819a04b9cb678fc6dabbfcad60	Voyager	37.7705913221670428	-122.433348404297504
11626	2020-02-08 09:11:36	2020-02-08	Curley Bednar	curley.bednar@geemail.com	San Francisco	California	869946727724717735	5cd12cd1c1746d8388205bad9913d64f	VISA 16 digit	37.7842332267009837	-122.418580470169232
11627	2020-02-08 09:13:23	2020-02-08	Dr. Tyler Graham IV	dr.tyler.graham.iv@geemail.com	Indianapolis	Indiana	6011012931904121029	0d296aa2584c7ca9bbd7f2c9cba04099	Maestro	39.8553606564186467	-86.1069005445778402
11628	2020-02-08 11:02:11	2020-02-08	Ezell Cummerata	ezell.cummerata@geemail.com	El Paso	Texas	3112478345672674571	406c5c3797771d4a3a926d570c5e16c2	JCB 16 digit	31.8363771657753745	-106.525830663692219
11629	2020-02-08 11:08:06	2020-02-08	Mr. Dorman Cassin V	mr.dorman.cassin.v@geemail.com	Dallas	Texas	3000453939044146	6a5bc09888dafd30b846b44aa634ed9d	Voyager	32.8616340789750225	-96.7995687993671652
11630	2020-02-08 11:12:47	2020-02-08	Yoselin Metz	yoselin.metz@geemail.com	Lowell	Massachusetts	4567062285505	436a400b67288fe628181866d1c7283f	Mastercard	42.6804524397347151	-71.3434616687580956
11631	2020-02-08 11:23:09	2020-02-08	Andon Kutch	andon.kutch@geemail.com	Arlington	Texas	210051977867425222	5edb92b1adb72b5f492a1f6b968d5289	VISA 13 digit	32.7138599664222411	-97.121591880873595
11632	2020-02-08 11:47:23	2020-02-08	Madelyn Gorczany	madelyn.gorczany@geemail.com	Glendale	Arizona	6011038288848342272	37821d95c74027e34fa1aaf83002314b	VISA 13 digit	33.5868829752080131	-112.232470020770648
11633	2020-02-08 11:54:22	2020-02-08	Murl Terry-Lesch	murl.terry.lesch@geemail.com	Atlanta	Georgia	869970420873492784	c557f084cc98e13c8756ede9f99acdfc	Voyager	33.6795699314955641	-84.50331390593648
11634	2020-02-08 11:56:30	2020-02-08	Christi Feil-Kovacek	christi.feil.kovacek@geemail.com	San Francisco	California	3764175398904949	86f97887966c7ca80c80203339fcd6c5	JCB 16 digit	37.7887626617476684	-122.435488221105587
11635	2020-02-08 12:05:48	2020-02-08	Chancey Braun	chancey.braun@geemail.com	Boise	Idaho	210049022861082094	90b22f3b296c090ee2344bc9caec1634	VISA 13 digit	43.5238654937733003	-116.210217781477425
11636	2020-02-08 12:19:06	2020-02-08	Nello Koch-Wuckert	nello.koch.wuckert@geemail.com	Clarksville	Tennessee	4654079526822	1f984312381685a5938c6474aea45f66	Discover	36.5675475146282452	-87.3246347138609735
11637	2020-02-08 12:52:26	2020-02-08	Charlene Jones-Emard	charlene.jones.emard@geemail.com	Modesto	California	3020051383603886	9482569eeaf153b1a205aa34ad666ba0	Voyager	37.6365969479549705	-120.907571483377367
11638	2020-02-08 13:16:15	2020-02-08	Petra Kirlin	petra.kirlin@geemail.com	Berkeley	California	3415560060639792	7bae031eb6dd8c27d7314040d12f42b4	JCB 16 digit	37.8803708063672957	-122.303672940819396
11639	2020-02-08 13:51:53	2020-02-08	Herschel Howell	herschel.howell@geemail.com	Houston	Texas	4196343612423887	475207284e69caa8038c9dd38b2e8922	Discover	29.8400150598105043	-95.4138520017746856
11640	2020-02-08 14:31:18	2020-02-08	Jamari Crona Sr.	jamari.crona.sr.@geemail.com	Killeen	Texas	6011960434560730995	c5411640071a2c0c42247b547edd2567	VISA 16 digit	31.0501359725601986	-97.7266097876876643
11641	2020-02-08 14:48:03	2020-02-08	Eden Nader	eden.nader@geemail.com	Detroit	Michigan	3112562384627778648	4468230f916adc92438c4e6c2c853ce9	Discover	42.3612220223452951	-83.0889772257886818
11642	2020-02-08 14:49:46	2020-02-08	Jaliyah Veum	jaliyah.veum@geemail.com	New York	New York	6011279879956563127	c1079579c3a4c1b58dcd8ff26bfd3c2d	JCB 16 digit	40.5977126122675855	-74.0213333787292243
11643	2020-02-08 15:15:16	2020-02-08	Mrs. Phoenix Toy DVM	mrs.phoenix.toy.dvm@geemail.com	San Francisco	California	180003533233220356	016c410bac59f7349f29edb984e5ef96	Maestro	37.778748422369361	-122.424474619742952
11644	2020-02-08 15:42:29	2020-02-08	Barbara Lakin	barbara.lakin@woohoo.com	San Francisco	California	4433317269473943	c269790d2b75233f7affca833b8315fc	Voyager	37.7781526382122124	-122.438618296810745
11645	2020-02-08 15:52:40	2020-02-08	Brandyn Hackett	brandyn.hackett@warmmail.com	San Francisco	California	51263771663572616	ccb084014fba430666cb30e569f2ea4c	VISA 16 digit	37.7747914365184769	-122.435504881241613
11646	2020-02-08 15:54:00	2020-02-08	Miss Deedee Goldner MD	miss.deedee.goldner.md@geemail.com	Jackson	Mississippi	3706004172425148	7ef61fc3026e2ec0308fff162cf5e2a1	VISA 16 digit	32.3654447636745886	-90.2097551143236416
11647	2020-02-08 16:30:35	2020-02-08	Pierce Willms	pierce.willms@geemail.com	Davie	Florida	4477215888280185	26111adb90bd12da450cb29741e42135	Mastercard	26.0945824278783043	-80.2084567090403198
11648	2020-02-08 16:31:08	2020-02-08	Ms. Ivonne Heaney DVM	ms.ivonne.heaney.dvm@woohoo.com	San Francisco	California	869954774292459422	d33014ad5324a28147b331109a20f251	Voyager	37.8134668077821203	-122.430181313987021
11649	2020-02-08 16:49:06	2020-02-08	Rona Quigley	rona.quigley@geemail.com	San Francisco	California	180006578673910716	fb62c2a87f320c4d7dbd2250f6a20e08	JCB 15 digit	37.7754662320796442	-122.433190919102387
11650	2020-02-08 16:51:52	2020-02-08	Dr. Porsha Anderson	dr.porsha.anderson@geemail.com	Atlanta	Georgia	869971059755103231	402def2817887bd8e2a57243a96c7dc8	JCB 15 digit	33.8042529116194714	-84.3913997352168082
11651	2020-02-08 17:08:57	2020-02-08	Miah Schulist	miah.schulist@geemail.com	Las Vegas	Nevada	869984583656339052	98d5847b79d592b480f6e1732fc1737c	Mastercard	36.2929934466358262	-115.194309322649985
11652	2020-02-08 17:11:09	2020-02-08	Cornel Zemlak	cornel.zemlak@geemail.com	San Francisco	California	869918438804624445	7021762ae8ea29c1fd53efaca16e1e5e	VISA 16 digit	37.7514063447218433	-122.428917961548464
11653	2020-02-08 17:44:17	2020-02-08	Dominque Pouros	dominque.pouros@woohoo.com	Fort Worth	Texas	210068446990226361	5aa3f6245574daa0654759947f3c0677	VISA 13 digit	32.8332743104137492	-97.3565383953329189
11654	2020-02-08 17:53:53	2020-02-08	Bjorn Reynolds	bjorn.reynolds@geemail.com	Boston	Massachusetts	4848073079208628	46bb8ca376e90d71c20fa85bb4b83789	JCB 16 digit	42.3448092512488401	-70.9349590129170622
11655	2020-02-08 18:03:50	2020-02-08	Alexandre Wuckert	alexandre.wuckert@geemail.com	New York	New York	3337284680362333870	1e3df7cfd46fbb1e3390a4931485f490	VISA 13 digit	40.5799127015974364	-73.8595551547955722
11656	2020-02-08 18:10:32	2020-02-08	Regan Hahn	regan.hahn@woohoo.com	Honolulu	Hawaii	51539430451105463	f0bf9ad7224920956af92f0a7efadfd0	VISA 13 digit	21.3454072194390001	-157.915542942213278
11657	2020-02-08 18:16:45	2020-02-08	Lorenz Lebsack	lorenz.lebsack@geemail.com	San Francisco	California	4382395039623	2385e86b128e54e7036055cbe2720e5e	Discover	37.7676435326904851	-122.440377260858313
11658	2020-02-08 18:23:23	2020-02-08	Myrtis Dicki DDS	myrtis.dicki.dds@geemail.com	Topeka	Kansas	869914211186315740	e1d59410b601de38a3ed7ebe62a6dd60	Maestro	39.0579785223983222	-95.6153521264612749
11659	2020-02-08 18:24:28	2020-02-08	Phyllis Hessel MD	phyllis.hessel.md@woohoo.com	College Station	Texas	3088585278749638073	18f819b831ab76b7af910b1e48c6fc8d	Discover	30.6318869838070142	-96.2870518067698953
11660	2020-02-08 18:28:11	2020-02-08	Libby Daugherty	libby.daugherty@geemail.com	Port St. Lucie	Florida	3096148505578470214	c36bac3570f051fad0d629c94aecdd94	Discover	27.3761145372077834	-80.3137623039159934
11661	2020-02-08 19:10:11	2020-02-08	Ms. Dayami Blanda DDS	ms.dayami.blanda.dds@geemail.com	Phoenix	Arizona	4205206079142	b0f4c2ba1724a3caa529a6dc85c00d6c	VISA 13 digit	33.4737254409518101	-112.02005236958378
11662	2020-02-08 19:17:22	2020-02-08	Dr. Raven Hoppe PhD	dr.raven.hoppe.phd@geemail.com	Montgomery	Alabama	676123234282129	e382578c2182edd0d1b9e5d9e8a37d9b	Mastercard	32.2824096244692811	-86.2791356824025399
11663	2020-02-08 19:36:39	2020-02-08	Lamonte Medhurst	lamonte.medhurst@woohoo.com	Tucson	Arizona	869976663584373652	8fce8539b18c0c98dd6dd2c2e1a45c72	Voyager	32.2326242931693798	-110.84265182835459
11664	2020-02-08 19:38:30	2020-02-08	Mr. Eliga Casper	mr.eliga.casper@geemail.com	Joliet	Illinois	869919287502945464	5ac1b0d78b89ed6dfe4060d3ae618354	VISA 16 digit	41.5344036535218351	-88.229360301896179
11665	2020-02-08 19:38:53	2020-02-08	Tyreke Quitzon	tyreke.quitzon@warmmail.com	Dallas	Texas	3701493808371815	1bf4784125debc2da9a29be97f311ad3	Maestro	32.8469244370508946	-96.7452370840553186
11666	2020-02-08 19:40:29	2020-02-08	Mr. Lorenza Considine	mr.lorenza.considine@warmmail.com	Chicago	Illinois	3528890598295994749	bbdb6bf6efa1b5dc05d319c2265b7133	American Express	41.8102663851644891	-87.6459289949882674
11667	2020-02-08 20:05:01	2020-02-08	Hakim Grant	hakim.grant@geemail.com	Ontario	California	210096318883049117	e29854b783ce62dc03f5755dc3c4c92b	VISA 16 digit	34.1033940128661683	-117.562700123303387
11668	2020-02-08 20:10:17	2020-02-08	Terell Gerhold	terell.gerhold@geemail.com	Minneapolis	Minnesota	51803122405596595	211fcc2608b2270202909842ed4a2971	JCB 16 digit	44.9182699896480884	-93.3273193427167769
11669	2020-02-08 20:12:13	2020-02-08	Philip Adams	philip.adams@geemail.com	Chicago	Illinois	3761100089827186	3ad3e5c9fb2053568bd6093d65ecb30b	VISA 13 digit	41.8857336301658307	-87.7306676002249048
11670	2020-02-08 20:12:56	2020-02-08	Dr. Frankie Rempel I	dr.frankie.rempel.i@geemail.com	San Antonio	Texas	3337806677297693856	6a07beffc7615ebc96ca4dcdc15def67	Discover	29.388541928173602	-98.488855469210435
11671	2020-02-08 20:18:54	2020-02-08	Link Purdy II	link.purdy.ii@geemail.com	Chicago	Illinois	3088679002383847981	ec9bd42d69170a4d7e7df8ad57081965	American Express	41.9276792277883743	-87.6776691956940937
11672	2020-02-08 20:26:30	2020-02-08	Ahmed Kozey	ahmed.kozey@geemail.com	Los Angeles	California	4294681633656	30b1be9f879acc7f189bedefb3dee2d2	Voyager	34.0045797500625255	-118.31182663640864
11673	2020-02-08 20:32:21	2020-02-08	Mavis Mosciski	mavis.mosciski@geemail.com	Inglewood	California	4353095903107681	ac53b042c6c1b7946895a1d898bd1734	VISA 13 digit	34.0221314369946697	-118.388654411959649
11674	2020-02-08 20:40:21	2020-02-08	Margarette Emard	margarette.emard@geemail.com	New York	New York	3528362443308487663	1da24a25b39a0b84c7a225ec7b5a7267	Diners Club / Carte Blanche	40.7195539130121489	-73.9042685432255269
11675	2020-02-08 20:52:29	2020-02-08	Deonte Schumm II	deonte.schumm.ii@geemail.com	San Antonio	Texas	3088154201164489542	bca1f60be3db2dbbaa1ad0d9fc5d49b1	JCB 15 digit	29.4664623617731039	-98.4314635087572043
11676	2020-02-08 21:09:17	2020-02-08	Davie Simonis II	davie.simonis.ii@geemail.com	Bridgeport	Connecticut	4840491642296367	6b95beec236eb474d6b0ae1ef133f36d	Voyager	41.1126055446617258	-73.1827744023773903
11677	2020-02-08 21:22:14	2020-02-08	Kelly Windler-Senger	kelly.windler.senger@geemail.com	San Diego	California	4032116229899907	e942d40249cfee836b5a1001001f1e7c	VISA 16 digit	32.9029325277145972	-117.08920689689927
11678	2020-02-08 21:26:46	2020-02-08	Elby Lowe	elby.lowe@geemail.com	San Diego	California	3718232515403383	779e685c2e00f892814b94cd62944cd3	VISA 16 digit	32.9141692576996974	-117.097613439653074
11679	2020-02-08 21:39:33	2020-02-08	Veda Ullrich	veda.ullrich@warmmail.com	Cleveland	Ohio	210091134671618418	d9769827629bb43341f6a6e9859b994f	JCB 16 digit	41.4975482411067915	-81.6344304271280805
11680	2020-02-08 21:54:03	2020-02-08	Sherman Fisher Jr.	sherman.fisher.jr.@geemail.com	Cleveland	Ohio	3000477446110397	1f5b9df3b69c4ececbcfdd018f29c70f	American Express	41.3932580237127823	-81.618518751510976
11681	2020-02-08 21:54:36	2020-02-08	Herman Stark	herman.stark@warmmail.com	San Francisco	California	3337257841674813206	5ddb569cda2d89826f37c549bcec43c3	Maestro	37.7645771037492537	-122.413953719203292
11682	2020-02-08 22:12:17	2020-02-08	Dr. Domingo White I	dr.domingo.white.i@geemail.com	Berkeley	California	210042211857367679	4621b4d005fc0fa2c74eceb960227ae8	VISA 13 digit	37.8482308144822568	-122.25957661937403
11683	2020-02-08 22:17:25	2020-02-08	Dr. Douglass Toy	dr.douglass.toy@warmmail.com	Vancouver	Washington	503880712771056	18baf0005425069dc1112ebf2647d9fd	JCB 15 digit	45.6662140485901418	-122.653073498007643
11684	2020-02-08 23:14:05	2020-02-08	Dan Lebsack	dan.lebsack@geemail.com	San Diego	California	3046464829412289	ea54f552ec293028ed930e45bc65c3ac	Diners Club / Carte Blanche	32.7715343414872891	-117.159100844655185
11685	2020-02-08 23:16:03	2020-02-08	Corinne Treutel MD	corinne.treutel.md@warmmail.com	Montgomery	Alabama	3023756464497787	8b81fc9f7c8861cc645c3ee8342508f7	VISA 13 digit	32.2539847541533433	-86.3283765112668249
11686	2020-02-08 23:40:56	2020-02-08	Ari Hauck	ari.hauck@geemail.com	San Francisco	California	3446490782247208	883d31af45878cfff1fdf34bbe5b61de	JCB 16 digit	37.7726463452317134	-122.439171855929061
11687	2020-02-09 00:25:04	2020-02-09	Laddie Yundt	laddie.yundt@warmmail.com	New York	New York	4911496803816	9d9be746c1b75ad0bbf5367526ebcc2a	VISA 13 digit	40.6523981712516402	-73.9047187338478864
11688	2020-02-09 00:28:19	2020-02-09	German Jacobson	german.jacobson@geemail.com	Colorado Springs	Colorado	4393432101017796	c1823ba3cea3fb82d52b1bef7072e917	JCB 15 digit	38.9283328044742376	-104.675384157492587
11689	2020-02-09 00:44:30	2020-02-09	Talia Tillman	talia.tillman@woohoo.com	Fort Lauderdale	Florida	869981868589066812	e60f5976a98247c49f6a6e936098e475	Discover	26.125427085951717	-80.1426659068379479
11690	2020-02-09 01:09:01	2020-02-09	Dr. Johan Buckridge II	dr.johan.buckridge.ii@warmmail.com	Fullerton	California	4519283222924447	dc860e9d7f1c1cf7e87a9e9920317547	VISA 13 digit	33.865996823242682	-117.881997522033743
11691	2020-02-09 01:12:35	2020-02-09	Arlis Terry	arlis.terry@woohoo.com	Irvine	California	6011758930914939444	6205a4d8096d72344da539f168d07a31	Discover	33.692450946803767	-117.862257728074866
11692	2020-02-09 01:38:47	2020-02-09	Senora McKenzie	senora.mckenzie@geemail.com	New York	New York	4490399686631592	bdccb5901ff8c08b1c389136c1dbc40f	Discover	40.5943982233051202	-73.9187630792975341
11693	2020-02-09 01:44:08	2020-02-09	Jami Shanahan	jami.shanahan@geemail.com	Scottsdale	Arizona	4774704389457137	ac9dc6c7ffb1887e6e804383bafe98c6	VISA 16 digit	33.6726841439150277	-111.83656405335887
11694	2020-02-09 01:49:39	2020-02-09	Mathilde Tillman	mathilde.tillman@geemail.com	Charlotte	North Carolina	3053661399644679	93c1f3a8143d93039fefa18556582bcb	VISA 16 digit	35.280034297171234	-80.8654564031343881
11695	2020-02-09 01:56:08	2020-02-09	Shane Brekke	shane.brekke@geemail.com	Tulsa	Oklahoma	6011365094998487849	9420d2cc1165bb3b1fb758e8d39c8cd9	VISA 16 digit	36.0461351221330446	-95.8942325877446677
11696	2020-02-09 02:02:09	2020-02-09	Miss Maebelle Larkin	miss.maebelle.larkin@warmmail.com	San Francisco	California	180041291638833372	1582fabbf17a2535c1cbd313d5dc0337	Maestro	37.7961441381693177	-122.425168784584358
11697	2020-02-09 02:24:56	2020-02-09	Giuliana Rice	giuliana.rice@geemail.com	Philadelphia	Pennsylvania	675927157282834	bac33bd61458ac53703c76a1cd7ebdce	JCB 16 digit	39.9232406575191732	-75.1072440365228857
11698	2020-02-09 02:25:14	2020-02-09	Jarrett Hintz	jarrett.hintz@geemail.com	San Angelo	Texas	51729165096698767	27e76c63d74752a7e92d72fd606210d2	Discover	31.4959859630245695	-100.382142203452077
11699	2020-02-09 02:36:33	2020-02-09	Jamila Haley PhD	jamila.haley.phd@geemail.com	Los Angeles	California	4974943506124166	d21f92d706c7ef5941eb2df069701bca	VISA 13 digit	33.994888010002299	-118.391980641613898
11700	2020-02-09 02:38:39	2020-02-09	Olar Oberbrunner-Rath	olar.oberbrunner.rath@geemail.com	New York	New York	55519915999320388	e5cb20f8d9ca78c23045f5e75b55ba8e	Mastercard	40.6137314862329504	-73.920296344802523
11701	2020-02-09 02:42:10	2020-02-09	Alexande Abernathy	alexande.abernathy@woohoo.com	Greeley	Colorado	180074144848451933	c4c5df9fac1593cf2722db5130a16721	Voyager	40.422868767759951	-104.799214950606967
11702	2020-02-09 02:44:47	2020-02-09	Miner Conn	miner.conn@geemail.com	Wichita	Kansas	3528346861981572058	c52d6055d6c23af28843303db4ec1860	VISA 16 digit	37.5920790508732168	-97.3763442835971773
11703	2020-02-09 02:45:21	2020-02-09	Mr. Kaiden McLaughlin MD	mr.kaiden.mclaughlin.md@geemail.com	Thornton	Colorado	6011430138608353171	2221a65ce48e071c61df3e5420e9d777	JCB 15 digit	39.8616567560337529	-105.022651952008914
11704	2020-02-09 02:48:55	2020-02-09	Ms. Hollis Sauer	ms.hollis.sauer@geemail.com	Oakland	California	3416753848892028	6040794e71e9ce4aad1613ddc12b8832	VISA 13 digit	37.8150534415396393	-122.264497729102729
11705	2020-02-09 02:54:36	2020-02-09	Georgine Ruecker DVM	georgine.ruecker.dvm@geemail.com	Louisville	Kentucky	53012057687102208	94b76ce77ce467c38f7aa3ac1e89c605	JCB 16 digit	38.2357557152766745	-85.6844086516253753
11706	2020-02-09 02:56:37	2020-02-09	Mrs. Keanna Emmerich PhD	mrs.keanna.emmerich.phd@geemail.com	Kent	Washington	502063614312716	80a040aa91a401e605c6054001dc5dbd	Voyager	47.407417771138249	-122.277870793607832
11707	2020-02-09 03:05:28	2020-02-09	Douglas Wyman	douglas.wyman@woohoo.com	Los Angeles	California	676303108227673	5b15ba7094d825274c96467a49387998	Maestro	34.0174931793339539	-118.429159846761451
11708	2020-02-09 03:10:45	2020-02-09	Coolidge Simonis-Mraz	coolidge.simonis.mraz@geemail.com	Fresno	California	55817738730482872	7623386d5fcf10fcc96286ca8f233b9a	VISA 16 digit	36.8253322445195153	-119.837858642043173
11709	2020-02-09 03:24:52	2020-02-09	Ty Beatty	ty.beatty@geemail.com	Peoria	Illinois	3088759889381607810	00f78f57a01d87081f456ec121f6e62a	VISA 13 digit	40.6596321035511821	-89.5871196163702734
11710	2020-02-09 03:42:16	2020-02-09	Cherish Pfeffer	cherish.pfeffer@geemail.com	Dallas	Texas	676238743534794	a74679afe182665d5713c6ad82e67854	VISA 16 digit	32.7860561719901895	-96.6883599922489338
11711	2020-02-09 03:47:58	2020-02-09	Odell O'Conner-Veum	odell.o'conner.veum@woohoo.com	San Francisco	California	869954063565126524	a7e6ab4bb04b2671fcc3d9f3f226ade6	VISA 16 digit	37.7642222695677461	-122.439970616457785
11712	2020-02-09 03:48:53	2020-02-09	Miss Kenley Turcotte MD	miss.kenley.turcotte.md@warmmail.com	Los Angeles	California	630418436518833	6fe96ca1dbfc5703c1d1874a5c1e9001	Diners Club / Carte Blanche	33.9348528521466974	-118.415967546262962
11713	2020-02-09 03:49:57	2020-02-09	Joaquin Goodwin DVM	joaquin.goodwin.dvm@geemail.com	Eugene	Oregon	6011180757791764944	5a421b351ad1b355a1b39598babeb892	Voyager	44.0115390521202201	-123.016825504553324
11714	2020-02-09 04:01:37	2020-02-09	Jedediah Torphy-Goldner	jedediah.torphy.goldner@geemail.com	San Francisco	California	4826931262335431	85436fc46db5938255062923161339ec	JCB 15 digit	37.7909154522953514	-122.439619869637681
11715	2020-02-09 04:23:10	2020-02-09	Karren Howe	karren.howe@geemail.com	San Francisco	California	502019554478578	5fd925918a3eed86402182018c5bd0ee	Maestro	37.7802072175233761	-122.432294877880778
11716	2020-02-09 04:56:38	2020-02-09	Laurence Schinner MD	laurence.schinner.md@geemail.com	Nashville	Tennessee	4617737178728483	58d71520549522db9d3c2973c11acb03	VISA 13 digit	36.1791771607596431	-86.7575564245600219
11717	2020-02-09 04:59:16	2020-02-09	Mara Leannon	mara.leannon@warmmail.com	Fairfield	California	3707246606461814	274af0ea2f9fa809a3c7b763ac73f11e	VISA 13 digit	38.3121541150968525	-122.104920108151063
11718	2020-02-09 05:08:43	2020-02-09	Twyla Gleichner DVM	twyla.gleichner.dvm@woohoo.com	Boston	Massachusetts	869988811361676088	0d0f74afa4610c6e7f5a01b5c234450b	American Express	42.34391258057952	-71.0233791881658192
11719	2020-02-09 05:17:54	2020-02-09	Zelma Waelchi PhD	zelma.waelchi.phd@geemail.com	Indianapolis	Indiana	4099815381244600	e4ee5037646915d2413357f833663add	JCB 16 digit	39.7611829212874142	-86.1980914986893509
11720	2020-02-09 05:35:35	2020-02-09	Kevan Wiza	kevan.wiza@warmmail.com	Louisville	Kentucky	6011271314671684600	3b0b2c34eced1d1686a35473f751b0dc	VISA 16 digit	38.239766491846737	-85.622692160455145
11721	2020-02-09 07:30:17	2020-02-09	Dakota Crona	dakota.crona@geemail.com	Las Vegas	Nevada	3733674809058343	c23a20ee0186359e2ac5e7f6a1e5b039	Voyager	36.159195019314808	-115.190806389201796
11722	2020-02-09 07:50:23	2020-02-09	Dr. Karon Rippin PhD	dr.karon.rippin.phd@geemail.com	San Francisco	California	3749507635510677	af04e81930b88ffe10f06db285bc5b93	Mastercard	37.7985738624070962	-122.416112406093944
11723	2020-02-09 08:00:42	2020-02-09	Gaylene Volkman	gaylene.volkman@warmmail.com	Glendale	Arizona	3423942895057855	fa167b0d0f0259a9ef5a6798fb180134	Maestro	33.5449616255931531	-112.15900396181047
11724	2020-02-09 08:36:34	2020-02-09	Felipe Bernhard	felipe.bernhard@geemail.com	San Francisco	California	180058734274077622	8f08393d2ebef8b4291624348c009690	VISA 16 digit	37.7693730466852244	-122.444430638364821
11725	2020-02-09 08:40:14	2020-02-09	Johnie Hessel-Littel	johnie.hessel.littel@woohoo.com	Los Angeles	California	180062371010407211	0fae5c735c4f43919475b793a4875879	Diners Club / Carte Blanche	34.1182538238685567	-118.367947832075131
11726	2020-02-09 09:14:56	2020-02-09	Bell Berge I	bell.berge.i@geemail.com	Raleigh	North Carolina	4843073400171086	c52532e499126e8eda193868280d5b7f	JCB 16 digit	35.8368519424594894	-78.6367602352455322
11727	2020-02-09 09:18:57	2020-02-09	Mr. Huey Stiedemann PhD	mr.huey.stiedemann.phd@woohoo.com	Vista	California	6011237681943916595	b9a8a8d61793df9950305f928e37df26	JCB 16 digit	33.1403852796629081	-117.138693409465631
11728	2020-02-09 09:42:52	2020-02-09	Leigh Towne	leigh.towne@woohoo.com	Mesa	Arizona	210082169925323432	6bd8ac546b0500329dbe4fabfc2da196	Discover	33.4069443170592137	-111.794042859634004
11729	2020-02-09 09:58:35	2020-02-09	Soloman Toy	soloman.toy@geemail.com	Baton Rouge	Louisiana	4619901373863192	4186ef7dc3358c05333ba7dabc2a8ebd	Maestro	30.5338353695094575	-91.1766359862979527
11730	2020-02-09 10:26:01	2020-02-09	Brennen Gutkowski III	brennen.gutkowski.iii@geemail.com	Miami Gardens	Florida	210078430246857987	6ae969e56cef6d05706d0315035887a9	Voyager	25.9685637750603249	-80.249471165124703
11731	2020-02-09 10:29:01	2020-02-09	Willa Dicki	willa.dicki@geemail.com	Edison	New Jersey	210036770364635660	f8fd34e058b06e89d6d5ac557cda6c1c	JCB 15 digit	40.5865736652594009	-74.417560754162821
11732	2020-02-09 10:34:53	2020-02-09	Selena Hudson DVM	selena.hudson.dvm@geemail.com	San Francisco	California	3088992130736191987	45bd993317072071e6982707363d42e1	Voyager	37.7652741514185237	-122.423603238512527
11733	2020-02-09 10:36:13	2020-02-09	Dr. Edmonia Farrell MD	dr.edmonia.farrell.md@warmmail.com	Houston	Texas	869986030886127871	f3b21bc3c8f5785f58d5899df5a447c2	Mastercard	29.7275277130849673	-95.4617349167369298
11734	2020-02-09 10:49:12	2020-02-09	Laurel Dooley	laurel.dooley@geemail.com	Boise	Idaho	501899536935119	e3cf80000343b3414459c0796d32f88b	JCB 16 digit	43.6397861253607999	-116.157420655499024
11735	2020-02-09 11:03:45	2020-02-09	Dr. Jordyn Schmidt	dr.jordyn.schmidt@geemail.com	Lubbock	Texas	676120928975943	9bd6bca1256df2e7f6b5d6ee787c2e95	VISA 16 digit	33.5127678002271807	-101.942050327864294
11736	2020-02-09 11:06:45	2020-02-09	Dr. Hurley Oberbrunner	dr.hurley.oberbrunner@geemail.com	Oakland	California	180067065759640108	d1d06cb9d2bc2b3145ecffe2192198c6	Mastercard	37.7745230838620856	-122.244893571218
11737	2020-02-09 11:30:08	2020-02-09	Shirley Quigley-Schneider	shirley.quigley.schneider@geemail.com	San Francisco	California	54015986885960552	971b14c3a3da7fdd50a280611fe7253b	JCB 16 digit	37.7392991157780102	-122.413056238577653
11738	2020-02-09 11:55:43	2020-02-09	Bella Cronin	bella.cronin@geemail.com	Los Angeles	California	4798821519906	81a682089dabd462040db4cb2b56422f	Discover	34.0340311521530126	-118.361818759002901
11739	2020-02-09 11:59:38	2020-02-09	Larissa Waelchi	larissa.waelchi@geemail.com	Victorville	California	676197684784941	94a3c6764eec5f2fe78ff835c3dfc247	VISA 16 digit	34.5454138234488681	-117.366377125928551
11740	2020-02-09 12:05:33	2020-02-09	Brynn Fay	brynn.fay@geemail.com	Rochester	New York	54678808732621500	c56373a1414eca2bdec72da998f899a6	Mastercard	43.1630076610926494	-77.5938075748976388
11741	2020-02-09 12:07:11	2020-02-09	Dr. Felton Thiel III	dr.felton.thiel.iii@warmmail.com	Pomona	California	503811036936240	8d454260f98d05d690aa20e83ba3830e	Voyager	34.0210895267352456	-117.667335078582539
11742	2020-02-09 12:22:04	2020-02-09	Santana Mueller	santana.mueller@geemail.com	Miramar	Florida	53275776291252404	28815550f6c4725b518f207da8b66dde	JCB 15 digit	26.0344020408093932	-80.2699862245462867
11743	2020-02-09 12:29:47	2020-02-09	Hazel Lesch	hazel.lesch@geemail.com	Sterling Heights	Michigan	6011923587931551725	5d7b2d5865914b0baeff94e215ddf547	Voyager	42.6200651453889918	-82.9375976692579684
11744	2020-02-09 12:37:47	2020-02-09	Annice Rau	annice.rau@geemail.com	New Haven	Connecticut	6011215418840226992	4dbac9474b68bb45cf3e8aa3772e3d3a	VISA 16 digit	41.399380380519851	-72.8417153289075969
11745	2020-02-09 12:40:23	2020-02-09	Leroy Schaden II	leroy.schaden.ii@woohoo.com	San Francisco	California	3088137633412583449	35a20220209a3d442239a1258284b5a7	Diners Club / Carte Blanche	37.7515502399522376	-122.442481214142717
11746	2020-02-09 12:47:31	2020-02-09	Jaycob Kris	jaycob.kris@warmmail.com	Chattanooga	Tennessee	52107299824925606	1d2d1020bb0c822d8b0b3de256958137	VISA 13 digit	35.0360701907742822	-85.2717290718402694
11747	2020-02-09 12:51:34	2020-02-09	Elick Cole	elick.cole@geemail.com	Stockton	California	55377415145126400	32207f105ded8bebee6a59b1637656be	American Express	38.0326408460468102	-121.324974750922252
11748	2020-02-09 13:03:59	2020-02-09	Ms. Maurine Olson PhD	ms.maurine.olson.phd@warmmail.com	Fort Worth	Texas	180098498507200680	f5b231fd4300352573300980b64f7723	Mastercard	32.7173197242021558	-97.2608547748818921
11749	2020-02-09 13:22:26	2020-02-09	Dr. Talen Keebler II	dr.talen.keebler.ii@geemail.com	Modesto	California	4800992798214664	55a5e5489b95685398f9dfff126f0f1f	Mastercard	37.5924138903152212	-121.032164507379761
11750	2020-02-09 13:48:57	2020-02-09	Griffin Buckridge	griffin.buckridge@geemail.com	Minneapolis	Minnesota	210065277992547493	f9d0be7c29a7985e4ffd2c2fefa091e4	Voyager	44.8763097121000243	-93.2194774138547473
11751	2020-02-09 13:50:12	2020-02-09	Nathaniel Daugherty	nathaniel.daugherty@geemail.com	Berkeley	California	869901817524124464	85b2c93f44481c100de497855cfef62e	VISA 16 digit	37.8533039885153713	-122.287887549805589
11752	2020-02-09 13:52:25	2020-02-09	Dr. Jean Huel MD	dr.jean.huel.md@geemail.com	Oakland	California	3528566422607609601	bb779150a249ef053d6dda26af8eca90	JCB 15 digit	37.7781459806402324	-122.272582266662042
11753	2020-02-09 13:54:44	2020-02-09	Patrick Torp	patrick.torp@woohoo.com	Santa Rosa	California	4782525039331160	e38ec65853455b44eeadf1a70f8886da	Voyager	38.4587110345840486	-122.678991997545964
11754	2020-02-09 14:04:27	2020-02-09	Agustin Swift	agustin.swift@woohoo.com	Oakland	California	210015813140923722	a06473bde4052f3cf77f28577b4c1547	Diners Club / Carte Blanche	37.7502728960841409	-122.257341937329983
11755	2020-02-09 14:14:59	2020-02-09	Mr. Clay Carroll III	mr.clay.carroll.iii@geemail.com	Meridian	Idaho	869990574940887115	d8c8336ed98bf66886d14fc35de9c742	Mastercard	43.5983503251343905	-116.394077179016165
11756	2020-02-09 14:46:28	2020-02-09	Babette Bosco-Gutkowski	babette.bosco.gutkowski@geemail.com	Los Angeles	California	3046460723508768	b9d71aa024963220a427c85df896ad57	American Express	34.1134913451369854	-118.496116070122639
11757	2020-02-09 14:54:40	2020-02-09	Bethel Hermann	bethel.hermann@geemail.com	Lakeland	Florida	675980848455558	874558a5b4d5e4caf631a1a542a587fd	JCB 16 digit	28.1463061733003705	-81.9349966567359758
11758	2020-02-09 14:57:13	2020-02-09	Dr. Zula McCullough DVM	dr.zula.mccullough.dvm@geemail.com	Charlotte	North Carolina	55921957529837848	e5127be634b3eafbc53911a3795c6d09	JCB 16 digit	35.115925620614739	-80.79564151414111
11759	2020-02-09 15:01:22	2020-02-09	Germaine Rodriguez	germaine.rodriguez@geemail.com	Temecula	California	4507015457836951	622093ce129dd4a5055ef6f99f8b0ca2	Maestro	33.5253754796594379	-117.13424082735628
11760	2020-02-09 15:19:38	2020-02-09	Mr. Anton Goodwin	mr.anton.goodwin@geemail.com	Houston	Texas	676397258132212	39b0ae3bf9d672ab21d94cbb26ba192e	Diners Club / Carte Blanche	29.8313277128696441	-95.4626815178446435
11761	2020-02-09 15:22:02	2020-02-09	Mrs. Kaylah Reynolds	mrs.kaylah.reynolds@geemail.com	Austin	Texas	3096398312552091505	3ab7785c1c8d02504fd187ea4cad7cd2	Discover	30.2222153085876251	-97.76591924659499
11762	2020-02-09 15:23:33	2020-02-09	Hazle Ward	hazle.ward@woohoo.com	San Jose	California	6011687231613827915	80085bb3e452b15c3cdb6dabd2994d84	VISA 16 digit	37.3168761552132651	-121.820276909064134
11763	2020-02-09 15:41:12	2020-02-09	Dr. Fran Hoeger PhD	dr.fran.hoeger.phd@geemail.com	Fontana	California	3408955848143761	6d5711879e5cdcd3a568cecb0c45b8db	VISA 16 digit	34.1609714773166928	-117.401210581166296
11764	2020-02-09 15:43:45	2020-02-09	Raven Bogisich-Roberts	raven.bogisich.roberts@geemail.com	Oakland	California	4199378385157	0d082a833ab20d465125a49912d258fc	VISA 16 digit	37.7968314413990072	-122.258814954591259
11765	2020-02-09 15:48:18	2020-02-09	Dr. Genoveva Schmitt MD	dr.genoveva.schmitt.md@woohoo.com	Chicago	Illinois	3337146461564118098	ccb1860e8a4675dca96371fbb3c68f3c	JCB 15 digit	41.8820692909717565	-87.7219283632032472
11766	2020-02-09 15:56:29	2020-02-09	Pinkey Hintz	pinkey.hintz@warmmail.com	Berkeley	California	6011653702706409498	e06a9006033484676fe8247672a0f5a5	VISA 13 digit	37.8911830491193342	-122.254944769208947
11767	2020-02-09 16:18:30	2020-02-09	Tevin Steuber	tevin.steuber@warmmail.com	Jacksonville	Florida	210049517087167298	71a3ceea9c9bd0aafe3f95d455f452b1	VISA 13 digit	30.4196125317882746	-81.6640643273558595
11768	2020-02-09 16:35:12	2020-02-09	Kierra Nicolas	kierra.nicolas@warmmail.com	Oakland	California	060418186198521	3b874111fdf5fd364082676ad535c194	JCB 16 digit	37.778755559233403	-122.302403382265908
11769	2020-02-09 16:38:22	2020-02-09	Venie Miller	venie.miller@geemail.com	Vancouver	Washington	4316000321139734	5626ea6aba48b9270f09d6f7cd16c05c	VISA 16 digit	45.5656660240214322	-122.68415318318344
11770	2020-02-09 17:03:50	2020-02-09	Junious Hermiston	junious.hermiston@woohoo.com	Fresno	California	4143741800653674	b43aa0ceb6ccb8c4f653de0050430f9b	JCB 16 digit	36.8161282880105105	-119.807069063569983
11771	2020-02-09 17:07:32	2020-02-09	Alejandra Ritchie-Brekke	alejandra.ritchie.brekke@geemail.com	Philadelphia	Pennsylvania	3054909328600422	6e0437a1b387a0acf56c7e41c01e5813	VISA 16 digit	40.0781554483767621	-75.2269551837250674
11772	2020-02-09 17:12:53	2020-02-09	Ms. Girtha Leannon DDS	ms.girtha.leannon.dds@geemail.com	Columbus	Ohio	589350031831386	0d1d2616e2b952a1427d8dfd5c65ee59	Voyager	40.0126650420062262	-82.9655457591407099
11773	2020-02-09 17:16:29	2020-02-09	Dr. Carli Champlin	dr.carli.champlin@geemail.com	Las Vegas	Nevada	3779150057803404	af0289e6cf97702a5943c72d8b1e968c	Diners Club / Carte Blanche	36.3032746595896754	-115.356572347946837
11774	2020-02-09 17:20:50	2020-02-09	Carra Hamill	carra.hamill@woohoo.com	San Francisco	California	675943325464428	0ed989bce39e53f750525b2ced6acfa0	VISA 16 digit	37.7372187798660121	-122.434755252427252
11775	2020-02-09 17:24:13	2020-02-09	Mikalah Frami-McDermott	mikalah.frami.mcdermott@warmmail.com	New York	New York	3112776843812217847	71c3e4aa7b67fdaf6000defe2e3d8c58	VISA 13 digit	40.7581671572513855	-73.9003567231714698
11776	2020-02-09 17:26:16	2020-02-09	Cheyanne O'Reilly	cheyanne.o'reilly@geemail.com	Paterson	New Jersey	3016528113876159	dc4ff8768a50dc353ca2acc93780c494	Discover	40.9389041728761072	-74.1572872844964337
11777	2020-02-09 17:31:23	2020-02-09	Avon Hills-Bradtke	avon.hills.bradtke@warmmail.com	San Francisco	California	869943351789314099	6755923a3fbfe7b972f0361b47efce65	Mastercard	37.7791666436983746	-122.411656925911174
11778	2020-02-09 17:33:00	2020-02-09	Zed Schamberger	zed.schamberger@warmmail.com	Milwaukee	Wisconsin	3528500757187810114	f59cb576bede5696032b56286c59155b	Discover	43.1218732895415258	-87.876208402785295
11779	2020-02-09 17:37:54	2020-02-09	Jolene Rice	jolene.rice@geemail.com	Berkeley	California	6011377122770829056	7fc2c948f2e3b300a0d9d5bf16ec61f6	American Express	37.8680778362977932	-122.28520144183527
11780	2020-02-09 17:39:44	2020-02-09	Miss Dyan Bernhard	miss.dyan.bernhard@geemail.com	Escondido	California	4532798526188277	eb51e55a612d6be1956ca31cfde0e938	American Express	33.0407055243611296	-117.161162823323153
11781	2020-02-09 18:05:40	2020-02-09	Ermine Larson	ermine.larson@geemail.com	San Diego	California	3337159910820903010	db36b01e110afa5851e71d7babf309ae	VISA 16 digit	32.8598129003375803	-117.223308169692757
11782	2020-02-09 18:33:42	2020-02-09	Lular Runolfsson	lular.runolfsson@geemail.com	New York	New York	6011218857499117068	160e4b8071d2a012e0c67da79e1e12d9	VISA 16 digit	40.7600631649363763	-73.8571917174745352
11783	2020-02-09 18:44:04	2020-02-09	Kayleigh Schinner PhD	kayleigh.schinner.phd@geemail.com	Athens	Georgia	503817175970528	325339bc450068ddd23c70c83cd52efb	Mastercard	33.9596977814290639	-83.3594891558516764
11784	2020-02-09 19:12:46	2020-02-09	Glenna Hahn	glenna.hahn@geemail.com	Los Angeles	California	561271504808842	89a886f819525575fa896760c03a11c1	American Express	34.0847547435998877	-118.431000339471922
11785	2020-02-09 19:17:03	2020-02-09	Dr. Lynsey Hodkiewicz	dr.lynsey.hodkiewicz@geemail.com	Sacramento	California	55528050796646493	4499fd89621ba9e08e23084863221aa0	Discover	38.4677630106251698	-121.482524706075338
11786	2020-02-09 19:28:09	2020-02-09	Mansfield Goyette Sr.	mansfield.goyette.sr.@geemail.com	San Francisco	California	869905954398512098	43c06bd5a0806fd963d6782f5d4c7366	American Express	37.7779414147813739	-122.424580449781246
11787	2020-02-09 19:38:13	2020-02-09	Ms. Silvia Davis MD	ms.silvia.davis.md@geemail.com	Nashville	Tennessee	3528333808431446206	0c65b23a2453a8b1ef0b3a1515e20b6b	VISA 16 digit	36.166026459600026	-86.8346746675576924
11788	2020-02-09 19:45:54	2020-02-09	Simpson Ferry	simpson.ferry@woohoo.com	Berkeley	California	3158842576254502777	f3ce29f27ecbdd40777d2311d801fbf9	Mastercard	37.8719581521522102	-122.302068217079494
11789	2020-02-09 20:28:25	2020-02-09	Mr. Ballard Schuppe II	mr.ballard.schuppe.ii@geemail.com	Newport News	Virginia	6011640783964963620	0142ec118e110edc50b95f49023222f7	VISA 16 digit	37.0078365460399539	-76.4566515764482375
11790	2020-02-09 20:42:29	2020-02-09	Ewin Zulauf	ewin.zulauf@geemail.com	Oakland	California	3744991485726564	7d9907ba73fc1b97c67d5243a2b4da0c	Voyager	37.8098712415055473	-122.280889722452329
11791	2020-02-09 20:47:25	2020-02-09	Trey Lemke	trey.lemke@geemail.com	Oakland	California	3474039958234170	f98a192f79e8752af2d82507a7a2d1b9	American Express	37.8238435337836805	-122.268599136598922
11792	2020-02-09 20:54:01	2020-02-09	Vic Haag	vic.haag@geemail.com	San Antonio	Texas	180066052727110357	59c71e81ceb2352040aec41bed0e0f05	VISA 16 digit	29.3777925754036744	-98.6094960468657291
11793	2020-02-09 21:32:45	2020-02-09	Celestino Kirlin	celestino.kirlin@geemail.com	San Francisco	California	4680999905225629	1bd6d68d13109a50cffdd84cb2066ac6	Voyager	37.7967437132894091	-122.422613041178877
11794	2020-02-09 21:50:10	2020-02-09	Jovany Collier	jovany.collier@warmmail.com	Glendale	California	869942684602810567	7d80b87767a87c8f9f83c673fc827982	Maestro	34.1137953379411201	-118.279951872294021
11795	2020-02-09 21:55:26	2020-02-09	Ebert Bogisich	ebert.bogisich@warmmail.com	San Francisco	California	869994040585492740	dbe6c85bc9c6e65ba21fbe5d237ff51c	Discover	37.7614893136245797	-122.429746582487965
11796	2020-02-09 22:25:56	2020-02-09	Rennie Gleason	rennie.gleason@geemail.com	Tacoma	Washington	51591540508162708	0aafc2a6a23f9ad234ae7fe264e5374e	Discover	47.2549626391500226	-122.447743117786203
11797	2020-02-09 23:05:58	2020-02-09	Mitch Thiel	mitch.thiel@woohoo.com	San Francisco	California	55563783433099256	11da17d0dc97c039f9d2dfc05fd91252	American Express	37.798964921936431	-122.418110345175734
11798	2020-02-09 23:06:10	2020-02-09	Dewitt Cormier	dewitt.cormier@geemail.com	New York	New York	4336807601233268	d0f2239e4e7ff10144067aa7415ab99e	Diners Club / Carte Blanche	40.6444683303814358	-74.0150994914013864
11799	2020-02-09 23:36:35	2020-02-09	Marley Osinski MD	marley.osinski.md@geemail.com	Huntington Beach	California	869975293398436007	93d65d3c91d17b9b9fa388e5bdfb00b1	JCB 15 digit	33.6037938942242462	-118.038660245820125
11800	2020-02-09 23:46:32	2020-02-09	Kiel Graham	kiel.graham@woohoo.com	San Francisco	California	3045148321221055	a96adf1f5606aeeaa51c2c0395beceb5	Discover	37.7535050125757863	-122.439271939314835
11801	2020-02-09 23:57:49	2020-02-09	Dr. Mell Lebsack MD	dr.mell.lebsack.md@geemail.com	San Francisco	California	54275800244744430	589a8a138c0d578ce756c3dc20ace284	Diners Club / Carte Blanche	37.7551254594622563	-122.415262317353935
11802	2020-02-10 00:03:13	2020-02-10	Sherron Cummerata-Swift	sherron.cummerata.swift@geemail.com	Charlotte	North Carolina	4881041342687	a865034029d10fa08d2a7878f7603f96	VISA 16 digit	35.1545312196735296	-80.8407718368750068
11803	2020-02-10 00:33:14	2020-02-10	Alver Weissnat	alver.weissnat@geemail.com	New York	New York	3096159605382749922	d476e59639153b72df087862f6cf1acb	Voyager	40.6856875435672691	-73.9807664482284366
11804	2020-02-10 00:52:55	2020-02-10	Dr. Valinda Auer	dr.valinda.auer@geemail.com	Louisville	Kentucky	180006322584481313	52e2ac09e8073cf60cc454fb7e45004a	VISA 16 digit	38.1164316350497288	-85.64002427608483
11805	2020-02-10 01:11:04	2020-02-10	Cristopher Flatley MD	cristopher.flatley.md@geemail.com	New York	New York	3468243883426269	6d646d785595d14ba670f8e8e5383499	Mastercard	40.7174214658550895	-73.9016648895934196
11806	2020-02-10 01:17:54	2020-02-10	Dominque Jerde	dominque.jerde@geemail.com	Los Angeles	California	4499603362933029	74c961b6602170e00d3120733e780fe1	Mastercard	34.0405885412223626	-118.369000589660544
11807	2020-02-10 01:24:34	2020-02-10	Azariah Gusikowski	azariah.gusikowski@geemail.com	New York	New York	3447558854162692	0793f771c4d5e79d1bab137f9550cf46	Discover	40.6206309824474161	-73.8409819661069662
11808	2020-02-10 01:31:04	2020-02-10	Authur Paucek	authur.paucek@woohoo.com	Oakland	California	55648700871321843	9b9f591c40cc3fa00ad5203b64201da4	JCB 15 digit	37.8132004271019042	-122.255666512933601
11809	2020-02-10 01:31:09	2020-02-10	Hazel Sawayn	hazel.sawayn@woohoo.com	San Francisco	California	3158006760781685691	99d4aad08a5a2a527e36f85957817296	VISA 13 digit	37.7752762513716291	-122.423275408528667
11810	2020-02-10 01:40:23	2020-02-10	Arabella Mraz DDS	arabella.mraz.dds@geemail.com	Fresno	California	3415734037552640	58d2c8d28528b0c2b32f86230e8d2973	Voyager	36.7572163488589254	-119.818560155817877
11811	2020-02-10 02:05:31	2020-02-10	Hallie Wehner	hallie.wehner@geemail.com	Phoenix	Arizona	676290503124217	bdc3fca3a53d793abcf1aaf1be782183	Voyager	33.5710100575283192	-112.120813389022288
11812	2020-02-10 02:07:28	2020-02-10	Ruthie Luettgen	ruthie.luettgen@geemail.com	Fort Worth	Texas	676262005456751	404627e8107dea785cdde0f0288e0e3e	Diners Club / Carte Blanche	32.8189505200888973	-97.4096400189965976
11813	2020-02-10 02:16:23	2020-02-10	Paityn Wilderman	paityn.wilderman@warmmail.com	Nashville	Tennessee	6011655418498749029	a17e137d93f3527078b9bb5d72bf0f55	Voyager	36.1212549371767793	-86.7027831035572945
11814	2020-02-10 02:29:07	2020-02-10	Blanchard Hyatt	blanchard.hyatt@geemail.com	Sacramento	California	3027629950126325	e39541acb65dbc9d7dd3de871f72695c	American Express	38.549901742654292	-121.515560911201305
11815	2020-02-10 02:36:10	2020-02-10	Dr. Flossie Heathcote PhD	dr.flossie.heathcote.phd@geemail.com	Port St. Lucie	Florida	869973886273612352	e823b6b2e84dc4b7771269b541a972df	Diners Club / Carte Blanche	27.2584458777349425	-80.4735212893776577
11816	2020-02-10 03:00:21	2020-02-10	Mr. Jamaal Johnston V	mr.jamaal.johnston.v@geemail.com	Richmond	California	52207674240988512	d804ad8f885af027d543b0f0c0aa28d7	Diners Club / Carte Blanche	37.9961701083418006	-122.356823512478172
11817	2020-02-10 03:08:47	2020-02-10	Dr. Author Brekke	dr.author.brekke@geemail.com	Irving	Texas	3158304843828414207	65114f204252d214ba8603a48cfe1be4	VISA 13 digit	32.8450455590568495	-96.9181994661968247
11818	2020-02-10 03:29:43	2020-02-10	Dr. Ryder Goyette	dr.ryder.goyette@warmmail.com	Oakland	California	869953046345707623	f5acb8f866575b902eaf65b93c2d2f05	Discover	37.7644748023674666	-122.213522810439301
11819	2020-02-10 03:38:00	2020-02-10	Mr. Lyle Heaney V	mr.lyle.heaney.v@geemail.com	Gilbert	Arizona	180053483054381011	446ffcc592ee9f6da34b2b34b591f4dd	JCB 16 digit	33.2322440563116217	-111.682717361640556
11820	2020-02-10 03:53:43	2020-02-10	Santina Haag	santina.haag@geemail.com	San Francisco	California	53210472019775631	cb5a61eb9360042dba35dc6ff81f82e1	Diners Club / Carte Blanche	37.7213172131180485	-122.415888714449025
11821	2020-02-10 04:04:11	2020-02-10	Dr. Franco Pacocha Jr.	dr.franco.pacocha.jr.@geemail.com	San Francisco	California	4735149799707705	d6d6d536ef77856c41a074b1e985233d	Maestro	37.7595606514873623	-122.427475598539871
11822	2020-02-10 04:17:18	2020-02-10	Lamont Windler	lamont.windler@warmmail.com	Toledo	Ohio	51396906912670015	36735dbc06299bd0f854d4a586d7dcc1	Discover	41.6885761806447022	-83.5074388864781696
11823	2020-02-10 04:33:02	2020-02-10	Aletha Kessler PhD	aletha.kessler.phd@geemail.com	Honolulu	Hawaii	869903584602136806	a9e2c15d05f36da8cc986c229fac27e0	Maestro	21.2520621128130713	-157.859967260223243
11824	2020-02-10 05:42:55	2020-02-10	Sandra Boyer	sandra.boyer@geemail.com	Berkeley	California	3112693197840285841	05ba5368b6e563cccf091a0a0bfff0d7	VISA 16 digit	37.8510430890847402	-122.255307330554743
11825	2020-02-10 05:53:44	2020-02-10	Mark Schmitt	mark.schmitt@geemail.com	Springfield	Missouri	503807665224346	fc3373561114c620ed332422885190d1	American Express	37.1476288886003232	-93.2984969331707816
11826	2020-02-10 06:02:55	2020-02-10	Mrs. Mellissa Fahey	mrs.mellissa.fahey@woohoo.com	San Diego	California	4300732486408292	5b09daaeae3a8a7552dc353183df311b	VISA 16 digit	32.8622748201780013	-117.162091605402537
11827	2020-02-10 06:28:12	2020-02-10	Mr. Jensen Hettinger	mr.jensen.hettinger@woohoo.com	Temecula	California	4481128858414	a36cb7658f305bc1f137fc8956a2b202	VISA 16 digit	33.5329277919273778	-117.099374018768586
11828	2020-02-10 06:39:00	2020-02-10	Aracely Upton	aracely.upton@warmmail.com	San Francisco	California	3158119565373718204	558a89a69740e9af868c0ba49d35f41a	JCB 15 digit	37.7871823334985493	-122.426801858802605
11829	2020-02-10 06:54:31	2020-02-10	Gianna Denesik	gianna.denesik@geemail.com	Murrieta	California	3096816692304020488	674f5f846bf1dbc9397a0f4fcb5e9201	Maestro	33.5309552798610184	-117.197576362676543
11830	2020-02-10 06:59:16	2020-02-10	Tomasa Herzog DDS	tomasa.herzog.dds@geemail.com	Las Vegas	Nevada	4116576557596459	0369df3f73a883ed519d5990fc9396fe	VISA 13 digit	36.2132402472764241	-115.315914781924704
11831	2020-02-10 07:01:24	2020-02-10	Ephriam Stark	ephriam.stark@woohoo.com	Pueblo	Colorado	3088472989246673498	075e915d4acbadc915f2cabe47550396	Diners Club / Carte Blanche	38.2180564838904857	-104.669733315878744
11832	2020-02-10 07:18:03	2020-02-10	Ever Corkery	ever.corkery@woohoo.com	Los Angeles	California	869983535837512701	7f7355e15760a3cd543997d8b66ae303	VISA 16 digit	34.067421703120317	-118.394528175796566
11833	2020-02-10 07:21:14	2020-02-10	Dr. Hadassah Pfannerstill	dr.hadassah.pfannerstill@geemail.com	Berkeley	California	6011177789929835614	9d9f1e8ba2fe362e8572d9cbbfe0c3ab	VISA 16 digit	37.8954538031039192	-122.242414046526619
11834	2020-02-10 07:29:21	2020-02-10	Dr. Joella Schuster	dr.joella.schuster@warmmail.com	Los Angeles	California	4581076893522174	bff74b2ccfc8fb014782d947d7206cb1	JCB 16 digit	33.9883332288689886	-118.373888317168877
11835	2020-02-10 07:29:36	2020-02-10	Alexandria Hirthe	alexandria.hirthe@geemail.com	Lincoln	Nebraska	3528249087431246931	e9ce76dc48d6b2bfdfb858c957b936ba	VISA 16 digit	40.8458480230551189	-96.5880479540836063
11836	2020-02-10 08:58:52	2020-02-10	Shepherd Mitchell	shepherd.mitchell@warmmail.com	Austin	Texas	210019284122725525	1bb343d0f4b6c062b95ce9ad0ab753dd	Maestro	30.3801705652974547	-97.6972895902354281
11837	2020-02-10 09:00:26	2020-02-10	Chancy Mohr Sr.	chancy.mohr.sr.@geemail.com	San Francisco	California	4111974334811272	5564e1ce45a8bdbbc80fa00effd94511	VISA 16 digit	37.7961732935568051	-122.419303034170753
11838	2020-02-10 10:22:16	2020-02-10	Dr. Vern Kub PhD	dr.vern.kub.phd@geemail.com	Berkeley	California	869956953836273527	e1cc959a4496184929f5576dc6205319	Maestro	37.8608241364047231	-122.280373168668575
11839	2020-02-10 11:11:57	2020-02-10	Dr. Emil Corwin Jr.	dr.emil.corwin.jr.@geemail.com	New York	New York	630446775628392	5741c06c68b616495e8c31b91684dde6	Maestro	40.6398814484234876	-73.8527959722455591
11840	2020-02-10 11:56:06	2020-02-10	Kimberley Dare PhD	kimberley.dare.phd@geemail.com	Baltimore	Maryland	869957857572516065	a7b0d445f148fd2cb6eb3edeeb193be4	VISA 13 digit	39.3278205523733035	-76.6171303751897028
11841	2020-02-10 11:56:50	2020-02-10	Gene Krajcik	gene.krajcik@geemail.com	Atlanta	Georgia	4694688105444	359bb050a28cb85ed9238a2c2079f637	JCB 16 digit	33.7044120251476755	-84.4785287234511344
11842	2020-02-10 12:19:43	2020-02-10	Elby Bauch	elby.bauch@geemail.com	Ventura	California	3446976031464354	58e3082765fb8d71a792cc2f95d1c570	VISA 13 digit	34.1934707184016702	-119.169484229349337
11843	2020-02-10 12:39:59	2020-02-10	Dr. Benard Cummerata	dr.benard.cummerata@geemail.com	San Francisco	California	210001247248961977	c69d656152c29a08830ff9d7d9628836	VISA 16 digit	37.7615494708635921	-122.441946780724521
11844	2020-02-10 12:46:03	2020-02-10	Belen Gaylord	belen.gaylord@geemail.com	Chicago	Illinois	54573934428452731	50627425a6730bea2bbfb95ba3943ec8	Maestro	41.8989009112887132	-87.6819694355159953
11845	2020-02-10 12:52:42	2020-02-10	Ottie Lynch	ottie.lynch@geemail.com	Downey	California	869933767553487567	42eca5b98e66394d9e143d03c3693156	Mastercard	33.8404657415363985	-118.215249189652127
11846	2020-02-10 13:22:52	2020-02-10	Jerrold Moen	jerrold.moen@geemail.com	Orlando	Florida	3029653137456627	b4676a683857a487a9d7973a8ffc4382	VISA 16 digit	28.4921416301544745	-81.1889893323149607
11847	2020-02-10 13:35:29	2020-02-10	Lanita Bins	lanita.bins@geemail.com	Providence	Rhode Island	4873320541575391	0229fd7f5d52fd2dedd20c2234af89ec	Maestro	41.7867771652847466	-71.4825878055684285
11848	2020-02-10 13:45:08	2020-02-10	Weston Zboncak	weston.zboncak@geemail.com	Oklahoma City	Oklahoma	3740281525179907	92dd1cf4e4adec1647051d3cfda539ca	Voyager	35.5653723886612809	-97.478019856045762
11849	2020-02-10 14:04:09	2020-02-10	Mikel Bins-Muller	mikel.bins.muller@geemail.com	Chicago	Illinois	6011737575472439687	8d8c8e644d45cf27d8a87d1a22a467b0	VISA 16 digit	41.7432368052028124	-87.7708049096662535
11850	2020-02-10 14:15:25	2020-02-10	Jeremie Johnston-Volkman	jeremie.johnston.volkman@geemail.com	San Francisco	California	6011539592311528018	86a0e3bcec0db32040db1b454653c289	American Express	37.7985901908221962	-122.420294769753838
11851	2020-02-10 14:19:38	2020-02-10	Kazuo Zemlak	kazuo.zemlak@warmmail.com	New York	New York	4494145935743	e28fc3cd5ef04b0629219149a4e0469b	Discover	40.6121535551957749	-73.9749371716182651
11852	2020-02-10 14:24:21	2020-02-10	Jeromy Kuhlman Jr.	jeromy.kuhlman.jr.@geemail.com	San Francisco	California	4215701413369111	5ab3a08eb403271b6eda8c1b487f9b32	VISA 16 digit	37.7628827708592141	-122.45194410036521
11853	2020-02-10 14:31:34	2020-02-10	Dr. Ember Crist DVM	dr.ember.crist.dvm@geemail.com	New York	New York	4686442659366236	dd5ca4d1dad6abf226776aff5bd52ba7	Discover	40.6795302214790127	-73.8631923934340477
11854	2020-02-10 14:48:37	2020-02-10	Darrien Corwin	darrien.corwin@geemail.com	New York	New York	4994625941152631	f7c1653e89834a99f7de19ae1a30b8b4	Voyager	40.619563291989266	-73.9770950465824484
11855	2020-02-10 15:06:00	2020-02-10	Ivy White	ivy.white@geemail.com	Austin	Texas	3494420314934032	a305298ecb67060ed3164c471ef96925	Voyager	30.2623680245257916	-97.7945638137176729
11856	2020-02-10 15:07:29	2020-02-10	Dr. Geary Runolfsdottir	dr.geary.runolfsdottir@geemail.com	Oakland	California	3410623987757934	9e10f7da31f4a44e7bf9ead0fa1ec680	Maestro	37.786413076196709	-122.269871210245597
11857	2020-02-10 15:28:18	2020-02-10	Rayan Weimann	rayan.weimann@geemail.com	Westminster	Colorado	4461345601454565	3b89a54bfc8a3b896555bf90b52dc05a	American Express	39.9752298843420988	-105.11267828891576
11858	2020-02-10 15:32:37	2020-02-10	Stevan O'Reilly	stevan.o'reilly@warmmail.com	San Diego	California	4139244119745	10620cc4feac93c67dcff7adb7521963	VISA 13 digit	32.7612717283956698	-117.087314533479514
11859	2020-02-10 15:33:21	2020-02-10	Autumn Klein	autumn.klein@geemail.com	Berkeley	California	869932482101286906	e99e55c4a52650a36583a27fbf33fa83	JCB 15 digit	37.8607024489177135	-122.269026255350042
11860	2020-02-10 15:43:27	2020-02-10	Yazmin Davis DVM	yazmin.davis.dvm@woohoo.com	New York	New York	3734533025945981	63f9755215dd632228096ecb17ecb0f9	JCB 15 digit	40.6497302304245522	-74.0240627821430479
11861	2020-02-10 16:12:41	2020-02-10	Kayleigh Block-Mills	kayleigh.block.mills@geemail.com	Santa Clarita	California	4054189049973	bcea2d02b182ad0bcd004ce7b4500461	JCB 16 digit	34.3722946139723078	-118.433726142729441
11862	2020-02-10 16:13:25	2020-02-10	Dr. Victor Kling Jr.	dr.victor.kling.jr.@geemail.com	Port St. Lucie	Florida	4595867686815286	a408ce13edd62171f87e97b82284485f	JCB 15 digit	27.2678514411341411	-80.3213705376807638
11863	2020-02-10 16:19:57	2020-02-10	Odalys Brown	odalys.brown@geemail.com	Las Vegas	Nevada	4452539452367220	c54e04470290e9a22c64f4ccbffac6a5	VISA 16 digit	36.2555044714927632	-115.242778109640255
11864	2020-02-10 16:20:28	2020-02-10	Dozier Keebler Sr.	dozier.keebler.sr.@geemail.com	St. Petersburg	Florida	4944211327223048	5795992b036792393627478096cee767	Diners Club / Carte Blanche	27.7864330293498938	-82.6722394061632428
11865	2020-02-10 16:30:49	2020-02-10	Presley Dare	presley.dare@woohoo.com	Little Rock	Arkansas	869902895431895326	89be785974e7ad5681f55cf5543207d6	Maestro	34.7448833837449556	-92.4068918853405847
11866	2020-02-10 16:54:03	2020-02-10	Charley Hoppe MD	charley.hoppe.md@geemail.com	Davie	Florida	210005674864231102	c201144df4ce503f373c6e4c74da6b2d	JCB 16 digit	26.1509171248678136	-80.3595425551198446
11867	2020-02-10 17:04:10	2020-02-10	Kattie Torp DDS	kattie.torp.dds@geemail.com	San Diego	California	4404990278917	f567296dfcd5a1c1bea3bb1e61f3a95e	Discover	32.7224927040349698	-117.162789031481381
11868	2020-02-10 17:12:10	2020-02-10	Marge Homenick	marge.homenick@geemail.com	Fayetteville	North Carolina	6011246552629745435	4443a6063226b579c3f8a91efded4c53	Diners Club / Carte Blanche	35.0070783162277195	-78.8901484005749296
11869	2020-02-10 17:43:33	2020-02-10	Dave Champlin-Wunsch	dave.champlin.wunsch@geemail.com	New York	New York	869963880103803127	162b43d1be9d01b23cc1ef347cb6dfb9	Maestro	40.7593907202817505	-73.8729983680311619
11870	2020-02-10 18:09:44	2020-02-10	Michal Heller	michal.heller@geemail.com	San Francisco	California	4250503224066	8f44d90959fc7b2fd3471236a09d1b6e	Diners Club / Carte Blanche	37.7751141950978422	-122.440167185443883
11871	2020-02-10 18:17:24	2020-02-10	Jeanna Russel-Pouros	jeanna.russel.pouros@geemail.com	Las Vegas	Nevada	3088149949806340253	c4b65f00317baf7477005534681d2546	Mastercard	36.2927188511107133	-115.258908853328222
11872	2020-02-10 19:11:13	2020-02-10	Mrs. Merle Schoen DDS	mrs.merle.schoen.dds@geemail.com	Aurora	Colorado	53750130146127045	f1b0e65f50a280b02687032bf7dac89c	VISA 16 digit	39.7668645945955106	-104.688316379732271
11873	2020-02-10 19:19:08	2020-02-10	Mr. Diallo Weber DDS	mr.diallo.weber.dds@geemail.com	Indianapolis	Indiana	52225665947457023	687ae43458b2dfa9a44f9f50c25e2481	Voyager	39.7065594979103622	-86.0542207448944367
11874	2020-02-10 19:35:31	2020-02-10	Efrain Nitzsche	efrain.nitzsche@woohoo.com	West Jordan	Utah	4074119841323	df57006f453dfbd7d19810cd7527ab95	Mastercard	40.5933102013334661	-111.914991610040147
11875	2020-02-10 19:38:24	2020-02-10	Shannon Auer	shannon.auer@warmmail.com	San Francisco	California	4242344711599795	274caf780e4f494a55e6472c456fd176	VISA 16 digit	37.761370285213502	-122.411235325928871
11876	2020-02-10 19:47:17	2020-02-10	Burton Breitenberg	burton.breitenberg@geemail.com	Tampa	Florida	4975504604086	4f33f8b9cc105fe96fe5eabbd537ea57	Diners Club / Carte Blanche	27.8827927142031484	-82.5548589311752465
11877	2020-02-10 19:57:19	2020-02-10	Brittny Roberts	brittny.roberts@geemail.com	Sandy Springs	Georgia	4289924017094957	a7c946099f5bdb8787487d2096d8b663	JCB 16 digit	34.0249169779065994	-84.4411595475941965
11878	2020-02-10 20:02:13	2020-02-10	Lyla Kris DDS	lyla.kris.dds@woohoo.com	San Francisco	California	4890864275846535	c5f7b158124d2d18949308143c4ceec5	Discover	37.7681402828749455	-122.385917623623044
11879	2020-02-10 20:25:38	2020-02-10	Dylan Bauch	dylan.bauch@woohoo.com	Atlanta	Georgia	3337905594138582406	78cff791528dc107d59e51a7cfe64519	VISA 16 digit	33.8605031159516443	-84.4022150020159785
11880	2020-02-10 20:38:31	2020-02-10	Gearldine Wuckert	gearldine.wuckert@geemail.com	Cape Coral	Florida	3088293051237317374	d21ae91c34b27e6f5d8bbcd4bdb440d4	VISA 16 digit	26.6933822486054169	-82.0437150130584882
11881	2020-02-10 20:48:07	2020-02-10	Miss Darcie Becker PhD	miss.darcie.becker.phd@geemail.com	Bakersfield	California	4789428853300267	0dce43922c8bfbe80db9f6e8c0d77d40	JCB 16 digit	35.2564303389459823	-119.086399044542759
11882	2020-02-10 20:56:40	2020-02-10	Erin Tremblay	erin.tremblay@geemail.com	Fremont	California	4714547377716425	8ea63cd4d541dd44df3645c07c28417a	Diners Club / Carte Blanche	37.4243720400314785	-121.866681380661944
11883	2020-02-10 21:18:59	2020-02-10	Xena Osinski	xena.osinski@geemail.com	Tyler	Texas	210039316836915996	5a308e88867b8b568a30bd604dd5e71a	Mastercard	32.3851951654117585	-95.274445694928616
11884	2020-02-10 21:30:12	2020-02-10	Latesha Kub MD	latesha.kub.md@warmmail.com	Kansas City	Missouri	180075851308152020	0eb6719159d8541aaf93f223202ca51d	JCB 15 digit	39.2073742830030625	-94.5152115421593209
11885	2020-02-10 21:34:28	2020-02-10	Stephanie Lynch	stephanie.lynch@geemail.com	Houston	Texas	3710773687596700	14bef3418d1fe023546e5c1e9dfee2d7	Diners Club / Carte Blanche	29.853153563391789	-95.412525031484293
11886	2020-02-10 21:35:01	2020-02-10	Harman Parisian	harman.parisian@geemail.com	Corona	California	4463749243731835	3ba37cbc212ec94dc2f66e18bfef102a	VISA 16 digit	33.8000500839091842	-117.559396266492087
11887	2020-02-10 21:41:01	2020-02-10	Elenor Schuppe-Sporer	elenor.schuppe.sporer@woohoo.com	San Francisco	California	3528798599653921921	d34108938a88b8bb422e3cf6d2294d0c	American Express	37.7758465752076518	-122.441082952180466
11888	2020-02-10 21:43:31	2020-02-10	Jamya Kertzmann MD	jamya.kertzmann.md@geemail.com	San Diego	California	869990606159904700	2b2be45207302a387480b0ea1c461a23	JCB 16 digit	32.8981197482973329	-117.064632170964032
11889	2020-02-10 22:07:26	2020-02-10	Viridiana Bernhard	viridiana.bernhard@geemail.com	Los Angeles	California	3112301286494983472	d2519dd3837935bd9f70f0fc3e9ed178	VISA 16 digit	34.0395998129952702	-118.406582394008709
11890	2020-02-10 23:05:05	2020-02-10	Julius Gerlach	julius.gerlach@geemail.com	Dallas	Texas	4939243247563721	e3805c8cb0064932eeb808dce2d5129f	JCB 15 digit	32.8270641295976944	-96.8457123366147243
11891	2020-02-10 23:11:55	2020-02-10	Sariah Schulist	sariah.schulist@woohoo.com	Bakersfield	California	869913887524565517	b14344477136735f7f46df0c405bcf50	Diners Club / Carte Blanche	35.3135601390793923	-119.117679219906407
11892	2020-02-10 23:12:26	2020-02-10	Keyon Rosenbaum-Parker	keyon.rosenbaum.parker@warmmail.com	San Francisco	California	3096177215920180990	f8cfa2636c11ba2732ebc8362b430c1f	Diners Club / Carte Blanche	37.7738907348410535	-122.403684314408707
11893	2020-02-10 23:43:04	2020-02-10	Robin Collins	robin.collins@geemail.com	Oceanside	California	3528568545620883684	eeca449d33f592f416ec092dc9ad4b67	VISA 13 digit	33.2981162936780564	-117.322645839684455
11894	2020-02-10 23:46:38	2020-02-10	Hallie Stoltenberg	hallie.stoltenberg@woohoo.com	San Francisco	California	4198421695138107	25a9c97af63374400eef5f91f828f1d4	JCB 16 digit	37.7822898722157277	-122.469075717607382
11895	2020-02-10 23:55:54	2020-02-10	Verda Beer	verda.beer@geemail.com	San Francisco	California	51604736428193642	73f1218c25e339ed24c73b93afa84ab2	VISA 13 digit	37.7572925513140376	-122.462924501546496
11896	2020-02-11 00:01:22	2020-02-11	Duard Bosco	duard.bosco@geemail.com	San Francisco	California	54923440733721700	6840413b284d4b4eec1754f7def154a2	VISA 16 digit	37.7743393072469544	-122.407452102519329
11897	2020-02-11 00:06:32	2020-02-11	Myrta Hintz	myrta.hintz@geemail.com	San Francisco	California	4120469406751	21f937d0566a19aa6cee3e45727cea5e	Discover	37.7578760110381424	-122.416905362402943
11898	2020-02-11 00:23:11	2020-02-11	Alexia Mante MD	alexia.mante.md@geemail.com	San Francisco	California	3112412003807824251	b98dd2572acb061adacdc5f3d5fd191f	Mastercard	37.7747469107978304	-122.440216293279335
11899	2020-02-11 00:37:56	2020-02-11	Jeanie Zemlak	jeanie.zemlak@geemail.com	Syracuse	New York	4483449740875	386cccbc089413e1f5a11462e91d50d9	VISA 16 digit	43.1141473786756393	-76.2394542506210513
11900	2020-02-11 00:39:00	2020-02-11	Lisandro Schimmel-Hammes	lisandro.schimmel.hammes@geemail.com	San Diego	California	3034556747494703	a1b86b7a8efa2ffe31eb03a11e0e31bd	Mastercard	32.8255109662257141	-117.127784328386198
11901	2020-02-11 00:45:05	2020-02-11	Lindsay Littel	lindsay.littel@geemail.com	Tucson	Arizona	210062639827508797	79cdf64e2a05823236786f50b61a35e4	American Express	32.0575824636075666	-110.945127317145833
11902	2020-02-11 01:06:43	2020-02-11	Zina Stiedemann	zina.stiedemann@geemail.com	San Francisco	California	4698876155806	6f704ba8f3aec88552244f30b36dbec9	VISA 16 digit	37.7767192892114068	-122.389837717701312
11903	2020-02-11 01:15:06	2020-02-11	Asia Ziemann	asia.ziemann@geemail.com	Tulsa	Oklahoma	6011714626494894073	0d3028fb905e1de56741cc6a928c6cc6	Discover	36.0499508882310238	-95.8484459202226162
11904	2020-02-11 01:31:00	2020-02-11	Ms. Hortensia O'Keefe	ms.hortensia.o'keefe@geemail.com	Oakland	California	4457593666729241	ebc44b8a814af522f21d5ecd1905cff0	VISA 16 digit	37.8060885259036326	-122.268703092896914
11905	2020-02-11 01:32:25	2020-02-11	Mr. Gonzalo Koch	mr.gonzalo.koch@geemail.com	Phoenix	Arizona	4321437280768769	8592c86e02923f3f24bca431fc12be9f	VISA 16 digit	33.6063269335709549	-112.136394795814908
11906	2020-02-11 01:50:07	2020-02-11	Emiliano Green	emiliano.green@geemail.com	Athens	Georgia	4478164947614	014b01094b0b4442f86a0fd4d57cbc17	Voyager	33.8832879716254709	-83.4437971115227697
11907	2020-02-11 02:08:08	2020-02-11	Burr Anderson	burr.anderson@geemail.com	Albuquerque	New Mexico	6011137504113840851	e13428b6a66b6efbeeaa6d8f14aca32e	Discover	35.1254404585942623	-106.733290324227511
11908	2020-02-11 02:47:03	2020-02-11	Mae Pacocha	mae.pacocha@woohoo.com	Ontario	California	210003097300727867	3b26bf7e3f76f4fe237272e7b9bb934e	JCB 16 digit	33.9485017038561381	-117.595072018784293
11909	2020-02-11 03:08:54	2020-02-11	Warren Mohr	warren.mohr@geemail.com	Henderson	Nevada	6011115738928787776	8c229d22f075fb1094acb69a74508598	Discover	35.9498970767881758	-115.085159035601478
11910	2020-02-11 03:21:32	2020-02-11	Carly Howell-Gaylord	carly.howell.gaylord@geemail.com	Atlanta	Georgia	869962538795011224	412c808ba4b22a2637977fe1cfbf146f	JCB 16 digit	33.6935835439056177	-84.5146693992007556
11911	2020-02-11 04:00:19	2020-02-11	Tricia Spencer	tricia.spencer@geemail.com	San Antonio	Texas	3096157149799386731	d57b0a587f118c8d6643e387de993ead	Diners Club / Carte Blanche	29.3877354396577921	-98.5708029607612559
11912	2020-02-11 04:26:06	2020-02-11	Sonia Hessel	sonia.hessel@geemail.com	Oakland	California	4883852922286501	c531056c92d13b1de7091b211e08e4b0	Maestro	37.7760293380848395	-122.255371465945103
11913	2020-02-11 04:35:30	2020-02-11	Rettie Cormier	rettie.cormier@geemail.com	Oklahoma City	Oklahoma	52728046637398201	d911136972b2af2454169c9bf534660c	American Express	35.4954839199226342	-97.5056122031424195
11914	2020-02-11 05:24:15	2020-02-11	Polk Deckow	polk.deckow@warmmail.com	San Francisco	California	3015298765554659	8084b8c2ee2478899393e3a391aec91d	American Express	37.745894245853215	-122.404970213802287
11915	2020-02-11 05:34:13	2020-02-11	Ancil Roob	ancil.roob@geemail.com	San Francisco	California	180030198806783953	aa1acd55a23e19a60a6fdb8145e2792c	Voyager	37.784994301080431	-122.416678237022651
11916	2020-02-11 05:37:47	2020-02-11	Mr. Rick Adams Jr.	mr.rick.adams.jr.@geemail.com	San Francisco	California	4237026560480	76e801b9ac924a229862c4864fb0facc	JCB 16 digit	37.7621652271987998	-122.437860610880165
11917	2020-02-11 05:56:54	2020-02-11	Mr. Slade Tremblay	mr.slade.tremblay@warmmail.com	San Francisco	California	869978175385174187	80611a56e58b39ea196abd2159d6af3b	Maestro	37.7594139554959867	-122.436500932955894
11918	2020-02-11 06:02:03	2020-02-11	Windell Hansen	windell.hansen@warmmail.com	Murfreesboro	Tennessee	3056955844219765	d97ec3d059b7a4a4720c776788bea3be	VISA 13 digit	35.8218840969379997	-86.3172556114234055
11919	2020-02-11 06:06:12	2020-02-11	Dr. Theadore Collier MD	dr.theadore.collier.md@geemail.com	Peoria	Arizona	4349399939280	29df7af9dee4b80c1950d51c616c48d9	American Express	33.8371003210347183	-112.389107707601042
11920	2020-02-11 06:09:05	2020-02-11	Johnna Nikolaus	johnna.nikolaus@geemail.com	New Orleans	Louisiana	4685608538839	994a77637c4439b1903956ac4950cf44	Diners Club / Carte Blanche	30.0221315875198691	-89.909789306649941
11921	2020-02-11 06:22:14	2020-02-11	Lilliana Willms	lilliana.willms@geemail.com	Arlington	Texas	180090756934961721	bfc04f96e1a197168b92b767432a0f38	VISA 16 digit	32.6607877334363721	-97.1111777800627038
11922	2020-02-11 06:25:10	2020-02-11	Mrs. Jayme Gaylord	mrs.jayme.gaylord@geemail.com	Long Beach	California	55296340731228428	854067e443b4a0d5110739db67a60195	JCB 16 digit	33.766493430576098	-118.119726600420847
11923	2020-02-11 06:55:08	2020-02-11	Carla O'Hara	carla.o'hara@geemail.com	Austin	Texas	4587097488505386	cf1577f9a73a86a45a5d93d4d5c8066d	JCB 16 digit	30.402569006489216	-97.7042233695980258
11924	2020-02-11 07:04:48	2020-02-11	Laila Grimes-Mosciski	laila.grimes.mosciski@geemail.com	Baltimore	Maryland	4444748294593940	4ea299992f16c140600bb8e4189c6dab	Discover	39.2495256411842988	-76.6347148637305935
11925	2020-02-11 07:24:38	2020-02-11	Brittny Watsica	brittny.watsica@geemail.com	Norfolk	Virginia	3407089149697639	95c0883f463c6833cb4cf753f85294b5	Maestro	36.841784103076904	-76.1456561984498137
11926	2020-02-11 07:47:59	2020-02-11	Kanye Grimes	kanye.grimes@geemail.com	San Francisco	California	3088345771140222829	6961faa1597801e382bfec178d74d4cf	Discover	37.7923783474662827	-122.445838173543237
11927	2020-02-11 07:58:56	2020-02-11	Liliana Bins-Gutkowski	liliana.bins.gutkowski@geemail.com	Milwaukee	Wisconsin	3158590551055693103	81ecd180ee3c7a595eeb17913021aa75	Discover	43.0750662767879646	-88.0565025412578137
11928	2020-02-11 08:05:13	2020-02-11	Slade Morissette	slade.morissette@warmmail.com	Chattanooga	Tennessee	3001457466924405	f52ad562462b3638969fb3ecc96a339e	Voyager	35.015091336037969	-85.2828942127820113
11929	2020-02-11 08:20:40	2020-02-11	Conway Lockman III	conway.lockman.iii@geemail.com	Los Angeles	California	3528402171786770100	af771e818c5b68e5de03f05369d6859c	VISA 16 digit	34.0373440283682172	-118.320132591155541
11930	2020-02-11 08:30:58	2020-02-11	Lynsey McKenzie-Hirthe	lynsey.mckenzie.hirthe@warmmail.com	San Francisco	California	180099813104627722	541258cbf9741ab689c94fd9af9c7467	JCB 16 digit	37.8043789040501892	-122.421756305293698
11931	2020-02-11 08:32:22	2020-02-11	Othel Casper	othel.casper@geemail.com	Winston–Salem	North Carolina	6011252992404009048	63b9c1af9b6f8b0b32cadaf5f1953ce6	Maestro	36.2007288933031219	-80.3412867603953913
11932	2020-02-11 08:47:48	2020-02-11	Rolla Hartmann-Kulas	rolla.hartmann.kulas@woohoo.com	Los Angeles	California	503837221277009	b12ccb12fb646f3c120e3205f19de0cf	Diners Club / Carte Blanche	34.0303220137819622	-118.422772835427139
11933	2020-02-11 09:44:20	2020-02-11	Sheila Wyman	sheila.wyman@geemail.com	San Antonio	Texas	4926767646121199	1b005dd475fc4bf894960b67319e5d79	VISA 16 digit	29.4876749093249444	-98.5536254925023769
11934	2020-02-11 10:38:27	2020-02-11	Amos Dickens IV	amos.dickens.iv@geemail.com	Los Angeles	California	869998225303501148	f592d4fa011f23a72a0bbee473f1deb5	Voyager	34.0211390473280062	-118.390155721734459
11935	2020-02-11 10:49:23	2020-02-11	Pam Gerhold	pam.gerhold@geemail.com	San Francisco	California	3158837896849820543	6e16cd7f56507e98c4cfb6f63a653c89	Mastercard	37.7605303168964284	-122.394350669072736
11936	2020-02-11 10:50:22	2020-02-11	Dr. Lafayette Nitzsche	dr.lafayette.nitzsche@warmmail.com	San Diego	California	3528390802327471998	8f55c7136140743c44ce116710bd10c3	JCB 16 digit	32.865048398223891	-117.220845033405354
11937	2020-02-11 10:53:07	2020-02-11	Erby Trantow	erby.trantow@woohoo.com	Minneapolis	Minnesota	6011419672434394715	2ccdd6abd6cd5eaf8de2ad6e5b38aa35	JCB 16 digit	45.0382126723036151	-93.2313263178609333
11938	2020-02-11 11:00:24	2020-02-11	Kiley Kshlerin	kiley.kshlerin@geemail.com	Baltimore	Maryland	3459400100367939	e2868691f237531214b0a12c0e55806d	VISA 16 digit	39.2608047948684487	-76.6908166843019501
11939	2020-02-11 11:07:33	2020-02-11	Elizebeth Schaden	elizebeth.schaden@warmmail.com	San Francisco	California	869949029037493212	3ca28eb3596d8ac9d5d719ac020be7f5	JCB 16 digit	37.7421566390332117	-122.446562082327375
11940	2020-02-11 11:21:21	2020-02-11	Wilfred Trantow	wilfred.trantow@geemail.com	San Francisco	California	3404141210362917	21d39fb00edb31d8e61eda8d5448668b	JCB 16 digit	37.7714485690379504	-122.459862148787209
11941	2020-02-11 11:31:13	2020-02-11	Shardae Bechtelar	shardae.bechtelar@geemail.com	New York	New York	3528631782317187581	9af4e7018ccefafdf629b7c7ea7084f7	VISA 13 digit	40.6544720628056666	-73.9727316319372505
11942	2020-02-11 11:46:38	2020-02-11	Janie Kessler	janie.kessler@woohoo.com	Colorado Springs	Colorado	180045338522883728	881417158a46ab1d6b8aea8d913a5e89	VISA 13 digit	38.8015380956280964	-104.735382579888025
11943	2020-02-11 11:47:28	2020-02-11	Ally Effertz-Ryan	ally.effertz.ryan@warmmail.com	Los Angeles	California	869955772585455486	eb1534eb8e7b29cc0943a7a9f5ad63a1	VISA 16 digit	34.0093785337504002	-118.434982057892896
11944	2020-02-11 12:12:16	2020-02-11	Neva Lowe	neva.lowe@geemail.com	Oakland	California	4929074846149774	2b3ab5848e23c5649b4d7f56c1570041	VISA 13 digit	37.7955912021528988	-122.277533519157444
11945	2020-02-11 12:17:56	2020-02-11	Makena King	makena.king@woohoo.com	Miramar	Florida	4074022133677	0362f0ce6b709d55cb818c5975563791	Mastercard	26.0577700627949085	-80.4307002573266629
11946	2020-02-11 12:26:12	2020-02-11	Wiliam Daniel	wiliam.daniel@woohoo.com	Oakland	California	869975893649832159	fef4730daace9c4ec50782a5abbe2d60	VISA 13 digit	37.8438882090703501	-122.247990441521821
11947	2020-02-11 12:41:09	2020-02-11	Vidal Larkin	vidal.larkin@woohoo.com	High Point	North Carolina	3096773456443726335	c9650de0199674bd7582e1a17ae3ea4b	JCB 16 digit	36.0895505082421053	-79.9981768304221248
11948	2020-02-11 12:54:11	2020-02-11	Randy Zboncak I	randy.zboncak.i@geemail.com	Santa Rosa	California	6011187287956429946	6c03ee60692d9ee5742853da077bd5f5	Maestro	38.537434895442054	-122.735528063798697
11949	2020-02-11 13:20:59	2020-02-11	Tyron Ruecker	tyron.ruecker@warmmail.com	San Antonio	Texas	3112667128817025151	e01b5357f20e07427c7f128b736fb1c9	VISA 13 digit	29.4249628630537536	-98.4622508985292058
11950	2020-02-11 13:35:05	2020-02-11	Dr. Will Renner V	dr.will.renner.v@geemail.com	Chicago	Illinois	676128897889060	331ee4ad56597f5686d04bf946ea39e7	VISA 13 digit	41.8063714679632383	-87.6934052926052345
11951	2020-02-11 13:57:49	2020-02-11	Manerva Bernhard	manerva.bernhard@geemail.com	Oakland	California	3492858057197337	2f2c6c193e854674f8198b4212be0ab5	Diners Club / Carte Blanche	37.7883207887930013	-122.293715404413533
11952	2020-02-11 14:22:39	2020-02-11	Gene Roberts-Luettgen	gene.roberts.luettgen@woohoo.com	New York	New York	4142838337544227	16f9d4255d96cb4413259e3a7e3043ec	VISA 13 digit	40.6891407584063671	-73.9767111851729453
11953	2020-02-11 14:24:54	2020-02-11	Edyth Prohaska	edyth.prohaska@geemail.com	Vallejo	California	4207960731835175	783940f7082b9a8abaec3fe411a0fd04	VISA 13 digit	38.1464895146988354	-122.166297407854344
11954	2020-02-11 14:25:37	2020-02-11	Miss Tameka Kulas	miss.tameka.kulas@geemail.com	Minneapolis	Minnesota	4897328791438	32b2e29e0d4d0e3f97fbebf1d0be448e	VISA 16 digit	44.9244674615647597	-93.3628298077538545
11955	2020-02-11 14:32:30	2020-02-11	Cleve Hilll Sr.	cleve.hilll.sr.@woohoo.com	Bakersfield	California	3401070218759035	6d0c0f22922c825b2b6f3b4e95e684d7	Mastercard	35.2437352311972489	-118.94040214319638
11956	2020-02-11 14:42:16	2020-02-11	Drusilla Hoppe-Johns	drusilla.hoppe.johns@geemail.com	Fayetteville	North Carolina	4802928478015896	0aa0fe7ca7cebea7154f8f1d378821b1	VISA 16 digit	35.1154687759254145	-78.8816754053011522
11957	2020-02-11 14:45:26	2020-02-11	Roswell Schuster	roswell.schuster@warmmail.com	Palmdale	California	4020192673249950	0886509ad740cc285061fa802f657974	JCB 16 digit	34.5120339301731462	-118.011360655817768
11958	2020-02-11 14:50:55	2020-02-11	Emanuel Quitzon	emanuel.quitzon@geemail.com	Kansas City	Missouri	4070639169666	3a56f2e80fe6b43d9620d019ee279a11	Voyager	39.0960046218544264	-94.4997336549907914
11959	2020-02-11 15:08:30	2020-02-11	Prudence Thompson	prudence.thompson@woohoo.com	Phoenix	Arizona	3005559682228473	dc24013aa4861057d515338d5f2f96ab	VISA 13 digit	33.5634702338304365	-112.11471787504145
11960	2020-02-11 15:17:52	2020-02-11	Ms. Gwenda Pfannerstill	ms.gwenda.pfannerstill@warmmail.com	San Francisco	California	4190294258597870	3e6a2c7650cffa514207d1d7065213b2	Maestro	37.7590319787691655	-122.439826348623001
11961	2020-02-11 15:23:21	2020-02-11	Marguerite Lueilwitz	marguerite.lueilwitz@warmmail.com	Woodbridge	New Jersey	6011155920169931153	f5156a9a34f0dc6f021c481bada6afe8	Diners Club / Carte Blanche	40.5121389765448825	-74.2248806638967267
11962	2020-02-11 15:23:41	2020-02-11	Blaise Lakin	blaise.lakin@woohoo.com	New Orleans	Louisiana	210068409261807004	11c5dec4fddbd1bcf30c778af673e5e8	JCB 16 digit	30.0487782713506384	-89.9973483045846194
11963	2020-02-11 15:58:32	2020-02-11	Kellee Beatty-Steuber	kellee.beatty.steuber@geemail.com	San Francisco	California	675910667946023	00e62e15122ab83e1c009f2f6be7cfd7	Voyager	37.7620696165917877	-122.423276740378867
11964	2020-02-11 16:22:12	2020-02-11	Leif Powlowski	leif.powlowski@woohoo.com	Phoenix	Arizona	3467746101509659	ce7ec9e864021b7c563ff06e79b2a1fa	Maestro	33.5366047146663107	-112.011760419832925
11965	2020-02-11 16:23:22	2020-02-11	Mr. Egbert Turcotte DDS	mr.egbert.turcotte.dds@warmmail.com	Rockford	Illinois	4265115901554	f75075a4059ff6006c11927321eb3d95	Voyager	42.2879993027087338	-89.0093939629200861
11966	2020-02-11 16:41:06	2020-02-11	Dr. Deane Denesik DDS	dr.deane.denesik.dds@woohoo.com	Ventura	California	54705907450318724	bc7ffbc43fc9fc82a8f4d9e1df531a55	JCB 16 digit	34.2361131881523875	-119.342918600291753
11967	2020-02-11 16:46:39	2020-02-11	Dr. Simon Prosacco	dr.simon.prosacco@woohoo.com	Norfolk	Virginia	4543915158868	3b06459f38a9c1723f25d3f338314e9e	American Express	36.8818115246035205	-76.1698581938635613
11968	2020-02-11 17:21:12	2020-02-11	Dr. Deron Gottlieb	dr.deron.gottlieb@warmmail.com	Waterbury	Connecticut	210057322808716633	5d98ea2556dad2deb99e4dc861471ef5	VISA 16 digit	41.5857174847312265	-73.1273226969789647
11969	2020-02-11 17:26:30	2020-02-11	Steward Gorczany	steward.gorczany@geemail.com	Berkeley	California	3002832945119331	5ed215e7617f73da45823d6c6387df45	Mastercard	37.8879551964493828	-122.289957008566645
11970	2020-02-11 17:28:55	2020-02-11	Rudy Mante	rudy.mante@woohoo.com	San Francisco	California	3759771249871498	ae84b6d5e41c158419727721ed9e4083	VISA 16 digit	37.7691061310534906	-122.425571006590275
11971	2020-02-11 18:59:27	2020-02-11	Olive Stanton	olive.stanton@geemail.com	Anchorage	Alaska	4364491371475733	20dbe09ccd5b7e117cba82083cc9f70c	VISA 16 digit	61.1960836872208915	-149.379370195570601
11972	2020-02-11 19:33:40	2020-02-11	Joselin Abernathy	joselin.abernathy@geemail.com	Vancouver	Washington	4357704918616471	8ef163ae0650e59c42cb0bcde56deb50	Diners Club / Carte Blanche	45.7063071914087971	-122.502446616167944
11973	2020-02-11 19:35:29	2020-02-11	Melinda Schimmel	melinda.schimmel@geemail.com	Washington	District of Columbia	52503656675341219	30908e6f03911fc249de2971c38b2026	JCB 15 digit	38.9419698232118066	-76.9341809774030025
11974	2020-02-11 19:42:35	2020-02-11	Dustyn Flatley	dustyn.flatley@geemail.com	Memphis	Tennessee	6011817688589226609	a64cc42251e16930941021eea310e94c	VISA 16 digit	35.0936527101390112	-89.9279982451140967
11975	2020-02-11 19:43:55	2020-02-11	Jax Wilderman	jax.wilderman@geemail.com	Newport News	Virginia	3337267977127097027	28519be3739091392af614a1c5e9ee7d	Discover	36.9814657296415419	-76.5129838363993997
11976	2020-02-11 20:19:45	2020-02-11	Adele Cronin	adele.cronin@geemail.com	San Bernardino	California	869939837140189648	c7bcf87001fa831a595de6045c4be421	Discover	34.1190279606994196	-117.326804365009437
11977	2020-02-11 20:33:43	2020-02-11	Keira Corwin	keira.corwin@warmmail.com	Chicago	Illinois	3051688053836236	a05a8189cae70a962e6ce4d598b3b7d6	JCB 15 digit	41.898322138499843	-87.7301401925302997
11978	2020-02-11 20:35:07	2020-02-11	Adolphus Feil	adolphus.feil@geemail.com	Torrance	California	869928372330525875	9c820ae218b3beb6a01d06d35cc9621a	VISA 16 digit	33.8262825561594198	-118.338931201550736
11979	2020-02-11 20:42:11	2020-02-11	Dr. Butch Brekke	dr.butch.brekke@geemail.com	Fairfield	California	4805008072458	0504444dbe85a2b478cd8120584454a2	Mastercard	38.2667223725590873	-122.07625046190843
11980	2020-02-11 20:48:50	2020-02-11	Dr. Ty Doyle	dr.ty.doyle@geemail.com	New York	New York	6011264023560022801	6abee56fb62dae86bb8d52e75cd83f2c	Mastercard	40.7244138006344443	-73.978231411230567
11981	2020-02-11 21:09:46	2020-02-11	Tianna Ondricka	tianna.ondricka@geemail.com	Saint Paul	Minnesota	6011240959370272483	e536f82a42249af882827dd6dd1ad2d9	Discover	44.9924216058045658	-93.0730600269775863
11982	2020-02-11 21:19:03	2020-02-11	Doreen Bechtelar PhD	doreen.bechtelar.phd@geemail.com	Oakland	California	53938391957504160	c82d1fc177b744b97beede5581b92c61	JCB 15 digit	37.7519280940494966	-122.261926832165528
11983	2020-02-11 21:26:35	2020-02-11	Alf Kreiger	alf.kreiger@geemail.com	New York	New York	4356541439422059	3f9ba8be57e436e83a60f93aee008872	JCB 16 digit	40.580647072730585	-73.9339696380671114
11984	2020-02-11 21:36:54	2020-02-11	Gustaf Hodkiewicz Jr.	gustaf.hodkiewicz.jr.@geemail.com	St. Louis	Missouri	210094877319327027	2448c2b4c03b84daf846c671384d83a7	VISA 16 digit	38.7326644192140535	-90.1894587108403556
11985	2020-02-11 21:42:04	2020-02-11	Sheryll Will	sheryll.will@warmmail.com	Plano	Texas	869900456803022767	5cd8d8e02e27a17353d4cabaf73b0094	Voyager	33.0900141715623448	-96.689000210649894
11986	2020-02-11 21:44:18	2020-02-11	Luz Sawayn	luz.sawayn@geemail.com	Denver	Colorado	6011133808585411644	ccae51894a2096ec979bcf6aa1ec2266	JCB 16 digit	39.6840903956960886	-104.860792428046835
11987	2020-02-11 21:45:13	2020-02-11	Dr. Clyda Hayes	dr.clyda.hayes@geemail.com	San Francisco	California	180064035594025636	7d4eccc8b84d2309744812f607ca846f	American Express	37.7855209330472448	-122.425247284977999
11988	2020-02-11 22:19:30	2020-02-11	Ms. Pandora Johnston	ms.pandora.johnston@geemail.com	Sacramento	California	55251515309929688	e11e8a772a17f34ae005871d0f273f10	VISA 13 digit	38.6052765698436673	-121.541969275312866
11989	2020-02-11 22:26:26	2020-02-11	Ms. Bernita Carroll	ms.bernita.carroll@warmmail.com	New York	New York	3487601513233834	c9bf7fcdf7c5b380d8017596f6a8d807	Diners Club / Carte Blanche	40.7303862488586432	-74.0378201997734635
11990	2020-02-11 22:46:52	2020-02-11	Dr. Quentin Ernser	dr.quentin.ernser@woohoo.com	New Haven	Connecticut	4357652993737110	f9351a5903a2707343b49c75f0d5577e	VISA 16 digit	41.3445543053086837	-72.9662390974815906
11991	2020-02-11 22:51:08	2020-02-11	Tayla Langworth	tayla.langworth@geemail.com	Elgin	Illinois	6011300844771681861	c59b2f55283215b65298f4752b5243ed	Discover	42.0991233642961831	-88.3701211876988424
11992	2020-02-11 22:52:10	2020-02-11	Hugo Huels MD	hugo.huels.md@warmmail.com	San Francisco	California	3528245235518704900	6a30be029ad4fd1f04fb945b29c594d2	VISA 16 digit	37.7436674133710852	-122.448807753077702
11993	2020-02-11 22:58:30	2020-02-11	Iris Fadel PhD	iris.fadel.phd@warmmail.com	Fairfield	California	3720706605483591	9ed59c5ad0a6a29dcc30c81991190924	JCB 15 digit	38.1737200047943759	-122.090818244219193
11994	2020-02-11 23:02:18	2020-02-11	Mackenzie Wilderman	mackenzie.wilderman@geemail.com	Durham	North Carolina	561235699934309	7bc9437d0b2feee96b142ff4820cb58d	Discover	36.068084912073239	-78.8636329276390455
11995	2020-02-11 23:16:26	2020-02-11	Bliss Braun	bliss.braun@geemail.com	Dallas	Texas	4807456904661	2437b49da53b827c78ae12c52db205c5	Diners Club / Carte Blanche	32.7132988784268548	-96.8624309417288742
11996	2020-02-11 23:19:10	2020-02-11	Alena Brakus	alena.brakus@geemail.com	New York	New York	6011660880822286098	30dfb780650e12bb6daff2248eeeeb51	Diners Club / Carte Blanche	40.5650888146590418	-73.9589554101124378
11997	2020-02-11 23:39:27	2020-02-11	Mr. Izaiah Bosco II	mr.izaiah.bosco.ii@geemail.com	Los Angeles	California	3158056570564334204	341f585a151e2fdc4fb60dc2cb0bd905	Maestro	33.94191921407878	-118.347919308300305
11998	2020-02-11 23:52:45	2020-02-11	Chuck Cremin	chuck.cremin@woohoo.com	Greensboro	North Carolina	4487139096362643	b43ad5055b16cb30976f1dee3ca5ecaa	VISA 13 digit	36.1767166320350029	-79.7974563741572211
11999	2020-02-11 23:55:22	2020-02-11	Dallas Stamm DVM	dallas.stamm.dvm@warmmail.com	Houston	Texas	6011508911658245837	dfcc6e84e638af9cf95687bde01ea688	American Express	29.817928394869341	-95.3333558704253363
12000	2020-02-11 23:59:40	2020-02-11	Mr. Osborn Casper Jr.	mr.osborn.casper.jr.@geemail.com	Philadelphia	Pennsylvania	3752982431864830	9c0fde731b6122797dad48632457b52f	VISA 13 digit	39.9670605483889574	-75.1626061112985013
12001	2020-02-12 00:12:24	2020-02-12	Ms. Kaaren Stoltenberg DDS	ms.kaaren.stoltenberg.dds@warmmail.com	Oakland	California	869981067281777566	2e7f1f498139fd9bf919312a465f8441	JCB 15 digit	37.8169902919294429	-122.272057080605109
12002	2020-02-12 00:17:08	2020-02-12	Melinda Lynch	melinda.lynch@geemail.com	Washington	District of Columbia	4481583072543	9570a6cc2bebcaef347bd4d11fd108b2	Mastercard	38.9838196006402384	-76.9667267417747496
12003	2020-02-12 00:30:49	2020-02-12	Perla Balistreri MD	perla.balistreri.md@geemail.com	El Paso	Texas	6011194446168775824	881acf87ca7930fd42fe02ee049bcf4f	Maestro	31.7520410287022621	-106.515744973484431
12004	2020-02-12 00:51:05	2020-02-12	Norbert Mueller MD	norbert.mueller.md@geemail.com	Salinas	California	3702847675843504	d23d28abf4d5a46ce9949b72aaeb4097	VISA 16 digit	36.6423431723143906	-121.701284040528165
12005	2020-02-12 00:56:47	2020-02-12	Dakota Kirlin	dakota.kirlin@geemail.com	Columbus	Ohio	3088294110852551532	f9a2c1729566f5a5ad5f8dd8b34f9b0e	Diners Club / Carte Blanche	39.9706873209260394	-82.9301811096027564
12006	2020-02-12 02:09:59	2020-02-12	Tevin Kuvalis-Bahringer	tevin.kuvalis.bahringer@geemail.com	San Francisco	California	6011838447737868142	f66d6c3d53bda36d97d9828b721fd0b6	Voyager	37.7996419800748811	-122.4618319246308
12007	2020-02-12 02:33:13	2020-02-12	Demario Bernhard-Daugherty	demario.bernhard.daugherty@warmmail.com	Philadelphia	Pennsylvania	55063135797888946	5eeb448da3d4b3c39bf6a2e801cf4d82	VISA 13 digit	40.0442524796310835	-75.123761621480071
12008	2020-02-12 02:34:43	2020-02-12	Jazlene Buckridge PhD	jazlene.buckridge.phd@geemail.com	Chicago	Illinois	676374020225038	f336034af331242a055f706635779c34	VISA 16 digit	41.9058473539840435	-87.7200917382288736
12009	2020-02-12 02:46:00	2020-02-12	Jerica Reilly-Green	jerica.reilly.green@woohoo.com	Paterson	New Jersey	52000026891268737	b7a9c17bf787e13e643328964a4dbc54	VISA 13 digit	40.9913557088423488	-74.2178770446192573
12010	2020-02-12 03:21:51	2020-02-12	Romello Lang	romello.lang@geemail.com	St. Petersburg	Florida	676354606771803	64f96c884ee1d193528424487ae40695	VISA 13 digit	27.8570612793210906	-82.5913349368967005
12011	2020-02-12 04:13:56	2020-02-12	Sannie Balistreri	sannie.balistreri@warmmail.com	San Francisco	California	3044346028156621	d39a71b2816910fb92c1904660da049a	American Express	37.7485563043256747	-122.411263409553229
12012	2020-02-12 04:18:05	2020-02-12	Junious Toy	junious.toy@woohoo.com	San Francisco	California	3112207413236809386	c1eeaaf9bb9cae9a5b99d20c28ee01c3	VISA 13 digit	37.8136101139704905	-122.438253676099734
12013	2020-02-12 04:29:52	2020-02-12	Mikaila Torp	mikaila.torp@geemail.com	New York	New York	6011766320883062461	0377928843c6fafcd48587c9ebc75efe	JCB 16 digit	40.5976628644615403	-73.952478117252511
12014	2020-02-12 05:22:48	2020-02-12	Dellie Blick	dellie.blick@geemail.com	Columbus	Ohio	4420447899832	35374b09dffb7e548cd703d31f056e57	Diners Club / Carte Blanche	39.960624585724247	-82.9063924286283651
12015	2020-02-12 05:31:43	2020-02-12	Mrs. Charline Erdman	mrs.charline.erdman@geemail.com	Henderson	Nevada	53688614176349634	536bf3addc4b91ed744c4eb13c92d6f1	VISA 16 digit	36.055139015049491	-115.067268111479294
12016	2020-02-12 06:00:50	2020-02-12	Amalie Cummings	amalie.cummings@geemail.com	Philadelphia	Pennsylvania	53371392848264174	ca83fb5ad94e83a1a47506b6b29c1048	VISA 16 digit	39.9516118199057857	-75.1980603786550574
12017	2020-02-12 06:31:08	2020-02-12	Josie Greenfelder MD	josie.greenfelder.md@geemail.com	Denver	Colorado	4018940062541575	802035af30887ffb17d1cad7bcfc8613	Maestro	39.7768134866893277	-104.939199119737751
12018	2020-02-12 06:40:27	2020-02-12	Yurem Gibson-Oberbrunner	yurem.gibson.oberbrunner@geemail.com	Corpus Christi	Texas	180034824603795074	f4a5e4f3805db8926c259a3364c2a0e7	VISA 16 digit	27.7397672752786448	-97.1431244425304214
12019	2020-02-12 06:45:17	2020-02-12	Dr. Michael Kshlerin DVM	dr.michael.kshlerin.dvm@geemail.com	San Francisco	California	3041670419020127	ba8505c093fccfe6e456bf3a01565a2b	Discover	37.7698308019408984	-122.464441763717261
12020	2020-02-12 07:15:33	2020-02-12	Blanche Bins	blanche.bins@geemail.com	Las Vegas	Nevada	630440704835830	e1c71886dfbbbace25c7438e5f7e633b	JCB 16 digit	36.3235184079136673	-115.178769890007004
12021	2020-02-12 07:28:40	2020-02-12	Dr. Meyer Bartoletti	dr.meyer.bartoletti@geemail.com	Hialeah	Florida	180080058631369775	c8b6d85960e448aedf26b565e0b0cd65	JCB 15 digit	25.9410828729603438	-80.3286738818414392
12022	2020-02-12 07:34:22	2020-02-12	Evelena Tillman	evelena.tillman@geemail.com	Long Beach	California	4472004366032515	4cbe1dfa462546c7a37a955b9af2f360	JCB 16 digit	33.7517074936356352	-118.08184579482041
12023	2020-02-12 07:52:02	2020-02-12	Dr. Demian Hintz	dr.demian.hintz@geemail.com	Austin	Texas	4722824672895653	0c6241892c6cb83be37185e45d4aad75	American Express	30.3844388712324189	-97.6544258480198692
12024	2020-02-12 07:54:57	2020-02-12	Shelbie Kuvalis	shelbie.kuvalis@geemail.com	Bakersfield	California	4266318983124624	c8fe298fdc70d5695f3d9162bcfa7416	Voyager	35.3390549916483465	-119.082374391312896
12025	2020-02-12 09:12:30	2020-02-12	Eustace Miller MD	eustace.miller.md@warmmail.com	Seattle	Washington	3436858912995197	4796e9f9480e8e5750ae568809d74df3	JCB 16 digit	47.5459199513699886	-122.370026369804137
12026	2020-02-12 09:17:49	2020-02-12	Wheeler Stanton	wheeler.stanton@geemail.com	Oakland	California	060457502544505	5200bb3c2bb61b0b957e6d46f90f47a0	Diners Club / Carte Blanche	37.7913848423327465	-122.265460985422322
12027	2020-02-12 09:18:54	2020-02-12	Adella Koepp	adella.koepp@warmmail.com	Portland	Oregon	4472347287157147	62655f6f87c02db8721ede4f846c0a04	VISA 16 digit	45.5033558481726814	-122.66926285009832
12028	2020-02-12 09:19:24	2020-02-12	Ms. Gianna Stracke	ms.gianna.stracke@geemail.com	San Francisco	California	3158057999565999393	2660baa9c99fe4eafac9cb73ec1317f4	VISA 16 digit	37.7411644331294127	-122.401610332912043
12029	2020-02-12 09:19:49	2020-02-12	Mrs. Esperanza Lueilwitz	mrs.esperanza.lueilwitz@geemail.com	Columbus	Georgia	3466177041389922	2423f4b11ebe7760809b10a22161558f	VISA 13 digit	32.4860235881105055	-84.8086131350766834
12030	2020-02-12 09:46:51	2020-02-12	Berlin Kemmer	berlin.kemmer@woohoo.com	Oakland	California	3042887491978217	b2221d2adc96acef3096a71372f1b1e1	Diners Club / Carte Blanche	37.796223574947355	-122.246994040342685
12031	2020-02-12 09:52:34	2020-02-12	Nels Greenfelder	nels.greenfelder@warmmail.com	Oakland	California	869972175354745633	029b3e8304a5cd1353437ed1efe4e612	VISA 13 digit	37.8070545800759348	-122.276158067551506
12032	2020-02-12 10:01:09	2020-02-12	Jason Schiller-Moore	jason.schiller.moore@geemail.com	Boise	Idaho	55605422063382977	dce65027c2e1777afa6ffe37a563fa44	VISA 16 digit	43.6642772254206264	-116.280392640615631
12033	2020-02-12 10:01:35	2020-02-12	Mr. Algie Upton	mr.algie.upton@geemail.com	Fort Worth	Texas	3112021604161666403	1b4a53c4ced0aa8971aa2b149fc683fb	Voyager	32.8404632758870747	-97.4425476808387714
12034	2020-02-12 10:26:50	2020-02-12	Tito Huels	tito.huels@warmmail.com	Salt Lake City	Utah	4261895774773896	cbd4bf17e8ac4b3ba84e2c3b81184d87	Mastercard	40.7732926810305543	-111.944742919033388
12035	2020-02-12 11:00:54	2020-02-12	Roe Robel-Anderson	roe.robel.anderson@warmmail.com	San Francisco	California	3734973755030093	1c591cad4d9d9056840f5b447ad2bf70	Diners Club / Carte Blanche	37.7315086657297059	-122.452120451388566
12036	2020-02-12 11:03:00	2020-02-12	Kody Padberg IV	kody.padberg.iv@geemail.com	San Antonio	Texas	210060007680647007	79481e26468d5a491818925863addca0	American Express	29.5303627498518679	-98.4396172902382887
12037	2020-02-12 11:13:03	2020-02-12	Callum Schulist-Weber	callum.schulist.weber@geemail.com	Washington	District of Columbia	6011816215863465280	22be961ec2eb777e5efe367fb33ee3ae	Discover	38.9945005591757621	-76.9370229128494856
12038	2020-02-12 11:15:06	2020-02-12	Deforest Hammes	deforest.hammes@geemail.com	Midland	Texas	4887938865445513	168b1c6077a51be19d27a49d314d8041	JCB 16 digit	32.1066915490854541	-102.063789036100729
12039	2020-02-12 11:27:14	2020-02-12	Le Ondricka	le.ondricka@geemail.com	Dallas	Texas	3423426484439807	77de4ba7d26ad813d8b69229a46ba346	JCB 16 digit	32.800678746336331	-96.7638125440999772
12040	2020-02-12 11:29:27	2020-02-12	Dr. Jordon Smith	dr.jordon.smith@geemail.com	Milwaukee	Wisconsin	3528301899725573209	cd0e42dfe2cc9cfc127f1d0fd589a287	Mastercard	43.0088328045412851	-87.9651941627830354
12041	2020-02-12 11:34:01	2020-02-12	Curley Grant-Jast	curley.grant.jast@geemail.com	Los Angeles	California	55342442928043737	493f20a5288cdc2f6180342e28ec39fd	Diners Club / Carte Blanche	34.1120228662952769	-118.311551651311291
12042	2020-02-12 11:43:10	2020-02-12	Skylar Weimann	skylar.weimann@geemail.com	Saint Paul	Minnesota	639046638783699	4f78948988656d81127087b09cf4eb23	VISA 16 digit	44.870478365145253	-93.039477702675768
12043	2020-02-12 12:26:52	2020-02-12	Delmer Braun	delmer.braun@woohoo.com	San Francisco	California	3158651721229034817	8ef2969a90eff08aa219ffa48f8625ff	JCB 15 digit	37.7900381125450409	-122.420239247360271
12044	2020-02-12 12:55:29	2020-02-12	Mr. Tristian Lind	mr.tristian.lind@geemail.com	Washington	District of Columbia	3112044102666504727	e8ea022cc2de18b994f25c59b6f999da	JCB 16 digit	38.809891575508189	-76.9179333059329622
12045	2020-02-12 13:39:10	2020-02-12	Jalyn Mann	jalyn.mann@geemail.com	Los Angeles	California	180047457468648966	8c6ba9dd9463913d0b0220128c3b14da	JCB 16 digit	34.0143347173329431	-118.334653865964327
12046	2020-02-12 13:40:59	2020-02-12	Reuben Fahey-Barton	reuben.fahey.barton@woohoo.com	Stockton	California	6011670741772781660	3405b9dc5007215e5264103036552f5d	JCB 16 digit	38.057029739647362	-121.258902294337005
12047	2020-02-12 14:00:59	2020-02-12	Karie Corkery	karie.corkery@geemail.com	Wichita	Kansas	4507605021934	2a269ec5feb1695daddf6c06ee62c0e2	Voyager	37.7207579836592046	-97.301103230492771
12048	2020-02-12 14:42:55	2020-02-12	Orvin Bartoletti	orvin.bartoletti@geemail.com	Washington	District of Columbia	3528126289666847213	1ae4dd4de97295485a77a6aea10a2ef6	American Express	38.8690996947031451	-77.0166931711349605
12049	2020-02-12 14:47:01	2020-02-12	Callum Parker	callum.parker@geemail.com	Des Moines	Iowa	639039766659906	b65b20fb07613aafcc25ba94f9548c4c	JCB 16 digit	41.5242646934673232	-93.5103914892811332
12050	2020-02-12 14:50:09	2020-02-12	Chancy Daniel	chancy.daniel@warmmail.com	New York	New York	55871036699602900	91c313b97e90c9db24c4d4b3914b5a4d	American Express	40.7437818312309687	-73.9607799746923149
12051	2020-02-12 14:52:17	2020-02-12	Antonina Murray MD	antonina.murray.md@geemail.com	Cleveland	Ohio	869973588431660501	c2dd598a8900053a89aaee944051626a	Voyager	41.5112605643309607	-81.7518587370175851
12052	2020-02-12 14:52:30	2020-02-12	Rogers Kiehn II	rogers.kiehn.ii@geemail.com	San Francisco	California	4112514334781	e41fe73dd334889efa060fa0dbb79086	JCB 15 digit	37.7683863962226525	-122.449186262102714
12053	2020-02-12 15:13:34	2020-02-12	Claudio Runte	claudio.runte@geemail.com	San Francisco	California	4059557244981	040068483e3ddd4b6e350609295fd9b2	Maestro	37.7969713063542656	-122.442173508050615
12054	2020-02-12 15:19:07	2020-02-12	Yoshiko Kuhic	yoshiko.kuhic@geemail.com	Oakland	California	4261718353531511	43f652644f38571fca557f3d9e2a274c	JCB 16 digit	37.7873422610878293	-122.250847959169889
12055	2020-02-12 15:33:46	2020-02-12	Mr. Ismael Hoeger	mr.ismael.hoeger@woohoo.com	Tulsa	Oklahoma	180008368960137845	7eb24046e53a8ca23ea31e7b34a492ae	JCB 15 digit	36.042672538095708	-95.808303354862332
12056	2020-02-12 15:45:28	2020-02-12	Lenora Boehm	lenora.boehm@geemail.com	Springfield	Illinois	180038388441406217	4abc120ab1f2c8bf7e061d5cb4cb1c19	JCB 16 digit	39.712528389009087	-89.5533471472099336
12057	2020-02-12 15:51:27	2020-02-12	Dr. Judah Schamberger	dr.judah.schamberger@geemail.com	West Palm Beach	Florida	6011389093221869551	e5e138d4789927c11c087929262b95fd	JCB 15 digit	26.7259158702880164	-80.1538446265574578
12058	2020-02-12 16:04:43	2020-02-12	Lorri Jenkins	lorri.jenkins@geemail.com	New York	New York	6011803126817583380	92ed5e14e165b014d9058349a3d001d6	American Express	40.5639616807214907	-73.9756192786980336
12059	2020-02-12 16:20:28	2020-02-12	Dorotha Bednar	dorotha.bednar@geemail.com	Miramar	Florida	3096827353266105711	aad29f9c173fba9a354a3674991fd39e	Voyager	25.9934488425012695	-80.4169658798251419
12060	2020-02-12 16:25:31	2020-02-12	Ferris Hoeger	ferris.hoeger@geemail.com	San Francisco	California	3465469902174951	614bb0ca9cff40c94457a64b9aaa4a29	American Express	37.7695126776201278	-122.401023986170841
12061	2020-02-12 16:33:51	2020-02-12	Omar Mayert	omar.mayert@warmmail.com	Saint Paul	Minnesota	3337872340928089353	43f11d9b305c0bec84d022b9891afb2e	JCB 15 digit	44.9910333179343525	-93.1366672807637599
12062	2020-02-12 16:40:35	2020-02-12	Tahj Marks	tahj.marks@warmmail.com	New York	New York	3528567378050398002	ef2fc8c9a9d3a216e8852b29b37b45e2	American Express	40.5769018768556435	-73.9134088740579784
12063	2020-02-12 16:46:36	2020-02-12	Kira Kuhic-Schinner	kira.kuhic.schinner@geemail.com	San Francisco	California	060485385048344	c0e36501a897c95630c1c71a2ada43d8	VISA 13 digit	37.7694390229678234	-122.430189457473176
12064	2020-02-12 16:56:37	2020-02-12	Raven Keebler-Christiansen	raven.keebler.christiansen@geemail.com	Milwaukee	Wisconsin	6011508365818461794	f3c9bde9a5066165fb59e897192177fa	Diners Club / Carte Blanche	43.0148475826803605	-87.9240962797410788
12065	2020-02-12 17:08:18	2020-02-12	Sampson Larkin	sampson.larkin@geemail.com	New York	New York	6011775576220324307	fee8bc05c89942269ddc6de78f3ed5dd	Diners Club / Carte Blanche	40.7326868100315309	-73.9539192709036115
12066	2020-02-12 17:12:17	2020-02-12	Barb Barrows MD	barb.barrows.md@warmmail.com	Henderson	Nevada	51403179980209154	b28c5d8c2c3f73c74db2afb125241fdc	American Express	35.9134911317311278	-115.070649575690553
12067	2020-02-12 17:26:00	2020-02-12	Kenan Adams	kenan.adams@geemail.com	San Antonio	Texas	3337248795589749446	14a67c119d4a2590e5e78a718803757a	American Express	29.5276600481547433	-98.600272674609343
12068	2020-02-12 17:28:44	2020-02-12	Kristopher Murphy	kristopher.murphy@warmmail.com	El Paso	Texas	3750236756010798	57258ed1a45a7a48f428d45a8f61b1b6	Mastercard	31.8421080541625621	-106.376008504254756
12069	2020-02-12 17:32:24	2020-02-12	Mrs. Vassie Crist	mrs.vassie.crist@geemail.com	Portland	Oregon	4391240745529478	284c8d70c9f4b4c753d24ffa169465fb	VISA 16 digit	45.6258925701845399	-122.639432185702034
12070	2020-02-12 17:33:47	2020-02-12	Jemal Schulist	jemal.schulist@woohoo.com	San Francisco	California	869955679308023907	9415fc5b9c327a4b41e2d4bb8594771d	American Express	37.7619335951194515	-122.39495320655557
12071	2020-02-12 17:40:53	2020-02-12	Deion Hegmann	deion.hegmann@geemail.com	Durham	North Carolina	210006507288414350	8ff2489a84c7f2bcb52093d8ae33b62e	Voyager	35.8976315436664919	-78.9415261483188715
12072	2020-02-12 18:09:19	2020-02-12	Lyda Treutel	lyda.treutel@woohoo.com	San Mateo	California	210018463907130660	c6327187c51530636fbeb35528a1fc74	Diners Club / Carte Blanche	37.6009957162078479	-122.224933123061803
12073	2020-02-12 18:09:54	2020-02-12	Brenda Satterfield	brenda.satterfield@geemail.com	Louisville	Kentucky	55727039479791956	7be44c250536b18af79e7cc9524def43	VISA 13 digit	38.1591656964641075	-85.6405794950272963
12074	2020-02-12 18:28:26	2020-02-12	Ms. Candyce Howell DVM	ms.candyce.howell.dvm@woohoo.com	Richmond	California	210096331235048695	9df0f55b3e56d55b70337c94b80caea2	Discover	37.8729094646360736	-122.451573876835781
12075	2020-02-12 18:31:47	2020-02-12	Boss Schimmel	boss.schimmel@geemail.com	Berkeley	California	589309943791831	3b6a9fec503a08b6c0055162eae8d8c6	Discover	37.8787591515820878	-122.273718732722287
12076	2020-02-12 18:55:56	2020-02-12	Mr. Coleman McKenzie	mr.coleman.mckenzie@geemail.com	Davenport	Iowa	3528812564086651786	a3df4efd64eb95d1441197c52732aad1	Discover	41.6099188332244765	-90.5948713027834884
12077	2020-02-12 19:05:35	2020-02-12	Asha Farrell-Hansen	asha.farrell.hansen@geemail.com	San Francisco	California	180024124281265058	205dafd0f524fda7cc9ef18293d534ae	Mastercard	37.7631741504799194	-122.403564788892069
12078	2020-02-12 19:06:02	2020-02-12	Kenyatta Shanahan	kenyatta.shanahan@woohoo.com	Glendale	Arizona	53634058850341746	82b9c7f49d54c5ae91f80eb8c97fe75b	JCB 15 digit	33.6113643090467846	-112.20477107127904
12079	2020-02-12 19:10:19	2020-02-12	Dr. Orlando Ondricka V	dr.orlando.ondricka.v@woohoo.com	Reno	Nevada	3044674970613848	4115fffa25e9315e09dd462bfdf835e7	Diners Club / Carte Blanche	39.6326626367479591	-119.78807695286126
12080	2020-02-12 19:19:02	2020-02-12	Brandon Kessler-Greenholt	brandon.kessler.greenholt@geemail.com	Jacksonville	Florida	4055763620351160	0dc30565c3232d91ec586d69b33c5f5a	Maestro	30.385764276055248	-81.6070575318843225
12081	2020-02-12 19:26:55	2020-02-12	Mr. Ezra Miller PhD	mr.ezra.miller.phd@geemail.com	Norfolk	Virginia	54167330292395456	1eae97bc0eb724737f88cc662deffff6	VISA 13 digit	36.9436749114207927	-76.2946175846275025
12082	2020-02-12 19:45:07	2020-02-12	Dr. Rishi Little DDS	dr.rishi.little.dds@geemail.com	San Francisco	California	676269714644007	e1796c306c38f1187b09a75ee32e5aa0	Discover	37.770894162870654	-122.444246361664113
12083	2020-02-12 19:53:41	2020-02-12	Isam Lebsack-Bins	isam.lebsack.bins@warmmail.com	Las Vegas	Nevada	4706783468494388	e0f1618f8783ac33e40534a016a5c9e5	Discover	36.2942162103585915	-115.324260203235212
12084	2020-02-12 20:05:14	2020-02-12	Rinda Dibbert	rinda.dibbert@geemail.com	San Antonio	Texas	3798430825627716	89dd552ff9fa4fd911a3c479e635cce0	JCB 16 digit	29.5252640298172828	-98.4871724953245291
12085	2020-02-12 20:12:51	2020-02-12	Suzan Daugherty DDS	suzan.daugherty.dds@geemail.com	Boise	Idaho	4879772669773	490ae79e8cf1c3c064f0692564c7a104	JCB 16 digit	43.5665220963906492	-116.303126369948316
12086	2020-02-12 20:26:06	2020-02-12	Mr. Rashawn Ortiz	mr.rashawn.ortiz@geemail.com	Daly City	California	6011291324330924913	f83eea73210ef0eceeead8fbe0ff2354	JCB 16 digit	37.7222803722523139	-122.556444306727499
12087	2020-02-12 20:37:31	2020-02-12	Kirk Hessel	kirk.hessel@woohoo.com	Tucson	Arizona	3741635237353473	ba79bbe75c370e74d2117220b0a5bc23	Diners Club / Carte Blanche	32.199838819219174	-110.792726761125394
12088	2020-02-12 21:00:06	2020-02-12	Izetta Bosco	izetta.bosco@geemail.com	Hampton	Virginia	3112792132509496462	787740fad34006e5729db6452a323df4	VISA 16 digit	37.0111406620610524	-76.3596942066777444
12089	2020-02-12 21:37:00	2020-02-12	Darryle Davis-Orn	darryle.davis.orn@geemail.com	Chula Vista	California	3112761121096792844	3ede964aa92e405c423d1c6839afb7b2	JCB 15 digit	32.6191609728381025	-117.102371942740675
12090	2020-02-12 21:57:59	2020-02-12	Stonewall Rogahn-Reichel	stonewall.rogahn.reichel@geemail.com	Phoenix	Arizona	4924705837331807	71c5997fe2707c6fced6e6c4121a8d59	Mastercard	33.6034073499429979	-112.060595098363621
12091	2020-02-12 22:15:43	2020-02-12	Virdie Bogan	virdie.bogan@geemail.com	Miami	Florida	3716699724823019	705bfed27b95aadda437f60dd9210be3	Discover	25.7363350062768923	-80.1714396517597123
12092	2020-02-12 22:31:46	2020-02-12	Ms. Susanna Larkin	ms.susanna.larkin@geemail.com	Houston	Texas	51538697485151389	594cec181558deb8a4d495df5732326b	Discover	29.7117350794918842	-95.3472443948049175
12093	2020-02-12 22:44:15	2020-02-12	Hulda Grimes MD	hulda.grimes.md@geemail.com	Colorado Springs	Colorado	503834037003257	c50f7e83948fe01b2a1e7e4a72d5df3f	Voyager	38.8730286910712692	-104.768449254954973
12094	2020-02-12 22:52:28	2020-02-12	Dr. Maleah McLaughlin	dr.maleah.mclaughlin@geemail.com	Chesapeake	Virginia	4883427417687	532c1d5c3df9f7bbd8e7c3c2e52c903a	Discover	36.6097515382576759	-76.2982830233249842
12095	2020-02-12 22:53:45	2020-02-12	Ms. Jeanette Boyer	ms.jeanette.boyer@geemail.com	San Francisco	California	869946513219306188	0be5c8539291c64468114644c2f6efd5	VISA 16 digit	37.7635972112541012	-122.397829426894646
12096	2020-02-13 00:00:53	2020-02-13	Hilary Considine	hilary.considine@warmmail.com	Louisville	Kentucky	3528008058911609725	d06cbfb18392a45600dc640ff006dde8	VISA 16 digit	38.1158944819957028	-85.6336448154017376
12097	2020-02-13 00:28:41	2020-02-13	Ernest Hamill	ernest.hamill@geemail.com	Austin	Texas	3027580695000160	d6cf9783e2dfaf942d63f24f4b37a8c0	American Express	30.3143612014722059	-97.8412748224806137
12098	2020-02-13 00:29:19	2020-02-13	Gil Nikolaus	gil.nikolaus@geemail.com	Little Rock	Arkansas	53189890324105920	6f6b38b1b67d8656157bd500d80535d8	Maestro	34.7985556477490832	-92.290493944134937
12099	2020-02-13 01:07:37	2020-02-13	Rachel Morissette	rachel.morissette@woohoo.com	San Francisco	California	060476555593151	4c307ed9b45674080730b28559bd0dec	American Express	37.7942382008461664	-122.452426151946796
12100	2020-02-13 01:18:29	2020-02-13	Leontine Blick	leontine.blick@geemail.com	Honolulu	Hawaii	54763615507359786	d72e4b06fab622dd34385b336a028878	Mastercard	21.4115835395392047	-157.805256515948486
12101	2020-02-13 01:31:18	2020-02-13	Iliana Lemke	iliana.lemke@geemail.com	Kansas City	Missouri	561267891132002	6da9d6547840e38fa4ecadc6cafe6908	American Express	39.0614808172289329	-94.4946795556452201
12102	2020-02-13 02:16:49	2020-02-13	Alanzo Rogahn	alanzo.rogahn@warmmail.com	Lubbock	Texas	3058065055709450	215443d7dfe4139343e9ae282853088a	VISA 16 digit	33.5564564312849214	-101.874763313113533
12103	2020-02-13 02:26:53	2020-02-13	Tyesha Ritchie	tyesha.ritchie@geemail.com	New York	New York	4329643539938515	cafad378f8857477f4768d457b638888	Mastercard	40.5969767020307444	-73.9487896090269032
12104	2020-02-13 02:34:43	2020-02-13	Marlie Schuppe	marlie.schuppe@woohoo.com	St. Petersburg	Florida	180039813561503260	61c681a493e4d975217e8f9bfafa2e49	Discover	27.8559609850756829	-82.6669790143970289
12105	2020-02-13 02:37:21	2020-02-13	Margurite Glover	margurite.glover@geemail.com	Santa Clarita	California	3467262921252934	6a213cd59dafa5d1c5be97177608bac0	VISA 16 digit	34.3369767755474911	-118.503124991255618
12106	2020-02-13 02:41:01	2020-02-13	Tania Kuvalis	tania.kuvalis@geemail.com	Oceanside	California	4110883027367925	07ddeda9f46adffe3e104cb663e942b1	Voyager	33.2317979954071347	-117.349580663823346
12107	2020-02-13 03:00:41	2020-02-13	Ruthann Swaniawski	ruthann.swaniawski@geemail.com	Gresham	Oregon	639055533556100	0ff931324de6d0f087e737157901d673	VISA 13 digit	45.406684783981369	-122.451864403326425
12108	2020-02-13 03:20:34	2020-02-13	Ressie Breitenberg	ressie.breitenberg@woohoo.com	San Francisco	California	3337671366873704137	80646404df190ff6e87ef1131e1208ce	VISA 16 digit	37.7887886064943501	-122.451113527303193
12109	2020-02-13 03:26:30	2020-02-13	Rodrick Strosin	rodrick.strosin@geemail.com	Boston	Massachusetts	6011723672650406558	162e40800ed639e1f870dbabd69b9849	Mastercard	42.2385074667334592	-70.9428081596221745
12110	2020-02-13 03:44:17	2020-02-13	Shakira Kulas	shakira.kulas@geemail.com	San Francisco	California	180022014501370402	ae0189b2ae7da5255f612e99756cc669	JCB 16 digit	37.7722488285305644	-122.430393716307989
12111	2020-02-13 03:51:26	2020-02-13	Jaydon Gerhold	jaydon.gerhold@warmmail.com	Sacramento	California	869936209685111457	ae84bedfd7dcf15daa5af7b1e330a06b	Diners Club / Carte Blanche	38.6152994586419354	-121.472432820197568
12112	2020-02-13 04:01:12	2020-02-13	Denisse Glover	denisse.glover@warmmail.com	Providence	Rhode Island	6011289405784336490	ed3793056e111155f1e35b7a5d90e38f	Diners Club / Carte Blanche	41.8871547392424191	-71.332590440000601
12113	2020-02-13 04:14:11	2020-02-13	Miss Keira Moore MD	miss.keira.moore.md@geemail.com	San Francisco	California	3158655934806931497	651952c692e527f62c9147f85b461225	VISA 13 digit	37.7723450948610235	-122.40865296391749
12114	2020-02-13 04:20:00	2020-02-13	Elihu Douglas	elihu.douglas@warmmail.com	Los Angeles	California	180094487172865921	311958101580771c45470fdef0943ac4	JCB 16 digit	33.9359410065092106	-118.389396265148363
12115	2020-02-13 04:45:17	2020-02-13	Dr. Marshall Hyatt	dr.marshall.hyatt@woohoo.com	Columbus	Ohio	3337737711867865521	65ddf8f0cadd4d75694f614b834e388e	VISA 13 digit	40.0772539359096456	-82.8909295517254634
12116	2020-02-13 05:32:10	2020-02-13	Shena Hartmann	shena.hartmann@geemail.com	Washington	District of Columbia	3007760734664354	791b91cbd858fcc84d3da809bf943b68	VISA 13 digit	38.8424668793831032	-77.1147387651007676
12117	2020-02-13 05:45:37	2020-02-13	Mr. Clide Kshlerin	mr.clide.kshlerin@geemail.com	Saint Paul	Minnesota	3112401099520480614	7d7e1c9291f01803cfbea2e27f2506e9	Diners Club / Carte Blanche	44.9706199002392637	-93.1745948521684824
12118	2020-02-13 05:46:34	2020-02-13	Mrs. Shirlene Lindgren DVM	mrs.shirlene.lindgren.dvm@geemail.com	San Francisco	California	52438209658569677	efd980c9bef012dd96e9187b1f450321	VISA 16 digit	37.7720057311587851	-122.462710371709221
12119	2020-02-13 06:00:04	2020-02-13	Shona Rath	shona.rath@warmmail.com	Phoenix	Arizona	4544727853871193	2ef2e68f4e7585a6086eb6181b556055	JCB 15 digit	33.6364602556385108	-112.165194723468659
12120	2020-02-13 06:04:04	2020-02-13	Ulysses Murphy	ulysses.murphy@geemail.com	Chicago	Illinois	869920870056207659	7393dedcfe8be693d85a5b832e32c299	Voyager	41.7433960825506603	-87.6400465725485134
12121	2020-02-13 06:22:43	2020-02-13	Mr. James Glover DVM	mr.james.glover.dvm@geemail.com	Thornton	Colorado	869979163166305682	3ac4d1a2f12ef74d1963b4c583122382	American Express	39.9461571557778896	-104.885315361169361
12122	2020-02-13 06:23:23	2020-02-13	Valarie Lubowitz	valarie.lubowitz@geemail.com	Detroit	Michigan	4321222229667789	969ca90a5c2f8cbce1cc42fe692321e1	American Express	42.476448411067949	-83.1365017856124808
12123	2020-02-13 06:35:02	2020-02-13	Gannon Streich	gannon.streich@geemail.com	Garland	Texas	53934736825150410	803b563b9c0a9950e62fa8cba7fa4d17	VISA 16 digit	32.8675508952002957	-96.7182595814272759
12124	2020-02-13 06:41:24	2020-02-13	Wardell Farrell	wardell.farrell@geemail.com	San Francisco	California	3015574716868384	691c08c6f4e7a6b928233a6743ff6655	Discover	37.7699307966917104	-122.421231565489222
12125	2020-02-13 06:43:02	2020-02-13	Algernon Rice	algernon.rice@geemail.com	Chicago	Illinois	869962666686403943	cb857b0e08ca4707b13a1b9e38a6620f	JCB 16 digit	41.8523080648224806	-87.7648093218479204
12126	2020-02-13 06:49:10	2020-02-13	Carisa Stroman	carisa.stroman@geemail.com	Stockton	California	3088333944071343088	e1d224ef17c0a9eb9814bed68f782342	American Express	38.04028241645657	-121.269436886309833
12127	2020-02-13 06:54:56	2020-02-13	Oda Goyette MD	oda.goyette.md@geemail.com	San Antonio	Texas	4103677118046	49f3a2bc595ecd2bf51c1e76fce91b08	VISA 16 digit	29.4136943759467471	-98.472723942326752
12128	2020-02-13 07:01:48	2020-02-13	Ms. Erline Streich	ms.erline.streich@geemail.com	Newark	New Jersey	3528166637024251935	810d92eb23b31dfff475643ba9d5b63d	Maestro	40.6329474304251406	-74.2222877411846156
12129	2020-02-13 07:27:18	2020-02-13	Sandy VonRueden	sandy.vonrueden@woohoo.com	San Francisco	California	6011229675761222565	9c8fde69ecaf3ab0f71c74db9191d07b	Discover	37.7541147305451901	-122.451925678439395
12130	2020-02-13 07:28:07	2020-02-13	Brett Dibbert	brett.dibbert@geemail.com	Santa Rosa	California	869995219194849545	f202984a0911b077af1a10c3436e28fb	Voyager	38.524495462666458	-122.804488121975595
12131	2020-02-13 07:34:59	2020-02-13	Markel Romaguera-Hahn	markel.romaguera.hahn@warmmail.com	Waco	Texas	6011532736910481221	6a7f959b9607f2f8da1cd87fad125df6	VISA 13 digit	31.6436663554724298	-97.1302389136180295
12132	2020-02-13 07:38:24	2020-02-13	Orvil Flatley	orvil.flatley@woohoo.com	Birmingham	Alabama	060463794636157	cca4762a013bdf147a79fde424511cd6	VISA 16 digit	33.6231256665453344	-86.8600900288913493
12133	2020-02-13 07:53:40	2020-02-13	Nicky Mraz MD	nicky.mraz.md@geemail.com	Santa Rosa	California	3055194616799827	0a32b2d1efeecb08f8aa8de9f3fcaa20	JCB 16 digit	38.4507188657421679	-122.658766581049562
12134	2020-02-13 08:03:11	2020-02-13	Violet Huel	violet.huel@geemail.com	Gilbert	Arizona	180026199129993648	ec1417b3cb30736950c06c2c89ea094e	Mastercard	33.221889569970962	-111.736962365884708
12135	2020-02-13 08:04:07	2020-02-13	Tyrus Douglas	tyrus.douglas@geemail.com	Lowell	Massachusetts	3051988509538539	c3bad71ebc7c0001fafe941050348c09	Diners Club / Carte Blanche	42.7071541305501015	-71.2595211136493845
12136	2020-02-13 08:15:15	2020-02-13	Nolan Wolff-Deckow	nolan.wolff.deckow@geemail.com	Gilbert	Arizona	54678774422873548	4309f2ad28c8511bb049fc718c7c7da6	Maestro	33.2261642664086025	-111.822734359478943
12137	2020-02-13 08:29:01	2020-02-13	Charlie Glover	charlie.glover@geemail.com	San Francisco	California	51784114576475033	a6d4106ec708e5e706e0f6878667e917	VISA 13 digit	37.7873378659778894	-122.435286350757096
12138	2020-02-13 08:43:38	2020-02-13	Elmer Walker	elmer.walker@geemail.com	San Francisco	California	6011503664654801005	6730d8ba86464622e224ef7a10e869f9	JCB 15 digit	37.7655618224541243	-122.406694162322339
12139	2020-02-13 09:06:25	2020-02-13	Ms. Brianda Boehm	ms.brianda.boehm@woohoo.com	Berkeley	California	3731631565943912	7cf83345d564916a70315a09ff0e3e04	JCB 16 digit	37.8747724462537079	-122.222454014943438
12140	2020-02-13 09:46:53	2020-02-13	Fayette Stiedemann-Stiedemann	fayette.stiedemann.stiedemann@geemail.com	Scottsdale	Arizona	3337776030868957407	558408af705b9d839e93fbaf6b08f6c5	JCB 15 digit	33.6861322680611153	-111.853762452300998
12141	2020-02-13 10:03:54	2020-02-13	Kim Ledner	kim.ledner@warmmail.com	Tucson	Arizona	589333478682330	2a58046a5edf39d99a71d531d362aa85	VISA 13 digit	32.1080924073275185	-110.895356004055955
12142	2020-02-13 10:07:41	2020-02-13	Karina Hane	karina.hane@geemail.com	Laredo	Texas	3054875569342802	8edb8d70ce85b7d85c8564521d90edca	American Express	27.6468228022284812	-99.4873242182664512
12143	2020-02-13 10:13:57	2020-02-13	Shawna Tremblay	shawna.tremblay@geemail.com	Phoenix	Arizona	4338441792423450	422a36949c04e17f154c2b047887cac9	Discover	33.5996993611499661	-112.075553663580123
12144	2020-02-13 10:23:47	2020-02-13	Trista Orn-Pfeffer	trista.orn.pfeffer@woohoo.com	San Francisco	California	51577868775159075	3b28373a65b61f612a6b2d2df997fac4	Maestro	37.728524885130696	-122.464332557528678
12145	2020-02-13 10:29:34	2020-02-13	Marlana Shields MD	marlana.shields.md@geemail.com	Oakland	California	4057984829580	f5fb7286e5f9a30e166063b2063491ed	JCB 16 digit	37.799267042817533	-122.289098663518004
12146	2020-02-13 10:35:03	2020-02-13	Mr. Kendrick Mante MD	mr.kendrick.mante.md@geemail.com	Chicago	Illinois	3719057191562999	83ebede407d4d018e70328594ee8a59c	Mastercard	41.9081055428668847	-87.7806005635794264
12147	2020-02-13 10:40:16	2020-02-13	Sierra Volkman	sierra.volkman@warmmail.com	Long Beach	California	3528608912906167608	4ba99a899d587295725ed516bf7335e4	Mastercard	33.8279114794272928	-118.055525260434663
12148	2020-02-13 10:41:15	2020-02-13	Ms. Lita Stark	ms.lita.stark@geemail.com	Los Angeles	California	589313007430088	344ad839d44d34662e34927f056d15db	JCB 16 digit	34.0614726118609283	-118.503300793654461
12149	2020-02-13 10:48:15	2020-02-13	Erastus Barton	erastus.barton@geemail.com	Gilbert	Arizona	4245158707910	21c0a669ecaf82ec8f0ea3c4585d6c2a	Voyager	33.3908047501809904	-111.803496752692752
12150	2020-02-13 11:04:18	2020-02-13	Tess Hirthe	tess.hirthe@geemail.com	San Francisco	California	6011091853189250469	4c43deb5de7d404d88008332b85e4c9c	VISA 16 digit	37.7774638662666362	-122.428601196178249
12151	2020-02-13 11:04:58	2020-02-13	Exie Turner-Schuppe	exie.turner.schuppe@geemail.com	Mobile	Alabama	4232695192848	8fbe0149421c23ce4b5715040728f341	VISA 16 digit	30.6224024847723513	-88.1770417681101719
12152	2020-02-13 11:17:45	2020-02-13	Kloe Blick	kloe.blick@warmmail.com	Los Angeles	California	4584607151225352	90f4a3b598b641ccc7357dceb1a9e4c0	Maestro	34.100178130842373	-118.357945315865052
12153	2020-02-13 11:26:29	2020-02-13	Kory Nicolas	kory.nicolas@woohoo.com	Omaha	Nebraska	6011485746926934375	1cedc3a392f7cd97ab9aa87a1fa29203	VISA 13 digit	41.2194078728236306	-96.1177692736614517
12154	2020-02-13 11:29:19	2020-02-13	Mrs. Maiya Tillman	mrs.maiya.tillman@geemail.com	San Jose	California	869986318810041999	22adf50c3d9892e4c52dd30335798cad	Diners Club / Carte Blanche	37.3666693681206539	-121.735160298667481
12155	2020-02-13 11:34:46	2020-02-13	Madonna White PhD	madonna.white.phd@geemail.com	Houston	Texas	4257624394868	71c9966bb47aa4452118d480c29caddb	Maestro	29.7038931322362281	-95.3330611800789853
12156	2020-02-13 11:38:29	2020-02-13	Jaslyn Haley	jaslyn.haley@geemail.com	New York	New York	4264259722494005	966053650d0d70de5116ba967fa605cc	American Express	40.5898883985113343	-73.9499498523201737
12157	2020-02-13 11:41:19	2020-02-13	Florian Hudson PhD	florian.hudson.phd@geemail.com	Washington	District of Columbia	210033580239299276	fe9b27f67c01fc25fe97911230f98022	Maestro	38.8367748890336628	-76.9464248997371669
12158	2020-02-13 11:45:07	2020-02-13	Mr. Randolf Mitchell III	mr.randolf.mitchell.iii@woohoo.com	Los Angeles	California	3112969547952314077	f5f7c31d5c3c062e1b5d3cda68e0db82	JCB 15 digit	34.0734160511154656	-118.367873079561804
12159	2020-02-13 11:56:15	2020-02-13	Mr. Cade Bednar	mr.cade.bednar@geemail.com	Grand Rapids	Michigan	4821796274701	b535aafdb574e0b0ed49ea55bc30cd0c	Mastercard	42.8936859473854284	-85.6388515017595182
12160	2020-02-13 12:22:21	2020-02-13	Kadeem Reichel	kadeem.reichel@geemail.com	Syracuse	New York	3442234182788427	a43e954c34b7612ebccd982d0df0b316	Diners Club / Carte Blanche	43.0000879292692986	-76.1279516711611421
12161	2020-02-13 12:25:30	2020-02-13	Marjory Harber	marjory.harber@warmmail.com	San Francisco	California	4595272997119363	b7773b85a9d79158e62ca4193a2d0b3d	Mastercard	37.7688374758054195	-122.437447108442569
12162	2020-02-13 12:50:08	2020-02-13	Lexie Windler	lexie.windler@woohoo.com	Oakland	California	639022165964937	39912dbc4aa14f74f6ceb0ca87d2ade3	Diners Club / Carte Blanche	37.8092342125666292	-122.280188811434357
12163	2020-02-13 13:21:54	2020-02-13	Lu Heaney	lu.heaney@warmmail.com	Columbus	Ohio	869972850624722295	2a215337cbf3dedca342e0d23d61ca69	JCB 15 digit	39.9139991628516455	-82.9811613680563909
12164	2020-02-13 13:25:10	2020-02-13	Rusty Brakus	rusty.brakus@geemail.com	Rancho Cucamonga	California	869907824357612882	8dbde293d4f29f0578a4c04f31b65c67	Voyager	34.1141866188488905	-117.492394234892728
12165	2020-02-13 13:27:02	2020-02-13	Aretha Crist	aretha.crist@geemail.com	Washington	District of Columbia	4013706661172459	0c57cf9f1fcafd831b1f4f327b4aea4f	VISA 16 digit	38.9436256896968942	-76.9496381303507917
12166	2020-02-13 13:28:16	2020-02-13	Dr. Darrius Schneider PhD	dr.darrius.schneider.phd@geemail.com	San Francisco	California	4831597026150581	613b6134723a6988dc7f1efefabfbadb	JCB 16 digit	37.7958416251302722	-122.417489848676254
12167	2020-02-13 13:28:41	2020-02-13	Terry Howell-Pollich	terry.howell.pollich@geemail.com	Chula Vista	California	51965269594756144	43066e77cbff6bc6e90c39e864d57c9d	JCB 15 digit	32.6873019104588778	-117.00689215355068
12168	2020-02-13 13:49:54	2020-02-13	Malcom Pfeffer	malcom.pfeffer@geemail.com	Dallas	Texas	3096393849045792939	6d64e949b52d81cf4d4e55895d984d1f	Maestro	32.7074019307076966	-96.7150591771081025
12169	2020-02-13 14:31:00	2020-02-13	Kylene Price	kylene.price@geemail.com	Sacramento	California	3337717874657915056	7b66a393f6914968fdca2992189e237d	Discover	38.5410451810140202	-121.440047449829422
12170	2020-02-13 14:41:40	2020-02-13	Alyssa Daniel	alyssa.daniel@geemail.com	Knoxville	Tennessee	3337764662214665658	95c27fee8c813a014cf3f4e6ad740e9c	VISA 13 digit	35.9510337251767496	-83.8813969418622492
12171	2020-02-13 14:56:21	2020-02-13	Byrdie Johnson-Streich	byrdie.johnson.streich@geemail.com	Long Beach	California	4800964007958175	4c04b3560ef8382c1f772787a14e2d9d	JCB 16 digit	33.7763162097714797	-118.091716924186045
12172	2020-02-13 15:25:10	2020-02-13	Devontae Wuckert-Reichert	devontae.wuckert.reichert@woohoo.com	Bellevue	Washington	3112387872313967957	787610dd886c69833072b634807f8446	Mastercard	47.6549786321070101	-122.233185127336526
12173	2020-02-13 15:44:56	2020-02-13	Dr. Hiram Gleichner V	dr.hiram.gleichner.v@geemail.com	San Francisco	California	3798401780734219	8c7b3b30fbd54a73f6a2d48b8648f775	Voyager	37.7568446799295785	-122.478553345372873
12174	2020-02-13 15:47:01	2020-02-13	Eulalie Beer	eulalie.beer@warmmail.com	San Diego	California	3001627467210646	6a920a26f4311574845f521e96a675ed	American Express	32.7919659626737214	-117.05067037892529
12175	2020-02-13 15:54:01	2020-02-13	Boston Mueller	boston.mueller@geemail.com	Cincinnati	Ohio	4028049796635675	69d626feeaf8dbd112635a56c53108c9	Voyager	39.1199813504468636	-84.4165757758349145
12176	2020-02-13 16:05:40	2020-02-13	Docia Krajcik	docia.krajcik@geemail.com	New York	New York	3088579750766639729	3e49da9369462d8085123dae993da970	VISA 16 digit	40.5790018219258641	-73.9294847659662366
12177	2020-02-13 16:17:15	2020-02-13	Adalynn Bartell-Skiles	adalynn.bartell.skiles@geemail.com	San Francisco	California	3055455473652247	8bf39c488f83cae5225b19b90d3bdcaa	Mastercard	37.7841391084452667	-122.436798053478995
12178	2020-02-13 17:00:39	2020-02-13	Dr. Berry Sporer II	dr.berry.sporer.ii@geemail.com	Glendale	California	210018304967463825	297599f92f6fe2aea3fbd632113b6392	Diners Club / Carte Blanche	34.1884841975510056	-118.24006511470229
12179	2020-02-13 17:21:53	2020-02-13	Miss Laci Schaden	miss.laci.schaden@geemail.com	Irvine	California	3451438471432138	f18894c5dc93d1ceb8fd344358e61d01	Mastercard	33.6932542139679256	-117.676025386900818
12180	2020-02-13 17:31:06	2020-02-13	Ashlyn Schroeder	ashlyn.schroeder@woohoo.com	Philadelphia	Pennsylvania	4731340437620509	1a0c23c9b3c677381eff50d330b8aa43	Voyager	40.0486301578074659	-75.1390626713998699
12181	2020-02-13 17:33:23	2020-02-13	Dr. Hayes Howell	dr.hayes.howell@geemail.com	Fort Worth	Texas	3337275987466695745	acbdd7de060ffd078a771b35d53542fd	JCB 15 digit	32.795519229449333	-97.3680514379225599
12182	2020-02-13 17:46:00	2020-02-13	Casey Beatty	casey.beatty@geemail.com	Oklahoma City	Oklahoma	55388759792641071	bc3fe2a0e7e33a7203284ecf58be7312	Voyager	35.5135742745272864	-97.4242888818390611
12183	2020-02-13 17:52:04	2020-02-13	Christiana Gaylord	christiana.gaylord@geemail.com	San Francisco	California	6011679921508467039	0b11dfafb98329643d46dc1a4b10779c	JCB 16 digit	37.7658504107479018	-122.376417779586347
12184	2020-02-13 18:03:16	2020-02-13	Jaylin Lemke Jr.	jaylin.lemke.jr.@geemail.com	San Francisco	California	3048256635577042	4616c2662dbaf4ab27fa2951c4a886f4	Maestro	37.7874856751072983	-122.422683114538458
12185	2020-02-13 18:06:40	2020-02-13	Lesta McDermott	lesta.mcdermott@woohoo.com	Phoenix	Arizona	4818597277081938	1b061cebb64c68a51e777cb890f5b65b	VISA 16 digit	33.5664144704982661	-112.15324519541339
12186	2020-02-13 18:20:06	2020-02-13	Juston Conn	juston.conn@geemail.com	Miami	Florida	4171006090192527	75a10361bc02b3f678591cafd2de907c	JCB 16 digit	25.8734590632047521	-80.1107608796902042
12187	2020-02-13 18:38:01	2020-02-13	Kaya Littel	kaya.littel@geemail.com	Madison	Wisconsin	3402007469842739	189e62ea777bbdf1aa35c85171891532	Discover	43.0433464973207549	-89.3527376438841259
12188	2020-02-13 18:42:02	2020-02-13	Duff McGlynn	duff.mcglynn@geemail.com	New York	New York	869947723150858530	b7199f58c9de7ae72124fc97f3a78a2d	Discover	40.7615948346201336	-73.9238949509233265
12189	2020-02-13 19:12:23	2020-02-13	Dr. Pink Kunde DVM	dr.pink.kunde.dvm@warmmail.com	Berkeley	California	675948974651159	cc31f94c73cabda05b7d105ef7a2e5f5	JCB 16 digit	37.8630907091988789	-122.29610100983372
12190	2020-02-13 19:23:44	2020-02-13	Litha Schulist	litha.schulist@geemail.com	New York	New York	4582389610939	e8f7531c09750a1fd2e600aed28f0e4a	VISA 16 digit	40.692644761478526	-73.8847027218330652
12191	2020-02-13 19:25:34	2020-02-13	Chrystal Paucek	chrystal.paucek@geemail.com	Santa Ana	California	4651250318896266	3840b033036ade31245992e50b804f7c	VISA 16 digit	33.7805359460983397	-117.913033988179635
12192	2020-02-13 19:28:54	2020-02-13	Welton Prosacco	welton.prosacco@geemail.com	Port St. Lucie	Florida	4322404786459730	709ea6f29f2ae1ef3ab374018eeac183	Mastercard	27.3007660588849319	-80.2913954248737554
12193	2020-02-13 19:42:26	2020-02-13	Journey Stiedemann-Rippin	journey.stiedemann.rippin@woohoo.com	Miami	Florida	3337467324696063387	b82059bd48c56d221bf3e5d79c9a299a	Discover	25.8029951476164179	-80.1815449037462571
12194	2020-02-13 19:48:01	2020-02-13	Keshawn King	keshawn.king@warmmail.com	Roseville	California	676278845919402	330a96729638a14e2842bdd029c8304d	Mastercard	38.7451307275854049	-121.310573693992197
12195	2020-02-13 19:49:54	2020-02-13	Dr. Jeff Jast PhD	dr.jeff.jast.phd@geemail.com	San Francisco	California	3028358980804953	a1a5ff4b391947bedcb0b0be70c2add4	Mastercard	37.7955332924441336	-122.445799945869709
12196	2020-02-13 20:17:56	2020-02-13	Ms. Edrie Funk DVM	ms.edrie.funk.dvm@geemail.com	North Charleston	South Carolina	3054220823505573	a9e9fc348237df0ff5ca11a17d8370a5	American Express	32.9400576102707561	-80.0467331541795204
12197	2020-02-13 20:25:20	2020-02-13	Thalia McLaughlin	thalia.mclaughlin@geemail.com	Jersey City	New Jersey	54752090202528965	05d617fab6ce37a21001e2984216bcf1	Diners Club / Carte Blanche	40.6409698073692596	-74.1224446383725848
12198	2020-02-13 20:56:13	2020-02-13	Charles Connelly	charles.connelly@geemail.com	San Diego	California	869993925965697093	49fae07d2098f22d00d65f104ab24027	JCB 16 digit	32.8140779981922392	-117.083886014521127
12199	2020-02-13 21:25:12	2020-02-13	Wong Jones-Douglas	wong.jones.douglas@geemail.com	Brownsville	Texas	869930410105995497	a9bdf18dc52096470571d1952c167e4a	VISA 16 digit	25.9100061243478201	-97.5541358318831726
12200	2020-02-13 21:27:37	2020-02-13	Dr. Dewey Kilback	dr.dewey.kilback@geemail.com	New York	New York	3158981032349419925	110ff3647d478f621f022e02bb37a419	JCB 16 digit	40.6438591848351081	-73.9770705975953433
12201	2020-02-13 21:29:06	2020-02-13	Nathanial Bins PhD	nathanial.bins.phd@geemail.com	Lancaster	California	4057591535546410	8f1c03a6dcf994d9e3e41ceb7dc97840	Diners Club / Carte Blanche	34.6366615453515223	-118.130611785172661
12202	2020-02-13 21:40:22	2020-02-13	Devyn Gerlach	devyn.gerlach@warmmail.com	Paterson	New Jersey	3482613635739759	2a3fb7ca1c56fea8c3b521a03713f468	Diners Club / Carte Blanche	40.8482850492421505	-74.2413249395761738
12203	2020-02-13 21:52:48	2020-02-13	Jacque Bayer	jacque.bayer@geemail.com	Rochester	New York	4020374655106016	9979814cc28b68f36493897873aeb5e6	JCB 15 digit	43.1738265500381573	-77.567756779003517
12204	2020-02-13 22:06:11	2020-02-13	Herb Doyle	herb.doyle@woohoo.com	Albuquerque	New Mexico	3088402745526729938	96be5b20015a258ff33e46ea56858b63	Discover	35.1514647258114081	-106.738540467533852
12205	2020-02-13 22:11:31	2020-02-13	Jerrold Medhurst	jerrold.medhurst@geemail.com	San Francisco	California	3434404074658695	9b12f8cc6c64798561f377f6adba5e0a	American Express	37.7543103199509673	-122.407417071382028
12206	2020-02-13 23:01:37	2020-02-13	Hillary Metz	hillary.metz@warmmail.com	Bakersfield	California	180078606761178301	bc80293cd9dff63ec97e3976d0e325c6	VISA 16 digit	35.3258836190391321	-119.070421329680087
12207	2020-02-13 23:06:33	2020-02-13	Carol Gaylord	carol.gaylord@geemail.com	Phoenix	Arizona	3059984715546509	546a56e17c786a6b6c0c78786cd51b68	JCB 16 digit	33.5712283057559304	-112.138094258347905
12208	2020-02-13 23:12:00	2020-02-13	Alisa Abshire-Hettinger	alisa.abshire.hettinger@warmmail.com	San Diego	California	4873318349471557	435b6276c287cc98dcca056311b47649	American Express	32.8861745190873762	-117.178120889691641
12209	2020-02-13 23:22:56	2020-02-13	Rudolfo Lockman Jr.	rudolfo.lockman.jr.@geemail.com	Wichita	Kansas	3488286856007786	2825a575cfc00d24af12bd058de2ada4	VISA 16 digit	37.6246918538928057	-97.4452927988689339
12210	2020-02-13 23:42:19	2020-02-13	Kaley Deckow	kaley.deckow@warmmail.com	Berkeley	California	6011140386080557394	7da3a6fadf1931539c5489673c1b7939	JCB 16 digit	37.9044420111904117	-122.263028702432877
12211	2020-02-13 23:48:07	2020-02-13	Corrina Bednar	corrina.bednar@geemail.com	Philadelphia	Pennsylvania	869901462314412884	21155553801cf286e774d758f2fec10a	JCB 15 digit	39.9514445676893004	-75.2225333797644851
12212	2020-02-13 23:52:38	2020-02-13	Orvel Lindgren	orvel.lindgren@geemail.com	San Francisco	California	639058681688287	e60b5fb08b47175b83f7a3c6a3d7d339	VISA 16 digit	37.7897756568865688	-122.448548072976649
12213	2020-02-14 00:10:10	2020-02-14	Tyree Friesen-Lakin	tyree.friesen.lakin@geemail.com	Oxnard	California	060428061705241	3cd1b3847085642ac25516afcae82961	JCB 16 digit	34.2973116285588588	-119.250041303728153
12214	2020-02-14 00:12:39	2020-02-14	Selmer Boyle	selmer.boyle@geemail.com	New York	New York	6011549345260065005	b352bc5b28185b553cb5a32d884774dc	Discover	40.6102386488802694	-73.9573547213233979
12215	2020-02-14 00:25:48	2020-02-14	Heyward Hauck	heyward.hauck@geemail.com	Surprise	Arizona	4114451713025714	3b7c110ef51aa5664227b178b05788c0	VISA 16 digit	33.7014003071695569	-112.372266729944187
12216	2020-02-14 00:32:26	2020-02-14	Love Tromp	love.tromp@warmmail.com	San Francisco	California	3337413003173804506	923fd9cdc64ae8153abfe695c107cc5a	VISA 13 digit	37.7457974541253733	-122.446892479166578
12217	2020-02-14 00:48:33	2020-02-14	Joey Wunsch I	joey.wunsch.i@geemail.com	Phoenix	Arizona	503894078579763	f01f5d2be27da0ce628930eb75555d72	VISA 16 digit	33.6410758217263961	-112.072728170726833
12218	2020-02-14 00:49:00	2020-02-14	Yesenia Kunze	yesenia.kunze@geemail.com	Providence	Rhode Island	3420196266697913	d5a2b572872e8cfa4c8708d921688dd6	Mastercard	41.8940397951606656	-71.3230808044701803
12219	2020-02-14 01:14:10	2020-02-14	Anya Batz	anya.batz@geemail.com	New York	New York	4625079603679001	3feff9cf3f538428a40f4a68cd48e283	VISA 16 digit	40.6908596848826818	-73.9124579299136997
12220	2020-02-14 01:15:46	2020-02-14	Mrs. Violet Grimes DVM	mrs.violet.grimes.dvm@geemail.com	Los Angeles	California	210027973075817939	7ac2823679ccb706924212ce98243f1a	Diners Club / Carte Blanche	34.0523614116344575	-118.484120443369449
12221	2020-02-14 02:24:29	2020-02-14	Gardner Mayer	gardner.mayer@geemail.com	Philadelphia	Pennsylvania	3158606814770592147	9c005e6913317223aec518d77ab14661	Diners Club / Carte Blanche	40.0949194689240329	-75.1044975968442969
12222	2020-02-14 02:46:44	2020-02-14	Doll Metz	doll.metz@geemail.com	San Jose	California	4582310075012	5704e994ea59aa570c9e8b19293c7552	Voyager	37.2931376744348597	-121.851993511359765
12223	2020-02-14 02:50:01	2020-02-14	Dr. Liana McKenzie	dr.liana.mckenzie@geemail.com	Washington	District of Columbia	3722596641937439	ffd3655c161160b8dcf95dbcc3a8f227	Voyager	38.8499014162257339	-76.991904770697289
12224	2020-02-14 03:06:30	2020-02-14	Yandel Haag	yandel.haag@geemail.com	San Francisco	California	180017971264131809	f431d6ad994cb51c913df2fb445443b4	VISA 16 digit	37.761581524367088	-122.443962305484391
12225	2020-02-14 03:32:53	2020-02-14	Alyse Schaefer DDS	alyse.schaefer.dds@geemail.com	Garland	Texas	4685827614691036	cccd94f00c4be16cc6a5d62a27b71acc	JCB 16 digit	32.892728454317151	-96.5838573959350697
12226	2020-02-14 03:34:37	2020-02-14	Dorathea Pfeffer	dorathea.pfeffer@geemail.com	Palmdale	California	630498691432672	5a4f86b364de546ba96f75e6ddf10c70	Maestro	34.5494680534433556	-118.038005048455304
12227	2020-02-14 03:51:01	2020-02-14	Enrique Moore MD	enrique.moore.md@geemail.com	Little Rock	Arkansas	6011332493399014931	8ad4b360283127e46d054fb60cb6b6e1	JCB 15 digit	34.7293836719632125	-92.3818511647976948
12228	2020-02-14 03:57:17	2020-02-14	Torry Funk	torry.funk@warmmail.com	Los Angeles	California	3096244691471598427	cb7a9d38d563b3e6509d7fb1e777d58c	VISA 16 digit	34.0369375116989019	-118.503290462120617
12229	2020-02-14 04:04:43	2020-02-14	Graham Kub	graham.kub@geemail.com	Aurora	Colorado	3337742754626899673	48e81280baaefd58acbc77234caf1e32	Mastercard	39.7185087713059062	-104.770282625791438
12230	2020-02-14 04:40:55	2020-02-14	Neva D'Amore	neva.d'amore@geemail.com	Lancaster	California	180016511496238005	fb942ab469fda872c945cc40d652d7c0	Maestro	34.6649100489694675	-118.205010192698978
12231	2020-02-14 04:44:17	2020-02-14	Anjali Grady DDS	anjali.grady.dds@woohoo.com	San Antonio	Texas	3707841157621426	0da5796ff93ee7f55da4a20de6d02117	VISA 16 digit	29.3961051781266924	-98.5938046498991554
12232	2020-02-14 04:51:30	2020-02-14	Waino Rau	waino.rau@geemail.com	Bellevue	Washington	4817014785072	e1d34b0848b6cf6a078a49c4bfeae979	Mastercard	47.5636819116022451	-122.128111001435656
12233	2020-02-14 05:01:44	2020-02-14	Jeannette Reinger	jeannette.reinger@geemail.com	Santa Ana	California	3028185165237018	fe682f71ecb41635f66787c8dc7b8ec0	JCB 16 digit	33.8054366505343467	-117.920864254554729
12234	2020-02-14 05:08:04	2020-02-14	Fisher Bechtelar-Pfannerstill	fisher.bechtelar.pfannerstill@geemail.com	Sandy Springs	Georgia	3088912104124917292	0d2dbcb9adc3e798ab455bd6af0d6381	VISA 16 digit	33.8715884399656204	-84.4327392397530474
12235	2020-02-14 05:12:39	2020-02-14	Mrs. Betsey Hahn PhD	mrs.betsey.hahn.phd@geemail.com	San Francisco	California	676348272414318	605613355ee926d5a0846abb1e5a1989	VISA 16 digit	37.7928278536107953	-122.413207364755053
12236	2020-02-14 05:21:25	2020-02-14	Kinsley Breitenberg PhD	kinsley.breitenberg.phd@warmmail.com	Wichita	Kansas	3704523540027270	4a722ce037796814eb8838ac6e9f48de	VISA 13 digit	37.6302813574083146	-97.3858424316361493
12237	2020-02-14 05:49:29	2020-02-14	Refugio Smitham IV	refugio.smitham.iv@geemail.com	San Mateo	California	3415619004471934	91c5805d097881a441028e5dc1644c4f	VISA 16 digit	37.5594208630148287	-122.314344990704569
12238	2020-02-14 05:51:42	2020-02-14	Marcelle Morissette-Gleason	marcelle.morissette.gleason@geemail.com	Omaha	Nebraska	4734433205014	bbf68846eb82b7fab409f9787301365c	Voyager	41.2213892945699385	-95.9833500620093218
12239	2020-02-14 05:56:49	2020-02-14	Octavie McCullough	octavie.mccullough@geemail.com	Hillsboro	Oregon	3044521949290960	318cad7b5fe389ea878fd8bae2cbb375	Voyager	45.523475800009443	-122.888486949556324
12240	2020-02-14 06:24:11	2020-02-14	Miss Haven Bartell	miss.haven.bartell@warmmail.com	San Francisco	California	180022089993881488	49e7201b591c0de151ea0c2fbc46b07d	Voyager	37.7761544508464908	-122.442442841479107
12241	2020-02-14 06:29:32	2020-02-14	Hamza Reichel	hamza.reichel@geemail.com	Charlotte	North Carolina	210066764113728465	5d5e5b4e45a06934911ab9d4b0338b4f	JCB 16 digit	35.2660458674907673	-80.7436943815965265
12242	2020-02-14 06:34:27	2020-02-14	Pam Bergstrom	pam.bergstrom@geemail.com	New York	New York	51676775104012877	a05fea3def4de0368fc2c337af9ad0ff	Mastercard	40.5735502507295465	-73.9329236468661577
12243	2020-02-14 06:35:32	2020-02-14	Bettye Ernser	bettye.ernser@woohoo.com	New York	New York	4250264308240885	ce4175217fbb786233b73f8f0d6d0c54	Mastercard	40.704109221952038	-73.9133138641610685
12244	2020-02-14 06:40:11	2020-02-14	Kinsey Nicolas-Padberg	kinsey.nicolas.padberg@woohoo.com	Albuquerque	New Mexico	6011797206241297381	cf71a07c664866aa6a51f4df8c72e80e	Diners Club / Carte Blanche	35.2022914032585916	-106.641758172221117
12245	2020-02-14 06:56:08	2020-02-14	Maddux O'Hara	maddux.o'hara@geemail.com	San Antonio	Texas	6011841690314655698	81ca657bd329b617cb571f96f0e9f5f7	VISA 13 digit	29.4796391332592833	-98.4485052013140063
12246	2020-02-14 07:36:23	2020-02-14	Wallace Blick-Brekke	wallace.blick.brekke@geemail.com	San Antonio	Texas	3796963534076629	a2d11a20e61e9f463b226f97f1422b31	JCB 16 digit	29.5411656992115077	-98.4903387036941922
12247	2020-02-14 07:50:06	2020-02-14	Jaime Beer	jaime.beer@woohoo.com	Bakersfield	California	210015519239611108	7a0159d8710d49af79a179ad8a54f2aa	JCB 15 digit	35.3585236492276138	-119.020500365532186
12248	2020-02-14 07:58:43	2020-02-14	Kendall Schmeler	kendall.schmeler@geemail.com	Berkeley	California	3003996127040729	c6eb6272d21381e72716663a7a71ef55	VISA 16 digit	37.8676976750915131	-122.291903658397132
12249	2020-02-14 08:05:18	2020-02-14	Bettye Ratke	bettye.ratke@geemail.com	Los Angeles	California	503831856579201	0d99c9e30802eba3a5cacab4aaf935b7	JCB 16 digit	34.0927093625865822	-118.427609598775575
12250	2020-02-14 08:14:20	2020-02-14	Rolla Christiansen	rolla.christiansen@geemail.com	Columbus	Ohio	869959338902076466	b481671146da8eb04436b943e3ae4da3	Maestro	40.0082475616175657	-82.9136820208050409
12251	2020-02-14 08:17:03	2020-02-14	Makayla Pfannerstill-Brown	makayla.pfannerstill.brown@warmmail.com	El Paso	Texas	869920730796275012	4550c3e8577a40a3bf67aaedd98880fb	Diners Club / Carte Blanche	31.8613691381473103	-106.377539466040218
12252	2020-02-14 08:22:23	2020-02-14	Miss Malia Price PhD	miss.malia.price.phd@woohoo.com	Phoenix	Arizona	54920906365463038	a998dbe1d73b3ad767b3a40c62d4aca6	VISA 16 digit	33.4774785973530271	-112.16284157628418
12253	2020-02-14 08:31:48	2020-02-14	Allison Gaylord	allison.gaylord@geemail.com	Oakland	California	561288543515733	9445f7f6e3cdca4454f40c71a7bfdabd	Mastercard	37.8516456154454275	-122.261819628119241
12254	2020-02-14 08:38:07	2020-02-14	Dr. Fredrick Jones II	dr.fredrick.jones.ii@geemail.com	San Francisco	California	639005023898025	4184a3eed56e9da1501c309b9a898f9a	VISA 16 digit	37.7750207968779961	-122.424968879420703
12255	2020-02-14 08:40:38	2020-02-14	Regina Dickinson	regina.dickinson@geemail.com	Vancouver	Washington	3337688450874525096	bcf709276190074e4dee2c97e27b3f5d	American Express	45.6188794332627197	-122.550899068691578
12256	2020-02-14 08:54:23	2020-02-14	Mrs. Lauretta Jerde DDS	mrs.lauretta.jerde.dds@geemail.com	Sterling Heights	Michigan	3112078499716929980	6219c7be83677aebf684d5f7b2324b84	VISA 16 digit	42.4862394229125258	-82.9951901047650722
12257	2020-02-14 09:39:20	2020-02-14	Paloma Bayer PhD	paloma.bayer.phd@geemail.com	San Francisco	California	869968148600961227	d92bee6956b9f423ac30feacfff2ffe5	Diners Club / Carte Blanche	37.7868417624288213	-122.457999403852611
12258	2020-02-14 09:50:55	2020-02-14	Delta Beier	delta.beier@warmmail.com	San Francisco	California	4795143284206080	aca17a0a4a7a7a8abd6e0a215827b831	Maestro	37.7414879549406663	-122.43281476304611
12259	2020-02-14 10:14:01	2020-02-14	Scarlett Barrows MD	scarlett.barrows.md@warmmail.com	Virginia Beach	Virginia	4385019885263	2e00e1b9d948afc9f0184c6a4a9980e6	VISA 13 digit	36.7926869635190812	-76.1062129148885589
12260	2020-02-14 10:15:51	2020-02-14	Humberto Harber	humberto.harber@woohoo.com	Newport News	Virginia	3096728319577597342	347a3d4005528a7bf9efff3409f36027	Maestro	37.1645097488433152	-76.5047302156016258
12261	2020-02-14 10:19:36	2020-02-14	Dr. Davis Wehner V	dr.davis.wehner.v@geemail.com	New York	New York	3453528537089068	1edb3eb072ed7d982a550ee38a010bef	Discover	40.7256419465169301	-73.9849473361752956
12262	2020-02-14 10:34:29	2020-02-14	Alvira Schamberger-Stanton	alvira.schamberger.stanton@geemail.com	Raleigh	North Carolina	3158419917018871913	834ea03487bf36a3375e9fdb1cb5ba81	VISA 13 digit	35.7571151336323467	-78.566782321169228
12263	2020-02-14 10:35:54	2020-02-14	Silvio Batz	silvio.batz@geemail.com	San Francisco	California	55458697891116196	0b3d2825cb67d581154a9483bdd9bb6f	JCB 16 digit	37.7934008788885194	-122.400667809456692
12264	2020-02-14 10:42:05	2020-02-14	Tammy Aufderhar	tammy.aufderhar@geemail.com	Davenport	Iowa	4324621885659724	8eb9441f5b13754da594d1e2542ad822	VISA 13 digit	41.6140015172570941	-90.6291718954648786
12265	2020-02-14 10:42:29	2020-02-14	Jeanie Parisian	jeanie.parisian@warmmail.com	San Francisco	California	6011571307556066981	d4395affdd17db412764049763cd669b	Voyager	37.7528770687534632	-122.423926083064515
12266	2020-02-14 10:42:41	2020-02-14	Infant Greenfelder	infant.greenfelder@warmmail.com	Los Angeles	California	3431314269394787	5b7a5250441acec8445cd12402b5c515	VISA 16 digit	33.9866558360267419	-118.379707838314772
12267	2020-02-14 10:57:30	2020-02-14	Rosalie Koss	rosalie.koss@geemail.com	San Francisco	California	869982683195396738	6231e6e27639e87cc0f98448eeb3c6a0	JCB 16 digit	37.7685834243825198	-122.426960587975458
12268	2020-02-14 10:57:49	2020-02-14	Mr. Kade Rolfson II	mr.kade.rolfson.ii@geemail.com	San Francisco	California	4270250805809930	e6e3ba47b2349fd15b8e876e23526ced	Diners Club / Carte Blanche	37.7353105122743813	-122.432690448679097
12269	2020-02-14 11:26:02	2020-02-14	Dannie Maggio	dannie.maggio@geemail.com	Fort Worth	Texas	3459603282658799	93c508917e199692887ffd0a18da8904	JCB 16 digit	32.8323298110216868	-97.3359936402931822
12270	2020-02-14 11:44:32	2020-02-14	Miss Grace Greenholt	miss.grace.greenholt@geemail.com	Glendale	Arizona	6011355667268205694	3ca91d948c29290195c744b11afa76ae	Mastercard	33.5737091931741674	-112.108070975102109
12271	2020-02-14 11:49:32	2020-02-14	Frankie Hand	frankie.hand@geemail.com	San Francisco	California	4715503565510	c60588db0c0f2d543554372da0c67fe7	VISA 16 digit	37.7892767388093631	-122.43796195153422
12272	2020-02-14 11:50:18	2020-02-14	Ritchie Aufderhar-Wiegand	ritchie.aufderhar.wiegand@geemail.com	Lancaster	California	3337042154607542490	805dd637ccae932e4aad3c9f4bc1086e	American Express	34.7801743752103363	-118.245616687645381
12273	2020-02-14 11:50:45	2020-02-14	Kamila Leannon	kamila.leannon@geemail.com	Boise	Idaho	4955982509083121	84e65126ad9736b733c277cdfd20d8c8	Mastercard	43.5427838179886351	-116.145936622955659
12274	2020-02-14 11:51:52	2020-02-14	Chancey Kassulke Jr.	chancey.kassulke.jr.@geemail.com	Berkeley	California	4023220117313	fa7dd54d5e5b8515c461e352b360355f	JCB 16 digit	37.8572958977537724	-122.253394000954728
12275	2020-02-14 12:00:41	2020-02-14	Ceasar Zboncak II	ceasar.zboncak.ii@geemail.com	Olathe	Kansas	3736202203787189	fe174f9a51d002c0096f5794fa074e81	Discover	38.7961933939840691	-94.8636985134501032
12276	2020-02-14 12:02:17	2020-02-14	Stanford Carroll-Feest	stanford.carroll.feest@woohoo.com	San Francisco	California	4821221101345972	423c0c4321e44373f6e92fcd8878c6bc	JCB 16 digit	37.7993751985651443	-122.446990424661607
12277	2020-02-14 12:04:27	2020-02-14	Dr. Larue Walter I	dr.larue.walter.i@geemail.com	Fresno	California	3409584109688436	a246bfdb1a4498ad159b8eb570ca1004	JCB 16 digit	36.770776720285788	-119.819352727952975
12278	2020-02-14 12:08:45	2020-02-14	Violetta Parisian	violetta.parisian@woohoo.com	San Francisco	California	502029806143425	3215ceb9e42643ebf5fdb9d08fca5677	VISA 16 digit	37.7875094159571034	-122.377361957334813
12279	2020-02-14 12:10:17	2020-02-14	Demario Bailey-Pacocha	demario.bailey.pacocha@geemail.com	Sterling Heights	Michigan	210052800273802108	e102fed70d019758ee6bb13dd80d5575	Diners Club / Carte Blanche	42.6736189150799063	-83.0149109926234843
12280	2020-02-14 12:35:29	2020-02-14	Arlington DuBuque	arlington.dubuque@geemail.com	San Mateo	California	3112839660268985452	9fa80868412515551528ea53adf4efe7	JCB 15 digit	37.486389641079306	-122.229530613202968
12281	2020-02-14 12:41:22	2020-02-14	Mrs. Olena Nolan PhD	mrs.olena.nolan.phd@geemail.com	San Francisco	California	3047405235702267	ad6ca793b2b34394c34aeb059f622444	Voyager	37.7768431484075577	-122.427173094770879
12282	2020-02-14 13:13:22	2020-02-14	Dr. Hayden Kuhn	dr.hayden.kuhn@warmmail.com	Dayton	Ohio	55719911513807099	d896034ad1d374b11f356d7f02e9ea01	JCB 16 digit	39.6842333105649772	-84.254380325433246
12283	2020-02-14 13:47:28	2020-02-14	Mrs. Pennie Bins	mrs.pennie.bins@geemail.com	San Francisco	California	6011233848385106613	e7b7b7a2d2a1e6e69f01f11cb1aae457	VISA 16 digit	37.7594559438026636	-122.413213684744477
12284	2020-02-14 15:10:12	2020-02-14	Mr. Wayne Mayert	mr.wayne.mayert@geemail.com	San Francisco	California	3402523958493628	60138eaa3b67d563c293d6e747a7cd21	Maestro	37.7279824254398477	-122.43847823247836
12285	2020-02-14 15:14:15	2020-02-14	Cassidy Cummerata	cassidy.cummerata@geemail.com	San Francisco	California	4921049855945864	4dc0f2f7f7b19d156cf4d8d7a9ee306a	JCB 15 digit	37.7732055908601012	-122.421378649734436
12286	2020-02-14 15:47:26	2020-02-14	Desean Turner	desean.turner@geemail.com	Austin	Texas	3096683942570731171	d79e9c5969267c1183d0abfb56c2ed30	Maestro	30.3422560752496118	-97.657756445208193
12287	2020-02-14 16:00:49	2020-02-14	Daisie Gutmann-Bins	daisie.gutmann.bins@geemail.com	Moreno Valley	California	51350420947781015	efeec1f996ecdcbdeb12b796b849462b	JCB 15 digit	33.910356762166316	-117.247549890816956
12288	2020-02-14 16:15:09	2020-02-14	Della Fadel-Mosciski	della.fadel.mosciski@woohoo.com	New York	New York	3528285551525014450	596d58939024d88db50f2d39472fb846	American Express	40.6575382145345188	-73.9913209347415659
12289	2020-02-14 16:26:29	2020-02-14	Marylin Dare-Harvey	marylin.dare.harvey@geemail.com	Fairfield	California	3096498814300721415	e0dbc30462f45822fe2ae66c2f91922e	American Express	38.2984359200235502	-122.03279612837396
12290	2020-02-14 16:48:34	2020-02-14	Shepherd Raynor	shepherd.raynor@warmmail.com	College Station	Texas	54170150208227436	8c984f31795b7f07a779d019b27a0eba	VISA 16 digit	30.5687407952778045	-96.393932402165234
12291	2020-02-14 17:00:34	2020-02-14	Hideo Zboncak	hideo.zboncak@geemail.com	Kansas City	Kansas	3015343324833176	2f4f37f9fab52681f038039957b85beb	Maestro	39.0782775582652562	-94.793552519235007
12292	2020-02-14 17:22:56	2020-02-14	Derl Feest	derl.feest@geemail.com	Buffalo	New York	4220365265468331	0b6fb7fdb6c468a0168dfde7c871cc42	JCB 16 digit	42.8687897122185646	-78.8835792216870999
12293	2020-02-14 17:24:57	2020-02-14	Memphis Kling-Little	memphis.kling.little@geemail.com	Columbus	Georgia	3337717144559050778	9f6f81164cc3c1ca60019d543c026395	Voyager	32.535698677976427	-84.8253587561823394
12294	2020-02-14 17:26:56	2020-02-14	Gladyce Dibbert	gladyce.dibbert@geemail.com	Chicago	Illinois	3088959655444038758	6b1b408b9e2f102e89e9d5e3dfcbdaf8	VISA 16 digit	41.8015355775900233	-87.6805208973150627
12295	2020-02-14 17:38:27	2020-02-14	Jan Balistreri-Renner	jan.balistreri.renner@geemail.com	New York	New York	6011160187842190317	8bfc501f385e4029a87da7172795944e	Discover	40.6996342593561877	-73.9554228200007202
12296	2020-02-14 18:11:49	2020-02-14	Geralyn McKenzie	geralyn.mckenzie@woohoo.com	San Francisco	California	6011566525583184272	174dba8072aea06ae81d6306e41c384c	Voyager	37.7977749000900118	-122.411766639438937
12297	2020-02-14 18:13:16	2020-02-14	Myrtice Conn-Pagac	myrtice.conn.pagac@geemail.com	Omaha	Nebraska	3088340666912166961	4e1a7294909b078b90f98ca289cb46ef	JCB 16 digit	41.1713546342361738	-96.0737297393962848
12298	2020-02-14 18:19:08	2020-02-14	Mrs. Dianna Stamm	mrs.dianna.stamm@warmmail.com	Waco	Texas	210044193708451233	0ba2cfac1d31a16b00f808692a396b1b	Mastercard	31.5895726257678113	-97.202092783957724
12299	2020-02-14 18:21:13	2020-02-14	Carol Carter	carol.carter@geemail.com	Washington	District of Columbia	180033622986323881	c32909ee14b60b9262b86056dc174596	VISA 16 digit	38.8352592429876324	-77.1077301342252639
12300	2020-02-14 18:40:17	2020-02-14	Maeve Fisher	maeve.fisher@geemail.com	Oklahoma City	Oklahoma	55256224869020781	6b8d0ef955f1adb01f77834fa8316da1	Diners Club / Carte Blanche	35.5111973877906806	-97.4939540425676796
12301	2020-02-14 18:52:24	2020-02-14	Jacques Daniel	jacques.daniel@geemail.com	San Francisco	California	4054839391435472	2af69e94079042ee3c36f826cf6c4338	JCB 16 digit	37.770680716150018	-122.417205639640486
12302	2020-02-14 18:54:17	2020-02-14	Maximo Padberg-Ankunding	maximo.padberg.ankunding@geemail.com	Boston	Massachusetts	3158607782247799513	356712ea7624d42754cddb633eff2c46	Diners Club / Carte Blanche	42.281337629042568	-71.1167904920827567
12303	2020-02-14 18:58:34	2020-02-14	Adelbert Littel	adelbert.littel@warmmail.com	Tulsa	Oklahoma	4729789580812	24c3d1633cf28cb0ae403de220307aef	Discover	36.105828062621498	-95.8344251489687622
12304	2020-02-14 18:58:46	2020-02-14	Crockett Kuphal	crockett.kuphal@geemail.com	Billings	Montana	869940919733102407	f26f6bbe33aeda2c49ac9924de31fa24	JCB 16 digit	45.8838350359108276	-108.459867789845532
12305	2020-02-14 19:13:39	2020-02-14	Cristy Hauck PhD	cristy.hauck.phd@geemail.com	San Francisco	California	3740595333788488	3c339cffbbfff232602b872e95a0741d	American Express	37.7481637644812196	-122.396577426719347
12306	2020-02-14 19:20:05	2020-02-14	Lenord Haag Jr.	lenord.haag.jr.@geemail.com	Chicago	Illinois	4834672175785	d33d611acb493cde4c490910026f04e2	JCB 16 digit	41.8335119603037882	-87.5831727530837014
12307	2020-02-14 19:23:00	2020-02-14	Milan Wunsch	milan.wunsch@geemail.com	San Francisco	California	589360871938258	0e5b88a0c1e72691cba460c4bb246f71	Maestro	37.7920207899663652	-122.435145944499894
12308	2020-02-14 19:48:43	2020-02-14	Maybelle Christiansen	maybelle.christiansen@geemail.com	Antioch	California	4895858330908	f75fdd316acbe01cc411d20b0afe846d	VISA 16 digit	38.0380216724503839	-121.752551555697622
12309	2020-02-14 20:16:33	2020-02-14	Juan Bogisich	juan.bogisich@geemail.com	San Antonio	Texas	53456026876213780	e7f7f602357842f3d1755698f0b5aa94	American Express	29.5531150403969001	-98.4555916985798518
12310	2020-02-14 20:19:21	2020-02-14	Nelly Mertz	nelly.mertz@geemail.com	San Francisco	California	6011949096233337692	e793eed124317ad89920d395919b852d	Diners Club / Carte Blanche	37.7661101398110119	-122.469776600952358
12311	2020-02-14 20:32:36	2020-02-14	Crawford Thompson	crawford.thompson@geemail.com	Arlington	Texas	4050085854169	3f13223a90bfaa65715811c7038d5575	VISA 13 digit	32.7440498024009159	-97.0804041405234557
12312	2020-02-14 21:19:49	2020-02-14	Miss Katelin Mertz DDS	miss.katelin.mertz.dds@warmmail.com	Centennial	Colorado	52279066774809508	80db1f088bdd88488b47b8ec570f8db4	Discover	39.6436281961429913	-104.784988428129253
12313	2020-02-14 21:32:49	2020-02-14	Mr. Chaz Stiedemann	mr.chaz.stiedemann@woohoo.com	Columbus	Ohio	676361869709602	f003d10168874dcea460590c49ff8176	JCB 16 digit	39.9614339129578298	-82.9361224542606692
12314	2020-02-14 21:35:44	2020-02-14	Lew Brakus-Gusikowski	lew.brakus.gusikowski@warmmail.com	Miami	Florida	6011715838900491951	ec0f306bef63a2233756eb9dc69de7ea	VISA 13 digit	25.8280246116358789	-80.1649748702406981
12315	2020-02-14 22:36:01	2020-02-14	Daniel Howe	daniel.howe@warmmail.com	New York	New York	210001521099270930	74f48356eff4fd39db6e2a23d263af0f	VISA 16 digit	40.6259237210024153	-73.9091529270064029
12316	2020-02-14 22:38:51	2020-02-14	Aurelio Spinka Jr.	aurelio.spinka.jr.@geemail.com	Plano	Texas	3528756136833810565	0acd8c017641c2660138919a2bfb27ac	Discover	33.1424106535587484	-96.8179479893479566
12317	2020-02-14 23:05:52	2020-02-14	Kristin O'Kon	kristin.o'kon@geemail.com	Downey	California	3762260176840002	819a29a3349a2ff7423eaf0f108cb5f4	JCB 15 digit	33.8513141631864016	-118.201788136560097
12318	2020-02-14 23:18:22	2020-02-14	Ruffin Halvorson	ruffin.halvorson@geemail.com	Houston	Texas	3112814540739331511	d79d5a724d5bb8eff8bcdaf06aaeab1a	Mastercard	29.7044908839356161	-95.4792147933986115
12319	2020-02-14 23:37:54	2020-02-14	Dr. Donat Parisian Sr.	dr.donat.parisian.sr.@geemail.com	Cedar Rapids	Iowa	869936515018553151	26f4d6a1c4c968ab172ad335518379b7	Mastercard	42.0015845813862967	-91.7630739779278741
12320	2020-02-14 23:54:57	2020-02-14	Mrs. Leta Koch DVM	mrs.leta.koch.dvm@geemail.com	San Antonio	Texas	52448259144238336	c65b25e5a3d003fc9859a5c06b6c1291	Diners Club / Carte Blanche	29.5252287898749124	-98.4307483893655188
12321	2020-02-15 00:14:16	2020-02-15	Ms. Miya Brekke	ms.miya.brekke@geemail.com	New York	New York	55273840571778207	c095a9fd70e507fbd2345f4c2c13b429	Maestro	40.7052108532041288	-73.9174020382937016
12322	2020-02-15 00:14:27	2020-02-15	Malachi Goodwin DDS	malachi.goodwin.dds@geemail.com	New York	New York	210005857189837998	3ca98d66b24d98916b026b2baf045900	VISA 13 digit	40.7472344358209497	-74.0115553271386801
12323	2020-02-15 00:45:54	2020-02-15	Erasmus Rohan	erasmus.rohan@geemail.com	Columbus	Ohio	4187977291082	dfb00393459ba121d3d92e25455b1b95	JCB 16 digit	39.9957571618303618	-82.9097530847184458
12324	2020-02-15 01:16:32	2020-02-15	Lauryn Lind	lauryn.lind@warmmail.com	New York	New York	4256839689492	b25d50dcba2fbbdabb8d04ab575647e8	VISA 16 digit	40.5775293943695701	-73.9475426248170464
12325	2020-02-15 01:46:17	2020-02-15	Jolie Schmeler	jolie.schmeler@geemail.com	Kansas City	Missouri	52724048127412371	0bd558b8c1b3fad2410ccdefd5a34f29	Voyager	39.1156756865628097	-94.5007884973883705
12326	2020-02-15 01:47:42	2020-02-15	Austin Schoen-Dibbert	austin.schoen.dibbert@woohoo.com	San Francisco	California	4871686804174	2669f61ab30284ae9ccbfd19b2320f02	VISA 16 digit	37.7808236903853398	-122.430766611764597
12327	2020-02-15 01:49:00	2020-02-15	Mrs. Magnolia Gislason	mrs.magnolia.gislason@warmmail.com	Fargo	North Dakota	3112197824018665063	1cda24b63a51b5d5a83b7ad0eb057d97	VISA 16 digit	46.7916699254184962	-96.7404631816744711
12328	2020-02-15 01:53:14	2020-02-15	Joshuah Lehner III	joshuah.lehner.iii@geemail.com	Vancouver	Washington	3733333621960083	726202009a9a72b13dcf3bc15f67ad2c	Maestro	45.6589896801464263	-122.561116425699367
12329	2020-02-15 02:08:48	2020-02-15	Duke Miller	duke.miller@warmmail.com	Houston	Texas	180048576390399973	2a21505a76df0f2b7a19e53d045f75fc	Voyager	29.7689691177647546	-95.2999395640116234
12330	2020-02-15 02:11:29	2020-02-15	Jody Berge	jody.berge@geemail.com	El Paso	Texas	210036274499853413	49b0161eff170487daed702d803306bf	VISA 13 digit	31.8202774894718097	-106.51634002844618
12331	2020-02-15 02:15:03	2020-02-15	Herman Yundt	herman.yundt@geemail.com	Oklahoma City	Oklahoma	180069600459238437	1ef6a33f04ff264098da3572b42170c9	JCB 16 digit	35.3976226844735464	-97.5237640921853455
12332	2020-02-15 02:15:44	2020-02-15	Thurston Kub	thurston.kub@geemail.com	San Francisco	California	3096688512921177377	80c26485f6fd7c04e1a763fa7a66972a	Voyager	37.7774367228295915	-122.435597645569004
12333	2020-02-15 02:18:31	2020-02-15	Orlo Krajcik	orlo.krajcik@woohoo.com	Pittsburgh	Pennsylvania	53616186333522087	62dc9ee85a522a73a56f9210f2ef46ff	JCB 15 digit	40.3739040463652472	-80.0180816331584026
12334	2020-02-15 02:59:18	2020-02-15	Joel Walter DVM	joel.walter.dvm@geemail.com	Berkeley	California	3043985722080636	0002a3fab8b7d26ba0b9a1e44e420f74	VISA 16 digit	37.9017588223860002	-122.248987301880717
12335	2020-02-15 03:29:47	2020-02-15	Ainsley Abshire PhD	ainsley.abshire.phd@geemail.com	Atlanta	Georgia	676156582114700	45ce07966292be8bc3124f22d03cb7ea	JCB 16 digit	33.7108467943776446	-84.4498329452749346
12336	2020-02-15 03:38:11	2020-02-15	Gust Murphy	gust.murphy@geemail.com	Los Angeles	California	3112238041886526787	5bade4813083a93e305855ed6dd9ff2c	Voyager	34.0758773847814638	-118.36668891785591
12337	2020-02-15 03:42:51	2020-02-15	Bruce Von	bruce.von@geemail.com	Newport News	Virginia	3040261905453286	8dcb440585e5115cfcfd429a03482c72	Discover	37.153758588469401	-76.4832951531075054
12338	2020-02-15 03:54:50	2020-02-15	Mrs. Santos Dare MD	mrs.santos.dare.md@geemail.com	San Francisco	California	3420120033382666	f85fc002650cbefa1ecbeff5c940d211	JCB 16 digit	37.7646946192419435	-122.444392587091883
12339	2020-02-15 04:12:19	2020-02-15	Harrell Baumbach	harrell.baumbach@geemail.com	Madison	Wisconsin	4100027189561493	f6eaad8f88805aa69b8bef8d4f923f43	American Express	43.1488284348484115	-89.4198710377678339
12340	2020-02-15 04:22:17	2020-02-15	Jamarcus Raynor	jamarcus.raynor@geemail.com	Midland	Texas	4175908662695	e197cd08abf714c2610b953d3535ee94	Discover	32.0470186795763681	-102.209624406531461
12341	2020-02-15 04:38:40	2020-02-15	Ms. Audriana Kutch	ms.audriana.kutch@woohoo.com	Oakland	California	3088768987868185943	60a668a976ceea5aec4b4605eb361cf5	JCB 15 digit	37.7937169907874164	-122.242486551182722
12342	2020-02-15 04:46:36	2020-02-15	Lindsay Hartmann	lindsay.hartmann@geemail.com	Austin	Texas	869987937506329597	62a8aea26cf4cbdc32e2efb32292ad8d	JCB 16 digit	30.2924438719298692	-97.7561441008705714
12343	2020-02-15 04:58:08	2020-02-15	Gaye Hahn	gaye.hahn@woohoo.com	Charlotte	North Carolina	4971907616492097	0f5eec262bd916146a1d9f8d05aad0d6	JCB 15 digit	35.3016785230740879	-80.800264179421589
12344	2020-02-15 04:58:39	2020-02-15	Charls Heathcote	charls.heathcote@geemail.com	New York	New York	3750281715508375	7f07f09455a48d6b1832a0e89b378ccf	VISA 16 digit	40.718825355194511	-73.9714916294801981
12345	2020-02-15 05:12:34	2020-02-15	Maceo Willms	maceo.willms@geemail.com	Los Angeles	California	4250804686720667	65c2cde59e25c2d517afd65d10af7123	Mastercard	33.967043802920351	-118.342623904113836
12346	2020-02-15 05:17:03	2020-02-15	Francisca Eichmann-Nikolaus	francisca.eichmann.nikolaus@geemail.com	New York	New York	3744335487853853	9449a55755c11e1258ca4d87b886d1ba	JCB 16 digit	40.654078443510457	-73.9602308833401594
12347	2020-02-15 06:05:38	2020-02-15	Terance Rodriguez	terance.rodriguez@geemail.com	Atlanta	Georgia	4923795431797835	c05015771f359b41fdb168e270e19f80	JCB 15 digit	33.6707130503185113	-84.4943952673625205
12348	2020-02-15 06:17:41	2020-02-15	Ole Williamson	ole.williamson@warmmail.com	Chicago	Illinois	180089879906787750	fff1283ddf43302cb922f698579976ed	Diners Club / Carte Blanche	41.8049900440800926	-87.6442595824163391
12349	2020-02-15 06:24:59	2020-02-15	Odalys Lueilwitz	odalys.lueilwitz@warmmail.com	San Mateo	California	4206407645434	4c3b5108976b227f78f0d445b16916af	Voyager	37.5346286689743351	-122.328536884192744
12350	2020-02-15 06:31:03	2020-02-15	Ms. Sherri Greenholt	ms.sherri.greenholt@geemail.com	Berkeley	California	3528500794553013502	295c9808cd5260bae0f435cd20304cd1	VISA 13 digit	37.863319689961962	-122.300277512143907
12351	2020-02-15 06:41:55	2020-02-15	Dr. Brionna Orn	dr.brionna.orn@woohoo.com	Oakland	California	869990111065064442	6bc0c8df8098e919a6e6537df5e980a4	JCB 16 digit	37.7829342321678823	-122.286165345125326
12352	2020-02-15 06:48:12	2020-02-15	Stacy Daniel	stacy.daniel@geemail.com	San Francisco	California	561285258464164	761e28684b79f6f91d67a1a3819219d7	VISA 16 digit	37.793916668449107	-122.421734102128269
12353	2020-02-15 06:50:39	2020-02-15	Londyn Schmeler	londyn.schmeler@geemail.com	Chicago	Illinois	210094311704104320	c45de0394158a6162cc12c4ccc8840ad	Mastercard	41.8815399234019239	-87.6750494343724114
12354	2020-02-15 07:01:35	2020-02-15	Natosha Luettgen	natosha.luettgen@geemail.com	Springfield	Missouri	3005442025594044	464db13c0a521372e7bea191f482fbf8	Voyager	37.1748992418132715	-93.3598702757444272
12355	2020-02-15 07:05:41	2020-02-15	Tamatha Zemlak	tamatha.zemlak@geemail.com	Hollywood	Florida	3112024389055848120	a8f36d3609db6dd8170ad082f4ad5a2f	American Express	26.0455317105576398	-80.0661020404476602
12356	2020-02-15 07:12:25	2020-02-15	Rolanda Rosenbaum MD	rolanda.rosenbaum.md@geemail.com	Knoxville	Tennessee	55024154714792477	936a38ee94ee22197edd2f9879a6be80	Voyager	35.8855321313317859	-83.954722676960003
12357	2020-02-15 07:19:32	2020-02-15	Oren Marquardt	oren.marquardt@geemail.com	Berkeley	California	4622838219825610	1e6f78a892a1a859b7760584746758f5	JCB 16 digit	37.8891514232610476	-122.27713302912052
12358	2020-02-15 07:22:25	2020-02-15	Dr. Conner Willms I	dr.conner.willms.i@geemail.com	Gresham	Oregon	3016390623961652	03a7d9fd6e392b033dd8ee364adca62a	Diners Club / Carte Blanche	45.4438029394440335	-122.372155857578292
12359	2020-02-15 07:22:26	2020-02-15	Scot Lueilwitz	scot.lueilwitz@geemail.com	Santa Ana	California	3528910232623274550	b98fe04a2f8b30e97573eab4e091fa1d	JCB 16 digit	33.7264753630023435	-117.927276933232321
12360	2020-02-15 08:14:31	2020-02-15	Wing Stark MD	wing.stark.md@woohoo.com	Boston	Massachusetts	3096142900990472748	38aa4c0dea4fd8ba0e93f116ae3627e7	JCB 15 digit	42.4174414546862266	-70.9672612884033498
12361	2020-02-15 08:15:48	2020-02-15	Grove Cronin	grove.cronin@geemail.com	Spokane	Washington	4309823347287784	b57955134033c3a090fc1295baf6baab	Maestro	47.5959375252719923	-117.399073229813212
12362	2020-02-15 08:51:12	2020-02-15	Kadijah Armstrong	kadijah.armstrong@woohoo.com	San Francisco	California	869997160671665335	d84c51a8114b728b0034ccb3cbdcf868	Discover	37.7942055265175441	-122.459070685713144
12363	2020-02-15 09:05:33	2020-02-15	Mr. Reilly Cummings V	mr.reilly.cummings.v@geemail.com	Oceanside	California	53105999947757206	d30bd8ef5911b49aa620df12e759a27a	American Express	33.2034698993321484	-117.374713527419416
12364	2020-02-15 09:12:52	2020-02-15	Lonzo Roberts	lonzo.roberts@warmmail.com	Fort Lauderdale	Florida	3469413898073807	6b60dd49b8570f3911119226e71b6009	JCB 16 digit	26.2111175983667373	-80.1075845996670353
12365	2020-02-15 09:16:13	2020-02-15	Holden Rowe-Littel	holden.rowe.littel@geemail.com	Laredo	Texas	3096427551284567663	083ce331e275b55c804cf42f135bcb19	JCB 16 digit	27.4744560805331943	-99.4123296694371845
12366	2020-02-15 09:20:54	2020-02-15	Cassondra Heathcote	cassondra.heathcote@geemail.com	Houston	Texas	4478720479514982	d216cc531ca7d6e1e51c4822b9eea95e	Voyager	29.6999049095980823	-95.3774744957700449
12367	2020-02-15 09:35:50	2020-02-15	Octavius Kris-Pagac	octavius.kris.pagac@geemail.com	Berkeley	California	3088452443503240447	b24d1a39a0a516da384938717028bc6f	VISA 13 digit	37.9082925194115319	-122.234484438172245
12368	2020-02-15 09:52:22	2020-02-15	Jovita Cummerata	jovita.cummerata@geemail.com	Phoenix	Arizona	4894570652109811	675ec8b1fc4a59f1543d83db64f4933d	JCB 15 digit	33.6719476137708895	-112.139922709010918
12369	2020-02-15 09:52:54	2020-02-15	Alan Windler	alan.windler@geemail.com	New York	New York	4376369830601899	7cec99ee8d8967a36535c82602d213e9	Mastercard	40.6341568241585023	-73.8899392960488797
12370	2020-02-15 10:03:50	2020-02-15	Marolyn Cremin	marolyn.cremin@warmmail.com	Montgomery	Alabama	4528132207428289	2323ad13cd8ae71ec1526f4a17d53efb	VISA 16 digit	32.2799415446750828	-86.3517171648017978
12371	2020-02-15 10:04:42	2020-02-15	Ms. Suellen Renner MD	ms.suellen.renner.md@geemail.com	Newark	New Jersey	869947052324368659	eec8ceb690fa3d29c29dcba0d323460c	VISA 16 digit	40.7144279688511048	-74.1230114752635387
12372	2020-02-15 10:14:37	2020-02-15	Everett Hodkiewicz	everett.hodkiewicz@warmmail.com	El Paso	Texas	210056751906007605	b54b1a46cfa79906eb1db9e4fa89c48d	JCB 16 digit	31.8191683266140544	-106.457992720043293
12373	2020-02-15 10:37:09	2020-02-15	Oralia Maggio	oralia.maggio@woohoo.com	San Francisco	California	3023222610724640	a55e3631d50411a56d5c3e79cc662e1e	VISA 13 digit	37.7805751813516082	-122.395216444861347
12374	2020-02-15 10:45:09	2020-02-15	Elisha Thiel PhD	elisha.thiel.phd@geemail.com	Greensboro	North Carolina	52910082489307329	e027c155587e14287bb2a9c0a1026acf	VISA 13 digit	36.1693040948476678	-79.7758208632450589
12375	2020-02-15 10:50:02	2020-02-15	Reina Halvorson	reina.halvorson@woohoo.com	West Jordan	Utah	4378312874217	690550bbff92a1da1bd74c1fb972802b	VISA 16 digit	40.5191209637351335	-112.022670321081947
12376	2020-02-15 10:55:32	2020-02-15	Barb Pollich MD	barb.pollich.md@woohoo.com	Albuquerque	New Mexico	3096764667381388828	60b5916da74d2a0c3afa31fa0ef799dc	Discover	35.1051930358767521	-106.639684617712732
12377	2020-02-15 11:07:32	2020-02-15	Verlie Bechtelar-Gulgowski	verlie.bechtelar.gulgowski@geemail.com	Escondido	California	3022375592849958	8c6ebb85376947ea1fc68aedc8d05398	Discover	33.0636089115630796	-117.135095445090897
12378	2020-02-15 11:14:14	2020-02-15	Cordaro Hintz DDS	cordaro.hintz.dds@geemail.com	Phoenix	Arizona	869903210346951041	c936ce970c99f62ce0ba9ff1d178c7c7	Maestro	33.5033387870926447	-112.030428215155752
12379	2020-02-15 11:14:50	2020-02-15	Newt Schmitt	newt.schmitt@woohoo.com	San Diego	California	3096587525524283691	60d7801d1fc85b50c4ef8b23888bee0e	American Express	32.7606142310492672	-117.10952886640095
12380	2020-02-15 11:51:36	2020-02-15	Dotty Yost DDS	dotty.yost.dds@geemail.com	Lakeland	Florida	3112875069149556380	274ad831f03dfac5208e78ed0ec88ad5	JCB 16 digit	27.9874385989103445	-81.9492367280531653
12381	2020-02-15 11:54:14	2020-02-15	Anastasia McKenzie-Lind	anastasia.mckenzie.lind@geemail.com	Torrance	California	3429578549671545	81687e63be1076573b4cb6fb0a5854c3	American Express	33.8006493591144661	-118.363264508790891
12382	2020-02-15 12:13:20	2020-02-15	Len McGlynn	len.mcglynn@geemail.com	San Francisco	California	4811336328620	a547603e773674208fbffab494a6fb2e	VISA 16 digit	37.7585557127608098	-122.409947445174268
12383	2020-02-15 12:30:41	2020-02-15	Cathie Raynor	cathie.raynor@geemail.com	Ontario	California	3041352767872124	63a82c9649aa0099a6b253c5a2ca0f8b	VISA 13 digit	34.0241963718231801	-117.567852060367173
12384	2020-02-15 12:50:27	2020-02-15	Cheyenne Cremin	cheyenne.cremin@geemail.com	Gresham	Oregon	4441637557287	490bfc3adcbf935ff0da24b57efe7fb6	VISA 16 digit	45.4613662454254879	-122.359552889623117
12385	2020-02-15 13:04:13	2020-02-15	Conrad Bergnaum	conrad.bergnaum@woohoo.com	Clovis	California	6011142593386796133	8ca607ce0802656da48dba1e4ddfb608	American Express	36.8079048234846482	-119.737283578149601
12386	2020-02-15 13:08:43	2020-02-15	Anahi Schulist	anahi.schulist@geemail.com	San Francisco	California	4267116285437408	d9f11b47e898c98a865015f9557484ef	VISA 16 digit	37.7867172806142619	-122.437679791441866
12387	2020-02-15 13:21:09	2020-02-15	Mr. Donaciano Howe	mr.donaciano.howe@woohoo.com	San Francisco	California	3059982411015878	4727d514e9c3af1299d728c071898af0	JCB 16 digit	37.8039715375584606	-122.41968764709479
12388	2020-02-15 13:31:56	2020-02-15	Talon Spencer IV	talon.spencer.iv@geemail.com	Oakland	California	869918641305730674	964127ac2a69aecbf1ff095d72487582	American Express	37.8266850961262975	-122.254146675226579
12389	2020-02-15 13:34:56	2020-02-15	Keandre Bins	keandre.bins@geemail.com	Phoenix	Arizona	4000406592596703	3fcc44c8bbd50764a28dad9a338a8a3c	JCB 16 digit	33.5940462851364217	-112.153739515545226
12390	2020-02-15 13:59:23	2020-02-15	Dr. Edwina Sipes	dr.edwina.sipes@geemail.com	San Antonio	Texas	3448078586354474	8480e5a2b5f4866eff8ce0d726ad7ebb	JCB 15 digit	29.4530146133691062	-98.6066573178231636
12391	2020-02-15 14:10:56	2020-02-15	Marge Mosciski	marge.mosciski@geemail.com	Portland	Oregon	3440414876855219	355000769a32b1ca74ef8800810536b3	JCB 15 digit	45.4874224195145089	-122.578758416464552
12392	2020-02-15 14:12:10	2020-02-15	Darnell Gerlach	darnell.gerlach@warmmail.com	Colorado Springs	Colorado	180021113907571323	400a16de0b52af3f1e28b501f34b7356	Discover	38.8002000251367676	-104.771260288373384
12393	2020-02-15 14:47:14	2020-02-15	Forest Tromp-Kub	forest.tromp.kub@warmmail.com	San Francisco	California	51594657239043879	14e5cb00f36df3b755b8e9aef9ce692c	Voyager	37.7653741201566788	-122.430364975472386
12394	2020-02-15 14:49:43	2020-02-15	Izayah Wyman	izayah.wyman@geemail.com	Phoenix	Arizona	3797419642936955	cbf81819d07690cbc2a7c6bc497dfd9e	VISA 16 digit	33.546229205972331	-112.147939208468799
12395	2020-02-15 15:24:10	2020-02-15	Demetra Shanahan	demetra.shanahan@geemail.com	San Bernardino	California	869990931713008610	e1ed8c01177a4c5abe3bfcb7956ae3d1	American Express	34.2216837874412505	-117.342519746978212
12396	2020-02-15 15:29:22	2020-02-15	Kazuko Adams	kazuko.adams@woohoo.com	Tallahassee	Florida	561233512386286	77c51c61cd6bed722e8b36eb4a02fab0	JCB 16 digit	30.4210584829118105	-84.2583455089960296
12397	2020-02-15 15:30:48	2020-02-15	Britany Oberbrunner	britany.oberbrunner@geemail.com	Everett	Washington	4353814094604185	f624d1c0742315e98c5d1ec1f335a179	JCB 15 digit	48.0032079066041888	-122.264580270148443
12398	2020-02-15 15:33:56	2020-02-15	Gustavus Zboncak II	gustavus.zboncak.ii@geemail.com	North Las Vegas	Nevada	6011029472313860015	883ac2f9423c8e7953f9af60c0dde328	VISA 16 digit	36.3767026819445149	-115.027405457406871
12399	2020-02-15 15:43:01	2020-02-15	Fran Gibson	fran.gibson@woohoo.com	Oakland	California	3033295571250334	053431e0d24f823db1cef9bd3afe1a0d	JCB 16 digit	37.8246180064732229	-122.297789849348376
12400	2020-02-15 16:10:14	2020-02-15	Mariel Bogisich	mariel.bogisich@warmmail.com	Saint Paul	Minnesota	4762062565769146	1b3048fddcd2758585cb6346581820cf	Discover	44.8999441487189372	-93.0647304812245153
12401	2020-02-15 16:22:05	2020-02-15	Ishmael Hoppe	ishmael.hoppe@geemail.com	Dallas	Texas	869976372245043593	993e307bca88137945b38e22d7db8a91	Maestro	32.8515464901264806	-96.8230955288708088
12402	2020-02-15 16:49:00	2020-02-15	Mr. Kirby Kihn	mr.kirby.kihn@geemail.com	Chula Vista	California	3528356957372691700	b8ea3b901bcbead0bac2eb22e0a24eec	Discover	32.5486841326810392	-116.991380876186113
12403	2020-02-15 17:03:47	2020-02-15	Neha Moore-Stroman	neha.moore.stroman@geemail.com	Glendale	Arizona	6011998787623034895	2429a3d73429cfff921891f5c07decfe	VISA 16 digit	33.5367834194324885	-112.105657723571724
12404	2020-02-15 17:18:05	2020-02-15	Dr. Agusta Upton	dr.agusta.upton@woohoo.com	San Francisco	California	3465197209947262	8b5ed9fdbbbae1e149b9d0f97b2d1ed2	JCB 16 digit	37.7663392782410909	-122.425103428382343
12405	2020-02-15 17:23:45	2020-02-15	Miss Ayana Ward	miss.ayana.ward@woohoo.com	Riverside	California	501883109218434	1edca85089a337efec8b3130f25404b0	Diners Club / Carte Blanche	33.8769979362323852	-117.352563426920014
12406	2020-02-15 17:32:04	2020-02-15	Aletha Hayes	aletha.hayes@geemail.com	New York	New York	210083442889959833	865878a198bde4b7481bb26a1a582291	JCB 16 digit	40.5954074368570019	-74.021754217230523
12407	2020-02-15 17:34:45	2020-02-15	Vernal Funk	vernal.funk@warmmail.com	San Francisco	California	4252879658841053	727762bfe89d3425204c32171a3f638d	Voyager	37.7698120407576141	-122.437531345305345
12408	2020-02-15 17:41:08	2020-02-15	Nonie Champlin	nonie.champlin@geemail.com	Albuquerque	New Mexico	869936313767610111	c25024273484fec5631a688c14ffa499	Voyager	35.1026641524530945	-106.611488991889729
12409	2020-02-15 17:50:10	2020-02-15	Carisa Leannon	carisa.leannon@woohoo.com	Dallas	Texas	4242699201516108	c82404e438fe1f145255f9eaf51c9a18	JCB 16 digit	32.694590081813935	-96.7125230011492931
12410	2020-02-15 17:58:48	2020-02-15	Dempsey Thiel	dempsey.thiel@warmmail.com	Fort Wayne	Indiana	4542901418297085	cdd83c03a4dfbc298d60c42ae79ef20b	JCB 16 digit	41.0829012211661819	-85.0735853251289598
12411	2020-02-15 18:03:15	2020-02-15	Dr. Nohely Spinka	dr.nohely.spinka@warmmail.com	El Paso	Texas	3158373861739982399	ae3afaf3b680d20c3f5802ece200932d	JCB 16 digit	31.8344939186997742	-106.429735946327455
12412	2020-02-15 18:15:20	2020-02-15	Elvis Gutmann	elvis.gutmann@geemail.com	Kenosha	Wisconsin	3717444890130959	33a79b77359a9ce0b7098215b3497768	American Express	42.5993957660932097	-87.7758995673846556
12413	2020-02-15 18:30:09	2020-02-15	Willy Boyer	willy.boyer@woohoo.com	Memphis	Tennessee	3003973442165986	ad8155bfba00ee732cd9f58ea90a1264	American Express	35.1652144177883912	-89.9493083438161847
12414	2020-02-15 18:57:26	2020-02-15	Marita Hudson	marita.hudson@geemail.com	West Palm Beach	Florida	3528940442754494471	d8d56c13805f185b1bafb8e9e216bf63	Maestro	26.6573994736034443	-80.0972642452292121
12415	2020-02-15 19:08:05	2020-02-15	Tambra McDermott-Funk	tambra.mcdermott.funk@geemail.com	San Francisco	California	4032828849250	9fce30206f4dd84f1f14fe8bbf44d7d2	VISA 16 digit	37.808354636590856	-122.430377651671606
12416	2020-02-15 19:14:43	2020-02-15	Siobhan Kuhn	siobhan.kuhn@warmmail.com	San Francisco	California	3799870985857141	bd0f0aa9e429e38248fab51d76229d7c	JCB 16 digit	37.7745715682469125	-122.451561807618603
12417	2020-02-15 19:28:46	2020-02-15	Nila Green-Carter	nila.green.carter@warmmail.com	Visalia	California	51074395955843664	c2984efb57577ae28491c978247c98f6	Maestro	36.2768764414779881	-119.23780873465688
12418	2020-02-15 19:46:46	2020-02-15	Foster Pagac	foster.pagac@geemail.com	Santa Clarita	California	4332792159460022	72e7008f31fd5c2d23209b29f514415b	JCB 16 digit	34.4604797610752271	-118.446529065827647
12419	2020-02-15 19:50:20	2020-02-15	Una Schroeder	una.schroeder@warmmail.com	San Francisco	California	676143389050543	2657eb363330a1f16265c7eeefe78705	VISA 13 digit	37.7918744923048422	-122.449019695408936
12420	2020-02-15 19:53:33	2020-02-15	Pate Prosacco	pate.prosacco@warmmail.com	San Francisco	California	676138688011485	ff9fcf8b11cb12b6466c14f2b80519b4	JCB 16 digit	37.7894271881825574	-122.417577679480019
12421	2020-02-15 20:00:13	2020-02-15	Jule Bernier	jule.bernier@geemail.com	Chicago	Illinois	6011083606721065443	e565f8dc5a02301995a7940014e5d53d	American Express	41.7377222442369913	-87.6418088653154683
12422	2020-02-15 20:03:23	2020-02-15	Keli Corkery MD	keli.corkery.md@geemail.com	San Francisco	California	869953638112451938	6b09cba27689880f64a7f63d3ada9d31	JCB 16 digit	37.7244874419213616	-122.454021398030278
12423	2020-02-15 20:44:41	2020-02-15	Blane Gibson-Boyer	blane.gibson.boyer@woohoo.com	San Francisco	California	6011799987659888328	7c9ca996df41121c8c14bf0b87e1bad8	JCB 15 digit	37.7815372171418815	-122.470981716653185
12424	2020-02-15 21:30:33	2020-02-15	Viney Gutmann	viney.gutmann@warmmail.com	Memphis	Tennessee	6011007705362296268	e104e9ed0b1c9717c5970e6f34f35ea1	Maestro	35.1677676378816386	-90.0553685824643821
12425	2020-02-15 21:41:58	2020-02-15	Dr. Harve Kulas V	dr.harve.kulas.v@warmmail.com	Kansas City	Missouri	4858347760094886	410a9d6d54509ed3e9e319dff652a624	Voyager	39.1843004142701687	-94.6484350321572236
12426	2020-02-15 22:24:12	2020-02-15	Darion Kassulke IV	darion.kassulke.iv@warmmail.com	Atlanta	Georgia	4572372435581146	c94f1263f0371c7286e5f7ac548c2d6a	JCB 15 digit	33.6812891346212524	-84.4217952219814123
12427	2020-02-15 22:33:00	2020-02-15	Mrs. Geneva Barton	mrs.geneva.barton@warmmail.com	Oakland	California	3051981013988787	57852dd18c2624dc42f9626ad9422400	American Express	37.8148770948137241	-122.260144218912941
12428	2020-02-15 22:51:59	2020-02-15	Dondre Gislason	dondre.gislason@woohoo.com	Birmingham	Alabama	55845285512845773	7afb23bbf21e038d3cc931ea6cdc4678	Mastercard	33.475118469379467	-86.7375000168345878
12429	2020-02-15 23:33:11	2020-02-15	Gonzalo Rau	gonzalo.rau@geemail.com	Oakland	California	4776112607655	31fed82311908a8399372dffee9b0b96	Discover	37.8060133922122716	-122.269628734248656
12430	2020-02-15 23:51:46	2020-02-15	Peyton Bashirian	peyton.bashirian@geemail.com	Fremont	California	180043587306759072	a583da72c3be1eb289b55ff63026d13f	VISA 16 digit	37.5096174942497171	-121.841973244537414
12431	2020-02-16 00:01:49	2020-02-16	Mr. Billie Carter	mr.billie.carter@geemail.com	Oakland	California	53568498492694294	013cd982c0e366b94b0faf9efdc5f72e	Diners Club / Carte Blanche	37.7732696128069989	-122.279140120024948
12432	2020-02-16 01:02:52	2020-02-16	Clyde Homenick	clyde.homenick@geemail.com	Visalia	California	3716329518926253	1db954c3dce180878bfedd9a206b681e	JCB 16 digit	36.2423253626052286	-119.26614164902233
12433	2020-02-16 01:23:27	2020-02-16	Dr. Thekla Steuber DDS	dr.thekla.steuber.dds@geemail.com	Surprise	Arizona	6011850130736680238	3ec75e03fe01561279f7b30ba37ef0ea	American Express	33.6733776768896718	-112.43231622402071
12434	2020-02-16 01:33:11	2020-02-16	Kadeem Swaniawski	kadeem.swaniawski@geemail.com	New York	New York	180056437499392550	a071bea96ee079925a52426a6bb8ed6d	Diners Club / Carte Blanche	40.5685345574039928	-74.0022914150625439
12435	2020-02-16 02:04:00	2020-02-16	Miss Carleen Auer DDS	miss.carleen.auer.dds@woohoo.com	Chicago	Illinois	3088931739913646136	676dcb809037bf46fe03d9601d7b655d	VISA 16 digit	41.8673291056253021	-87.6321854530397815
12436	2020-02-16 02:09:40	2020-02-16	Norman Kutch	norman.kutch@geemail.com	Rockford	Illinois	3475657300445514	1344ad7eb06331dd84085d286a49f196	VISA 16 digit	42.2862479639716469	-88.9987950649395572
12437	2020-02-16 02:13:28	2020-02-16	Kaliyah Koch	kaliyah.koch@geemail.com	San Francisco	California	4113462451691717	6b19b53254707672ed74685a2b5626c1	Maestro	37.7934191742817021	-122.418835453588883
12438	2020-02-16 02:22:46	2020-02-16	Kalen Sawayn	kalen.sawayn@geemail.com	Dallas	Texas	630483159350715	13d54ba80543df8749b4752c42b8e893	VISA 16 digit	32.7883799397658606	-96.8071739460304315
12439	2020-02-16 02:24:00	2020-02-16	Mack Feest	mack.feest@geemail.com	St. Petersburg	Florida	3528415424935897026	269aa10b54d437934c814352859712c6	VISA 13 digit	27.7595836968980727	-82.6932773569024988
12440	2020-02-16 02:26:33	2020-02-16	Ardelle Hilpert	ardelle.hilpert@geemail.com	Birmingham	Alabama	3158741216390399216	e5732bfbf7f1daf89c5bce72128201a4	Maestro	33.5654419064778864	-86.8410438433066076
12441	2020-02-16 02:41:18	2020-02-16	Kiefer O'Kon	kiefer.o'kon@geemail.com	Grand Rapids	Michigan	3088958858346215869	099f936d91016ba548e0ab71c7d7012e	Discover	42.8715818912059063	-85.7019808636181182
12442	2020-02-16 02:46:19	2020-02-16	Aditya Flatley	aditya.flatley@woohoo.com	San Francisco	California	6011865181348299951	cb441a8c31ec20b83fd54ec6aa252e04	JCB 15 digit	37.7699944799529916	-122.397385480459704
12443	2020-02-16 02:52:44	2020-02-16	Ebert Oberbrunner	ebert.oberbrunner@geemail.com	Los Angeles	California	4685059680941612	9bc4a7a31cf85dd8d68e47481ac1fad6	VISA 16 digit	34.0420068042218631	-118.484086078590892
12444	2020-02-16 02:53:58	2020-02-16	Alina Thiel	alina.thiel@woohoo.com	San Francisco	California	3042978239754885	8d7f5d8b6cc6f86b51926f653a5e1e3a	VISA 16 digit	37.7627176743600899	-122.448541311350411
12445	2020-02-16 03:09:51	2020-02-16	Stoney Thompson	stoney.thompson@geemail.com	San Francisco	California	869905993043553610	141dcfa7d6c100caa843411bc02db247	VISA 16 digit	37.7573812267230977	-122.437678068772001
12446	2020-02-16 03:11:21	2020-02-16	Victoriano Davis	victoriano.davis@geemail.com	Philadelphia	Pennsylvania	869962641783216209	f09a6908e63ae5c9a5104b0a64c82e78	American Express	39.9671668198850014	-75.0670434806861095
12447	2020-02-16 03:46:22	2020-02-16	Dr. Warren Stroman	dr.warren.stroman@woohoo.com	Madison	Wisconsin	210036581769210573	d6ea299338fa87f7d22feb5fae229604	JCB 16 digit	43.0879929498743266	-89.4366957285791671
12448	2020-02-16 03:54:25	2020-02-16	Lashawn Harris Sr.	lashawn.harris.sr.@woohoo.com	Fort Collins	Colorado	3714287172925023	f6eb9ccc554ea8915840b5af82147765	Discover	40.5553090469602537	-105.081265595271447
12449	2020-02-16 04:06:09	2020-02-16	Vivian Emmerich	vivian.emmerich@geemail.com	Tucson	Arizona	4820967150864096	230b1446c1b17ae8b8620144c62c7f23	Diners Club / Carte Blanche	32.1272614968050263	-110.90531727035939
12450	2020-02-16 04:18:19	2020-02-16	Ms. Adison Hermann	ms.adison.hermann@geemail.com	Kansas City	Missouri	3096852761078158108	739b666dccda367afaa7e1052e60b5c3	JCB 16 digit	39.1351863801315432	-94.5043768480177988
12451	2020-02-16 04:20:18	2020-02-16	Clearence Pfannerstill	clearence.pfannerstill@woohoo.com	Chicago	Illinois	4919817518435	016718d7ec8b40fddb6c4d366a2eaee2	VISA 16 digit	41.8850783850368131	-87.7772497150611031
12452	2020-02-16 04:32:11	2020-02-16	Tessa Hagenes	tessa.hagenes@warmmail.com	New York	New York	503848310950414	10eaa753618d52cc5f0bb8338ea3d375	Discover	40.6463578709159066	-74.0221763308055642
12453	2020-02-16 04:38:02	2020-02-16	Mr. Domenic Schoen V	mr.domenic.schoen.v@geemail.com	Cary	North Carolina	3056447311752684	64c26004b338cb602ba5bba39ebbc343	American Express	35.7351578588239889	-78.793659182879324
12454	2020-02-16 04:54:05	2020-02-16	Letha Muller	letha.muller@geemail.com	San Francisco	California	4141715343259985	e00da5513d78b4e755c69d00a6dac798	American Express	37.7734869395173405	-122.443732431827598
12455	2020-02-16 04:59:35	2020-02-16	Chiquita Johnson MD	chiquita.johnson.md@woohoo.com	Boston	Massachusetts	3455452004076938	e2b8a934c5ba0dd227ddd0a4c5df678c	VISA 16 digit	42.3677378128916047	-71.0892264123491913
12456	2020-02-16 05:22:22	2020-02-16	Mr. Acey Quitzon	mr.acey.quitzon@warmmail.com	Overland Park	Kansas	639010689934387	efc18f0dbfff369e516718953174fa44	JCB 15 digit	38.9117332619484557	-94.6950540307950206
12457	2020-02-16 05:22:42	2020-02-16	Mrs. Jaclyn Nader MD	mrs.jaclyn.nader.md@geemail.com	Milwaukee	Wisconsin	4830804411926141	4787333419b932ca7b1a8d28247f4e7c	VISA 16 digit	43.0198300752408755	-88.0346280590266019
12458	2020-02-16 05:44:50	2020-02-16	Earl Bradtke Jr.	earl.bradtke.jr.@geemail.com	Toledo	Ohio	54162763269443948	bfe282a58cd1993c829f9fe231e9290c	JCB 16 digit	41.5849787752315407	-83.6116381751704978
12459	2020-02-16 05:48:12	2020-02-16	Mrs. Hollie Johnson MD	mrs.hollie.johnson.md@geemail.com	Tempe	Arizona	869952476808201734	aca95588a3d1ab596443b87d74a8013f	JCB 16 digit	33.3393158499538842	-111.999542071533568
12460	2020-02-16 05:55:37	2020-02-16	Travon Kutch-Walter	travon.kutch.walter@warmmail.com	Detroit	Michigan	639076685041279	9248a7d2d5ef7a275c230d8ecc63aa6e	Maestro	42.3756412341184969	-83.0488178034432138
12461	2020-02-16 05:56:47	2020-02-16	Mr. Dessie Hilpert Sr.	mr.dessie.hilpert.sr.@warmmail.com	Glendale	Arizona	3528508374435693789	6425d80062e16740518b3d5cbc0f2ebc	JCB 15 digit	33.5209577199298892	-112.252216921167076
12462	2020-02-16 06:14:45	2020-02-16	Ulysses Turcotte	ulysses.turcotte@geemail.com	Houston	Texas	4522429422424	0540f7b7fe168c329b7dfd76bd211598	JCB 16 digit	29.742528149679675	-95.4573977408479948
12463	2020-02-16 06:24:51	2020-02-16	Kris Frami	kris.frami@geemail.com	San Francisco	California	561217489266068	e16de02991bd84c3dae33a04cc64518d	Voyager	37.7636414245707641	-122.438807902465882
12464	2020-02-16 07:11:14	2020-02-16	Julianna Keeling	julianna.keeling@woohoo.com	Oxnard	California	4767050044695557	6bc05ef75db278f96c33934a50f42c70	Diners Club / Carte Blanche	34.2798143540464366	-119.154457307365163
12465	2020-02-16 07:16:49	2020-02-16	Flavia Littel	flavia.littel@woohoo.com	San Francisco	California	4479167849294	17a1ad3e2e5588fcbfd77085a6f537cf	VISA 16 digit	37.7764860745078579	-122.42839962257186
12466	2020-02-16 07:28:16	2020-02-16	Hugo Larson	hugo.larson@geemail.com	San Francisco	California	869944112016367667	3db4986c2f39f2b54c14a12ecd0abbb8	VISA 13 digit	37.7510857882246427	-122.382506988045591
12467	2020-02-16 07:40:19	2020-02-16	Jakobe Schmeler V	jakobe.schmeler.v@geemail.com	Jacksonville	Florida	869997017869015550	bd3af4e554b7d05ad029e5c7ff485a00	JCB 16 digit	30.3125154317874461	-81.6106348881576338
12468	2020-02-16 08:09:08	2020-02-16	Ham Bahringer	ham.bahringer@geemail.com	Jacksonville	Florida	4203096252051	a20674ede3411f35b36238230d1cef94	VISA 16 digit	30.3361741533555076	-81.5950485560189946
12469	2020-02-16 08:42:26	2020-02-16	Leeann Smith-Mante	leeann.smith.mante@geemail.com	Chicago	Illinois	4771217807094757	2d6716b24aec9b11ba7c60277fea7731	JCB 15 digit	41.9339210391346384	-87.7464358135156317
12470	2020-02-16 08:55:25	2020-02-16	Rollin Corwin IV	rollin.corwin.iv@geemail.com	Modesto	California	210057094384857061	827327576d3a8194df5210d8751505be	Mastercard	37.5646928519476262	-121.014026029707864
12471	2020-02-16 09:06:59	2020-02-16	Dr. Griffith Hayes	dr.griffith.hayes@geemail.com	Glendale	California	54079352853803618	4d38f44d4ec5184d77ee3ffe278b80ef	VISA 16 digit	34.1762832500725935	-118.186868235039711
12472	2020-02-16 09:12:04	2020-02-16	Chad Sporer	chad.sporer@warmmail.com	San Francisco	California	4388983709691	4a38a3b062b68453bd249aec70f18353	Maestro	37.7749559396228705	-122.422688725231836
12473	2020-02-16 09:18:24	2020-02-16	Carolann Ward	carolann.ward@woohoo.com	San Francisco	California	4909885105948786	4f850344e7f63ea964277de30258daf8	Voyager	37.80098495146094	-122.421216701896739
12474	2020-02-16 09:21:06	2020-02-16	Jennifer Watsica DDS	jennifer.watsica.dds@geemail.com	San Francisco	California	210061469824838323	78d7591cc48cf9fe5a716d241d11b195	American Express	37.7620147196915283	-122.42778511699602
12475	2020-02-16 09:33:16	2020-02-16	Mr. Harvie Smitham I	mr.harvie.smitham.i@woohoo.com	San Diego	California	6011889908016614398	bb93bb9e189266705955680a73154cc1	American Express	32.8528985210295801	-117.065332063278191
12476	2020-02-16 09:37:25	2020-02-16	Rayne Kshlerin	rayne.kshlerin@woohoo.com	Santa Clarita	California	180053834847502042	a529b57f45d54c8b9c9935acee8d1bae	Voyager	34.4268573776558	-118.548949437086279
12477	2020-02-16 09:51:17	2020-02-16	Dr. Winnie Price Sr.	dr.winnie.price.sr.@geemail.com	Indianapolis	Indiana	3528395919717960359	6bd0b7ef6c3f66be3d9b3a107c8657e8	Voyager	39.7803636534612579	-86.2134111328251578
12478	2020-02-16 10:06:50	2020-02-16	Joe Rice	joe.rice@warmmail.com	Fort Worth	Texas	3045275269013820	e2fcd01e0347fdbf9af17c78d4f5aa44	VISA 16 digit	32.8259628009572637	-97.4288463403292013
12479	2020-02-16 10:09:11	2020-02-16	Caitlin Stanton	caitlin.stanton@woohoo.com	Detroit	Michigan	3784393915425399	9368acdbe1f1553682aa6a0f1ba2419b	VISA 16 digit	42.4345854913275744	-83.0361204519987126
12480	2020-02-16 10:17:29	2020-02-16	Octavia Upton	octavia.upton@geemail.com	Birmingham	Alabama	3096467381598497683	19bb3e32e8b9cfadecd62886bd9dd491	Mastercard	33.4734555616766229	-86.8895112050939389
12481	2020-02-16 10:51:53	2020-02-16	Abdullah Schulist	abdullah.schulist@geemail.com	Louisville	Kentucky	54909739461505518	8d39a321180d91359454f65ee906129b	Maestro	38.1831775013260497	-85.6888018218405563
12482	2020-02-16 11:16:25	2020-02-16	Lem Bailey IV	lem.bailey.iv@woohoo.com	Everett	Washington	6011194918736180349	1c012bf15ef5fe705dabfb990c2cf23a	VISA 13 digit	47.9712065731532888	-122.25010885183103
12483	2020-02-16 11:19:04	2020-02-16	Tobin Nitzsche I	tobin.nitzsche.i@geemail.com	League City	Texas	3096648577048823434	e9ce96fc74276545bcff78db09a0eace	VISA 13 digit	29.5403688455395432	-95.1903896647490484
12484	2020-02-16 12:07:56	2020-02-16	Estrella Hoppe	estrella.hoppe@warmmail.com	San Francisco	California	3446169365933497	584270cdfb75dad95d6f4a7c713725e0	VISA 13 digit	37.7639730626922798	-122.4327108828154
12485	2020-02-16 12:13:01	2020-02-16	Linnie Gleichner	linnie.gleichner@warmmail.com	Berkeley	California	4921496138160110	7a02df1e537d53c4c25a09061feb0ca2	Maestro	37.9006614889674012	-122.277392821972086
12486	2020-02-16 12:28:42	2020-02-16	Mrs. Lana Smith DDS	mrs.lana.smith.dds@geemail.com	San Francisco	California	869913617211074378	1afb602b3ace9dedddb6aa5de421b5cf	Diners Club / Carte Blanche	37.8032514505883697	-122.443391257210536
12487	2020-02-16 12:42:01	2020-02-16	Lewis Hammes-Crooks	lewis.hammes.crooks@geemail.com	Newark	New Jersey	210079475630851186	cb35b03fb5cb7678468a7d831f15a947	JCB 16 digit	40.6703620353627997	-74.2330467572644324
12488	2020-02-16 12:45:41	2020-02-16	Dr. Rand Cremin I	dr.rand.cremin.i@geemail.com	Phoenix	Arizona	6011324255298326546	0cc9053673bd881268d492403103b90e	Discover	33.5382028513986654	-112.002142047828443
12489	2020-02-16 13:05:56	2020-02-16	Denise Fritsch	denise.fritsch@geemail.com	Madison	Wisconsin	4577326053623627	2ae3b53d7c726f7242718fdbdf03d8e9	VISA 16 digit	43.1545678386438638	-89.518370471696926
12490	2020-02-16 13:08:43	2020-02-16	Era Keebler	era.keebler@woohoo.com	Cary	North Carolina	210075727490449061	2d9eef2cb731371ce2da7094775e0af5	Diners Club / Carte Blanche	35.7661002023719305	-78.7835531292568874
12491	2020-02-16 13:10:33	2020-02-16	Jamarcus Nader-Jones	jamarcus.nader.jones@geemail.com	Mesa	Arizona	6011207575312183512	d2565d4be5a2991b70df43f3cee8ae2a	VISA 16 digit	33.3021806567121246	-111.667442090984053
12492	2020-02-16 13:19:45	2020-02-16	Silvio Altenwerth	silvio.altenwerth@geemail.com	New York	New York	3440301970188391	ee3e9ba10bbb704c1b79e12235a86e04	VISA 16 digit	40.582102611683311	-73.8979007445171447
12493	2020-02-16 14:16:18	2020-02-16	Alwina Bradtke-Pouros	alwina.bradtke.pouros@warmmail.com	Oakland	California	3158522480316480535	5fa210c8f2b0d1c0135e5eebee28cbc4	American Express	37.7770640777084594	-122.261240333585079
12494	2020-02-16 14:22:04	2020-02-16	Rosemary Orn DVM	rosemary.orn.dvm@warmmail.com	Hollywood	Florida	676260451267912	872217e10a92dd766fbc61c244d2780c	Diners Club / Carte Blanche	26.0009182124808405	-80.0929085955772422
12495	2020-02-16 14:23:20	2020-02-16	Angel Jacobs PhD	angel.jacobs.phd@warmmail.com	Berkeley	California	6011768637616764636	7b89827e7bf6ddd91a8924ffd3015691	VISA 16 digit	37.8506833817103896	-122.279763181900393
12496	2020-02-16 14:26:10	2020-02-16	Liberty Yundt	liberty.yundt@geemail.com	San Francisco	California	4438849624194553	c6e608974fe87aae47ce879e041f46d1	American Express	37.7993339896455112	-122.430402422441944
12497	2020-02-16 15:29:55	2020-02-16	Earley Prosacco	earley.prosacco@geemail.com	Oakland	California	4212043649957572	fa9bf2cbdd63b5ab163eae63edc040a6	VISA 16 digit	37.7869473591629372	-122.259928812538249
12498	2020-02-16 15:31:15	2020-02-16	Harold Bergnaum	harold.bergnaum@geemail.com	Fort Lauderdale	Florida	52641132832590513	62dc3ee3923a68da07a2e0b6407fe8b1	JCB 16 digit	26.1159719492297633	-80.0490872291203601
12499	2020-02-16 15:34:23	2020-02-16	Johnie Heidenreich DDS	johnie.heidenreich.dds@geemail.com	San Antonio	Texas	55666685846397092	14253da97f51351068028dc414a0cc09	JCB 15 digit	29.4269557355042544	-98.5990938499405871
12500	2020-02-16 15:34:55	2020-02-16	Alexis Weissnat	alexis.weissnat@geemail.com	Oakland	California	4952502143840521	da9571163659f765b641e5eba051f22c	JCB 16 digit	37.7883597794501327	-122.280370767542578
12501	2020-02-16 15:35:10	2020-02-16	Winton Ebert	winton.ebert@woohoo.com	Waterbury	Connecticut	869969339605707868	6eaf50b399955abdfb52e26e26769a2d	VISA 16 digit	41.5085874481163941	-73.0198175046507174
12502	2020-02-16 15:40:37	2020-02-16	Rupert Marquardt	rupert.marquardt@geemail.com	San Francisco	California	4616475773902	d491c6a689ff081ff676bbb047b89871	VISA 16 digit	37.8290642079739001	-122.425497541570465
12503	2020-02-16 16:07:34	2020-02-16	Junior Hoeger	junior.hoeger@geemail.com	New York	New York	180063742043402396	97183c975921798ae63db0c90d8b8c55	VISA 16 digit	40.7259687356408691	-73.9009469348367247
12504	2020-02-16 16:09:13	2020-02-16	Sydni Rosenbaum	sydni.rosenbaum@geemail.com	Memphis	Tennessee	3528791956153613597	102a5c46d4cbb7080e3449bd070a558b	American Express	35.0350900836821637	-90.0344788470096944
12505	2020-02-16 16:39:01	2020-02-16	Brogan Berge	brogan.berge@woohoo.com	Fort Worth	Texas	3479269505617933	49219fd1a204a6e514157a2ef8a8ab38	Diners Club / Carte Blanche	32.8518738079871966	-97.3091261325690908
12506	2020-02-16 17:04:27	2020-02-16	Mindi Waters	mindi.waters@geemail.com	Berkeley	California	51889209072050548	49d20cfb0a3e615e7f11000e6924e2fa	JCB 15 digit	37.8700675074599289	-122.268076194448668
12507	2020-02-16 17:50:17	2020-02-16	Rashaan Johnson	rashaan.johnson@geemail.com	Fremont	California	869949854802864721	44d3864d23c3077841e9ca33bf9d0722	American Express	37.4458099632691628	-121.956829589511074
12508	2020-02-16 18:16:03	2020-02-16	Ignatz Cremin	ignatz.cremin@geemail.com	Corpus Christi	Texas	3439749888981468	fbfb786d1b222549a17390710ccb811c	Discover	27.7611754393141723	-97.2528435159303228
12509	2020-02-16 18:22:34	2020-02-16	Gage Moen-Oberbrunner	gage.moen.oberbrunner@geemail.com	Wichita	Kansas	52135392831531883	d582b0c7a1cca4fd68ee325bbd73556b	JCB 16 digit	37.622732281719145	-97.3868523141570392
12510	2020-02-16 18:42:09	2020-02-16	Lashanda Hagenes	lashanda.hagenes@geemail.com	Las Cruces	New Mexico	3088789135630989862	ddc7f73a6a07de509b8a310bbb0446c2	VISA 13 digit	32.3776418678961662	-106.697467060026526
12511	2020-02-16 18:42:52	2020-02-16	Alphonsine Harber-Treutel	alphonsine.harber.treutel@geemail.com	Amarillo	Texas	6011806224449137894	1095415201ec0556e3fb729b2b2ca4fb	Maestro	35.155348097828778	-101.760905405864875
12512	2020-02-16 19:05:21	2020-02-16	Kassandra Adams-Halvorson	kassandra.adams.halvorson@geemail.com	Lincoln	Nebraska	502044835654367	f95df2c92f5ddb9d3676c408788ba512	JCB 16 digit	40.7876960115060214	-96.7311410659153097
12513	2020-02-16 19:14:11	2020-02-16	Evelyne Stehr-Sanford	evelyne.stehr.sanford@woohoo.com	San Jose	California	53128435438071610	b31d53d37f29d9e02a653552e4107fa7	American Express	37.324383277660985	-121.872047833561524
12514	2020-02-16 19:33:59	2020-02-16	Robt Marvin-Torphy	robt.marvin.torphy@geemail.com	San Francisco	California	3499626042841357	7f356339c353e241c01a19fe4231db10	VISA 13 digit	37.7803916473761134	-122.4428665113618
12515	2020-02-16 19:53:55	2020-02-16	Mr. Shade Gleichner I	mr.shade.gleichner.i@geemail.com	Houston	Texas	4051504947745864	7e681d9efab4a062dc08c9cb25f969ff	American Express	29.7295503838997348	-95.3398898892585152
12516	2020-02-16 20:00:09	2020-02-16	Ryley Gleichner	ryley.gleichner@geemail.com	Chicago	Illinois	210084434860762970	4f1093cf3a3e266d75c1bb42182f44d0	JCB 16 digit	41.875146201609077	-87.6158968283824606
12517	2020-02-16 20:02:44	2020-02-16	Mitzi Schowalter	mitzi.schowalter@geemail.com	Irving	Texas	3112502100518974945	00cc991c7fcf0cfff7f9b23e8c67c195	Diners Club / Carte Blanche	32.8314617314327535	-97.0066552444174874
12518	2020-02-16 20:10:47	2020-02-16	Brynlee Lesch	brynlee.lesch@geemail.com	Surprise	Arizona	4866721688491	07f5b1e1db632647247d8a6cbe6eaac0	Mastercard	33.6314138017822088	-112.468466923315816
12519	2020-02-16 20:22:03	2020-02-16	Ignacio Kemmer	ignacio.kemmer@geemail.com	Minneapolis	Minnesota	3786830282596458	0e966efa092021941ce3bbe1195fd91b	VISA 13 digit	44.9640834316696925	-93.3455385634481871
12520	2020-02-16 20:33:23	2020-02-16	Mr. Hans Feil MD	mr.hans.feil.md@geemail.com	Reno	Nevada	54570967498143304	214adc1d5fafba043ccae5f1e6a6939c	Diners Club / Carte Blanche	39.6312246707812008	-119.919251348839708
12521	2020-02-16 21:28:47	2020-02-16	Mr. Burton Weber	mr.burton.weber@warmmail.com	Tuscaloosa	Alabama	4895792684556129	d75438d428fb98b3638fd753e986f6bc	Mastercard	33.2304765261765525	-87.5471413232482973
12522	2020-02-16 21:30:43	2020-02-16	Edith Hansen PhD	edith.hansen.phd@geemail.com	Kenosha	Wisconsin	3096073572728843954	4e39dbda635b2dcd979d27d35380f518	Diners Club / Carte Blanche	42.6280024391904462	-87.8139117777574825
12523	2020-02-16 21:46:06	2020-02-16	Dr. Calla Schaden PhD	dr.calla.schaden.phd@geemail.com	Washington	District of Columbia	3096525435710215082	fe6ce9e6c5f316dc71a6c4e3c8ee4616	VISA 13 digit	38.9732772972699237	-77.0193552848629679
12524	2020-02-16 22:17:03	2020-02-16	Vannie Medhurst-Hayes	vannie.medhurst.hayes@warmmail.com	Sugar Land	Texas	869911206979135308	bbf42ea28efe37662b89724c232df006	Maestro	29.5234253261756159	-95.5798687174458053
12525	2020-02-16 22:26:14	2020-02-16	Austen Bruen I	austen.bruen.i@geemail.com	San Francisco	California	4129179030090	df4b59381db6a8a872673443fa395977	VISA 16 digit	37.7685956955611459	-122.414602032988412
12526	2020-02-16 22:44:24	2020-02-16	Becky Stamm-Mertz	becky.stamm.mertz@geemail.com	San Francisco	California	3112084315772469681	01575c6b05cda5f51de840d93f9641f8	Mastercard	37.7722096306550341	-122.442141589105191
12527	2020-02-16 22:44:26	2020-02-16	Orlena Welch	orlena.welch@geemail.com	Oakland	California	3528291633248204360	299727065680dbfc2ea6e31b0e875d0f	VISA 16 digit	37.8300807151865754	-122.254704656832715
12528	2020-02-16 22:49:02	2020-02-16	Mr. Namon Wunsch	mr.namon.wunsch@warmmail.com	Boulder	Colorado	3000586779555828	85b329533f6cf11bd31ad0bf9502968a	VISA 13 digit	39.9307139888852873	-105.295121334461129
12529	2020-02-16 23:13:29	2020-02-16	Ishmael Nienow Jr.	ishmael.nienow.jr.@woohoo.com	Columbia	South Carolina	869934793409363983	dc88fae7339c4efac0dc609bd1e6e343	JCB 15 digit	33.9305023932162655	-80.8143993258494788
12530	2020-02-16 23:14:37	2020-02-16	Granville Bergstrom	granville.bergstrom@woohoo.com	Frisco	Texas	4448444017368200	874e86f7e7273a5c5c82b643cc4dceb4	JCB 16 digit	33.2004725443661215	-96.7663557007186057
12531	2020-02-16 23:25:18	2020-02-16	Fielding Cummerata-Marks	fielding.cummerata.marks@geemail.com	Milwaukee	Wisconsin	4586702154710266	d96ba8f35b0ca75133112a02d6843f27	VISA 16 digit	42.9914332081183801	-87.9578664733197542
12532	2020-02-16 23:41:56	2020-02-16	Encarnacion Hoeger Jr.	encarnacion.hoeger.jr.@geemail.com	Oakland	California	6011740243144918118	1ca3c4ffdd34660715e9340b59baecd5	JCB 16 digit	37.8343068071106359	-122.272355312417901
12533	2020-02-16 23:43:01	2020-02-16	Torry Lueilwitz II	torry.lueilwitz.ii@warmmail.com	Oakland	California	676379536708914	677007efaa0604fb2b0cd045534daae8	Voyager	37.8091793802941396	-122.295508264698611
12534	2020-02-16 23:51:18	2020-02-16	Lexis Kilback	lexis.kilback@geemail.com	Oakland	California	4897003963155171	325f3d8f7169d327f30062b83f97d01d	American Express	37.8150999426966905	-122.272682573067655
12535	2020-02-16 23:55:22	2020-02-16	Morton Thiel	morton.thiel@geemail.com	Modesto	California	51383270638519427	ccaa803d5438f537e64a553280ee91a2	Diners Club / Carte Blanche	37.5701826169155595	-120.938849449736992
12536	2020-02-17 00:16:41	2020-02-17	Mr. Jacoby Fadel DDS	mr.jacoby.fadel.dds@woohoo.com	Bakersfield	California	3158970117485067753	fd90f5e5446e0e43a9c2d46affdd9326	Discover	35.3420420452661759	-119.062113594710084
12537	2020-02-17 00:29:05	2020-02-17	Latrina Fahey	latrina.fahey@warmmail.com	Irving	Texas	3528299124908506247	54222c72f53a73be739c92648071e9e2	Mastercard	32.8208293662358059	-97.0648355382774071
12538	2020-02-17 00:31:33	2020-02-17	Iona Schumm	iona.schumm@geemail.com	Houston	Texas	53931158323304758	66f7a22cdbd4e27eefdf52b5cbf21d78	JCB 15 digit	29.8333515618540339	-95.3600688231658182
12539	2020-02-17 00:34:51	2020-02-17	Juelz Hermiston	juelz.hermiston@geemail.com	Orlando	Florida	4531186483144171	8ddba5c9d51a7c5ec9cbe168028ce2cc	Voyager	28.3934195659853508	-81.262059534104921
12540	2020-02-17 00:48:08	2020-02-17	Carmen Grady	carmen.grady@geemail.com	San Francisco	California	630447299889452	e17078a4a5d2f073235679e23bd8c41c	Voyager	37.7638721834143709	-122.45203815353787
12541	2020-02-17 01:07:03	2020-02-17	Dania Adams	dania.adams@geemail.com	San Francisco	California	3772632481409491	0902f2c6daf5d1c62c5fc9273529ca4f	American Express	37.7788322655265745	-122.441680292965856
12542	2020-02-17 01:23:04	2020-02-17	Amy Hilll MD	amy.hilll.md@geemail.com	Oakland	California	4623239874963458	9b9a475295ccd8e75d03a0a13365825f	American Express	37.8160946933401476	-122.276182973244914
12543	2020-02-17 01:55:50	2020-02-17	Netta Doyle	netta.doyle@geemail.com	Pueblo	Colorado	3096767647826524192	f70c5c8975399884f9e3744bef78e922	Maestro	38.2005890465784788	-104.615564660621061
12544	2020-02-17 02:11:08	2020-02-17	Kara Walter PhD	kara.walter.phd@geemail.com	Houston	Texas	210002655517402672	a9e52e19d19a9c31350549bcc60f8fb2	Mastercard	29.745974073101209	-95.3788924849607014
12545	2020-02-17 02:25:56	2020-02-17	Wm Boehm	wm.boehm@geemail.com	Mesquite	Texas	4144902827175	6ec49594a3b7cceecf8e0a2eecef312f	JCB 15 digit	32.7383203788470496	-96.6078159529447618
12546	2020-02-17 02:49:57	2020-02-17	Cristen Schaden DDS	cristen.schaden.dds@geemail.com	Washington	District of Columbia	3112321469005368260	e1a656aeb1541f381d005021be9dc604	JCB 15 digit	38.820295961227643	-76.9698582350954439
12547	2020-02-17 02:58:23	2020-02-17	Sie Gerhold III	sie.gerhold.iii@geemail.com	New York	New York	4836494865163633	6854065b720fa01f60757c2822a55feb	Voyager	40.7107446649335287	-73.9010240847140523
12548	2020-02-17 03:02:30	2020-02-17	Hilton O'Kon	hilton.o'kon@warmmail.com	Chicago	Illinois	180084750987723318	34d2dedb53ea45946d1774fbeead41dc	JCB 16 digit	41.7612858958844129	-87.7760412255797462
12549	2020-02-17 03:09:44	2020-02-17	Demarco Leuschke	demarco.leuschke@geemail.com	Fresno	California	4161322273137	ea9118908d19d785bfd1bc2c9f97d2ea	JCB 15 digit	36.7266219598114461	-119.734204280806338
12550	2020-02-17 03:12:20	2020-02-17	Tayla Kub-Towne	tayla.kub.towne@geemail.com	San Francisco	California	210016546312191822	b917cce8f3149811d0a3a46f40667b8e	VISA 16 digit	37.7361935180488075	-122.439201544624794
12551	2020-02-17 03:32:11	2020-02-17	Lemmie Gorczany	lemmie.gorczany@geemail.com	Colorado Springs	Colorado	3088862621106180102	1926c431859dbca629dc0e7014876552	Maestro	38.9075985556982431	-104.735417738572508
12552	2020-02-17 03:36:18	2020-02-17	Dr. Eura Lang DVM	dr.eura.lang.dvm@woohoo.com	San Francisco	California	4993625687930068	bee370f610cf128cb8214e61cdbf275d	Voyager	37.7765900755540969	-122.414293835912886
12553	2020-02-17 03:37:57	2020-02-17	Mr. Deric Bruen	mr.deric.bruen@geemail.com	Long Beach	California	4896056056945883	f87faa0d31e0537f60cfcbcef9a0d369	JCB 16 digit	33.802695691847056	-118.076780369381609
12554	2020-02-17 03:40:24	2020-02-17	Hayley Predovic	hayley.predovic@geemail.com	San Francisco	California	3791933962721553	8195c1714283bc12f5e2fe47d4df1550	VISA 16 digit	37.7373784634383327	-122.457170620637569
12555	2020-02-17 03:48:16	2020-02-17	Gaetano Wisozk	gaetano.wisozk@geemail.com	Newark	New Jersey	4221312503826	a9e749a2836b5fc152f3c7d8c1527c23	VISA 13 digit	40.6755852105010334	-74.1006837077181757
12556	2020-02-17 04:23:01	2020-02-17	Mr. Randell Lueilwitz	mr.randell.lueilwitz@geemail.com	Springfield	Missouri	3026740695225081	309bfa5264d056e61372b11835729747	Diners Club / Carte Blanche	37.2540467108793578	-93.2643540150776573
12557	2020-02-17 05:18:08	2020-02-17	Mckinley Bartoletti	mckinley.bartoletti@woohoo.com	Los Angeles	California	210022301671426266	b4c614e9fa84591d49a6ca4e339cea0a	JCB 15 digit	34.0548009273927619	-118.494619937473161
12558	2020-02-17 05:36:57	2020-02-17	Miss Lexie Murray DVM	miss.lexie.murray.dvm@geemail.com	San Francisco	California	180089949869900714	a26fd66b3bc6750ef597bd1aba39a0c6	Discover	37.7641938400545243	-122.450637191317213
12559	2020-02-17 05:58:06	2020-02-17	Dr. Tegan Gutmann	dr.tegan.gutmann@geemail.com	Alexandria	Virginia	180044467242682663	5e99bdbb02eb0fc99ab9d121bc6bd9cc	Voyager	38.8349899958003277	-77.1656663771238271
12560	2020-02-17 06:04:28	2020-02-17	Miss Madilynn Conroy PhD	miss.madilynn.conroy.phd@geemail.com	Las Vegas	Nevada	3046645436298398	ad101e489bd602e6c8f20bf434407444	Mastercard	36.1643575711742002	-115.240298416626075
12561	2020-02-17 06:21:12	2020-02-17	Dr. Alyson Conn	dr.alyson.conn@woohoo.com	Louisville	Kentucky	4735855391821856	b2bc1d6aea8cbe8465f14df6a6ba7335	Discover	38.090585517361383	-85.7095117608621706
12562	2020-02-17 06:25:40	2020-02-17	Dr. Volney Smitham	dr.volney.smitham@geemail.com	Philadelphia	Pennsylvania	3112544732002159920	e30b36cd7e604dff59e2db15ccf5d27a	American Express	40.0395116487942602	-75.0842126940276557
12563	2020-02-17 06:30:33	2020-02-17	Dr. Merlin Satterfield III	dr.merlin.satterfield.iii@warmmail.com	Oakland	California	4966092658552228	fb82dbdcbea88a73805791c6a0998b19	JCB 15 digit	37.8084147560685579	-122.281107297515518
12564	2020-02-17 07:09:19	2020-02-17	Miss Kirsten Rolfson	miss.kirsten.rolfson@geemail.com	San Francisco	California	639016494702364	f31977437f14b896ad304fbc5e5136c8	VISA 16 digit	37.7485260203938466	-122.462244144052363
12565	2020-02-17 07:19:11	2020-02-17	Moira Miller-Casper	moira.miller.casper@geemail.com	Little Rock	Arkansas	869920978402707437	605882deffc969403e3ca7acc22be8c8	Discover	34.6398686888437695	-92.4061121671333865
12566	2020-02-17 07:26:15	2020-02-17	Mr. Gunner Morar Jr.	mr.gunner.morar.jr.@geemail.com	Cleveland	Ohio	4979588809686	caf494555bb5943ae393fb56405129f8	Diners Club / Carte Blanche	41.4908061978258189	-81.7203571494441547
12567	2020-02-17 07:44:19	2020-02-17	Keely VonRueden DDS	keely.vonrueden.dds@geemail.com	New York	New York	3096894543447357193	9084817138bf25854a21cc66de149ca0	Voyager	40.6267284977938985	-73.9000851230591564
12568	2020-02-17 08:31:47	2020-02-17	Tavian Wisoky	tavian.wisoky@geemail.com	San Antonio	Texas	4719262270601	7b364d0bf6f4124f900d794f1a48024f	JCB 15 digit	29.4692051931355152	-98.4987161726992468
12569	2020-02-17 08:37:35	2020-02-17	Haiden Hoeger	haiden.hoeger@geemail.com	Cleveland	Ohio	4563654182979438	02da36aa2c745d43e389933b8cb6ed38	Discover	41.450215221600601	-81.6463089510105533
12570	2020-02-17 08:44:20	2020-02-17	Talen Prohaska	talen.prohaska@geemail.com	Portland	Oregon	630459339600443	03b0222e217997c2cb043fcf58c12001	Mastercard	45.4718881042562444	-122.670997786615047
12571	2020-02-17 08:49:20	2020-02-17	Lynne Welch	lynne.welch@geemail.com	Naperville	Illinois	3753154123502271	0a0aec3d3ce8f6cda3397096c724b662	Mastercard	41.8444535569667835	-88.0652453077379676
12572	2020-02-17 08:52:18	2020-02-17	Lilyana Torphy	lilyana.torphy@geemail.com	Las Vegas	Nevada	210089902070868105	a0b8c79096349e44e3cee8817aae5f27	Mastercard	36.1934862932756545	-115.189109600961572
12573	2020-02-17 09:19:30	2020-02-17	Letha Abbott	letha.abbott@geemail.com	Omaha	Nebraska	180041380123826619	fc7ff257badeef0bf05aa967d36b0fce	JCB 15 digit	41.3155497603729387	-95.9709964528329778
12574	2020-02-17 09:26:00	2020-02-17	Dr. Ricki Fay Sr.	dr.ricki.fay.sr.@geemail.com	New York	New York	3418894905850406	d586ffc909ecc35f0a233f0cbef5892c	Voyager	40.5979829147681599	-73.8474518048472675
12575	2020-02-17 09:40:50	2020-02-17	Ms. Hannah Osinski	ms.hannah.osinski@woohoo.com	San Francisco	California	3736502666905263	d7663653a54f8f9ce6e49a0c80d7943e	Voyager	37.7438812422134546	-122.424998820674716
12576	2020-02-17 09:41:15	2020-02-17	Galilea Runolfsson	galilea.runolfsson@geemail.com	Salinas	California	4442202030842700	2d2f776c83859c7a7876db892b8f646f	American Express	36.64483805645704	-121.557561256893734
12577	2020-02-17 10:02:21	2020-02-17	Miss Celie Feil MD	miss.celie.feil.md@geemail.com	San Francisco	California	3528600360280392384	64fadf1c629e0115473125977dbfa3de	JCB 16 digit	37.7583816258862228	-122.421173169859827
12578	2020-02-17 10:42:21	2020-02-17	Claudette McKenzie-Hettinger	claudette.mckenzie.hettinger@geemail.com	San Francisco	California	3425284798454709	6d6ea1e79b0a01fc109cbf49fdcf8ac2	JCB 15 digit	37.7758671503750563	-122.429253369496067
12579	2020-02-17 10:48:03	2020-02-17	Mr. Nicholaus Koepp	mr.nicholaus.koepp@woohoo.com	Elk Grove	California	675941396845020	347ecff703fad8a5821a9a1bafd409a7	Mastercard	38.3455439667500571	-121.301842879401519
12580	2020-02-17 10:50:55	2020-02-17	Dr. Reino Tremblay DVM	dr.reino.tremblay.dvm@warmmail.com	San Mateo	California	3096141971609130903	cadf6d49f282a8556a18fad900f84ece	Discover	37.6458528333689983	-122.365128986429795
12581	2020-02-17 10:58:22	2020-02-17	Paris Rippin	paris.rippin@warmmail.com	Philadelphia	Pennsylvania	3045443624731847	45e260e58d58e1b80bfc74c1b9fea246	VISA 13 digit	39.9261365942150377	-75.2127818697031643
12582	2020-02-17 11:08:15	2020-02-17	Ms. Kenisha Robel	ms.kenisha.robel@geemail.com	San Francisco	California	3088593505880264354	d95e7f2bb2fde27f6da6b983fd41b792	Diners Club / Carte Blanche	37.7806307018056984	-122.425133963413231
12583	2020-02-17 11:10:00	2020-02-17	Dr. Washington Mraz	dr.washington.mraz@geemail.com	New York	New York	3049416917669409	45582fac8a45ac85486c84a1fad06c78	VISA 13 digit	40.6269210087824604	-73.9652993546694546
12584	2020-02-17 11:28:57	2020-02-17	Jensen Steuber-Mills	jensen.steuber.mills@geemail.com	San Francisco	California	54783927321929587	f21d5cb1efabc06ecc37ef1669f6ee2a	VISA 13 digit	37.8070905351490936	-122.43377479255318
12585	2020-02-17 11:40:15	2020-02-17	Jalynn Lowe-Dickinson	jalynn.lowe.dickinson@geemail.com	Oakland	California	4248325526555605	125810325e5d4d0d986ee52204f7ff40	JCB 16 digit	37.8132266905558438	-122.263265072851027
12586	2020-02-17 11:48:13	2020-02-17	Nicolle Renner PhD	nicolle.renner.phd@geemail.com	Los Angeles	California	53485474257153982	924965e792c2c1beed08f164bcaae1bf	VISA 16 digit	34.0779784648545032	-118.328352595585585
12587	2020-02-17 11:53:42	2020-02-17	Deane Lakin	deane.lakin@geemail.com	San Francisco	California	869956636954562975	f7eaff35518b8c1d3609bb6a12f53210	Voyager	37.7662224438386147	-122.435944780237151
12588	2020-02-17 12:09:49	2020-02-17	Val Effertz	val.effertz@geemail.com	Murrieta	California	3008367352755289	c126b330d79896a9fc0576b07fbeed93	VISA 13 digit	33.4789608312401938	-117.181750285010409
12589	2020-02-17 12:19:29	2020-02-17	Salome Keebler	salome.keebler@geemail.com	Glendale	California	3112904047447774934	3aa0f67eda897a6778faed08ca597e8f	JCB 16 digit	34.1103064422715434	-118.194678561798483
12590	2020-02-17 12:26:58	2020-02-17	Benjamen Miller	benjamen.miller@warmmail.com	Berkeley	California	676304309378323	4f7019fc3c4e7ae96157eb829a0208ae	Diners Club / Carte Blanche	37.8542983740200469	-122.257154012560548
12591	2020-02-17 12:39:42	2020-02-17	Loy Abshire	loy.abshire@geemail.com	Orange	California	3054804598052737	3b7a9cbde2ead59fdc64dfb766bde19d	Maestro	33.7928039278257657	-117.762127814172956
12592	2020-02-17 13:08:56	2020-02-17	Lurena Steuber	lurena.steuber@geemail.com	Los Angeles	California	4583545807414544	2529c2e357b03005e792d611448e0a73	VISA 16 digit	34.0212594230990817	-118.455318918823451
12593	2020-02-17 13:27:52	2020-02-17	Dinah D'Amore	dinah.d'amore@geemail.com	San Francisco	California	869996604266209406	587fd5daa358f9dfd628ecb208f6bbb0	VISA 16 digit	37.7902037181543022	-122.425425015625464
12594	2020-02-17 13:29:24	2020-02-17	Cleone Lowe-Lueilwitz	cleone.lowe.lueilwitz@geemail.com	Yonkers	New York	53044504111147715	b1b4edc431351e098e32c1c63f047630	JCB 16 digit	41.0433200978409545	-73.8765037038713785
12595	2020-02-17 13:40:21	2020-02-17	Lorrayne Larson	lorrayne.larson@geemail.com	Mobile	Alabama	6011242774954727119	6ba6ad28467b2884a8517dbc1a71640a	Voyager	30.5751423783708347	-88.1083586345564527
12596	2020-02-17 13:42:26	2020-02-17	Dr. Redden Casper V	dr.redden.casper.v@geemail.com	Jacksonville	Florida	060421894847066	2f0615fb4a21b5df6ba646f3fe890e7b	JCB 16 digit	30.3640830398123711	-81.5698658819388669
12597	2020-02-17 13:54:41	2020-02-17	Dr. Burton Kertzmann V	dr.burton.kertzmann.v@woohoo.com	Surprise	Arizona	869990677983222627	fedac72a639dbc565b48236461105b32	VISA 13 digit	33.668421029322225	-112.547301544924068
12598	2020-02-17 14:09:35	2020-02-17	Carlota O'Connell	carlota.o'connell@woohoo.com	Oklahoma City	Oklahoma	3052311987053344	80d14f887636c0fdfc714f8bd55fa87f	Voyager	35.4619975868057509	-97.5592914902500752
12599	2020-02-17 14:11:53	2020-02-17	Alysa Hartmann PhD	alysa.hartmann.phd@geemail.com	Jacksonville	Florida	869925230295378818	43162fefe22fd26923261f12153572d6	VISA 16 digit	30.4128539999067797	-81.7482163996513975
12600	2020-02-17 14:44:15	2020-02-17	Less Schoen	less.schoen@geemail.com	Tyler	Texas	3030341876763937	88e37c684b8fcd160fd2b91113bc3d5c	VISA 13 digit	32.3765799609992655	-95.2246717649154277
12601	2020-02-17 15:00:21	2020-02-17	Darin Murphy-Huels	darin.murphy.huels@geemail.com	New York	New York	6011903174619095657	c9a451c27a81d8e307ab293efc77159f	Voyager	40.5749362207241333	-73.9441397114552501
12602	2020-02-17 15:00:33	2020-02-17	Andrae Huels III	andrae.huels.iii@geemail.com	Berkeley	California	3112361133154482360	116696d494eeb9763a6357bebcff713e	Maestro	37.868035468698416	-122.262324132085041
12603	2020-02-17 15:03:52	2020-02-17	Felecia Krajcik	felecia.krajcik@geemail.com	Kansas City	Kansas	53631250107502161	fcc58833cb4342cad4d29129af8c1c45	American Express	39.044892535395924	-94.7048783447530127
12604	2020-02-17 15:25:06	2020-02-17	Sie Streich	sie.streich@geemail.com	New York	New York	869970829442985328	c8fbbbb09f152b228bba8ac36860a31b	Maestro	40.7389128341563023	-73.9271822148829614
12605	2020-02-17 15:55:31	2020-02-17	Dr. Sheryll Gislason MD	dr.sheryll.gislason.md@geemail.com	Vacaville	California	3009779128616869	b80f224d7fa8300e762500228c12d5a6	Maestro	38.4269631927493975	-121.887007581616942
12606	2020-02-17 16:09:29	2020-02-17	Parker Ruecker	parker.ruecker@geemail.com	Miami	Florida	675997475799207	3b370fd5ba1bbbf23ea0121b1f7725fd	VISA 13 digit	25.7058445235852169	-80.1469427019696781
12607	2020-02-17 16:16:46	2020-02-17	Leon Purdy	leon.purdy@geemail.com	Kansas City	Missouri	869986200380060262	f1c4d36677bc0d94179e34dc8d8f16f0	VISA 16 digit	39.1839210027664961	-94.4775458087436846
12608	2020-02-17 16:27:39	2020-02-17	Nancie McGlynn	nancie.mcglynn@woohoo.com	Irvine	California	4513414295583804	c24fabecdbf147691caeaf661114639d	American Express	33.619518020005529	-117.709219522495943
12609	2020-02-17 16:42:06	2020-02-17	Rudy Stark	rudy.stark@geemail.com	Richmond	California	3088977213116320217	9de1c87854f5a60817c80f7a59c13e05	VISA 16 digit	37.9591536279257369	-122.300512616927179
12610	2020-02-17 16:47:09	2020-02-17	May Jacobi	may.jacobi@geemail.com	Moreno Valley	California	4451120499988	850357b2e6b1e39ad4bb60c50a3805b8	Mastercard	33.9341674314804322	-117.210329954323171
12611	2020-02-17 16:50:25	2020-02-17	Ginny Willms	ginny.willms@woohoo.com	Philadelphia	Pennsylvania	4306683129705	445dc3f246d7ff176ef3b0a272fa3b7e	JCB 16 digit	40.031651667594538	-75.121540539282563
12612	2020-02-17 17:00:42	2020-02-17	Lorenz Shields	lorenz.shields@warmmail.com	Jacksonville	Florida	180015860315255257	34b5c7a36b34812877eca2c6196fd873	JCB 16 digit	30.3014049320999526	-81.5665453714862565
12613	2020-02-17 17:13:27	2020-02-17	Ms. Cali Roob DDS	ms.cali.roob.dds@warmmail.com	Amarillo	Texas	4795653599477	c7bf46f4127b2d1e49b131b68cb1c14c	Mastercard	35.1894517799071949	-101.777031028722234
12614	2020-02-17 17:14:45	2020-02-17	Tevin Crooks-Purdy	tevin.crooks.purdy@geemail.com	Houston	Texas	4327171852228100	bf98b720b46f9043161039c7ac9b050e	Diners Club / Carte Blanche	29.769490434842556	-95.4614859133508133
12615	2020-02-17 17:15:30	2020-02-17	Alexandr Lubowitz	alexandr.lubowitz@geemail.com	Chicago	Illinois	210006083879793933	6a66f0217a7459423797864dfc234f49	JCB 16 digit	41.8166189207997192	-87.7721029365930718
12616	2020-02-17 17:48:30	2020-02-17	Jadyn Howe	jadyn.howe@geemail.com	Vacaville	California	561293294896324	f2b9fcc317e2e143093370febbfcc7ad	JCB 15 digit	38.3112467396665366	-122.000779010622949
12617	2020-02-17 17:48:35	2020-02-17	Dell Vandervort	dell.vandervort@geemail.com	Tallahassee	Florida	3466942415753114	b2facabf522c0cd5228201349aa446b3	JCB 16 digit	30.5489300088979334	-84.2592245703112326
12618	2020-02-17 18:02:29	2020-02-17	Jolene Keeling-Little	jolene.keeling.little@geemail.com	Moreno Valley	California	210014145360932088	97f72822c8ee497287b96fd2b7594c0f	JCB 16 digit	33.938074519996718	-117.157140971717226
12619	2020-02-17 18:14:04	2020-02-17	Laverne Emard	laverne.emard@woohoo.com	Bridgeport	Connecticut	3337591687890624934	ccdfcb10daa1057d5491b2d0950245f6	Diners Club / Carte Blanche	41.1847536643199561	-73.1293558413527904
12620	2020-02-17 19:00:25	2020-02-17	Evans Jacobson	evans.jacobson@geemail.com	Denton	Texas	4268931427373835	b26dd939668aae7750953df5e6884df5	VISA 13 digit	33.2295788338672367	-97.080761919509257
12621	2020-02-17 19:07:22	2020-02-17	Everett Stehr	everett.stehr@geemail.com	Columbus	Ohio	4885610964573	302628eb1e11465627f2ba52f0c560b2	VISA 13 digit	40.0360699332363907	-83.0578885084252931
12622	2020-02-17 19:30:21	2020-02-17	Almond Abshire DVM	almond.abshire.dvm@geemail.com	Lewisville	Texas	501841710965413	eabb210038512fd8b8cad6dcdd8b2394	Maestro	32.9831702617913436	-97.0017796881992496
12623	2020-02-17 19:33:51	2020-02-17	Jaylee Hammes	jaylee.hammes@geemail.com	Berkeley	California	3016367298477503	d9762a94667b41062f2eded60d69d20d	Diners Club / Carte Blanche	37.8623935540307173	-122.282424668949503
12624	2020-02-17 19:52:12	2020-02-17	Mr. Henry Little	mr.henry.little@warmmail.com	San Francisco	California	3712412878603607	9b740872576b407773e19cb0d66498b3	JCB 16 digit	37.7660343229635984	-122.403709977251069
12625	2020-02-17 19:55:57	2020-02-17	Olevia Crist DDS	olevia.crist.dds@geemail.com	New York	New York	676388735566080	6da5d7df6d8109da2fdb376deef5e190	VISA 13 digit	40.6231601820550878	-73.8402135319437747
12626	2020-02-17 20:09:40	2020-02-17	Ms. Skye Romaguera PhD	ms.skye.romaguera.phd@geemail.com	Chula Vista	California	3528205648461611468	e7f713a8901eae959f4fa451b8f0b4d4	Mastercard	32.6031737330134916	-116.985526869282864
12627	2020-02-17 20:13:40	2020-02-17	Delora Hane MD	delora.hane.md@geemail.com	Los Angeles	California	210020379420759148	64ea2c656abaeb504856eaa8a6254901	JCB 16 digit	34.0977562942408028	-118.324644622578461
12628	2020-02-17 20:21:56	2020-02-17	Cassandra Wolf DVM	cassandra.wolf.dvm@geemail.com	Columbus	Ohio	869987221905523666	2795b534045adf45d97b96da65b5e51f	Mastercard	39.9397682005118568	-83.0070439565230203
12629	2020-02-17 20:28:17	2020-02-17	Fonda Streich	fonda.streich@geemail.com	Lexington	Kentucky	676272785577635	c2abba6d5634267c7ef7ecb4cc931df6	Mastercard	38.0193758163012561	-84.4694759457737092
12630	2020-02-17 20:36:02	2020-02-17	Kavon Schinner-Hegmann	kavon.schinner.hegmann@geemail.com	New York	New York	869985885961111715	5fd060b9f71698a2ab39a7ad1240fea0	VISA 16 digit	40.7347092645000686	-74.0372661690123408
12631	2020-02-17 20:38:24	2020-02-17	Mr. Bernhard Kling I	mr.bernhard.kling.i@geemail.com	Berkeley	California	4082958130864	3596afae3c192e2455b5bc1daf5dd22b	JCB 16 digit	37.8529338011049319	-122.254523262625298
12632	2020-02-17 20:51:00	2020-02-17	Virgil Fritsch-Reinger	virgil.fritsch.reinger@warmmail.com	Houston	Texas	4547911535003	7196e0a5b4c8a33eb1e652e19158a0d3	Discover	29.8151891182255007	-95.4638819036554622
12633	2020-02-17 21:03:05	2020-02-17	Venessa Morar	venessa.morar@woohoo.com	Bakersfield	California	180035010162363566	0c21989148f0019682a2a28b8fa79456	Diners Club / Carte Blanche	35.2385265225719664	-119.066386873302235
12634	2020-02-17 21:07:33	2020-02-17	Katharine Orn	katharine.orn@geemail.com	Detroit	Michigan	3468159613370025	1db10519f21defe1742fa701286dac0a	VISA 13 digit	42.431288545152178	-83.0509567269708953
12635	2020-02-17 21:19:17	2020-02-17	Dr. Edgardo Reilly	dr.edgardo.reilly@geemail.com	Columbus	Ohio	3528035501965435650	024061ee9c04f45e54a69c2b1d84d703	Voyager	39.9421867065642004	-82.9019272878069557
12636	2020-02-17 21:21:51	2020-02-17	Aloys Denesik	aloys.denesik@geemail.com	Palmdale	California	4634110610629	c7beb78a995623d9b06875d2061ce93d	VISA 13 digit	34.5358802410159242	-118.099859630222994
12637	2020-02-17 21:33:04	2020-02-17	Mr. Alston Abbott V	mr.alston.abbott.v@woohoo.com	New York	New York	3054635205377608	aff33585f6d4cf2b4698ec5ff155e8f0	Diners Club / Carte Blanche	40.76019606327079	-73.9724866764515667
12638	2020-02-17 21:44:41	2020-02-17	Dolores DuBuque	dolores.dubuque@geemail.com	New York	New York	3096206627092662214	a5d73a42b23dfb4f00ea1087d44e6736	VISA 13 digit	40.7011766945701083	-73.8710577503673704
12639	2020-02-17 21:46:41	2020-02-17	Libbie Renner-Russel	libbie.renner.russel@geemail.com	Hartford	Connecticut	3043629127220294	8b9c5e7b3a14911b3a345a9b4506f816	Maestro	41.7220411567963652	-72.7634417668808311
12640	2020-02-17 21:52:25	2020-02-17	Imo Leannon	imo.leannon@geemail.com	Washington	District of Columbia	3039836346342577	4601db9a4dc6e5d22c50d927ef721932	VISA 16 digit	38.9137387787722062	-76.9686672975055899
12641	2020-02-17 22:06:15	2020-02-17	Edw Schaden-Heidenreich	edw.schaden.heidenreich@geemail.com	St. Petersburg	Florida	639046700717245	2745826da91607931b1c9b8778ae0fc5	Discover	27.6647196033392113	-82.6666202956702563
12642	2020-02-17 22:34:30	2020-02-17	Lavonda Ortiz	lavonda.ortiz@geemail.com	Jersey City	New Jersey	3158164727336206925	dfd37fbb9af30521167a5616db145dd1	Mastercard	40.7202086366653404	-74.0711792833127163
12643	2020-02-17 22:41:42	2020-02-17	Tyrell Mertz-McDermott	tyrell.mertz.mcdermott@geemail.com	Houston	Texas	4498803857768	d946df8e6c1cf4148cafcb38fc3b83f7	VISA 13 digit	29.7590227159749716	-95.314896010515838
12644	2020-02-17 22:53:20	2020-02-17	Asberry Koch-Hoppe	asberry.koch.hoppe@woohoo.com	Thousand Oaks	California	869914410550891928	f1c534b28bda65bcfcd1706f2178ed09	JCB 16 digit	34.2786702732361874	-118.906797791263841
12645	2020-02-17 23:28:52	2020-02-17	Brionna Gaylord	brionna.gaylord@geemail.com	Allentown	Pennsylvania	3016843429165985	14b18ae5643672b1ee279145bc5b8c68	American Express	40.5632561640594176	-75.4397479559309687
12646	2020-02-17 23:33:08	2020-02-17	Hershell Paucek	hershell.paucek@geemail.com	Cary	North Carolina	3039619055931503	8287f93179cd4d512e8f64598cc6abbf	Voyager	35.7293586819540749	-78.85129140742049
12647	2020-02-17 23:40:33	2020-02-17	Meaghan Erdman	meaghan.erdman@geemail.com	Tempe	Arizona	4940542683577856	77b9d157733864c3bb32cc1f8b2c65fe	JCB 15 digit	33.3258712675344171	-111.89997761752754
12648	2020-02-17 23:48:32	2020-02-17	Isaac Cassin	isaac.cassin@geemail.com	San Francisco	California	180071873511840575	267319488c14346318bd4dc76d6b512e	Diners Club / Carte Blanche	37.7746749591473971	-122.422260081633851
12649	2020-02-18 00:09:09	2020-02-18	Lilie Zemlak-Bergnaum	lilie.zemlak.bergnaum@geemail.com	Lowell	Massachusetts	3454720195607625	2ad1eb92ba81543b19eada9a8a26595d	American Express	42.6769315143916756	-71.2303167576774996
12650	2020-02-18 00:16:37	2020-02-18	Taft Langworth	taft.langworth@geemail.com	West Valley City	Utah	3014404884595133	44290cdee8533e45b351c90b581667ae	Maestro	40.7028234033137508	-112.027639685406527
12651	2020-02-18 00:17:25	2020-02-18	Tawanna Dach PhD	tawanna.dach.phd@geemail.com	Bridgeport	Connecticut	3337865540665618368	89652662de6d0c0e4e990d98c526bad9	VISA 16 digit	41.1118150567799745	-73.2348997597016478
12652	2020-02-18 00:20:01	2020-02-18	Meyer Blanda	meyer.blanda@warmmail.com	Corpus Christi	Texas	676104410376422	7da7e55b64fccedf9fefd4179987055d	VISA 13 digit	27.7193687889195992	-97.1401826659977417
12653	2020-02-18 00:36:05	2020-02-18	Johnpaul Kunde PhD	johnpaul.kunde.phd@geemail.com	Seattle	Washington	6011682262429769293	b5401ee4d16f744e035f312d36001ac7	Voyager	47.6824649652391699	-122.43281921985708
12654	2020-02-18 01:07:54	2020-02-18	Dr. Dewayne Mayert	dr.dewayne.mayert@woohoo.com	San Francisco	California	6011654365898862160	45fed27f2a7f426b50924cce7a2c0f8f	American Express	37.7905240847125583	-122.435250315863613
12655	2020-02-18 01:09:32	2020-02-18	Antonio Beer	antonio.beer@geemail.com	Oakland	California	3722943735258365	72aca759ebbdbb4eede36ff7fac42778	VISA 13 digit	37.840314328058021	-122.29090562447459
12656	2020-02-18 01:47:13	2020-02-18	Ruby Gutmann	ruby.gutmann@warmmail.com	Phoenix	Arizona	561236001992712	95f7dfedf14e94d67a1bea05f412d616	VISA 16 digit	33.551675661600008	-112.136397319792223
12657	2020-02-18 01:54:03	2020-02-18	Mabelle Bosco	mabelle.bosco@woohoo.com	San Francisco	California	869937259699828793	98b18499508326f547476d679ebbb13e	Diners Club / Carte Blanche	37.7591575127759072	-122.466357013020357
12658	2020-02-18 03:13:22	2020-02-18	Newman Koelpin III	newman.koelpin.iii@geemail.com	Elgin	Illinois	3112098926802872746	27b44cb0e399a515e8512c7984852e36	American Express	42.0540211866427214	-88.4105923923019361
12659	2020-02-18 03:13:27	2020-02-18	Ms. Veta Rau PhD	ms.veta.rau.phd@geemail.com	Bakersfield	California	4660818392660193	b593d89b9646fa196b364e91d7774f33	JCB 16 digit	35.2781524345453832	-119.025269095254316
12660	2020-02-18 03:35:57	2020-02-18	Adriel Gaylord	adriel.gaylord@geemail.com	Everett	Washington	180065642110737005	fa19e66d2086dc561482c229edf85366	Mastercard	47.9735192834291624	-122.194975420845296
12661	2020-02-18 03:39:14	2020-02-18	Vernon Lynch	vernon.lynch@geemail.com	Memphis	Tennessee	4094403066841860	ee0dd14d40b530c1b7cdc8d694ab19f0	JCB 15 digit	35.0969744660493035	-90.021023759644109
12662	2020-02-18 03:43:06	2020-02-18	Gusta Kessler	gusta.kessler@geemail.com	Madison	Wisconsin	3528630568815672948	173ce759c62d8a3f3c84515584e16c2d	VISA 16 digit	42.9901022513370989	-89.3405466691941115
12663	2020-02-18 03:51:24	2020-02-18	Miss Kyla Lakin	miss.kyla.lakin@geemail.com	San Francisco	California	869998627026842941	453452dbbfaf4954953db8d7ebc6cf6d	VISA 13 digit	37.7566343528477262	-122.426502999969301
12664	2020-02-18 03:52:20	2020-02-18	Kaye Hand	kaye.hand@geemail.com	Overland Park	Kansas	4854105864754829	3fde0227fa6ad52ffbae12c4adff1400	Voyager	38.8199103803709207	-94.7137200490612514
12665	2020-02-18 04:06:45	2020-02-18	Henretta Aufderhar-Mann	henretta.aufderhar.mann@woohoo.com	McKinney	Texas	4120188986141	ec4ada3d00f0bb72924c48d20e8547f3	American Express	33.1198422690052539	-96.7224905503746157
12666	2020-02-18 04:23:04	2020-02-18	Aldona Shanahan-Purdy	aldona.shanahan.purdy@geemail.com	Seattle	Washington	869943765028255989	66a28851839e84f7ab2dbbd4df8c58fb	Mastercard	47.5269332627225651	-122.272808046072342
12667	2020-02-18 04:23:58	2020-02-18	Jimmy Jenkins	jimmy.jenkins@geemail.com	Alexandria	Virginia	3049871282611230	aca899411862e06507bf953a23de278e	Maestro	38.7913712374050164	-77.1388794106882187
12668	2020-02-18 04:28:12	2020-02-18	Arlyne Blanda	arlyne.blanda@geemail.com	Columbus	Ohio	210056045267847216	d616b8e8d055768947943efcc9933a3b	JCB 15 digit	39.9040852766528715	-83.0704615988537682
12669	2020-02-18 04:34:42	2020-02-18	Trinity Conroy	trinity.conroy@geemail.com	New York	New York	3528104393272781646	fa8e59c9e8766716fb4dcc535f88c19b	Diners Club / Carte Blanche	40.6056235067769862	-73.9140181264735787
12670	2020-02-18 04:40:58	2020-02-18	Dana Pagac	dana.pagac@geemail.com	San Antonio	Texas	3760653268216515	d20f5c8a27aa8423af46f6502912d069	Diners Club / Carte Blanche	29.5035188238207269	-98.480331938511128
12671	2020-02-18 04:47:19	2020-02-18	Dillan Carroll	dillan.carroll@geemail.com	San Francisco	California	3763363363334158	a26893eb91ca9731421d0a701869eadf	Diners Club / Carte Blanche	37.771725285986534	-122.446353506668501
12672	2020-02-18 04:55:07	2020-02-18	Genoveva Hettinger	genoveva.hettinger@woohoo.com	Des Moines	Iowa	3477672419753342	f10567545013d11e6b7214048a4fd396	Voyager	41.5108791778538375	-93.5604341576851937
12673	2020-02-18 05:12:23	2020-02-18	Nakia Strosin-Howell	nakia.strosin.howell@geemail.com	Los Angeles	California	3112006012985671469	e74bc7d6ac6896dda89bce5f01c75fc6	Mastercard	34.0506398666515935	-118.450625521269814
12674	2020-02-18 05:15:39	2020-02-18	Dr. Britany Nienow PhD	dr.britany.nienow.phd@geemail.com	Ontario	California	503811103759103	88d10aa180cf4117c9aa4f1396e1d81c	JCB 16 digit	34.0901250072900197	-117.613489519675085
12675	2020-02-18 05:17:16	2020-02-18	Mrs. Ayanna Cremin DDS	mrs.ayanna.cremin.dds@warmmail.com	San Francisco	California	869957655617388635	83ddc61459f28a051853753afc2c2df0	American Express	37.7625771532849726	-122.425442978893386
12676	2020-02-18 05:33:01	2020-02-18	Darell Green Jr.	darell.green.jr.@geemail.com	Minneapolis	Minnesota	4553242188512	aceda441d39bc4f1d4826a640f02274e	Diners Club / Carte Blanche	44.8752524446781678	-93.2873698754973617
12677	2020-02-18 05:33:27	2020-02-18	Karter Lesch	karter.lesch@geemail.com	Raleigh	North Carolina	6011983698752435638	518d14e1e3f246a0f2affa57a445d8c4	Discover	35.7390389046765833	-78.5913062021538593
12678	2020-02-18 05:53:35	2020-02-18	Add Stanton	add.stanton@geemail.com	New York	New York	51597947351119772	58a64cc46d003dfc493018ad4fcef204	JCB 16 digit	40.5765573717411598	-74.0285345607332914
12679	2020-02-18 05:56:39	2020-02-18	Marcia Beahan	marcia.beahan@geemail.com	Birmingham	Alabama	675997087928418	e7aadd15a0d5e3bc9c8df9e13bfb0be3	Mastercard	33.5033862419217812	-86.7397073390204554
12680	2020-02-18 06:07:09	2020-02-18	Mr. Odus Von II	mr.odus.von.ii@geemail.com	Milwaukee	Wisconsin	210074487737443473	2325514649a99822a71a8da97b6cb842	VISA 16 digit	43.1507111938290251	-88.0560218758515987
12681	2020-02-18 06:38:10	2020-02-18	Kyler Boyer	kyler.boyer@geemail.com	Irvine	California	52326340219088249	a63314c7a16d6236606ef86124654f98	Voyager	33.7500746219433907	-117.803286060878264
12682	2020-02-18 06:46:06	2020-02-18	Oralia Jacobi	oralia.jacobi@geemail.com	San Francisco	California	676139817669342	7c7a4ea8c24037bb7642db5854304fef	JCB 15 digit	37.7795776512324721	-122.433372763626991
12683	2020-02-18 07:01:08	2020-02-18	Bobbye Davis	bobbye.davis@geemail.com	Fresno	California	3158157375514968798	e4e4914855a6b6163cacf0757f0b306e	JCB 16 digit	36.7977013137996209	-119.765354464027666
12684	2020-02-18 07:38:18	2020-02-18	Narcissus Herzog	narcissus.herzog@geemail.com	New York	New York	180088151633118969	9be912d32bc2c22164215335f309fc4a	VISA 16 digit	40.6058092457931465	-73.8400024631887675
12685	2020-02-18 07:44:30	2020-02-18	Tamiko Kozey	tamiko.kozey@geemail.com	Lubbock	Texas	3780884751969387	1db6c85db033c6f7f884d4b619d25f04	JCB 16 digit	33.5400806589093108	-101.807751421854647
12686	2020-02-18 08:09:39	2020-02-18	Ginny Mraz DDS	ginny.mraz.dds@geemail.com	San Francisco	California	3088018284937875011	f74dc47efb5f53437130157f43d754e6	Diners Club / Carte Blanche	37.7805381139624785	-122.46369610704734
12687	2020-02-18 08:24:08	2020-02-18	Acey Ullrich MD	acey.ullrich.md@woohoo.com	Nashville	Tennessee	676189744969083	bfbab1ce4f09de9dc64548df6dd1a980	Diners Club / Carte Blanche	36.2325753503136312	-86.8136409946624212
12688	2020-02-18 08:51:44	2020-02-18	Fisher Deckow-Lynch	fisher.deckow.lynch@woohoo.com	Berkeley	California	3528105679509402025	719c39a82af59cf63bf512e7c9e90b22	American Express	37.900414099445797	-122.239731851272182
12689	2020-02-18 09:07:07	2020-02-18	Damien Jacobi	damien.jacobi@geemail.com	Boise	Idaho	3337970364024069052	c114c43bf790ba71a21758170227c902	VISA 16 digit	43.6688101373750754	-116.210989003694436
12690	2020-02-18 09:19:06	2020-02-18	Mrs. Sherie Gottlieb	mrs.sherie.gottlieb@woohoo.com	San Francisco	California	4698894187165140	ca82acb3294b9f3d7cdbab2c181fb801	VISA 16 digit	37.7615093045344494	-122.425906385721674
12691	2020-02-18 09:33:43	2020-02-18	Dr. Avon Cartwright	dr.avon.cartwright@warmmail.com	Madison	Wisconsin	4625991600515	a23ed8d57ec5050ac5b4de05e00cf631	VISA 16 digit	43.0909695828307449	-89.494653644494349
12692	2020-02-18 09:40:22	2020-02-18	Nella Gerlach-Stoltenberg	nella.gerlach.stoltenberg@woohoo.com	Lakewood	Colorado	4292837379117	17d601cfffb25dbd8d726161fe6d6352	Voyager	39.6133832274876525	-105.019107146563371
12693	2020-02-18 09:46:55	2020-02-18	Dr. Marlys Rath DDS	dr.marlys.rath.dds@geemail.com	Fresno	California	869937127603167782	978477ef3698f5ec76f22b96ab09895e	JCB 15 digit	36.7698413198687106	-119.841344197850304
12694	2020-02-18 09:48:16	2020-02-18	Mr. Lloyd Frami I	mr.lloyd.frami.i@geemail.com	Wichita Falls	Texas	4402676905902	7008ac89a367494f5c392490c3852f16	JCB 15 digit	33.9889022707667223	-98.5899428007580241
12695	2020-02-18 09:49:13	2020-02-18	Finnegan Stiedemann PhD	finnegan.stiedemann.phd@geemail.com	San Francisco	California	180042469274503934	b3f18436b5521f5c43d63f0456f7fd9f	Maestro	37.7618766715501195	-122.446073071149115
12696	2020-02-18 10:07:20	2020-02-18	Britta Marks	britta.marks@warmmail.com	Oakland	California	503861938919331	b9d19f409367d00dc25bfb88934aded3	JCB 15 digit	37.8235381324839253	-122.2641773479113
12697	2020-02-18 10:25:19	2020-02-18	Tamya Hyatt	tamya.hyatt@woohoo.com	Provo	Utah	3088409417208014004	9ca99dee4a4d9a75cdf10220abbe8c15	American Express	40.3276334267828602	-111.700075022052232
12698	2020-02-18 10:57:13	2020-02-18	Dr. Olaf Stoltenberg Jr.	dr.olaf.stoltenberg.jr.@geemail.com	Durham	North Carolina	4457469917449	7ce664a8a19ff79075d76128cb8461cb	JCB 16 digit	36.0700060649555141	-78.8595161393653683
12699	2020-02-18 11:10:32	2020-02-18	Damien Walsh IV	damien.walsh.iv@woohoo.com	San Francisco	California	180053389652538243	cfd1ed858576fa51c696f8100885edec	VISA 16 digit	37.7459810285378197	-122.436128553629302
12700	2020-02-18 11:28:08	2020-02-18	Messiah Muller	messiah.muller@geemail.com	North Las Vegas	Nevada	3050700903719719	47c7136be0983cc5c05611278253fb7d	VISA 13 digit	36.2338401619035722	-115.140211773685749
12701	2020-02-18 11:43:08	2020-02-18	Treva Mayer	treva.mayer@geemail.com	Elk Grove	California	4469613185864	93e36a403f7ff2f81e30fa418a95eb46	Mastercard	38.3769822375666365	-121.307682419279601
12702	2020-02-18 12:07:17	2020-02-18	Nathalie Grady PhD	nathalie.grady.phd@geemail.com	San Francisco	California	6011647295299923321	236b94bbb81d73139c9d1e0f4f6b2f54	JCB 15 digit	37.7724437095435306	-122.414118020006356
12703	2020-02-18 12:30:57	2020-02-18	Zachary Turner	zachary.turner@geemail.com	Oakland	California	4167480637518	0065863d9ed0022e0317a89c0222a216	JCB 16 digit	37.8218848336089764	-122.267164882491286
12704	2020-02-18 12:54:59	2020-02-18	Shelly Bogan	shelly.bogan@warmmail.com	Phoenix	Arizona	3749341216425919	1827187619fa353ddcce59b200fca552	Voyager	33.6662386202652044	-112.16157772992031
12705	2020-02-18 13:23:34	2020-02-18	Barry Schmitt	barry.schmitt@warmmail.com	St. Louis	Missouri	210053509084362017	e93d3e699fdd5dfc8e3d235099dc1b20	Voyager	38.6207118835922358	-90.227560903504866
12706	2020-02-18 13:25:40	2020-02-18	Berneice Krajcik	berneice.krajcik@geemail.com	Berkeley	California	3337382767866219142	7a77828a84d2e9e5105e5510e2424dff	Mastercard	37.8531514325752383	-122.25996556944223
12707	2020-02-18 13:33:46	2020-02-18	Wm Abernathy	wm.abernathy@warmmail.com	St. Louis	Missouri	4834123164255	372ece05e590dec063fc81d1f1cbefc7	Mastercard	38.6263185357365728	-90.223455815297001
12708	2020-02-18 13:51:12	2020-02-18	Mrs. Shauna Schroeder	mrs.shauna.schroeder@geemail.com	Hialeah	Florida	6011180347619337246	a0582893788381db79a41c328af9b265	JCB 16 digit	25.89615213796273	-80.3372105549923958
12709	2020-02-18 15:12:43	2020-02-18	Mariano Cole	mariano.cole@warmmail.com	San Francisco	California	4735507484362773	d0fdd57182b161ffbe51d98f5fb67120	VISA 16 digit	37.7339033613325228	-122.441622203423194
12710	2020-02-18 15:23:23	2020-02-18	Yael Kuphal	yael.kuphal@geemail.com	Aurora	Colorado	3096345256287761300	9125ada08456e1d06ad460fd1833bb2e	American Express	39.6125306893251832	-104.671609196777268
12711	2020-02-18 15:23:45	2020-02-18	Sherron Cremin	sherron.cremin@geemail.com	Austin	Texas	52152937098887937	f4e80adb38e02184568b49c61020ccda	JCB 15 digit	30.2074958232823754	-97.7679648061987052
12712	2020-02-18 15:24:08	2020-02-18	Kael Keebler	kael.keebler@geemail.com	Sacramento	California	3402815229914931	965f66c2c86a537eab04c92013bde3ff	VISA 13 digit	38.4767642903871874	-121.44337231542579
12713	2020-02-18 15:30:37	2020-02-18	Kyler Hills I	kyler.hills.i@geemail.com	Austin	Texas	4945814692337431	f3a6483dd98497c10c74568b3d51051e	Discover	30.306612829364461	-97.7932281593099333
12714	2020-02-18 15:50:45	2020-02-18	Kimberly Bahringer	kimberly.bahringer@geemail.com	Augusta	Georgia	3528676255924778999	2fba652ee16571459e74b4def11a7047	Diners Club / Carte Blanche	33.3419422673731987	-82.0713964841157235
12715	2020-02-18 15:57:22	2020-02-18	Mrs. Latoya Feeney	mrs.latoya.feeney@geemail.com	Columbus	Ohio	869934385592800002	4638f2492133355f98345504bd308bec	Diners Club / Carte Blanche	40.0273712066046912	-82.996262326487539
12716	2020-02-18 16:01:24	2020-02-18	Amiyah Cummerata	amiyah.cummerata@warmmail.com	Philadelphia	Pennsylvania	6011631995774691990	7f5f89d7bc0cdb4414203edaaf875300	VISA 16 digit	39.9105429383419477	-75.0613485460069114
12717	2020-02-18 16:33:03	2020-02-18	Mr. Santana Homenick	mr.santana.homenick@geemail.com	San Francisco	California	869912750056835834	8ea536a83f795ee57d7ebc067151bf7c	JCB 16 digit	37.7478777087729114	-122.421790231028695
12718	2020-02-18 17:09:45	2020-02-18	Madie Herzog	madie.herzog@geemail.com	San Francisco	California	53581578298327430	ba371c2a21de3e0f650cafbb0b96f5c6	American Express	37.7712715898437281	-122.467472328366583
12719	2020-02-18 17:12:03	2020-02-18	Michale Olson	michale.olson@warmmail.com	Detroit	Michigan	3337558688716334592	6351bb44b3314dbaa982ed5d3b5d8084	American Express	42.3155877579860444	-83.1993955328248376
12720	2020-02-18 17:56:47	2020-02-18	Rashaad Heathcote	rashaad.heathcote@geemail.com	San Francisco	California	4721998653218217	1f5bfa063716e804fbd75531cf20bc67	Maestro	37.792341162558543	-122.41651241861031
12721	2020-02-18 18:18:14	2020-02-18	Jailene Jast	jailene.jast@geemail.com	Fresno	California	3015525954634581	9ffa63db807537b4ea2e19b3d46b3cd4	VISA 13 digit	36.8525637057017548	-119.852892661478009
12722	2020-02-18 19:03:27	2020-02-18	Goldie Leuschke	goldie.leuschke@geemail.com	Escondido	California	4087024200305379	a0d11b70c7770d039cfbf5342863683d	Diners Club / Carte Blanche	33.181821179086711	-117.02461044939794
12723	2020-02-18 19:20:13	2020-02-18	Kalvin Schumm	kalvin.schumm@geemail.com	Clinton	Michigan	54929992548592795	371894bf0ba170f3f7e4669da25f1da8	JCB 16 digit	42.5024126081794478	-82.8726517028715506
12724	2020-02-18 19:40:20	2020-02-18	Mr. Auguste Mueller IV	mr.auguste.mueller.iv@geemail.com	Lincoln	Nebraska	3748022922959026	835029f142bd8a29178f5b45cbfe0c45	JCB 16 digit	40.8532258170209772	-96.7375739313356604
12725	2020-02-18 20:05:03	2020-02-18	Eddy Orn	eddy.orn@woohoo.com	Palmdale	California	4839767718615819	99f4571e9f53d000d8a7b3731b753e00	Discover	34.5042954113651064	-118.015684883854917
12726	2020-02-18 20:33:50	2020-02-18	Lee Lindgren	lee.lindgren@warmmail.com	Fort Worth	Texas	676241555518376	e5ea7b685928a466db3a87bb7d5d188b	JCB 16 digit	32.8038401501774786	-97.4391237755127264
12727	2020-02-18 20:51:07	2020-02-18	Spurgeon Zemlak	spurgeon.zemlak@geemail.com	Killeen	Texas	4102428854784	db92b2570ca143d9142a0455416ad0ff	Voyager	31.1754960729505868	-97.678644990751522
12728	2020-02-18 20:57:40	2020-02-18	Herbert Heaney	herbert.heaney@warmmail.com	Kansas City	Missouri	6011320580064783230	3035c8a4f2eddd22165dbfce127bfd63	VISA 16 digit	39.1520850147422408	-94.4538574991039894
12729	2020-02-18 21:02:00	2020-02-18	Izora Grady	izora.grady@geemail.com	Fontana	California	6011203262376757507	13f872e54f428e2bc2aa4ba0da92e945	Diners Club / Carte Blanche	34.1970760116036985	-117.448702668659024
12730	2020-02-18 21:07:33	2020-02-18	Mrs. Ila Goyette	mrs.ila.goyette@geemail.com	Frisco	Texas	3467991406183293	36a8ca46f0df0afbcea97f921f60ec5a	Mastercard	33.2102333561513561	-96.8351571828335409
12731	2020-02-18 21:08:08	2020-02-18	Miss Clarisa Kreiger DVM	miss.clarisa.kreiger.dvm@geemail.com	Minneapolis	Minnesota	3337695523812783851	ae6fb6b7bf93d67e4593615564d4b6e4	Voyager	44.9278052732434077	-93.2048509768016658
12732	2020-02-18 21:23:37	2020-02-18	Mr. Noble Schimmel	mr.noble.schimmel@woohoo.com	San Mateo	California	3112896037061456702	a2338f7448946cdedccf4401be09b4dd	Diners Club / Carte Blanche	37.5708610899627189	-122.283742535053193
12733	2020-02-18 22:10:59	2020-02-18	Uriah Frami	uriah.frami@geemail.com	Houston	Texas	3528679750184719540	21d48e954a55d9c8b08784535a801251	VISA 13 digit	29.7597975378468647	-95.3346534858938384
12734	2020-02-18 22:21:17	2020-02-18	Reagan McGlynn	reagan.mcglynn@geemail.com	Houston	Texas	180055738587014753	e36f33385741cc349e1d89a3410b3eff	Mastercard	29.7517347294915453	-95.4173489000663153
12735	2020-02-18 22:21:55	2020-02-18	Ahmad Feil III	ahmad.feil.iii@woohoo.com	Irvine	California	869984704687665907	44189fb454975480fe427cfc0df9dfe2	American Express	33.6638374986607616	-117.868124079332873
12736	2020-02-18 22:44:36	2020-02-18	Dr. Erland Doyle MD	dr.erland.doyle.md@woohoo.com	Jackson	Mississippi	3449866086124333	1064b076029d229d007014192bf74713	VISA 16 digit	32.3974903689876257	-90.1673451568439646
12737	2020-02-18 23:14:49	2020-02-18	Christin Weber	christin.weber@geemail.com	St. Louis	Missouri	4647360892838	e663e72f417524879854f646443b6062	Mastercard	38.6996891904313145	-90.3218546078544193
12738	2020-02-18 23:18:11	2020-02-18	Darin Robel	darin.robel@warmmail.com	San Francisco	California	4990937861416258	bdcbc57129b712ff8e16ed81e77d27ad	JCB 16 digit	37.767676985301982	-122.445083102967146
12739	2020-02-18 23:31:03	2020-02-18	Mr. Len Baumbach II	mr.len.baumbach.ii@warmmail.com	San Francisco	California	210012071158559184	79777a898563ebb9328abc8ddaafa323	Discover	37.764842287884349	-122.40327104971611
12740	2020-02-18 23:47:06	2020-02-18	Tad Wyman	tad.wyman@geemail.com	San Francisco	California	180073543151048007	25eb40d1557b5468ab49b1e6bbf49b61	JCB 16 digit	37.7867797251262942	-122.411916337725486
12741	2020-02-18 23:56:13	2020-02-18	Kailee Purdy	kailee.purdy@geemail.com	Boise	Idaho	869992306395274772	b5f5e43e6a9b062bceaa98727f9a9641	JCB 16 digit	43.6144050601076358	-116.183281779122353
12742	2020-02-19 01:25:34	2020-02-19	Ariel Fahey	ariel.fahey@woohoo.com	San Francisco	California	3112696393708203565	9bb2768a61fb8280a791ecd80731dff7	VISA 16 digit	37.7510049061509889	-122.42012330867334
12743	2020-02-19 01:34:22	2020-02-19	Venie Leannon	venie.leannon@geemail.com	Philadelphia	Pennsylvania	4947993698863299	75c5cbd8b93a534d83b77545640cdf83	JCB 16 digit	39.9847787034191171	-75.2278517062675292
12744	2020-02-19 02:00:43	2020-02-19	Reed Harber-Weber	reed.harber.weber@geemail.com	San Francisco	California	3112488124221159048	f6dcbd8e940de98c8b2e218222caeb72	Diners Club / Carte Blanche	37.805079143709726	-122.451632077648412
12745	2020-02-19 02:46:15	2020-02-19	Spencer Hamill	spencer.hamill@woohoo.com	Raleigh	North Carolina	4042200943670	68a84cd35022b63fef9c068063f973b7	JCB 15 digit	35.929104982562734	-78.6964408755239191
12746	2020-02-19 03:39:21	2020-02-19	Bradford McClure	bradford.mcclure@geemail.com	Chicago	Illinois	869946179121491060	f8a660590d3e3e8d9fdc79e9cd90d060	Voyager	41.881692816952615	-87.6613436602085727
12747	2020-02-19 03:56:28	2020-02-19	Miss Cayla Kuhic PhD	miss.cayla.kuhic.phd@geemail.com	St. Louis	Missouri	4544567555294	92ca193f8d803ac63e9063d77b80ce70	VISA 16 digit	38.5675439185153692	-90.2607359544377772
12748	2020-02-19 04:08:06	2020-02-19	Stephan Monahan	stephan.monahan@warmmail.com	Berkeley	California	4011728445680435	d5c150dc7b6cbfb8e4f3f5a0a2f85918	Voyager	37.8819466531474376	-122.273269212432311
12749	2020-02-19 04:10:29	2020-02-19	Mr. Tyrone Wehner	mr.tyrone.wehner@geemail.com	San Francisco	California	4496728776261	f80712fe9d2936f93942764c34502cf5	VISA 16 digit	37.7815660936738738	-122.425776642833682
12750	2020-02-19 04:11:15	2020-02-19	Ms. Mattie Schinner	ms.mattie.schinner@geemail.com	Scottsdale	Arizona	210094824751169087	dd9504851a75650f0981dd04ef9cd01b	American Express	33.6510762470431644	-111.857352647601061
12751	2020-02-19 04:11:24	2020-02-19	Gurney Wyman-Little	gurney.wyman.little@geemail.com	Arlington	Texas	6011859036947866360	c5d29de6eb69c9071c2e5989b244d8b5	VISA 16 digit	32.7821943690784252	-97.0402480549670798
12752	2020-02-19 04:14:38	2020-02-19	Miss Peggy Stamm PhD	miss.peggy.stamm.phd@warmmail.com	Oklahoma City	Oklahoma	4894083018834	d9b09463bf1698ba396adcd597d888fd	JCB 15 digit	35.462296962403137	-97.5757822591707082
12753	2020-02-19 04:16:04	2020-02-19	Adrianne Cruickshank	adrianne.cruickshank@warmmail.com	Fort Worth	Texas	6011478328685149666	3e3de6e63de2158866dcfef288ecf652	JCB 16 digit	32.7529756972622152	-97.3546814843833488
12754	2020-02-19 04:33:28	2020-02-19	Dr. Drew Leuschke Sr.	dr.drew.leuschke.sr.@woohoo.com	San Francisco	California	3480065867631547	fc4e0187f48140763823856ac1c58f08	Maestro	37.7705944242598477	-122.422629548329709
12755	2020-02-19 04:35:43	2020-02-19	Mr. Robley Champlin DDS	mr.robley.champlin.dds@woohoo.com	Worcester	Massachusetts	3014917713158229	c5cb93b48e6cd122f9f2e386c4478806	Diners Club / Carte Blanche	42.2846931839995079	-71.8108413145665025
12756	2020-02-19 05:18:55	2020-02-19	Obie Botsford	obie.botsford@geemail.com	Las Cruces	New Mexico	4172506490981915	1472d704071b0afac6a864f9f9e29f48	VISA 16 digit	32.3544716434121113	-106.863659475802251
12757	2020-02-19 05:34:51	2020-02-19	Herman Tremblay-Marquardt	herman.tremblay.marquardt@warmmail.com	Charlotte	North Carolina	3760599641470669	fe04aff0df19d73dfed64bdb5c3f4390	Maestro	35.248746083329614	-80.8999062721561728
12758	2020-02-19 05:41:15	2020-02-19	Mrs. Felicia Sipes DVM	mrs.felicia.sipes.dvm@woohoo.com	Miami Gardens	Florida	53435570260442261	f917d2f6e3fd6760d2f26675d99ed451	American Express	25.8668516165517239	-80.3276323362965172
12759	2020-02-19 05:52:26	2020-02-19	Sammie Brakus	sammie.brakus@geemail.com	San Francisco	California	3032923069497262	881dd72a8d2e819be6958f4dc219ab9c	Mastercard	37.7765904686342679	-122.402989135997103
12760	2020-02-19 06:00:20	2020-02-19	Dalia Mann	dalia.mann@geemail.com	New York	New York	3012795563645079	f7c6b0e085bd5721cdb3d1655f7cbe94	Discover	40.5784357067886745	-74.0384874802444131
12761	2020-02-19 06:04:15	2020-02-19	Esteban Satterfield	esteban.satterfield@geemail.com	New York	New York	3528406573642326728	77c6f9c9126245dfe6126cd449290928	Mastercard	40.6542441930845371	-74.0284251039277734
12762	2020-02-19 06:12:09	2020-02-19	Mr. Jacoby Okuneva DDS	mr.jacoby.okuneva.dds@geemail.com	Boston	Massachusetts	869983521536302214	be8580f424a97115ad003f086e4e57d8	Discover	42.3870653496757157	-71.0885712489437367
12763	2020-02-19 06:12:50	2020-02-19	Pinkney Wintheiser	pinkney.wintheiser@geemail.com	Berkeley	California	3088813390342456979	ce130e2596a55147f6d1dc8986aa7335	VISA 16 digit	37.8655254387900584	-122.275958805773755
12764	2020-02-19 06:15:08	2020-02-19	Portia Nicolas	portia.nicolas@geemail.com	Oklahoma City	Oklahoma	676363666448608	22dac238e6c8a1c210ea7af72270aafe	Voyager	35.458766288254786	-97.5514619701903314
12765	2020-02-19 06:15:23	2020-02-19	Reggie Erdman	reggie.erdman@geemail.com	Charleston	South Carolina	869930388786787914	bfa7ea82507900b656a6cd3cde493fe9	Mastercard	32.8203768104776756	-80.0033059674464226
12766	2020-02-19 06:16:09	2020-02-19	Arta Weimann	arta.weimann@geemail.com	New York	New York	3088104750490344343	afac462c78ffd23b1bbe47ebce57839d	JCB 16 digit	40.6769198531042804	-73.9681541828799993
12767	2020-02-19 06:31:45	2020-02-19	Linnie Wisozk	linnie.wisozk@geemail.com	Oakland	California	3088068428218526517	a3d293b314af1217643106b2811d0063	American Express	37.8151325404823737	-122.278548706532618
12768	2020-02-19 06:56:00	2020-02-19	Mr. Derek Miller Jr.	mr.derek.miller.jr.@warmmail.com	New York	New York	502013479391834	e331dc673598747edb92fc50f6ca681c	JCB 15 digit	40.7494546784311495	-73.9911283622857212
12769	2020-02-19 06:59:11	2020-02-19	Santo Roob DDS	santo.roob.dds@geemail.com	New York	New York	3096418054169307082	883ee1fc48eb29a0439100ac4243c6df	JCB 16 digit	40.6116266564689568	-73.9973451214272444
12770	2020-02-19 07:25:32	2020-02-19	Nolia Howe	nolia.howe@geemail.com	San Diego	California	3495556152302524	ba2b62af9f60d594de88ccb87029e82e	Mastercard	32.8510572494540369	-117.234936589086431
12771	2020-02-19 07:52:24	2020-02-19	Britt Daniel	britt.daniel@geemail.com	Los Angeles	California	3528947779568172436	60ab675b600464758f44a32994ef3cc1	VISA 16 digit	33.9413602370634635	-118.315382566767923
12772	2020-02-19 07:54:43	2020-02-19	Trever Williamson	trever.williamson@geemail.com	Minneapolis	Minnesota	4264268708866	b11bbe7199d4fdd1a81ca6cacc717d58	JCB 16 digit	45.0338341037828442	-93.20414822411648
12773	2020-02-19 08:11:58	2020-02-19	Elza Walsh	elza.walsh@geemail.com	New York	New York	869942065651269113	915e46ae901b7f8ddb98287fbc3a90a7	Maestro	40.7027152557149492	-73.9662382847525208
12774	2020-02-19 08:21:58	2020-02-19	Taurus Ebert DVM	taurus.ebert.dvm@geemail.com	San Mateo	California	54051375394422319	ae0392c065c5dd6674caeeb8de79852f	Discover	37.4855718195319128	-122.369011015151059
12775	2020-02-19 08:23:29	2020-02-19	Dr. Brynlee Weimann	dr.brynlee.weimann@geemail.com	New York	New York	53619615247911579	5ef2b53c4db61934445476049dbcd10c	JCB 16 digit	40.6265233884789012	-73.9502604470483931
12776	2020-02-19 08:29:37	2020-02-19	Angel Sawayn	angel.sawayn@warmmail.com	New York	New York	3528732891871729197	b66b2423d008279a6bafa696275638be	American Express	40.6828744286429114	-74.0265706532530459
12777	2020-02-19 08:45:52	2020-02-19	India Kuvalis	india.kuvalis@geemail.com	San Francisco	California	4152836445350039	5a0c19614dbc8b373399bd259c74773f	Maestro	37.8001233703629254	-122.424437473696088
12778	2020-02-19 09:43:31	2020-02-19	Willy Purdy	willy.purdy@geemail.com	Fontana	California	4807460170374	9d6cc96efffaede8e29dfa1bcd63d508	Discover	34.1881896048933314	-117.538527528363844
12779	2020-02-19 09:48:45	2020-02-19	Junius Mills	junius.mills@geemail.com	Chicago	Illinois	6011586948887635938	370f18fe1ecdadac68c5b1ec1e9665d7	JCB 16 digit	41.7450876789003615	-87.6389546375751394
12780	2020-02-19 10:05:00	2020-02-19	Theo Gibson	theo.gibson@geemail.com	Greensboro	North Carolina	4588856107842820	6c76afd4426b5f2a813f29894bf1018a	JCB 16 digit	36.1449990392778062	-79.87250644932314
12781	2020-02-19 10:07:55	2020-02-19	Magnolia Green	magnolia.green@geemail.com	Lexington	Kentucky	180078650100440576	8275b1aeb6b01fa60b395a6b05bfb505	JCB 15 digit	38.0458390666514674	-84.4535202602289559
12782	2020-02-19 10:17:05	2020-02-19	Leann Beer	leann.beer@woohoo.com	New York	New York	6011071969039609607	392100072d24505444aacf083dfa582b	JCB 16 digit	40.7426429079603381	-73.8883637208852946
12783	2020-02-19 10:25:26	2020-02-19	Irene Hahn-Schowalter	irene.hahn.schowalter@woohoo.com	Chicago	Illinois	3772912162957517	ad5116fb5ad6e2cce0bae0d3093de265	VISA 13 digit	41.7488730055581811	-87.7295233250159754
12784	2020-02-19 10:26:46	2020-02-19	Mr. Jarred Hilll DVM	mr.jarred.hilll.dvm@woohoo.com	Berkeley	California	4410769796758757	9d727b5cecc0190bbcd6df746f3de702	VISA 16 digit	37.8707350905923974	-122.273153320094323
12785	2020-02-19 10:31:18	2020-02-19	Vernell Frami	vernell.frami@geemail.com	Houston	Texas	676215683963241	6975b4344e64c356e8c1d05afea4de50	JCB 16 digit	29.8688235420811914	-95.4415525652017465
12786	2020-02-19 10:36:33	2020-02-19	Jerrie Cronin	jerrie.cronin@geemail.com	Indianapolis	Indiana	210088489318685377	e1c8234e19aade159b3f244e049eac38	Voyager	39.8171138028621669	-86.1407181960266115
12787	2020-02-19 10:45:42	2020-02-19	Adelbert Krajcik	adelbert.krajcik@geemail.com	San Francisco	California	180091447389182026	a5f393568b49d3eaf419ae17f41474d1	JCB 16 digit	37.7592046206809968	-122.39570713490447
12788	2020-02-19 11:08:48	2020-02-19	Lurline Langosh	lurline.langosh@geemail.com	Fresno	California	4683573394767172	f2920f36a5b29f91a3f57bb63ef891fb	JCB 15 digit	36.7825189848303822	-119.81289229752646
12789	2020-02-19 11:38:07	2020-02-19	Cain Emmerich V	cain.emmerich.v@geemail.com	Irvine	California	180027646977807691	c9a05c45efee4892dd161405f442cf53	Mastercard	33.6475440073307652	-117.808397100680693
12790	2020-02-19 11:42:51	2020-02-19	Mr. Tex Wisozk II	mr.tex.wisozk.ii@warmmail.com	Plano	Texas	3712482544580885	a0e175ea724640930e6321e0706a6b7c	VISA 16 digit	33.072471993704518	-96.71836641428024
12791	2020-02-19 12:01:49	2020-02-19	Garner Wilderman II	garner.wilderman.ii@geemail.com	San Francisco	California	180041788742275358	de76fa17e8ac2c88c6edeaeacf971ce1	JCB 16 digit	37.8071244872258561	-122.439064796696428
12792	2020-02-19 12:14:17	2020-02-19	Miss Karma Cormier	miss.karma.cormier@geemail.com	Naperville	Illinois	676237931271011	e340773c9f12149253e350040f4f3a00	Diners Club / Carte Blanche	41.8314580495383623	-88.1967852064296665
12793	2020-02-19 12:23:05	2020-02-19	Darvin Marks	darvin.marks@geemail.com	Boise	Idaho	3528382599789153300	f8cb25086cb72772b0ad7a2384605981	VISA 16 digit	43.6442307048615064	-116.234038545722896
12794	2020-02-19 12:28:56	2020-02-19	Roll West	roll.west@geemail.com	Green Bay	Wisconsin	3456084601525949	1004d3ea8df1c0e245bcccc35a324940	VISA 16 digit	44.49454270862676	-87.8850570085745346
12795	2020-02-19 12:34:08	2020-02-19	Anita Mayer	anita.mayer@warmmail.com	Bakersfield	California	180035579132894496	4ab1e6075f6346d9bbc7af532dd766a3	Voyager	35.3065057172149395	-118.973351792226723
12796	2020-02-19 12:54:23	2020-02-19	Miss Siobhan Ankunding	miss.siobhan.ankunding@geemail.com	Grand Prairie	Texas	53231277133679642	29b97dab712f94ddd895368408d0a083	Mastercard	32.6068067652691198	-96.9682694454085095
12797	2020-02-19 12:59:06	2020-02-19	Kaleena Kessler	kaleena.kessler@woohoo.com	Oakland	California	4271895481551	2833d1949e8f6cfdc3f339a1873d3961	VISA 16 digit	37.7631710258631017	-122.307005842826143
12798	2020-02-19 12:59:41	2020-02-19	Dania Brekke	dania.brekke@warmmail.com	Jacksonville	Florida	676216906979030	9e778ec2a9cacbfd9e21017af13a7ba2	VISA 13 digit	30.2910245230939239	-81.5899151392359414
12799	2020-02-19 13:00:14	2020-02-19	Dr. Jeramiah Schmitt	dr.jeramiah.schmitt@geemail.com	Cedar Rapids	Iowa	3059968339683731	c9350a35be6a264cf940efe7bbd38aa0	American Express	41.9399838491883088	-91.677685280104356
12800	2020-02-19 13:29:32	2020-02-19	Maryam Wiza PhD	maryam.wiza.phd@geemail.com	Oakland	California	51811849575000707	8518a31e2c07b17a69929c8784ba1fa2	Discover	37.8348938301063811	-122.2426639334264
12801	2020-02-19 13:54:46	2020-02-19	Lotta Fadel	lotta.fadel@geemail.com	San Francisco	California	3059756887710737	6dd1c4f88c0d8b9099f3bd3ee0b46a49	JCB 16 digit	37.7635724488487767	-122.480793257450003
12802	2020-02-19 14:00:18	2020-02-19	Benedict Marvin MD	benedict.marvin.md@geemail.com	San Francisco	California	6011648975988970142	2b62eda3009eddc8054156df6fb16c1d	Mastercard	37.7604816013091735	-122.433143678610875
12803	2020-02-19 14:20:09	2020-02-19	Dr. Dayanara Roob PhD	dr.dayanara.roob.phd@warmmail.com	New York	New York	3752560749639944	8cd884f2c9ad55a875f9a09655ec3f28	Discover	40.7400657736919811	-73.9864507147006663
12804	2020-02-19 14:36:49	2020-02-19	Verne Heidenreich MD	verne.heidenreich.md@geemail.com	Corpus Christi	Texas	4424984233108	473080f655a56fe2e605dc3010ae75f4	JCB 16 digit	27.7858767612308277	-97.0838729659389656
12805	2020-02-19 14:55:51	2020-02-19	Ritchie Thompson	ritchie.thompson@geemail.com	Washington	District of Columbia	6011474829600794977	594e8528d31970ed3cb32cf3210284ab	Maestro	38.900460955480483	-76.953664799335229
12806	2020-02-19 15:04:10	2020-02-19	Tarik Johnson	tarik.johnson@geemail.com	Reno	Nevada	3000961557586917	8f3f7f996faa73fb4178eaf8cfd01da0	Voyager	39.4525405653364984	-119.797463405800613
12807	2020-02-19 15:52:41	2020-02-19	Rene Gibson-Corkery	rene.gibson.corkery@geemail.com	Thousand Oaks	California	561271245211892	5527d91f008c87717435f4b47c305563	VISA 16 digit	34.1464793367117636	-118.834974107370527
12808	2020-02-19 15:53:42	2020-02-19	Ms. Phylicia Corwin MD	ms.phylicia.corwin.md@woohoo.com	San Francisco	California	4854954787701460	9a64ba09563c515f59fa7326f23069a7	VISA 16 digit	37.774189914444996	-122.396448010038455
12809	2020-02-19 16:08:23	2020-02-19	Edythe Terry	edythe.terry@geemail.com	Houston	Texas	4608041666419437	1c4289fdbc61af762201b2f6b4e71890	Diners Club / Carte Blanche	29.7794277459461227	-95.2965409214623236
12810	2020-02-19 16:10:06	2020-02-19	Chelsie Kilback	chelsie.kilback@woohoo.com	Corpus Christi	Texas	4185875737868432	dbe97c2f5d7a82714538dc713e234400	Voyager	27.7226834493625915	-97.1838284720960957
12811	2020-02-19 16:10:11	2020-02-19	Ouida Blanda	ouida.blanda@woohoo.com	Denver	Colorado	676204389781321	770f7a41e045955701c063842e36364f	Discover	39.773595123696694	-104.814624477947504
12812	2020-02-19 16:34:42	2020-02-19	Dr. Lue Dibbert	dr.lue.dibbert@geemail.com	San Francisco	California	210077940784129228	bf3045115a7c3dbc33c72555f760e4bf	Mastercard	37.7815954899262465	-122.420676197028925
12813	2020-02-19 16:39:40	2020-02-19	Pranav Mueller	pranav.mueller@geemail.com	San Francisco	California	869924105413424242	940b5740f686db8c840287a3a8fdf108	Maestro	37.7666742690257209	-122.435681971742284
12814	2020-02-19 16:45:36	2020-02-19	Ms. Aliya D'Amore DDS	ms.aliya.d'amore.dds@geemail.com	Fresno	California	4598643103214	efec0636f225d68a589f312991f29449	Discover	36.7136222532358047	-119.813845735659456
12815	2020-02-19 16:48:07	2020-02-19	Pearle Jast	pearle.jast@woohoo.com	Newark	New Jersey	869920444736949682	ea3a02c98cdd75006d0077e038eb9cb2	Voyager	40.7305759451266383	-74.1470883269537211
12816	2020-02-19 16:59:46	2020-02-19	Brittnay Pfannerstill	brittnay.pfannerstill@geemail.com	Syracuse	New York	3337348388979051059	dd753fb6ba19651dfa518d279d1fead7	JCB 16 digit	43.0648974006380882	-76.1920280803240928
12817	2020-02-19 17:06:34	2020-02-19	Deegan McDermott	deegan.mcdermott@warmmail.com	St. Petersburg	Florida	3158387165560781415	4293026642b7428ae1670dfad5d4c0ea	VISA 13 digit	27.8367601468116064	-82.567886926222954
12818	2020-02-19 17:09:19	2020-02-19	Dr. Breana Mraz	dr.breana.mraz@geemail.com	Everett	Washington	3001545243837336	dfe4120074dc63639bb54dbfbac94100	JCB 16 digit	47.8665103775341052	-122.268785426405813
12819	2020-02-19 17:12:04	2020-02-19	Creola Buckridge	creola.buckridge@geemail.com	Hialeah	Florida	3337815618223661483	4de3b4ee4e5caa4331b5170661c6e60c	VISA 16 digit	25.7740760891210314	-80.2457114766255017
12820	2020-02-19 17:20:10	2020-02-19	Tania Bartoletti	tania.bartoletti@geemail.com	Jacksonville	Florida	4366859245555153	7529df6bed352252b91976a10d593fd0	VISA 13 digit	30.2707895290624336	-81.6808371217068299
12821	2020-02-19 17:39:20	2020-02-19	Brantley Mayert	brantley.mayert@woohoo.com	San Francisco	California	3786801186485973	f21d8327b2541364cabae69f056c624e	VISA 16 digit	37.8016855753679195	-122.432728482049555
12822	2020-02-19 18:15:10	2020-02-19	Darline Rohan	darline.rohan@geemail.com	Fort Wayne	Indiana	4961311994457669	929ec792e673f3890f4d06f27a05fa0e	Maestro	41.1128682148892466	-85.1405701579745937
12823	2020-02-19 18:20:07	2020-02-19	Almond White	almond.white@geemail.com	Baton Rouge	Louisiana	3158152893040023180	b85c04cdab6ab4fb9cf4ca3700da16b1	VISA 16 digit	30.3973863888278615	-91.2125124123055429
12824	2020-02-19 18:36:18	2020-02-19	Donn Berge	donn.berge@geemail.com	Phoenix	Arizona	869970801354121432	5d240f94dbe53f2c59acacc1e1dff8bb	Voyager	33.6453710153166199	-111.990823079126329
12825	2020-02-19 19:03:41	2020-02-19	Rodger Wolff	rodger.wolff@geemail.com	Charlotte	North Carolina	4931311064986057	fa98d1437b219f9e962af51b698a28b2	Maestro	35.1939903481185397	-80.8749430591650338
12826	2020-02-19 19:04:59	2020-02-19	Carole Cruickshank	carole.cruickshank@geemail.com	St. Louis	Missouri	503883691242354	1991a0925bfdf75358e4a4bf9de7a5b7	Discover	38.6396600536227197	-90.2176586262419846
12827	2020-02-19 19:22:37	2020-02-19	Frida White	frida.white@geemail.com	Fresno	California	54174767531216335	07b18f8cca5e33edbe8c82b5e96b89f5	American Express	36.8561574874319149	-119.761334286128729
12828	2020-02-19 19:25:48	2020-02-19	Delina Hilll	delina.hilll@geemail.com	Berkeley	California	6011250746063714658	7f14edb72ed5022ea8a8e29a1963c93e	JCB 16 digit	37.8836153947663661	-122.248205060151903
12829	2020-02-19 19:37:22	2020-02-19	Kristopher Nader-Schroeder	kristopher.nader.schroeder@woohoo.com	Richmond	Virginia	4768854399513128	0965ecd864f637fbce17c2bb44fba093	Maestro	37.4723712375141673	-77.4618465919271131
12830	2020-02-19 20:00:15	2020-02-19	Brittaney Bartell	brittaney.bartell@geemail.com	Los Angeles	California	4577516540975	d72f90b720c8f84251e05ff63a57d764	JCB 16 digit	34.072599245128778	-118.430798837495217
12831	2020-02-19 20:09:35	2020-02-19	Reginal Bosco	reginal.bosco@woohoo.com	Richardson	Texas	3528252232245775717	bbef45b5ef573823174eedbf7a112120	Voyager	32.879204360884799	-96.7215085379075248
12832	2020-02-19 20:18:30	2020-02-19	Brook Hauck III	brook.hauck.iii@woohoo.com	San Francisco	California	3732021450421902	4bc6d6f24ef5c3da986ab677dc2ed405	Maestro	37.7504207673568928	-122.391470256525096
12833	2020-02-19 20:18:31	2020-02-19	Adan Botsford	adan.botsford@geemail.com	Richmond	Virginia	4839889840380292	190923d7fd43361d8cfd4d3a9ba3440f	Discover	37.5687368560802142	-77.4144939485695147
12834	2020-02-19 20:19:25	2020-02-19	Joell Lebsack DVM	joell.lebsack.dvm@geemail.com	New York	New York	210008157673360178	1bba581d2c4774275267dee95eb128db	JCB 15 digit	40.7513170376643501	-74.0205528174888343
12835	2020-02-19 20:46:24	2020-02-19	Miss Lilia Jakubowski MD	miss.lilia.jakubowski.md@geemail.com	Bakersfield	California	3158413022469421866	578ab3de127a4e202c53712ed8cadc7d	JCB 16 digit	35.2804734380625149	-119.067776535012939
12836	2020-02-19 20:59:02	2020-02-19	Clarine Reichel	clarine.reichel@warmmail.com	San Francisco	California	4821288774173353	8a68400fcd81154d60d8a6f7b9958d96	American Express	37.7625179580813182	-122.441925212341488
12837	2020-02-19 21:00:19	2020-02-19	Addyson Harber	addyson.harber@woohoo.com	New York	New York	51812723900600839	7b5a4ac42632eb3d99ef12a1321711ec	Discover	40.6819379931073613	-73.9753841193754198
12838	2020-02-19 22:05:37	2020-02-19	Dr. Carmelo Shanahan	dr.carmelo.shanahan@geemail.com	Fayetteville	North Carolina	55887017742634340	0faccbf4c8d0ba53b6c81919730d0994	JCB 16 digit	35.1449927768923303	-78.9306571175940377
12839	2020-02-19 22:07:01	2020-02-19	Zollie Mraz	zollie.mraz@geemail.com	San Antonio	Texas	869924479482829361	fb87cb7315b5bb7c43927bc8ffa78e7e	American Express	29.5586439551390718	-98.4656726322904206
12840	2020-02-19 22:24:55	2020-02-19	Ms. Bertie Upton	ms.bertie.upton@warmmail.com	San Francisco	California	53721064632533307	5ee12d5729efa97a8f02f0eb88d17562	Voyager	37.7712308450652046	-122.458743026312277
12841	2020-02-19 22:45:01	2020-02-19	Damarion Schinner	damarion.schinner@geemail.com	San Antonio	Texas	675936214188058	ff1942be3ac1ebfda000da67a08e8b71	Discover	29.3949946725811806	-98.4626481411814609
12842	2020-02-19 22:51:59	2020-02-19	Dr. Elzy Cremin	dr.elzy.cremin@geemail.com	Round Rock	Texas	54091952340985029	398de6bae2f4b3bd6101e58aaef6875a	Voyager	30.5018986824106442	-97.7427390158493097
12843	2020-02-19 22:54:48	2020-02-19	Matias Abshire-Johnson	matias.abshire.johnson@warmmail.com	Nashville	Tennessee	4982941235841753	996404a98e023a51dc6000003c72ea90	VISA 16 digit	36.1986342301249451	-86.7909759826399352
12844	2020-02-19 23:00:44	2020-02-19	Curtis Schmitt	curtis.schmitt@warmmail.com	Los Angeles	California	3736597650698502	b98b17e3438c5241764ed0969e5fdfb3	American Express	33.9666411943599584	-118.383916739699615
12845	2020-02-19 23:02:25	2020-02-19	Yoel Davis-Kihn	yoel.davis.kihn@geemail.com	Philadelphia	Pennsylvania	3751368401388722	bb115621518371cf61a70055383c028d	VISA 13 digit	39.9252398642670343	-75.198228504265856
12846	2020-02-19 23:03:36	2020-02-19	Patience Parisian	patience.parisian@warmmail.com	San Francisco	California	630442585721956	f1cbeb5cbd5883bee589a4759f55139e	Discover	37.7418428810845725	-122.428992676766242
12847	2020-02-19 23:22:25	2020-02-19	Sherman Welch	sherman.welch@warmmail.com	Peoria	Arizona	3158550491907584457	c7c8881e6bdc1b389b0a763bd50d0349	Discover	33.7536956644419561	-112.255459592856468
12848	2020-02-19 23:28:12	2020-02-19	Ms. Grace Anderson MD	ms.grace.anderson.md@warmmail.com	Sterling Heights	Michigan	3053161960697826	f6d0b580f5614a0913b522ee40c7cc2c	Maestro	42.5327742084011433	-83.0124993466000944
12849	2020-02-19 23:33:20	2020-02-19	Ethelyn Christiansen	ethelyn.christiansen@geemail.com	Phoenix	Arizona	3022319851984643	816a7f2a5c5e4b881e47d63e2c81cc1c	JCB 15 digit	33.4866958830904267	-112.127211208261926
12850	2020-02-20 00:02:38	2020-02-20	Graves Cummerata	graves.cummerata@woohoo.com	Raleigh	North Carolina	4940906547786914	4f5e8d4ba094fccbc2644ef3c1eb8147	VISA 16 digit	35.7961177790671528	-78.633022517006097
12851	2020-02-20 00:11:58	2020-02-20	Dr. Fleeta Beatty	dr.fleeta.beatty@geemail.com	San Francisco	California	676165122212197	65938760de0354b06ed6918d32ec3dbd	Mastercard	37.7714661967852976	-122.446588223207698
12852	2020-02-20 00:44:54	2020-02-20	Aleen Quitzon	aleen.quitzon@geemail.com	Anaheim	California	6011661500627809477	3a69ae02f85a9802078e111b7956957c	Discover	33.9413212243299895	-117.714122766230616
12853	2020-02-20 00:49:37	2020-02-20	Freddie Balistreri	freddie.balistreri@warmmail.com	West Covina	California	869991537451925789	321a6319fa69415efaa0870e33caece6	Maestro	34.1518276185370979	-117.895889118367421
12854	2020-02-20 01:18:17	2020-02-20	Ms. Adrianna Mann MD	ms.adrianna.mann.md@woohoo.com	Portland	Oregon	4322274953618909	0c5c8a21fbbf3e058e1c2aa6dd0c05f5	Voyager	45.4684950317610017	-122.564770045550546
12855	2020-02-20 01:38:58	2020-02-20	Alonzo Weimann	alonzo.weimann@warmmail.com	Berkeley	California	3046274313078441	1ce70c388d3a80c66f78f19d88ff41cd	Mastercard	37.8798820024914562	-122.256081174295176
12856	2020-02-20 01:42:57	2020-02-20	Orvis Keebler	orvis.keebler@woohoo.com	San Francisco	California	3031836820278238	c4f469a40ddf5f1079c7efdaa3f0878c	Voyager	37.8010962779184396	-122.387622516542734
12857	2020-02-20 01:48:16	2020-02-20	Miss Caitlin Gusikowski	miss.caitlin.gusikowski@geemail.com	Washington	District of Columbia	6011267536203959789	b3ddf1e68b7349635d83c00bdf2ab2b9	Voyager	38.827222832039368	-77.0801531979095245
12858	2020-02-20 02:01:33	2020-02-20	Judi Corwin-Bogan	judi.corwin.bogan@woohoo.com	San Francisco	California	869923196424477882	906b465b383306f1e107f1d18d59d8db	VISA 16 digit	37.7711144910824146	-122.412533588083278
12859	2020-02-20 02:12:21	2020-02-20	Villa Medhurst DVM	villa.medhurst.dvm@woohoo.com	Augusta	Georgia	6011215515562419307	dcf1ba7fe24122e57d786d7a96e71e53	Discover	33.4112099338527742	-82.0853785225950219
12860	2020-02-20 02:13:43	2020-02-20	Mattye Mueller-Watsica	mattye.mueller.watsica@geemail.com	Los Angeles	California	55376779216032024	536a6c90b80847d3e92b5ecfcff1652b	JCB 16 digit	34.0949306288134295	-118.443242686660213
12861	2020-02-20 02:46:22	2020-02-20	Cedrick Murazik	cedrick.murazik@geemail.com	San Diego	California	210099683251355231	ed65559d86685ebb6969fff28c95c5ca	VISA 16 digit	32.8085126740459359	-117.121827016295867
12862	2020-02-20 03:06:42	2020-02-20	Mikal Bergstrom-Harvey	mikal.bergstrom.harvey@geemail.com	Corpus Christi	Texas	3713733898191458	a579ba02f679b2a619653b66c30b325f	Discover	27.8484245814319706	-97.1066394551020124
12863	2020-02-20 03:16:35	2020-02-20	Miss Sasha Goldner	miss.sasha.goldner@warmmail.com	San Jose	California	3435840920221882	bd109a033379d5f319068364899946dc	Voyager	37.2200354925178019	-121.8106256030254
12864	2020-02-20 03:22:54	2020-02-20	Goldie Greenfelder	goldie.greenfelder@warmmail.com	Spokane	Washington	4289756708376461	5f8379fe632996e9c3936de56a31722a	VISA 16 digit	47.6602179663494212	-117.365060148564353
12865	2020-02-20 03:38:23	2020-02-20	Dr. Blanchard Nienow	dr.blanchard.nienow@geemail.com	Lakewood	New Jersey	869982639113505396	4315d3449e2f2c6a18a574f590b38560	VISA 16 digit	40.1515024247862442	-74.1670347325313912
12866	2020-02-20 03:47:29	2020-02-20	Daisey Rippin	daisey.rippin@warmmail.com	Fort Worth	Texas	3042716542010490	d616f402fed1062843cb42a7c9fcb608	Voyager	32.7032972085811195	-97.3235626980483488
12867	2020-02-20 04:08:18	2020-02-20	Lennie Marquardt	lennie.marquardt@geemail.com	New York	New York	3158097652259239483	e765b3a2454e406d6e8d1ba9047248bb	JCB 16 digit	40.7426471331380284	-73.950046888681868
12868	2020-02-20 04:12:03	2020-02-20	Mira Carroll-Larkin	mira.carroll.larkin@geemail.com	Houston	Texas	4067887358306900	35080931f277c0ee8006bb6bb0397ad0	JCB 16 digit	29.8740271413777023	-95.3786698780968862
12869	2020-02-20 04:43:14	2020-02-20	Altie Ryan	altie.ryan@geemail.com	Charlotte	North Carolina	3528360160470390630	2ce1706d1d6388c2bc7e27f815befcad	Discover	35.2285828856538998	-80.7920762452241092
12870	2020-02-20 04:43:54	2020-02-20	Scott West-Ondricka	scott.west.ondricka@geemail.com	Baltimore	Maryland	869937649216338310	6e98d3968392b1b3af8509bdd2636eb3	Maestro	39.2085410664323675	-76.5232164926379994
12871	2020-02-20 04:49:54	2020-02-20	Doyle Koelpin	doyle.koelpin@geemail.com	San Francisco	California	53444623137421494	229c7331d189c9fda0eff0d5c2f8ce56	JCB 16 digit	37.7634472411076771	-122.417068603968445
12872	2020-02-20 05:02:06	2020-02-20	Mr. Orin Blanda	mr.orin.blanda@woohoo.com	San Francisco	California	4765491156184356	3ff82ad131f225404bc8e1d6d9ccbb9e	VISA 16 digit	37.7623095291024597	-122.456212594627715
12873	2020-02-20 05:12:36	2020-02-20	Kenny Gleichner V	kenny.gleichner.v@geemail.com	Berkeley	California	3701602469314175	661129d81555c32cb49774f695906867	Discover	37.826835490610101	-122.289867542361065
12874	2020-02-20 05:44:40	2020-02-20	Ms. Laquita Purdy	ms.laquita.purdy@warmmail.com	San Jose	California	675983922130832	efbc8b231a691cb34043f7f6530d793d	JCB 16 digit	37.3087292127598076	-121.759179479930182
12875	2020-02-20 06:03:44	2020-02-20	Dedric Wolf	dedric.wolf@geemail.com	Kansas City	Missouri	4950605892130044	0f60fd148ddb27b441e547d0604c8221	Mastercard	39.2220938979018499	-94.5629766148738611
12876	2020-02-20 06:55:59	2020-02-20	Kaye Mayert	kaye.mayert@geemail.com	Montgomery	Alabama	3795318129470326	238cae51d58c7030e5cb3158ec592d1a	Maestro	32.3598579348929221	-86.2454726324103689
12877	2020-02-20 07:09:20	2020-02-20	Miss Lyndsey Koss	miss.lyndsey.koss@geemail.com	San Francisco	California	6011222627805701127	247a0a1adde84e6d0caa1829c93f9149	JCB 15 digit	37.8072063542279579	-122.426579020284493
12878	2020-02-20 07:23:31	2020-02-20	Dr. Conway Lesch	dr.conway.lesch@geemail.com	Las Cruces	New Mexico	4865681080032932	2dc75d9f33baebf647aeaf510edfafd9	American Express	32.3546054459676142	-106.857325375324862
12879	2020-02-20 08:01:27	2020-02-20	Sarai Simonis	sarai.simonis@woohoo.com	Fremont	California	4863835408783	9b82165df83b20cf3843fa8f6d46388d	VISA 16 digit	37.4958026132248392	-121.946439894939587
12880	2020-02-20 08:32:50	2020-02-20	Mrs. Libby Borer DDS	mrs.libby.borer.dds@woohoo.com	Columbus	Georgia	589382482517388	a1cc2c9e675dc03860ec1be249ac25c3	Discover	32.4303224382035395	-84.9583627071861116
12881	2020-02-20 08:35:48	2020-02-20	Mr. Darrius Schowalter Jr.	mr.darrius.schowalter.jr.@geemail.com	Phoenix	Arizona	589359537862209	893b7f7b4bc9b090a0647033c6f20814	Voyager	33.5269446531243673	-112.100189605767284
12882	2020-02-20 09:57:57	2020-02-20	Dr. Niko Moore DDS	dr.niko.moore.dds@woohoo.com	Houston	Texas	54827781263518959	9a57d1d69eb3932d75ffb152d0510135	VISA 13 digit	29.7538522848937674	-95.4718956879820695
12883	2020-02-20 09:58:59	2020-02-20	Brendan Hilll IV	brendan.hilll.iv@geemail.com	San Francisco	California	210048867045755952	2cebfa3c64d712a3857209f23119a77a	VISA 16 digit	37.7565925755190221	-122.400816324826337
12884	2020-02-20 11:04:09	2020-02-20	Miriah Funk-Wolf	miriah.funk.wolf@warmmail.com	Henderson	Nevada	4614121565590	d2e5cb0255ded4c3fb00f7c67d6a4daa	Maestro	35.9807287683643438	-115.016295660582188
12885	2020-02-20 11:11:13	2020-02-20	Burnice Moore-Reichert	burnice.moore.reichert@warmmail.com	Jacksonville	Florida	4364277190112320	dee176556fbc04e99929eac43bd32802	American Express	30.2710396203730241	-81.6234667502422013
12886	2020-02-20 11:24:31	2020-02-20	Britany Parker-Breitenberg	britany.parker.breitenberg@woohoo.com	New York	New York	52513546286229051	cef9315c438ea3e86525d09f98621a42	JCB 15 digit	40.5940507695302344	-73.9201670683350329
12887	2020-02-20 11:40:15	2020-02-20	Trudy Gorczany	trudy.gorczany@geemail.com	Atlanta	Georgia	869946142127955652	3e6faa07c9edd0420c019b94d52ae5d4	American Express	33.8546040132917483	-84.4453915930863559
12888	2020-02-20 11:44:58	2020-02-20	Audrina Dooley DDS	audrina.dooley.dds@geemail.com	Berkeley	California	3528229733373535856	c342f179c3bb8a3bd618e2fa4486627d	JCB 16 digit	37.8924296533593008	-122.319688894569083
12889	2020-02-20 11:49:43	2020-02-20	Rafaela Cole	rafaela.cole@geemail.com	San Francisco	California	4500916508046	1bd614bf16da9ce0fafe31e7afdd5ee7	JCB 16 digit	37.7932800571433916	-122.41843702016881
12890	2020-02-20 11:55:16	2020-02-20	Dillion Auer	dillion.auer@geemail.com	San Francisco	California	869954606296696494	3056f96302c4c7ad6049b3abf31fcfb3	Mastercard	37.7570803637836434	-122.409350119550552
12891	2020-02-20 12:12:16	2020-02-20	Dr. Shamar Medhurst	dr.shamar.medhurst@geemail.com	Pearland	Texas	4176399539632	1152720e2fe885d4e351a8bc865dd97c	Mastercard	29.5132789602309487	-95.3137380726024475
12892	2020-02-20 12:21:39	2020-02-20	Zachary Senger III	zachary.senger.iii@geemail.com	Berkeley	California	3158610249036106206	e13bbddc5d516bd6c734133529da39c8	Discover	37.873957648311027	-122.243648317709315
12893	2020-02-20 12:24:20	2020-02-20	Ocie Yost	ocie.yost@warmmail.com	Atlanta	Georgia	4597334570224008	279f09dcbd5fe8e3a2be226a79e30989	VISA 16 digit	33.7985223123148089	-84.3505075854759667
12894	2020-02-20 12:40:54	2020-02-20	Hershell Flatley	hershell.flatley@geemail.com	West Covina	California	4163982171064	873fbdc487cb843ae5959d5394e8c870	American Express	34.0587920386452225	-117.996512205719569
12895	2020-02-20 12:51:41	2020-02-20	Braydon Bartell DDS	braydon.bartell.dds@geemail.com	New York	New York	3112520979537186179	ef35980d24d76ba6ad5d2b76e1fe342d	VISA 13 digit	40.6959863030109545	-73.9913100514456659
12896	2020-02-20 13:09:08	2020-02-20	Celestino Flatley	celestino.flatley@geemail.com	San Francisco	California	3528882598575850264	6e13f247436697bba7d93bd5d01c6549	Maestro	37.7412995588235276	-122.399386175699163
12897	2020-02-20 13:33:58	2020-02-20	Philip Strosin	philip.strosin@geemail.com	Pomona	California	3088960448562656883	5c216d1582c64e464b02ce834a4bec3d	Discover	34.148973596751695	-117.661745074388008
12898	2020-02-20 14:03:20	2020-02-20	Eleanora Zieme	eleanora.zieme@geemail.com	San Jose	California	4842748707646572	1ecefaba95e025639692579c72e63332	Discover	37.271190277143198	-121.846419279904666
12899	2020-02-20 14:05:16	2020-02-20	Treasure Skiles DVM	treasure.skiles.dvm@geemail.com	Jacksonville	Florida	3411617088025273	89abad93aabd26399b8fe5e1f2b59c33	Diners Club / Carte Blanche	30.3652507329411812	-81.7048348479982565
12900	2020-02-20 14:07:57	2020-02-20	Lorrie Leuschke	lorrie.leuschke@warmmail.com	Memphis	Tennessee	4395860718302995	0eb0f666ef1f2dd6d722fc0252d106ff	JCB 15 digit	35.101688740502297	-89.8777802695311578
12901	2020-02-20 14:17:40	2020-02-20	Mr. Pascal Luettgen V	mr.pascal.luettgen.v@geemail.com	Arvada	Colorado	6011237222906287417	40475838c1f4dcde3910970d0ae793e2	VISA 16 digit	39.8735310694377887	-105.215302436656501
12902	2020-02-20 14:39:27	2020-02-20	Barb Will	barb.will@woohoo.com	Austin	Texas	3420880060298016	11eb70c20d82276d32dbea236aad2db3	JCB 16 digit	30.2144300490278752	-97.8112554935511298
12903	2020-02-20 14:45:36	2020-02-20	Minna Fay	minna.fay@geemail.com	Lakeland	Florida	3029509339771140	f37a6614ed0d9ddd01041cdb27e2eb23	JCB 16 digit	28.1045387612488113	-81.9666559505626537
12904	2020-02-20 14:53:11	2020-02-20	Jeanine Schuppe	jeanine.schuppe@geemail.com	Woodbridge	New Jersey	3431282330927432	41a421e3c0f8b38ed28ee0a6a9eaf559	American Express	40.4815275900222318	-74.2226497539643191
12905	2020-02-20 15:22:55	2020-02-20	Sidney Kshlerin	sidney.kshlerin@geemail.com	San Francisco	California	3337623681553131347	3a69992e8b26fc5b569a8d3185a33228	JCB 16 digit	37.7662651139102721	-122.443976037820249
12906	2020-02-20 15:36:42	2020-02-20	Namon Berge	namon.berge@woohoo.com	Vancouver	Washington	3112826180756686715	c0dda9ae05e64c095e80537bf5d9a114	VISA 16 digit	45.6436602852378073	-122.640296298225223
12907	2020-02-20 16:39:17	2020-02-20	Saniyah Stanton-Ankunding	saniyah.stanton.ankunding@geemail.com	New Haven	Connecticut	4099254142070	6ca491e59e0a1a730d7fc334d7a2a935	VISA 16 digit	41.333518560276552	-72.8279351023025754
12908	2020-02-20 16:51:51	2020-02-20	Mrs. Simone Barrows	mrs.simone.barrows@woohoo.com	Seattle	Washington	630461045587104	1c8011bc7cc3ea96241e7f1dc1d86084	JCB 15 digit	47.6195927736274882	-122.359364259048917
12909	2020-02-20 17:01:47	2020-02-20	Danyel Schuppe	danyel.schuppe@geemail.com	Irvine	California	4464176794561412	a276d97e9de3fbd6ba18d8d5b1b659ce	VISA 16 digit	33.6991068388815975	-117.786998858676469
12910	2020-02-20 17:07:30	2020-02-20	Lovie Cole	lovie.cole@geemail.com	Bellevue	Washington	54485441639458322	d7fdaaa652f487c7abcf8f73720db1f1	Voyager	47.6247111736513702	-122.173505437193427
12911	2020-02-20 17:18:51	2020-02-20	Lexi Jenkins	lexi.jenkins@geemail.com	Jacksonville	Florida	4874900499672	6cdbfda3d98ec9996959c0a39c23d24b	JCB 15 digit	30.3882828251510873	-81.6975305705875172
12912	2020-02-20 17:27:43	2020-02-20	Janine Runte	janine.runte@geemail.com	San Francisco	California	3112872217296348944	1d0e651e2dc00d0e0b246b056d6f5be5	JCB 16 digit	37.7849201998010429	-122.427024270491231
12913	2020-02-20 17:39:55	2020-02-20	Stefanie Romaguera	stefanie.romaguera@geemail.com	San Diego	California	4179662490186	fffe09113dbe5de7a9f78702986fb0ca	Maestro	32.8457946905467679	-117.17136333285832
12914	2020-02-20 17:42:54	2020-02-20	Jude Ortiz	jude.ortiz@geemail.com	New York	New York	869916293433580373	484772dcdb3bc3678e5d6a3736ed470a	Diners Club / Carte Blanche	40.7524419766142927	-73.8770934932295233
12915	2020-02-20 17:55:19	2020-02-20	Olof Hyatt-Aufderhar	olof.hyatt.aufderhar@woohoo.com	Evansville	Indiana	869909296740536771	b9d85d20988d757ee0731c4a9ecd577b	VISA 13 digit	38.0157549047980439	-87.6244793018259145
12916	2020-02-20 17:56:11	2020-02-20	Marlys Koelpin MD	marlys.koelpin.md@warmmail.com	Augusta	Georgia	4596928994051144	8d0c3e29c2840a279011aba10d88d679	Voyager	33.4630942935328903	-82.0538604913108145
12917	2020-02-20 18:04:28	2020-02-20	Dr. Bird Wuckert	dr.bird.wuckert@geemail.com	San Francisco	California	3088834627970243186	1d74cbabdb57c9664efe23180f882517	VISA 13 digit	37.7955011687353135	-122.442760669842386
12918	2020-02-20 18:30:18	2020-02-20	Chelsea Emard DVM	chelsea.emard.dvm@geemail.com	Berkeley	California	4846223092554415	8e3dbe194aa32ea85b8871650c3fdf8b	JCB 16 digit	37.8239693788682061	-122.277382174304549
12919	2020-02-20 18:34:04	2020-02-20	Milford Koepp	milford.koepp@geemail.com	San Francisco	California	3112362955832629098	fcc741e47ecbb95b0b9930e97aa201f5	American Express	37.7679231954037391	-122.432713645485833
12920	2020-02-20 19:10:15	2020-02-20	Keon Schinner	keon.schinner@geemail.com	Fremont	California	3724751317566669	c03e6bc718ce3573b6227dc1e8e14542	Maestro	37.5402216753158768	-122.008546259299663
12921	2020-02-20 19:10:48	2020-02-20	Mr. Devonta Lynch	mr.devonta.lynch@geemail.com	Columbus	Ohio	4668446617595028	fd393af17a26fa8fa3293d3d311e06cb	American Express	39.9630814465738808	-82.9435223629467231
12922	2020-02-20 19:14:57	2020-02-20	Julia Hoppe	julia.hoppe@geemail.com	Chandler	Arizona	3112125861607086878	fe784b0317c409b1f56a26952484eb73	Mastercard	33.2988854046069065	-111.896390106564013
12923	2020-02-20 19:20:13	2020-02-20	Jahiem Hahn	jahiem.hahn@geemail.com	Oakland	California	6011292518318622394	8fcc30c3c0331bfe3220f0024b7d4b87	VISA 13 digit	37.8090349381509228	-122.301451807931997
12924	2020-02-20 19:30:41	2020-02-20	Clemence Bartell PhD	clemence.bartell.phd@geemail.com	Dayton	Ohio	3003059739223314	f6fddc6fc0f65eeba9ac9f93073e381d	Maestro	39.846339432501793	-84.2607534220166485
12925	2020-02-20 19:44:21	2020-02-20	Garrett Schuster	garrett.schuster@warmmail.com	Dallas	Texas	180066544554259687	b6d1f7099ae8c657c061b89c07b4739a	Diners Club / Carte Blanche	32.8577492997787886	-96.8212301914542905
12926	2020-02-20 19:54:12	2020-02-20	Ivory Johns	ivory.johns@geemail.com	Albuquerque	New Mexico	3044324310879291	ed3c203d47a57b882c941793dc7ef714	JCB 16 digit	35.0059065577708211	-106.728603624699275
12927	2020-02-20 20:05:21	2020-02-20	Marlen Torp	marlen.torp@woohoo.com	Los Angeles	California	210081763491602863	b21fb3c61a97caf9632f0228f0125983	VISA 16 digit	34.1081505116406802	-118.339642145763335
12928	2020-02-20 20:31:11	2020-02-20	Vassie O'Connell DDS	vassie.o'connell.dds@geemail.com	San Francisco	California	675948756702071	4d52270215c1ab62ab2623f97258f0de	VISA 16 digit	37.7881718889642784	-122.378409265058679
12929	2020-02-20 20:53:02	2020-02-20	Tambra Lakin	tambra.lakin@woohoo.com	Oakland	California	4635340008104120	74e0c5b35f16d3380f58799d6ce9c7e7	JCB 16 digit	37.7462864185257061	-122.271409144884828
12930	2020-02-20 20:54:10	2020-02-20	Leone O'Conner	leone.o'conner@geemail.com	Thornton	Colorado	6011746861550566180	d940ed6d9770976efff6afc6c1e3895d	Diners Club / Carte Blanche	39.8853515507519276	-105.007883385352045
12931	2020-02-20 21:11:15	2020-02-20	Dr. Jess Schinner	dr.jess.schinner@woohoo.com	San Francisco	California	3337647400152102563	a7c8bd31fee6da5345f3979f3abb82cb	Discover	37.8082059109068211	-122.413104692806655
12932	2020-02-20 21:19:17	2020-02-20	Tiffani Dietrich	tiffani.dietrich@geemail.com	Raleigh	North Carolina	3528209783231527441	b6c0479c14cb03242a139060f10f4ac9	Discover	35.7987554863229391	-78.6116555555194623
12933	2020-02-20 21:34:18	2020-02-20	Emory Boehm	emory.boehm@geemail.com	Mesa	Arizona	55452220286624132	72c594be9e34b537ec3f9607bcebdae3	Maestro	33.3873278639424598	-111.632077678328002
12934	2020-02-20 21:51:03	2020-02-20	Rico Herzog	rico.herzog@geemail.com	Oklahoma City	Oklahoma	3088936309835788831	9fee905c70c00a478be489406c972da9	American Express	35.5078317535486079	-97.4468763479392948
12935	2020-02-20 22:05:46	2020-02-20	Robin Frami	robin.frami@geemail.com	Las Cruces	New Mexico	4221240375560	a50108aebadd3a44bbb7409e66513d39	VISA 16 digit	32.2746586923055361	-106.886321643798425
12936	2020-02-20 22:45:25	2020-02-20	Alena Hackett	alena.hackett@geemail.com	Jacksonville	Florida	869908270461762313	1981a9c5d0a1b19fe34f0f598ebd10d9	Diners Club / Carte Blanche	30.3028821616485722	-81.6992435810234525
12937	2020-02-20 22:59:42	2020-02-20	Jeremey Pouros	jeremey.pouros@woohoo.com	Boise	Idaho	630413709709078	a4e9e6f253193a41496a354e3018c2dd	American Express	43.6307875047575706	-116.170529430891207
12938	2020-02-20 23:10:01	2020-02-20	Dr. Leamon Bednar DVM	dr.leamon.bednar.dvm@woohoo.com	Mesa	Arizona	869951082350276008	c6a08dc5c2157156c0ef31b518cd5c8d	VISA 13 digit	33.4421064021211123	-111.631071352341763
12939	2020-02-20 23:35:45	2020-02-20	Lanie Zieme	lanie.zieme@warmmail.com	Los Angeles	California	869940741842924897	e7ed1e9932e98af11d1a6b8639d8a9d9	VISA 13 digit	33.9311174888495302	-118.323373019508267
12940	2020-02-21 00:08:10	2020-02-21	Jaidyn Toy-Yundt	jaidyn.toy.yundt@geemail.com	Syracuse	New York	3454432725266837	34281f6c2be1ca46d5b6eb09a29b1b95	VISA 16 digit	43.1145778751317366	-76.1024808411732323
12941	2020-02-21 00:08:52	2020-02-21	Bradyn Gerlach	bradyn.gerlach@woohoo.com	Cedar Rapids	Iowa	3010222556595981	7b54b0e8fe2b85d33a63ab71e5b04ccf	JCB 16 digit	41.9872144382521526	-91.7290347205076415
12942	2020-02-21 00:26:49	2020-02-21	Mr. Enrique Johnston	mr.enrique.johnston@geemail.com	Lexington	Kentucky	3002760865207614	eb0486d801c1ab15f41e40ee95521898	Diners Club / Carte Blanche	37.9972363987348984	-84.494027681545532
12943	2020-02-21 00:39:59	2020-02-21	Miss Jailyn Bednar DVM	miss.jailyn.bednar.dvm@geemail.com	Berkeley	California	676393639742795	bacae96eafebd1df94b09aeb9dcc8331	JCB 15 digit	37.8663907166154559	-122.279803122694616
12944	2020-02-21 01:20:32	2020-02-21	Lynn Ledner	lynn.ledner@geemail.com	Kenosha	Wisconsin	3112176030690878421	91964bea0f919f30264771a92cf045d0	VISA 16 digit	42.5336242649544047	-87.8136430316831991
12945	2020-02-21 01:23:10	2020-02-21	Miss Harlow Bauch MD	miss.harlow.bauch.md@geemail.com	Springfield	Massachusetts	3018487465469550	a45dcce4e7bce802abc501f5579885eb	American Express	42.0877747595049385	-72.5850055786408603
12946	2020-02-21 01:27:47	2020-02-21	Dee Jones	dee.jones@warmmail.com	Honolulu	Hawaii	4261190824767944	13bc5701bf1e033775786fc5bce73e58	JCB 16 digit	21.3447620171804004	-157.900236928670097
12947	2020-02-21 01:37:19	2020-02-21	Ms. Shelli Rodriguez	ms.shelli.rodriguez@geemail.com	Dallas	Texas	54528273284582877	02f816e2df62c460f18251357706020a	Diners Club / Carte Blanche	32.7614233868468574	-96.7074414734691317
12948	2020-02-21 02:09:18	2020-02-21	Risa Smitham	risa.smitham@geemail.com	Philadelphia	Pennsylvania	869990742597497476	622243840e6da25f4faef329c8421e7f	Diners Club / Carte Blanche	40.0143057096708574	-75.0940807607390042
12949	2020-02-21 02:18:29	2020-02-21	Redmond Botsford-Kuhic	redmond.botsford.kuhic@woohoo.com	New York	New York	4869338674309244	48869b8952a8493028d0465150c92ec4	JCB 16 digit	40.738576666660606	-73.9194434542104517
12950	2020-02-21 02:28:16	2020-02-21	Miss Serina Connelly DVM	miss.serina.connelly.dvm@woohoo.com	San Francisco	California	51889942088485049	0ab09518cca8209887d25506256c7cd8	Diners Club / Carte Blanche	37.7694044572874503	-122.417967911123426
12951	2020-02-21 02:44:32	2020-02-21	Ole Wolff	ole.wolff@geemail.com	San Francisco	California	869913579918757269	8ace05865260cad3de8480cfff116401	VISA 16 digit	37.7464355756081105	-122.467967328153037
12952	2020-02-21 02:55:52	2020-02-21	Alfonso Rosenbaum	alfonso.rosenbaum@geemail.com	Dallas	Texas	869989893772216380	261714b9792f7e46fdc20c2f6bc04b04	JCB 16 digit	32.8819829293798662	-96.7973943131007246
12953	2020-02-21 03:27:37	2020-02-21	Khalid Bartell	khalid.bartell@geemail.com	San Francisco	California	676276139647838	2734ca4d376ca9a9333f176c1cb391f0	JCB 16 digit	37.7293852643240655	-122.443791756115928
12954	2020-02-21 04:27:16	2020-02-21	Auther Runte	auther.runte@warmmail.com	Grand Prairie	Texas	180088523983505187	2f36420addaca3248215d44fe6c6c2af	VISA 16 digit	32.7452084227517233	-97.0883364130150568
12955	2020-02-21 05:07:24	2020-02-21	Harland Harris-Marks	harland.harris.marks@geemail.com	Houston	Texas	3400069200700123	ffcfdd967daa56a18f5ffdb7c70e53b1	Voyager	29.7428559326644972	-95.3818827493131209
12956	2020-02-21 05:10:11	2020-02-21	Brandy Botsford	brandy.botsford@geemail.com	Akron	Ohio	6011472809944439804	774e9643fddb8b7227aff14b0c6de3b5	Mastercard	41.0393078421540594	-81.4411958107572076
12957	2020-02-21 05:19:10	2020-02-21	Claudia Osinski MD	claudia.osinski.md@woohoo.com	San Francisco	California	210017604211825344	156836edaf60cca99a9435e2e6cc09a6	JCB 16 digit	37.7326772901975289	-122.418123921652722
12958	2020-02-21 05:38:22	2020-02-21	Isidore Eichmann-Schaden	isidore.eichmann.schaden@geemail.com	San Francisco	California	53307395641492644	394a88d649bcd3c27b7b632072073a98	Discover	37.7644812046174749	-122.464245296280268
12959	2020-02-21 05:58:43	2020-02-21	Hardin Cremin	hardin.cremin@geemail.com	Rochester	New York	6011558752284601020	8e6c01558f2d22d7c1a39fcca75f79c6	VISA 16 digit	43.2095233247127339	-77.6080922234110488
12960	2020-02-21 06:13:30	2020-02-21	Mr. Jeffie Russel I	mr.jeffie.russel.i@woohoo.com	Colorado Springs	Colorado	3058414807747725	66b964f754c4b4f2506b6bdbc9cd06ea	VISA 16 digit	38.8290584433872255	-104.72389846669212
12961	2020-02-21 06:17:07	2020-02-21	Mrs. Tori Kilback DDS	mrs.tori.kilback.dds@geemail.com	Paterson	New Jersey	6011910262441576589	00776ad6842a07dd50c78551b2a30552	Discover	40.9227131266102191	-74.2066837603665874
12962	2020-02-21 06:19:15	2020-02-21	Press Wiza	press.wiza@geemail.com	San Francisco	California	4291999998839	18d28add7f5a6a2f3c224fcfc395a7ff	American Express	37.8006798106471749	-122.437010897610591
12963	2020-02-21 06:25:01	2020-02-21	Dr. Jaslyn Rowe	dr.jaslyn.rowe@woohoo.com	Berkeley	California	501869737911490	242d4d4df67a84b494f6551bd46f86c5	Discover	37.8981998736189212	-122.246723715468775
12964	2020-02-21 06:55:23	2020-02-21	Evertt Smith	evertt.smith@woohoo.com	Fayetteville	North Carolina	3052617893465509	91ae3eeafd280bd9b524d64d05561c75	JCB 16 digit	35.0480575257234293	-78.9393900095615493
12965	2020-02-21 07:18:36	2020-02-21	Rona Labadie	rona.labadie@geemail.com	San Francisco	California	869981048602945199	0743d47861fb423881c151e9405ef331	JCB 16 digit	37.7698262444783595	-122.419329954674922
12966	2020-02-21 07:29:09	2020-02-21	Martez Hand	martez.hand@geemail.com	Clarksville	Tennessee	4707396564606067	39374306eeb5e503389be26fdbe987c7	Diners Club / Carte Blanche	36.4860751269511923	-87.2715046134263304
12967	2020-02-21 07:56:05	2020-02-21	Madisen O'Hara	madisen.o'hara@geemail.com	Chicago	Illinois	180059908876701750	72283179775751c67eb6be83ac3646e8	Diners Club / Carte Blanche	41.8182406075134878	-87.6191827551025852
12968	2020-02-21 07:58:58	2020-02-21	Denver Schneider PhD	denver.schneider.phd@geemail.com	Tulsa	Oklahoma	3787717928913735	5e80268ef55cfa6cdd496e8bb37f004e	VISA 16 digit	36.0646037361487686	-95.88382468465268
12969	2020-02-21 08:00:48	2020-02-21	Cassie Ferry PhD	cassie.ferry.phd@geemail.com	Carrollton	Texas	3112970110582463082	51f9fd1d7158184618dc6f229c50d9e5	VISA 16 digit	32.9260454907469438	-96.904502071612697
12970	2020-02-21 08:05:30	2020-02-21	Pearle Muller	pearle.muller@geemail.com	San Francisco	California	4937051398439	b85246fdc55da45027e792f72a7b7833	JCB 16 digit	37.7548744069805124	-122.433543243937791
12971	2020-02-21 08:19:22	2020-02-21	Mykel Mertz	mykel.mertz@geemail.com	Gainesville	Florida	3791446236873563	fe850761c533fbe58a8644af9a6637d2	Diners Club / Carte Blanche	29.6062356100708222	-82.2645955755248792
12972	2020-02-21 08:33:42	2020-02-21	Roseanna Champlin-Erdman	roseanna.champlin.erdman@geemail.com	El Paso	Texas	3088101408032782040	32b957d5efee52b0ded45163388f4e56	Voyager	31.927885409334305	-106.337317362705249
12973	2020-02-21 08:33:44	2020-02-21	Burnice Jacobi	burnice.jacobi@geemail.com	Louisville	Kentucky	3038910820884254	1fd85fd5c1e1faa8f853f2eb2e3e05f0	Voyager	38.08428639773242	-85.5994858885254786
12974	2020-02-21 08:55:23	2020-02-21	Steward Weimann-Kertzmann	steward.weimann.kertzmann@woohoo.com	Jacksonville	Florida	869943787946289569	172946fcacec5f2a839150128812ac9f	Discover	30.2963808998517692	-81.7033434512171937
12975	2020-02-21 09:02:48	2020-02-21	Dossie Hirthe	dossie.hirthe@geemail.com	New York	New York	4266570320731871	b6a4804502430ce851c9d2b2551a6780	Voyager	40.625999212520199	-73.9852235678013415
12976	2020-02-21 09:15:51	2020-02-21	Arnav Lemke	arnav.lemke@woohoo.com	Los Angeles	California	6011739541895014281	2947d3fafe17e15679c37b4ea06a6408	VISA 16 digit	34.1181677116412629	-118.447305805654452
12977	2020-02-21 09:40:35	2020-02-21	Primus Lowe	primus.lowe@warmmail.com	Las Vegas	Nevada	3401942045233501	869d53d184cc4d952f1035b6cd7d4118	Voyager	36.324144623811172	-115.179214247336972
12978	2020-02-21 09:59:21	2020-02-21	Wava Boyle	wava.boyle@woohoo.com	Las Cruces	New Mexico	3158522876555779471	c3a66a2091adfac0277e76a883da093c	Maestro	32.3930175871621842	-106.695249373524263
12979	2020-02-21 10:02:29	2020-02-21	Burrel Larkin	burrel.larkin@geemail.com	New York	New York	180006249775735753	eb49c00f0b90827c356220adc525b471	American Express	40.6358258092999449	-74.0055194595724259
12980	2020-02-21 10:03:05	2020-02-21	Dr. Caiden Abbott	dr.caiden.abbott@geemail.com	Hialeah	Florida	6011478574645752996	2f2fa16cf14034311c788093c83dbc04	Mastercard	25.8695475619729613	-80.3423690876360865
12981	2020-02-21 10:50:18	2020-02-21	Felton Haag	felton.haag@geemail.com	San Diego	California	54554062885012518	612b9ec6379b84ee1803c4c909fc60bb	Mastercard	32.8792133922290049	-117.04577363588848
12982	2020-02-21 11:06:25	2020-02-21	Mrs. Leatrice Heaney	mrs.leatrice.heaney@geemail.com	San Francisco	California	4191656828917	f235cc94cc392f4c18f561ac9fb8b338	Voyager	37.7630879631656029	-122.427556939352698
12983	2020-02-21 11:13:34	2020-02-21	Agnes Hagenes	agnes.hagenes@geemail.com	Los Angeles	California	55529487095956828	860cfaee3a981799c90ac54b90f1ebf5	Maestro	34.046223294442143	-118.376917231920359
12984	2020-02-21 11:20:05	2020-02-21	Julious Runolfsson	julious.runolfsson@geemail.com	Rancho Cucamonga	California	4287095455875025	1b1d29ad0efab6e432aae8be459ea5bf	VISA 16 digit	34.16045188247152	-117.559516937519234
12985	2020-02-21 11:31:57	2020-02-21	Mr. Ricci Kuvalis Jr.	mr.ricci.kuvalis.jr.@geemail.com	Winston–Salem	North Carolina	210035269013571880	80f912c1e8c11f584276c854c9ed1a18	JCB 15 digit	36.1034527259644094	-80.2875212453901668
12986	2020-02-21 11:46:10	2020-02-21	Tessie Durgan	tessie.durgan@geemail.com	Albuquerque	New Mexico	3757976123874979	072841c6a60200b6ac6c0b9ae035aa41	JCB 16 digit	35.035774291925506	-106.655357137934871
12987	2020-02-21 12:14:30	2020-02-21	Mr. Silvio Koss	mr.silvio.koss@geemail.com	Chattanooga	Tennessee	210010692347182414	6d51bfba675404d2323aa7808746d652	American Express	35.1146892833840099	-85.1578225951936076
12988	2020-02-21 12:23:59	2020-02-21	Luster Kuhlman PhD	luster.kuhlman.phd@woohoo.com	Mesquite	Texas	54599863742580275	a25df821ed6d310a2d2a9bea641561e5	VISA 13 digit	32.6882000424709176	-96.5798433917306482
12989	2020-02-21 12:27:44	2020-02-21	Westley Corwin DDS	westley.corwin.dds@geemail.com	Cincinnati	Ohio	3337338656143166637	276fc1f570ad501b5b3660cc2398931f	JCB 15 digit	39.1988665302515003	-84.5410299435529851
12990	2020-02-21 12:35:28	2020-02-21	Janay Fahey	janay.fahey@geemail.com	Oakland	California	3528741433355976967	cda58e786d3458ecc36557c610ea80d4	Discover	37.8042974017299969	-122.290815305844163
12991	2020-02-21 12:52:34	2020-02-21	Viola Koepp	viola.koepp@geemail.com	Woodbridge	New Jersey	4967060671126147	a4635f794490a0c48566867b1d55ee67	VISA 16 digit	40.6577635454170405	-74.2600676456324749
12992	2020-02-21 12:53:57	2020-02-21	Maybelle Champlin	maybelle.champlin@geemail.com	Cincinnati	Ohio	210051908237669074	07bab23fb97b41d8925e2da6b0759b56	JCB 15 digit	39.1258283690780431	-84.4379781644597642
12993	2020-02-21 12:56:05	2020-02-21	Gale Grimes MD	gale.grimes.md@geemail.com	Raleigh	North Carolina	210064549984142447	6e056e849d350883cdc6ee131f473e8e	JCB 16 digit	35.8127292344946397	-78.6027348532743844
12994	2020-02-21 12:57:18	2020-02-21	Roseanne Kautzer	roseanne.kautzer@warmmail.com	New Haven	Connecticut	4857036503331561	2395489484cd96a41ee30043d835eb9f	American Express	41.2690860370166632	-72.9393777185119632
12995	2020-02-21 13:01:33	2020-02-21	Herb Carroll	herb.carroll@geemail.com	Reno	Nevada	060447079411766	c10aa4489f2e94ef01ff2e4c0df53c01	VISA 16 digit	39.4714822386469706	-119.80717300853469
12996	2020-02-21 13:47:23	2020-02-21	Friend Fay DVM	friend.fay.dvm@geemail.com	Hialeah	Florida	4767236479501	067041acf5491c52f759f71ad330ba20	VISA 16 digit	25.8320600065380361	-80.3100212350390734
12997	2020-02-21 13:54:31	2020-02-21	Lida Kohler	lida.kohler@woohoo.com	Corona	California	4944718790848176	bd4b12d17d302260e4ea3bf86e38ccf0	Maestro	33.8227088669203226	-117.640972356379038
12998	2020-02-21 14:08:20	2020-02-21	Ashley Rohan	ashley.rohan@woohoo.com	Modesto	California	3112106668835888857	5d7dda5dd14dd2a27c30fe835d4dabf7	VISA 16 digit	37.6644311353564305	-121.073090671489012
12999	2020-02-21 14:11:54	2020-02-21	Don Ullrich	don.ullrich@warmmail.com	Mesa	Arizona	4201956513448	41364c7cb7f834f223f80f6fa121175d	VISA 13 digit	33.3537503406550684	-111.719587254093582
13000	2020-02-21 14:17:51	2020-02-21	Chastity Parisian	chastity.parisian@geemail.com	Grand Rapids	Michigan	869971676160141801	32cb8dbfb32f580021ecc688d612a13e	American Express	42.9950581607211362	-85.6163832928188242
13001	2020-02-21 14:33:14	2020-02-21	Dr. Chad Harris	dr.chad.harris@geemail.com	Denver	Colorado	869962637448790935	8e581c6ff2399acc04de5d90cd70b9b5	Diners Club / Carte Blanche	39.6937840599153162	-104.919389934070779
13002	2020-02-21 14:58:23	2020-02-21	Damian Kessler	damian.kessler@geemail.com	Raleigh	North Carolina	3038345743799646	d3277918db86166111ebde0618973244	JCB 16 digit	35.8034836550842925	-78.6925946847938036
13003	2020-02-21 15:15:00	2020-02-21	Fuller Dickinson-Oberbrunner	fuller.dickinson.oberbrunner@geemail.com	San Francisco	California	869934204911593083	b7588572dc63bf5f81389d0f31ae7629	VISA 16 digit	37.7873377373324999	-122.418299950799181
13004	2020-02-21 15:16:55	2020-02-21	Augustina Bayer	augustina.bayer@geemail.com	Dallas	Texas	4493351432539212	3ceea9838263ac7004ac7bd4aecd7236	Discover	32.6971577693048872	-96.7275799313057121
13005	2020-02-21 15:17:04	2020-02-21	Dr. Hermann Prosacco	dr.hermann.prosacco@woohoo.com	Milwaukee	Wisconsin	4977473110368	e86cb0426e52f41378283a3c5e561b7a	JCB 16 digit	43.1176066217098395	-87.9422305079277606
13006	2020-02-21 15:20:44	2020-02-21	Dr. Lawrence Roberts	dr.lawrence.roberts@geemail.com	New York	New York	3462504732158429	19c41b5a013fc207b3e1d33c7abdcac0	Diners Club / Carte Blanche	40.6251101033054312	-73.9705884144071462
13007	2020-02-21 15:20:57	2020-02-21	Kyson Kunde V	kyson.kunde.v@geemail.com	San Francisco	California	55275077407163431	9b188d61662789596200d7470c2c5415	JCB 16 digit	37.7758386365887873	-122.405482087719761
13008	2020-02-21 15:31:59	2020-02-21	Mr. Paris Boehm	mr.paris.boehm@warmmail.com	Rochester	Minnesota	3088513431463828498	ba124db9b1fe5cb962913876682369fc	Maestro	43.9503497617688055	-92.4673634915266121
13009	2020-02-21 16:28:14	2020-02-21	Lannie Waters	lannie.waters@geemail.com	Los Angeles	California	4097027839926174	f1ac12fa18eea6c5506d69184e0be1df	Mastercard	34.022766465400899	-118.395433400058366
13010	2020-02-21 17:08:48	2020-02-21	Mrs. Oline Kuhn	mrs.oline.kuhn@woohoo.com	Riverside	California	3337690459742687869	dfcabf763dc90a84e3428a25e5638070	JCB 16 digit	33.8574623732309803	-117.489284610978132
13011	2020-02-21 17:37:30	2020-02-21	Ms. Alisson Mraz DVM	ms.alisson.mraz.dvm@warmmail.com	New York	New York	3528298679449698499	cf0728ef9683da47905a92fab59d7df3	JCB 16 digit	40.6183521851655058	-73.9586730589520158
13012	2020-02-21 18:10:39	2020-02-21	Dr. Masako Labadie DDS	dr.masako.labadie.dds@woohoo.com	Philadelphia	Pennsylvania	869975996839727772	47266aee43ffd074a1260d668fdf668d	VISA 13 digit	40.0192333612550044	-75.1207900154769419
13013	2020-02-21 18:40:06	2020-02-21	Della Champlin-Graham	della.champlin.graham@geemail.com	Berkeley	California	3158990534534273651	d3b589863bc99a78447627d6f0d8f972	JCB 16 digit	37.8877992396024155	-122.288849422591937
13014	2020-02-21 18:59:00	2020-02-21	Marshal Fay PhD	marshal.fay.phd@geemail.com	Scottsdale	Arizona	3337655282437088257	0ecb851ce2130406a29f0408eda784be	VISA 13 digit	33.726210783341152	-111.862662617393198
13015	2020-02-21 19:17:13	2020-02-21	Rock Breitenberg	rock.breitenberg@woohoo.com	Salem	Oregon	3112983407318000625	9e4b43097d50b77d32bcb08a2b69406a	Mastercard	44.9404440274730277	-122.974385206836089
13016	2020-02-21 19:17:44	2020-02-21	Cammie Upton	cammie.upton@geemail.com	Oklahoma City	Oklahoma	4331722062022	fe0dc937c4bc5f30cb86e431cc7f499a	VISA 16 digit	35.521858113762363	-97.4890320797346561
13017	2020-02-21 19:27:37	2020-02-21	Miss Shannen Ernser	miss.shannen.ernser@geemail.com	Columbus	Ohio	3027653443384648	980aea15f94ad3a40f565758d4d9ccf1	Mastercard	39.9632862971674641	-83.0585883575726314
13018	2020-02-21 19:44:07	2020-02-21	Mrs. Kiyoko Friesen DVM	mrs.kiyoko.friesen.dvm@warmmail.com	St. Louis	Missouri	3088905828164455578	bea30dbcaef77b32805541cde71a64cc	JCB 16 digit	38.6868313040740759	-90.1810123092498657
13019	2020-02-21 19:52:17	2020-02-21	Cecily Jast MD	cecily.jast.md@geemail.com	San Francisco	California	4758207234572795	528316bab88f5b490f890f3501d4c54b	Diners Club / Carte Blanche	37.8168184369844269	-122.423221193930303
13020	2020-02-21 20:11:47	2020-02-21	Anitra Leannon-Heaney	anitra.leannon.heaney@geemail.com	Fresno	California	4914545142170785	c2147a3d777d5401c90bfd6b411df519	VISA 16 digit	36.7944152256347223	-119.850447428749504
13021	2020-02-21 20:17:03	2020-02-21	Gabriel Grady	gabriel.grady@geemail.com	Fontana	California	6011609270700986601	3383d36d1e4b37414395a888ecc855cc	Discover	34.1215869289040583	-117.492048358758538
13022	2020-02-21 20:43:29	2020-02-21	Blanchard Paucek	blanchard.paucek@woohoo.com	San Francisco	California	3112189542218555724	6a41e2a8cfc6840359a5e2281c0223d1	JCB 15 digit	37.7614481328012914	-122.425760223806549
13023	2020-02-21 20:50:12	2020-02-21	Kaycee Jaskolski	kaycee.jaskolski@geemail.com	Meridian	Idaho	869955604080174710	8265b39d7219ab048afeb001765142b1	Diners Club / Carte Blanche	43.6943358813885538	-116.453717272443328
13024	2020-02-21 21:16:46	2020-02-21	Odalys Pagac	odalys.pagac@geemail.com	Phoenix	Arizona	869945781261128633	74978e8efeaefbbb1c0b1589ca5f3d40	VISA 13 digit	33.4791572469219574	-111.993266351048277
13025	2020-02-21 21:22:42	2020-02-21	Toya Block-Johnson	toya.block.johnson@geemail.com	San Francisco	California	4792067265126	ef54577ec0434f8e9489c9fe75537987	Diners Club / Carte Blanche	37.7675156751887826	-122.429241126342973
13026	2020-02-21 21:25:13	2020-02-21	Salvador Torphy-Brekke	salvador.torphy.brekke@woohoo.com	San Francisco	California	869956415931816840	61fafbe2f61417de459efafd211e7679	JCB 16 digit	37.7601350700012972	-122.446726887100425
13027	2020-02-21 21:27:27	2020-02-21	Sonja Kuhic	sonja.kuhic@geemail.com	El Paso	Texas	869976612708742904	a3229497e734813e215e0149236708c0	Maestro	31.8926954473663145	-106.375617625050253
13028	2020-02-21 22:51:33	2020-02-21	Guthrie Price V	guthrie.price.v@woohoo.com	San Francisco	California	869944411103575194	01abf6204a7e74c2bac1df7d0dafde7e	Maestro	37.8063687125357148	-122.420111253144626
13029	2020-02-21 22:51:34	2020-02-21	Durrell Hickle	durrell.hickle@geemail.com	San Francisco	California	3733719148536317	496329f3b9c6037e2b7b9529c52b2d51	JCB 16 digit	37.800738192119212	-122.438734624871529
13030	2020-02-21 22:57:12	2020-02-21	Esequiel Kling	esequiel.kling@woohoo.com	New York	New York	3028332653686146	15797f7f667972f0e663e84ab9cd1689	Mastercard	40.6206225578896678	-73.9994320053502861
13031	2020-02-22 00:18:00	2020-02-22	Georgeanna Frami-Koch	georgeanna.frami.koch@geemail.com	Round Rock	Texas	3112450741694366828	a78b15614eafb7ae4fc8e3bdd5296230	Voyager	30.6089345573585483	-97.6169126867167591
13032	2020-02-22 01:01:59	2020-02-22	Rollin Kub	rollin.kub@geemail.com	New York	New York	869929380192132861	59438e42ef4557361000dda0e2b7c441	JCB 15 digit	40.7433727705143411	-74.0208806304156752
13033	2020-02-22 01:23:20	2020-02-22	Mrs. Martina Boehm	mrs.martina.boehm@woohoo.com	San Francisco	California	4683007837134211	c8625f74824bb3e60df50300867d4794	VISA 13 digit	37.7936541452240959	-122.450879805416733
13034	2020-02-22 01:35:36	2020-02-22	Odalys O'Keefe	odalys.o'keefe@geemail.com	San Francisco	California	869955422903526002	fcc2d66a6d94d8a876fa188fd293f14a	Mastercard	37.7598797164893298	-122.44628261635242
13035	2020-02-22 01:38:50	2020-02-22	Mrs. Maddison Miller DDS	mrs.maddison.miller.dds@geemail.com	Los Angeles	California	210055143998461489	def3ef0360c8d62b426e48ff30cdad35	JCB 16 digit	33.9762873388227078	-118.500718232941992
13036	2020-02-22 01:40:26	2020-02-22	Esteban Watsica	esteban.watsica@geemail.com	Denver	Colorado	060488307073317	e706ced7478e85343abed254a61f59e0	Discover	39.8439007681380915	-104.889084193367893
13037	2020-02-22 01:41:33	2020-02-22	Chancey Schowalter-Satterfield	chancey.schowalter.satterfield@woohoo.com	Amarillo	Texas	4757484786697251	402238657526f3c528ca60ec6edae750	JCB 16 digit	35.1382107285015266	-101.883047650647171
13038	2020-02-22 01:49:07	2020-02-22	Russ Kozey	russ.kozey@geemail.com	College Station	Texas	3022085591061048	e2ada80e5b862241b5c90d1250786cf4	VISA 16 digit	30.5882602245591571	-96.382791324130821
13039	2020-02-22 02:05:49	2020-02-22	Merry Cole	merry.cole@geemail.com	Boston	Massachusetts	180023738412838573	3c2db3008f5aa034acf34b284d06db2d	JCB 16 digit	42.3625799836758503	-70.9834002742495471
13040	2020-02-22 02:17:13	2020-02-22	Dozier Stoltenberg	dozier.stoltenberg@geemail.com	New York	New York	3492641415883057	6914df2655a92474b3da4f07199d0f82	American Express	40.7193548734989008	-74.0265349866718054
13041	2020-02-22 02:22:15	2020-02-22	Alyssia Jerde	alyssia.jerde@warmmail.com	Winston–Salem	North Carolina	3337778486133329756	8e7a3644cf673b96383aa9cdfc271a41	VISA 16 digit	36.0790343906495679	-80.3529742713216706
13042	2020-02-22 02:31:53	2020-02-22	Aurilla Schulist	aurilla.schulist@geemail.com	Houston	Texas	210001527015983191	f07b6466f2bb6ae7356e67c455a868f0	American Express	29.7777565636284649	-95.3619305812768658
13043	2020-02-22 02:32:21	2020-02-22	Bailey Gerhold	bailey.gerhold@geemail.com	Rockford	Illinois	3733722526384839	d9347ce1103a76ba36eb7ce478e012b3	Mastercard	42.2940181585505641	-89.0017498070657211
13044	2020-02-22 02:44:58	2020-02-22	Miss Shay Strosin	miss.shay.strosin@geemail.com	Houston	Texas	676164274385737	8c2f6ae01fef3b586e1ec38727c15bca	VISA 16 digit	29.7641270257145152	-95.37610865119062
13045	2020-02-22 02:51:33	2020-02-22	Patrice Blanda	patrice.blanda@woohoo.com	Atlanta	Georgia	869923302799942274	742cd5c921ac444433d06d763210e356	JCB 16 digit	33.7874247555896687	-84.4841822321105838
13046	2020-02-22 02:58:25	2020-02-22	Alexandro Greenfelder-Franecki	alexandro.greenfelder.franecki@woohoo.com	Thousand Oaks	California	3438303754193286	a400dec7b24a82ddc9c1ba469c394e48	Mastercard	34.1051263339623816	-118.781627304703747
13047	2020-02-22 03:11:00	2020-02-22	Kody Jones	kody.jones@geemail.com	Buffalo	New York	3037555397477668	0dd0baafb5d6fc70aa3a35b5dc52d124	VISA 16 digit	42.9634900480229405	-78.9288327176522557
13048	2020-02-22 03:49:01	2020-02-22	Mrs. Alissa Zboncak PhD	mrs.alissa.zboncak.phd@woohoo.com	Winston–Salem	North Carolina	54440256018640694	e3ecb81abf39bc54a6e9e425a467e1a0	VISA 13 digit	36.0769262757383302	-80.2314680472612309
13049	2020-02-22 03:52:18	2020-02-22	Lyndia Corkery	lyndia.corkery@woohoo.com	San Francisco	California	3337152918295648595	cfe3434e26a742051521fd67087dfcd5	Discover	37.7856936724368282	-122.422619354732987
13050	2020-02-22 04:12:30	2020-02-22	Junie Christiansen-Wilkinson	junie.christiansen.wilkinson@geemail.com	San Francisco	California	676131209468094	4082f370c230591a71e57233f3ac6d9e	JCB 15 digit	37.743710278498952	-122.42235747160683
13051	2020-02-22 04:14:56	2020-02-22	Drusilla Walter	drusilla.walter@geemail.com	Kansas City	Missouri	4825818450813843	2ca57b63c64a7d9ed578171c3ece1b99	Maestro	39.1946658755488713	-94.4839518677201085
13052	2020-02-22 04:19:04	2020-02-22	Wilfred Powlowski I	wilfred.powlowski.i@woohoo.com	New York	New York	4640467574995	e9562b1cb5a7ca62d86efdaeae49aaf0	JCB 15 digit	40.7210990053825057	-73.9489860943879904
13053	2020-02-22 04:51:21	2020-02-22	Mr. Daxton Bayer III	mr.daxton.bayer.iii@woohoo.com	Columbus	Ohio	210029171753953831	db5a74b4efa0b241a10421d4ff352fed	Maestro	40.0496634762313235	-82.9032257702902058
13054	2020-02-22 04:56:46	2020-02-22	Myron Sporer V	myron.sporer.v@geemail.com	Oakland	California	210037157193237174	e7ba92ea6e35ef8a783df628927366e9	VISA 16 digit	37.7833115682446063	-122.268336376868263
13055	2020-02-22 05:17:29	2020-02-22	Maybelle Abbott-Ullrich	maybelle.abbott.ullrich@warmmail.com	San Francisco	California	6011317781667665742	ae27689d5623c5545f06ff294d7eaaaf	JCB 16 digit	37.7731234556297082	-122.443658023002442
13056	2020-02-22 05:32:09	2020-02-22	Leonia Aufderhar	leonia.aufderhar@geemail.com	Baltimore	Maryland	54925884283705175	fe65dc5902b55adc8748ed7cd839bfa1	American Express	39.2408021205570492	-76.6096976586636202
13057	2020-02-22 05:34:10	2020-02-22	Jonah Hirthe	jonah.hirthe@geemail.com	Oakland	California	210049345233310517	0ce4536760f3294fbfb2b61847a66f76	Maestro	37.7946501951439302	-122.257449966793217
13058	2020-02-22 05:40:00	2020-02-22	Dolph Mraz	dolph.mraz@geemail.com	Wichita	Kansas	3049283033136428	d9b070629742c80447d57d0ece100ae8	Diners Club / Carte Blanche	37.788828218669444	-97.2849553655102852
13059	2020-02-22 05:44:45	2020-02-22	Gaylord Fadel	gaylord.fadel@geemail.com	Moreno Valley	California	51648313786021852	fd47fd7ba3be13a855d3acefe12139e0	JCB 16 digit	33.9633003104470674	-117.298962313026934
13060	2020-02-22 05:47:23	2020-02-22	Marchello Pacocha	marchello.pacocha@geemail.com	Nashville	Tennessee	4943334580819	cc0c19c59bad804f6deb77f53f009baf	JCB 15 digit	36.1305716093286833	-86.8596014724951146
13061	2020-02-22 05:48:56	2020-02-22	Denver Donnelly	denver.donnelly@geemail.com	Austin	Texas	3096673589778090777	0b28963ecb1ed4924769a70895ca6a48	Maestro	30.3628127713814351	-97.7389881518442252
13062	2020-02-22 05:54:12	2020-02-22	Alvah Kunze MD	alvah.kunze.md@warmmail.com	San Francisco	California	3738890538869629	e9c18ddf85035ebd0a6502287896cc90	Voyager	37.7610564902547523	-122.425616422787741
13063	2020-02-22 05:54:29	2020-02-22	Alondra Braun DDS	alondra.braun.dds@woohoo.com	Albuquerque	New Mexico	4372575473122	c19a5d27b0ba7b0bf69f9121b4d49f26	Diners Club / Carte Blanche	35.0979631932586429	-106.674926392880835
13064	2020-02-22 06:01:28	2020-02-22	Ms. Odalys Cronin	ms.odalys.cronin@woohoo.com	Oklahoma City	Oklahoma	3028197848010225	71458db925244b27e6700cbdb5818817	Diners Club / Carte Blanche	35.4623270029112732	-97.5801441182278069
13065	2020-02-22 06:02:57	2020-02-22	Demarcus Gleichner	demarcus.gleichner@geemail.com	Phoenix	Arizona	3337760942482663674	33f92b276d84c8af54f8f191cfc484ce	Discover	33.5805628033287817	-112.097402600657574
13066	2020-02-22 06:13:09	2020-02-22	Tamera Gulgowski	tamera.gulgowski@woohoo.com	Norfolk	Virginia	3024389013405850	f854891c1601893e9831ecb5f45e519a	JCB 16 digit	37.0147409167625057	-76.2043796264570261
13067	2020-02-22 06:15:41	2020-02-22	Alexande Mills	alexande.mills@warmmail.com	New York	New York	4178634935187	fa7f6c2181a2303f89c20429c37ed47d	Mastercard	40.6819479956049435	-73.8696806543867979
13068	2020-02-22 06:21:38	2020-02-22	Marquita Wyman	marquita.wyman@geemail.com	San Francisco	California	3747937295575169	be5d1a868aee56a34abc65e4cfd879d2	JCB 15 digit	37.7644720062480204	-122.449037670246696
13111	2020-02-22 13:22:21	2020-02-22	Narcissus Kuphal	narcissus.kuphal@geemail.com	Chicago	Illinois	3528634242091245730	ae0a6bf85bd87c8f1bfc4470d5a7a2b7	JCB 15 digit	41.919177488267799	-87.588389991692452
13069	2020-02-22 06:22:47	2020-02-22	Mr. Armond Gerlach	mr.armond.gerlach@geemail.com	Manchester	New Hampshire	675982664499900	bb0c2333d68332a835efa1a176d41527	VISA 13 digit	42.9559408756509455	-71.520976783510676
13070	2020-02-22 06:31:21	2020-02-22	Jammie Graham-Kuhn	jammie.graham.kuhn@woohoo.com	Knoxville	Tennessee	55307257261079871	65cc9936c09c1cb538e8f0f768feb3c7	Mastercard	35.9905332790751018	-84.0389047133952261
13071	2020-02-22 07:06:39	2020-02-22	Lorena O'Hara	lorena.o'hara@geemail.com	San Antonio	Texas	3730122644298123	e7ad3c2075abb73df9cf6e88d0ed7952	Mastercard	29.4305916541792456	-98.5610370243735616
13072	2020-02-22 07:12:54	2020-02-22	Zenas Abernathy	zenas.abernathy@woohoo.com	Nashville	Tennessee	3797796219778880	dd52a8534fbe9d5d1a0b92eb88d5ad2f	American Express	36.1564817493438682	-86.7677088051009946
13073	2020-02-22 07:15:19	2020-02-22	Misael Herzog	misael.herzog@geemail.com	Dallas	Texas	4499986587909	fca83f0710dd5a0297b291651e275f58	VISA 16 digit	32.8783069650914541	-96.7655450634620991
13074	2020-02-22 07:24:37	2020-02-22	Olie Crooks-Rolfson	olie.crooks.rolfson@geemail.com	Jacksonville	Florida	3799748415183280	39b01aadf4d638760369ce956ba9e2f0	Discover	30.2635622145194567	-81.7493253225073317
13075	2020-02-22 07:44:12	2020-02-22	Linna Wisoky	linna.wisoky@geemail.com	Columbia	South Carolina	3050618332822245	b94f378e666d03b0f8546d58599fec30	Discover	33.9863883620858189	-80.9226804719325088
13076	2020-02-22 08:11:27	2020-02-22	Iva Greenholt	iva.greenholt@geemail.com	New York	New York	3096120968156203708	a50077e9c7ad007a938438799aa5dd96	JCB 16 digit	40.5696472441535434	-73.9688305424887602
13077	2020-02-22 08:27:43	2020-02-22	Cinda Mann-Thiel	cinda.mann.thiel@geemail.com	New York	New York	4925091606459866	3f0264ccfd1075788dbd7d2897e5c091	VISA 16 digit	40.5880638187974654	-73.8789414706535581
13078	2020-02-22 08:52:41	2020-02-22	Dr. Rolf Schaefer II	dr.rolf.schaefer.ii@geemail.com	Seattle	Washington	6011527037086799711	fdc0035aa24c1b8fe4801be271d9b058	Mastercard	47.6467556401547014	-122.318871135023983
13079	2020-02-22 08:58:24	2020-02-22	Norris Rath	norris.rath@geemail.com	Tucson	Arizona	4176356627966	1f3a02932ab0082e63c874ff73c7dacd	Voyager	32.1880756419193048	-110.907132629188141
13080	2020-02-22 09:08:29	2020-02-22	Zavier King	zavier.king@geemail.com	Downey	California	3088239023334252967	feb84d680eaae4278726e951ad91988d	Discover	34.0009684879116705	-118.125900332174822
13081	2020-02-22 09:16:59	2020-02-22	Tuan Bruen	tuan.bruen@geemail.com	New York	New York	3337653855469312349	6ac25ee41db4a5dd52db08e16ea549f7	Mastercard	40.6963497496899222	-73.8807252791140172
13082	2020-02-22 09:25:01	2020-02-22	Glynis Hermiston-Tromp	glynis.hermiston.tromp@geemail.com	Elizabeth	New Jersey	4281223214950121	2b4be3e18ae3f66cc6bd41bf642e6337	JCB 15 digit	40.7157393732700541	-74.1520897619836035
13083	2020-02-22 09:27:29	2020-02-22	Erle Kautzer-Effertz	erle.kautzer.effertz@geemail.com	Oakland	California	4126751299192	50f99d764ae912abc7fc314e482fd8c5	Discover	37.7940366549334001	-122.242958013266389
13084	2020-02-22 09:40:36	2020-02-22	Kaela Hermann	kaela.hermann@geemail.com	Los Angeles	California	53469812384388098	4724ad119db9b1c8045e2c9da8780c41	Mastercard	33.9541469738218922	-118.412611743807048
13085	2020-02-22 09:41:26	2020-02-22	Ancil Berge	ancil.berge@geemail.com	Berkeley	California	180081168847866966	c55308e806f6bd9287e49a82f2e69c18	VISA 13 digit	37.8531605124467632	-122.273854679966931
13086	2020-02-22 09:46:39	2020-02-22	Zander Treutel-Murazik	zander.treutel.murazik@geemail.com	Modesto	California	3337311084644323576	56654efcf803c11f50b1e74a91b725da	JCB 15 digit	37.7218341713305563	-121.05298258785345
13087	2020-02-22 10:01:44	2020-02-22	Vickey Kuphal	vickey.kuphal@geemail.com	Hillsboro	Oregon	180025225256878616	dcbbae4cfe3e18d1676ded6149761ee6	VISA 16 digit	45.476422600142655	-123.016259144448483
13088	2020-02-22 10:09:00	2020-02-22	Miss Janey Breitenberg MD	miss.janey.breitenberg.md@warmmail.com	Arlington	Texas	3096967649187087536	495c8c382e269645dc00fc5b6812428f	Maestro	32.7248561743430741	-97.1219047241404638
13089	2020-02-22 10:23:17	2020-02-22	Gibson Cartwright	gibson.cartwright@woohoo.com	Chicago	Illinois	3441770784952243	a9ae73e59993dcde9a994c1f0bef9513	Voyager	41.8187048915609765	-87.7406852340355528
13090	2020-02-22 10:31:24	2020-02-22	Ellwood Kemmer	ellwood.kemmer@warmmail.com	Escondido	California	3528712630762596040	7704a6093db5311f215bd5a6eb40801c	JCB 15 digit	33.0886676149204391	-117.08868559540808
13091	2020-02-22 10:43:57	2020-02-22	Estel Jones	estel.jones@geemail.com	Frisco	Texas	3528830255013627332	5fa3a174547c0978b50ea96d13e561c5	VISA 16 digit	33.1766881676387015	-96.7814551707100037
13092	2020-02-22 11:05:04	2020-02-22	Tracey Baumbach II	tracey.baumbach.ii@geemail.com	San Francisco	California	630426363037834	e6708bb7dfa4ccb13d6683204c2c624e	JCB 15 digit	37.7585752969722748	-122.45969150395392
13093	2020-02-22 11:21:03	2020-02-22	Deshaun Flatley-Reynolds	deshaun.flatley.reynolds@geemail.com	Tempe	Arizona	3015086585436359	c2e7215dec6063009779cc4d21902cbb	Maestro	33.316180245849857	-111.860146905717627
13094	2020-02-22 11:22:15	2020-02-22	Chalmer Grimes	chalmer.grimes@geemail.com	Reno	Nevada	3439116027436087	ca14d5ee6ff0213b157335d68d831e80	VISA 16 digit	39.634525662202762	-119.928143069676693
13095	2020-02-22 11:38:03	2020-02-22	Elick Donnelly	elick.donnelly@geemail.com	Phoenix	Arizona	51476360905977719	9e4da5c1a1c4aada265d2e2bf0562151	VISA 13 digit	33.5823991872768843	-112.081330292897675
13096	2020-02-22 11:40:54	2020-02-22	Travis Reynolds	travis.reynolds@geemail.com	Charleston	South Carolina	869916813045129150	68152149a1dc43902a8d9ae0a13a5af7	VISA 13 digit	32.8120719553899036	-79.9358656009342496
13097	2020-02-22 11:44:16	2020-02-22	Ann Mayert-Rolfson	ann.mayert.rolfson@geemail.com	Phoenix	Arizona	180007157413426926	9c79902099b57ff7e1a92a54dbc038de	Diners Club / Carte Blanche	33.4976036918282531	-112.016413606137419
13098	2020-02-22 11:47:14	2020-02-22	Branch Bechtelar MD	branch.bechtelar.md@warmmail.com	Fresno	California	180015115292046561	ea94ff4c6a9d89ae2676494911e1a3cb	Maestro	36.8697826241016386	-119.808595838781073
13099	2020-02-22 11:49:29	2020-02-22	Carissa Thiel	carissa.thiel@geemail.com	Costa Mesa	California	210054303520585251	f8cb677ae486b7d85a84a8b0d3ab7de8	JCB 16 digit	33.5826459879536188	-117.83415849077069
13100	2020-02-22 11:56:28	2020-02-22	Ms. Arvilla Becker	ms.arvilla.becker@geemail.com	Houston	Texas	54007944954837631	fda4f254d30543e5a0eb5d4696d315e9	VISA 16 digit	29.8742131355762481	-95.3221421200331349
13101	2020-02-22 12:19:35	2020-02-22	Myrta Nitzsche	myrta.nitzsche@woohoo.com	Tempe	Arizona	3015048342035239	993ec9096c1ac843b8bfc361f3913112	VISA 13 digit	33.2978261955004129	-111.85980775188952
13102	2020-02-22 12:30:16	2020-02-22	Najee Cummings	najee.cummings@warmmail.com	Oklahoma City	Oklahoma	676176993988799	a2302b667cb336a30fa100701ab17d14	Maestro	35.557588245477902	-97.4387360934529454
13103	2020-02-22 12:38:06	2020-02-22	Bernadette Purdy	bernadette.purdy@geemail.com	Los Angeles	California	869991030832724709	62fa45213ac8d290752e3b56fcbdb059	JCB 16 digit	34.039945318955553	-118.40075512304827
13104	2020-02-22 12:39:12	2020-02-22	Dr. Misael Muller	dr.misael.muller@geemail.com	Oakland	California	210016298587462948	8909d1fab75a7c6bab1b83350aecd8d7	Discover	37.7976605061697057	-122.258904531583568
13105	2020-02-22 12:39:34	2020-02-22	Miss Dayanara Wiza DVM	miss.dayanara.wiza.dvm@geemail.com	New York	New York	4002288315749589	366474d6e48e98a18e8c7a287577e792	JCB 16 digit	40.5849050476439288	-73.9412966007728159
13106	2020-02-22 12:39:44	2020-02-22	Earlene Donnelly DDS	earlene.donnelly.dds@geemail.com	Vista	California	3051881341019158	20a5cea05454cded609532d1b4aec88a	VISA 16 digit	33.2610537690091874	-117.290342572011426
13107	2020-02-22 12:41:04	2020-02-22	Khari Spencer	khari.spencer@woohoo.com	Oakland	California	52005845881242245	5fc4860b9e38158ee0a4b856e8ddb627	Maestro	37.8176112625923295	-122.27908919936776
13108	2020-02-22 12:49:38	2020-02-22	Candi Stamm	candi.stamm@geemail.com	Garland	Texas	4413373706772904	98a4ccdfc034f15f46c0d3d1e3cae971	Maestro	32.9122459628388242	-96.6412660848043856
13109	2020-02-22 13:02:09	2020-02-22	Mr. Aidyn Harber PhD	mr.aidyn.harber.phd@geemail.com	Laredo	Texas	3158522134768241594	d6b8defe80fcd421a3eb293d7f05b223	American Express	27.6558352912027416	-99.5248178269255845
13110	2020-02-22 13:08:30	2020-02-22	Irena Blanda	irena.blanda@geemail.com	Berkeley	California	3024252633194439	a31f52307dbf5b1e048ad89907ffd226	Maestro	37.8622547938636629	-122.261674921679159
13112	2020-02-22 13:24:28	2020-02-22	Bartholomew Lehner	bartholomew.lehner@geemail.com	San Francisco	California	3337817310870677867	f24091d16f072cddf6d2d3e9da24290b	Mastercard	37.8212474680276998	-122.40399016360503
13113	2020-02-22 14:00:15	2020-02-22	King Torphy V	king.torphy.v@geemail.com	San Francisco	California	3096380796474336412	be97b534950de3fcecac4b2b1c0e31dc	Mastercard	37.8082479144013774	-122.461199308345286
13114	2020-02-22 14:19:59	2020-02-22	Vallie McDermott	vallie.mcdermott@geemail.com	North Las Vegas	Nevada	3158363600461713859	259f7f1eecf38cc7f3145bc0de3ceb6d	JCB 16 digit	36.1868172579135745	-115.124591460426899
13115	2020-02-22 14:20:19	2020-02-22	Dr. Candace Spinka DDS	dr.candace.spinka.dds@geemail.com	Louisville	Kentucky	869946080116528447	f459901af9835feb6e98f816c6b6deaf	JCB 15 digit	38.1282108689561454	-85.5664244812518433
13116	2020-02-22 14:33:08	2020-02-22	Monique Streich	monique.streich@geemail.com	Ontario	California	869905646243314619	4ab8f945511338d6992e173b7e382591	American Express	34.0664110004115841	-117.536340895258647
13117	2020-02-22 14:39:55	2020-02-22	Maranda McClure PhD	maranda.mcclure.phd@geemail.com	San Diego	California	3438916296604435	c16d75cbe60837e961e11e36f6b97419	VISA 13 digit	32.8849084515191592	-117.159926212662839
13118	2020-02-22 14:44:50	2020-02-22	Ms. Andrea Champlin DVM	ms.andrea.champlin.dvm@geemail.com	San Antonio	Texas	3112989278786401270	754b275be8adc605964b763cba643ff0	JCB 16 digit	29.5044078883785765	-98.4592977005824395
13119	2020-02-22 14:50:15	2020-02-22	Miss Marlena Donnelly MD	miss.marlena.donnelly.md@geemail.com	Jacksonville	Florida	3044873911478960	daa565bb785a13080190c1f4829a1e4c	Mastercard	30.2860174396593109	-81.6910177535455801
13120	2020-02-22 15:00:28	2020-02-22	Messiah Bode	messiah.bode@geemail.com	San Francisco	California	4866169646647	bb5237614e29597084d384dfa8727575	VISA 16 digit	37.7328989717997914	-122.425895856919993
13121	2020-02-22 15:15:34	2020-02-22	Elam Lynch	elam.lynch@warmmail.com	Dallas	Texas	4022692949609	041596cd9eda07e097af4d8919516e0a	Diners Club / Carte Blanche	32.8268457076318612	-96.7826109226755733
13122	2020-02-22 15:26:27	2020-02-22	Luvenia Runte-Pagac	luvenia.runte.pagac@geemail.com	New York	New York	4240499419309	73dc0d8315824a08c82ec22e12ac7328	Discover	40.6933682369291745	-73.9685061550594867
13123	2020-02-22 15:32:39	2020-02-22	Alysha Steuber	alysha.steuber@geemail.com	Santa Clarita	California	6011745635703813140	c0c04bba742cefb1e200c75b3bc39254	American Express	34.3072743515223237	-118.449163732780889
13124	2020-02-22 15:41:57	2020-02-22	Pearly Gleason	pearly.gleason@warmmail.com	Berkeley	California	4219535217192055	b9d3528c3d08d9bce5a01d7308b51b41	VISA 13 digit	37.8582846289265049	-122.213325816972144
13125	2020-02-22 15:58:45	2020-02-22	Mrs. Kaleigh Lind MD	mrs.kaleigh.lind.md@warmmail.com	Alexandria	Virginia	639039087401434	a1aacc8cfdba661e8593a371e52592c7	VISA 13 digit	38.7236403136629548	-77.1561576197840395
13126	2020-02-22 16:14:39	2020-02-22	Elyse Gaylord	elyse.gaylord@geemail.com	Tulsa	Oklahoma	3492911235911531	ad6aaadc621d57e3f162d9c3da38b288	JCB 16 digit	36.181175342285627	-95.8376142321575344
13127	2020-02-22 16:16:32	2020-02-22	Ferne Schoen	ferne.schoen@geemail.com	Tulsa	Oklahoma	6011217672185306441	74de218333e64d5eba11ba4edc6fcbf5	VISA 16 digit	36.0465156950425296	-95.9543536234136667
13128	2020-02-22 16:25:47	2020-02-22	Chet Smith	chet.smith@geemail.com	San Antonio	Texas	639059342224462	d8074b43aea7d7f1aa18879f5eef2b25	JCB 16 digit	29.4285447960790236	-98.4805356944281556
13129	2020-02-22 16:26:42	2020-02-22	Melany Weber-Metz	melany.weber.metz@geemail.com	Omaha	Nebraska	4805508088500847	626c30bf3bde85eadba19f3c6bd1c120	JCB 16 digit	41.2474005214549635	-96.0659673394750797
13130	2020-02-22 16:31:00	2020-02-22	Dr. Ferrell Padberg Sr.	dr.ferrell.padberg.sr.@geemail.com	St. Louis	Missouri	060440236242471	34d49514a33671dbfe097e556885127c	American Express	38.5653440781094119	-90.2201829961504842
13131	2020-02-22 16:39:32	2020-02-22	Oralia O'Kon-Beier	oralia.o'kon.beier@geemail.com	Charlotte	North Carolina	4597005383085964	7e3b837c2c3968009e44033a665bcfbf	Discover	35.2110697263639381	-80.9034434973206373
13132	2020-02-22 16:45:45	2020-02-22	Mr. Wardell Lowe DDS	mr.wardell.lowe.dds@geemail.com	Oakland	California	4068319313182	73f686f1340a7b5776a14a80dd28e512	Diners Club / Carte Blanche	37.8126977579405263	-122.271533345401593
13133	2020-02-22 16:47:57	2020-02-22	Shenna Kub	shenna.kub@warmmail.com	San Francisco	California	51600346657464336	785296d3943d3e54b116402f5b33fcf3	Mastercard	37.7911412820383248	-122.426612459825066
13134	2020-02-22 16:50:01	2020-02-22	Calhoun Johnson	calhoun.johnson@woohoo.com	San Francisco	California	4223913569980365	88a9110ce9d386e40a2cc3b56b23fa56	Maestro	37.7576720121991087	-122.413270856222724
13135	2020-02-22 17:15:51	2020-02-22	Williemae Hoppe	williemae.hoppe@warmmail.com	New York	New York	639068248681360	235e2dc2d843ac3a4415aa3f6b94bb55	VISA 16 digit	40.7003530677165841	-73.8647697045363429
13136	2020-02-22 17:51:07	2020-02-22	Cleora Hayes-Bergstrom	cleora.hayes.bergstrom@geemail.com	San Francisco	California	561274926019196	ac86dcceff34140ad935054a57fd770b	Mastercard	37.7868785971230992	-122.433800070431943
13137	2020-02-22 17:58:40	2020-02-22	Tahj O'Hara	tahj.o'hara@woohoo.com	Oxnard	California	4534212712523	10fac8ba613cdaf75d7f563afddf8c3f	Mastercard	34.1942852192979316	-119.137376564266532
13138	2020-02-22 18:15:19	2020-02-22	Everette Ferry	everette.ferry@warmmail.com	Torrance	California	3411594602662487	83b6b9edd454bf49f7471185483c3a74	VISA 16 digit	33.8542588864825689	-118.288266198349731
13139	2020-02-22 18:16:29	2020-02-22	Dr. Dayne Wolf	dr.dayne.wolf@geemail.com	San Francisco	California	3450841376360018	28ef8295f399e42b5427904a103e0207	JCB 15 digit	37.7695135269232267	-122.448978565388941
13140	2020-02-22 18:18:10	2020-02-22	Carol Hane	carol.hane@geemail.com	New York	New York	3756531315068814	82508027bc1e11d6ea8174f80f7e24b1	Discover	40.6522210146989664	-74.0346796672221217
13141	2020-02-22 18:19:40	2020-02-22	Ms. Easter Friesen	ms.easter.friesen@warmmail.com	Chicago	Illinois	4400498215202641	dde2e58257944a16dabbcf521ca36f35	VISA 16 digit	41.8067978809423764	-87.6696405778203172
13142	2020-02-22 18:22:27	2020-02-22	Dr. Houston Murazik V	dr.houston.murazik.v@woohoo.com	Glendale	California	869911954805247181	7b49d417606b1ba0765b5f268fd85bdb	VISA 13 digit	34.1262939150199287	-118.150353472902623
13143	2020-02-22 18:33:05	2020-02-22	Nickolas Walker Sr.	nickolas.walker.sr.@geemail.com	Miami	Florida	3158703972130349582	f01d365cf881978b33ede6d13847e74b	JCB 15 digit	25.7068528893541561	-80.2473549798935721
13144	2020-02-22 18:36:52	2020-02-22	Admiral Daugherty	admiral.daugherty@woohoo.com	San Francisco	California	180038577747023052	39271d0851dc3a981bab5aabcb26c79e	JCB 15 digit	37.7921614446574807	-122.446740824900232
13145	2020-02-22 18:44:53	2020-02-22	Dr. Audrina Schowalter	dr.audrina.schowalter@geemail.com	Rockford	Illinois	4964452760546	2b2e618754001d269cf7cb582f938317	Maestro	42.290234914609421	-89.1120362938664812
13146	2020-02-22 18:45:17	2020-02-22	Saverio Ruecker III	saverio.ruecker.iii@warmmail.com	San Diego	California	53529420603336399	2afc34bb0623a6432ecac88cff1a5a59	JCB 16 digit	32.8387335008542962	-117.181008536219608
13147	2020-02-22 19:06:44	2020-02-22	Tristen Langworth	tristen.langworth@geemail.com	Austin	Texas	3088696588920926287	8efa91ffb79331bd7fe304de20089230	Maestro	30.2259139601733509	-97.7176934186607582
13148	2020-02-22 19:26:35	2020-02-22	Gilmer Veum	gilmer.veum@woohoo.com	San Francisco	California	3495648719650923	4e1220f618d5160e2662826c2e1b8262	Voyager	37.780398972901871	-122.399494648970887
13149	2020-02-22 19:29:21	2020-02-22	Dayami Wisozk-Ebert	dayami.wisozk.ebert@geemail.com	Lakewood	Colorado	4414328241881056	61845afe4b140ce2062a0fa17cdcb0a8	Discover	39.7268571293387609	-105.061347618561612
13150	2020-02-22 19:33:13	2020-02-22	Paris Hermiston-Farrell	paris.hermiston.farrell@warmmail.com	Columbus	Ohio	4860278586985179	3ec5b401c13b25aba02419c3d66e7dac	Diners Club / Carte Blanche	40.0716196998998484	-83.0316108702916722
13151	2020-02-22 19:33:57	2020-02-22	Lissa Altenwerth-Eichmann	lissa.altenwerth.eichmann@geemail.com	Berkeley	California	6011280255618101472	92bd5d885c221e2977900da0e3effe93	JCB 15 digit	37.8672491271464722	-122.299088570814988
13152	2020-02-22 19:44:10	2020-02-22	Trenten Paucek	trenten.paucek@geemail.com	Oakland	California	4288901089678579	358f4b6df03fee8047444fc74732f0ca	Diners Club / Carte Blanche	37.8257641897222996	-122.281025248420761
13153	2020-02-22 19:57:13	2020-02-22	Haiden McLaughlin	haiden.mclaughlin@warmmail.com	Indianapolis	Indiana	210014739571568739	5b997e8c30ab7859eb5bdb238da68e1d	Voyager	39.7989361231688363	-86.1850197991091704
13154	2020-02-22 20:10:49	2020-02-22	Vonetta Farrell	vonetta.farrell@geemail.com	New York	New York	3481858802878564	1e939732d9be5278195363f725680ff9	JCB 15 digit	40.7383241083230843	-73.8848185376159847
13155	2020-02-22 20:25:47	2020-02-22	Collins Will-Kautzer	collins.will.kautzer@warmmail.com	San Francisco	California	060484564162422	032b2cf7aa2e7f60e7e651a94487aa0b	Discover	37.7977709900042811	-122.453300933832168
13156	2020-02-22 20:28:50	2020-02-22	Larry Keeling	larry.keeling@geemail.com	San Antonio	Texas	501850144879082	5f52c1407d78c231f65d05352b2f9f36	VISA 16 digit	29.5184152022074926	-98.5426274774897735
13157	2020-02-22 20:37:59	2020-02-22	Miss Shawanda Ebert DDS	miss.shawanda.ebert.dds@geemail.com	Tucson	Arizona	6011307455283009047	815d19f241143e6f813224424d706bce	JCB 15 digit	32.0674856525886796	-110.890756080322333
13158	2020-02-22 20:44:53	2020-02-22	Dorman Volkman	dorman.volkman@geemail.com	Las Vegas	Nevada	6011749666785643127	b3e714267d3696cd99b010b342e93f0f	VISA 16 digit	36.1913273503638777	-115.278898485165456
13159	2020-02-22 21:12:15	2020-02-22	Floy Turner	floy.turner@woohoo.com	San Antonio	Texas	53818365721832417	70f0c5d969bd31a1b08dc825356e7cae	Diners Club / Carte Blanche	29.4709763702075946	-98.512472300121928
13160	2020-02-22 21:23:18	2020-02-22	Champ Lynch	champ.lynch@geemail.com	Oklahoma City	Oklahoma	4224245882290118	c0218991923146289e2e42e8fddf2589	VISA 13 digit	35.5133226923089467	-97.4559202886547951
13161	2020-02-22 21:28:37	2020-02-22	Nanette Strosin	nanette.strosin@warmmail.com	New Orleans	Louisiana	3112334438793119313	0090fdd0eb13aebd968d69e2d698fa62	American Express	29.9844144792310878	-89.8920521664693979
13162	2020-02-22 22:14:26	2020-02-22	Pennie Metz	pennie.metz@warmmail.com	Paterson	New Jersey	180028146993788487	cbe48e5284f97aa99da07a96f28b93df	Voyager	40.9631206808101354	-74.1182535815492258
13163	2020-02-22 22:21:37	2020-02-22	Jaydan Mosciski	jaydan.mosciski@geemail.com	Clinton	Michigan	210042297497773855	87fdb72713026d17e9898bf7d4729065	VISA 16 digit	42.5258544313322773	-82.9316755752153654
13164	2020-02-22 23:11:32	2020-02-22	Chas Ryan	chas.ryan@geemail.com	Boise	Idaho	3096099790211468598	c41e768add4d27b49210fde8c466a64d	VISA 16 digit	43.6409375638838881	-116.330701843249429
13165	2020-02-22 23:15:33	2020-02-22	Dirk Upton	dirk.upton@geemail.com	Tuscaloosa	Alabama	55031277264506293	466ffe2206e44869e2ce65640befe7cd	VISA 13 digit	33.1542846427354974	-87.4494010976146825
13166	2020-02-22 23:21:09	2020-02-22	Dr. Taj Lesch MD	dr.taj.lesch.md@geemail.com	Berkeley	California	6011121185305441175	2570c622e6b9b61a6907da3af7195756	Maestro	37.8894562011297467	-122.245896429098906
13167	2020-02-22 23:36:01	2020-02-22	Norris Kessler	norris.kessler@geemail.com	Wichita	Kansas	3006015610952287	f7d09c43face2ecb3846f2884ed95fa8	VISA 16 digit	37.7880623576108334	-97.3977613112624709
13168	2020-02-22 23:47:26	2020-02-22	Jarrod Waters	jarrod.waters@geemail.com	Beaumont	Texas	3528486078754891389	d6abc96a24008642407907a899bd3431	Mastercard	30.1421401962243038	-94.1664214809212865
13169	2020-02-22 23:49:01	2020-02-22	Lenord Gorczany	lenord.gorczany@geemail.com	Dallas	Texas	3112707229636908015	551f050a30b1981ba2468c4774609ba4	Discover	32.7915984795235147	-96.737524082927024
13170	2020-02-22 23:54:31	2020-02-22	Dr. Talan Hammes IV	dr.talan.hammes.iv@geemail.com	San Antonio	Texas	6011103789318113069	1680ea8f6ec02bd5191ecbe18bf931aa	Mastercard	29.4581765736058365	-98.5670854178558926
13171	2020-02-22 23:56:44	2020-02-22	Jamari Frami	jamari.frami@geemail.com	Fresno	California	4625919223864865	0895b5cc983514ce0b14b5c8b5d30cac	JCB 15 digit	36.7819282947447164	-119.830147108725839
13172	2020-02-23 00:00:32	2020-02-23	Mrs. Hope Schimmel	mrs.hope.schimmel@geemail.com	Rialto	California	6011226986777409648	2bd50fddf4dd5f6bba1273e4f4f67795	Diners Club / Carte Blanche	34.0838827698707618	-117.403361285952101
13173	2020-02-23 00:01:06	2020-02-23	Davina Schmitt	davina.schmitt@geemail.com	Oakland	California	4697804105588225	ca910f1982f1f27befbb3ab938bd9b42	JCB 16 digit	37.8225089168606345	-122.241054283450026
13174	2020-02-23 00:19:56	2020-02-23	Maribel Lindgren-Osinski	maribel.lindgren.osinski@woohoo.com	Newark	New Jersey	4465741262207134	06a261667630c9d05de40726f83967f7	Diners Club / Carte Blanche	40.7105213380798716	-74.223535201300308
13175	2020-02-23 00:21:26	2020-02-23	Mr. Collis McKenzie	mr.collis.mckenzie@geemail.com	Los Angeles	California	869960009806022867	3cd113520a8dafcf0ca4f2c7d649fc3f	Discover	34.0827021223824431	-118.334561407425625
13176	2020-02-23 00:22:17	2020-02-23	Jalissa Hintz MD	jalissa.hintz.md@geemail.com	Des Moines	Iowa	51582879499982893	f0c2f49283b5f3ca2b3781991fb1cc37	Discover	41.4877113666594042	-93.5776072298221351
13177	2020-02-23 00:25:16	2020-02-23	Velda Conn	velda.conn@woohoo.com	Boston	Massachusetts	3112512654790135771	3a6345aebf6babba1e9d0922c1828120	VISA 16 digit	42.411022711422298	-71.0965161587528911
13178	2020-02-23 00:25:44	2020-02-23	Mr. Cain Spencer IV	mr.cain.spencer.iv@woohoo.com	Philadelphia	Pennsylvania	869920039596067888	44b8564e3727d32958805ad20b947da0	VISA 13 digit	39.9216677682898933	-75.1810418347261873
13179	2020-02-23 00:47:14	2020-02-23	Collis Terry	collis.terry@warmmail.com	Minneapolis	Minnesota	639007095912247	0372a1e2e58554f24a9f6e10d84cbb8d	VISA 13 digit	44.9049609643958476	-93.1754580740157508
13180	2020-02-23 01:01:19	2020-02-23	Mr. Lawerence Medhurst I	mr.lawerence.medhurst.i@geemail.com	Los Angeles	California	501861986778605	f7ddbb68029314e55b4e2c17d5b99ab4	JCB 16 digit	33.9431568630371245	-118.355164538788785
13181	2020-02-23 01:22:31	2020-02-23	Jerrie Stokes	jerrie.stokes@geemail.com	Wichita	Kansas	3045959433301597	b309665676f29c21dec215e196ea7c3d	JCB 15 digit	37.6368110770236726	-97.3139771744810105
13182	2020-02-23 01:42:57	2020-02-23	Julianna Morar-O'Connell	julianna.morar.o'connell@geemail.com	Vallejo	California	4188746849860491	6e7d125c9265077a32ccdbc4d1668f2a	Maestro	38.011352250082048	-122.305501602670176
13183	2020-02-23 02:00:07	2020-02-23	Markel Funk	markel.funk@geemail.com	Centennial	Colorado	180003176227704611	b9699468c29b311652844aa28175a0b1	JCB 15 digit	39.5827236347872784	-104.858912609972435
13184	2020-02-23 02:05:38	2020-02-23	Misti Spinka	misti.spinka@woohoo.com	San Jose	California	6011495584179169029	aedeacca7d80c920a6a32454b8a6c2d7	JCB 16 digit	37.3875557468093973	-121.79136934738942
13185	2020-02-23 02:13:26	2020-02-23	Florene Nader-Mosciski	florene.nader.mosciski@warmmail.com	Fort Collins	Colorado	4616141433733118	329166adda0437ae1677e56529b511fb	JCB 16 digit	40.4625570626620217	-105.04073493629248
13186	2020-02-23 02:19:02	2020-02-23	Ottilia Emmerich	ottilia.emmerich@geemail.com	Los Angeles	California	3158878370887122006	2177c858a73800aab40f316c7fbb5f78	Voyager	33.9647848811797743	-118.335447154519329
13187	2020-02-23 02:38:00	2020-02-23	Victor Hauck III	victor.hauck.iii@geemail.com	Kansas City	Missouri	4751719288370089	69200c08a557854d4b1e4eac900f08e8	JCB 16 digit	39.0677578397396985	-94.5065472680367549
13188	2020-02-23 03:04:45	2020-02-23	Ricky Erdman Sr.	ricky.erdman.sr.@geemail.com	Nashville	Tennessee	3158012523967938405	a867709f466076b2e55c80b71300f4ec	Discover	36.2053302544757685	-86.8064262548368362
13189	2020-02-23 03:23:57	2020-02-23	Jaquan Boehm	jaquan.boehm@geemail.com	Irvine	California	3029123009466765	e88a99018f502c83a26f005a6fc81cfc	JCB 16 digit	33.5808178721010719	-117.728397302656617
13190	2020-02-23 03:29:02	2020-02-23	Oralia Berge	oralia.berge@geemail.com	Hayward	California	869963265021915353	b546bc08088905bcdf50d7d7f7bb9bc4	Mastercard	37.5351079783856889	-122.199483125077194
13191	2020-02-23 03:34:53	2020-02-23	Randolph Thiel	randolph.thiel@geemail.com	Los Angeles	California	4650786270101808	af8d72f4268ae864942aa2e353b42f50	VISA 16 digit	34.0674484578292791	-118.352595046813775
13192	2020-02-23 03:36:47	2020-02-23	Liane Kuhn	liane.kuhn@geemail.com	Seattle	Washington	53462324536045482	7a69246d8a06d161f5a87286c57724a8	VISA 16 digit	47.5394512007869778	-122.407046808667104
13193	2020-02-23 03:53:44	2020-02-23	Letta Waelchi	letta.waelchi@warmmail.com	Oakland	California	6011145971945293841	94199e638bfc8b9e3f0292114d3195fc	JCB 16 digit	37.7542829586409923	-122.282709982081471
13194	2020-02-23 04:04:56	2020-02-23	Elias Dibbert	elias.dibbert@geemail.com	Norman	Oklahoma	3096693683343294554	b71cf8567405047ede81af873b905cc3	American Express	35.2232510210521497	-97.4030347893267816
13195	2020-02-23 04:05:39	2020-02-23	Susann Langosh	susann.langosh@geemail.com	Aurora	Colorado	4369861008265	36c942442a4e8fffdff4975c01201931	VISA 13 digit	39.7525315237809025	-104.683815677615627
13196	2020-02-23 04:20:58	2020-02-23	Kenney White	kenney.white@geemail.com	Santa Rosa	California	3031229783162963	c5b580bff131e94b74a2909ba0b983d3	American Express	38.4576231108635724	-122.761323184311763
13197	2020-02-23 04:23:29	2020-02-23	Ainsley Olson	ainsley.olson@geemail.com	Oakland	California	180094558789634031	be8a4583c74c9ac957ded084c812fa6e	JCB 16 digit	37.8140213123251527	-122.244206533476401
13198	2020-02-23 04:28:04	2020-02-23	Dr. Jessie Terry	dr.jessie.terry@geemail.com	Dallas	Texas	180062661877392641	be28f9f2cb896f8a7a113f6cc3a49b9c	JCB 16 digit	32.81667045972236	-96.6753376908097408
13199	2020-02-23 04:32:16	2020-02-23	Azaria Miller	azaria.miller@woohoo.com	Berkeley	California	869913310182047975	90de9ef54bbf695788aeffe1f98a25d0	Discover	37.8705488735050366	-122.294563592330448
13200	2020-02-23 04:42:00	2020-02-23	Emil Wisozk	emil.wisozk@woohoo.com	San Francisco	California	3466626461374053	bd13ed665565b1ce187d6371f5bc7336	JCB 15 digit	37.7809880499560435	-122.459613926827174
13201	2020-02-23 04:52:43	2020-02-23	Austyn Mueller	austyn.mueller@geemail.com	Spokane	Washington	210077510705441489	cade4602726d381271c85360b31583e9	VISA 16 digit	47.6085380383074295	-117.468021003659075
13202	2020-02-23 04:55:10	2020-02-23	Mr. Kit Quigley	mr.kit.quigley@woohoo.com	Atlanta	Georgia	180044201079605707	b0d3101bdb668e15f31c7f0718b91ffd	Mastercard	33.7363480130486195	-84.4705611375670884
13203	2020-02-23 05:02:42	2020-02-23	Melony Klein	melony.klein@geemail.com	Detroit	Michigan	675900285929766	01fec464fe4f6ce92d98deafe60715b7	VISA 13 digit	42.4213179412223411	-83.182376982050755
13204	2020-02-23 05:06:47	2020-02-23	Jaylon Wiza	jaylon.wiza@geemail.com	Santa Ana	California	180016049257537265	8c1119a457249bc7d9e6804d7a3505ca	Voyager	33.8009303512155981	-117.871381781568743
13205	2020-02-23 05:08:52	2020-02-23	Gearldine Glover DVM	gearldine.glover.dvm@geemail.com	Chicago	Illinois	3337442724107859606	2bdc0fb774450190883d40ad336df082	VISA 13 digit	41.7395964515697244	-87.6296114588186157
13206	2020-02-23 05:29:52	2020-02-23	Isidro Barton	isidro.barton@geemail.com	Tyler	Texas	589373660947547	930ce1d17fd7e424acc8cc203c0bb440	JCB 15 digit	32.3595081466298566	-95.4004753105450334
13207	2020-02-23 05:31:34	2020-02-23	Jamari Jones-White	jamari.jones.white@geemail.com	Lakewood	New Jersey	180005192912486529	9f8369ab9d87704656b45f6ce0cf1a63	Diners Club / Carte Blanche	40.1464110495340094	-74.2243040753338477
13208	2020-02-23 05:39:46	2020-02-23	Atlas Langworth	atlas.langworth@woohoo.com	San Francisco	California	3337965509485433521	dfd19760b13e3c80a281404c0cca7841	Voyager	37.783700203133094	-122.436688668196851
13209	2020-02-23 05:48:42	2020-02-23	Nada Willms PhD	nada.willms.phd@warmmail.com	Omaha	Nebraska	3053491663440954	ae8ab60dbe1a5863e22de88f29d80a3e	Voyager	41.239438084667178	-96.1192676085162958
13210	2020-02-23 05:52:47	2020-02-23	Garvin Adams	garvin.adams@warmmail.com	Clarksville	Tennessee	869994890503692296	d4dfd3badefe57230f40698f287927b7	Diners Club / Carte Blanche	36.5031472578771456	-87.3111851643722616
13211	2020-02-23 06:03:39	2020-02-23	Clive Wisozk	clive.wisozk@geemail.com	Chula Vista	California	869950329570956070	2322be5ea296b1e79e8b4be58d1dedf4	Diners Club / Carte Blanche	32.6460931159321177	-116.964191378676134
13212	2020-02-23 06:11:11	2020-02-23	Orelia Leffler	orelia.leffler@woohoo.com	Richardson	Texas	869980355821530756	b0364c4d00e8a3840abd7afd7743626d	VISA 13 digit	32.9066829621560828	-96.7224517962191328
13213	2020-02-23 06:21:20	2020-02-23	Ms. Shea Hirthe	ms.shea.hirthe@woohoo.com	Berkeley	California	52141641385082350	a0324c23bd741090dbf9c3a761ff0a91	American Express	37.8473894067351893	-122.267560084282735
13214	2020-02-23 06:50:33	2020-02-23	Loretta Hamill-Welch	loretta.hamill.welch@geemail.com	San Bernardino	California	6011782153658604781	729a99ca37538c9935a4f0a83485acd7	VISA 16 digit	34.1398005116529717	-117.272947062995655
13215	2020-02-23 07:03:11	2020-02-23	Serena Swaniawski	serena.swaniawski@warmmail.com	Berkeley	California	4549221390236560	b2fbd73557e19112dc4421e8c7eaeb50	VISA 13 digit	37.8499928639622851	-122.252092652568621
13216	2020-02-23 07:24:47	2020-02-23	Tod Fisher	tod.fisher@geemail.com	Toledo	Ohio	4340009132747	d51d945047acf7ff83bd8413de04b4ab	JCB 15 digit	41.6172618494074769	-83.545241379491614
13217	2020-02-23 08:02:32	2020-02-23	Rolando Cartwright	rolando.cartwright@geemail.com	Philadelphia	Pennsylvania	4985886317811306	06ba205d1538a01cad75360b06978d22	Mastercard	40.0737976864404999	-75.1669250429041682
13218	2020-02-23 08:07:52	2020-02-23	Carley Roob	carley.roob@geemail.com	Minneapolis	Minnesota	6011829385097103406	8156b92852c086a19448193abea9fe68	Maestro	44.8915855033874465	-93.2907135698750523
13219	2020-02-23 08:14:36	2020-02-23	Ivey Armstrong DVM	ivey.armstrong.dvm@woohoo.com	Bellevue	Washington	3528875917513978178	3da9f2552a642f6ae0cedf32a4bad3f7	Voyager	47.6581855200879332	-122.179903342207894
13220	2020-02-23 08:22:05	2020-02-23	Veta Baumbach	veta.baumbach@geemail.com	Costa Mesa	California	3744652923418822	471e5147981116c66ab38ab93a44cd18	Maestro	33.7657347093351206	-117.936867417427905
13221	2020-02-23 08:29:14	2020-02-23	Renea Jast-Hudson	renea.jast.hudson@geemail.com	San Francisco	California	4523252523687007	dc74d91af5377322e152914a509253c5	Voyager	37.7653655222967188	-122.433810313903848
13222	2020-02-23 08:34:48	2020-02-23	Gaylord Corwin	gaylord.corwin@geemail.com	Los Angeles	California	180045446008324776	bc2db35225a852d5e33ff8514831fa6a	VISA 16 digit	34.0410420795302784	-118.490824712160219
13223	2020-02-23 08:41:44	2020-02-23	Glinda Lubowitz	glinda.lubowitz@geemail.com	Chicago	Illinois	4828890260913284	f4feb9742235ef17d103154e4c2dc7a3	VISA 16 digit	41.7380948331974437	-87.6182218757953422
13224	2020-02-23 08:46:44	2020-02-23	Marlen Hirthe	marlen.hirthe@geemail.com	Berkeley	California	6011191700363663091	b4591487eaa4b2623246c03d5e06a1fb	Voyager	37.8921273320834615	-122.27617133421289
13225	2020-02-23 08:49:11	2020-02-23	Phyllis Conroy-Bernier	phyllis.conroy.bernier@geemail.com	Santa Ana	California	3796301493538760	e2ac2dcc009bbb0f62b613617d8fd677	JCB 16 digit	33.7380578225117205	-117.968604251222686
13226	2020-02-23 08:49:26	2020-02-23	Geraldo Ebert	geraldo.ebert@geemail.com	Surprise	Arizona	869966509433663011	532d28e504387a504c6efc3be9e472ec	Diners Club / Carte Blanche	33.6424660482205482	-112.403247144096341
13227	2020-02-23 09:45:06	2020-02-23	Casimer Predovic-Witting	casimer.predovic.witting@geemail.com	New York	New York	3096109042502018981	e96f14dfa0d379a71b04c4ab15d86c21	JCB 16 digit	40.654299308661372	-74.0376175507798706
13228	2020-02-23 09:48:03	2020-02-23	Erik Homenick	erik.homenick@geemail.com	Los Angeles	California	6011513944521790963	25ea6395b1ff0606eb8599009d8e43af	JCB 16 digit	33.9467662573657876	-118.505545673239226
13229	2020-02-23 09:59:15	2020-02-23	Rayford Dietrich IV	rayford.dietrich.iv@woohoo.com	San Francisco	California	4572832291247	3b5433593164d1e6053c292a57095fb9	Discover	37.7904381919616412	-122.406593363645626
13230	2020-02-23 10:01:04	2020-02-23	Kacy Champlin DDS	kacy.champlin.dds@geemail.com	Honolulu	Hawaii	3031665873865983	2cbfe0c49cecc076f2d1a92f26cafc19	Mastercard	21.3287323560781772	-157.894124894470337
13231	2020-02-23 10:10:25	2020-02-23	Diane Quitzon	diane.quitzon@geemail.com	Ventura	California	55609175135092653	53c7221e0ab505bce7a864fc8b6ca680	JCB 16 digit	34.2705642534580122	-119.332521381006387
13232	2020-02-23 10:13:57	2020-02-23	Dejuan Steuber	dejuan.steuber@warmmail.com	Berkeley	California	561255468123157	52f82de8cc1e8b91288eed36fc366acd	Diners Club / Carte Blanche	37.8690958947714122	-122.27660857835636
13233	2020-02-23 10:22:44	2020-02-23	Kanesha Kunze	kanesha.kunze@geemail.com	San Francisco	California	3096584190689235474	030246d8ab7c1bc48161b89af7bf02d9	Diners Club / Carte Blanche	37.7841274171627575	-122.393542797062551
13234	2020-02-23 10:38:51	2020-02-23	Darby Reynolds-Cassin	darby.reynolds.cassin@geemail.com	San Francisco	California	4479469483504667	837330c2b38cf7c6dbb1ea2fc4befceb	Discover	37.7609317186570905	-122.435949959909308
13235	2020-02-23 10:47:34	2020-02-23	Konnor O'Hara	konnor.o'hara@geemail.com	Grand Prairie	Texas	4152278245777279	e73ef24b0af63c52935940634757fc1a	JCB 16 digit	32.6948499627463534	-97.0843927092257957
13236	2020-02-23 10:56:13	2020-02-23	Sophie Abbott	sophie.abbott@geemail.com	Westminster	Colorado	4374438868902	aa3130e0ee9dacf80cda3be6f51b7ea5	JCB 16 digit	39.8395817173950348	-105.151255205101904
13237	2020-02-23 11:03:54	2020-02-23	Verna Pagac	verna.pagac@geemail.com	Milwaukee	Wisconsin	3088854354418830301	2d76a42ba864b915426d093ba5c33ccd	Voyager	43.1034502685155729	-87.9411945965707389
13238	2020-02-23 11:05:02	2020-02-23	Dondre Jacobi	dondre.jacobi@geemail.com	Clovis	California	4365854731588397	50d5572061621f6ccbc81402a92cd1bd	VISA 16 digit	36.7530573224991599	-119.775128834515442
13239	2020-02-23 11:35:14	2020-02-23	Mychal Kilback	mychal.kilback@geemail.com	New York	New York	3420922309429950	095af78d0eb09eb1c2a8e91faab8d4dc	VISA 16 digit	40.5979393227249403	-73.8713327584683839
13240	2020-02-23 12:17:06	2020-02-23	Cherryl Parisian	cherryl.parisian@geemail.com	San Francisco	California	3020798470651661	8041f8861428e9c800aa51bb68667a39	Discover	37.7445305078961084	-122.443960517654872
13241	2020-02-23 12:26:34	2020-02-23	Nia Lehner-Keeling	nia.lehner.keeling@geemail.com	Anaheim	California	4576646525781	b175904c490b341ef0bf32b37a95c8a4	JCB 16 digit	33.8439435727726661	-117.733007205298534
13242	2020-02-23 12:50:17	2020-02-23	Jamison Schowalter	jamison.schowalter@geemail.com	Toledo	Ohio	639044679534402	acf4a77ab763cd09d01b7259e4f2f348	VISA 16 digit	41.7022780988536752	-83.527351161311941
13243	2020-02-23 12:51:13	2020-02-23	Syed Adams-Yundt	syed.adams.yundt@geemail.com	Salinas	California	210006865551315435	3c2e47d9ea224bdecfc891a30cd206bf	JCB 16 digit	36.7093178389359238	-121.615077768004312
13244	2020-02-23 13:10:15	2020-02-23	Kaitlynn Hartmann-Wilderman	kaitlynn.hartmann.wilderman@geemail.com	Costa Mesa	California	3088427951801832451	ec8d0ef3c7af7c7a3051e5521c5319cf	JCB 15 digit	33.6041375830318785	-117.979244054746999
13245	2020-02-23 13:11:01	2020-02-23	Shelby Oberbrunner	shelby.oberbrunner@geemail.com	Berkeley	California	52686808007979724	877c4258b85399fc8c75fa8ea23322c6	Voyager	37.8565524140279948	-122.271852635021588
13246	2020-02-23 13:16:07	2020-02-23	Mrs. Alexis Koelpin	mrs.alexis.koelpin@geemail.com	El Paso	Texas	4706142497149598	f454967470ab1635c33e241cad624538	Diners Club / Carte Blanche	31.833084816841037	-106.407424188356856
13247	2020-02-23 13:17:19	2020-02-23	Little Carroll	little.carroll@geemail.com	League City	Texas	4763611626602297	a9b296cf581c2529476e894c112d61de	VISA 16 digit	29.4545884301349545	-95.163592555884648
13248	2020-02-23 13:20:49	2020-02-23	Jerome Haley	jerome.haley@warmmail.com	San Bernardino	California	676297584566026	cf611acfd7452a87a3cb865feb0d15d1	Mastercard	34.0632124235186708	-117.280138046877823
13249	2020-02-23 13:22:39	2020-02-23	Bernice Bashirian	bernice.bashirian@geemail.com	Springfield	Massachusetts	4745086095999	2427c8fa20c611cca7403db562e00249	Diners Club / Carte Blanche	42.0467849754467551	-72.6294892409909636
13250	2020-02-23 13:23:14	2020-02-23	Yetta Wolf-Leffler	yetta.wolf.leffler@woohoo.com	Simi Valley	California	4851152259673	1bd5fce7a4b72333a6d4b6f6954d1505	Discover	34.3065592408418638	-118.789613826353104
13251	2020-02-23 13:32:03	2020-02-23	Miss Essa Braun	miss.essa.braun@geemail.com	Los Angeles	California	3052167868555546	36c4bfc34093c668e912903b88996d17	Maestro	33.9811873106151765	-118.406127863562844
13252	2020-02-23 13:37:43	2020-02-23	Nanci McCullough	nanci.mccullough@geemail.com	Columbus	Ohio	4032024163324	b670f64e180dc2c52cca61b0dcda5d16	VISA 13 digit	40.0741217247720769	-83.050696814130248
13253	2020-02-23 13:54:13	2020-02-23	Brynn Hamill	brynn.hamill@woohoo.com	San Francisco	California	503821999054634	d21caee0f0ae30699d89f0f1212b94d7	Maestro	37.7538418998801504	-122.410192448036142
13254	2020-02-23 14:00:13	2020-02-23	Otto Wyman	otto.wyman@woohoo.com	Berkeley	California	3096020819617595623	86eac25c3859e5290747627fffb94671	JCB 16 digit	37.8569693206829569	-122.264878597391814
13255	2020-02-23 14:02:06	2020-02-23	Gavin Mills-Hilll	gavin.mills.hilll@geemail.com	Baltimore	Maryland	3749117692162881	d1e30d419c8391ea1308440d4d59a064	JCB 15 digit	39.2537947459146324	-76.6987120284251915
13256	2020-02-23 14:15:32	2020-02-23	Paula Borer-Funk	paula.borer.funk@geemail.com	San Francisco	California	3010188817103792	b35e4652d4c09d3df8e49ead2808d24a	JCB 16 digit	37.7812431347920494	-122.40814576344583
13257	2020-02-23 14:16:53	2020-02-23	Gayla Jones	gayla.jones@woohoo.com	Boise	Idaho	4566500862826	36b9a9bc2239bb430d44b75f3cb8fc54	Discover	43.5176425832927265	-116.140950657260419
13258	2020-02-23 14:18:15	2020-02-23	Ms. Maritza Wintheiser	ms.maritza.wintheiser@geemail.com	Miami	Florida	4477812391944	ad9ff6c0a2e27f4d663657d685c3720c	VISA 13 digit	25.83383505927846	-80.128324463811154
13259	2020-02-23 14:18:16	2020-02-23	Tyreke Becker DVM	tyreke.becker.dvm@warmmail.com	Cary	North Carolina	869943571649657078	3eb0af1e0c61c1c9fa0af06a7b73517e	Diners Club / Carte Blanche	35.8649364797972154	-78.8300369231116065
13260	2020-02-23 14:27:42	2020-02-23	Dr. Virgel Waters II	dr.virgel.waters.ii@woohoo.com	Oakland	California	210064612957264877	ecd69ce4e29bf677f9a80cfe3c691f0d	Diners Club / Carte Blanche	37.7980860503851517	-122.267002264142334
13261	2020-02-23 14:34:05	2020-02-23	Jaydan Parisian	jaydan.parisian@warmmail.com	Pueblo	Colorado	3027610855844543	f8f5152e6148571f944ca8a81fd0ebad	American Express	38.3332023262023895	-104.691201095176126
13262	2020-02-23 14:44:34	2020-02-23	Rosalee Aufderhar-Morissette	rosalee.aufderhar.morissette@geemail.com	Wilmington	North Carolina	3780136402315993	43a718bdd1b8aa3da6f534241b658633	JCB 16 digit	34.1884535169050139	-77.9069743875872405
13263	2020-02-23 14:51:09	2020-02-23	Miss Tyra Kautzer	miss.tyra.kautzer@geemail.com	Tucson	Arizona	6011331151566079142	4ff1df446d81b1692b7209098aba8f2c	JCB 16 digit	32.216411204919595	-110.777110518537825
13264	2020-02-23 15:48:37	2020-02-23	Hunt Pollich	hunt.pollich@geemail.com	San Francisco	California	502004593437868	333c24422de1a8a1a423822c91ee7119	American Express	37.7635162725082125	-122.43108639262249
13265	2020-02-23 15:53:48	2020-02-23	Landon Steuber	landon.steuber@woohoo.com	Saint Paul	Minnesota	869962249832985210	cf1450ad7f38c0c14a4335384d6249f0	Mastercard	44.8894610841698949	-93.1780145953208176
13266	2020-02-23 16:04:50	2020-02-23	Dr. Kiyoshi Kuvalis Sr.	dr.kiyoshi.kuvalis.sr.@geemail.com	Glendale	California	4924363667768	dc31cdf138d89d715d1c8f350ce7d051	VISA 16 digit	34.0899762938484514	-118.167308836047724
13267	2020-02-23 16:06:38	2020-02-23	Victory Monahan DVM	victory.monahan.dvm@geemail.com	San Francisco	California	3440209478196453	d7f46f7a886fb7158497799dfadf967f	American Express	37.7949520536058969	-122.47428555843652
13268	2020-02-23 16:09:52	2020-02-23	Dion Murphy	dion.murphy@woohoo.com	Birmingham	Alabama	3528265647485774481	16e001443c1d209aac5b882843166046	JCB 16 digit	33.4655284289527657	-86.8499988264646419
13269	2020-02-23 16:48:19	2020-02-23	Moody McKenzie III	moody.mckenzie.iii@geemail.com	Birmingham	Alabama	6011657714074597933	cbf6367ebfb4858578d317a639e93e93	Mastercard	33.5080256887968631	-86.8913940519336734
13270	2020-02-23 16:59:07	2020-02-23	Miss Rubye Rogahn	miss.rubye.rogahn@geemail.com	West Jordan	Utah	4182226930317	14e773d45a0b7ed57025d8b4cbf40952	JCB 15 digit	40.5681936305739015	-111.963547293431304
13271	2020-02-23 16:59:31	2020-02-23	Lynda Green	lynda.green@geemail.com	San Francisco	California	4307522462980809	4d44a451239644f042f6f541f85324e4	Maestro	37.7659651057086307	-122.427877081362297
13272	2020-02-23 17:03:47	2020-02-23	Devon Towne PhD	devon.towne.phd@warmmail.com	Wilmington	North Carolina	869900966671309443	a50d9429aa141ab8686cf5f23fbe4da6	Mastercard	34.2671481675755274	-77.8253280557218972
13273	2020-02-23 17:09:48	2020-02-23	Jalisa Stokes	jalisa.stokes@geemail.com	Everett	Washington	060423602438626	843ae6f584274dec540bac9d41e0c24d	JCB 16 digit	47.9138702335659445	-122.098931978515907
13274	2020-02-23 17:14:16	2020-02-23	Ona Feeney-Johnson	ona.feeney.johnson@geemail.com	San Francisco	California	630471427789301	f6c237d6dea380a5d42f605a19a57c47	Diners Club / Carte Blanche	37.7643792938129366	-122.449463295009394
13275	2020-02-23 17:36:13	2020-02-23	Millie Windler DDS	millie.windler.dds@geemail.com	Berkeley	California	3054529407619166	3e9f0d5ed1225d26bb0e42a6f6a82ec9	JCB 16 digit	37.9041219782840884	-122.259661530270222
13276	2020-02-23 17:47:20	2020-02-23	Miss Unknown Jast DVM	miss.unknown.jast.dvm@geemail.com	Killeen	Texas	4753191968362943	8cb520fc12b4c1196d75be7b8bf5d989	VISA 16 digit	31.1709867567986265	-97.6400362918321036
13277	2020-02-23 18:00:50	2020-02-23	Miss Marlie Renner PhD	miss.marlie.renner.phd@woohoo.com	Atlanta	Georgia	589327244687136	0e0fbc31144d15366e4ddab1cd84a66d	Voyager	33.8547152519501751	-84.3716655323792253
13278	2020-02-23 18:00:56	2020-02-23	Tavares Anderson	tavares.anderson@geemail.com	San Francisco	California	869934531596203483	0ed5a435b53130c1351ef2985dee9980	JCB 16 digit	37.7919789567922351	-122.400456098804099
13279	2020-02-23 18:20:38	2020-02-23	Shepherd Homenick	shepherd.homenick@geemail.com	Elk Grove	California	3041082842549229	248a627d9ca3114f25cb7cfee84e8097	VISA 16 digit	38.3605423249121742	-121.42409317362123
13280	2020-02-23 18:43:13	2020-02-23	Jimmie Terry	jimmie.terry@warmmail.com	Milwaukee	Wisconsin	3020476513699662	c50b31d7e62fbd09615bea03ac38bcf1	VISA 13 digit	43.1205351434733686	-87.9699094203401444
13281	2020-02-23 18:56:21	2020-02-23	Kiana Beatty DVM	kiana.beatty.dvm@geemail.com	New York	New York	4267043002331	8dee6a29203c35535ad671b8b773b39a	Diners Club / Carte Blanche	40.7068989297132902	-73.8622429592896168
13282	2020-02-23 18:57:53	2020-02-23	Michial Cartwright	michial.cartwright@geemail.com	San Francisco	California	4720365591158	3642ef02d37978bfe0f65bce34404c4b	VISA 16 digit	37.7977233604917728	-122.444832616131393
13283	2020-02-23 19:40:45	2020-02-23	Dr. Georgina Ward PhD	dr.georgina.ward.phd@geemail.com	Mesquite	Texas	4372717314812	b43683f6eb3082143d80fe9790f60ed6	VISA 16 digit	32.7985665139086535	-96.6661597832769246
13284	2020-02-23 19:59:39	2020-02-23	Marlen Jones-Schowalter	marlen.jones.schowalter@geemail.com	Anaheim	California	502011632478548	71705a991e88d8f29a415ce31059190f	VISA 13 digit	33.9135590875819304	-117.810163764350477
13285	2020-02-23 20:00:44	2020-02-23	Asberry Greenholt	asberry.greenholt@woohoo.com	Los Angeles	California	6011173495676352811	e26abe75ac10f5bd413ab069135c4bb0	VISA 16 digit	34.0921709359955045	-118.356707914685074
13286	2020-02-23 20:10:41	2020-02-23	Mr. Fenton Boyer III	mr.fenton.boyer.iii@woohoo.com	Milwaukee	Wisconsin	4471577457888060	4dbc05ce46a55b03335ddb506454c1f6	VISA 16 digit	43.0807639232456694	-87.9084085872497383
13287	2020-02-23 20:37:00	2020-02-23	Norbert Osinski	norbert.osinski@geemail.com	Clarksville	Tennessee	4705602469593249	faa595eadf0969c5733f33e64d0eaa2f	Maestro	36.5007632821925014	-87.3910089111372912
13288	2020-02-23 21:02:58	2020-02-23	Abigayle Brekke	abigayle.brekke@warmmail.com	San Francisco	California	3337522254307106452	f9ae4f0b87f2c13b41e17012965395cc	JCB 16 digit	37.7916158033136611	-122.422379005582485
13289	2020-02-23 21:18:31	2020-02-23	Andrew Barrows	andrew.barrows@geemail.com	Berkeley	California	3032322825766443	25261e756a8e50244c7cf36a75207915	VISA 13 digit	37.8986385999645776	-122.249580452319435
13290	2020-02-23 21:23:04	2020-02-23	Ms. Valerie Cummings	ms.valerie.cummings@geemail.com	San Antonio	Texas	869997999404997261	e18d8c1dad062f2136d9e9c5f65fbba2	Diners Club / Carte Blanche	29.4452215152863417	-98.5991854613017296
13291	2020-02-23 21:31:27	2020-02-23	Lamarcus Wintheiser	lamarcus.wintheiser@geemail.com	Milwaukee	Wisconsin	3088043212077447308	61ef5c8a2bc8733e75c22a5a98b6e6d9	JCB 16 digit	43.0555104053199287	-87.9604433203216729
13292	2020-02-23 21:46:22	2020-02-23	Harden Schmeler	harden.schmeler@woohoo.com	Syracuse	New York	3158895043339587378	14966db496a161239c5dbdb2f701401a	VISA 13 digit	43.065635494640091	-76.2288915904950386
13293	2020-02-23 22:00:34	2020-02-23	Kylah Smitham	kylah.smitham@geemail.com	Sunnyvale	California	869907548651562523	caf861075369c71b33090db0d67cdf0f	Diners Club / Carte Blanche	37.3851286388926241	-122.108777366691456
13294	2020-02-23 22:48:44	2020-02-23	Dr. Leopold Schuppe I	dr.leopold.schuppe.i@warmmail.com	Philadelphia	Pennsylvania	3411325691278608	d91bc6ca7db588b9b04c62db06d1f855	VISA 16 digit	39.9919966689735631	-75.1037668503254707
13295	2020-02-23 23:04:33	2020-02-23	Dalvin Lebsack	dalvin.lebsack@geemail.com	Austin	Texas	6011446328504732840	3c93b7f3b2e1b5b0d7c006e7b472b91a	VISA 16 digit	30.2365203597243877	-97.7272744397871236
13296	2020-02-23 23:15:54	2020-02-23	Clyde Douglas	clyde.douglas@geemail.com	Columbus	Ohio	3774610201095236	2fa3734cee8bb07c9b2e6eb71a526d5c	Mastercard	40.0202544202141439	-82.8964824194323313
13297	2020-02-23 23:20:15	2020-02-23	Tayshaun Hamill	tayshaun.hamill@geemail.com	Hillsboro	Oregon	3039601990135309	a7920f5bdc7726092676ae1894f4733c	JCB 16 digit	45.4609784734640243	-122.986076514205706
13298	2020-02-23 23:22:45	2020-02-23	Ronny McGlynn MD	ronny.mcglynn.md@geemail.com	San Francisco	California	4814452716099	bf95caed0a924126b8bef26f29aed72c	Diners Club / Carte Blanche	37.8072103587415924	-122.451697154812337
13299	2020-02-23 23:23:23	2020-02-23	Newell Ratke	newell.ratke@geemail.com	Chicago	Illinois	676173792744465	b995ef57a07ad166a409fb952ec92e0d	Diners Club / Carte Blanche	41.8781947965104138	-87.7150301833201098
13300	2020-02-23 23:33:30	2020-02-23	Webster Davis	webster.davis@warmmail.com	Tucson	Arizona	55166860471197928	669c405db5c0b1b2dafcea3c87adc626	Mastercard	32.1884038576431593	-110.825674363434686
13301	2020-02-23 23:41:30	2020-02-23	Milton Sporer	milton.sporer@geemail.com	San Francisco	California	210070236612187950	95e3c88ff6d68fa09abd86ed7da6ff20	VISA 16 digit	37.7778972948152045	-122.468175065784294
13302	2020-02-23 23:58:47	2020-02-23	Dorthey Parisian	dorthey.parisian@geemail.com	Arlington	Texas	3158011891227226130	519bddb1ffeb8cc0cd684ed9d3ea365b	VISA 13 digit	32.6174483631521426	-97.1223123927161112
13303	2020-02-24 00:31:04	2020-02-24	Steven Cruickshank	steven.cruickshank@woohoo.com	Raleigh	North Carolina	210072088514969227	daa39893848b4ea02bbb0bd38475ffb9	VISA 16 digit	35.8403159727942153	-78.6741773568496114
13304	2020-02-24 00:35:03	2020-02-24	Berlin Sauer	berlin.sauer@geemail.com	Columbus	Ohio	3721733922245593	e3af186eaf99d0e68187d4b28b1fc732	JCB 16 digit	40.015242011057957	-82.9803898876301957
13305	2020-02-24 00:53:17	2020-02-24	Siobhan Shanahan	siobhan.shanahan@woohoo.com	Bakersfield	California	3088542841535070959	345f4bc82c8fa5b81161b5d15d0915b4	VISA 16 digit	35.3891607813246551	-118.988432687408476
13306	2020-02-24 01:01:08	2020-02-24	Otto Leuschke	otto.leuschke@geemail.com	Los Angeles	California	3096976108928901447	e225989b83a9830615827ced10fdd426	JCB 16 digit	34.0650319302786144	-118.491646987850956
13307	2020-02-24 01:09:37	2020-02-24	Ms. Deneen Smith	ms.deneen.smith@geemail.com	Oakland	California	54870857392819934	289ba7153a24aa2d87a9d7c5627e2930	VISA 13 digit	37.8055452801997447	-122.249134106350056
13308	2020-02-24 01:56:19	2020-02-24	Joshuah Ferry PhD	joshuah.ferry.phd@warmmail.com	Los Angeles	California	869908396279122034	f6dbcbaa5860d20a2dcd9aa40bd1ba46	Mastercard	33.94253854768872	-118.470449579972026
13309	2020-02-24 02:04:13	2020-02-24	Kyara Littel	kyara.littel@geemail.com	Kansas City	Missouri	3337157490214094124	8742d37c5cc44cdbcabb99f6d9f23223	VISA 16 digit	39.2008485690526669	-94.5392766322232774
13310	2020-02-24 02:06:58	2020-02-24	Mr. Jayce Anderson PhD	mr.jayce.anderson.phd@woohoo.com	Augusta	Georgia	6011054071048851543	974863795e5bfdb6ab53de71e743c951	VISA 16 digit	33.4137193146832274	-82.0517099108375731
13311	2020-02-24 02:11:30	2020-02-24	Gearld Thiel	gearld.thiel@geemail.com	Renton	Washington	3054169556864378	0c148b640b49df21e8c0600b25de897b	VISA 16 digit	47.3912493603363671	-122.112088921394189
13312	2020-02-24 02:14:42	2020-02-24	Cedric Kreiger	cedric.kreiger@geemail.com	Phoenix	Arizona	3112631363899040157	fbda52c4bd9e323aec74f73e49243924	Discover	33.6308077061947444	-111.992068973129989
13313	2020-02-24 02:19:51	2020-02-24	Mrs. Veva Veum DVM	mrs.veva.veum.dvm@geemail.com	Nashville	Tennessee	4469719231818690	d8e4e048bde18fdc6b42af09ecaf4c05	VISA 13 digit	36.1729722600553174	-86.8384621963277397
13314	2020-02-24 02:24:43	2020-02-24	Mrs. Tessie Larkin MD	mrs.tessie.larkin.md@woohoo.com	Garden Grove	California	3337168272153853281	771095516cde54f1fe309a5c1b95ff5d	Voyager	33.7653118614397911	-117.976714425582429
13315	2020-02-24 02:32:18	2020-02-24	Mrs. Cappie Feil MD	mrs.cappie.feil.md@geemail.com	Eugene	Oregon	3528171440214582687	685ee7eff474c23e1d5ac37eed6b5cfd	VISA 16 digit	44.1356963430725031	-123.178657355996606
13316	2020-02-24 02:46:49	2020-02-24	Tad Schmeler Jr.	tad.schmeler.jr.@warmmail.com	Arlington	Texas	4769483836532	d193bc437f5c3e0d4399a826a4a8e092	Discover	32.7717353749804161	-97.043693241619323
13317	2020-02-24 03:01:29	2020-02-24	Crista Dickinson	crista.dickinson@warmmail.com	Oakland	California	4960799997834010	eba010ced7a8bf7d5f9e1e2b082e5788	JCB 15 digit	37.8278260395109385	-122.23739254646209
13318	2020-02-24 03:13:47	2020-02-24	Destini Wiegand	destini.wiegand@warmmail.com	Arlington	Texas	3029855803647492	657e6b619bd0af96f284977c09e63c73	VISA 13 digit	32.6360142295498363	-97.0394634110413534
13319	2020-02-24 03:17:35	2020-02-24	Ms. Valerie Stroman DDS	ms.valerie.stroman.dds@geemail.com	San Francisco	California	3096902289101767539	67289c703b37dcb47c38e313f9549e4c	JCB 16 digit	37.7590520239609546	-122.445491253578041
13320	2020-02-24 04:20:28	2020-02-24	Elder Dooley	elder.dooley@geemail.com	Berkeley	California	676209869505546	c3554443bb6373eef9b8e0666e397e40	VISA 13 digit	37.8787942091932663	-122.244297671152395
13321	2020-02-24 04:42:24	2020-02-24	Maxwell Champlin	maxwell.champlin@geemail.com	Baltimore	Maryland	6011407060769622815	a800653dda6eb4a93a671b8651573ec9	VISA 16 digit	39.2665268458891603	-76.6607614959143149
13322	2020-02-24 05:08:25	2020-02-24	Ms. Audie Morissette DVM	ms.audie.morissette.dvm@warmmail.com	Chesapeake	Virginia	4415180210940	209cdcfa7637fea9584ca0e83f28c5e4	VISA 13 digit	36.6563110924098652	-76.2555480016238931
13323	2020-02-24 05:12:29	2020-02-24	Alba Hand	alba.hand@warmmail.com	Laredo	Texas	54462264368780998	9dc47125f56e927b99c6406db4d19f63	Voyager	27.4876950072772814	-99.5018088668126524
13324	2020-02-24 05:18:26	2020-02-24	Dr. Gidget Davis	dr.gidget.davis@geemail.com	San Francisco	California	3088271071279630498	6dd36f16c84fad292c3266f59f7ec35d	Diners Club / Carte Blanche	37.7571658218878312	-122.466843126815604
13325	2020-02-24 05:32:43	2020-02-24	Kelsie Pfeffer	kelsie.pfeffer@geemail.com	Oakland	California	869947933435807430	7eeac388947184dfb2303dd24015bed6	Mastercard	37.8105284940064621	-122.277384278329123
13326	2020-02-24 05:44:41	2020-02-24	Sheryll Wintheiser-Donnelly	sheryll.wintheiser.donnelly@geemail.com	Tampa	Florida	180081274453783089	c32967fcf26426f33d6fc67a87df91f0	Mastercard	27.9890041456673266	-82.4989596209701119
13327	2020-02-24 05:50:44	2020-02-24	Dr. Meryl Heaney DDS	dr.meryl.heaney.dds@warmmail.com	St. Petersburg	Florida	3027589654281760	faa9e0228d3fc04d6b93065fe4220b9f	VISA 16 digit	27.7303860349468891	-82.5467544960215633
13328	2020-02-24 05:51:58	2020-02-24	Keisha Dooley	keisha.dooley@geemail.com	San Francisco	California	3439009340995030	80b7d0932027756a1af0d425b6ad1719	VISA 16 digit	37.7395601892239654	-122.422127805915181
13329	2020-02-24 05:52:40	2020-02-24	Dayna Beatty	dayna.beatty@woohoo.com	Spokane	Washington	3088888256083044979	793f29af27a44ef7530c9dc2b6e975c4	Mastercard	47.7470336022559536	-117.347837068456414
13330	2020-02-24 06:03:32	2020-02-24	Elianna Hammes	elianna.hammes@geemail.com	New York	New York	4312230358678163	42512f42433b11932b0404f106194a5a	VISA 16 digit	40.7239024915955952	-73.9977366872958839
13331	2020-02-24 06:08:28	2020-02-24	Nyah Hoppe	nyah.hoppe@woohoo.com	Houston	Texas	3158050254239065602	71cd6e966f2cd9143110b4900140c32d	Maestro	29.7168336687687784	-95.3696744385190271
13332	2020-02-24 06:09:48	2020-02-24	Julian Purdy	julian.purdy@warmmail.com	Evansville	Indiana	6011533299953105537	da1008c4670e37a1313a9e879a779e1e	VISA 16 digit	38.0632902063101497	-87.5988081857960736
13333	2020-02-24 06:15:43	2020-02-24	Dr. Boston Reinger	dr.boston.reinger@woohoo.com	Temecula	California	676265506078669	48b2d28dc46ec4c29c60f2fdda15f9ea	Diners Club / Carte Blanche	33.5314104603271943	-117.204620343093566
13334	2020-02-24 06:22:59	2020-02-24	Mr. Javier Miller I	mr.javier.miller.i@geemail.com	San Francisco	California	4794586183701331	bda4b49f95ecd000844130c8518a66c8	VISA 13 digit	37.7825831274441626	-122.442921613039218
13335	2020-02-24 06:27:47	2020-02-24	Allan Farrell-Kertzmann	allan.farrell.kertzmann@warmmail.com	Oakland	California	4243659590073268	d7d34f5556ea6e51aa378229c08271b4	JCB 16 digit	37.7800888092478502	-122.229858014353994
13336	2020-02-24 06:39:32	2020-02-24	Mrs. Shiela Emard	mrs.shiela.emard@geemail.com	Anchorage	Alaska	3057421045151330	132cc56978b51319c6d8415041007405	Discover	61.2672926260374524	-149.356345835712915
13337	2020-02-24 06:46:36	2020-02-24	Audie Fahey	audie.fahey@geemail.com	San Francisco	California	869978788679254612	a8c40d7a7f759821500803559bca2f67	Maestro	37.8226113423153265	-122.402411812183203
13338	2020-02-24 06:48:46	2020-02-24	Cristian Murazik-Collier	cristian.murazik.collier@geemail.com	Peoria	Arizona	6011624658559777132	ad8e7442f2d73d93bbdbdb5f1b2ca233	JCB 15 digit	33.7334186911851148	-112.299564037697394
13339	2020-02-24 06:59:44	2020-02-24	Altie Thiel-Berge	altie.thiel.berge@geemail.com	Jersey City	New Jersey	060429263918566	ae0a35ef167c21236b38e8b6ab54e3c3	JCB 16 digit	40.7433511052686725	-74.1275402478363361
13340	2020-02-24 07:00:48	2020-02-24	Chiquita Maggio	chiquita.maggio@geemail.com	Richmond	Virginia	4905047484084	fb5e2f192a8ec7f2ad30161c1dd26ac9	Discover	37.4910933064516598	-77.4791086004804868
13341	2020-02-24 07:22:22	2020-02-24	Aric Walsh-Crist	aric.walsh.crist@woohoo.com	Las Vegas	Nevada	4002465084630329	6c892bc5670d15ce9d8060162714e454	VISA 16 digit	36.2105096388708816	-115.28059571755341
13342	2020-02-24 08:07:49	2020-02-24	Infant Schoen	infant.schoen@geemail.com	San Francisco	California	4682221340606489	6de079c03bfd708ca87465267a0b56d1	JCB 16 digit	37.7909942780351784	-122.386087233212294
13343	2020-02-24 08:11:19	2020-02-24	Leslie Lesch	leslie.lesch@warmmail.com	Greensboro	North Carolina	4632507155209182	4faf7a47299e25dc9bb21c6453f64f90	VISA 16 digit	36.0005831951391002	-79.8631698600929241
13344	2020-02-24 08:38:12	2020-02-24	Mr. Loyal Wisozk V	mr.loyal.wisozk.v@geemail.com	Detroit	Michigan	501877240257426	0af23063a48ccc057ef9d36eb0301dda	VISA 16 digit	42.3897534147761803	-83.1020095734976252
13345	2020-02-24 08:49:08	2020-02-24	Mrs. Kaylynn Marks	mrs.kaylynn.marks@warmmail.com	New Orleans	Louisiana	4904525368209295	5a29137fe8f2a4d8253dc1b8403c5b63	Maestro	30.0390046133674673	-89.8456702899448629
13346	2020-02-24 08:51:53	2020-02-24	Belinda Hane	belinda.hane@geemail.com	Meridian	Idaho	3112480810560213457	ed79904c7ca967b040e959e7a46e9ab0	Voyager	43.5932112903341604	-116.304380100819841
13347	2020-02-24 09:01:48	2020-02-24	Ms. Shanelle Heaney	ms.shanelle.heaney@woohoo.com	Spokane	Washington	6011535388817246583	d947b7456350169bb777bc10f516d26a	Mastercard	47.7201359621953216	-117.461473831384637
13348	2020-02-24 09:16:26	2020-02-24	Lyn Green	lyn.green@geemail.com	San Antonio	Texas	3337409297812424082	4366a3ae51bbb4aedebaaf4eeb30a2d6	American Express	29.5569316353719671	-98.5135576197713618
13349	2020-02-24 09:26:07	2020-02-24	Cherelle Block	cherelle.block@geemail.com	San Francisco	California	4107276380463735	33ab03918691670caaa70663234855fd	Mastercard	37.7610760860003865	-122.452614654278676
13350	2020-02-24 10:12:08	2020-02-24	Ossie Jerde PhD	ossie.jerde.phd@geemail.com	Chicago	Illinois	6011408670355519115	9d62474ca867ad5a2d6a937ad197347b	JCB 15 digit	41.916424399830774	-87.7454054387316091
13351	2020-02-24 10:28:24	2020-02-24	Bina Jast	bina.jast@geemail.com	New York	New York	3704945644590434	6a7cff236fa33c7fca481045b4a40c34	American Express	40.6656702826954444	-74.031456775766614
13352	2020-02-24 10:29:31	2020-02-24	Hillery Stroman	hillery.stroman@geemail.com	Chula Vista	California	869978314255972178	9b9504dff1c35687c16b6eeaf20166f7	VISA 13 digit	32.5393625871043639	-116.9845739588838
13353	2020-02-24 10:57:57	2020-02-24	Ms. Tammy Olson	ms.tammy.olson@woohoo.com	Cary	North Carolina	4679864330130	3ec73b67c5ce7d1f0ef007889a070ed2	Mastercard	35.8208754145648385	-78.7811433695808034
13354	2020-02-24 11:03:43	2020-02-24	Ashlee Waelchi-Bernhard	ashlee.waelchi.bernhard@geemail.com	Chicago	Illinois	6011017280142898229	bdf4fef838f4e1ec0fbe2fac0dbc03b4	JCB 16 digit	41.869480418164656	-87.7571160960972207
13355	2020-02-24 11:05:26	2020-02-24	Hayward Senger	hayward.senger@geemail.com	Riverside	California	3008085315995459	7b0ad5d6e21902004a37d1d470e1f755	JCB 16 digit	33.901399814565103	-117.363773174441221
13356	2020-02-24 11:38:05	2020-02-24	Mrs. Rihanna Pollich	mrs.rihanna.pollich@geemail.com	Miami	Florida	4566515407856684	c4e45e618b1fca99a649dde33a2e6a34	VISA 16 digit	25.7556110489785688	-80.2411197411235406
13357	2020-02-24 11:46:57	2020-02-24	Noble Lowe II	noble.lowe.ii@geemail.com	Montgomery	Alabama	4754158908060449	270b96620bfda14361451c4a95b30f5b	Discover	32.2862143252443516	-86.3305230872392571
13358	2020-02-24 11:53:10	2020-02-24	Ms. Riya Ziemann DDS	ms.riya.ziemann.dds@geemail.com	San Francisco	California	3158563262356227731	068d5f39c08ab8f522729a1cc17d5af2	Discover	37.7492483780451096	-122.406010696445108
13359	2020-02-24 11:53:30	2020-02-24	Bobbye Skiles	bobbye.skiles@geemail.com	San Francisco	California	4458580068310	9f9d2620de31261d105ae41d5c82bdc6	Maestro	37.7722137472580499	-122.44121942134008
13360	2020-02-24 11:56:11	2020-02-24	Doyle Metz Jr.	doyle.metz.jr.@geemail.com	Bellevue	Washington	6011366234687168230	01865d6bb30641aa11c1e33d1ef455dd	Discover	47.5043490292221335	-122.21485307664237
13361	2020-02-24 12:00:41	2020-02-24	Jeff Prosacco	jeff.prosacco@geemail.com	Las Vegas	Nevada	676324549925436	19d039320427f800c7451ee336906391	JCB 15 digit	36.1428026766151191	-115.280181743318579
13362	2020-02-24 12:02:00	2020-02-24	Vander Schuppe	vander.schuppe@woohoo.com	Seattle	Washington	3112691286315494624	bed46b478560f87121fb90a183d4d033	VISA 16 digit	47.6036635073758632	-122.388101342964546
13363	2020-02-24 12:35:08	2020-02-24	Diamond Tremblay	diamond.tremblay@geemail.com	Phoenix	Arizona	4371652072533796	edb3e2d746aac498a2cddbca57dda8e0	Discover	33.5447349286105521	-112.173171283251051
13364	2020-02-24 12:50:26	2020-02-24	Dr. Emmer Koch DVM	dr.emmer.koch.dvm@geemail.com	San Francisco	California	3112762790623927401	491fb1c57dbd17f0f2c50efb15256e6a	American Express	37.7597672252443957	-122.411636196182414
13365	2020-02-24 12:50:52	2020-02-24	Dr. Hartwell Fritsch	dr.hartwell.fritsch@woohoo.com	West Covina	California	180075435215779768	00f083c28c289774bd5947d21ff0becc	JCB 16 digit	33.9789650635901879	-117.812540713797873
13366	2020-02-24 12:51:42	2020-02-24	Lorraine Marvin PhD	lorraine.marvin.phd@geemail.com	Chicago	Illinois	869940628932930571	53e5f8189fd2688c1e2689f58abf295c	Mastercard	41.8726081377662709	-87.7745722313906924
13367	2020-02-24 13:12:45	2020-02-24	Alexia Runte	alexia.runte@warmmail.com	Louisville	Kentucky	060440913731531	a0690d9f0c3b85957203680f4046dcdd	VISA 16 digit	38.1084697999428954	-85.5581159050647244
13368	2020-02-24 13:17:32	2020-02-24	Dr. Frederick Stroman DDS	dr.frederick.stroman.dds@woohoo.com	Chicago	Illinois	561222247326048	ccfaa6e9082e01f9276eac04c28fd936	VISA 16 digit	41.8496435638818909	-87.6517438486248182
13369	2020-02-24 13:18:33	2020-02-24	Jahiem Cremin	jahiem.cremin@geemail.com	Phoenix	Arizona	869924081979172766	921f44b276fdea114cc8cf936cf032c1	VISA 13 digit	33.5531195836074687	-112.038661871470893
13370	2020-02-24 13:19:01	2020-02-24	Vernetta Pollich	vernetta.pollich@geemail.com	San Francisco	California	6011270632255884697	9e1cdf472ca5207f287eeed2d83824e8	JCB 16 digit	37.7318138130063616	-122.404497641733741
13371	2020-02-24 13:41:18	2020-02-24	Larae Bartoletti	larae.bartoletti@warmmail.com	Richardson	Texas	4659809993507	de6d8e680bd2fdeea29674d08bbbe4a0	American Express	32.9349030845101893	-96.7731292296893884
13372	2020-02-24 13:54:59	2020-02-24	Dr. Vlasta Veum MD	dr.vlasta.veum.md@geemail.com	Charlotte	North Carolina	501850515783236	b3da0f34615244d764e574e5669808de	JCB 16 digit	35.1345204621341054	-80.8853505367357286
13373	2020-02-24 13:58:08	2020-02-24	Dr. Cael Erdman DDS	dr.cael.erdman.dds@woohoo.com	New York	New York	4741022636732560	7ec3fbbbb5012579e3dca579820606a1	Voyager	40.6096826749611637	-73.876902166464177
13374	2020-02-24 14:37:37	2020-02-24	Mr. Lovell Harber Sr.	mr.lovell.harber.sr.@geemail.com	New York	New York	210076407266456330	dd7fee364f3c118492734f6ac8c136df	VISA 16 digit	40.5682068634536108	-73.8578006509121536
13375	2020-02-24 14:44:52	2020-02-24	Mr. Brandan Greenfelder	mr.brandan.greenfelder@geemail.com	Houston	Texas	180024069337969460	8cd5a54e4af4afb706c06969482bf00c	Maestro	29.7981394216496511	-95.3284648396089693
13376	2020-02-24 15:09:46	2020-02-24	Lannie Rodriguez PhD	lannie.rodriguez.phd@warmmail.com	Anchorage	Alaska	4058073962708424	ba77fe8774f3d8e009b1e83b25cd811f	Diners Club / Carte Blanche	61.1692111140333168	-149.328585673554983
13377	2020-02-24 15:11:25	2020-02-24	Ms. Ivonne Reichert	ms.ivonne.reichert@geemail.com	San Antonio	Texas	180006376848783187	4ed08231d4df2dd4213fb232773ab165	Voyager	29.3979596175324183	-98.583552332857991
13378	2020-02-24 15:30:33	2020-02-24	Paige Steuber	paige.steuber@warmmail.com	Santa Clarita	California	3015936690624762	ffe022d43e8dcce0228fbe1c9980b4b3	Discover	34.4240492629557835	-118.475137456516549
13379	2020-02-24 15:39:12	2020-02-24	Delphine Barrows	delphine.barrows@woohoo.com	Pearland	Texas	3112093782300522126	0be274c8153a563c6c99983faa1d8d64	American Express	29.5460392948512016	-95.4122258849762375
13380	2020-02-24 15:59:17	2020-02-24	Brittney Lockman	brittney.lockman@geemail.com	Nashville	Tennessee	3112530695697264675	cdc6535fd367686b9598e0362339be84	Maestro	36.2650599097024653	-86.7363811723794811
13381	2020-02-24 16:02:47	2020-02-24	Dr. Morris Bartoletti V	dr.morris.bartoletti.v@geemail.com	Santa Clara	California	210006858483339078	022f7fe74d8e7eccdaa3c4501a7d7d80	VISA 16 digit	37.431701934039971	-121.904862442193178
13382	2020-02-24 16:05:07	2020-02-24	Miss Felice West DVM	miss.felice.west.dvm@geemail.com	Hialeah	Florida	180009267652080215	ea96346e4f554ace5e45177129124489	JCB 15 digit	25.9264480203367782	-80.297060282704976
13383	2020-02-24 16:12:27	2020-02-24	Dr. Derrick D'Amore Jr.	dr.derrick.d'amore.jr.@woohoo.com	Philadelphia	Pennsylvania	4349666613175478	fd6630133e31198b0afd59305d736655	VISA 16 digit	39.9587014434818144	-75.0386328509908225
13384	2020-02-24 16:18:05	2020-02-24	Mrs. Cecily Kemmer PhD	mrs.cecily.kemmer.phd@geemail.com	Reno	Nevada	4381901458691274	4788d75dfe97ee5161d832d542c09efd	Mastercard	39.5674929372113198	-119.7799143276807
13385	2020-02-24 16:37:40	2020-02-24	Duane Turner	duane.turner@geemail.com	Sparks	Nevada	4070113923798843	68a02f769cf681fe949dba51c9a860f4	American Express	39.6469903886556665	-119.677436277395486
13386	2020-02-24 16:47:05	2020-02-24	Anne Stroman	anne.stroman@warmmail.com	San Francisco	California	51441569630725324	5719cf91a249af4487d5dcfefa906e8d	Diners Club / Carte Blanche	37.7956746873477343	-122.426886241183183
13387	2020-02-24 16:58:27	2020-02-24	Docia Fritsch	docia.fritsch@woohoo.com	Virginia Beach	Virginia	3477320871583712	77629fde19cb5b618722921f8fdbfac0	Voyager	36.7930404898896839	-75.9285502161502848
13388	2020-02-24 17:14:13	2020-02-24	Keagan Jerde	keagan.jerde@warmmail.com	Fort Collins	Colorado	54582015792160594	2ccd1a78e8f10789f3d167bd3f0a0c08	Discover	40.5886517913237199	-105.022350725340843
13389	2020-02-24 17:20:59	2020-02-24	Alicia Herman	alicia.herman@warmmail.com	San Francisco	California	3096258175558954805	f9045dd3a8ed5a0a5b750509037259fe	American Express	37.7967978152737771	-122.434542916257712
13390	2020-02-24 17:22:14	2020-02-24	Adriana Morissette MD	adriana.morissette.md@geemail.com	New York	New York	3748115524047040	1cf97131b1b6b53d67e290d902e09eda	Voyager	40.6270788118001036	-74.0015790647722724
13391	2020-02-24 18:05:51	2020-02-24	Gwen Gorczany	gwen.gorczany@geemail.com	San Francisco	California	502045648131717	fd72e4907f40eeb41d5e1dbe5900983a	JCB 16 digit	37.7829694765534114	-122.422377549561034
13392	2020-02-24 18:09:31	2020-02-24	Kaleena Gaylord	kaleena.gaylord@geemail.com	Mesquite	Texas	3481231225062937	4d95ee1992e45f4fde9aed76ac18a04c	JCB 16 digit	32.6673590301811743	-96.6454663025878489
13393	2020-02-24 18:23:42	2020-02-24	Mrs. Ilda Berge	mrs.ilda.berge@woohoo.com	Anaheim	California	180085073679901533	391238add4ac7c5b49b0a66f1a11d176	VISA 13 digit	33.7584451218899346	-117.690958752317727
13394	2020-02-24 18:55:40	2020-02-24	Brittani Batz	brittani.batz@woohoo.com	Arvada	Colorado	869966195384759550	a1d65d5f61763608114b3e00012962a9	American Express	39.8120439998514968	-105.228368966232239
13395	2020-02-24 19:03:32	2020-02-24	Leatha Kshlerin	leatha.kshlerin@warmmail.com	Pembroke Pines	Florida	4235046496250754	cb02e9a35a9252dcaba8ebfacfd4cbb9	JCB 16 digit	25.9694689075499774	-80.3265456185579296
13396	2020-02-24 19:12:01	2020-02-24	Oddie Volkman	oddie.volkman@geemail.com	New York	New York	3096512820358774000	375fed4d0e7c07e187ac9c28aa5ba74d	Diners Club / Carte Blanche	40.674353945510461	-73.897360201542071
13397	2020-02-24 19:14:26	2020-02-24	Georgianna Runolfsdottir DVM	georgianna.runolfsdottir.dvm@geemail.com	Houston	Texas	4228208427548362	8b361d7e8a9f7aec5da651aef5d07a7b	VISA 16 digit	29.7043895781118437	-95.4254667524263311
13398	2020-02-24 19:19:22	2020-02-24	Truman Jast-Legros	truman.jast.legros@woohoo.com	Los Angeles	California	869936768628578825	fe98913d2b534f2b8c8264e357a6e2f6	Discover	34.0885042867023458	-118.376736424443493
13399	2020-02-24 19:19:23	2020-02-24	Weldon Smith	weldon.smith@geemail.com	New York	New York	3088676666463871583	13d3e7f9eb934f1ccf4a8ebd8da6e059	VISA 13 digit	40.7559482097849255	-74.0277331699512899
13400	2020-02-24 19:22:24	2020-02-24	Tiera Harvey	tiera.harvey@woohoo.com	San Francisco	California	3023028010593398	addd624f6e1f0d38681b185b4be5eea5	Diners Club / Carte Blanche	37.7308903813690861	-122.439310204757803
13401	2020-02-24 19:39:13	2020-02-24	Tyrek Hills	tyrek.hills@woohoo.com	Antioch	California	54265224616612764	1553567a444e77407622c59e36efc867	JCB 15 digit	37.893982470341399	-121.859101114765551
13402	2020-02-24 19:53:48	2020-02-24	Virge Lowe	virge.lowe@woohoo.com	Sterling Heights	Michigan	4989956002136420	56bc8e5a0283acc11052f09c32776d50	Mastercard	42.6068835869047788	-82.9854007199566723
13403	2020-02-24 19:54:36	2020-02-24	Mateo Renner-Rutherford	mateo.renner.rutherford@geemail.com	San Antonio	Texas	502070287341674	7179522de5e12cdfc2b1376f4097eae8	Mastercard	29.5194606245566149	-98.5034029644750007
13404	2020-02-24 20:01:35	2020-02-24	Harlene Bode	harlene.bode@geemail.com	Thornton	Colorado	3528896580317528006	dbced3ef792b95337054f9f88de9422e	JCB 16 digit	39.8951349589373976	-104.969703701853007
13405	2020-02-24 20:06:00	2020-02-24	Linus Beahan	linus.beahan@geemail.com	Memphis	Tennessee	52807643205992979	fd9eb333a0d6d9f214951a7c3317f194	Diners Club / Carte Blanche	35.0300004854865392	-89.9483158945363073
13406	2020-02-24 20:39:14	2020-02-24	Miss Oneida Bernier	miss.oneida.bernier@geemail.com	San Mateo	California	4457308469192004	4b143112ec155810eb3c4c012c582dee	VISA 13 digit	37.5473994350872928	-122.360122752128532
13407	2020-02-24 20:45:31	2020-02-24	Zed Shields	zed.shields@geemail.com	Nashville	Tennessee	869908606531637128	bfffa74b14dd3a1863bf77cdcee34df3	Maestro	36.1528130945872519	-86.858947061179208
13408	2020-02-24 20:54:08	2020-02-24	Alvis Hilll	alvis.hilll@geemail.com	Arlington	Texas	4256713040368440	1caeae39bcdb76a4c0ed0ca1a20222b4	Voyager	32.6693383814550913	-97.0593398136578571
13409	2020-02-24 20:57:11	2020-02-24	Solon Barton	solon.barton@woohoo.com	Atlanta	Georgia	4170993627831001	f1024d7e71cf327acff0bf062628e545	VISA 16 digit	33.6903092493113121	-84.3983540955044447
13410	2020-02-24 21:14:49	2020-02-24	Maribeth Wilderman-Schimmel	maribeth.wilderman.schimmel@warmmail.com	San Francisco	California	3088469770085482513	e80998fe35312cca8c41c227991744f0	Diners Club / Carte Blanche	37.7779805928555277	-122.44803667211292
13411	2020-02-24 21:17:02	2020-02-24	Dr. Chandler Bogisich III	dr.chandler.bogisich.iii@woohoo.com	Las Vegas	Nevada	502066453149396	cebb3a700ba6684acf27b92495425c06	Voyager	36.201915093567969	-115.216653325988347
13412	2020-02-24 21:18:17	2020-02-24	Alla Gerlach	alla.gerlach@geemail.com	New York	New York	6011660967730135481	089a391a379630a3e2e488c943b4dd7a	JCB 16 digit	40.5658853593505881	-73.8407017077214931
13413	2020-02-24 21:23:20	2020-02-24	Darci Nitzsche	darci.nitzsche@warmmail.com	New York	New York	6011731544042355191	3137b0612efef3edf6fb8f20fd583640	Discover	40.6863361816611118	-73.903292950791112
13414	2020-02-24 21:24:03	2020-02-24	Dennie Franecki	dennie.franecki@warmmail.com	Fremont	California	561298729717748	3db521ceb3a527d91092e5840108e922	JCB 16 digit	37.4991866821125157	-121.993607969208426
13415	2020-02-24 21:43:44	2020-02-24	Dixie Reilly	dixie.reilly@warmmail.com	Las Vegas	Nevada	4133441015251	3312aac571ecb2244d5d8ae08e02d19e	Voyager	36.133137134984878	-115.264139274994278
13416	2020-02-24 21:53:35	2020-02-24	Logan McDermott-Sauer	logan.mcdermott.sauer@warmmail.com	Torrance	California	4431773243862647	8492c96a3529de006ed1e91defe642ae	Voyager	33.7899807673320183	-118.324367876968893
13417	2020-02-24 22:04:14	2020-02-24	Morgan Greenholt I	morgan.greenholt.i@warmmail.com	Los Angeles	California	3337003475448021973	60b1805991ce06fccf511e1d3b3b94b5	Mastercard	34.0300539329979514	-118.370842616259296
13418	2020-02-24 22:06:08	2020-02-24	Dr. Lilla Abbott DDS	dr.lilla.abbott.dds@woohoo.com	Elk Grove	California	676149167130936	73ae40f48637032abdfbaed421d504ad	JCB 16 digit	38.4274309391438962	-121.350738545125353
13419	2020-02-24 22:20:38	2020-02-24	Dequan Volkman-Prohaska	dequan.volkman.prohaska@geemail.com	Coral Springs	Florida	4780937886098	c27c0ea8203971f080b5492e01e9026e	JCB 16 digit	26.2150848301656545	-80.2996337905183424
13420	2020-02-24 22:22:04	2020-02-24	Aedan Kovacek	aedan.kovacek@geemail.com	Scottsdale	Arizona	4322787266772	705df74fb9f317ee405aa692d34bf4af	Maestro	33.6285016234155734	-111.852384730797624
13421	2020-02-24 22:26:55	2020-02-24	Mr. Isai Christiansen	mr.isai.christiansen@geemail.com	Thousand Oaks	California	3027508207665402	090cd1e1090bbade7b75c522d2d0608b	VISA 16 digit	34.2229806508675196	-118.941202402665098
13422	2020-02-24 23:03:46	2020-02-24	Dr. Charlottie Boyer MD	dr.charlottie.boyer.md@geemail.com	Charleston	South Carolina	3417385339985729	34583e9becfd0918cf1e928be6720730	Discover	32.7339681800916793	-79.9702828271929178
13423	2020-02-24 23:29:01	2020-02-24	Dr. Horacio Ruecker	dr.horacio.ruecker@geemail.com	San Francisco	California	180076934792739350	62b53fcf0a97faa28e196446b959e707	American Express	37.7490967092547152	-122.418853982550829
13424	2020-02-24 23:42:28	2020-02-24	Dr. Meda Bashirian	dr.meda.bashirian@warmmail.com	Fresno	California	53599112832460554	a51d380a20a6e09ad585fe81b9b3185a	VISA 16 digit	36.8057096570603548	-119.77476924803257
13425	2020-02-24 23:53:54	2020-02-24	Mohamed Bogan	mohamed.bogan@geemail.com	St. Louis	Missouri	869995041082450008	8704f9bc8bb3b7d06e1b8a920ae78969	JCB 15 digit	38.7233582898199558	-90.2778534499932164
13426	2020-02-25 00:21:26	2020-02-25	Jaron Sipes PhD	jaron.sipes.phd@warmmail.com	Columbia	South Carolina	3528340836727843795	f346f579205dac3e0635c5a5d56fd695	JCB 15 digit	33.94111821868308	-80.807424109198152
13427	2020-02-25 00:21:41	2020-02-25	Nakia Hirthe	nakia.hirthe@geemail.com	San Francisco	California	6011548300653552672	822cf27393071b0583dc2891e1ceb8f8	Mastercard	37.778000382271415	-122.411276047375495
13428	2020-02-25 01:15:59	2020-02-25	Mr. Alden Block	mr.alden.block@geemail.com	Long Beach	California	3528590243072140165	cfaf7e171e273dff45e04c1b1fa21537	JCB 16 digit	33.7609182876355902	-118.121141656737024
13429	2020-02-25 01:51:06	2020-02-25	Micaela O'Hara	micaela.o'hara@woohoo.com	San Francisco	California	869975377818796551	649e869f7fa769636dab8ebed2586514	VISA 13 digit	37.7572635608171083	-122.411263878766036
13430	2020-02-25 02:03:59	2020-02-25	Wellington Weber	wellington.weber@geemail.com	Torrance	California	4833046605800578	0b19d4e8cd4af8361dee71b8c4d55512	Maestro	33.7848332064133174	-118.374988340133427
13431	2020-02-25 02:15:37	2020-02-25	Mr. Arlis Ryan	mr.arlis.ryan@geemail.com	Washington	District of Columbia	3059259838163940	af57dd5d9f6c887f48623f505c8f664a	JCB 16 digit	38.878397326710072	-76.9606805891476569
13432	2020-02-25 02:37:50	2020-02-25	Miss Terese Willms MD	miss.terese.willms.md@geemail.com	Boston	Massachusetts	54995063352982479	b168b213a48096266942a7a8c7673323	JCB 16 digit	42.3211568883322187	-71.1056882359970359
13433	2020-02-25 02:43:47	2020-02-25	Lawanda Rogahn	lawanda.rogahn@geemail.com	Akron	Ohio	3713184027612842	70049b8a32b71c28009b49842eaa0d77	JCB 16 digit	41.0587074198592461	-81.4454449110511689
13434	2020-02-25 02:44:21	2020-02-25	Jorja Harber	jorja.harber@geemail.com	Tulsa	Oklahoma	3337451961812864715	d6dad8889701b85cf018d7bb781311fb	JCB 16 digit	36.1464194748453735	-95.9483163007955966
13435	2020-02-25 03:00:44	2020-02-25	Miss Maye Rau DVM	miss.maye.rau.dvm@geemail.com	Chicago	Illinois	3112716347917416448	322fbce3b825a49152eb7431eed4f793	VISA 16 digit	41.8267907500568796	-87.7414435876097514
13436	2020-02-25 03:05:32	2020-02-25	Devante Swaniawski	devante.swaniawski@geemail.com	New York	New York	4960459110988298	9d205ef2548aba9b48be408d895de932	JCB 16 digit	40.5771571224313234	-73.8462173784047309
13437	2020-02-25 03:14:23	2020-02-25	Kaitlin Bashirian	kaitlin.bashirian@geemail.com	Milwaukee	Wisconsin	561206826557008	8003ac94e78b74b0efbfc15aa4814474	Discover	43.0556070932738493	-87.9030744218833746
13438	2020-02-25 03:22:15	2020-02-25	Hence Renner	hence.renner@geemail.com	Athens	Georgia	869934863312891972	5b7884662d19d4ca4889d54376b11ac4	Discover	33.8992472018305193	-83.4186815914813309
13439	2020-02-25 03:26:06	2020-02-25	Miss Adeline Volkman DDS	miss.adeline.volkman.dds@geemail.com	Murrieta	California	3158271116075640470	47cb33fee27dc28d8366cc4ce820a8d1	Mastercard	33.529469401399048	-117.105530399819457
13440	2020-02-25 03:32:59	2020-02-25	Otto Predovic	otto.predovic@geemail.com	Omaha	Nebraska	3337606345549874649	0e386c76a5f84a5a79e231cf45494d91	Discover	41.2729776810068643	-95.9455971647635124
13441	2020-02-25 03:33:30	2020-02-25	Londyn Lind	londyn.lind@geemail.com	New York	New York	4958805591344589	85b00312279f0f061a93fe7e5f923e5d	American Express	40.7483778382409341	-73.8992596043169527
13442	2020-02-25 03:41:57	2020-02-25	Dr. Ofelia Leuschke PhD	dr.ofelia.leuschke.phd@geemail.com	Berkeley	California	6011062886300166078	e21ab4eb60fd774a68d32bb4ff456792	VISA 13 digit	37.8801534686254584	-122.270204084733322
13443	2020-02-25 03:43:57	2020-02-25	Tiarra Weimann	tiarra.weimann@warmmail.com	Oklahoma City	Oklahoma	4522785644610995	4a0c804fef53d2717d630c2d7f7b5373	VISA 16 digit	35.3814512424081613	-97.4377865070838425
13444	2020-02-25 04:13:30	2020-02-25	Jalon Howe	jalon.howe@warmmail.com	Portland	Oregon	52054960923062558	b181e13b7f368e331bbb9b808d88c69f	Mastercard	45.5336725161764733	-122.588708351505929
13445	2020-02-25 04:14:50	2020-02-25	Jaylin Hessel	jaylin.hessel@geemail.com	Boston	Massachusetts	4691737445995	76fb70b9f3f1be81c4d0d964c73021d9	JCB 15 digit	42.3738857753276861	-71.0693806151345342
13446	2020-02-25 04:15:59	2020-02-25	Hakim McDermott	hakim.mcdermott@geemail.com	Shreveport	Louisiana	3010494186708322	30911bb0c14eb0e999785fd1fce19a34	Discover	32.3692109281435663	-93.8672231256708471
13447	2020-02-25 04:18:22	2020-02-25	Lashunda Witting PhD	lashunda.witting.phd@geemail.com	Berkeley	California	210005322750161120	dc6b0532dac601ec17a842255d31c859	VISA 16 digit	37.9001134733635467	-122.295460260093606
13448	2020-02-25 04:38:05	2020-02-25	Belton Ward	belton.ward@geemail.com	Colorado Springs	Colorado	4029877237791	2272561943368fe0f04b331943bd4c82	JCB 16 digit	38.907498721410704	-104.705078089439127
13449	2020-02-25 05:27:30	2020-02-25	Rochelle Ebert	rochelle.ebert@geemail.com	Pasadena	California	869971473183788697	63736410efda274ce474f1e62bf70b94	JCB 15 digit	34.1189851900417409	-118.115693553658573
13450	2020-02-25 05:47:48	2020-02-25	Fenton O'Keefe	fenton.o'keefe@geemail.com	San Francisco	California	3777569914180114	b667c1e8e92a882fda4b061219ebdbb4	Diners Club / Carte Blanche	37.7607845611201185	-122.439625519632216
13451	2020-02-25 06:03:09	2020-02-25	Khloe Kuphal	khloe.kuphal@woohoo.com	Spokane	Washington	3034290860329955	d38e04e58278a934ddc5a14fc07bc047	Mastercard	47.6146235284633903	-117.522102715018391
13452	2020-02-25 06:30:14	2020-02-25	Dallin Kiehn-Schimmel	dallin.kiehn.schimmel@geemail.com	Denver	Colorado	4234691661469928	57dec44cb3d4c9c875433f89a83ff7a5	Maestro	39.6947147551510469	-104.869398455020416
13453	2020-02-25 06:32:00	2020-02-25	Aiyana Kuhic	aiyana.kuhic@woohoo.com	Dallas	Texas	869950361089638600	c562c23207ccdcd973f172b164c9e781	Voyager	32.702632478698348	-96.817706653844553
13454	2020-02-25 06:43:17	2020-02-25	Osvaldo Bernhard-Prosacco	osvaldo.bernhard.prosacco@warmmail.com	Raleigh	North Carolina	4023359685445	ec3fd9dd8bd07a6adacffc32eeba67a5	Diners Club / Carte Blanche	35.880863568386431	-78.5631878995738901
13455	2020-02-25 06:48:27	2020-02-25	Pamela Bosco	pamela.bosco@geemail.com	Seattle	Washington	869995307241588214	54b3cf22c21f8e0599a7095c941b463e	Discover	47.5429272630177451	-122.382193477863069
13456	2020-02-25 06:54:16	2020-02-25	Olof Macejkovic Jr.	olof.macejkovic.jr.@warmmail.com	Norwalk	California	676128703096389	8ca8d483b15a96dfc28bb404f8e3a6bb	JCB 15 digit	33.9925462714511895	-118.05040383981914
13457	2020-02-25 08:11:49	2020-02-25	Nanie Larkin	nanie.larkin@geemail.com	Oakland	California	869902652085264402	bf5d6a8f4ef31e6a2a6ac239d9c98926	Discover	37.7918132147882844	-122.255041385629966
13458	2020-02-25 08:20:54	2020-02-25	Gillian Harris	gillian.harris@woohoo.com	McKinney	Texas	4446934856274842	a729b6fa8e6401471d277c5ee93231ab	JCB 16 digit	33.1209801586475265	-96.6622509167362125
13459	2020-02-25 08:33:40	2020-02-25	Tevin DuBuque-Smitham	tevin.dubuque.smitham@geemail.com	San Francisco	California	3016937837757878	a65f7e9505a8df7f37a29cfefa004882	American Express	37.7917033786525991	-122.442341819754063
13460	2020-02-25 08:40:05	2020-02-25	Cathleen Ruecker	cathleen.ruecker@warmmail.com	Chicago	Illinois	4464710614247	bb0405a847a2c2adf5e8af9a01ea7065	VISA 16 digit	41.9223213532309984	-87.6873503771640372
13461	2020-02-25 08:48:12	2020-02-25	Fitzhugh Gerhold II	fitzhugh.gerhold.ii@geemail.com	San Francisco	California	3012219721421513	7fdee37523efc8f725cd18e3d2829b1d	VISA 16 digit	37.7890843820605653	-122.464495570034785
13462	2020-02-25 08:56:08	2020-02-25	Shelley Crist	shelley.crist@geemail.com	Wichita Falls	Texas	3426358857691150	ef2b3683a86b361134e5688234020ed4	VISA 16 digit	33.8506127257559442	-98.617581167855846
13463	2020-02-25 09:15:53	2020-02-25	Cristobal Davis	cristobal.davis@warmmail.com	San Francisco	California	3038435550888804	43d0fe6d830126b18253de4fa12b6140	VISA 16 digit	37.7549802524724143	-122.424649125374714
13464	2020-02-25 09:20:32	2020-02-25	Milo Murphy DVM	milo.murphy.dvm@geemail.com	San Francisco	California	4060451150064634	5d80239291a740dc84640b418d22b740	VISA 16 digit	37.7838702373001851	-122.390126636597884
13465	2020-02-25 09:25:11	2020-02-25	Dr. Dillie Kutch	dr.dillie.kutch@geemail.com	Springfield	Missouri	4491305652712380	bca0daf82b866d6a97319ca4ffbd1cf4	Mastercard	37.1305325657788714	-93.3232192757364487
13466	2020-02-25 09:39:05	2020-02-25	Mr. Jered Collier	mr.jered.collier@geemail.com	Winston–Salem	North Carolina	4985407384959	436c6d5b2b1767266f4d55f52699b57e	Voyager	36.161604567547144	-80.1671404135078092
13467	2020-02-25 09:52:35	2020-02-25	Kanesha McDermott	kanesha.mcdermott@geemail.com	San Francisco	California	869926996077613551	b3ca4447394406ba9766f17ea9a0d0fa	VISA 13 digit	37.7807512014485454	-122.412272729290152
13468	2020-02-25 09:57:02	2020-02-25	Jude Donnelly	jude.donnelly@geemail.com	Austin	Texas	4546571953027027	1fb1329c498b4df2d0a6f8bd3e2c524e	Mastercard	30.2158026157539332	-97.7343042938277193
13469	2020-02-25 09:58:07	2020-02-25	Dr. Leonce Miller MD	dr.leonce.miller.md@geemail.com	Saint Paul	Minnesota	51002238636223749	f5511b82096b79be97a04e3cfc7a0527	JCB 16 digit	44.9906837367858756	-93.0857720207687436
13470	2020-02-25 10:11:58	2020-02-25	Margarito Block	margarito.block@geemail.com	New York	New York	180051667113722254	3d7a152090c34100f97005cc9fa6fc06	VISA 16 digit	40.6281914863027609	-73.9941900501388972
13471	2020-02-25 10:28:48	2020-02-25	Dr. Joanie Kassulke	dr.joanie.kassulke@geemail.com	New York	New York	3158117066872444584	d9885fa1ee978bfb64b791f506e04575	JCB 16 digit	40.6047080452777465	-73.8786218200705918
13472	2020-02-25 10:36:00	2020-02-25	Rochelle Franecki	rochelle.franecki@geemail.com	Glendale	California	3044453065284124	a2320ece519cc55c66845eff471e08e5	JCB 15 digit	34.2075283726897084	-118.341168822710586
13473	2020-02-25 10:51:37	2020-02-25	Ardis Goldner-Davis	ardis.goldner.davis@geemail.com	Oakland	California	3096626493541911401	87cf4c60fa36ce3ff0494ffad7ddc4d5	JCB 15 digit	37.7974568579713406	-122.217668607148468
13474	2020-02-25 11:17:29	2020-02-25	Mr. Florentino Doyle	mr.florentino.doyle@geemail.com	Houston	Texas	210024313572156684	16ef606ba33e8bc125270a034b5076e3	VISA 16 digit	29.7823632556091979	-95.4421263379991132
13475	2020-02-25 11:20:34	2020-02-25	Arturo Stroman	arturo.stroman@geemail.com	San Francisco	California	3096455246762632692	ebfe533c8d0daca9fb6aae643912fb8a	Maestro	37.782466407496706	-122.447023631045568
13476	2020-02-25 11:21:59	2020-02-25	Hardy Hills-D'Amore	hardy.hills.d'amore@geemail.com	Philadelphia	Pennsylvania	210031171818731558	a15ea9b7ec3398ac9a02a6ef7f75a09e	JCB 16 digit	40.1083200367126622	-75.227302101803204
13477	2020-02-25 12:03:29	2020-02-25	Harriette Schoen	harriette.schoen@geemail.com	Oakland	California	3007997382772457	ad0770d01ca620c9e56b7c93c162cd26	American Express	37.8037543175622872	-122.254993014901729
13478	2020-02-25 12:04:16	2020-02-25	Mr. Mekhi Bailey IV	mr.mekhi.bailey.iv@geemail.com	Dallas	Texas	4748567126739	89caed90e94620d3dc7ac23d404044a2	Maestro	32.7088910266097628	-96.8185439046900598
13479	2020-02-25 12:06:43	2020-02-25	Bud Abshire	bud.abshire@geemail.com	Des Moines	Iowa	3754206540761705	c1063e9cb7cf42edb729e94192e2808e	Maestro	41.6510706398844732	-93.6501365421850238
13480	2020-02-25 12:15:21	2020-02-25	Tito Schowalter	tito.schowalter@geemail.com	New York	New York	869940974310273584	59576f2174432874c36adf9a09297299	VISA 16 digit	40.7420796681884667	-73.961976499286294
13481	2020-02-25 12:25:14	2020-02-25	Khalid Bashirian	khalid.bashirian@geemail.com	Huntsville	Alabama	4914036330670	98fe11198d40e0724826347126c759a9	JCB 15 digit	34.704640930682416	-86.7583569569997479
13482	2020-02-25 12:32:09	2020-02-25	Socorro Harber	socorro.harber@warmmail.com	Phoenix	Arizona	3400598149161849	07abd5c5db19f0eaeabd8722b65005fa	VISA 16 digit	33.6107868759360215	-112.099320662107701
13483	2020-02-25 12:32:39	2020-02-25	Misty Hoppe	misty.hoppe@geemail.com	Fairfield	California	3096237255322688347	38525726e6ba5e98a4234ec20e01c0a6	JCB 15 digit	38.2959607763338852	-121.943095523585001
13484	2020-02-25 12:49:55	2020-02-25	Karl Barton	karl.barton@geemail.com	Salt Lake City	Utah	3096268749121070303	3972183cecede95b91cb19c669398925	Diners Club / Carte Blanche	40.8129121365170917	-111.994600795250378
13485	2020-02-25 13:03:04	2020-02-25	Mr. Tyrell Effertz PhD	mr.tyrell.effertz.phd@woohoo.com	Indianapolis	Indiana	3337329799163832216	3ecb780be428d3299af4d5f226dfc528	JCB 15 digit	39.8652675558354659	-86.2236207680512194
13486	2020-02-25 14:11:36	2020-02-25	Coby Shanahan	coby.shanahan@geemail.com	Jacksonville	Florida	3764140481952015	8e7735246b9da7759d2bec134f235f21	VISA 13 digit	30.4367035253956928	-81.64931354416386
13487	2020-02-25 14:23:45	2020-02-25	Andres Nolan	andres.nolan@geemail.com	Berkeley	California	4783707571043523	0a27677ad75f4d590d7da2bf12facacd	Mastercard	37.8712349317782824	-122.242415592693447
13488	2020-02-25 14:27:38	2020-02-25	Miss Tiffany Boyer PhD	miss.tiffany.boyer.phd@woohoo.com	New York	New York	869927094596548273	7a8adc3bb171c0c374e5734a3c3d8fb5	VISA 16 digit	40.6479521266873931	-74.0094044412381891
13489	2020-02-25 14:50:13	2020-02-25	Alysia Stiedemann	alysia.stiedemann@geemail.com	New York	New York	3057545262448902	df999062aabccad32137f298c6c4ebf8	Voyager	40.5886864900812512	-73.880273824640355
13490	2020-02-25 14:51:19	2020-02-25	Britton Schaden	britton.schaden@warmmail.com	Macon	Georgia	180061301858574799	ecd7094f00c77ca1ae34f253ec69e531	Discover	32.7615379945386209	-83.7832534822363328
13491	2020-02-25 15:23:33	2020-02-25	Garnett Kutch	garnett.kutch@geemail.com	San Diego	California	4607966784730	f8c2f8b293bcb03c7620ed5f84ba590d	Maestro	32.8004842324249424	-117.052911462392657
13492	2020-02-25 15:33:22	2020-02-25	Bobbi Welch	bobbi.welch@warmmail.com	Berkeley	California	4180597873233503	4297e2808f44d7893b25d7b8afe4a91d	VISA 16 digit	37.8506099256083388	-122.301068191914254
13493	2020-02-25 15:41:03	2020-02-25	Liliana Lakin	liliana.lakin@woohoo.com	Los Angeles	California	4269272948192	fabed111f218ef9e2f81986dea6dd958	Diners Club / Carte Blanche	33.9836633813433338	-118.376289398175842
13494	2020-02-25 15:51:01	2020-02-25	Pinkney Considine	pinkney.considine@geemail.com	Columbia	South Carolina	4076508475804242	3b08470cd2002f63ef1860b3562b190e	JCB 15 digit	34.0838285759355841	-80.8287406916748665
13495	2020-02-25 15:51:10	2020-02-25	Elwyn Quitzon Sr.	elwyn.quitzon.sr.@woohoo.com	San Francisco	California	3112231886590953264	8f03140ec0985a14eb4731b5da5be720	VISA 16 digit	37.7500085776284209	-122.433371497604924
13496	2020-02-25 15:58:14	2020-02-25	Kaylan Berge	kaylan.berge@geemail.com	Anaheim	California	4705925181699915	69f4532473848c574cb2b6af1b12572d	Diners Club / Carte Blanche	33.8285375875253251	-117.796910745345428
13497	2020-02-25 16:20:20	2020-02-25	Krish Langosh	krish.langosh@geemail.com	San Francisco	California	869965313673470869	3ecbfdc36a9f220a088a1f1f48047571	Maestro	37.7771697863809663	-122.430091667963623
13498	2020-02-25 16:24:12	2020-02-25	Harman Erdman	harman.erdman@geemail.com	San Francisco	California	676215549353579	1d6b6fa78a99716d020ac2d149954390	Diners Club / Carte Blanche	37.7912992635870779	-122.450735006869948
13499	2020-02-25 16:35:21	2020-02-25	Fanny Runolfsdottir	fanny.runolfsdottir@geemail.com	New York	New York	3052119888795081	76d73f00edec41456171a5101a581392	JCB 16 digit	40.6401572741325907	-73.924681924785304
13500	2020-02-25 17:01:28	2020-02-25	Mr. Claudie Osinski V	mr.claudie.osinski.v@woohoo.com	Houston	Texas	3479811516617400	95641e41f46a51c969721753628358ba	JCB 16 digit	29.8140407913908376	-95.4555544928196866
13501	2020-02-25 17:32:33	2020-02-25	Mrs. Hortencia Kuphal DDS	mrs.hortencia.kuphal.dds@warmmail.com	Kansas City	Missouri	210042634429685015	4390b25f1a01809ae2d47b3049b5d019	Diners Club / Carte Blanche	39.1173405838035109	-94.5915995740089528
13502	2020-02-25 18:01:46	2020-02-25	Dr. Quinn Moore II	dr.quinn.moore.ii@woohoo.com	San Francisco	California	502076013016449	307385aeac49aca6f2790413af604a31	Mastercard	37.7871407024733799	-122.423019624073419
13503	2020-02-25 18:12:58	2020-02-25	Mr. Tal Kemmer PhD	mr.tal.kemmer.phd@geemail.com	Los Angeles	California	869951511483069971	cdedc7e912bd161ff2d210325fd25679	JCB 16 digit	34.011882664249832	-118.409150081033999
13504	2020-02-25 18:33:15	2020-02-25	Selene Muller-DuBuque	selene.muller.dubuque@woohoo.com	San Francisco	California	4674637548878	6b7a8fba4e0c253701d9a10b442f9be9	JCB 16 digit	37.7843128772907093	-122.417261276120257
13505	2020-02-25 18:59:04	2020-02-25	Isaiah Bernhard-Rodriguez	isaiah.bernhard.rodriguez@warmmail.com	Baltimore	Maryland	3112192335377555998	134e8d3961b3a3e33cd3e29105216353	VISA 16 digit	39.3764844291377756	-76.6339157330822189
13506	2020-02-25 19:31:38	2020-02-25	Brett Anderson	brett.anderson@geemail.com	Louisville	Kentucky	180021419647406542	858fd3a27b4bb34c8665d5c39d91eb27	Diners Club / Carte Blanche	38.2472551200442012	-85.6909852508526342
13507	2020-02-25 19:40:33	2020-02-25	Delia Schmeler	delia.schmeler@woohoo.com	Boston	Massachusetts	53475541832835101	15e784c71bbfca318d986568c5cd1142	Maestro	42.3982447034381309	-71.0768322207916583
13508	2020-02-25 19:44:44	2020-02-25	Ernst Mayer III	ernst.mayer.iii@geemail.com	Los Angeles	California	6011513284981894900	24de1604e26873528436fa0760f9b2de	JCB 16 digit	34.0203286679327448	-118.507002605590216
13509	2020-02-25 19:53:20	2020-02-25	Mrs. Lizeth Weber	mrs.lizeth.weber@geemail.com	Raleigh	North Carolina	210039357686879700	099ca1c22bb1d357a749faed9b681aa8	VISA 13 digit	35.7689923114743067	-78.6501192830905325
13510	2020-02-25 20:05:22	2020-02-25	Sariah Hagenes	sariah.hagenes@geemail.com	Clearwater	Florida	6011437223447782203	a72241f8c8c084ffc70942ad798a8d2f	JCB 16 digit	27.8811658173926169	-82.6955854568894893
13511	2020-02-25 20:08:28	2020-02-25	Gladis Metz	gladis.metz@geemail.com	Springfield	Missouri	6011506294722407580	38c8da31777d4025bc5b2cc4f4fc5aba	VISA 13 digit	37.1184365461308516	-93.2257162776600694
13512	2020-02-25 20:08:37	2020-02-25	Filomena Tromp-Cummings	filomena.tromp.cummings@geemail.com	Alexandria	Virginia	3713601742785652	a4930f789a55a80428a2939e341d6d71	American Express	38.8663719201575901	-77.1686602795947465
13513	2020-02-25 20:11:50	2020-02-25	Haleigh Towne	haleigh.towne@geemail.com	San Jose	California	4416221322849480	b6c4f38088d4f7a2d5309a7cb0d142fc	JCB 16 digit	37.3828402969341766	-121.890410221157225
13514	2020-02-25 20:28:49	2020-02-25	Dr. Deacon Schmitt	dr.deacon.schmitt@geemail.com	Clearwater	Florida	869949681517243044	abb6427b0191cef81dda37647a62e77a	American Express	27.9149038623679431	-82.7772487055309085
13515	2020-02-25 20:49:27	2020-02-25	Dr. Destry Schmitt	dr.destry.schmitt@geemail.com	Los Angeles	California	3480175596034515	c8b59048090f91322bf700ac42b75608	Discover	34.0603127227961977	-118.353737466362489
13516	2020-02-25 20:50:15	2020-02-25	Lonna Nienow-Ondricka	lonna.nienow.ondricka@geemail.com	New York	New York	639033962121605	4f5f60cc3fad8a0d5df2e29dd81b27fa	American Express	40.6865612589046322	-73.8573733311507823
13517	2020-02-25 20:53:25	2020-02-25	Delmer Little	delmer.little@geemail.com	Tuscaloosa	Alabama	210006519772375120	9143bd9559bc761c11046844a4089341	JCB 16 digit	33.2075765487793788	-87.511689441614223
13518	2020-02-25 21:22:14	2020-02-25	Ms. Margaret White	ms.margaret.white@warmmail.com	Greeley	Colorado	3051976131709743	54230145f417d32494ef1a3725d3b3fb	Diners Club / Carte Blanche	40.3750933819983189	-104.769962772990397
13519	2020-02-25 21:30:53	2020-02-25	Scott Schmitt	scott.schmitt@warmmail.com	Escondido	California	55963496939531492	0a4e71570ef372caa2f2f3401240ceee	VISA 13 digit	33.2096970031265144	-116.994325056044389
13520	2020-02-25 22:36:51	2020-02-25	Hamilton Gleichner-Mayer	hamilton.gleichner.mayer@warmmail.com	Garland	Texas	869933961433681941	c6f81ceb763876f621da6b44a4138145	Discover	32.951246705861017	-96.6491754730392358
13521	2020-02-25 22:43:57	2020-02-25	Ms. Kathryne Koch	ms.kathryne.koch@geemail.com	Alexandria	Virginia	180031552287435765	68c9270299aa6c2bd7174bff9c32b553	VISA 16 digit	38.7734035356085727	-77.1546834455788257
13522	2020-02-25 22:51:45	2020-02-25	Shannon Schamberger V	shannon.schamberger.v@woohoo.com	San Francisco	California	869975037279148276	ce04daa34eefee2a8639f5662eef1d0a	JCB 16 digit	37.7861042780605274	-122.423334024682717
13523	2020-02-25 23:10:12	2020-02-25	Mr. Bill Feil	mr.bill.feil@geemail.com	San Diego	California	3096619692196113200	31718ee1e97ab873e2133f285d064125	JCB 16 digit	32.7975914150543488	-117.197907094182455
13524	2020-02-25 23:11:57	2020-02-25	Tyreese Friesen	tyreese.friesen@geemail.com	Rochester	Minnesota	4574272519829940	691e31b219f8bce53560b1ce8951fc4f	JCB 15 digit	43.990825604823975	-92.3871552186205918
13525	2020-02-25 23:14:22	2020-02-25	Abagail Waters	abagail.waters@geemail.com	Davenport	Iowa	3739178432141090	7b838f3f345e7a4c3ffb9c1237a28977	VISA 16 digit	41.6403535806838434	-90.569620700782167
13526	2020-02-25 23:17:29	2020-02-25	Kinte Larson	kinte.larson@geemail.com	Los Angeles	California	6011562079969570260	ede8ae0a9811ab819f365e06bd40e9d4	VISA 13 digit	33.9945547272317086	-118.396542536280293
13527	2020-02-25 23:27:48	2020-02-25	Mr. Clemente Williamson	mr.clemente.williamson@warmmail.com	Los Angeles	California	3337795738066015631	b2c8e103d823d62550a238f5cbb6fb33	Discover	33.9801090154662688	-118.455989274474973
13528	2020-02-26 00:13:23	2020-02-26	Hasan Bins	hasan.bins@geemail.com	San Francisco	California	6011361076349590722	308ab99ffc5aaa9dd30c64a92407f805	American Express	37.7494580485121674	-122.453778193065773
13529	2020-02-26 00:15:53	2020-02-26	Reina White	reina.white@geemail.com	San Francisco	California	869989496833703295	3077fa290c1e72061240e9e0e0c5c946	JCB 16 digit	37.8285901574840295	-122.430044248664046
13530	2020-02-26 01:04:26	2020-02-26	Dr. Creed Thiel PhD	dr.creed.thiel.phd@geemail.com	Winston–Salem	North Carolina	3766302347288210	bb4dca516f08793e9a583340e1febe3c	Mastercard	36.1685771492540837	-80.1720415127128376
13531	2020-02-26 01:09:57	2020-02-26	Mrs. Melanie Willms DVM	mrs.melanie.willms.dvm@woohoo.com	Simi Valley	California	3112811874503588714	4f41cd9d0e5769a53a719ce955f85265	Diners Club / Carte Blanche	34.2605719696968762	-118.811771911721678
13532	2020-02-26 01:36:44	2020-02-26	Cooper Zieme	cooper.zieme@geemail.com	Jacksonville	Florida	52626229707859137	910bb58bd80813faeb8fdd5194c1b1b6	VISA 13 digit	30.4272242773376398	-81.7429428435008987
13533	2020-02-26 01:56:02	2020-02-26	Hudson Hayes	hudson.hayes@warmmail.com	Houston	Texas	6011142128201987706	207a0a9f52bb676db67cbec6df384340	American Express	29.7097599416118108	-95.4330679721213926
13534	2020-02-26 02:04:45	2020-02-26	Albertine Rohan-West	albertine.rohan.west@warmmail.com	Newark	New Jersey	52393893193316406	212139f266339f0cbcbea50524ad11d0	Discover	40.6511934632349821	-74.096652058951932
13535	2020-02-26 02:16:54	2020-02-26	Miss Manuelita Gaylord PhD	miss.manuelita.gaylord.phd@geemail.com	Detroit	Michigan	4803249169285212	814ec628c0e2af47e68e0e31c8170853	JCB 16 digit	42.4225528982859146	-83.0584399771995834
13536	2020-02-26 02:25:26	2020-02-26	Cash Marquardt	cash.marquardt@geemail.com	Victorville	California	180054669243552376	13a7bc911ac38a59e4f350cd404e7fda	VISA 16 digit	34.603306817286466	-117.358353013188022
13537	2020-02-26 02:49:23	2020-02-26	Deasia Stamm	deasia.stamm@geemail.com	Berkeley	California	6011614607220583447	2d3f82889bfa5e1c5761010e2acf23a4	VISA 16 digit	37.8492173770080953	-122.278909550452838
13538	2020-02-26 03:09:02	2020-02-26	Miss Rayne Ullrich	miss.rayne.ullrich@geemail.com	Denver	Colorado	869903683487850414	702ace8ceafcfe3fd056275a5b1199f0	Voyager	39.7350327883433536	-104.833166089957956
13539	2020-02-26 03:32:51	2020-02-26	Arvin Bradtke PhD	arvin.bradtke.phd@geemail.com	Plano	Texas	3033771499791765	47f48b69a9efb5ca1796941a43c4b7d9	Mastercard	33.0427121097307648	-96.7192388449046803
13540	2020-02-26 03:46:36	2020-02-26	Irena Bernier-Jakubowski	irena.bernier.jakubowski@woohoo.com	Minneapolis	Minnesota	502028175918458	8a5e436234208f20e34ffb7ee7173fcf	VISA 13 digit	44.8965803329452839	-93.2089478904653248
13541	2020-02-26 03:51:00	2020-02-26	Denton Davis-Ferry	denton.davis.ferry@warmmail.com	San Francisco	California	4142771516245888	86b6cbf028f8501cfbe3a3d0e557123c	Diners Club / Carte Blanche	37.7831569175501016	-122.400049794908156
13542	2020-02-26 04:04:07	2020-02-26	Abbott Schulist	abbott.schulist@warmmail.com	San Francisco	California	3158200485777639932	0caef974e3e6086a9ffe022060cf56a7	Maestro	37.743459145883854	-122.462437316194809
13543	2020-02-26 04:14:56	2020-02-26	Ms. Nilda Klocko DVM	ms.nilda.klocko.dvm@woohoo.com	Arlington	Texas	675989585332193	d054f34e60d1adfadb1186ec9890bbbd	JCB 16 digit	32.6361401516262433	-97.0482089098103415
13544	2020-02-26 04:29:28	2020-02-26	Mr. Ocie Emmerich	mr.ocie.emmerich@warmmail.com	San Antonio	Texas	3778473722508971	b8e1ef86259ce26fac4cbdd133960147	American Express	29.4013771112147708	-98.4364454846199521
13545	2020-02-26 04:38:42	2020-02-26	Kaylynn Bins	kaylynn.bins@geemail.com	Omaha	Nebraska	3158945543988013782	9da0c47f62603893357f913c641f544b	Diners Club / Carte Blanche	41.3175962223816668	-96.1357484449747943
13546	2020-02-26 05:08:26	2020-02-26	Brandy Gislason	brandy.gislason@geemail.com	Salem	Oregon	3112108131598049447	42833c380d281060d0655340b3c618d2	JCB 15 digit	44.8964554064244012	-122.937842442204058
13547	2020-02-26 05:12:45	2020-02-26	Leopoldo Schuppe	leopoldo.schuppe@geemail.com	Oakland	California	4725246233839	eac21499a0403992ec790ba197c57000	JCB 15 digit	37.7956129042888023	-122.238661475257857
13548	2020-02-26 05:18:36	2020-02-26	Mr. Roe Cassin	mr.roe.cassin@geemail.com	San Francisco	California	3466208100250067	7aef43662412ae649a1d356688f8b601	JCB 15 digit	37.7763516956773202	-122.393016949655575
13549	2020-02-26 05:42:16	2020-02-26	Dr. Gustavo Schuster MD	dr.gustavo.schuster.md@geemail.com	Boston	Massachusetts	3096915495932169648	984cd29c3ba44f9d777a44186edfb8a1	VISA 13 digit	42.3484919694419943	-71.0156855431802541
13550	2020-02-26 05:55:40	2020-02-26	Evonne Goldner	evonne.goldner@geemail.com	Tallahassee	Florida	3337520489541345159	c41ff023d94c3513080e1b4af25ecd19	Voyager	30.4518508955858671	-84.3226238651681683
13551	2020-02-26 05:58:34	2020-02-26	Theophile Fisher	theophile.fisher@geemail.com	Vacaville	California	3096422937336493716	d184cf6d35c1468ace5fd1467d9530b5	JCB 15 digit	38.3405972602438183	-121.88808317891062
13552	2020-02-26 06:01:07	2020-02-26	Wyman Heaney	wyman.heaney@geemail.com	Boise	Idaho	060463547471076	41a18a1947c5056b12d0acf5aa2ceb28	VISA 13 digit	43.6609869152445356	-116.331662051212788
13553	2020-02-26 06:07:05	2020-02-26	Rueben Dietrich	rueben.dietrich@geemail.com	Greensboro	North Carolina	4183181053658479	f2ee225a5f908e4f06612fce40ae6a31	Voyager	36.1210270018898001	-79.8390170278940303
13554	2020-02-26 06:07:15	2020-02-26	Mrs. Teena Schamberger	mrs.teena.schamberger@geemail.com	Houston	Texas	180083862447076269	d9332cdf10671fc792bf2d8b96219957	Mastercard	29.797914820498228	-95.4270805144697505
13555	2020-02-26 06:18:47	2020-02-26	Arlie Swaniawski-Langosh	arlie.swaniawski.langosh@geemail.com	San Francisco	California	869947917779108273	55f87b13e9769f687798e37d5432d59d	Discover	37.7752033436179175	-122.43009330688939
13556	2020-02-26 06:24:06	2020-02-26	Tristin Johnston	tristin.johnston@geemail.com	West Valley City	Utah	675953372726108	10569c83fb6cbc29c6b843638897cdcd	VISA 16 digit	40.7332454913984989	-112.07726003855764
13557	2020-02-26 06:30:11	2020-02-26	Ms. Hazle Bailey	ms.hazle.bailey@geemail.com	Lincoln	Nebraska	3471692914189426	0fabc550aae1952b3be56b08b463f080	JCB 16 digit	40.8491415737681081	-96.6938720145888624
13558	2020-02-26 06:38:18	2020-02-26	Orrie Grady	orrie.grady@warmmail.com	San Francisco	California	3442896087846466	5f329232b97dcfc55936e1d81aebb0b9	VISA 16 digit	37.8034014344186531	-122.457237352475886
13559	2020-02-26 07:39:58	2020-02-26	Mr. Stephan Littel II	mr.stephan.littel.ii@woohoo.com	Moreno Valley	California	630440835691136	aa04c90ac9440d688a552af0cdf5a30c	JCB 16 digit	33.8447656313415592	-117.229590011478209
13560	2020-02-26 08:07:03	2020-02-26	Augustina Wunsch	augustina.wunsch@geemail.com	St. Petersburg	Florida	180058118113741327	3055cdc7d7394143dd183299cf33b245	JCB 16 digit	27.7811228542942565	-82.5661276239793693
13561	2020-02-26 08:18:15	2020-02-26	Vessie Bauch MD	vessie.bauch.md@warmmail.com	Los Angeles	California	3469422184172314	915ccc3757afdfb76592f08cd57fd2a1	Diners Club / Carte Blanche	34.0223375478625272	-118.451648350431768
13562	2020-02-26 08:43:02	2020-02-26	Burleigh Walter	burleigh.walter@geemail.com	Davie	Florida	3036962083576350	8e1770dd2da206c5176332e96004e937	JCB 16 digit	26.0840571660812941	-80.3563982467073856
13563	2020-02-26 09:07:21	2020-02-26	Mr. Kaeden Rodriguez Jr.	mr.kaeden.rodriguez.jr.@geemail.com	Anaheim	California	4021076271971454	28e7e42847a2e3806416919e5735fef0	American Express	33.8464800049383214	-117.699791822696469
13564	2020-02-26 09:18:13	2020-02-26	Katlyn Mertz-Wilderman	katlyn.mertz.wilderman@geemail.com	Jersey City	New Jersey	869979233634104486	ac82aca80b033c48f6e90d0b98e19549	JCB 15 digit	40.6728934887271336	-73.9664340662259718
13565	2020-02-26 09:21:15	2020-02-26	Suzie Gorczany	suzie.gorczany@geemail.com	Los Angeles	California	4780062458772361	2d4f8ff2fd6b5226d642acea37f63cbf	VISA 16 digit	33.9411184409499143	-118.504164203302182
13566	2020-02-26 09:26:07	2020-02-26	Desirae Ledner	desirae.ledner@geemail.com	Fort Worth	Texas	210070297469026030	8154964a5f9500ed28ffbc306656e67b	JCB 16 digit	32.7024780057892244	-97.3562453073736265
13567	2020-02-26 09:31:15	2020-02-26	Emily Bartell	emily.bartell@geemail.com	Toledo	Ohio	3528473787086605789	fa4a260a4db26c254d86de1d8ddcac2f	JCB 15 digit	41.67273339570351	-83.6596176628355011
13568	2020-02-26 09:56:04	2020-02-26	Darius Mitchell	darius.mitchell@geemail.com	Tampa	Florida	4876101293804065	b9e36152020885d6cb1b18fd188f40fd	VISA 16 digit	27.9363766075227389	-82.4373233498752001
13569	2020-02-26 10:05:02	2020-02-26	Aniyah Schamberger	aniyah.schamberger@geemail.com	Philadelphia	Pennsylvania	3731847132673143	ac7fa32f08f7dfca0516fc77355e8e43	Maestro	40.0322649321012207	-75.185227594561141
13570	2020-02-26 10:18:18	2020-02-26	Dr. Taniya Bashirian DVM	dr.taniya.bashirian.dvm@warmmail.com	Oakland	California	501881409333200	db1c375cb09cb928aee7538b5c7c10fd	JCB 16 digit	37.7550433032827755	-122.281376965965507
13571	2020-02-26 10:18:54	2020-02-26	Goldie Stehr	goldie.stehr@geemail.com	New York	New York	4344795098372501	0a66e91020aeba2bdcef4f9e52c78327	VISA 13 digit	40.6387098859287761	-73.851969692519674
13572	2020-02-26 10:20:24	2020-02-26	Ms. Antoinette Koelpin MD	ms.antoinette.koelpin.md@geemail.com	Berkeley	California	3427964100677521	92c642ebb42259e52516f05d40953d99	JCB 16 digit	37.8708159583491195	-122.267744988726818
13573	2020-02-26 10:24:42	2020-02-26	Tal Kirlin III	tal.kirlin.iii@geemail.com	San Francisco	California	589363094372974	5d19e061c42fa811c38896066076f35e	VISA 16 digit	37.7747764969418611	-122.436510900561686
13574	2020-02-26 10:39:45	2020-02-26	Clementina Quitzon PhD	clementina.quitzon.phd@geemail.com	Lexington	Kentucky	4564695718887	d60954d25de543d4e2278116a989b700	VISA 13 digit	38.114738748117162	-84.5422442807715271
13575	2020-02-26 10:49:25	2020-02-26	Mr. Muhammad D'Amore MD	mr.muhammad.d'amore.md@geemail.com	San Francisco	California	4895930357410428	d805d976f21e2bf099646ede491501ff	Discover	37.786141381815149	-122.457933887517768
13576	2020-02-26 11:44:59	2020-02-26	Irine Schaefer	irine.schaefer@geemail.com	New York	New York	869915220419054983	8f98d7056e310729b04d07006035a319	JCB 15 digit	40.5785404114741795	-73.8879585407104287
13577	2020-02-26 11:51:01	2020-02-26	Maddox Zboncak	maddox.zboncak@woohoo.com	New York	New York	3468082755097893	83f6d579e3ebc1860119c0c53e6e0efa	JCB 16 digit	40.615889122499155	-73.9674245542742312
13578	2020-02-26 12:04:39	2020-02-26	Kieran Swaniawski	kieran.swaniawski@geemail.com	Ontario	California	4484549327820651	41eb6bcd3bbeccd24ea3165b138b3306	JCB 16 digit	34.0758170328713987	-117.703343339088192
13579	2020-02-26 12:16:25	2020-02-26	Cecil Lemke	cecil.lemke@geemail.com	San Francisco	California	52484044806116482	a16650d43b70c9aaf88ed7c017c6b5ed	JCB 16 digit	37.7666773650679843	-122.447898630550014
13580	2020-02-26 12:17:44	2020-02-26	Lukas Hartmann	lukas.hartmann@warmmail.com	Burbank	California	6011943419215549744	95dfd9b0378ef3838f5e1f175e47817c	American Express	34.1291208199154568	-118.335281759177903
13581	2020-02-26 12:20:04	2020-02-26	Dr. Cyntha Hilll PhD	dr.cyntha.hilll.phd@geemail.com	Chicago	Illinois	3709962603067424	03b42b637a31e1d8343e77fc5f192769	Maestro	41.7607688296888071	-87.7598524697620377
13582	2020-02-26 12:34:01	2020-02-26	Mrs. Vera Schultz	mrs.vera.schultz@geemail.com	New York	New York	869957042358699787	a032fe0c61afbbf2c3c08458fba17ccb	VISA 16 digit	40.6175085474494821	-73.9785388520814422
13583	2020-02-26 13:05:00	2020-02-26	Dr. Zula Leffler DVM	dr.zula.leffler.dvm@geemail.com	San Francisco	California	630415863538961	bd911f00b943d4f8867094df29cb4b0f	VISA 16 digit	37.8159735911692181	-122.427916622118971
13584	2020-02-26 13:08:43	2020-02-26	Miss Pamela Maggio DDS	miss.pamela.maggio.dds@warmmail.com	Los Angeles	California	4598095899053	40f2656e5c7418dbdcc90bbc030592f1	VISA 16 digit	33.974977958980574	-118.322516488888482
13585	2020-02-26 13:29:32	2020-02-26	Cal Haag	cal.haag@geemail.com	Salt Lake City	Utah	3337040630161601105	28eed9674a29b9db3bb8b9cdcd0fefc8	Diners Club / Carte Blanche	40.7884219464991205	-111.852132159372786
13586	2020-02-26 13:40:19	2020-02-26	Stewart Runte	stewart.runte@geemail.com	Columbia	Missouri	4930757342004405	bf9bd61b48b3533c6cac38d4e61aba6a	Voyager	38.8881116840404104	-92.3008371466358284
13587	2020-02-26 13:46:15	2020-02-26	Sarai Moen	sarai.moen@geemail.com	San Francisco	California	4812993321338	0bee86e6b5052544a2abe0a24d6e81ed	VISA 16 digit	37.7803741463515763	-122.472081157832605
13588	2020-02-26 14:02:18	2020-02-26	Bascom Abbott	bascom.abbott@geemail.com	New York	New York	4264701728448	66fc2e9d4618eb050b8ad995937cb826	VISA 16 digit	40.6576400904208413	-73.8749198751419698
13589	2020-02-26 14:31:03	2020-02-26	Durwood Hegmann IV	durwood.hegmann.iv@geemail.com	Jacksonville	Florida	54136826290352967	d58846a44f073358ed6dd82766179390	Discover	30.2530958673968904	-81.6780466174319457
13590	2020-02-26 14:35:33	2020-02-26	Texie Ritchie-Rau	texie.ritchie.rau@warmmail.com	Saint Paul	Minnesota	4726811881948015	2cd20bdfb922bb6d3c7269819eddc5cc	JCB 15 digit	44.8568917744267779	-93.0937349035669115
13591	2020-02-26 14:52:09	2020-02-26	Miss Georgiann Schiller	miss.georgiann.schiller@geemail.com	San Antonio	Texas	3483580945087956	35157da0468dc4136c6f3ab69e1ed774	VISA 16 digit	29.390432594956458	-98.6005366472363391
13592	2020-02-26 15:11:32	2020-02-26	Dr. Alphonsus Rau	dr.alphonsus.rau@geemail.com	San Antonio	Texas	561263675802654	44a16d9631e8b3909dcf0470e61dbf38	JCB 16 digit	29.424762935664134	-98.5996050526224082
13593	2020-02-26 15:14:00	2020-02-26	Mr. Estel Homenick	mr.estel.homenick@geemail.com	San Francisco	California	3528820938065584384	0eff0498b7053a99239630f1c17f08b8	Diners Club / Carte Blanche	37.7683136442042269	-122.421400709604868
13594	2020-02-26 15:47:00	2020-02-26	Araminta Schulist	araminta.schulist@geemail.com	Irvine	California	180067000417696382	96523c3b1e7ebeb90ce4103a07ecaadc	JCB 16 digit	33.7037013788722462	-117.808032303258031
13595	2020-02-26 15:59:28	2020-02-26	Lyle Brown	lyle.brown@geemail.com	San Francisco	California	3158176366955594414	3460d1122c4d17c59f51f502691cbbd0	VISA 16 digit	37.7833533657355432	-122.448749637396418
13596	2020-02-26 16:19:05	2020-02-26	Marcelina Hilll	marcelina.hilll@geemail.com	Lakewood	Colorado	4793706993193	9680f8aa9dd2eceba822b12ca6400864	JCB 16 digit	39.6323458449389818	-105.055395998807995
13597	2020-02-26 16:21:06	2020-02-26	Ezell Kulas	ezell.kulas@geemail.com	Boston	Massachusetts	630467256564724	6755d3759d86d74354d1fe9a44a23bdb	Discover	42.3403153512794503	-70.9706427709151058
13598	2020-02-26 16:21:24	2020-02-26	Dr. Chaz Reinger II	dr.chaz.reinger.ii@geemail.com	Columbia	South Carolina	869931872517228651	ba2270fab41070a02bc0f1a7fe3ee1e9	JCB 16 digit	33.9685865707494301	-80.9122921436112392
13599	2020-02-26 16:27:11	2020-02-26	Miss Berenice Witting	miss.berenice.witting@geemail.com	Berkeley	California	6011194211170135916	87acb5b651fe22025c4451cf46b3b41c	JCB 16 digit	37.9056999822144434	-122.271323305957708
13600	2020-02-26 16:54:31	2020-02-26	Dr. Kendrick Medhurst DVM	dr.kendrick.medhurst.dvm@geemail.com	Honolulu	Hawaii	676304414400012	e1336452d0959d15e586067754f1d606	Mastercard	21.3581884814642393	-157.891581883116061
13601	2020-02-26 17:05:24	2020-02-26	Kian Ziemann	kian.ziemann@woohoo.com	Los Angeles	California	3052544574702994	19225ebd2ec4df2f69e3e1466b7db00b	Discover	33.9964882791373881	-118.464158202194795
13602	2020-02-26 17:15:06	2020-02-26	Llewellyn Rath	llewellyn.rath@woohoo.com	Manchester	New Hampshire	4784594696774	93c01b3adc406e55deb532481d501773	VISA 16 digit	42.9979360067822043	-71.354422354314849
13603	2020-02-26 17:17:42	2020-02-26	Babe Bogan	babe.bogan@geemail.com	Evansville	Indiana	3025780149301840	383dda81edbe1f8c2fae7cfa735a9f29	Mastercard	38.0155587860055206	-87.4377810804571993
13604	2020-02-26 17:24:32	2020-02-26	Arno Huels	arno.huels@warmmail.com	Berkeley	California	210053997871783299	f657ae580142b9ad60c4bd7d82a6929f	VISA 16 digit	37.8978818288071011	-122.271961520300692
13605	2020-02-26 17:31:22	2020-02-26	Robin Beier	robin.beier@geemail.com	Omaha	Nebraska	6011523101581384470	7e8bb46d821c4f1479a22d4d68bb5d94	VISA 16 digit	41.25079673413709	-96.1379982077166488
13606	2020-02-26 17:33:26	2020-02-26	Mrs. Madilynn Marvin DVM	mrs.madilynn.marvin.dvm@geemail.com	Athens	Georgia	4815880589386440	054e52a343dcc2f6090cac7b8292af6c	VISA 16 digit	33.9886189704019515	-83.3623988887410547
13607	2020-02-26 17:36:57	2020-02-26	Mr. Zigmund Gorczany DDS	mr.zigmund.gorczany.dds@geemail.com	Chicago	Illinois	51439344212554458	25b654b428f5aa6f4625088ce2972e3e	JCB 16 digit	41.883013522422317	-87.7484680037975266
13608	2020-02-26 18:06:23	2020-02-26	Ms. Pamella Schulist PhD	ms.pamella.schulist.phd@geemail.com	San Francisco	California	180009828698561813	a3552db979cbd0ab4331ee22edf477d3	Maestro	37.7694732660345878	-122.423547033833714
13609	2020-02-26 18:17:13	2020-02-26	Magen Auer	magen.auer@geemail.com	Baltimore	Maryland	869904899557332013	50bab4688d7afb5e0a16283a10a29809	JCB 15 digit	39.2640641832724171	-76.6183214489389286
13610	2020-02-26 18:30:32	2020-02-26	Wilhelm Koepp	wilhelm.koepp@warmmail.com	South Bend	Indiana	6011953882078406491	15c1ffabac840fc9d6eaee448b4f95eb	VISA 13 digit	41.6751772591058227	-86.1844049064032731
13611	2020-02-26 18:37:38	2020-02-26	Berdie Haag-Beatty	berdie.haag.beatty@geemail.com	Houston	Texas	6011448995127642883	5f1725bf20c3cb828decae0496934835	JCB 15 digit	29.7438661958169206	-95.4387753983974534
13612	2020-02-26 19:11:55	2020-02-26	Lorinda Sporer	lorinda.sporer@geemail.com	Plano	Texas	4686407953026364	4466dd3fb82dabf8b7a86ac6b33bd886	Diners Club / Carte Blanche	33.0193994022991504	-96.8098470160454525
13613	2020-02-26 19:26:33	2020-02-26	Dr. Heriberto Bruen PhD	dr.heriberto.bruen.phd@geemail.com	Oakland	California	6011111291871143773	dc6ba7641e36ada8577abac8fd7d114f	Mastercard	37.8177174963355185	-122.282435153770578
13614	2020-02-26 19:53:08	2020-02-26	Isaiah Prohaska	isaiah.prohaska@geemail.com	Santa Clara	California	55279591234591933	e9addfe0c437ed9068c545d68cc01859	JCB 15 digit	37.3830361904393911	-122.056848501413683
13615	2020-02-26 20:04:38	2020-02-26	Irva Bashirian	irva.bashirian@warmmail.com	San Diego	California	3088316295826639531	09b927eefb065f62687b8100578d18cd	VISA 16 digit	32.8503484868045916	-117.09765042256565
13616	2020-02-26 20:23:25	2020-02-26	Flor Hyatt	flor.hyatt@warmmail.com	Santa Rosa	California	3427346461699353	a74385a96eb5e7ff105281d1dc96d290	VISA 16 digit	38.4368671436917069	-122.781496405905486
13617	2020-02-26 20:50:37	2020-02-26	Dr. Amerigo Hermann DVM	dr.amerigo.hermann.dvm@geemail.com	Dallas	Texas	4170121250759030	f5b7465577eb8001e5fd3d5054f2b6b0	VISA 16 digit	32.7317261418599657	-96.7824419241361227
13618	2020-02-26 20:56:56	2020-02-26	Dr. Kimberley Hammes	dr.kimberley.hammes@geemail.com	San Francisco	California	3720237667626877	af36f6bac50d4e136ed671bf34fae20c	JCB 16 digit	37.7364284826880336	-122.414321309100657
13619	2020-02-26 21:08:43	2020-02-26	Mrs. Cori Rath DVM	mrs.cori.rath.dvm@geemail.com	Bellevue	Washington	6011257663390380793	c14a2c49a61b45981ebd8ab7baf6b363	VISA 13 digit	47.6910167560629574	-122.114375618757677
13620	2020-02-26 21:13:00	2020-02-26	Darell Spinka	darell.spinka@warmmail.com	Dallas	Texas	180088439146091876	d514af5e15df554298958dacf085f224	VISA 13 digit	32.883461425061526	-96.7924098206646732
13621	2020-02-26 21:24:21	2020-02-26	Almon Kuhic	almon.kuhic@geemail.com	Sacramento	California	4805141922716948	6f313fb28b59fe06ac5fd91dcdbe8f9c	Diners Club / Carte Blanche	38.6182203245148088	-121.44540511875077
13622	2020-02-26 22:21:37	2020-02-26	Dr. Robert Walker	dr.robert.walker@geemail.com	Chicago	Illinois	180057000238712709	30c38ca551c2aab1aed22a188821ab35	American Express	41.7482910563074086	-87.7412563619233623
13623	2020-02-26 22:53:55	2020-02-26	Carly Prohaska	carly.prohaska@geemail.com	Eugene	Oregon	52201698625329105	f01e4e3a746432b6d3c4d236a482b568	VISA 16 digit	44.1317452108681181	-123.193049995367232
13624	2020-02-26 23:10:41	2020-02-26	Lauren Bernhard	lauren.bernhard@geemail.com	Corona	California	4801083016825	9c8e7372ac1e879e0c9381f6d08ba211	Maestro	33.7750075493827495	-117.515369519658393
13625	2020-02-26 23:18:31	2020-02-26	Chandler Leuschke	chandler.leuschke@geemail.com	Garden Grove	California	3722186111298007	fdde9c630740942b0deefe1f7a9d4cd7	VISA 13 digit	33.7113737289618669	-118.040969214729955
13626	2020-02-26 23:33:58	2020-02-26	Latosha McClure	latosha.mcclure@geemail.com	Phoenix	Arizona	3528550226145259649	1e61062765a47cf5175fd07417f5083e	JCB 16 digit	33.522165659482404	-112.089964917621018
13627	2020-02-26 23:50:26	2020-02-26	Gerald Stark	gerald.stark@geemail.com	Durham	North Carolina	4287227349727019	0be1a2dfb1fd37f9e553c85eea0e74be	VISA 16 digit	35.9367160455103942	-78.8634751928407667
13628	2020-02-26 23:57:19	2020-02-26	Lea Prosacco	lea.prosacco@geemail.com	Boise	Idaho	52084957331616441	4caf1d81876e1e848d8174e73dd19cb6	Mastercard	43.513390654572099	-116.191856156541789
13629	2020-02-27 00:00:41	2020-02-27	Dwayne Grimes MD	dwayne.grimes.md@woohoo.com	Chicago	Illinois	869977418998611034	abce48cfd13fbcb4bc8efa02bb2ba2f4	Discover	41.781890982699025	-87.6474147195491895
13630	2020-02-27 00:01:01	2020-02-27	Suzanne Dooley-Vandervort	suzanne.dooley.vandervort@geemail.com	Everett	Washington	3473095006825980	782a7e16ba1940db4cee6ab88f6edf34	Voyager	48.006616971537845	-122.213266032388063
13631	2020-02-27 00:06:07	2020-02-27	Clemens Cartwright	clemens.cartwright@geemail.com	Saint Paul	Minnesota	4077528962614	8a417bc58eaf4c49c806caebd80103c1	VISA 13 digit	44.9230748476401018	-93.1581630710776949
13632	2020-02-27 00:54:09	2020-02-27	Beula Price	beula.price@warmmail.com	Houston	Texas	180012623978010143	50a9c14cbfa1898b8861305854ba1f93	Mastercard	29.8392327615138129	-95.387249464729436
13633	2020-02-27 00:55:37	2020-02-27	Ms. Ernestina Larson DVM	ms.ernestina.larson.dvm@geemail.com	Tampa	Florida	180086967980537507	496f9b085c836535ea52bda1f4e69542	Voyager	27.9743086525354521	-82.517105262328684
13634	2020-02-27 01:00:59	2020-02-27	Leonor Reynolds	leonor.reynolds@warmmail.com	Montgomery	Alabama	869932787376024505	1b951065df74cbdced5e83af85a25f49	VISA 16 digit	32.3925146470244982	-86.3112128305867259
13635	2020-02-27 01:06:05	2020-02-27	Ryan Streich	ryan.streich@geemail.com	Arlington	Texas	6011016258888143662	3bba75817962bee9a3ef8969a08669e9	JCB 16 digit	32.6779034288849672	-97.0599090264204989
13636	2020-02-27 01:08:28	2020-02-27	Val Murphy-Ankunding	val.murphy.ankunding@geemail.com	Phoenix	Arizona	51958536066822011	d02960dd25f0b5c1662b1901c11d985e	Mastercard	33.667228353296224	-112.150575834878168
13637	2020-02-27 01:16:15	2020-02-27	Tyrique Kovacek	tyrique.kovacek@geemail.com	Bellevue	Washington	4452101539711670	314bce4037cd649ded89d598629f9780	Discover	47.5020377773974118	-122.06490216600335
13638	2020-02-27 01:19:20	2020-02-27	Wilson Price	wilson.price@geemail.com	New York	New York	6011484418870194296	f46a769510b83f4d27fa838403aafa66	VISA 16 digit	40.6373076732959575	-73.8603615922283296
13639	2020-02-27 01:33:53	2020-02-27	Leila Smitham	leila.smitham@geemail.com	Oakland	California	3004798653496054	3b0fcac999f7fed4c8e259f4178a7d2a	JCB 16 digit	37.8251547852395049	-122.289953817026614
13640	2020-02-27 01:53:18	2020-02-27	Marilee Leannon	marilee.leannon@geemail.com	New York	New York	3047240846336498	e9785dfb7a1824c313cc863584ecfd74	JCB 16 digit	40.6574300717785917	-73.8391976281896234
13641	2020-02-27 02:28:09	2020-02-27	Chalmer Keeling	chalmer.keeling@geemail.com	San Francisco	California	3088222407520619007	f4141f47a63fdb5fbe1d53e623a13b4e	VISA 16 digit	37.7349920469499907	-122.415654713802397
13642	2020-02-27 02:36:20	2020-02-27	Miss Charlize Mraz DDS	miss.charlize.mraz.dds@geemail.com	Macon	Georgia	4308964078435407	d416ac6d33f283efa75a90e8efd7385e	JCB 16 digit	32.7496896828070234	-83.726278592013557
13643	2020-02-27 03:04:58	2020-02-27	Burleigh McDermott MD	burleigh.mcdermott.md@geemail.com	San Francisco	California	53316614552043835	a7d4df9f55372c519edc3d859c213019	VISA 13 digit	37.7840001243005759	-122.434471350171648
13644	2020-02-27 03:45:08	2020-02-27	Felicia Corwin	felicia.corwin@geemail.com	New York	New York	3528941365049787574	a6f9e839c7ee0b70c0ee97b252d51ccc	JCB 15 digit	40.6227172013130016	-73.9072846243519308
13645	2020-02-27 03:48:51	2020-02-27	Foch Langosh	foch.langosh@woohoo.com	Los Angeles	California	55111365093443573	2134baa59aae508fa97f6d1b874aad93	VISA 13 digit	34.0981474012002295	-118.473297840588913
13646	2020-02-27 03:53:33	2020-02-27	Shianne Wisoky-Jast	shianne.wisoky.jast@geemail.com	Aurora	Colorado	4059099089854295	4916423ea3deefcf4c173a6df5df2b80	JCB 15 digit	39.6165965641029203	-104.768823517218976
13647	2020-02-27 04:16:18	2020-02-27	Annabell Raynor	annabell.raynor@geemail.com	Philadelphia	Pennsylvania	3528736882295943585	679e96aec7f05e3ce90579200472518a	Voyager	39.9941192779183368	-75.1826199684191607
13648	2020-02-27 04:35:56	2020-02-27	Dimitrios Pouros	dimitrios.pouros@geemail.com	Berkeley	California	180093008375587772	fa0b6f645f389c6a7865ddfd3e77a982	Discover	37.8644968962406878	-122.263066994807673
13649	2020-02-27 04:36:22	2020-02-27	Gaston Will	gaston.will@warmmail.com	Milwaukee	Wisconsin	4181963228406	19ffecc9e26e62fe8b50df200bcc92c5	American Express	43.0011490081522609	-87.9354093362677816
13650	2020-02-27 04:57:57	2020-02-27	Lilianna Bernier	lilianna.bernier@woohoo.com	Tucson	Arizona	3528047189858426402	5a63f011057f1460ec3c3202f0534f26	VISA 16 digit	32.2039980021346395	-110.89614859071969
13651	2020-02-27 04:58:29	2020-02-27	Rikki Kling	rikki.kling@warmmail.com	Berkeley	California	639035307985156	d121248d3a1b46bb3fb3788374da4484	JCB 16 digit	37.8738602989391779	-122.277460693522329
13652	2020-02-27 05:09:43	2020-02-27	Inga Braun	inga.braun@geemail.com	Glendale	Arizona	4760512540245	77d71f1b9a613b404cc0624f5f2c24d9	Discover	33.5118612092215571	-112.102845374427361
13653	2020-02-27 05:13:16	2020-02-27	Jaxton Lowe	jaxton.lowe@geemail.com	San Antonio	Texas	4980010215947261	5a311f38a3c7751d5ff3408077fdfb65	VISA 13 digit	29.4425206871774066	-98.4686645237099327
13654	2020-02-27 05:19:19	2020-02-27	Clarinda Littel	clarinda.littel@geemail.com	Springfield	Illinois	869914082884595630	54ed7906fb186e66e57fa560ee77360e	Mastercard	39.7415392902366804	-89.6554678215648977
13655	2020-02-27 05:19:47	2020-02-27	Miss Tina Gleichner PhD	miss.tina.gleichner.phd@woohoo.com	Wilmington	North Carolina	54209617984080473	ddf330585a83f445d6abb0ef8ad5202b	VISA 16 digit	34.1102882020927964	-77.884560350188238
13656	2020-02-27 06:04:46	2020-02-27	Tamya Erdman	tamya.erdman@geemail.com	San Francisco	California	3011284669032160	a8baaa8ba16634a6f622338df0c38706	VISA 13 digit	37.7389404692388908	-122.385473420018499
13657	2020-02-27 06:12:07	2020-02-27	Buna Prosacco	buna.prosacco@warmmail.com	Garland	Texas	3741248097592360	82d588f8ffa671d361df87e5d27482dd	Discover	32.9815716049868612	-96.6444231685411239
13658	2020-02-27 06:21:07	2020-02-27	Katlyn Roob	katlyn.roob@geemail.com	San Francisco	California	3528442804232296906	21a2e6d1b4882af61fe906b50f6b8129	Discover	37.7873818353306916	-122.449878952270424
13659	2020-02-27 06:25:16	2020-02-27	Elenora Reichert MD	elenora.reichert.md@warmmail.com	Minneapolis	Minnesota	3471091495457163	c02e5efe8a2a7e6e478d35b12d0cdd37	Maestro	45.0019727117467667	-93.3280024851944319
13660	2020-02-27 06:28:15	2020-02-27	Star Abbott	star.abbott@geemail.com	Chicago	Illinois	6011142677749730358	8cf3a2f9bf696baa014478f949fcf01e	VISA 16 digit	41.8587574702523639	-87.738923094052069
13661	2020-02-27 07:01:52	2020-02-27	Liller Hermiston	liller.hermiston@geemail.com	Detroit	Michigan	6011918956477216448	b64179a161d57356bb15b48d3fa15a05	VISA 16 digit	42.3349391539972331	-83.0090617066368424
13662	2020-02-27 07:29:06	2020-02-27	Orris Kub Jr.	orris.kub.jr.@geemail.com	Berkeley	California	4814922070942579	31b535049d6d58cac7baafefb9f1e099	Voyager	37.8770578564496176	-122.250505409244184
13663	2020-02-27 08:11:01	2020-02-27	Mr. Joseluis Shanahan	mr.joseluis.shanahan@geemail.com	Chicago	Illinois	3112166905156253577	40718fefa834552403cb88964e3f5d2d	JCB 16 digit	41.88938129570559	-87.6202452336002153
13664	2020-02-27 08:15:24	2020-02-27	Frances Purdy	frances.purdy@geemail.com	Boston	Massachusetts	3405278754649397	23434f5c0df70618548c633bc44b5b92	JCB 16 digit	42.3282374243885258	-71.0308017868034511
13665	2020-02-27 08:17:00	2020-02-27	Sharee Lowe	sharee.lowe@geemail.com	Boston	Massachusetts	4203060749692272	0a93b9b45fa39192935fc37f2182ab37	JCB 15 digit	42.2407121341843137	-70.9670340751714974
13666	2020-02-27 08:19:26	2020-02-27	Ms. Takisha Bergstrom	ms.takisha.bergstrom@geemail.com	Madison	Wisconsin	869911046269484093	9f190d37f8c32bc7e5363573242ede7c	VISA 16 digit	43.1510245833985522	-89.3587745536003268
13667	2020-02-27 08:33:30	2020-02-27	Sylvia Rath	sylvia.rath@geemail.com	Henderson	Nevada	52801652895995701	eeb615547e27703bc6200924c9a59b86	Voyager	36.0924960924711087	-114.955716424544164
13668	2020-02-27 08:35:48	2020-02-27	Lyndsay Reynolds	lyndsay.reynolds@geemail.com	Fresno	California	4537254148388825	7b8a10fbf426d133475e102b36d5d0ab	JCB 16 digit	36.7645606651309862	-119.779799334575983
13669	2020-02-27 08:42:54	2020-02-27	Gerhard Reichert	gerhard.reichert@woohoo.com	Berkeley	California	3470426858168323	28ec4da4c4da9fd17b1c97a6ebde072f	Diners Club / Carte Blanche	37.8789318646411743	-122.249532498832266
13670	2020-02-27 08:49:09	2020-02-27	Sebrina Bartoletti	sebrina.bartoletti@geemail.com	Los Angeles	California	676354338035774	f84479d5d5174afea331783dc5644a90	American Express	33.927246039487045	-118.320773536012695
13671	2020-02-27 08:50:32	2020-02-27	Wellington Zieme	wellington.zieme@geemail.com	Aurora	Colorado	060426295932508	14785debe07a986885d4b80d47c28496	Mastercard	39.743467410711574	-104.7281145854041
13672	2020-02-27 08:54:40	2020-02-27	Eli Johnston	eli.johnston@geemail.com	Indianapolis	Indiana	3158753207465955912	94f2fb25c6157f401c570a1ad27f2eaa	Mastercard	39.7287180988591118	-86.0554718320459102
13673	2020-02-27 09:00:11	2020-02-27	Collie Thiel I	collie.thiel.i@geemail.com	Chesapeake	Virginia	6011413068956248072	2ab86da763f9cd9205b52089da540799	American Express	36.7099233992170539	-76.229998564704502
13674	2020-02-27 09:22:46	2020-02-27	Prosper Conroy	prosper.conroy@geemail.com	Portland	Oregon	3005696700317654	6a8bcf4ac5233529d8c7e796ca33ba1e	Diners Club / Carte Blanche	45.4854213773626839	-122.620405394304555
13675	2020-02-27 09:24:18	2020-02-27	Ruthie Gutkowski	ruthie.gutkowski@geemail.com	Berkeley	California	180052505974748662	1d42846ea6abf5e9093fa2ee8205a916	JCB 16 digit	37.8774701631434567	-122.290897128023957
13676	2020-02-27 09:39:07	2020-02-27	Markell Auer-O'Kon	markell.auer.o'kon@geemail.com	Tucson	Arizona	3337489627819025305	6ddc6a514ce197a74bfb193c60364d85	VISA 16 digit	32.1700911573175361	-110.965831431303542
13677	2020-02-27 09:45:48	2020-02-27	Tess Strosin	tess.strosin@geemail.com	San Francisco	California	4062673170983190	ae239b381ca86dc412f6b366f6647f4d	Maestro	37.7658304970871512	-122.421353529836082
13678	2020-02-27 09:55:25	2020-02-27	Sylvanus Dickinson	sylvanus.dickinson@geemail.com	Phoenix	Arizona	869999896629654941	7591bb9bdb2e7a03b90730d643ae330a	Discover	33.4744929233964541	-112.016655470842878
13679	2020-02-27 10:05:05	2020-02-27	Rochelle Murphy-O'Keefe	rochelle.murphy.o'keefe@woohoo.com	Cleveland	Ohio	869946227145403320	0465b0831744f241a6d4058a981b80ac	Mastercard	41.4263618813212915	-81.7323076520353595
13680	2020-02-27 10:51:25	2020-02-27	Lavern Runolfsdottir	lavern.runolfsdottir@woohoo.com	Visalia	California	4055072274263	42454e5f15898d7b0e0e4ec9fa2ad96e	Mastercard	36.3934057007499021	-119.38073432060294
13681	2020-02-27 11:00:44	2020-02-27	Corina Pacocha	corina.pacocha@geemail.com	Lafayette	Louisiana	4599636616758	97acd76ee705a159d2f278443cbffcad	JCB 16 digit	30.2969288862753672	-91.9482084011509926
13682	2020-02-27 11:04:01	2020-02-27	Lonnie Wunsch	lonnie.wunsch@warmmail.com	San Francisco	California	6011995846703619885	5b0872f048e6dbccadfdc718f4628292	JCB 16 digit	37.8134704800525938	-122.462641107981923
13683	2020-02-27 11:40:49	2020-02-27	Trula Green	trula.green@geemail.com	Atlanta	Georgia	4639787946585479	4bff028b7aaf7a6ea804e1dcf4bc5b4d	JCB 16 digit	33.7029473813060676	-84.5151959079828146
13684	2020-02-27 11:59:03	2020-02-27	Genevra Fay	genevra.fay@warmmail.com	New York	New York	3499531986982011	ad10c61c64240eccbf7c09452ff1cbd9	JCB 16 digit	40.7226069553513099	-74.0310194554634364
13685	2020-02-27 13:06:26	2020-02-27	Juston Mosciski	juston.mosciski@woohoo.com	West Jordan	Utah	4135160301952	7869a4c6caa631153ce6e78168f7f682	JCB 15 digit	40.6238739615563347	-112.079651349884642
13686	2020-02-27 13:12:04	2020-02-27	Redden Hirthe	redden.hirthe@geemail.com	New York	New York	180057722162731633	7626e38cb2896e680cbb3979c6295898	Mastercard	40.6340222236458217	-73.9855332891818165
13687	2020-02-27 13:40:33	2020-02-27	Abagail Schneider	abagail.schneider@geemail.com	Boise	Idaho	4180690138520549	abbc449f9d5bc9fbefd8fb7646629ec3	VISA 16 digit	43.6583983920186753	-116.235764046917481
13688	2020-02-27 13:43:09	2020-02-27	Dr. Eleonora Friesen	dr.eleonora.friesen@warmmail.com	Houston	Texas	4998197842185	2af8df3473bfe90010d11d873da3e160	Mastercard	29.8715320345092579	-95.2977987011909562
13689	2020-02-27 13:43:44	2020-02-27	Bode Schultz-Kessler	bode.schultz.kessler@geemail.com	Fort Worth	Texas	180094481744782706	f18596ccef82f12a6de6aac7e1941904	Mastercard	32.6919059576522599	-97.2855619775418177
13690	2020-02-27 14:06:40	2020-02-27	Miss Katelyn Denesik	miss.katelyn.denesik@warmmail.com	Berkeley	California	3004429217282950	8e3762a2bafe2b2aceeb5214576a1436	JCB 16 digit	37.882926076277748	-122.286372112745269
13691	2020-02-27 14:11:14	2020-02-27	Mrs. Ilah Hackett DDS	mrs.ilah.hackett.dds@geemail.com	Everett	Washington	4420707663105015	58872367ce677512a24688b498464687	Mastercard	47.8791240058265615	-122.240455517045788
13692	2020-02-27 14:36:28	2020-02-27	Ellamae Kohler	ellamae.kohler@geemail.com	San Francisco	California	54690228497288128	1f3580fa6ceb0d4b63427cf83478de5b	Diners Club / Carte Blanche	37.7669249137725132	-122.431276798240916
13693	2020-02-27 15:13:00	2020-02-27	Dr. Adolph Cremin	dr.adolph.cremin@geemail.com	Spokane	Washington	4289305077210230	96c9b5274757d00273f2a18d2a601d0e	Voyager	47.6366045779321325	-117.373752889027074
13694	2020-02-27 15:23:08	2020-02-27	Mrs. Ruby Orn MD	mrs.ruby.orn.md@geemail.com	Fargo	North Dakota	6011361376694864262	6de08fb86d88f46d62c1108d11d84cce	Voyager	46.8165220274355249	-96.9075327116958789
13695	2020-02-27 15:54:30	2020-02-27	Andreas Durgan	andreas.durgan@woohoo.com	Edison	New Jersey	3528294804128288412	ee878df6f7e4362c52e6e6c7a5bb9f3a	American Express	40.4665366852618718	-74.4443923248961568
13696	2020-02-27 15:56:21	2020-02-27	Dr. Winnie Halvorson DDS	dr.winnie.halvorson.dds@geemail.com	San Francisco	California	51104832054587226	fde429e6ebc28c1e8c65c39012b3cf41	Discover	37.7507361843052891	-122.417897466091887
13697	2020-02-27 16:02:38	2020-02-27	Loy Hauck	loy.hauck@geemail.com	Berkeley	California	561217132420823	a9bc3fc5e4cf09982429564b3aca8e23	Mastercard	37.8716889473417027	-122.272623500230395
13698	2020-02-27 16:15:38	2020-02-27	Karolyn Lueilwitz	karolyn.lueilwitz@geemail.com	Rochester	Minnesota	210086212730431382	8804e7d3138fcd4c51eda7ef8ecd1e2d	JCB 16 digit	44.0669407698228923	-92.3856301549009942
13699	2020-02-27 16:27:27	2020-02-27	Kourtney Beer	kourtney.beer@woohoo.com	Odessa	Texas	3096631768027710622	5cd9fcf1efb93a892f3ad1232eb97a4f	American Express	31.9024196657363319	-102.416988923602176
13700	2020-02-27 16:47:24	2020-02-27	Holmes Hamill	holmes.hamill@geemail.com	Austin	Texas	180024662326580494	c4d5c7ab98b0643558fc0189ee574129	VISA 16 digit	30.3378823447167854	-97.7248080201685525
13701	2020-02-27 16:49:52	2020-02-27	Bethel Wilkinson	bethel.wilkinson@warmmail.com	New York	New York	869947759511596369	fc913f30f1d523288f19999d13d88b4d	American Express	40.6501706824861486	-73.8858894829068333
13702	2020-02-27 17:03:10	2020-02-27	Ragna Lakin	ragna.lakin@woohoo.com	Milwaukee	Wisconsin	6011102403645095723	041293e069f0e0a4137f0456af242fd9	Diners Club / Carte Blanche	43.1593826106835152	-87.9281640996791509
13703	2020-02-27 17:22:37	2020-02-27	Ms. Dannie Funk	ms.dannie.funk@warmmail.com	Fort Collins	Colorado	6011434982676602183	c113917cafc9c70d556050872142768b	VISA 13 digit	40.6268757078021778	-105.142502168095859
13704	2020-02-27 17:27:31	2020-02-27	Alida Hickle	alida.hickle@geemail.com	San Francisco	California	4089524902174708	26b71b6bdd643971a66c8d450ed4bf78	Voyager	37.8005730622562695	-122.449291540704351
13705	2020-02-27 17:38:48	2020-02-27	Braulio Schimmel	braulio.schimmel@geemail.com	Portland	Oregon	4768791395488	56696694d3351260f63b3f97078a2caa	VISA 16 digit	45.5448431985341031	-122.58601391995326
13706	2020-02-27 17:41:50	2020-02-27	Dr. Ingeborg Schaden	dr.ingeborg.schaden@woohoo.com	San Francisco	California	54461239566060774	883fd10a31d66bbf3344d0c7ed95f715	Voyager	37.7610329308277812	-122.412621823149038
13707	2020-02-27 17:44:38	2020-02-27	Talon Stroman	talon.stroman@geemail.com	Oakland	California	4629975821261	830d03c06afda6a1a47bb2f0dd3f6637	American Express	37.817591713302761	-122.261202825186459
13708	2020-02-27 17:59:38	2020-02-27	Ms. Arley Mohr	ms.arley.mohr@geemail.com	Los Angeles	California	3088586572622648574	e60f44df469bcfdaae1173887c46cbf5	Diners Club / Carte Blanche	34.1053245074912894	-118.335784781816599
13709	2020-02-27 18:11:03	2020-02-27	Illa Emmerich-Little	illa.emmerich.little@geemail.com	Kansas City	Missouri	676258847678776	70b5b4eeb0435319804b43d91bc9cb4d	VISA 16 digit	39.1709009460475315	-94.4729139178283503
13710	2020-02-27 18:13:22	2020-02-27	Jamaal Walsh-Satterfield	jamaal.walsh.satterfield@woohoo.com	Columbus	Ohio	3742897949714173	a985942c2dfb7fe4f6636dc838827c87	Voyager	40.0098999261900801	-82.9603084998905729
13711	2020-02-27 18:36:44	2020-02-27	Nyla Strosin	nyla.strosin@geemail.com	New York	New York	869948424752063392	43b224f2aaf763193dd6d5c11d09c4bd	Discover	40.7426229395661466	-73.8731446316361371
13712	2020-02-27 18:52:30	2020-02-27	Mr. Willy VonRueden	mr.willy.vonrueden@geemail.com	Nashville	Tennessee	53449442688832164	b639ae0013b8a01c13a723586263f28c	Diners Club / Carte Blanche	36.1849632610689795	-86.7052704855240819
13713	2020-02-27 19:27:20	2020-02-27	Denese Gulgowski	denese.gulgowski@geemail.com	Houston	Texas	3449755182804817	b3b0e6d80fb3d463e386df9fbd1e22f6	VISA 16 digit	29.8673618172839284	-95.3059197405833771
13714	2020-02-27 19:35:05	2020-02-27	Mr. Matias Bergstrom DDS	mr.matias.bergstrom.dds@geemail.com	Fort Worth	Texas	3734591228574610	7945bf1b7055e8c2739fd4c299026d85	VISA 16 digit	32.8576731776874524	-97.3429614601477908
13715	2020-02-27 19:42:31	2020-02-27	Kanesha Schmeler	kanesha.schmeler@geemail.com	Dallas	Texas	502070969153447	b3215fd5cb8691ee65df086fdf7c425b	Voyager	32.8299272721905311	-96.7032540768347673
13716	2020-02-27 20:00:46	2020-02-27	Beatrice Dare MD	beatrice.dare.md@geemail.com	Gilbert	Arizona	180098122327581406	7510f2864edc058361bb2fedf31c41cf	VISA 16 digit	33.329737117082999	-111.763757043904064
13717	2020-02-27 20:03:52	2020-02-27	Zenobia Harvey	zenobia.harvey@geemail.com	New York	New York	210063488541954583	a65614c0dafedf3a2193616fb43cd801	Mastercard	40.6615431791394926	-73.8991015324730398
13718	2020-02-27 20:05:44	2020-02-27	Tahj Kozey	tahj.kozey@geemail.com	Oakland	California	6011743039605770270	ec2edb51eccacc45eee46d654a2e5535	VISA 13 digit	37.789791167629815	-122.236170223635867
13719	2020-02-27 20:11:48	2020-02-27	Ms. Tinnie Ferry MD	ms.tinnie.ferry.md@geemail.com	Lowell	Massachusetts	3049064910271599	bdd7698318ff992132e42ffe51138869	JCB 15 digit	42.6200873444192112	-71.4114983940370394
13720	2020-02-27 20:30:53	2020-02-27	Octavia Stoltenberg PhD	octavia.stoltenberg.phd@warmmail.com	Yonkers	New York	4257195509431	6288efdd7e0a941ca778c0294c7c8704	Voyager	41.0330308548375982	-73.8589993997827179
13721	2020-02-27 20:41:08	2020-02-27	Vonnie Cummings MD	vonnie.cummings.md@geemail.com	New York	New York	630482420995134	84fa4dbd0eb0202741fa29b1aa51324a	JCB 15 digit	40.7075200180746606	-74.0254986309807776
13722	2020-02-27 20:42:21	2020-02-27	Elmer Quitzon	elmer.quitzon@geemail.com	Pittsburgh	Pennsylvania	4482049345193712	faeb74ba17f3678a6ca36b95b49f88e9	VISA 13 digit	40.5056458342775656	-80.0023413131650614
13723	2020-02-27 20:42:33	2020-02-27	Micky Bashirian	micky.bashirian@geemail.com	Reno	Nevada	4918300974998	d6d23dcb15076bf7f19e5a7554cbae4d	Mastercard	39.6332161892749397	-119.878369592006877
13724	2020-02-27 21:07:31	2020-02-27	Anderson Tremblay-Osinski	anderson.tremblay.osinski@woohoo.com	Sacramento	California	869912439536838440	3baa90926a1f953b8d5529ee49dc6932	JCB 16 digit	38.540076427886639	-121.375813768642388
13725	2020-02-27 21:15:42	2020-02-27	Makenzie Schmidt	makenzie.schmidt@geemail.com	New York	New York	630498412082533	87c367de7a4aedc154eb77707cf4667c	Voyager	40.5776801056452072	-73.8540342368081184
13726	2020-02-27 21:16:42	2020-02-27	Dr. John Reichert III	dr.john.reichert.iii@geemail.com	Frisco	Texas	3481588849853797	5b694563d10fd7ddf83191805b3eba99	JCB 16 digit	33.1356638959605263	-96.7437663661990257
13727	2020-02-27 21:18:00	2020-02-27	Maury Renner I	maury.renner.i@geemail.com	Waterbury	Connecticut	3528889688218338737	bc9f81071a45ee6426838b4150b6095e	VISA 16 digit	41.4783631465900697	-73.0539406111843874
13728	2020-02-27 21:23:56	2020-02-27	Mr. Luke Ferry DDS	mr.luke.ferry.dds@warmmail.com	Los Angeles	California	502072131478223	de54426e1357d115e3e9fa3e3cd8d2a2	JCB 16 digit	33.9812084129877334	-118.34354724027142
13729	2020-02-27 21:30:59	2020-02-27	Stormy Carter	stormy.carter@geemail.com	Fort Lauderdale	Florida	639072257372580	28e35ac9754e0a966884d9f6e4992155	Maestro	26.2165648789599537	-80.1657557268448073
13730	2020-02-27 21:42:36	2020-02-27	Ms. Rosella Goyette	ms.rosella.goyette@geemail.com	Jacksonville	Florida	4475171111176	c53085f48439abc830e01ed7275ee21c	VISA 16 digit	30.3225557744089507	-81.600338298183317
13731	2020-02-27 22:24:08	2020-02-27	Dr. Wess Runolfsson Jr.	dr.wess.runolfsson.jr.@woohoo.com	Oakland	California	3042103895935617	9a9e8cb7942d691b5a6e35d718a9d6d5	JCB 16 digit	37.8246859001088467	-122.244176673055065
13732	2020-02-27 22:41:33	2020-02-27	Russell Daugherty	russell.daugherty@geemail.com	San Francisco	California	4800605215074640	84920b9813ab5ecd054371b220f2a0f7	American Express	37.7595036317121711	-122.452692110323355
13733	2020-02-27 23:00:34	2020-02-27	Vito Feest MD	vito.feest.md@woohoo.com	San Francisco	California	53679377128831544	e77ed42f123d783ba3f56bf8e5cff8ae	VISA 13 digit	37.7827306132940066	-122.402581935808996
13734	2020-02-27 23:24:30	2020-02-27	Valarie Heathcote	valarie.heathcote@geemail.com	Nashville	Tennessee	3461217416489843	03d0e75da32bc7f2a6602380665d0687	JCB 15 digit	36.2250595593016556	-86.8467849444039075
13735	2020-02-27 23:45:11	2020-02-27	Willis Murazik	willis.murazik@woohoo.com	Fullerton	California	3039255521269507	699e3d0c743b91e0e3f3368a487e1aa2	Mastercard	33.9587227594263865	-117.988711755324147
13736	2020-02-27 23:51:37	2020-02-27	Miss Dorothea DuBuque	miss.dorothea.dubuque@geemail.com	Oakland	California	3112092745384104906	5934b08d6471abc9ba9e1a70500c9679	Maestro	37.8224757285607325	-122.253918707133863
13737	2020-02-28 00:05:42	2020-02-28	Bria Deckow	bria.deckow@woohoo.com	New York	New York	4560124272017	8826471904981200db111ea85f5e7b15	JCB 16 digit	40.5777828733660257	-73.9787126717053383
13738	2020-02-28 00:07:06	2020-02-28	Lindsey Marquardt-Kozey	lindsey.marquardt.kozey@geemail.com	Charlotte	North Carolina	6011909465287394834	808305f55af14a807264a8c539f21955	VISA 16 digit	35.2124193749643837	-80.8336742235291723
13739	2020-02-28 00:15:28	2020-02-28	Mrs. Shaniqua Rolfson	mrs.shaniqua.rolfson@warmmail.com	Dallas	Texas	3096663796558331477	2d0389fbc378bb4b16707be201477526	VISA 16 digit	32.8898458839200458	-96.8479811877906229
13740	2020-02-28 00:21:38	2020-02-28	Reatha Weissnat	reatha.weissnat@geemail.com	San Francisco	California	869938126470184044	5e96d8f978214a6ae52f6d329d9aad99	Diners Club / Carte Blanche	37.7909586333206562	-122.42538893194542
13741	2020-02-28 00:22:38	2020-02-28	Mrs. Sharee Steuber	mrs.sharee.steuber@geemail.com	San Francisco	California	51175320139214317	530eedf4e0f0684c2360e88cf878157d	Discover	37.7616189846878001	-122.445734972397887
13742	2020-02-28 00:27:27	2020-02-28	Kaden Gislason	kaden.gislason@geemail.com	Los Angeles	California	180024226836115645	c2b3630acf3e71ed86d3c9f8be5c40ff	American Express	34.07399265056997	-118.362449630581949
13743	2020-02-28 00:34:28	2020-02-28	Hilda Senger	hilda.senger@geemail.com	Philadelphia	Pennsylvania	503890477583661	10c2f86175ca28cbcdab1bf5b32bf4f3	Voyager	40.071878956114503	-75.07936511499733
13744	2020-02-28 00:43:36	2020-02-28	Azalee Willms	azalee.willms@woohoo.com	Omaha	Nebraska	676377720901550	b5d21625b3158cb02e5ed1535aaf1bc5	Voyager	41.2956540572136674	-96.0861606112796807
13745	2020-02-28 00:46:49	2020-02-28	Deon Schmidt-Greenfelder	deon.schmidt.greenfelder@warmmail.com	San Antonio	Texas	869998715550475434	ddb9cc98c697771418a2b1afa09a0547	Discover	29.3775509788725522	-98.5723378598991786
13746	2020-02-28 00:59:58	2020-02-28	Chandra Brakus	chandra.brakus@woohoo.com	New Haven	Connecticut	6011111120722724418	dbae9616cb4239e12ed02c63aa735a18	VISA 13 digit	41.2126616746179764	-73.0072597084566866
13747	2020-02-28 01:02:03	2020-02-28	Mrs. Myrna Tillman MD	mrs.myrna.tillman.md@geemail.com	Glendale	Arizona	4674722715838	d9e4e17e381fb70fc38df7bc746b18a4	VISA 16 digit	33.547652518539131	-112.24628960660435
13748	2020-02-28 01:02:48	2020-02-28	Jarett Watsica	jarett.watsica@geemail.com	New York	New York	4176263063487	e4e1291c76423ebb677290fb080fc992	Discover	40.5799504024200104	-73.8724788977194606
13749	2020-02-28 01:45:09	2020-02-28	Cherish Nolan	cherish.nolan@woohoo.com	Gilbert	Arizona	4244250080049569	fc5810eb47a9f405cd417635798b0673	VISA 13 digit	33.2110529645692552	-111.728637170385937
13750	2020-02-28 01:48:50	2020-02-28	Wallace Lakin	wallace.lakin@woohoo.com	Hillsboro	Oregon	4924974914927644	d449aab2c224199f7ca15b8f96782701	VISA 16 digit	45.4599005720317351	-122.917173897164687
13751	2020-02-28 01:57:54	2020-02-28	Arnoldo Brown	arnoldo.brown@geemail.com	San Francisco	California	53449261019876777	185370188c61895f6880ece3eedfb12a	Diners Club / Carte Blanche	37.7783261340271395	-122.42364644195743
13752	2020-02-28 01:59:31	2020-02-28	Louanna Bergstrom PhD	louanna.bergstrom.phd@woohoo.com	Milwaukee	Wisconsin	869907090862360363	89282e25b57b816a3040460624c6c2c3	VISA 13 digit	43.0262441948607517	-87.8959001925408927
13753	2020-02-28 02:25:09	2020-02-28	Christi Gutmann	christi.gutmann@geemail.com	Newark	New Jersey	6011304381882843227	aa8ec67f931f46f0a33b6936fa8821fb	Diners Club / Carte Blanche	40.732787273070592	-74.1042259657498477
13754	2020-02-28 02:29:00	2020-02-28	Judie Beatty-Oberbrunner	judie.beatty.oberbrunner@warmmail.com	Los Angeles	California	52121129435951125	9c9b9aa969dfc874bad667ac8cd9d934	Maestro	33.9555942392773886	-118.315156652731076
13755	2020-02-28 02:30:01	2020-02-28	Carlo Douglas	carlo.douglas@geemail.com	Berkeley	California	3112734994550332628	41ec74081905addf516a6266dbe37037	Discover	37.8484719213980227	-122.266942314030075
13756	2020-02-28 02:38:26	2020-02-28	Dellar Boyle PhD	dellar.boyle.phd@warmmail.com	Hartford	Connecticut	869970047505698890	61de40bfeb1990bfb3c2deb9554212a2	Maestro	41.7525762056481113	-72.7711770625677019
13757	2020-02-28 02:46:26	2020-02-28	Vera Parisian	vera.parisian@geemail.com	San Francisco	California	869980850471112319	900726e5471188ac21271b3f19b295c6	Mastercard	37.7539867216051803	-122.422041175570499
13758	2020-02-28 02:55:45	2020-02-28	Dejuan Lehner	dejuan.lehner@geemail.com	Sacramento	California	55129204599755117	db9c0b7b6192bb11dd7851403b429596	American Express	38.5930939363580237	-121.551527964813999
13759	2020-02-28 02:56:27	2020-02-28	Zeta Braun PhD	zeta.braun.phd@geemail.com	San Diego	California	3457780721031010	b7a3e5616e4a8370aabda5211978c416	Maestro	32.7185429146580375	-117.14443954959512
13760	2020-02-28 02:58:34	2020-02-28	Elvis Huel	elvis.huel@geemail.com	San Francisco	California	3438523032361013	ca8cdedc7aca70626c1466ccddea8e11	VISA 16 digit	37.7729388086192372	-122.414276080424315
13761	2020-02-28 03:11:37	2020-02-28	Lizette Jenkins-Collier	lizette.jenkins.collier@geemail.com	Denver	Colorado	3337579641702580350	455e4652eb4dad14e2d9adc9698d516c	VISA 16 digit	39.7581635730393188	-104.803721040977535
13762	2020-02-28 03:16:18	2020-02-28	Manly Wyman	manly.wyman@warmmail.com	San Francisco	California	6011643046461510287	58eb6399821de26b33000141fc9d040f	Maestro	37.787587485760433	-122.427856325535529
13763	2020-02-28 03:29:22	2020-02-28	Blas Braun-Gaylord	blas.braun.gaylord@geemail.com	Detroit	Michigan	4668645663570	2b95c961b6403e5d39b8d3c535344987	JCB 15 digit	42.3174966907985564	-83.1712793645568098
13764	2020-02-28 03:34:09	2020-02-28	Dr. Shelby Rogahn Jr.	dr.shelby.rogahn.jr.@warmmail.com	Houston	Texas	3528809148720674910	9cb316eb8ac580607895894bfb0ba735	VISA 16 digit	29.764475175001099	-95.4155856475714614
13765	2020-02-28 03:56:21	2020-02-28	Dianna O'Hara	dianna.o'hara@geemail.com	Dallas	Texas	3009664959065966	30724878fcde39a75ebdfe8cf2ae2319	VISA 16 digit	32.7222421705063482	-96.7984079176522698
13766	2020-02-28 04:06:41	2020-02-28	Cassie Windler	cassie.windler@woohoo.com	Los Angeles	California	3756605970905773	5dfda069d68e7050e913090c1bc03eb7	JCB 16 digit	33.9356112375255634	-118.456387612222869
13767	2020-02-28 04:11:21	2020-02-28	Mrs. Ashanti Cremin MD	mrs.ashanti.cremin.md@geemail.com	Oakland	California	4146046854767	d598e23175c3b2cb3673f7ec3d3a1a47	VISA 16 digit	37.8499065501948451	-122.279031048210427
13768	2020-02-28 04:14:42	2020-02-28	Latoya Skiles-Altenwerth	latoya.skiles.altenwerth@geemail.com	Tempe	Arizona	210079485646409655	df98e38fc61062cec00a23d989b8e9d4	VISA 16 digit	33.3748264839794473	-111.903559878518053
13769	2020-02-28 04:15:14	2020-02-28	Needham Schulist PhD	needham.schulist.phd@geemail.com	Tallahassee	Florida	210054453587751492	c81b33c17c913a561b705a0fe68cf832	American Express	30.3878615666203231	-84.340157998727264
13770	2020-02-28 04:31:05	2020-02-28	Ms. Kelsey Thompson	ms.kelsey.thompson@geemail.com	New York	New York	589339931653107	53133450bdf39bbfad59afe9c6da28c1	JCB 16 digit	40.6582975714225299	-73.9508089107356881
13771	2020-02-28 04:33:25	2020-02-28	Dr. Zaria Donnelly DDS	dr.zaria.donnelly.dds@geemail.com	San Francisco	California	180049412791636095	d8a064114c47f40d53ca33febf8b6db9	Voyager	37.7631305285287198	-122.464584904688479
13772	2020-02-28 04:33:41	2020-02-28	Fawn Pollich	fawn.pollich@geemail.com	San Francisco	California	210051633719413045	382eaffc71da40bd30e3b749c3f307db	Diners Club / Carte Blanche	37.7415567695808392	-122.432022404480222
13773	2020-02-28 04:40:00	2020-02-28	Jannie Feeney MD	jannie.feeney.md@geemail.com	Detroit	Michigan	53113184353364462	c954519e6f868841312ea444ffe05b7b	Voyager	42.3546204521246281	-83.0190494406156176
13774	2020-02-28 05:09:35	2020-02-28	Fae Romaguera	fae.romaguera@geemail.com	Fresno	California	3096818638481001161	0e26455b08e16e04f7c4ae5f898ccfc2	VISA 13 digit	36.8092918935105189	-119.841653230471167
13775	2020-02-28 05:20:12	2020-02-28	Mr. Jakobe Franecki Jr.	mr.jakobe.franecki.jr.@warmmail.com	Sterling Heights	Michigan	3158887554081957197	d3f465a12414e1892272b5e177350241	American Express	42.5576733981806825	-82.9560698048371847
13776	2020-02-28 05:28:25	2020-02-28	Rafaela Legros-Willms	rafaela.legros.willms@geemail.com	Austin	Texas	3158829600300480130	5915f3d601c990c3634c9f8bcc9d58fe	JCB 15 digit	30.3191610839344534	-97.6907978717010508
13777	2020-02-28 05:49:48	2020-02-28	Keon Rowe	keon.rowe@geemail.com	Eugene	Oregon	3112381012025294806	e5126b8facbfafb29a2ea3fc728d8893	JCB 15 digit	44.1053290169879801	-123.177912431209165
13778	2020-02-28 05:59:19	2020-02-28	Reinaldo Kessler-Hahn	reinaldo.kessler.hahn@geemail.com	Saint Paul	Minnesota	4255546593443	6cf946f576bc4bf9599d33cf9de1af2e	American Express	44.9495981845945138	-93.0124243441768073
13779	2020-02-28 06:47:38	2020-02-28	Erastus Mante	erastus.mante@woohoo.com	Tampa	Florida	3783641928832089	849435b004dd6911e6e9131e69c2f3a1	Discover	27.980777385656161	-82.4263821395792036
13780	2020-02-28 07:26:23	2020-02-28	Tea Fritsch	tea.fritsch@warmmail.com	Berkeley	California	4076155153249074	bfb076dea9c84d62884ef171b69bb688	Voyager	37.8962706575355881	-122.244377521521429
13781	2020-02-28 07:28:42	2020-02-28	Norris Hammes	norris.hammes@geemail.com	Phoenix	Arizona	180078741950916938	3b14aa321498566fc10fa1fd3988f161	VISA 16 digit	33.6699425637189336	-112.056688412877179
13782	2020-02-28 07:39:52	2020-02-28	Mr. Jackson Ankunding	mr.jackson.ankunding@geemail.com	Long Beach	California	869920198226709358	7b0b52de70d9fd21488c9baef5965ce7	Voyager	33.8541706878047393	-118.171193688844511
13783	2020-02-28 08:13:20	2020-02-28	Owen Heaney	owen.heaney@geemail.com	Los Angeles	California	3158508808450938108	18717453172c95e2e054128462319bdb	JCB 15 digit	33.9391302766144278	-118.409240251220012
13784	2020-02-28 08:33:42	2020-02-28	Fronnie Kshlerin DDS	fronnie.kshlerin.dds@woohoo.com	Atlanta	Georgia	3703539743585154	610eb0d3164021a31f5ba293b5c4d97a	VISA 16 digit	33.679814862766861	-84.3881521551914631
13785	2020-02-28 08:46:46	2020-02-28	Grove Gleason III	grove.gleason.iii@warmmail.com	San Francisco	California	6011653753415486467	36459e7e223bb8f250d941794b40a343	Voyager	37.7665166629139577	-122.433429355626657
13786	2020-02-28 08:47:28	2020-02-28	Kahlil Lesch-Cruickshank	kahlil.lesch.cruickshank@geemail.com	Warren	Michigan	53404192717501024	b714fc74f42315e95812d9f08f8cb486	JCB 16 digit	42.5821160844989137	-83.0738391955848812
13787	2020-02-28 09:04:24	2020-02-28	Rian Kreiger	rian.kreiger@geemail.com	Corpus Christi	Texas	4236101246268488	53094ff5e290b21ade3870a3b96b3f74	Discover	27.7645226510643965	-97.2350690243128639
13788	2020-02-28 09:10:22	2020-02-28	Denver Schmidt DVM	denver.schmidt.dvm@geemail.com	San Diego	California	6011551634212766678	b402b58e9437d5f3742d79d8b187ebbb	Discover	32.8115705024983768	-117.151685784561565
13789	2020-02-28 09:17:52	2020-02-28	Elon Greenholt	elon.greenholt@geemail.com	Surprise	Arizona	3528920222889317225	8f7bee21f299797b38c6a04191dbfcb8	VISA 16 digit	33.591101520996915	-112.489356417325126
13790	2020-02-28 10:14:37	2020-02-28	Randolf Barton	randolf.barton@geemail.com	Washington	District of Columbia	53288941972190381	57d4d4838524677eacd8ac53d92cf143	Mastercard	38.9753359077297148	-76.9581660346806018
13791	2020-02-28 10:16:59	2020-02-28	Mr. Howell Hilpert Sr.	mr.howell.hilpert.sr.@warmmail.com	Gresham	Oregon	3433887069385905	75ff450da8acc38dcbd5413bfd060ff0	VISA 16 digit	45.4261071466796054	-122.539028216785184
13792	2020-02-28 10:19:43	2020-02-28	Mr. Theodore Ernser	mr.theodore.ernser@geemail.com	San Francisco	California	3528709476503414175	25ff245325629d16fbfc5c260b5b23fa	JCB 16 digit	37.7927290306981689	-122.445937172787751
13793	2020-02-28 10:22:28	2020-02-28	Kristyn Wiegand	kristyn.wiegand@warmmail.com	Anchorage	Alaska	51774902473141555	2fea30f148ffa52f1392953e17d7445e	Discover	61.1220175403852011	-149.262489995698644
13794	2020-02-28 10:23:45	2020-02-28	Jimmie Rutherford-Corkery	jimmie.rutherford.corkery@geemail.com	Abilene	Texas	3528835826118361574	5babcecc58aafcc2891e4ebbb1b9a3cd	VISA 13 digit	32.412039850845936	-99.766930975387254
13795	2020-02-28 10:32:14	2020-02-28	Joelle Lubowitz	joelle.lubowitz@geemail.com	Louisville	Kentucky	4197116172044	250f05f548b47bff0db634d4169093f1	Maestro	38.1731913383021961	-85.7444101994928047
13796	2020-02-28 10:51:43	2020-02-28	Rashaan Murazik	rashaan.murazik@geemail.com	College Station	Texas	3045890873177264	4e8fee087d47aa90b3da4cf0f6fdc84d	VISA 16 digit	30.6054866199892004	-96.2344556721240281
13797	2020-02-28 10:57:56	2020-02-28	Moises Hammes	moises.hammes@geemail.com	Albuquerque	New Mexico	3112509345975155040	57bae4a501a1c71e5ee299e599740bc4	Diners Club / Carte Blanche	35.0996281378105337	-106.554251535383614
13798	2020-02-28 11:03:19	2020-02-28	Art Mante-Kuhlman	art.mante.kuhlman@geemail.com	El Paso	Texas	3112967519965331705	2e13e50e2f4e92fc3075325a126050e8	Mastercard	31.7964710011906924	-106.424970076790089
13799	2020-02-28 11:15:13	2020-02-28	Braydon D'Amore	braydon.d'amore@geemail.com	Berkeley	California	180092365426985889	88050a10c7566f18552d48fb3d7fa4f3	VISA 16 digit	37.8867464966822141	-122.259963548573609
13800	2020-02-28 11:46:15	2020-02-28	Buna Jast	buna.jast@geemail.com	Atlanta	Georgia	3096934371406628467	8f16c552cc81b250fa6430b233341104	JCB 16 digit	33.7889907079093206	-84.4925328117374335
13801	2020-02-28 11:49:06	2020-02-28	Roxy Stokes DDS	roxy.stokes.dds@geemail.com	New York	New York	3528309299305532026	a64828f5b8a8e3e24a09fe2bb8a704f5	VISA 13 digit	40.662644191993401	-73.8672063615068737
13802	2020-02-28 11:50:06	2020-02-28	Dr. Marion Turcotte DDS	dr.marion.turcotte.dds@woohoo.com	New York	New York	3112768903975660322	dac648ee137ff8094896c811b43300e3	Maestro	40.7130487301610415	-73.9241725748300524
13803	2020-02-28 11:51:00	2020-02-28	Polly Friesen MD	polly.friesen.md@geemail.com	Louisville	Kentucky	51656311678336890	93b64ec0d69847e1eb094e92b6f059de	Mastercard	38.2387848618343469	-85.7330026063673216
13804	2020-02-28 12:12:01	2020-02-28	Pedro Kerluke	pedro.kerluke@geemail.com	El Paso	Texas	3019035160747124	1d0d992c6867963fad7b9ef8b6a5b934	Mastercard	31.9205705353353189	-106.497771791320304
13805	2020-02-28 12:21:29	2020-02-28	Jacquline Jacobson	jacquline.jacobson@geemail.com	San Francisco	California	3158838567672182561	1d9defb8ec6bc44828c4c3b4991aedb4	Discover	37.7611249511385907	-122.405473898576602
13806	2020-02-28 12:21:43	2020-02-28	Michal Nienow PhD	michal.nienow.phd@geemail.com	San Francisco	California	4182061065724	6ae6202e1df44549919bb3d57df9363b	Voyager	37.7764196733888369	-122.427200447671268
13889	2020-02-29 05:25:47	2020-02-29	Ambrose Daugherty	ambrose.daugherty@woohoo.com	Fort Worth	Texas	51244637825023612	61695b80bb02324442be905b62a1e46c	VISA 16 digit	32.7902044322863233	-97.2629776242941659
13807	2020-02-28 12:28:59	2020-02-28	Zander Morissette	zander.morissette@geemail.com	Hillsboro	Oregon	4536340173536	26c0e26a47e5ae49370ccfce98960d72	Diners Club / Carte Blanche	45.5090366076882944	-123.021630355871096
13808	2020-02-28 12:31:35	2020-02-28	Icey Fay	icey.fay@geemail.com	Chicago	Illinois	3337173033627461934	20ecd4ce48a9497e04ae717e0f2e0e2d	Maestro	41.8676053338985881	-87.6793705082062615
13809	2020-02-28 12:42:41	2020-02-28	Burnice Lueilwitz	burnice.lueilwitz@geemail.com	Oakland	California	3772716763007428	19a4ee66181a44c93bc243f48ff51bc7	VISA 16 digit	37.7936610284374339	-122.300005583957386
13810	2020-02-28 12:52:51	2020-02-28	Chadd Wuckert	chadd.wuckert@woohoo.com	Salem	Oregon	639046231952949	c93e43c9a91c52f20542121a0a677c5a	JCB 15 digit	44.8802333780366922	-123.004558844600624
13811	2020-02-28 13:00:41	2020-02-28	Mr. William Johnston	mr.william.johnston@geemail.com	Fort Worth	Texas	180053842714545010	2057d58c877f714c2ca7b0f270f478fb	VISA 16 digit	32.8801179584637282	-97.3569332353591932
13812	2020-02-28 13:04:34	2020-02-28	Mrs. Margery Huel	mrs.margery.huel@geemail.com	Seattle	Washington	3158624976153606188	ec5e312086b0a5798a21fc9a6828602c	VISA 13 digit	47.7180321832112995	-122.290016324996571
13813	2020-02-28 13:04:38	2020-02-28	Kobe Kautzer	kobe.kautzer@geemail.com	Los Angeles	California	502014394412499	74b24461944f86543b9b89bb5c5621ba	VISA 16 digit	34.0755160810291713	-118.351341021432717
13814	2020-02-28 13:16:00	2020-02-28	Elda Jast	elda.jast@geemail.com	Lexington	Kentucky	6011890055706986350	2ab84dc2501f56c9cecf3a05b4a06ef8	Voyager	38.1010739925660218	-84.4686565679863008
13815	2020-02-28 13:19:33	2020-02-28	Lulah Hermann PhD	lulah.hermann.phd@warmmail.com	New York	New York	503864585148097	e2c4c7e1fe7da4f79287f16d62103e46	Diners Club / Carte Blanche	40.5689830804001517	-74.0164097733225645
13816	2020-02-28 13:29:08	2020-02-28	Job Beahan	job.beahan@warmmail.com	Salem	Oregon	6011744786559656314	597f9928331baf2393bffa4c764f4c2f	VISA 13 digit	44.9998956666596186	-123.011422639309245
13817	2020-02-28 13:45:03	2020-02-28	Estefany Kshlerin	estefany.kshlerin@warmmail.com	New York	New York	4944828098578639	e4bcb4769a35c0833f24b5d5721e5396	American Express	40.6009589018523656	-73.9969877926062765
13818	2020-02-28 14:21:52	2020-02-28	Mr. Jaden Kassulke	mr.jaden.kassulke@woohoo.com	Elk Grove	California	3029726008739287	33b31adec4f6569d19b72e7f074bb0b4	Maestro	38.4899077734727442	-121.2971238602791
13819	2020-02-28 14:41:52	2020-02-28	Dr. Oakley Conroy V	dr.oakley.conroy.v@geemail.com	Chicago	Illinois	6011083032964268158	bc65ec2b1972d4784ad39dbc5cec30f3	JCB 16 digit	41.901248943929005	-87.6679697144340651
13820	2020-02-28 15:07:13	2020-02-28	Dr. Harry Hermann	dr.harry.hermann@geemail.com	Chattanooga	Tennessee	561251655811688	6167b428c5e1d5974829bce47d66fe8b	VISA 16 digit	34.998012397190557	-85.1822274517096645
13821	2020-02-28 15:21:47	2020-02-28	Antonia O'Reilly	antonia.o'reilly@geemail.com	San Francisco	California	3799760532416022	265d972c8d00d28ed4f69c9f27e34a43	Discover	37.7723979409278741	-122.436758844683709
13822	2020-02-28 15:27:50	2020-02-28	Elba Buckridge MD	elba.buckridge.md@geemail.com	San Francisco	California	869964611625949141	01820f6eeee82a5824aee66ab3fe5432	JCB 15 digit	37.7933616874326361	-122.466045667747878
13823	2020-02-28 15:41:08	2020-02-28	Dr. Severo Bergnaum	dr.severo.bergnaum@geemail.com	Houston	Texas	4218417379334	bfa59841a7fd7e1863793cb79f82250a	Mastercard	29.7995588850308195	-95.3861830895315848
13824	2020-02-28 16:00:05	2020-02-28	Dr. Pershing Frami IV	dr.pershing.frami.iv@geemail.com	New York	New York	4599983994882912	b8f9d69d60da5a6147a2b021b1e253c1	Maestro	40.6855808687154195	-73.8661307115003467
13825	2020-02-28 16:50:23	2020-02-28	Piper Aufderhar-Okuneva	piper.aufderhar.okuneva@woohoo.com	Shreveport	Louisiana	869901843337736476	813f4d6a89ed2f775f6ec0aa96860eac	Discover	32.5513835629686739	-93.7990324128165724
13826	2020-02-28 16:55:17	2020-02-28	Fairy Hamill	fairy.hamill@geemail.com	Atlanta	Georgia	3337636413121083262	a8f64eac3de61b4534952187b1615d15	JCB 15 digit	33.760537876588856	-84.3993870619729165
13827	2020-02-28 17:11:22	2020-02-28	Dr. Lucretia Cassin DVM	dr.lucretia.cassin.dvm@geemail.com	Springfield	Missouri	4390088914262756	e30c64d6f05ad3ed0a21817c499e619c	Diners Club / Carte Blanche	37.2538949545666611	-93.3498000106133645
13828	2020-02-28 17:12:46	2020-02-28	Maverick Dicki	maverick.dicki@geemail.com	Tempe	Arizona	3017598882401231	eda149f5833baa6594f79dd2a9fbef5d	JCB 16 digit	33.3268966320823878	-112.031165394096817
13829	2020-02-28 17:21:52	2020-02-28	Mr. Bo McCullough	mr.bo.mccullough@geemail.com	Oklahoma City	Oklahoma	3031829825566137	386440749d41ad5041b0b58828e81bbf	Discover	35.4858566281762009	-97.5924043751217454
13830	2020-02-28 17:47:22	2020-02-28	Dr. Aleah Emmerich DDS	dr.aleah.emmerich.dds@warmmail.com	Grand Prairie	Texas	589336633328202	5fcf9a9363241d83a9d56cafbe7e1f36	American Express	32.7226575832866118	-97.0314434820659528
13831	2020-02-28 18:15:10	2020-02-28	Mr. Koby Becker	mr.koby.becker@geemail.com	New York	New York	3033280218986490	c2067e1babcc3d69b62e9579f6264996	VISA 16 digit	40.649515842435882	-73.9773570161674172
13832	2020-02-28 18:20:22	2020-02-28	Cullen Hayes Sr.	cullen.hayes.sr.@geemail.com	Oakland	California	630473524097372	b54ff244521e11f402c31b0132a9950d	JCB 15 digit	37.7969777089620749	-122.274931975066139
13833	2020-02-28 18:23:17	2020-02-28	Desirae Leuschke	desirae.leuschke@geemail.com	Austin	Texas	675913091505365	e894e8511272f3816b29ddd927aba4ef	VISA 16 digit	30.3004152778662714	-97.7384044253505806
13834	2020-02-28 18:26:17	2020-02-28	Mr. Lacy Leffler	mr.lacy.leffler@warmmail.com	Allen	Texas	3724280645151754	51b858f251f45a7a79946bf2cdea4eae	American Express	33.1065084547761828	-96.7085544131178381
13835	2020-02-28 19:13:46	2020-02-28	Alabama Torp DVM	alabama.torp.dvm@warmmail.com	San Francisco	California	180043432927006134	ddbf531fd0c4fb733e73a309db4f3801	Discover	37.7880135700808992	-122.46578850548282
13836	2020-02-28 19:26:55	2020-02-28	Bertie Watsica	bertie.watsica@warmmail.com	Sacramento	California	3096766637125176761	7336c7dd6002f331e6aae307a2204fd6	VISA 16 digit	38.5013037765197481	-121.547789188545565
13837	2020-02-28 19:54:43	2020-02-28	Mr. Hadley Gutkowski III	mr.hadley.gutkowski.iii@geemail.com	San Francisco	California	3112496081700858468	161aff03b7a0a2895204786025b63208	Voyager	37.7434073306604176	-122.44820322108869
13838	2020-02-28 20:00:43	2020-02-28	Ariane Dickinson	ariane.dickinson@geemail.com	San Francisco	California	3025132450145566	8f0f260f6b6f7812030940976d581e1d	JCB 15 digit	37.7681295223492768	-122.442767268330414
13839	2020-02-28 20:05:41	2020-02-28	Ms. Marleigh Ratke	ms.marleigh.ratke@geemail.com	Louisville	Kentucky	6011851034727446568	bb7910b697501a2728906979e70bc4d3	JCB 16 digit	38.2555077692862611	-85.5961036023288955
13840	2020-02-28 20:07:21	2020-02-28	Mrs. Livia Beer	mrs.livia.beer@geemail.com	Birmingham	Alabama	6011732893872603033	12b709a77b991bb5e2c4b012ee7824d2	Diners Club / Carte Blanche	33.6051859405614408	-86.7230703610703415
13841	2020-02-28 20:14:32	2020-02-28	Clair Schiller-Satterfield	clair.schiller.satterfield@warmmail.com	San Francisco	California	3031651058671545	69ef41272e6234ffde82dbbb156cdf39	Maestro	37.7786941512333172	-122.426360025262326
13842	2020-02-28 20:25:55	2020-02-28	Jabez Mayer DVM	jabez.mayer.dvm@geemail.com	Richardson	Texas	3782304833746545	45b6c5245f3ec9e84f52c7704a3b97b6	JCB 16 digit	32.9769034357976167	-96.7084783150576044
13843	2020-02-28 20:32:29	2020-02-28	Alyssia Runte-Hoppe	alyssia.runte.hoppe@geemail.com	Detroit	Michigan	6011334110777036553	fd999b1e50a762f2cd206bc64565ced3	VISA 16 digit	42.4333161542583284	-83.1403411032751194
13844	2020-02-28 20:38:31	2020-02-28	Minor Mertz	minor.mertz@woohoo.com	Berkeley	California	4356419965500	c3a94047c68befd0bffabd6bb8db622f	Discover	37.867457228329549	-122.320792367910272
13845	2020-02-28 20:51:07	2020-02-28	Lindbergh Koelpin	lindbergh.koelpin@warmmail.com	Boston	Massachusetts	4671446348751010	95b6455ba625fd9eeaabbeb1be881b30	Diners Club / Carte Blanche	42.3934947895985133	-71.1198600554324685
13846	2020-02-28 21:29:59	2020-02-28	Ernestina Runte	ernestina.runte@geemail.com	New York	New York	503824169519501	ede0087210630d868b23ae15f345ccd5	Maestro	40.6660749728083601	-73.943017613737652
13847	2020-02-28 21:32:12	2020-02-28	Darryn Jast II	darryn.jast.ii@geemail.com	Fort Wayne	Indiana	3447762105371975	de598b8040dc183807429c412a4e93a6	JCB 16 digit	41.1155801007308099	-85.1921698139734644
13848	2020-02-28 21:51:26	2020-02-28	Dr. Adelia Hessel DDS	dr.adelia.hessel.dds@geemail.com	Oklahoma City	Oklahoma	4191594947172418	518629a5719f98533b5e5d288293c828	VISA 16 digit	35.4611248378086827	-97.6090614160418539
13849	2020-02-28 21:55:01	2020-02-28	Dudley Lowe	dudley.lowe@geemail.com	Chicago	Illinois	3096040044608577284	e004740f90f23ad5e0e3936a26f3c485	JCB 16 digit	41.8529049936983739	-87.6447260203335361
13850	2020-02-28 22:16:56	2020-02-28	Marta Gaylord	marta.gaylord@woohoo.com	Ontario	California	3112675978455993387	24271de6d37ce0d0d22f7ab4e089a1e6	VISA 16 digit	33.9867185057286179	-117.616451726817346
13851	2020-02-28 22:27:34	2020-02-28	Margretta Hartmann MD	margretta.hartmann.md@geemail.com	Berkeley	California	51914484427790424	352d14042cfa356b1736569991addd29	Maestro	37.8609512615985651	-122.251272576724418
13852	2020-02-28 22:37:04	2020-02-28	Sondra Casper	sondra.casper@geemail.com	San Francisco	California	4901497775352	726d8ff74a53f70e7987147d866b82ae	Mastercard	37.7544142873409783	-122.431970481956881
13853	2020-02-28 22:39:12	2020-02-28	Wilbur Mertz	wilbur.mertz@geemail.com	San Francisco	California	3088360311443525519	e26c972817172859de0ba0165e6e548a	JCB 15 digit	37.7769330244236698	-122.4358967679145
13854	2020-02-28 22:40:27	2020-02-28	Mrs. Lakeisha Rolfson	mrs.lakeisha.rolfson@warmmail.com	Hampton	Virginia	53379441006199250	25e4e7501bcb902bfc5317f290e690c8	Voyager	36.9698548077624309	-76.3743178000770513
13855	2020-02-28 22:42:15	2020-02-28	Jasmyne Blick	jasmyne.blick@warmmail.com	San Francisco	California	869974630373183693	1773139b0e3b098cee24371f141fb64f	Voyager	37.7416347734194204	-122.435851407224661
13856	2020-02-28 22:49:06	2020-02-28	Shanita Hagenes	shanita.hagenes@geemail.com	Costa Mesa	California	4438145829897946	2600b33f9c6b4f515c7088900e22c152	Diners Club / Carte Blanche	33.6105229338645941	-117.829539587800582
13857	2020-02-28 23:07:40	2020-02-28	Ettie Ledner	ettie.ledner@geemail.com	Charlotte	North Carolina	3797706042383360	48ee7a2ff2705dde1462b93e02a9cdff	VISA 13 digit	35.1969301262192431	-80.8660146715995012
13858	2020-02-28 23:31:40	2020-02-28	Adrien Olson	adrien.olson@geemail.com	San Francisco	California	3002078991590286	7b2c0bfd6c49a57df6fca82b24fafe1d	Discover	37.77349342475528	-122.423516330137915
13859	2020-02-29 00:14:03	2020-02-29	Dr. Kelvin Paucek	dr.kelvin.paucek@geemail.com	San Francisco	California	4369197688642742	feb0c3eb6e8444e2a1f1e30559d2972d	JCB 15 digit	37.7794828785246324	-122.460840008111958
13860	2020-02-29 00:31:47	2020-02-29	Aletha Ondricka	aletha.ondricka@geemail.com	Clovis	California	3434825323895359	a7e76f809c663198a96a86bf029e1f80	JCB 16 digit	36.8453153078787068	-119.756997734780981
13861	2020-02-29 00:36:11	2020-02-29	Margy Mitchell	margy.mitchell@warmmail.com	Fort Wayne	Indiana	51926167610866590	81297853ab8e3ab25f2fcbaddca1360d	JCB 15 digit	41.0089747335545738	-85.1349552628338415
13862	2020-02-29 00:36:27	2020-02-29	Dr. Halsey Smith	dr.halsey.smith@geemail.com	Houston	Texas	4784895042452107	45425bf9316ca642f1c5c2c0f9bac1c8	Discover	29.8143869701385498	-95.446684295545893
13863	2020-02-29 00:38:44	2020-02-29	Lugenia Fadel	lugenia.fadel@geemail.com	Joliet	Illinois	501872779805182	70e31155867ffcac015468ea895bf3b8	VISA 13 digit	41.5351711765255729	-88.0507205181393715
13864	2020-02-29 00:58:27	2020-02-29	Miss Rosetta Erdman DDS	miss.rosetta.erdman.dds@warmmail.com	Fullerton	California	4884295443131179	0cc5de1776fdf038dda43abe6df24d37	VISA 16 digit	33.7914604090310604	-117.843398572757835
13865	2020-02-29 01:04:27	2020-02-29	Sarita Kuhlman	sarita.kuhlman@geemail.com	Dayton	Ohio	4715965240883	5bce193aac1497d7e3d7b792393baa7a	JCB 16 digit	39.690957812385264	-84.2656431216936568
13866	2020-02-29 01:05:30	2020-02-29	Carmela Johnson-Breitenberg	carmela.johnson.breitenberg@geemail.com	Vacaville	California	3088930812490530709	e8d4e027209a26cb09112f14c930aa14	VISA 13 digit	38.2888196672439634	-121.916406589781133
13867	2020-02-29 01:23:43	2020-02-29	Iyana Wintheiser	iyana.wintheiser@geemail.com	Phoenix	Arizona	180084184120664652	9cc58e9275384a7a293b7b65c88ff833	VISA 16 digit	33.6376303431510948	-112.0106749695655
13868	2020-02-29 01:26:21	2020-02-29	Shaquille Collier	shaquille.collier@geemail.com	Long Beach	California	4479059625879513	64db3787c83a7de70845910b979fd7df	JCB 16 digit	33.8161713315460801	-118.057115024297687
13869	2020-02-29 01:39:40	2020-02-29	Richie Hilpert-Heidenreich	richie.hilpert.heidenreich@geemail.com	Glendale	Arizona	3413377490055776	e18d382d65ae77751729c06716492d46	JCB 16 digit	33.4922309597250063	-112.18585768903381
13870	2020-02-29 01:46:55	2020-02-29	Lyle Zieme	lyle.zieme@woohoo.com	Colorado Springs	Colorado	3088897070644556796	4d4a37543f1582271af64d5e85572c0e	Maestro	38.8587926208090053	-104.821081268756458
13871	2020-02-29 01:54:59	2020-02-29	Dr. Belton McCullough DVM	dr.belton.mccullough.dvm@geemail.com	Spokane	Washington	4866455918256784	42a8f72fce22f04229bc4110c9e3d086	JCB 15 digit	47.7649513399001222	-117.41559534095154
13872	2020-02-29 02:07:55	2020-02-29	Leanne Maggio	leanne.maggio@geemail.com	Henderson	Nevada	3009709036137401	eb07bd39ccc1f9e22fe2b93aa040f536	Maestro	35.9694573157865563	-115.120389187956974
13873	2020-02-29 02:18:58	2020-02-29	Mr. Duke Mertz DDS	mr.duke.mertz.dds@geemail.com	San Francisco	California	3337254525372322205	78db91a5a4e6e05fb8469a16c46d7d38	Voyager	37.7377045461875014	-122.423519387937588
13874	2020-02-29 02:27:25	2020-02-29	Marcelle Stroman-Brakus	marcelle.stroman.brakus@geemail.com	Berkeley	California	6011066693248961222	44cd0d5c910026c2280e1897087aecb3	VISA 16 digit	37.8758799087970885	-122.276509213308358
13875	2020-02-29 02:34:57	2020-02-29	Lowell Huels II	lowell.huels.ii@geemail.com	Lansing	Michigan	589320249898808	6f14447e44036a5a942f32d9872b350f	Voyager	42.7277281142149121	-84.623189508834102
13876	2020-02-29 02:37:48	2020-02-29	Mandi Orn	mandi.orn@woohoo.com	Seattle	Washington	4142439279050	a11398540653c3eb826a4ad83109bf4e	VISA 13 digit	47.6884272877518072	-122.267705823240419
13877	2020-02-29 02:53:05	2020-02-29	Colie Runte	colie.runte@geemail.com	Peoria	Arizona	869948000412244471	6f0605f933c075903e85479da4b08f26	American Express	33.8157892720110738	-112.254810913179071
13878	2020-02-29 02:59:11	2020-02-29	Maryjo Emmerich-Glover	maryjo.emmerich.glover@warmmail.com	Shreveport	Louisiana	3096465532296037252	0e073700e8e08e61f39e9a2105246bb5	VISA 13 digit	32.4616772563435134	-93.7218376533340631
13879	2020-02-29 03:06:33	2020-02-29	Dr. Colton Moore	dr.colton.moore@geemail.com	Fort Worth	Texas	503838038012696	7c2b5de51baacc076b105fa86798ec40	VISA 16 digit	32.766974133398385	-97.397953692852326
13880	2020-02-29 03:11:57	2020-02-29	Carmen Homenick	carmen.homenick@geemail.com	Chicago	Illinois	4943393048888860	06f6abbdea8a662e57d91fe7e3b9d5a0	Maestro	41.8496834676548843	-87.7490495466656881
13881	2020-02-29 03:15:38	2020-02-29	Rhianna Carroll MD	rhianna.carroll.md@geemail.com	New York	New York	4912097689828	9a46825447d47dd19c3a4e23497484cc	Voyager	40.7274471502043269	-73.9022007321834593
13882	2020-02-29 03:35:43	2020-02-29	Dr. Orland Abshire	dr.orland.abshire@warmmail.com	Tallahassee	Florida	869994719852925520	aa92c95539a02ac4a6a52d568b865434	JCB 15 digit	30.3846009104069346	-84.1816290815841342
13883	2020-02-29 04:05:58	2020-02-29	Memphis Muller	memphis.muller@geemail.com	San Francisco	California	4948960401826	d72b2948ccc086c29ca0444fd79bbb6f	VISA 16 digit	37.7796326330161421	-122.437072802244899
13884	2020-02-29 04:08:38	2020-02-29	Phoenix Wisoky	phoenix.wisoky@geemail.com	Berkeley	California	55239278576014026	31e0a541bc3757bc85d8350c633a1a29	Voyager	37.9308555262240787	-122.300290817116021
13885	2020-02-29 04:15:57	2020-02-29	Alzina Bergnaum	alzina.bergnaum@geemail.com	Lexington	Kentucky	4481048880543183	ad6ef419f9dafcfdeb126eb9dad66521	Maestro	38.0506033133592467	-84.4316970757573841
13886	2020-02-29 04:34:09	2020-02-29	Dr. Stevan D'Amore Jr.	dr.stevan.d'amore.jr.@geemail.com	North Las Vegas	Nevada	3112986375634361533	c695ea4e11f1a4234bed0e5ec8222eee	VISA 16 digit	36.193916593507673	-115.104915417706223
13887	2020-02-29 04:48:18	2020-02-29	Jarred Dooley	jarred.dooley@geemail.com	Lansing	Michigan	869920448034677374	cee113c7974426624850cdb258c6f436	VISA 13 digit	42.635662556982787	-84.602918096318092
13888	2020-02-29 05:12:44	2020-02-29	Alek Cummerata IV	alek.cummerata.iv@geemail.com	Oakland	California	3096361314472533718	5d062a575eeb38a43569d54f38f5b831	Mastercard	37.806574230401317	-122.274165486118861
13890	2020-02-29 05:27:36	2020-02-29	Neal Bayer	neal.bayer@geemail.com	Los Angeles	California	4796924194125273	d8a1202639a352a1d064b34e16a16623	JCB 16 digit	33.9812811285588836	-118.448053241334108
13891	2020-02-29 05:38:33	2020-02-29	Emerson Mayer Sr.	emerson.mayer.sr.@geemail.com	Nashville	Tennessee	060402761676945	34c739a750fdeece5c57bafc61677a6d	Diners Club / Carte Blanche	36.2710822257336218	-86.8239731257688163
13892	2020-02-29 05:39:36	2020-02-29	Sheri Oberbrunner	sheri.oberbrunner@geemail.com	Denver	Colorado	3528574397129840159	17183223156791110368d2889c204e03	Discover	39.7175999812833922	-104.848839233840266
13893	2020-02-29 05:40:02	2020-02-29	Zeno Conn	zeno.conn@geemail.com	San Francisco	California	4249624201573	e69e3f78ff543f9e0ec0bb98c240f3be	JCB 16 digit	37.7707708886659219	-122.446808630292097
13894	2020-02-29 06:06:47	2020-02-29	Lorne Ratke-Collier	lorne.ratke.collier@geemail.com	Newport News	Virginia	4482578701968853	1a32735836684377fb55b94fd307b2f9	JCB 16 digit	37.0091361988231569	-76.4571576396729853
13895	2020-02-29 06:18:01	2020-02-29	Raynard Rippin	raynard.rippin@geemail.com	Chicago	Illinois	52728514441317782	209a77f33aa22a581e360ab4ebddeead	American Express	41.8485267582185614	-87.7002035927988572
13896	2020-02-29 06:40:40	2020-02-29	Dr. Denis Watsica	dr.denis.watsica@woohoo.com	New York	New York	6011821924466749056	ea7501ef20fd7f1fea737505922346b3	Mastercard	40.5938880345076285	-73.9977610568877253
13897	2020-02-29 06:42:52	2020-02-29	Kerri Rutherford	kerri.rutherford@warmmail.com	Philadelphia	Pennsylvania	4652102191531	0a333a28fde45356edfa6de7a92dbc11	JCB 16 digit	39.9314108871348168	-75.0895370256986467
13898	2020-02-29 06:54:24	2020-02-29	Lacy Daniel	lacy.daniel@geemail.com	Houston	Texas	869918538760414960	0a4f9b99319b605f6a8b7c9a62c0abfd	Voyager	29.6999914408274002	-95.3779097386185128
13899	2020-02-29 06:59:36	2020-02-29	Brande Rath-Grant	brande.rath.grant@geemail.com	Stockton	California	6011100103792334592	c28f3addff772ec23c15d1fdf25602b8	JCB 16 digit	38.0278086201019576	-121.25599372243434
13900	2020-02-29 07:05:11	2020-02-29	Miss Enriqueta Maggio	miss.enriqueta.maggio@woohoo.com	Berkeley	California	180025926938494892	edaf963db8efde9f06ce4cb9a45f1e42	Voyager	37.8298297262754915	-122.277843322606017
13901	2020-02-29 07:13:27	2020-02-29	Susie Roberts	susie.roberts@geemail.com	Fayetteville	North Carolina	4952982038327	dcd6cdc6539548a8db8536d8e295f86e	VISA 16 digit	35.1266121683895562	-78.9865618004128294
13902	2020-02-29 07:48:59	2020-02-29	Kent O'Reilly	kent.o'reilly@geemail.com	San Francisco	California	180059171052036877	66356d31fceb40ec3ae943ed7a408dc9	JCB 16 digit	37.8270837160399225	-122.427654698531981
13903	2020-02-29 08:02:11	2020-02-29	Serena Kuphal	serena.kuphal@woohoo.com	Oklahoma City	Oklahoma	3014806824903021	dba9686075a781ec0e92e1d72c085381	VISA 16 digit	35.437437432250384	-97.4914059907559363
13904	2020-02-29 08:16:48	2020-02-29	Mr. Delmas Doyle	mr.delmas.doyle@woohoo.com	Hayward	California	502030816715020	572837b71b84ff5613f37edd99b4c9f4	American Express	37.6818777853611877	-122.06890029299781
13905	2020-02-29 08:30:16	2020-02-29	Miss Contina Emmerich DVM	miss.contina.emmerich.dvm@woohoo.com	Cincinnati	Ohio	869969737544777837	db9721b005bd7052bacabe598c3b28cc	Maestro	39.1471389691110687	-84.4783348080042629
13906	2020-02-29 08:49:56	2020-02-29	Novella Ernser	novella.ernser@warmmail.com	Los Angeles	California	6011917122354590857	36b7966d3e1e08479b1b461c3f7c7c28	American Express	34.0802809025958169	-118.484169947448365
13907	2020-02-29 08:50:56	2020-02-29	Ms. Evalena Donnelly	ms.evalena.donnelly@geemail.com	Modesto	California	3528555783528726011	3f0a564302ca635d79de4d1606a17a35	VISA 13 digit	37.709753831336279	-121.092590682648122
13908	2020-02-29 08:54:44	2020-02-29	Colette McKenzie	colette.mckenzie@woohoo.com	San Francisco	California	4580266038237306	87d85205a46eda10dd6221ef2782576a	JCB 16 digit	37.7609969722513625	-122.456119658240468
13909	2020-02-29 09:05:41	2020-02-29	Trevor Roberts-Dare	trevor.roberts.dare@geemail.com	Berkeley	California	3058467851800444	7f77ef39a9342fc46df5df7698195909	JCB 15 digit	37.8843251165591965	-122.287900506688842
13910	2020-02-29 09:10:34	2020-02-29	Hillery Lowe	hillery.lowe@woohoo.com	San Francisco	California	3088079972304660331	0c4519aee515e188bbf5510fff6b2038	Voyager	37.7770354707761626	-122.433489869303259
13911	2020-02-29 09:14:22	2020-02-29	Ryann Howell	ryann.howell@geemail.com	San Francisco	California	3039048235510419	e6824ba57722e394033b6a465ffcff7b	JCB 15 digit	37.736659467782772	-122.438388302786379
13912	2020-02-29 09:16:27	2020-02-29	Kasandra Bode	kasandra.bode@geemail.com	Oklahoma City	Oklahoma	3417877883533996	f3e5a2312a0be0c2ab4f4f8f905e40e3	JCB 15 digit	35.5340168343301883	-97.5154794400919229
13913	2020-02-29 09:20:19	2020-02-29	Maximus Bergnaum	maximus.bergnaum@warmmail.com	San Francisco	California	4993693271409873	ff7d6b35a4dbd51de76326ce845be719	VISA 13 digit	37.8035824297681486	-122.429371926951461
13914	2020-02-29 09:34:40	2020-02-29	Ardyce Hamill	ardyce.hamill@warmmail.com	Fort Collins	Colorado	51151149547825127	22bf353947dc5dccd111f727aad6782c	Maestro	40.5611194854293018	-105.012657331670823
13915	2020-02-29 09:43:00	2020-02-29	Mrs. Arvilla Block	mrs.arvilla.block@geemail.com	New York	New York	3528080450641131172	88adf0a5610b00c59fa1049a65f06cb0	Voyager	40.62789787540585	-73.9921410278778495
13916	2020-02-29 09:48:50	2020-02-29	Dr. Savilla Heathcote DVM	dr.savilla.heathcote.dvm@geemail.com	Midland	Texas	4052101356711070	7973380fa203a895d1457bb21a797ffd	VISA 16 digit	32.0013382257617991	-102.081952577292924
13917	2020-02-29 10:03:29	2020-02-29	Tom Kovacek V	tom.kovacek.v@geemail.com	Oakland	California	3721201238712730	c6d8faf83b044509de9eb20f1b6e176d	Discover	37.7909164011730638	-122.291997500282704
13918	2020-02-29 10:25:38	2020-02-29	Mr. Coty Wilkinson	mr.coty.wilkinson@geemail.com	Nashville	Tennessee	4127569791353719	619745f47d2682210e93ad0b95bf8665	VISA 16 digit	36.1008801677387154	-86.8259080834593533
13919	2020-02-29 10:42:03	2020-02-29	Bertrand Raynor I	bertrand.raynor.i@geemail.com	Renton	Washington	210043427830650283	873991ab5c00e7d4d0474543d00fbec9	JCB 16 digit	47.5041938889831314	-122.114217582957806
13920	2020-02-29 10:45:10	2020-02-29	Adina Schneider DVM	adina.schneider.dvm@geemail.com	Oakland	California	3528704477207780551	ca94dcd7de925fb454ad37c4997a3bd8	Voyager	37.8253338434753843	-122.256986227036521
13921	2020-02-29 10:58:11	2020-02-29	Jarrad Bogisich Sr.	jarrad.bogisich.sr.@woohoo.com	Cincinnati	Ohio	561288850981189	7d1d173d6db22ed5d6b5c815de599793	VISA 13 digit	39.0567207660756992	-84.5276146050814532
13922	2020-02-29 11:00:48	2020-02-29	Nathaniel Schinner	nathaniel.schinner@geemail.com	Santa Clarita	California	6011596266143122205	8d7209eb2a5f27675468d07ddbacfe71	JCB 16 digit	34.4128499395418928	-118.571811111840233
13923	2020-02-29 11:11:37	2020-02-29	Beyonce Goldner	beyonce.goldner@geemail.com	San Francisco	California	630420483705974	5dd6f4b4f36bdc2add882e092dd305e7	VISA 16 digit	37.750080751950442	-122.443462381968772
13924	2020-02-29 11:14:47	2020-02-29	Kyle Eichmann	kyle.eichmann@geemail.com	Glendale	California	4598443351584156	396e2f38dbb9ad7a0169443683e08afd	VISA 16 digit	34.170887942261615	-118.272486011953276
13925	2020-02-29 11:17:48	2020-02-29	Marina Welch	marina.welch@geemail.com	Oakland	California	55016926246234973	e1306964e9995b229a2c2a850abf0c3d	JCB 15 digit	37.8338300219859391	-122.274409782446654
13926	2020-02-29 11:19:33	2020-02-29	Dionne Hackett-Towne	dionne.hackett.towne@geemail.com	San Francisco	California	53001152006902181	144c08f871ebdcda44a7f90cd1494b26	VISA 16 digit	37.7606361373618924	-122.442072847035135
13927	2020-02-29 11:23:59	2020-02-29	Frona Bailey-Wilderman	frona.bailey.wilderman@warmmail.com	Vancouver	Washington	4349141620683	60c60c04db6aa00c165ce60db2d2db06	VISA 13 digit	45.5803754049889776	-122.58184797024056
13928	2020-02-29 11:47:50	2020-02-29	Ms. Gina Flatley DDS	ms.gina.flatley.dds@warmmail.com	Austin	Texas	3029272230290823	d21d823480ca15363541b637ef3b2f14	VISA 16 digit	30.3818451718553888	-97.7808140042010763
13929	2020-02-29 11:50:07	2020-02-29	Lida Lindgren-Hauck	lida.lindgren.hauck@geemail.com	Las Vegas	Nevada	3337750127574015536	8d5c60daead93338c57f70ef083501ca	VISA 13 digit	36.2180323899824188	-115.299944877878204
13930	2020-02-29 11:52:32	2020-02-29	Marlen Emmerich-Windler	marlen.emmerich.windler@geemail.com	San Francisco	California	869929248089694113	2c06d9c0294d218b48f8a7b7094c181d	Maestro	37.7809458454928944	-122.474496194867754
13931	2020-02-29 11:53:17	2020-02-29	Cicero Cummerata	cicero.cummerata@woohoo.com	Oklahoma City	Oklahoma	3112487754694274204	795a28f7acf0cb962efd46b579299330	Diners Club / Carte Blanche	35.4943761493455625	-97.5737458863656997
13932	2020-02-29 12:08:04	2020-02-29	Osie Abbott-Cassin	osie.abbott.cassin@geemail.com	Toledo	Ohio	6011832494991953745	45bf78f5a5852d7ded94a79889001d38	Maestro	41.7249255601022355	-83.4875696332525479
13933	2020-02-29 12:11:28	2020-02-29	Johney Gutmann-Purdy	johney.gutmann.purdy@geemail.com	Irvine	California	6011102218139280965	5cd4b64e1d37f22dfa68ce8d99bddf24	Maestro	33.7062477582149214	-117.728195683426407
13934	2020-02-29 12:24:38	2020-02-29	Lurana Ratke	lurana.ratke@geemail.com	Phoenix	Arizona	52735393430230533	577cc64f98b76a8cf0af15a7d06252a0	JCB 16 digit	33.5411718249253923	-112.002877545768769
13935	2020-02-29 13:00:37	2020-02-29	Mrs. Odie Nicolas	mrs.odie.nicolas@geemail.com	Elizabeth	New Jersey	4311641835065272	b5434da9b4cc52591772286d4c118408	JCB 16 digit	40.6773968981705636	-74.123489973455662
13936	2020-02-29 13:09:14	2020-02-29	Lavina Hodkiewicz	lavina.hodkiewicz@woohoo.com	Daly City	California	4274463375808796	6b9115487180a311b4f3057f7a3fe78c	VISA 13 digit	37.6417280342351646	-122.470798121308917
13937	2020-02-29 13:17:24	2020-02-29	Lela Haag-Shields	lela.haag.shields@geemail.com	Richmond	Virginia	4790487726361168	012f649ad600726c087e3e4b94705c92	VISA 16 digit	37.4480722051333643	-77.5712687690500218
13938	2020-02-29 13:18:41	2020-02-29	Idell Abbott	idell.abbott@warmmail.com	Orlando	Florida	6011417493539716476	853492da9ebd7248262de2fdace99e66	VISA 16 digit	28.4751509687662114	-81.2020837046638206
13939	2020-02-29 13:33:46	2020-02-29	Dr. Darryll Goldner MD	dr.darryll.goldner.md@geemail.com	San Francisco	California	3528830597008560394	0fafc3ff505d5ccad97610536f6b1612	Diners Club / Carte Blanche	37.7808348897615289	-122.483497944785981
13940	2020-02-29 13:59:46	2020-02-29	Randi Littel	randi.littel@geemail.com	San Francisco	California	3420299865336055	00b3da8daaa9c0a1f140ec584a930154	Diners Club / Carte Blanche	37.7814970109868682	-122.44759671959622
13941	2020-02-29 14:10:40	2020-02-29	Dr. Franklyn Veum	dr.franklyn.veum@geemail.com	Columbus	Ohio	502030476996563	4755e872662368167964e2d7842fb306	VISA 16 digit	40.0075198730032895	-82.970295489183826
13942	2020-02-29 14:14:03	2020-02-29	Celie Ward	celie.ward@geemail.com	Norman	Oklahoma	3528987244347317597	2595eeeb2007a426bf1f624e6179e4aa	American Express	35.2858128493227099	-97.3070418025154567
13943	2020-02-29 14:42:02	2020-02-29	Damarion Gaylord	damarion.gaylord@warmmail.com	New York	New York	869999158610739110	5c8475b7a7a92bd9b55a582066be3842	VISA 13 digit	40.6985559647660722	-73.869121164818111
13944	2020-02-29 14:44:35	2020-02-29	Dorsey Satterfield	dorsey.satterfield@woohoo.com	San Diego	California	3096045762058824873	38d1f4ac1e6a52cdc591fb7a8f6db483	Mastercard	32.8012122614841886	-117.139355400847279
13945	2020-02-29 15:00:24	2020-02-29	Graham Spencer	graham.spencer@geemail.com	San Francisco	California	210063224161955927	7dbceb03dfdf22f0c30d7893b3b0d9c0	Voyager	37.7757028847632839	-122.433024969670214
13946	2020-02-29 15:01:26	2020-02-29	Remington Wolff	remington.wolff@geemail.com	Lincoln	Nebraska	6011133904056726832	cea45d7ef781df7dd2fb202a7134cd62	VISA 16 digit	40.8330866604130662	-96.6897539599958833
13947	2020-02-29 15:02:34	2020-02-29	Ms. Cadence Hand DDS	ms.cadence.hand.dds@woohoo.com	San Antonio	Texas	210023736606051573	bf1e8e0ce936031401672e131307212e	JCB 16 digit	29.5180307521089915	-98.5406772790312715
13948	2020-02-29 15:07:08	2020-02-29	Troy Mayer	troy.mayer@geemail.com	Fort Lauderdale	Florida	3528436979539666395	58f49743e9c06de5ae0211f6a7666a34	Diners Club / Carte Blanche	26.2114650637831552	-80.2113054837386983
13949	2020-02-29 15:38:16	2020-02-29	Miss Sybil Bayer	miss.sybil.bayer@warmmail.com	Atlanta	Georgia	869909687716194381	c70df95aa060d31e05394204d0323622	JCB 16 digit	33.6702078269138951	-84.4255818182647317
13950	2020-02-29 15:54:59	2020-02-29	Nona Okuneva	nona.okuneva@geemail.com	San Francisco	California	4908782196160606	2e6b12c462c284a77f09d2c6b8a0b177	VISA 16 digit	37.7552832004207986	-122.417127920073256
13951	2020-02-29 16:18:46	2020-02-29	Hal Yundt	hal.yundt@geemail.com	San Francisco	California	3528930507606990058	ab94a9becc854fab4f8b162333d9998a	VISA 13 digit	37.7475984414555512	-122.443175146547873
13952	2020-02-29 16:23:53	2020-02-29	Leslie Jakubowski	leslie.jakubowski@geemail.com	Jersey City	New Jersey	3528769552465057280	617709e3949fea64ccfa0812e7bf7f69	Diners Club / Carte Blanche	40.6820611169967776	-74.1575496371325187
13953	2020-02-29 16:41:53	2020-02-29	Zula Runolfsson	zula.runolfsson@geemail.com	Huntington Beach	California	4301078640051423	4be1005b0babeece84e8cc983a56641a	Maestro	33.7131482937879881	-117.969767070387675
13954	2020-02-29 16:48:45	2020-02-29	Mireya Dietrich	mireya.dietrich@woohoo.com	New York	New York	210035781565426297	e78f20c7b988a1a003a5cb34768c5a90	VISA 16 digit	40.669953261384741	-73.9685283141106282
13955	2020-02-29 17:14:47	2020-02-29	Dr. Lavern Quigley	dr.lavern.quigley@geemail.com	Akron	Ohio	3448728918284027	727c204d27fd550b66be72c5151e8391	VISA 16 digit	41.0514876589942759	-81.531448257745808
13956	2020-02-29 17:25:35	2020-02-29	Bryan Heidenreich DVM	bryan.heidenreich.dvm@geemail.com	Escondido	California	675911870505762	aebddfcc394d92fa5da0a1c08e8cf984	JCB 16 digit	33.1710646482411775	-117.060057447502388
13957	2020-02-29 17:28:07	2020-02-29	Robt Harris	robt.harris@geemail.com	San Francisco	California	3096973066922615244	41aaa649986a4626891a34405f211e9c	Maestro	37.7556569124307586	-122.45667448070563
13958	2020-02-29 17:30:23	2020-02-29	Mauricio Lubowitz-Bailey	mauricio.lubowitz.bailey@geemail.com	Detroit	Michigan	180095516417264539	8723e9d51b9b1377374250c3f977bef7	JCB 16 digit	42.4741437254399088	-83.0469984225116633
13959	2020-02-29 17:34:36	2020-02-29	Alida Cruickshank	alida.cruickshank@geemail.com	Tampa	Florida	180048839810849658	1a6e8cf2924101632b34906dacf2ebfa	Mastercard	28.0315624531473944	-82.576380636191729
13960	2020-02-29 17:35:47	2020-02-29	Caitlin Stamm	caitlin.stamm@geemail.com	Columbia	Missouri	6011960513814772950	f73f22443474c7f6ad3e22b2a595f046	JCB 16 digit	38.9676137887754095	-92.3116145285365235
13961	2020-02-29 17:38:08	2020-02-29	Marjorie Howell-Upton	marjorie.howell.upton@geemail.com	Charleston	South Carolina	4199534071758	49bededb6058b80b98e8285dd868d854	Maestro	32.9092182660471693	-80.0347944921497287
13962	2020-02-29 17:47:13	2020-02-29	Johnathon Ryan	johnathon.ryan@woohoo.com	Birmingham	Alabama	3033172004382937	d2e45a8e0711eef5b060aebc38c1ce3a	Voyager	33.586413640368356	-86.7581351144015827
13963	2020-02-29 17:54:16	2020-02-29	Sarina Kassulke	sarina.kassulke@geemail.com	San Francisco	California	869981624113872443	2307035af242be431df71736df40ca7a	Voyager	37.7751558383880379	-122.436523690831194
13964	2020-02-29 18:08:16	2020-02-29	Braulio Grady	braulio.grady@geemail.com	Mesa	Arizona	4912236070913261	35deec3299b6dc1faec3d0e7a0826c74	American Express	33.4559222446434177	-111.637881342310081
13965	2020-02-29 18:49:40	2020-02-29	Nathaniel Schuppe	nathaniel.schuppe@geemail.com	Oklahoma City	Oklahoma	3497765707514958	85756afa07701887643a5b9068a48f26	VISA 16 digit	35.3796209297984845	-97.5239479946333887
13966	2020-02-29 19:07:33	2020-02-29	Landan Welch I	landan.welch.i@geemail.com	Irving	Texas	6011527578837429025	a1af64fa4864463c3c77084b908c0ce5	JCB 16 digit	32.8615599960505946	-96.9906228467170166
13967	2020-02-29 19:16:08	2020-02-29	Orville O'Reilly	orville.o'reilly@geemail.com	Saint Paul	Minnesota	6011971527040291350	60f19e7ed11666598f18dfd2801cc04d	American Express	45.0272666743431245	-93.1729514831475996
13968	2020-02-29 19:16:49	2020-02-29	Silvio Willms	silvio.willms@warmmail.com	Sandy Springs	Georgia	060440973633627	d079fe2a70cf67c4058858ea6893fccb	Voyager	33.9664864646792424	-84.3715085030615342
13969	2020-02-29 19:47:14	2020-02-29	Mildred Larkin	mildred.larkin@warmmail.com	Long Beach	California	3749609893219999	0039c7818ce7985130955733a5ccbd95	JCB 16 digit	33.8853304632760555	-118.123882922779018
13970	2020-02-29 20:12:36	2020-02-29	Barbara Brekke-Heidenreich	barbara.brekke.heidenreich@geemail.com	Santa Clarita	California	3096388023288966892	c4b17324466db64235aecf22ac307c0b	JCB 16 digit	34.3452942139208304	-118.555630661045015
13971	2020-02-29 20:23:09	2020-02-29	Evette O'Reilly	evette.o'reilly@warmmail.com	Columbia	South Carolina	3740393134442723	6186610c2c235d97e83d2d0d8b2ebdc4	Diners Club / Carte Blanche	33.9998543446682362	-80.8883764071408677
13972	2020-02-29 20:26:32	2020-02-29	Ms. Hessie Rodriguez DDS	ms.hessie.rodriguez.dds@geemail.com	Milwaukee	Wisconsin	4767767547427952	8bbc370081953cf229bd3e88b037bffa	Discover	43.0945501890119118	-87.942669962216911
13973	2020-02-29 20:39:54	2020-02-29	Mardell Berge	mardell.berge@woohoo.com	Phoenix	Arizona	4001367532815687	5a085c265e833074a78b42b61e881fcd	JCB 16 digit	33.4917235199295007	-111.99742160084881
13974	2020-02-29 20:45:13	2020-02-29	Mr. Ples Leffler	mr.ples.leffler@geemail.com	Chicago	Illinois	210060830019541769	ce5deac159d44fc4e835ff0d2dcd4dc3	JCB 16 digit	41.9283638717908431	-87.6926232748694616
13975	2020-02-29 20:48:48	2020-02-29	Lollie Lueilwitz	lollie.lueilwitz@woohoo.com	Los Angeles	California	3337629443083834468	da1ad5f2c5237fda429913c11a8c9ff4	American Express	33.9739780749060216	-118.377399020594723
13976	2020-02-29 21:17:23	2020-02-29	Rowland Morar	rowland.morar@geemail.com	Syracuse	New York	55655003809907944	4b7c3c84df20af4e833820f0cc22b34d	Diners Club / Carte Blanche	42.9825869000367788	-76.0538138535119685
13977	2020-02-29 21:18:54	2020-02-29	Vernita Zemlak-Nicolas	vernita.zemlak.nicolas@woohoo.com	Los Angeles	California	3528237138017757769	3ca0b7575ff3de3086d28ca6c206cc42	VISA 16 digit	34.1053508387744415	-118.441117078344519
13978	2020-02-29 21:21:43	2020-02-29	Sonja Weber	sonja.weber@geemail.com	Anaheim	California	869912864713865157	964ae2afe1ac81be68e96478807fd60f	JCB 16 digit	33.9454978699628285	-117.788548491264123
13979	2020-02-29 21:51:58	2020-02-29	Mr. Jefferson Herzog DVM	mr.jefferson.herzog.dvm@geemail.com	Phoenix	Arizona	55958374976364936	5c881c66e6209556b2273beca29a21ec	Discover	33.5392415235683359	-112.062945208644877
13980	2020-02-29 22:18:30	2020-02-29	Thaddeus O'Reilly	thaddeus.o'reilly@warmmail.com	Honolulu	Hawaii	4593370392569	e5ce5ad2452c4c6b6861229a314f1979	Maestro	21.4200731063943373	-157.896667753646511
13981	2020-02-29 22:35:35	2020-02-29	Jeffrey Schamberger	jeffrey.schamberger@woohoo.com	San Antonio	Texas	6011655200211557909	52ea6515d8999ae9a566fa76efd85573	Diners Club / Carte Blanche	29.4154714764632281	-98.4292272771078984
13982	2020-02-29 22:37:42	2020-02-29	Lone Shanahan	lone.shanahan@geemail.com	Omaha	Nebraska	676354818972439	8c116bfd583bc39e914b60bc4a3861b7	American Express	41.3623685962200156	-95.9936361109022158
13983	2020-02-29 22:48:38	2020-02-29	Belen Mertz DDS	belen.mertz.dds@geemail.com	Round Rock	Texas	3018369791909279	39a1a39aee00b4391a555a51084fa50a	VISA 16 digit	30.4915519058842222	-97.6632676760051339
13984	2020-02-29 23:12:17	2020-02-29	Mrs. Electa Roob	mrs.electa.roob@woohoo.com	San Francisco	California	869919078992062005	10b509564ca8f70921fa7942b96700ec	Discover	37.7700868272609043	-122.428207742820533
13985	2020-02-29 23:18:22	2020-02-29	Keena Miller	keena.miller@geemail.com	New York	New York	6011410145068677464	dfebc17306054d7d580c3a779981a0a3	Discover	40.6341124081276348	-73.8636543849844429
13986	2020-02-29 23:26:32	2020-02-29	Vincent Stoltenberg-Hegmann	vincent.stoltenberg.hegmann@warmmail.com	Baltimore	Maryland	3430456024082313	85f4577d92dbae507093befe43f1742e	JCB 16 digit	39.3178369581233653	-76.5668130466267485
13987	2020-02-29 23:42:35	2020-02-29	Milburn Ernser	milburn.ernser@geemail.com	Memphis	Tennessee	53778558848488323	accaaabb5d099dd9476b6f857ea39436	Voyager	35.1995693313024987	-89.9657958282880514
13988	2020-02-29 23:46:12	2020-02-29	Anwar Watsica II	anwar.watsica.ii@geemail.com	Lexington	Kentucky	4724679256201	8e988aff7ccf4289558a0b5bdb55d17b	VISA 16 digit	38.041993151685972	-84.4939035896111221
13989	2020-03-01 00:11:10	2020-03-01	Hollis Satterfield	hollis.satterfield@geemail.com	New York	New York	4446675362089584	2777b078a4cb69412312d6ee21682a1f	Voyager	40.5649952652621977	-73.8584243993170588
13990	2020-03-01 00:13:13	2020-03-01	Tierra Bashirian	tierra.bashirian@geemail.com	Rochester	New York	210069248553180954	d7a99643ce6c039cf5fe3f75c7fa8dd8	JCB 15 digit	43.2523542767833931	-77.6483820306375634
13991	2020-03-01 00:36:36	2020-03-01	Rayne Krajcik	rayne.krajcik@geemail.com	Greensboro	North Carolina	502058196336711	ced9d1ccc37813dad1b7eb1d489681f7	American Express	36.1551614338181935	-79.9257687521148483
13992	2020-03-01 00:38:32	2020-03-01	Yasmeen Herzog	yasmeen.herzog@woohoo.com	Phoenix	Arizona	53546402163913345	4319f62dd2a872d34daadc2a4b1436f5	Maestro	33.6308511765141063	-112.087808347346638
13993	2020-03-01 00:47:51	2020-03-01	Isaak Eichmann MD	isaak.eichmann.md@warmmail.com	Wilmington	North Carolina	210098765642694112	845f34a8187eed231c0e37bf7c47c914	JCB 16 digit	34.1693612351834801	-77.8393065622069003
13994	2020-03-01 01:02:27	2020-03-01	Dorris Stracke-Marquardt	dorris.stracke.marquardt@geemail.com	Gilbert	Arizona	3454125552490906	ba63814ab2625a880eb39437666871a5	Mastercard	33.3636093853853595	-111.836810109312083
13995	2020-03-01 01:03:12	2020-03-01	Woody Littel	woody.littel@geemail.com	Charlotte	North Carolina	3710983059937289	8ed6789522f71c704774a2a68084e366	VISA 13 digit	35.1117785644505176	-80.9240795235093771
13996	2020-03-01 01:13:27	2020-03-01	Raymon Shanahan	raymon.shanahan@geemail.com	San Francisco	California	3034574418520854	5490fdf5916a62b463d5f4a2395a0c0b	Discover	37.8129724374326912	-122.42536236747911
13997	2020-03-01 01:15:01	2020-03-01	Bee Dach	bee.dach@geemail.com	Springfield	Illinois	52101707557320205	aa2aef1c7eebbdd9725da26495a71dca	VISA 16 digit	39.7582374541241705	-89.5989087723199304
13998	2020-03-01 01:25:04	2020-03-01	Ryder Klocko	ryder.klocko@geemail.com	Houston	Texas	4138714055280	c8e27bcd4dee91062ca4312520214415	Voyager	29.715457652097939	-95.4056270994260984
13999	2020-03-01 01:41:42	2020-03-01	Maddox McLaughlin	maddox.mclaughlin@geemail.com	San Francisco	California	52152266118706871	f3ead901a99e7a9f63a30cb6c833f5e8	JCB 16 digit	37.7846721618874781	-122.444137579751683
14000	2020-03-01 01:44:39	2020-03-01	Brandan Miller PhD	brandan.miller.phd@geemail.com	Raleigh	North Carolina	6011953805152100284	25087e7bb06baab41a851327be11e9bb	Maestro	35.7651766531769155	-78.5913089732110564
14001	2020-03-01 01:50:26	2020-03-01	Brea Rice DDS	brea.rice.dds@geemail.com	Houston	Texas	210078335721147962	f83f60641e5fd7909f9fb045f501b99e	Discover	29.7914073388170451	-95.3855342321578377
14002	2020-03-01 01:59:33	2020-03-01	Mr. Braeden Wolf	mr.braeden.wolf@warmmail.com	Oakland	California	4266682514355076	689030ba12515227cd233cbb1d19fdf4	Voyager	37.8277617312868131	-122.266985996083477
14003	2020-03-01 02:00:59	2020-03-01	Talmadge Marvin PhD	talmadge.marvin.phd@geemail.com	Buffalo	New York	4547413218298474	2b1be544513f1130f73d1d0131e57b5f	VISA 16 digit	42.8637905902881187	-78.9132249602980949
14004	2020-03-01 02:03:57	2020-03-01	Myrl White	myrl.white@geemail.com	Minneapolis	Minnesota	210048655210931700	55e8b803daa0c9c4e7b7230481586e48	VISA 16 digit	44.9941735338505353	-93.2606177799675606
14005	2020-03-01 02:30:23	2020-03-01	Dillon Champlin	dillon.champlin@geemail.com	Bakersfield	California	3049862812858300	45b7869cd3732368f848fa986f77c735	VISA 16 digit	35.3255721942231062	-119.002598475785177
14006	2020-03-01 02:47:29	2020-03-01	Grover West	grover.west@geemail.com	Costa Mesa	California	3774273661175186	59f61f7e0fc3326724dc139201ca5f32	American Express	33.7420475488543516	-117.860272017992287
14007	2020-03-01 02:58:01	2020-03-01	Mrs. Evalyn Rippin MD	mrs.evalyn.rippin.md@woohoo.com	Mesa	Arizona	3040741043600625	a127726611832ff75e78176c37316681	VISA 13 digit	33.3446806908264719	-111.623210659471894
14008	2020-03-01 03:12:38	2020-03-01	Augustus Hermann	augustus.hermann@warmmail.com	Oakland	California	3443186369511346	58db52ff30ebb143f665f6f121026105	Discover	37.8085524774813138	-122.262106811380249
14009	2020-03-01 03:31:09	2020-03-01	Cody Rempel	cody.rempel@geemail.com	Phoenix	Arizona	180047133050385412	6543f68966024e6ce4701ada7996af8b	VISA 16 digit	33.5710302774727367	-112.147934226312117
14010	2020-03-01 03:48:47	2020-03-01	Denese Bogan	denese.bogan@warmmail.com	Oakland	California	54529208580616804	c283c92eb16083529e70b32e56a2cc3a	Diners Club / Carte Blanche	37.810309004969568	-122.244040570631384
14011	2020-03-01 03:58:55	2020-03-01	Stan West	stan.west@geemail.com	Modesto	California	869955114157483283	85cbb7aa2a6882dc1e30a9b45f3d6086	Mastercard	37.5531157878693236	-121.094799848154182
14012	2020-03-01 04:27:15	2020-03-01	Jett Lindgren	jett.lindgren@geemail.com	San Francisco	California	4059872404278	f708402e17e45e5e7b46ac41d1fde98f	JCB 15 digit	37.7891305470909558	-122.447204713064636
14013	2020-03-01 04:31:09	2020-03-01	Thresa Hammes	thresa.hammes@geemail.com	San Francisco	California	3158582271292098046	4f75ea2ce0f47f0c1bdbdf3ad7076659	Maestro	37.7829839439885902	-122.400653731105791
14014	2020-03-01 04:34:48	2020-03-01	Janeen Walker PhD	janeen.walker.phd@geemail.com	San Francisco	California	869907203170248663	548beff77e3aebe30c3e10738c48dd08	JCB 15 digit	37.7546393667986848	-122.406347430706106
14015	2020-03-01 04:36:35	2020-03-01	Roxanna Hoeger	roxanna.hoeger@geemail.com	Hayward	California	6011543842873890726	4c8a98b7a0579bbac04fe83db6aff252	American Express	37.6970281690813636	-122.032369429317868
14016	2020-03-01 04:44:01	2020-03-01	Mr. Vernal Aufderhar MD	mr.vernal.aufderhar.md@geemail.com	McKinney	Texas	869976718807600206	ba32fabf22900e6a365a0d5718264526	VISA 16 digit	33.2837391113527161	-96.5943698408845819
14017	2020-03-01 04:46:07	2020-03-01	Hjalmer Hartmann II	hjalmer.hartmann.ii@geemail.com	San Antonio	Texas	4200933901972083	d83d8a49b5b6b884df58844a645f5878	JCB 16 digit	29.5092042813614022	-98.4314475721050002
14018	2020-03-01 05:06:04	2020-03-01	Ms. Paisley Dooley DVM	ms.paisley.dooley.dvm@geemail.com	San Francisco	California	4814492089169523	a77371785e3dd7d11bb3a9c395031adc	Voyager	37.7924022491745788	-122.443026165322991
14019	2020-03-01 05:23:14	2020-03-01	Dr. Mariano McLaughlin DVM	dr.mariano.mclaughlin.dvm@geemail.com	New York	New York	4959211481205494	8eb5c8bdaf23366647ad2bc07a42c028	Voyager	40.6804662690721415	-73.9519712258491637
14020	2020-03-01 05:42:29	2020-03-01	Isadore White-Lang	isadore.white.lang@geemail.com	Sandy Springs	Georgia	869978883440091151	1a880bf858e35cfd4a729016e7cb069b	American Express	34.0053753872923537	-84.3097879505332628
14021	2020-03-01 05:45:19	2020-03-01	Chelsea Bernier	chelsea.bernier@geemail.com	Edison	New Jersey	4404202425052242	414a3cf3fdd87a0d630e1baf0af357a5	VISA 16 digit	40.5872453084643894	-74.3643904075078694
14022	2020-03-01 05:51:00	2020-03-01	Mr. Aldo Legros II	mr.aldo.legros.ii@geemail.com	Newark	New Jersey	502025227844476	cf6f397cd7c7a1ec13fb073e49331322	Mastercard	40.7398857144553261	-74.2113456849683075
14023	2020-03-01 05:58:00	2020-03-01	Mrs. Joella Medhurst MD	mrs.joella.medhurst.md@geemail.com	Nashville	Tennessee	060486602820242	1767486ba7efd0df26e7e30606b327e3	VISA 16 digit	36.1871172564692785	-86.8263772569037968
14024	2020-03-01 06:11:39	2020-03-01	Netta Larkin	netta.larkin@geemail.com	Oceanside	California	869937360261814227	0fde2d843e7e8702774ae529818b91a8	VISA 16 digit	33.1364038671720778	-117.379752381433548
14025	2020-03-01 06:15:20	2020-03-01	Stefan Ankunding	stefan.ankunding@geemail.com	San Francisco	California	4431789239567388	217fdcc8d1d272b99acacf5c4f860f07	American Express	37.7904583657198572	-122.416570890763381
14026	2020-03-01 06:21:51	2020-03-01	Donita Lemke	donita.lemke@geemail.com	Houston	Texas	3040500746706323	a247695b0440c331bf34f493bd4fe498	Discover	29.757631672600656	-95.464998426895221
14027	2020-03-01 07:04:26	2020-03-01	Viviana Hudson PhD	viviana.hudson.phd@geemail.com	San Francisco	California	210079942216566967	24792533bd969476acaac91ffeb4d679	VISA 16 digit	37.7775342863435029	-122.441320110829537
14028	2020-03-01 07:11:15	2020-03-01	Obe McClure	obe.mcclure@geemail.com	Charlotte	North Carolina	3773090278917029	1dae48924285490ca98b13a2f4d59ffe	Voyager	35.2479775110512961	-80.7864401925765065
14029	2020-03-01 08:02:12	2020-03-01	Lawerence Pfannerstill	lawerence.pfannerstill@geemail.com	Tucson	Arizona	630472474657912	5afa017416e1d61ef4133465624448f4	Discover	32.1567048082634841	-110.813389797857397
14030	2020-03-01 08:07:30	2020-03-01	Johnathan Pagac PhD	johnathan.pagac.phd@geemail.com	Berkeley	California	210085288119984317	32319022ceda0bbc0149181a3b923aa3	Diners Club / Carte Blanche	37.8913351728880201	-122.279795852708958
14031	2020-03-01 08:12:19	2020-03-01	Torrance Dickens-Stracke	torrance.dickens.stracke@geemail.com	New York	New York	3021316792196643	65f75f08449b6f6afe4a7cb0958e7077	JCB 16 digit	40.7111902908645575	-74.0084359337005679
14032	2020-03-01 08:16:49	2020-03-01	Burdette Spencer Jr.	burdette.spencer.jr.@woohoo.com	San Francisco	California	503848818797341	3ac74efad7e4b373943267d6dcc9e879	JCB 16 digit	37.788259011918548	-122.432670200323059
14033	2020-03-01 08:17:26	2020-03-01	Gayle Denesik	gayle.denesik@geemail.com	Berkeley	California	54596951458417882	57e68d65c5fa9ac176196d7718bd60f8	American Express	37.8751121542176037	-122.255679117828649
14034	2020-03-01 08:31:51	2020-03-01	Colleen Dooley MD	colleen.dooley.md@warmmail.com	San Francisco	California	53668376509012966	a5ac5beb92ca256d2aefaa6e33b6816b	VISA 16 digit	37.784931824339715	-122.470296446285843
14035	2020-03-01 09:00:15	2020-03-01	Connie Howell	connie.howell@geemail.com	Baltimore	Maryland	53350968754897779	7aea311f7213d7199a95bcb31ffcf723	VISA 16 digit	39.3465033495798693	-76.6738607170078978
14036	2020-03-01 09:09:43	2020-03-01	Margarette Dicki	margarette.dicki@warmmail.com	Laredo	Texas	869983307107792383	8b64105d0524f56d762b6175958fe095	JCB 15 digit	27.6157607121109976	-99.5522624469835336
14037	2020-03-01 09:47:24	2020-03-01	Dr. Dayana Hand	dr.dayana.hand@geemail.com	Burbank	California	6011510425099520308	646f4032be4a2ace932cc96719459dbd	JCB 16 digit	34.1423390865255172	-118.358657121289156
14038	2020-03-01 10:11:33	2020-03-01	Dr. Kip Marks II	dr.kip.marks.ii@geemail.com	San Francisco	California	55010948968846764	8ea3177a7825b9483f20e9c5293aaff3	VISA 16 digit	37.7799978419043612	-122.423792370314899
14039	2020-03-01 10:31:47	2020-03-01	Dr. Alonza Ullrich	dr.alonza.ullrich@geemail.com	Broken Arrow	Oklahoma	4188468469864	aeed3444c6acdb9b47b5512d907e953d	JCB 15 digit	36.0134408442545677	-95.7183975990340201
14040	2020-03-01 10:54:15	2020-03-01	Ieshia Terry	ieshia.terry@geemail.com	El Paso	Texas	589319384345955	cf083d3649b7f1ee2683879a76f6c213	Diners Club / Carte Blanche	31.842966218741239	-106.410206692803655
14041	2020-03-01 11:02:41	2020-03-01	Montana Stoltenberg	montana.stoltenberg@geemail.com	Corpus Christi	Texas	676251573784371	6f6a46bfd26d86265f9e0441a546142a	American Express	27.8321876376338295	-97.2262750062454444
14042	2020-03-01 11:24:15	2020-03-01	Mrs. Jenelle Conn	mrs.jenelle.conn@warmmail.com	San Francisco	California	869967508532058825	1d575c53e0963ad764c188678a14b1cc	JCB 16 digit	37.7587340395719977	-122.44382496859167
14043	2020-03-01 11:32:13	2020-03-01	Ancel Keeling	ancel.keeling@geemail.com	Tampa	Florida	3088573159480552240	eefc48b0d4f0e2c12f5154c1e53cf899	VISA 16 digit	28.0558105269562432	-82.389527177366233
14044	2020-03-01 11:46:01	2020-03-01	Dr. Jana Simonis	dr.jana.simonis@geemail.com	Macon	Georgia	180041044340129815	05cddcc20f2986e9a0384124c6bddad3	Voyager	32.7734253465674783	-83.7391306039139636
14045	2020-03-01 12:11:34	2020-03-01	Maxie Little	maxie.little@geemail.com	Louisville	Kentucky	180047843166945657	a6c24c7d7d53ccc82250192b01782f8a	VISA 13 digit	38.0803638749193354	-85.6601147892955765
14046	2020-03-01 12:25:08	2020-03-01	Codey Marks	codey.marks@geemail.com	Madison	Wisconsin	3010379163244351	f8da287722f15362f0939686650299c6	Discover	42.9926426521010683	-89.3615729823593057
14047	2020-03-01 12:48:27	2020-03-01	Georgianna Bartoletti	georgianna.bartoletti@geemail.com	Phoenix	Arizona	4318756274467996	36fbb18e483bdfad82b9faf240613e3e	VISA 13 digit	33.6049976115513616	-111.99544418234602
14048	2020-03-01 12:48:54	2020-03-01	Waldemar Marks IV	waldemar.marks.iv@geemail.com	Inglewood	California	180043150940419478	991875f0412e573f04a0cf8cf224ac61	JCB 16 digit	33.9262860366854824	-118.352155450361977
14049	2020-03-01 12:48:59	2020-03-01	Tegan Bernhard	tegan.bernhard@woohoo.com	San Francisco	California	3031592376922170	defce862fb6007878e377b4002f20943	VISA 16 digit	37.7698796839191218	-122.454527621207774
14050	2020-03-01 12:51:04	2020-03-01	Liz Wisoky DVM	liz.wisoky.dvm@geemail.com	Mesa	Arizona	6011475929478541259	fcd8eb9706d81a603967b71d4b4efee2	JCB 16 digit	33.4433790619164668	-111.813855958625297
14051	2020-03-01 12:58:45	2020-03-01	Mrs. Roseanne Conroy	mrs.roseanne.conroy@geemail.com	New York	New York	4360232535267747	d6bcddccdaafd8c3c8d0f39782bc8dd7	American Express	40.6858191554658077	-73.8453126896068426
14052	2020-03-01 13:14:20	2020-03-01	Mr. Harvey Orn Jr.	mr.harvey.orn.jr.@geemail.com	San Francisco	California	4603044405810	4d9f761f84ae03237d89c5281220a8c3	JCB 16 digit	37.7575984218062146	-122.452184293241118
14053	2020-03-01 13:20:20	2020-03-01	Bush Emmerich-Nienow	bush.emmerich.nienow@geemail.com	Buffalo	New York	3096297175556684217	0a1ebfa133c91a71f805de6d26cf8af1	Mastercard	42.8443457172438471	-78.8220765058815545
14054	2020-03-01 13:36:56	2020-03-01	Mrs. Leontine Hoeger	mrs.leontine.hoeger@geemail.com	San Francisco	California	52354294358222140	74a77ae8fe96d40b283f4aec9f510419	JCB 16 digit	37.8028427917652365	-122.416172201492969
14055	2020-03-01 13:44:50	2020-03-01	Maximilian Cremin	maximilian.cremin@geemail.com	Charlotte	North Carolina	4873273692287540	4f13458f5f90198c1bfbf57c542d9e63	American Express	35.1898056941360196	-80.7862298822440295
14056	2020-03-01 13:51:30	2020-03-01	Jazmine Kling	jazmine.kling@geemail.com	Phoenix	Arizona	3419349479774028	9cdfd7527a2aa6c7c5bd545d76379df8	VISA 16 digit	33.6255700140658789	-112.161179027559612
14057	2020-03-01 13:58:45	2020-03-01	Londyn Pollich	londyn.pollich@geemail.com	Charlotte	North Carolina	869968929978113487	3cd09da7d92a2abe2e0708779abec8cf	VISA 13 digit	35.2396881763610992	-80.897042713448414
14058	2020-03-01 14:05:36	2020-03-01	Mr. Saul Hauck	mr.saul.hauck@geemail.com	Davie	Florida	51153373019434782	2485653cc0ad85a0b397754026fafa1f	JCB 16 digit	26.1036829925406728	-80.2457987161725725
14059	2020-03-01 14:07:54	2020-03-01	Ms. Rihanna Dickinson	ms.rihanna.dickinson@woohoo.com	New York	New York	869976429301666178	93315d1ac5fbdf10be8dda7bda683652	JCB 16 digit	40.7525285060740998	-74.0216443203285337
14060	2020-03-01 14:23:19	2020-03-01	Althea Quitzon-Emmerich	althea.quitzon.emmerich@woohoo.com	Rockford	Illinois	4919878676395	1ad54e88e01927f310c16e8752f26274	Diners Club / Carte Blanche	42.2097730197489298	-89.0250364238213763
14061	2020-03-01 15:03:47	2020-03-01	Raven Smitham	raven.smitham@geemail.com	Jurupa Valley	California	4813255885259843	1f2fa0d4202ea958fb978a96cad61343	American Express	34.0116778088197123	-117.368577009581401
14062	2020-03-01 15:10:05	2020-03-01	Maria Moen	maria.moen@geemail.com	San Jose	California	501858025245083	6ab94ca1d28e9e50edd306675f4306e0	American Express	37.2472001642275643	-121.876639792671057
14063	2020-03-01 15:20:57	2020-03-01	Kevon Ziemann	kevon.ziemann@geemail.com	San Francisco	California	180019488660014099	514cb3afdcbeaf19affb20600de29a92	JCB 16 digit	37.7551540741149338	-122.449861534416286
14064	2020-03-01 16:03:51	2020-03-01	Sade Hoeger	sade.hoeger@woohoo.com	Little Rock	Arkansas	3427271718741826	eca638a720894481f0b24f015756a023	JCB 15 digit	34.6915793122068052	-92.2601448167920068
14065	2020-03-01 16:09:04	2020-03-01	Isaak Graham	isaak.graham@geemail.com	San Francisco	California	4164482921037364	4476e019c51adeecb3d451cf54004127	Discover	37.7859221549108142	-122.447592415830215
14066	2020-03-01 16:19:57	2020-03-01	Lavonia D'Amore-Jast	lavonia.d'amore.jast@geemail.com	San Francisco	California	869959425454628883	1f221455c94d6c756d953210ba054b03	American Express	37.7795678481745583	-122.405297319535777
14067	2020-03-01 16:24:47	2020-03-01	Tawny Ryan	tawny.ryan@warmmail.com	New York	New York	4012795162342894	71cd580fbbd912eea62cb8777dde38ed	VISA 16 digit	40.7176083742398731	-73.9932496509876074
14068	2020-03-01 16:25:23	2020-03-01	Ms. Areli Murphy MD	ms.areli.murphy.md@geemail.com	Santa Clara	California	3703609407332175	b8b7b512507e4fb977e6d8636b38a287	VISA 16 digit	37.43805069320873	-121.973426783829552
14069	2020-03-01 16:40:38	2020-03-01	Harvey Huels	harvey.huels@geemail.com	Indianapolis	Indiana	3033887238759382	e1afb5043739bc4a20310375a31e022f	JCB 16 digit	39.8303808524746401	-86.1322794940058145
14070	2020-03-01 17:01:36	2020-03-01	Tamela Berge	tamela.berge@geemail.com	San Francisco	California	3046045076753259	55f9e2683fe78708251cd48771c6b5e8	VISA 16 digit	37.7429688225152589	-122.45345063084234
14071	2020-03-01 17:14:14	2020-03-01	Bose Kreiger	bose.kreiger@geemail.com	Tulsa	Oklahoma	4202776979428811	6af96c3549a0b856267b429e0cfeb4ab	JCB 16 digit	36.156004111040005	-95.8515839923128397
14072	2020-03-01 17:17:58	2020-03-01	Burns Okuneva	burns.okuneva@geemail.com	Shreveport	Louisiana	53483560587486613	a29a1741e186c46c5cb0751020cd9fd2	JCB 16 digit	32.4498857409931745	-93.808241659982869
14073	2020-03-01 17:32:04	2020-03-01	Burrel Bosco	burrel.bosco@geemail.com	Louisville	Kentucky	4822396951933074	466082518c85a7a12d4b4f9b4752e27f	JCB 16 digit	38.1513615278895912	-85.6135760688293743
14074	2020-03-01 17:32:38	2020-03-01	Kyle Bode III	kyle.bode.iii@warmmail.com	Lakewood	Colorado	3088858164778614914	fa2ac6db1ed330284b8cbfc85991a899	JCB 15 digit	39.7594642386712138	-105.189240654746442
14075	2020-03-01 17:45:17	2020-03-01	Mr. Nicholaus Schneider DDS	mr.nicholaus.schneider.dds@woohoo.com	Glendale	Arizona	210001433612884645	c699739fa1beab830ac2b978c9f5dd3b	Discover	33.4397447858233008	-112.239843597195659
14076	2020-03-01 17:51:00	2020-03-01	Karel Mann DVM	karel.mann.dvm@woohoo.com	Chicago	Illinois	589396230469007	ba9a559dbd5126d60765e63668a3c2cf	Diners Club / Carte Blanche	41.7830214055091176	-87.6461853680696237
14077	2020-03-01 18:40:33	2020-03-01	Auguste Nikolaus	auguste.nikolaus@geemail.com	Kansas City	Missouri	3792917893993752	8a5a0b2bee7e771788e9128c51b4aaa1	JCB 16 digit	39.0348593456972424	-94.6057834518365581
14078	2020-03-01 18:44:23	2020-03-01	Tiffani White	tiffani.white@geemail.com	San Jose	California	3711658129522191	f9310e0a110ba1066c8fbf8bc9124691	VISA 16 digit	37.2169446955256191	-121.874061175271493
14079	2020-03-01 18:55:45	2020-03-01	Delora Wiegand	delora.wiegand@geemail.com	New York	New York	561278445759786	92d0ba3ae9a0755521367e7480387a15	VISA 16 digit	40.6138739145584395	-73.8974829061783822
14080	2020-03-01 19:07:24	2020-03-01	Mr. Delmas Feest DVM	mr.delmas.feest.dvm@geemail.com	Killeen	Texas	4159656144107438	107ef287fcc22c0bf3fb77bd6b20ab41	VISA 13 digit	31.0087961218550809	-97.7584459360856499
14081	2020-03-01 19:15:30	2020-03-01	Antonette Towne	antonette.towne@warmmail.com	San Francisco	California	210028556132198572	8d3f44f0371d80ea08ff35f92f6e3166	Diners Club / Carte Blanche	37.7081428198351247	-122.423988707298477
14082	2020-03-01 20:22:18	2020-03-01	Berton Metz	berton.metz@woohoo.com	Austin	Texas	869979678651326869	aa02d9164b356f30e83083ad8bce3d9e	JCB 15 digit	30.2891525772526862	-97.8210912827640868
14083	2020-03-01 20:29:18	2020-03-01	Monna Emmerich	monna.emmerich@geemail.com	Philadelphia	Pennsylvania	3112887285211604702	8b55d73bfdaa5db6306ca73b879012fd	JCB 16 digit	39.9383574251975872	-75.0898409400500384
14084	2020-03-01 20:43:16	2020-03-01	Isam Kilback	isam.kilback@geemail.com	Columbia	Missouri	869954752943013681	d4246cc0e4219bc4767f96b2e346d4db	American Express	38.9853913667958807	-92.321518615591998
14085	2020-03-01 20:45:06	2020-03-01	Lorin Weissnat-Hansen	lorin.weissnat.hansen@geemail.com	Clinton	Michigan	210077936744572143	809b30cec199129af96058800d096957	Mastercard	42.4947127540197229	-82.8671321022864475
14086	2020-03-01 20:59:16	2020-03-01	Hamp Shields Sr.	hamp.shields.sr.@geemail.com	San Francisco	California	3158746325831980339	763756ebf6403de37b849996815b8f7a	VISA 16 digit	37.7456960302517359	-122.432459167935448
14087	2020-03-01 21:07:56	2020-03-01	Kendrick Berge	kendrick.berge@woohoo.com	Dallas	Texas	676115743580043	2307dc7dc27597a6758eb4fba8f14315	VISA 16 digit	32.8791291341923184	-96.7078492402061727
14088	2020-03-01 21:25:22	2020-03-01	Nakita Robel	nakita.robel@woohoo.com	Oakland	California	3463119813629245	e44d4a0b3a2183238d3b8a5998e45430	JCB 16 digit	37.7868757357418517	-122.270448771324268
14089	2020-03-01 21:29:45	2020-03-01	Ms. Aleta Kreiger	ms.aleta.kreiger@geemail.com	San Francisco	California	54705410341129145	deec4c4fd589ea6d4d870d1a06ff3763	JCB 16 digit	37.77135915646857	-122.430312326651958
14090	2020-03-01 21:34:04	2020-03-01	Mariyah Mitchell PhD	mariyah.mitchell.phd@geemail.com	Houston	Texas	630425550402769	6b677273b35082cfc35853b05b3a9f2f	VISA 16 digit	29.738306719584763	-95.4107956782929563
14091	2020-03-01 22:01:00	2020-03-01	Sonia Moore	sonia.moore@woohoo.com	San Francisco	California	4267412953551194	a13d705890671c60794e9e17755046e6	VISA 16 digit	37.7471624375978294	-122.417219413518097
14092	2020-03-01 22:05:02	2020-03-01	Dr. Johana Kassulke MD	dr.johana.kassulke.md@woohoo.com	Tulsa	Oklahoma	180059201169978222	c6cd29315c5d04fc8c6b2319d8ac4540	Discover	36.0726814798913864	-95.964243926103407
14093	2020-03-01 22:44:28	2020-03-01	Mr. Esau Reilly	mr.esau.reilly@geemail.com	Orlando	Florida	180066624690366339	0368eb93b40412d35a350f3603904002	Diners Club / Carte Blanche	28.5099715001679961	-81.3236429385807327
14094	2020-03-01 22:44:51	2020-03-01	Dr. Tyrus Lubowitz III	dr.tyrus.lubowitz.iii@geemail.com	Chicago	Illinois	676219119642973	632f2ec1eb4b5a3c3be6f81848fed61c	Mastercard	41.7794278258293872	-87.7180077641300784
14095	2020-03-01 22:47:18	2020-03-01	Vara Hills	vara.hills@geemail.com	Manchester	New Hampshire	180078635975050980	987355c87d92b7325653e82c7dbd64b7	JCB 16 digit	42.9651486796397748	-71.4730114844519733
14096	2020-03-01 22:53:44	2020-03-01	Sandi Cole	sandi.cole@warmmail.com	New York	New York	3158448054078883136	b88b0857ae60c5f8e93836d56de1c850	Mastercard	40.6224257492218186	-73.9453091767046544
14097	2020-03-01 23:03:13	2020-03-01	Monica Heller	monica.heller@geemail.com	Dallas	Texas	3337497991821761285	d03ff08dc228c5e0c927ad2b064ce711	American Express	32.7346542391732385	-96.7224336739592161
14098	2020-03-01 23:39:54	2020-03-01	Lorayne Bartell	lorayne.bartell@geemail.com	Portland	Oregon	54127473218202239	a83f7a049dedee634fc9cb294ecb78d4	American Express	45.6218558680620063	-122.551301185740158
14099	2020-03-01 23:42:25	2020-03-01	Bryana Conroy	bryana.conroy@geemail.com	Oklahoma City	Oklahoma	3011106454030861	3ec9c1b92f83781b391f65efe8a0a0f6	VISA 16 digit	35.5187425904817928	-97.5816860352538527
14100	2020-03-01 23:54:19	2020-03-01	Celia Stanton	celia.stanton@geemail.com	Lewisville	Texas	869947065907124323	fc0735653203edc2a064c2f6d632140d	Mastercard	33.0192733303163166	-96.9606378055207472
14101	2020-03-02 00:01:49	2020-03-02	Maximillian Johnston	maximillian.johnston@geemail.com	Fort Worth	Texas	3337299196993860929	63e69758b2f9c6cf1a2baca47a663212	VISA 16 digit	32.8797305896002783	-97.3563275413408888
14102	2020-03-02 00:53:20	2020-03-02	Miss Ila Simonis	miss.ila.simonis@geemail.com	San Francisco	California	869983057724911177	a8a0d9e4927bcc48e12759592b4a9cae	JCB 16 digit	37.7946928966869677	-122.466429323537909
14103	2020-03-02 00:53:48	2020-03-02	Mr. Virgil Upton Sr.	mr.virgil.upton.sr.@geemail.com	Los Angeles	California	3054696301361920	7fd1a53806ab484c86443eeca3378ce4	JCB 16 digit	34.044565882334112	-118.350621201050643
14104	2020-03-02 01:13:38	2020-03-02	Leighton Mitchell	leighton.mitchell@geemail.com	Charleston	South Carolina	4722538998789495	ca529a2b4554af213546a2b9f706f47b	VISA 16 digit	32.7722873264454293	-79.8970339786410335
14105	2020-03-02 01:21:24	2020-03-02	Mrs. Avis Ernser DVM	mrs.avis.ernser.dvm@warmmail.com	Berkeley	California	4341106613174062	7950601a7954696b59c4cfa75d0b6604	Discover	37.8589710988834867	-122.294718937769645
14106	2020-03-02 02:03:53	2020-03-02	Justice Leuschke-Adams	justice.leuschke.adams@warmmail.com	Ann Arbor	Michigan	676295169026093	3c25131d6b269165a72a40f269ccc22c	JCB 16 digit	42.1856091680996101	-83.7559927786342797
14107	2020-03-02 02:06:58	2020-03-02	Mrs. Nohely Kihn DVM	mrs.nohely.kihn.dvm@geemail.com	Berkeley	California	4999957165718952	e6456f0fb960e08373caaa153fe3bfbc	VISA 16 digit	37.8975185221154049	-122.289396916459495
14108	2020-03-02 02:24:54	2020-03-02	Ottie Langosh	ottie.langosh@geemail.com	Irvine	California	3766371773261900	0a24fa61523f077894aa794b182b8584	VISA 16 digit	33.6319056521650452	-117.73063707961812
14109	2020-03-02 02:30:05	2020-03-02	Lise Moore	lise.moore@geemail.com	Jacksonville	Florida	51956059420117996	715bb59c10e2c74fd77bc814deace987	JCB 16 digit	30.408742265175654	-81.7177929676681885
14110	2020-03-02 02:59:33	2020-03-02	Ason Moore	ason.moore@geemail.com	Sunnyvale	California	4247730322325	86e1992176e8635b3863bb21871f323a	Maestro	37.4263538729857714	-122.089856052697826
14111	2020-03-02 03:07:18	2020-03-02	Ardath Keeling	ardath.keeling@woohoo.com	Athens	Georgia	4260117000116803	4b9e491c44be5edbdd40fbbb5d7e19cc	VISA 13 digit	33.90879176521711	-83.3313055335193837
14112	2020-03-02 03:16:24	2020-03-02	Dr. Garrison Padberg PhD	dr.garrison.padberg.phd@woohoo.com	Oklahoma City	Oklahoma	4314739055305704	0d11b5406b42f7ab7eedf7f1e01dddf5	Voyager	35.5295853211455039	-97.4378230939980625
14113	2020-03-02 04:35:09	2020-03-02	Coral Wuckert	coral.wuckert@geemail.com	Detroit	Michigan	3797007067371947	b833bb249a6924e34354779b3e36667a	JCB 16 digit	42.3951975801885155	-83.0416848605152182
14114	2020-03-02 04:41:49	2020-03-02	Mr. Bethel Walsh	mr.bethel.walsh@geemail.com	Albuquerque	New Mexico	4275583470682413	0625b46f2577599717e2bd2b2dac9edc	Voyager	35.1177970945969236	-106.639189312474429
14115	2020-03-02 05:20:56	2020-03-02	Adilene Williamson	adilene.williamson@geemail.com	San Francisco	California	4138161351746065	731d7fb1003ec8a615eb58cb13a1c30b	Maestro	37.7923457393477449	-122.446962813192172
14116	2020-03-02 05:55:11	2020-03-02	Shaylee Sawayn-Harvey	shaylee.sawayn.harvey@woohoo.com	Oakland	California	210055294205841987	27bd7183ba04d876329bf8a62fbedfdf	Maestro	37.8123536608725672	-122.274790670972337
14117	2020-03-02 06:00:53	2020-03-02	Lavonne Flatley	lavonne.flatley@woohoo.com	Columbia	Missouri	6011828595541825187	bf8681b66de10d1848bdd867edc8ed57	Maestro	38.8700587755416151	-92.3697524307348914
14118	2020-03-02 06:31:55	2020-03-02	Marchello Kohler	marchello.kohler@geemail.com	San Francisco	California	4243533461295	299f95075cc6e7613ebd5838a52059c9	JCB 16 digit	37.7732310840083585	-122.436225103102117
14119	2020-03-02 06:33:15	2020-03-02	Olive O'Conner	olive.o'conner@woohoo.com	Wilmington	North Carolina	869965636362044490	ea241ad91255f2ebe86756b6c055eef6	Maestro	34.1530174307346357	-77.809841143851358
14120	2020-03-02 06:41:22	2020-03-02	Miss Adison Schmeler DDS	miss.adison.schmeler.dds@geemail.com	Surprise	Arizona	869965251445174577	7709fd0d05e20f71afc83974db7a945e	JCB 16 digit	33.6534578146640229	-112.357775617646794
14121	2020-03-02 06:44:07	2020-03-02	Mrs. Melodie Bins	mrs.melodie.bins@woohoo.com	Pasadena	California	3112948168385452826	07734b810f9e7b80a46cbe29bfb8b77d	Voyager	34.2398750193737484	-118.221438251836602
14122	2020-03-02 06:58:02	2020-03-02	Julia Champlin-Senger	julia.champlin.senger@geemail.com	Berkeley	California	869923911105995295	037581d3f409956a2b9a3f2ffa67c584	Voyager	37.8698633985984685	-122.256605063540931
14123	2020-03-02 07:53:52	2020-03-02	Patric Quigley I	patric.quigley.i@geemail.com	Round Rock	Texas	3010971533815686	eedc8a1864b67d6cf46687ab16a8b076	Maestro	30.5405370026499057	-97.70597371220029
14124	2020-03-02 08:01:11	2020-03-02	Dr. Newt Ratke	dr.newt.ratke@geemail.com	Miramar	Florida	3158423922465306276	3a7edb67201bb7dfcc6b2894676e09f3	VISA 13 digit	26.0724427182674425	-80.2429756312623681
14125	2020-03-02 08:32:34	2020-03-02	Yandel Doyle-Rice	yandel.doyle.rice@geemail.com	Miami	Florida	4947168519512	3956ecb75fb0be6353a718d0f73a8f37	Discover	25.6851714162293838	-80.2587194028649549
14126	2020-03-02 08:42:41	2020-03-02	Miss Leatha Rau MD	miss.leatha.rau.md@geemail.com	Charlotte	North Carolina	3437531645142838	a48b7fc2712b8f3b6f55b407320bdd78	JCB 15 digit	35.281219581027699	-80.8209269664194494
14127	2020-03-02 08:51:49	2020-03-02	Johnie Schoen	johnie.schoen@geemail.com	San Francisco	California	4440920584815226	2f79c696f12edf937f382318630276c3	Voyager	37.768559235474676	-122.402213923480772
14128	2020-03-02 08:57:01	2020-03-02	Mrs. Lavonda Ritchie MD	mrs.lavonda.ritchie.md@woohoo.com	New York	New York	52191677539330245	74d2536dd0455f682a9872cfcd22dd38	JCB 15 digit	40.5784484608788034	-73.9995446657191991
14129	2020-03-02 09:10:18	2020-03-02	Mrs. Carri Kutch PhD	mrs.carri.kutch.phd@woohoo.com	Berkeley	California	6011964634180390163	b2f82916ca53e031ef1c15345dff0423	Maestro	37.8952396300097263	-122.28989210469814
14130	2020-03-02 09:10:31	2020-03-02	Dr. Darren Kirlin I	dr.darren.kirlin.i@woohoo.com	Jacksonville	Florida	3337289583135735725	d39b6994f2263a5a399095a1978d6f5a	Voyager	30.3919451748073115	-81.6005065363910091
14131	2020-03-02 09:22:34	2020-03-02	Mistie Schultz	mistie.schultz@woohoo.com	Phoenix	Arizona	4243101144711	3be3d13de3785c2d9b09fbcda7e8f1f8	JCB 16 digit	33.5041588910322687	-111.995195985066147
14132	2020-03-02 09:23:46	2020-03-02	River Hane	river.hane@woohoo.com	Boston	Massachusetts	3019581841273907	a9ab902e5362868c633ae0e25e2e09db	Diners Club / Carte Blanche	42.2357834876682645	-71.1050323128651911
14133	2020-03-02 09:49:21	2020-03-02	Ms. Socorro Medhurst	ms.socorro.medhurst@warmmail.com	San Francisco	California	869912306380174802	5f8e36359496d00fb51f9a2bda2cde4c	JCB 16 digit	37.745205235962473	-122.43547271957793
14134	2020-03-02 10:09:51	2020-03-02	Kymani Little	kymani.little@geemail.com	San Antonio	Texas	180067709119994750	f4ef10d9bfdcb458d1bd4bf17fa5658e	Maestro	29.5019046797953557	-98.4790328714832555
14135	2020-03-02 10:14:16	2020-03-02	Garth Klocko	garth.klocko@geemail.com	Waterbury	Connecticut	4439155889557917	81c5e4562698231a1e01c8e941507c1f	VISA 16 digit	41.6054419342931396	-73.0279256534211356
14136	2020-03-02 10:52:03	2020-03-02	Oliver Feil	oliver.feil@woohoo.com	Carrollton	Texas	3096141357289001798	c97c520b94f0631007454b8da8b26335	Maestro	33.0234798461120533	-96.8392271455705185
14137	2020-03-02 10:58:58	2020-03-02	Katheryn Wolf	katheryn.wolf@geemail.com	San Francisco	California	3057629929732625	b7f23b65c00a3a4eb460930fdc6dcbf8	Voyager	37.8164250578002168	-122.426947459015835
14138	2020-03-02 11:01:04	2020-03-02	Mell Mueller	mell.mueller@geemail.com	Los Angeles	California	3088056272728434778	8635be4110a857b2264a9384ac21bddc	American Express	34.0547839719667991	-118.499370117391635
14139	2020-03-02 11:21:33	2020-03-02	Dr. Citlali Abernathy	dr.citlali.abernathy@geemail.com	San Francisco	California	3023565384855044	258b7fdab4d42288928f75f1c9e493a8	VISA 16 digit	37.7650795455053157	-122.405053864160067
14140	2020-03-02 11:22:28	2020-03-02	Breana Swaniawski	breana.swaniawski@geemail.com	Phoenix	Arizona	4111310789735	db7a8c63f84516925c88ba1d485409f5	Discover	33.6374742368634827	-112.023706279594833
14141	2020-03-02 11:31:47	2020-03-02	Ermina Nader-Maggio	ermina.nader.maggio@geemail.com	Tacoma	Washington	4584723351529632	6407ed2a95d77df04c91730642f4ec68	VISA 13 digit	47.1610495066855151	-122.545507455780353
14142	2020-03-02 11:38:03	2020-03-02	Dr. Burnice Thompson V	dr.burnice.thompson.v@warmmail.com	New Haven	Connecticut	3337747883702928323	988c0311ec807918c9a8c847d5796701	JCB 16 digit	41.2874743416897942	-72.9849803274031643
14143	2020-03-02 11:41:39	2020-03-02	Jessee Greenfelder-Osinski	jessee.greenfelder.osinski@geemail.com	Oceanside	California	51674526796707023	a55c1c0835d12e246c4f06bf38d61342	Discover	33.2567299867402753	-117.260878856441749
14144	2020-03-02 12:13:27	2020-03-02	Herschel Stehr	herschel.stehr@geemail.com	Aurora	Illinois	4399818547242929	bbe32db0b2e235826354c30afac469bc	Maestro	41.7688663294762392	-88.2563340784911077
14145	2020-03-02 12:39:34	2020-03-02	Hermine Sipes DDS	hermine.sipes.dds@geemail.com	New Orleans	Louisiana	3528866919938964107	4ebfa61322726771da72456d296f5274	American Express	30.1466861515320836	-90.0257630709819523
14146	2020-03-02 12:45:34	2020-03-02	Lindbergh McClure	lindbergh.mcclure@geemail.com	San Francisco	California	869925605118376208	569d2ebd0418a0ff1252e7076e567dc0	Mastercard	37.7787233847687105	-122.433423965893908
14147	2020-03-02 12:55:59	2020-03-02	Barrie Mertz	barrie.mertz@geemail.com	Phoenix	Arizona	869923445291106375	32ace5ff8dc4e0682122178fa609d16e	JCB 16 digit	33.5846183542095176	-112.0071689039398
14148	2020-03-02 13:00:45	2020-03-02	Cleveland Durgan	cleveland.durgan@geemail.com	Oakland	California	869944469185406613	3ffdce713a6477e05c465e4d28af0dd1	JCB 16 digit	37.8135191514378235	-122.291436783822689
14149	2020-03-02 13:42:53	2020-03-02	Marguerite Walsh	marguerite.walsh@geemail.com	Sterling Heights	Michigan	3337488663857978650	1050f9aef100a27008a46b0beb120fe5	JCB 16 digit	42.6708540384274002	-83.0113784432571293
14150	2020-03-02 13:44:21	2020-03-02	Mr. Maurice Heaney	mr.maurice.heaney@geemail.com	Honolulu	Hawaii	676320490849443	d5129a97be2ca43613072ed505642a62	Voyager	21.4029084187682734	-157.888914374236379
14151	2020-03-02 13:51:14	2020-03-02	Mrs. Alani Schowalter	mrs.alani.schowalter@woohoo.com	New York	New York	3112000944836643436	98d53ee894cb649e8d7eaf2c3ba85616	VISA 16 digit	40.6211055863406472	-73.8763286847516838
14152	2020-03-02 13:53:53	2020-03-02	Faith Bauch MD	faith.bauch.md@geemail.com	Portland	Oregon	4688192022841260	90052563b5b23ff38aadcc91de2c3af2	VISA 16 digit	45.4637676317133028	-122.571697842283186
14153	2020-03-02 14:01:16	2020-03-02	Dr. Hanna Boehm MD	dr.hanna.boehm.md@geemail.com	Mobile	Alabama	4973201620114220	b741d73ea4e1b034bfc075c62484a335	JCB 16 digit	30.5747651138916581	-88.0727288871675711
14154	2020-03-02 14:04:28	2020-03-02	Arlyn Stark	arlyn.stark@woohoo.com	Fort Collins	Colorado	3528617702847381841	3eea1d3ac60a667eb6e6eac454bc0c91	JCB 16 digit	40.6070444377761319	-105.037747908379146
14155	2020-03-02 14:18:18	2020-03-02	Gaither Lindgren	gaither.lindgren@geemail.com	San Diego	California	3096001126832703542	4b886401505136c3868a73e52013e611	Mastercard	32.8029488728448726	-117.083319474700843
14156	2020-03-02 14:27:54	2020-03-02	Antonetta Berge	antonetta.berge@geemail.com	San Francisco	California	3096353640020041295	d2535033adc3315063fa5b5d44389ff1	JCB 15 digit	37.7461057481092084	-122.424224963319404
14157	2020-03-02 14:37:49	2020-03-02	Mr. Orvel Schinner	mr.orvel.schinner@geemail.com	Los Angeles	California	3706092369525424	3b723a2a40e16c84b729cbe0db170dee	VISA 16 digit	33.9311498163599481	-118.356422911304236
14158	2020-03-02 14:55:42	2020-03-02	Arnie Ankunding	arnie.ankunding@geemail.com	New York	New York	4415209919056420	244c6cd4c54e1e4cf55060efa9e5a881	Diners Club / Carte Blanche	40.7273731900136937	-73.8976818101376267
14159	2020-03-02 15:03:22	2020-03-02	Bruno Ondricka	bruno.ondricka@woohoo.com	Columbus	Georgia	589380514209149	2dec11096224f3e84a327372bd75ee43	VISA 13 digit	32.4474275279369166	-84.8363811369217871
14160	2020-03-02 15:29:48	2020-03-02	Dr. Stephenie Turcotte	dr.stephenie.turcotte@warmmail.com	Round Rock	Texas	180031591426937752	39eed13ff9fe68cf26eb262dab966594	Voyager	30.5200348482605079	-97.6580794629491891
14161	2020-03-02 15:32:59	2020-03-02	Norris Bednar	norris.bednar@warmmail.com	Fremont	California	060400736604471	59537a550651c2969c558de8699b054c	JCB 15 digit	37.5941993680018953	-122.016758309908951
14162	2020-03-02 15:47:08	2020-03-02	Crockett Rodriguez DVM	crockett.rodriguez.dvm@geemail.com	Washington	District of Columbia	3029399136988828	3328cab48f4ce4895d28965ea0f85c9c	JCB 15 digit	38.9899289498370152	-76.9391800718594396
14163	2020-03-02 15:54:55	2020-03-02	Mrs. Denisha Cremin	mrs.denisha.cremin@warmmail.com	New York	New York	4709128738567976	bb870c301d4cc77d186580a3fee4aa39	American Express	40.6970180699825264	-73.9128457044146927
14164	2020-03-02 15:56:38	2020-03-02	Leonora Jerde MD	leonora.jerde.md@woohoo.com	Indianapolis	Indiana	3337409903970926210	b814415012025b36f174e0dd78f43111	Voyager	39.7467537385418979	-86.165076436355335
14165	2020-03-02 16:07:33	2020-03-02	Karim Bauch-Klocko	karim.bauch.klocko@woohoo.com	Columbus	Ohio	4893742283275664	536c71b26739b87f2b9d1dad5ef0d356	Mastercard	39.9669306328564886	-82.9591811365682759
14166	2020-03-02 17:00:54	2020-03-02	Cathrine Brown DVM	cathrine.brown.dvm@warmmail.com	Los Angeles	California	676108888716530	cface65a0153a7159cb807d9a2ec7dda	Diners Club / Carte Blanche	33.9800367405969652	-118.435092495101685
14167	2020-03-02 17:07:41	2020-03-02	Keyla Donnelly	keyla.donnelly@geemail.com	Memphis	Tennessee	869993346735274479	48931fea3aac9c398d1ad13dc63f4bc7	JCB 16 digit	35.1558474248807897	-89.9802767906595022
14168	2020-03-02 17:10:00	2020-03-02	Abbott Hane	abbott.hane@geemail.com	San Bernardino	California	3528133997322878692	4fe2d394a5d375037439c07113508944	Voyager	34.0958289027478543	-117.268621286914126
14169	2020-03-02 17:12:53	2020-03-02	Dr. Valentino Schamberger DVM	dr.valentino.schamberger.dvm@geemail.com	Henderson	Nevada	3096125320175128752	428ce3badb5eec45c4da5e44074afa36	JCB 15 digit	35.929587399394066	-115.047628823636856
14170	2020-03-02 17:41:01	2020-03-02	Murl Gusikowski-Ferry	murl.gusikowski.ferry@geemail.com	Corona	California	210012654102278439	1c65313eabf3714f0015ca6276e69820	VISA 13 digit	33.9181618104577112	-117.533166008649388
14171	2020-03-02 17:57:57	2020-03-02	Doll Wilderman	doll.wilderman@geemail.com	Long Beach	California	4930719783105455	73376cfd7603d86e515c977a61f5bfd5	JCB 15 digit	33.7667631608255192	-118.205615142003822
14172	2020-03-02 18:01:25	2020-03-02	Dimitrios Kub	dimitrios.kub@geemail.com	Oakland	California	869991876738405201	91bc088b77ad3e2d41cd9a719084b923	Maestro	37.8164872464750488	-122.299726880846237
14173	2020-03-02 18:48:32	2020-03-02	Dr. Shari Corwin	dr.shari.corwin@warmmail.com	New Haven	Connecticut	3112600376131295840	dc18d6cbb2cbef8b011bd7a1c457461e	JCB 16 digit	41.3716555030543347	-73.0197928769513993
14174	2020-03-02 19:05:37	2020-03-02	Dr. Stuart Lynch IV	dr.stuart.lynch.iv@geemail.com	Detroit	Michigan	4601164513959	bc7a22fa4f4729b0a4b9a5e0abe6c3b1	JCB 16 digit	42.4054399267230195	-83.0072360945518994
14175	2020-03-02 19:34:34	2020-03-02	Tori Bartell	tori.bartell@geemail.com	Montgomery	Alabama	3158787295877623244	515d133fe2723fdc23854c0ff5473503	JCB 16 digit	32.4412029227174799	-86.2983185905184484
14176	2020-03-02 19:35:37	2020-03-02	Lura Halvorson-Wunsch	lura.halvorson.wunsch@geemail.com	San Francisco	California	3337125594905490944	dd0381513127f7072206ee2f25428f36	Discover	37.8090371686009021	-122.38102404541651
14177	2020-03-02 19:55:30	2020-03-02	Jakob Tremblay	jakob.tremblay@geemail.com	San Jose	California	3444706979082591	450c271ba5638bd267150c91a2ccb0eb	Voyager	37.2855720405753743	-121.875431963124868
14178	2020-03-02 20:34:05	2020-03-02	Paris O'Hara-Hane	paris.o'hara.hane@warmmail.com	Phoenix	Arizona	4388791335705	f2960833b66f56c804fd082802167fdb	VISA 16 digit	33.6681246661048377	-111.999161083849529
14179	2020-03-02 20:36:07	2020-03-02	Elberta Buckridge	elberta.buckridge@geemail.com	San Diego	California	180042795754447303	8c5f751a40ff38968b2819dfa2a4360c	JCB 16 digit	32.7197204715173697	-117.23111464426853
14180	2020-03-02 20:48:48	2020-03-02	Tiffani Conn	tiffani.conn@geemail.com	Baltimore	Maryland	3096635481696909287	4c704c5502fdb077597726e38f381af7	Voyager	39.2097306674811961	-76.555574212318291
14181	2020-03-02 20:49:22	2020-03-02	Vergie Towne	vergie.towne@geemail.com	San Francisco	California	3055997950615494	5db94dbd6d3c3875bfae57dc2f69ef34	VISA 13 digit	37.7640443573338587	-122.434075124796976
14182	2020-03-02 20:56:48	2020-03-02	Mr. Adonis Huels	mr.adonis.huels@woohoo.com	Athens	Georgia	4378207688481980	803eb518971b4a731ebfe876dc42d8f0	Mastercard	33.8708006509769675	-83.4521966780651354
14183	2020-03-02 20:59:18	2020-03-02	Jaimee Cruickshank-Wunsch	jaimee.cruickshank.wunsch@geemail.com	Dallas	Texas	4968614934300847	20c2690fc62c0fb4ddbbe7219870da27	JCB 16 digit	32.7932462132342195	-96.8177864141724882
14184	2020-03-02 21:13:08	2020-03-02	Stefanie Raynor	stefanie.raynor@woohoo.com	San Francisco	California	3750722338971433	54e3a585e869a539498e1797eff2f415	Discover	37.7632242901683881	-122.433865060756219
14185	2020-03-02 21:28:28	2020-03-02	Rome Auer	rome.auer@geemail.com	Jacksonville	Florida	4891359754538835	562bb2f65855e368bb46188df8410ab0	Discover	30.278555073408036	-81.6636525730680773
14186	2020-03-02 21:42:50	2020-03-02	Darrian Treutel	darrian.treutel@geemail.com	Baton Rouge	Louisiana	3725344874636411	53d62bf1b927483f40bc822898d91540	VISA 13 digit	30.5378853051204224	-91.117553831321743
14187	2020-03-02 21:56:06	2020-03-02	Dr. Branch Wolf V	dr.branch.wolf.v@geemail.com	New York	New York	3038331315742032	d66584ee3772ee5ec7a034d2c76c08a2	VISA 16 digit	40.761510708624499	-73.9302343230590253
14188	2020-03-02 21:59:37	2020-03-02	Mr. Taj Thiel	mr.taj.thiel@geemail.com	Seattle	Washington	180093138991991072	a546408b3b3b3580d7c622e0fd5b0e75	American Express	47.6926527191810337	-122.328935066649308
14189	2020-03-02 22:04:17	2020-03-02	Newell Doyle	newell.doyle@geemail.com	Oakland	California	6011411039843191645	85ae569f9709bcdab74eab343b8ddfa3	VISA 16 digit	37.8118061378123329	-122.253875778629791
14190	2020-03-02 22:07:27	2020-03-02	Germaine Wilderman DDS	germaine.wilderman.dds@geemail.com	Berkeley	California	3096334221213655565	068ac55c85cff0f276c74562971e1350	VISA 16 digit	37.89746395441977	-122.268249355615794
14191	2020-03-02 22:08:45	2020-03-02	Anthoney Jacobs	anthoney.jacobs@geemail.com	San Francisco	California	561228282929810	85d6bc9655766ce0017dbc6d94d5aac7	American Express	37.7391872990898918	-122.436134294246301
14192	2020-03-02 22:15:40	2020-03-02	Mr. Tre Larson	mr.tre.larson@geemail.com	Berkeley	California	4437624172968695	a811ec6a4c602f0ba4ee7059edb01074	VISA 16 digit	37.8804755798879214	-122.273140445246497
14193	2020-03-02 22:16:39	2020-03-02	Eartha Mayer	eartha.mayer@geemail.com	Edison	New Jersey	3528163540777849553	9558a88c0131fb0bd8226ebecb5beb4b	VISA 13 digit	40.4503909043464773	-74.4138497518427755
14194	2020-03-02 22:17:27	2020-03-02	Gwendolyn Watsica	gwendolyn.watsica@geemail.com	Irving	Texas	3781823111398506	62572b59243534557b1c67d7e8576e5f	Voyager	32.8729190607506823	-96.9567334965150849
14195	2020-03-02 22:33:52	2020-03-02	Ples Ledner	ples.ledner@geemail.com	Oakland	California	3484784637738087	8f5da298683fba0f96bb4210e3c361ca	Maestro	37.8166533524483199	-122.298478625810489
14196	2020-03-02 22:35:12	2020-03-02	Corene Macejkovic-Kling	corene.macejkovic.kling@woohoo.com	Akron	Ohio	639056982174874	13e39f30c2a61165f6d532ef30cd01d4	American Express	41.0802945994138753	-81.5096432135287614
14197	2020-03-02 22:36:03	2020-03-02	Mr. Dixon Hegmann PhD	mr.dixon.hegmann.phd@geemail.com	New York	New York	502063455275709	a696be7b13b569afe9236867b21129cb	JCB 16 digit	40.6850043839532844	-73.8836985562357995
14198	2020-03-02 22:52:19	2020-03-02	Emery Mayer	emery.mayer@geemail.com	Denver	Colorado	4714071528004839	f8028430b905f6e502e823e21fcee8ea	Mastercard	39.7438452964235083	-104.83741096921861
14199	2020-03-02 22:55:53	2020-03-02	Janette Will	janette.will@geemail.com	Los Angeles	California	3088128225946908910	c962fef2bff8daf8c87a7f36d309dc14	VISA 16 digit	34.0470643474586296	-118.386163643001765
14200	2020-03-02 23:03:45	2020-03-02	Mr. Alexande Veum III	mr.alexande.veum.iii@geemail.com	San Francisco	California	180084969901332325	f75b61d4e17c0e7c2cbe6d9fac28c9f6	VISA 16 digit	37.7720262732393266	-122.436543432566594
14201	2020-03-02 23:09:55	2020-03-02	Harl Green	harl.green@geemail.com	New York	New York	060442953303007	8e8ddc1be3d051d6a10a4356522cb138	JCB 16 digit	40.7532151461802385	-73.9693761625688495
14202	2020-03-02 23:11:17	2020-03-02	Omie Kunde PhD	omie.kunde.phd@geemail.com	Charlotte	North Carolina	6011691689572568776	95dfc9f3bebc4c9314215fce154abb20	American Express	35.1430663496974844	-80.8533896701820254
14203	2020-03-02 23:37:00	2020-03-02	Deirdre Ondricka	deirdre.ondricka@warmmail.com	Jacksonville	Florida	869964206203416439	0de4f89610782290fb3270910c0edca9	Mastercard	30.240324914600329	-81.7522385769136264
14204	2020-03-02 23:39:25	2020-03-02	Randolph Roberts	randolph.roberts@woohoo.com	New York	New York	869959606367809401	a5e293423bca32fe882c3c6e651dc87c	VISA 16 digit	40.729181836707518	-73.9703917164716813
14205	2020-03-02 23:51:29	2020-03-02	Kerry Rau	kerry.rau@geemail.com	Pearland	Texas	4396694133226	a541abc6cc46f5dbcb4242503d52bd98	VISA 16 digit	29.5322124225359417	-95.2579454919643638
14206	2020-03-02 23:52:58	2020-03-02	Mr. Lesley Green	mr.lesley.green@geemail.com	New York	New York	4012961193787354	51a4423ef876507e944879ca21653f7b	Diners Club / Carte Blanche	40.6145443739593048	-73.9724473023682805
14207	2020-03-02 23:59:39	2020-03-02	Mrs. Laurette Abernathy	mrs.laurette.abernathy@warmmail.com	Philadelphia	Pennsylvania	3158940535238040750	58ed42d1e90af310c111838587e33b27	Maestro	40.1064217123627671	-75.0816337564859566
14208	2020-03-03 00:02:26	2020-03-03	Elizah Wunsch	elizah.wunsch@geemail.com	San Francisco	California	51981093014334989	57cf47b74f4e15cd0aba9a2939f46753	JCB 15 digit	37.7654427656764895	-122.428527489071527
14209	2020-03-03 00:10:53	2020-03-03	Glynda Konopelski	glynda.konopelski@geemail.com	Miami	Florida	6011450319743576489	e58ed9ab5c6cbe258aa2b75489e4e8d0	Diners Club / Carte Blanche	25.7632447735078642	-80.2569329033479164
14210	2020-03-03 00:36:03	2020-03-03	Alex Funk MD	alex.funk.md@geemail.com	Roseville	California	52072254711315925	bc44bc7d5134908a3f334820d8648405	Diners Club / Carte Blanche	38.7195519699770969	-121.260300952916594
14211	2020-03-03 00:37:10	2020-03-03	Cornie Bechtelar	cornie.bechtelar@geemail.com	Birmingham	Alabama	6011159628269889108	0f1a04eeb9d6e6dfe6892c2b67541a19	Discover	33.5011250162288547	-86.7698708983380413
14212	2020-03-03 00:37:11	2020-03-03	Landin McClure-Beer	landin.mcclure.beer@geemail.com	New York	New York	3158453925816032528	cc2d836b74a076ad34bf3d9b4f60ce22	Mastercard	40.7548168095052219	-73.8592631595570595
14213	2020-03-03 00:47:05	2020-03-03	Therman Kuhic	therman.kuhic@geemail.com	Salinas	California	52206659415889000	bf7c2ea528199cae00cc7be7fcad139d	VISA 16 digit	36.7562727433394585	-121.697577520151441
14214	2020-03-03 01:03:48	2020-03-03	Aloys Vandervort	aloys.vandervort@geemail.com	Chicago	Illinois	210032113175672081	425e89e4761091612a4585058a007922	VISA 13 digit	41.7887127696838263	-87.7557935765042885
14215	2020-03-03 01:04:19	2020-03-03	Sonny Crooks	sonny.crooks@geemail.com	San Francisco	California	52510755339641336	59757eb580ac50d909e3ae7f5c28ab58	JCB 16 digit	37.7791246787688237	-122.443577058986861
14216	2020-03-03 01:08:52	2020-03-03	Winfred Leuschke	winfred.leuschke@geemail.com	Coral Springs	Florida	52064424501508100	f79d5d5e518c6fc7a9c5464d8e4a5d71	VISA 16 digit	26.2814827905099868	-80.2113028249360553
14217	2020-03-03 01:26:17	2020-03-03	Orilla Stark DVM	orilla.stark.dvm@geemail.com	Las Vegas	Nevada	180010718210509381	148cbb8e94aed46ff49125558a48d38a	VISA 13 digit	36.1975824858628172	-115.275899139672887
14218	2020-03-03 01:29:19	2020-03-03	Shyann Murphy	shyann.murphy@geemail.com	San Antonio	Texas	4062192862707395	93bcb376d3851b3722d34210592f10b0	JCB 16 digit	29.3989954454429459	-98.6025174855090683
14219	2020-03-03 01:44:04	2020-03-03	Oakley Schmidt DVM	oakley.schmidt.dvm@geemail.com	New York	New York	3112499149800100755	511f13fd720217afeea9f57866054fa8	VISA 16 digit	40.7287882474940233	-73.8775783147092824
14220	2020-03-03 01:57:23	2020-03-03	Karon Collier	karon.collier@geemail.com	Lincoln	Nebraska	4156512895251	52b2be850c6cb8252e7e0ee065731cec	Diners Club / Carte Blanche	40.8207087700739493	-96.6598217256527477
14221	2020-03-03 01:57:46	2020-03-03	Dimitri Spencer	dimitri.spencer@geemail.com	New York	New York	503835839498132	16360c3c09327a4a27235f17cda88fdc	Mastercard	40.6282913773078462	-73.8975904561474835
14222	2020-03-03 02:03:45	2020-03-03	Ms. Celena Gislason	ms.celena.gislason@woohoo.com	Visalia	California	210072325300294406	31763dac85376635f24ca61cfa78d3ba	Voyager	36.3455040955405693	-119.397426026839398
14223	2020-03-03 02:12:40	2020-03-03	Epsie Brakus DDS	epsie.brakus.dds@geemail.com	Albuquerque	New Mexico	3112591769907934561	5fd171b739bc72058821f641ef66b765	Voyager	35.1696487944241625	-106.705995900470398
14224	2020-03-03 02:29:33	2020-03-03	Adda Wisozk	adda.wisozk@geemail.com	Lowell	Massachusetts	53957561751914122	0019b832934472460208ff0195473b6e	JCB 16 digit	42.5981446217615201	-71.3781393651723874
14225	2020-03-03 03:01:31	2020-03-03	Brandi Thiel	brandi.thiel@geemail.com	Thousand Oaks	California	4414109780273	e03022985d2862604f4607cbffb6d75e	JCB 16 digit	34.2555700175736106	-118.920906033777442
14226	2020-03-03 03:08:23	2020-03-03	Mrs. Nilda Kreiger MD	mrs.nilda.kreiger.md@geemail.com	Lowell	Massachusetts	3528942260721549658	bc1246769f893aaeba105ae03222ad97	Diners Club / Carte Blanche	42.6552025312893122	-71.3291274064559531
14227	2020-03-03 03:16:48	2020-03-03	Deidra Glover	deidra.glover@warmmail.com	Louisville	Kentucky	3043944173232972	488e4947d5ab1724d1449140dfba3146	Diners Club / Carte Blanche	38.1067888223934901	-85.644995339873816
14228	2020-03-03 03:19:44	2020-03-03	Jeffrey Bruen	jeffrey.bruen@geemail.com	San Diego	California	3112388049438322967	ef604a6e592f8068526dd1d7bada8e97	Maestro	32.7506491057641824	-117.089534823121511
14229	2020-03-03 03:20:09	2020-03-03	Miss Gwen Fisher MD	miss.gwen.fisher.md@geemail.com	Greeley	Colorado	4254446282327970	d6dd61f459045a3ab60346818a7e2803	VISA 13 digit	40.5057989297501777	-104.700726477273548
14230	2020-03-03 03:23:44	2020-03-03	Anie Bradtke DVM	anie.bradtke.dvm@geemail.com	Los Angeles	California	3051723903497671	a0840eac798f47478147ebdbaeaa1b43	VISA 16 digit	34.0331114646378907	-118.378298434893779
14231	2020-03-03 03:32:12	2020-03-03	Clemon Morar DVM	clemon.morar.dvm@woohoo.com	Des Moines	Iowa	589303717336667	7bf67f60e22012ad126893dc3e7fd65d	Discover	41.6588912342883688	-93.5161141029603868
14232	2020-03-03 03:36:28	2020-03-03	Dwight Powlowski	dwight.powlowski@geemail.com	San Francisco	California	4739929447098797	e51c559538b56785b8036643fd4155cf	American Express	37.7845227401333901	-122.451125357886326
14233	2020-03-03 03:44:51	2020-03-03	Mr. Offie Sporer	mr.offie.sporer@geemail.com	San Francisco	California	630404481403030	a3975dc45db74751728c099ceb60be5a	VISA 16 digit	37.7916032141755736	-122.455875257130543
14234	2020-03-03 03:51:30	2020-03-03	Edwardo Walker	edwardo.walker@geemail.com	Dallas	Texas	6011293049809660882	053b2f6a7ec6f48365aa34cfad288cc1	Discover	32.6994016157735174	-96.6747078866660559
14235	2020-03-03 03:57:50	2020-03-03	Mrs. Tiny Jacobson	mrs.tiny.jacobson@geemail.com	Dallas	Texas	6011667409272799195	bfc3aeb9be3d5edd8c8cdc85cf78a35f	VISA 16 digit	32.7325471313476584	-96.7741656355522508
14236	2020-03-03 04:01:39	2020-03-03	Royce Davis Jr.	royce.davis.jr.@geemail.com	New York	New York	869945563002447542	baf5df810995abf542a92139d6b5e60d	Mastercard	40.7142086378987855	-73.9982758073963254
14237	2020-03-03 04:15:23	2020-03-03	Mr. Percy Gorczany	mr.percy.gorczany@geemail.com	Lincoln	Nebraska	210035017316796468	f5405725c732f8bc7142ba888e11ecc0	American Express	40.8240571927763511	-96.7795068973835555
14238	2020-03-03 04:16:16	2020-03-03	Armstead Kulas	armstead.kulas@geemail.com	Winston–Salem	North Carolina	3491041161610567	abfa08664a9a959f0d9b2489ea9920d6	JCB 16 digit	36.1872788078848231	-80.3030067332684894
14239	2020-03-03 04:27:24	2020-03-03	Zandra Howe-Waters	zandra.howe.waters@woohoo.com	San Francisco	California	3337986951918204639	91516d0306724ba8a126246c3d12fdf2	Mastercard	37.7780916767217576	-122.461671100710248
14240	2020-03-03 04:38:24	2020-03-03	Coby Spinka	coby.spinka@geemail.com	El Cajon	California	869972709592688534	38e8d3ec4d3389ec8d82a5f87142434c	JCB 16 digit	32.751067241654539	-116.861532982410495
14241	2020-03-03 04:43:26	2020-03-03	Miss Dulcie Bruen	miss.dulcie.bruen@geemail.com	New York	New York	3047277895177639	a54711e1e4928852e8ab857a50b3540a	JCB 15 digit	40.5989650430381275	-73.9129832398042055
14242	2020-03-03 04:51:20	2020-03-03	Leota Ratke DDS	leota.ratke.dds@geemail.com	New Orleans	Louisiana	869988901633010933	f9a922dbadf020532e429a4ba12addd9	JCB 15 digit	30.0721859581783413	-89.8605480520315467
14243	2020-03-03 05:04:30	2020-03-03	Aron Kihn	aron.kihn@geemail.com	Indianapolis	Indiana	3528524622992649416	7f9b96d70113bd5ae90105e276bfc478	JCB 16 digit	39.8009506604641672	-86.1874197830647262
14244	2020-03-03 05:09:55	2020-03-03	Zhane White	zhane.white@geemail.com	Macon	Georgia	4652594188284	c71f1336a047380542a8de7958dfdc53	JCB 16 digit	32.7819680812314118	-83.6867841787830002
14245	2020-03-03 05:24:49	2020-03-03	Mr. Lance Yundt	mr.lance.yundt@warmmail.com	Berkeley	California	3754414899825630	5c67e98a0cc27c03b6ae6f1c8d956aae	Maestro	37.8884551970719059	-122.284804577448924
14246	2020-03-03 05:33:26	2020-03-03	Capitola Mann-Welch	capitola.mann.welch@geemail.com	Memphis	Tennessee	4137870939739845	81b260cbc3a8f1f391ff41631139c754	VISA 16 digit	35.1916462708331679	-89.9699636242609557
14247	2020-03-03 05:39:38	2020-03-03	Reubin Goodwin	reubin.goodwin@geemail.com	Aurora	Illinois	4206958399527028	d65a9a29f264e249884cc244f176445d	JCB 15 digit	41.6800561214555074	-88.3562842640954926
14248	2020-03-03 05:47:00	2020-03-03	Dr. Rossie Greenholt	dr.rossie.greenholt@geemail.com	Phoenix	Arizona	53135797786219278	b90b82466dc7576a95440b12608e2e17	VISA 13 digit	33.4966665099773593	-112.056424428515513
14249	2020-03-03 07:30:18	2020-03-03	Algernon Turcotte	algernon.turcotte@geemail.com	Lexington	Kentucky	6011351932133669308	919ca4a40c9110a474a79317cab94876	American Express	38.1038138228811363	-84.3594085158679547
14250	2020-03-03 07:30:30	2020-03-03	Clarnce Herman	clarnce.herman@geemail.com	San Francisco	California	4708115143677	e135cd489eb5a561279c1c59e83e6b54	VISA 16 digit	37.788787014324825	-122.463259702756602
14251	2020-03-03 07:31:02	2020-03-03	Mrs. Alisson Sauer	mrs.alisson.sauer@geemail.com	Thornton	Colorado	3337680979341821405	f2abc40643fd62401c7977c65de4aa55	JCB 15 digit	39.9626535307016226	-104.952395207404351
14252	2020-03-03 07:37:38	2020-03-03	Mr. Stanford Ortiz DVM	mr.stanford.ortiz.dvm@warmmail.com	San Francisco	California	4225176639961942	d41927b6f8deaa6ffa88f71e814f4b1a	Mastercard	37.7861447207264689	-122.444785101257224
14253	2020-03-03 08:16:30	2020-03-03	Bennie Farrell	bennie.farrell@warmmail.com	Orlando	Florida	3048170941395413	9d2bf2d73a553ca59fadcca50f2ea85d	American Express	28.391386772811785	-81.3644845109399455
14254	2020-03-03 08:19:03	2020-03-03	Gracelyn Steuber-Zboncak	gracelyn.steuber.zboncak@warmmail.com	Independence	Missouri	3337650418121829524	280d051c9d136fea858bc1d4f9a655fe	Diners Club / Carte Blanche	39.0803061232920754	-94.410579506568979
14255	2020-03-03 08:24:27	2020-03-03	Sydnee Brekke-Kilback	sydnee.brekke.kilback@geemail.com	St. Petersburg	Florida	589350448966940	e250458e294578cca3f3ef8943be597e	Mastercard	27.8553607823681091	-82.6803547630909748
14256	2020-03-03 08:31:41	2020-03-03	Lorelai Smitham	lorelai.smitham@geemail.com	Thousand Oaks	California	6011847553952236730	d53c3bac06c85900550f457f447fbaa5	Maestro	34.14148450533785	-118.8446966256395
14257	2020-03-03 08:51:53	2020-03-03	Esteban Terry	esteban.terry@warmmail.com	Clarksville	Tennessee	6011773425498732068	c6445cd1a0a2db1f6ba58125c9acedfb	Maestro	36.5797754581213042	-87.4384093029376146
14258	2020-03-03 09:29:16	2020-03-03	Randell Stehr	randell.stehr@geemail.com	San Francisco	California	4946763489661629	cdfea42306c209cc03d269a02e6414a7	JCB 15 digit	37.7529962991960133	-122.421950002508197
14259	2020-03-03 09:48:25	2020-03-03	Dillard Stiedemann	dillard.stiedemann@geemail.com	Philadelphia	Pennsylvania	3112396960029244107	a448813f8002bf447be40c2dde34df2c	VISA 16 digit	40.040711880890278	-75.0994071941722297
14260	2020-03-03 09:48:46	2020-03-03	Gustie Murphy	gustie.murphy@geemail.com	Plano	Texas	676183158543310	1bf2732e1ea63f0b9e474dfa249dd9fb	VISA 16 digit	33.0141873765822496	-96.6582287509176865
14261	2020-03-03 09:51:59	2020-03-03	Dr. Clifford Kris	dr.clifford.kris@warmmail.com	San Francisco	California	4782947203634833	80d5afaf5cef4133490361d819cbaf8d	JCB 16 digit	37.777761170331388	-122.409902028116136
14262	2020-03-03 10:06:45	2020-03-03	Miss Rosina O'Hara DDS	miss.rosina.o'hara.dds@geemail.com	Jersey City	New Jersey	6011591615889863817	bcbd2c53de947a4e630cc7b8da69dda9	Discover	40.6830522180009595	-74.0884292834393676
14263	2020-03-03 10:09:26	2020-03-03	Winston Hane	winston.hane@geemail.com	New York	New York	6011835131334763889	8fc4e97de403fb2e43ed49169ceae8af	American Express	40.6961119220349943	-73.8612940838456069
14264	2020-03-03 10:16:50	2020-03-03	Dr. Estill Wehner	dr.estill.wehner@warmmail.com	Houston	Texas	3112659374502462495	4916376fe3f255a5eac097c76d19b53e	JCB 16 digit	29.8657211910545826	-95.4818434980712851
14265	2020-03-03 10:41:06	2020-03-03	Mrs. Sallie Harvey DDS	mrs.sallie.harvey.dds@woohoo.com	Nashville	Tennessee	3158447631970777721	610bde4b7ecd170a8b343c443a68a1a9	VISA 13 digit	36.0862117243122285	-86.8138454796653178
14266	2020-03-03 10:49:45	2020-03-03	Emeline Marks MD	emeline.marks.md@warmmail.com	Berkeley	California	6011830589670541455	360a2aa1efe657cd80d97733b00d977c	Mastercard	37.8395187108256721	-122.299491463735208
14267	2020-03-03 10:53:00	2020-03-03	Dr. Wilson Pacocha DVM	dr.wilson.pacocha.dvm@warmmail.com	Tempe	Arizona	6011528131318765324	ce75ccd12f9847f08e39f35aa0db625b	Discover	33.3804358905103058	-111.936895070973037
14268	2020-03-03 10:55:28	2020-03-03	Kamila Wehner	kamila.wehner@woohoo.com	Fullerton	California	869931385074248707	ffade42a56ae5451eb19377f3512227c	Discover	33.8138867511570425	-117.951838086146864
14269	2020-03-03 11:22:51	2020-03-03	Zeb Zboncak-Cremin	zeb.zboncak.cremin@geemail.com	Midland	Texas	3528869628401123995	5494452dc2295d8fc4d94b7cb53469a9	VISA 13 digit	31.997719557974861	-102.19938168448769
14270	2020-03-03 11:25:44	2020-03-03	Jeraldine Feest	jeraldine.feest@geemail.com	Greensboro	North Carolina	4284960830172	37c554462dc7cb9ce93ec7a76c3e30ef	Discover	36.1914896956294783	-79.9054738044720096
14271	2020-03-03 11:45:15	2020-03-03	Salina Boyle	salina.boyle@geemail.com	Corona	California	869943534617436701	1d8c8b88fdbe7d916ca6ca7b06de778c	JCB 15 digit	33.8639650049041947	-117.499683446876702
14272	2020-03-03 12:23:03	2020-03-03	Ettie Ward	ettie.ward@geemail.com	Atlanta	Georgia	6011035084199991426	0f40a23da160ed74d056f7d67082e181	JCB 16 digit	33.6815722995713358	-84.3559185582257811
14273	2020-03-03 13:20:20	2020-03-03	Luana Keeling PhD	luana.keeling.phd@woohoo.com	Toledo	Ohio	502055667223931	73e653ccdb755cab0cc555d9f61230b7	Maestro	41.6538627919446682	-83.6574042640492337
14274	2020-03-03 13:25:58	2020-03-03	Sybil Adams	sybil.adams@geemail.com	Miami	Florida	3096817315249748828	02daf118b51ad8152ce4cdb1964ed58c	JCB 16 digit	25.8464343320250514	-80.2410326621834287
14275	2020-03-03 13:32:02	2020-03-03	Iona Russel-Reichel	iona.russel.reichel@warmmail.com	San Jose	California	52293241007899137	f7e4b518491442f27b58d16607cde5a3	JCB 16 digit	37.3932112320613115	-121.902940027391168
14276	2020-03-03 13:46:14	2020-03-03	Alston Shanahan	alston.shanahan@geemail.com	Knoxville	Tennessee	3032139917926739	7050c2b62962f8db758e20b4cbd82dec	Maestro	35.9464614418398583	-83.9781371001835879
14277	2020-03-03 13:57:11	2020-03-03	Laurel Jenkins	laurel.jenkins@woohoo.com	New York	New York	4552718690474571	d49ee3c3041c2bdcb8c9c198f482f0c7	VISA 16 digit	40.5741022540014242	-73.9289244427241385
14278	2020-03-03 14:02:11	2020-03-03	Irvine Kihn-Hartmann	irvine.kihn.hartmann@warmmail.com	Houston	Texas	4280064088800666	ca97805be1acac475ce5cd7c5c774501	VISA 13 digit	29.7185262957200393	-95.365283041029798
14279	2020-03-03 14:03:06	2020-03-03	Adalynn Metz PhD	adalynn.metz.phd@geemail.com	Honolulu	Hawaii	54544391669827129	f456cd0e964167f600afec0f62cae0ee	American Express	21.2463328484661886	-157.748959131839115
14280	2020-03-03 14:06:38	2020-03-03	Beadie Swaniawski	beadie.swaniawski@woohoo.com	Stockton	California	3528747429189950222	6b342108d426da68dc9f9204397b7fe0	JCB 16 digit	38.0294860338989693	-121.215100612919031
14281	2020-03-03 14:13:33	2020-03-03	Miss Maya O'Connell	miss.maya.o'connell@geemail.com	New York	New York	3036831464207846	b8c4ba50d44c637a7cc14e82260e2da1	Discover	40.6085698739383361	-73.8610226631991509
14282	2020-03-03 14:18:19	2020-03-03	Carlie Altenwerth-Rutherford	carlie.altenwerth.rutherford@geemail.com	Miami	Florida	3005860471129264	ec3f1277a3700866d76e7a8c08e8350d	VISA 16 digit	25.7915476280402416	-80.1754220846448078
14283	2020-03-03 14:48:48	2020-03-03	Dorr McLaughlin III	dorr.mclaughlin.iii@geemail.com	San Francisco	California	3158835005265245696	8f7b8a219773a9c559eafc76d60367be	JCB 16 digit	37.7602180031915111	-122.457784906445013
14284	2020-03-03 14:54:36	2020-03-03	Mr. Angelo Bergstrom MD	mr.angelo.bergstrom.md@geemail.com	San Francisco	California	3088148144868249920	c3e0f6f3508e23580ed9c9f94a0d9eec	VISA 16 digit	37.7782091969489073	-122.409082034972187
14285	2020-03-03 15:30:20	2020-03-03	Francisquita Ratke	francisquita.ratke@geemail.com	Louisville	Kentucky	3748102269975056	d77ac44a26d8dd89d7aaa0e20186d1b2	JCB 16 digit	38.2247211256898893	-85.5794999884512322
14286	2020-03-03 15:35:04	2020-03-03	Montana Schaefer	montana.schaefer@warmmail.com	El Monte	California	55799328328340005	5751a9c848c573a958a556174521db15	Diners Club / Carte Blanche	34.0860171923603801	-118.106660508437457
14287	2020-03-03 16:04:19	2020-03-03	Kamilah Walker	kamilah.walker@geemail.com	Fontana	California	3723367888148034	c7151b8e077e9460f057a460821e894d	VISA 13 digit	34.0644010771680641	-117.427951528625201
14288	2020-03-03 16:09:38	2020-03-03	Estefania Sanford	estefania.sanford@geemail.com	New York	New York	3043974072675245	b00611ebaaec98bb41d1e65ac91da33d	Voyager	40.663781400559472	-73.9970361205179188
14289	2020-03-03 16:33:54	2020-03-03	Salomon Hamill-Crist	salomon.hamill.crist@woohoo.com	Birmingham	Alabama	869979357350609418	cd12704c7899d84eaf318819cc4e56ee	American Express	33.622983099126813	-86.7981588035132745
14290	2020-03-03 16:40:49	2020-03-03	Ibrahim Stanton	ibrahim.stanton@geemail.com	Berkeley	California	55875903371334050	e75b4c6a2543ade0f904d2bc1a5746be	American Express	37.8679006815080186	-122.277497985457785
14291	2020-03-03 17:00:04	2020-03-03	Danika Hamill-Hills	danika.hamill.hills@warmmail.com	Fort Collins	Colorado	210023543843838659	2ea23ff1558fb297d446b798cfe88bc5	VISA 16 digit	40.6172140952821863	-105.082611769479897
14292	2020-03-03 17:05:02	2020-03-03	Maliyah Hyatt	maliyah.hyatt@warmmail.com	Minneapolis	Minnesota	3158997560841048117	5980807b7b7463bcad38a0ae1cfad002	Diners Club / Carte Blanche	45.022815905100849	-93.2255519112843984
14293	2020-03-03 17:24:36	2020-03-03	Josefita Ward	josefita.ward@geemail.com	Louisville	Kentucky	180041197463005194	4effae40d6d5ae771f00cab8e7125bf8	JCB 16 digit	38.169935198304799	-85.5999416680611773
14294	2020-03-03 17:32:53	2020-03-03	Jeromy Kilback	jeromy.kilback@geemail.com	Albuquerque	New Mexico	54297846581704895	367cd8f635d7f109eb8310b265748308	JCB 16 digit	35.1962509571243132	-106.656525172812493
14295	2020-03-03 17:36:31	2020-03-03	Cristine Pouros	cristine.pouros@warmmail.com	Jacksonville	Florida	3447980708555535	e686b52e435109e19b00ffad10c4bdd0	JCB 16 digit	30.3171074094302959	-81.7133744445242058
14296	2020-03-03 17:41:17	2020-03-03	Mrs. Vina Orn DDS	mrs.vina.orn.dds@geemail.com	Columbus	Ohio	869949039008875404	6d66c32500ce5d65e1aae7f675c25b45	Discover	39.9463373818479468	-82.9227905434791097
14297	2020-03-03 17:56:03	2020-03-03	Hilbert Senger	hilbert.senger@geemail.com	Odessa	Texas	4625438825564716	14d37354c5add636ee2e7decf3d81192	Maestro	31.8427519592933379	-102.363916980537027
14298	2020-03-03 18:08:09	2020-03-03	Mr. Kelly Nicolas	mr.kelly.nicolas@geemail.com	Berkeley	California	52613573630894306	80e3cb4086424929dd2ddd1199e72dc2	VISA 16 digit	37.8685073170127211	-122.275172930673818
14299	2020-03-03 18:23:13	2020-03-03	Chancy Kozey-Mraz	chancy.kozey.mraz@geemail.com	San Francisco	California	180071155025937117	a3ebe0c2abab07d58f665fac8009a727	VISA 13 digit	37.8041004232261031	-122.459924460381174
14300	2020-03-03 18:34:05	2020-03-03	Randi Larson DVM	randi.larson.dvm@geemail.com	Aurora	Illinois	4508011578892139	60eddef3d5156daafe6f02cbf13bdfb5	American Express	41.8325111018251619	-88.2334230349793955
14301	2020-03-03 19:18:48	2020-03-03	Ferne Bednar	ferne.bednar@geemail.com	Grand Prairie	Texas	180069678269712726	2458ce079e800958c5901b3312055611	JCB 16 digit	32.5979386108979625	-97.0346830172337604
14302	2020-03-03 19:34:22	2020-03-03	Cordero Morissette	cordero.morissette@geemail.com	Tampa	Florida	54114360956968946	5524f68c0b61e8bb2a33c852166a7d71	VISA 16 digit	28.0499244972713271	-82.408722548487404
14303	2020-03-03 19:41:36	2020-03-03	Miss Eleanora Doyle PhD	miss.eleanora.doyle.phd@warmmail.com	Atlanta	Georgia	639048629224212	18348688ba6e88c06dd3071588b5c646	Diners Club / Carte Blanche	33.6677235042952034	-84.429288098034263
14304	2020-03-03 19:44:12	2020-03-03	Dr. Kamren Batz	dr.kamren.batz@warmmail.com	Escondido	California	3158822829210807390	2daf10c419d1adc717487b3d5b0c2567	Mastercard	33.1133553884219367	-117.163025926589967
14305	2020-03-03 20:17:25	2020-03-03	Demetra Hoppe	demetra.hoppe@warmmail.com	Springfield	Massachusetts	4377839733356824	0d074064f7b934d93b888c722e6eaac1	Mastercard	42.1513214415609809	-72.4860747590288526
14306	2020-03-03 20:26:02	2020-03-03	Brigid Jacobs	brigid.jacobs@geemail.com	San Francisco	California	3448474500542130	c75d049d5a50ee6a45de0877967055ff	Diners Club / Carte Blanche	37.759380916291299	-122.41379174879782
14307	2020-03-03 20:27:36	2020-03-03	Carrol Torphy	carrol.torphy@geemail.com	New York	New York	4689665373311222	28ef25c9c0c523dad6e15c6875342b9e	Mastercard	40.6266807020399696	-73.9609219896968426
14308	2020-03-03 20:30:56	2020-03-03	Clemente Sawayn	clemente.sawayn@geemail.com	New York	New York	869996779064110608	159811eb15aae37c6f723a466ed3ce55	VISA 16 digit	40.581039575882258	-73.9344877747248859
14309	2020-03-03 20:49:58	2020-03-03	Rogers Wiza	rogers.wiza@warmmail.com	Eugene	Oregon	3422292932494914	a0db9ce9f4580cd303f8c75b1e9be529	JCB 16 digit	44.1091023162666716	-123.154546422743053
14310	2020-03-03 20:58:15	2020-03-03	Vernie Schoen	vernie.schoen@geemail.com	New York	New York	210068554380861653	415e7af7aebaabba1b5988c5896bb260	Maestro	40.6594647522773585	-73.8832132266730071
14311	2020-03-03 21:04:25	2020-03-03	Sanjuanita Rath	sanjuanita.rath@geemail.com	Springfield	Massachusetts	3037732199322349	07a845f625de8471fb0d2228d109fe48	Voyager	42.1632530177216935	-72.6166679533757389
14312	2020-03-03 21:17:13	2020-03-03	Mr. Treyvon Toy IV	mr.treyvon.toy.iv@geemail.com	San Francisco	California	4505070947928506	74b75a784b4b21d8dffaacdedba1e639	JCB 16 digit	37.7759578584414655	-122.436144340417414
14313	2020-03-03 21:42:11	2020-03-03	Pauletta Mertz DVM	pauletta.mertz.dvm@geemail.com	Indianapolis	Indiana	3088958764937096801	83037904d32ab11ab47e4bb6b77bf907	Maestro	39.8638195867191953	-86.2402925880361266
14314	2020-03-03 21:44:31	2020-03-03	Darvin Harris I	darvin.harris.i@geemail.com	San Francisco	California	869956631694493011	e77a9d2ba04a660aa2e70573e0933eb2	Voyager	37.7728176825456359	-122.42323202805116
14315	2020-03-03 21:56:23	2020-03-03	Lars Lubowitz	lars.lubowitz@geemail.com	San Francisco	California	3049846156517754	118e5aab2fbdd6c444bd75b267fa220c	Maestro	37.7591565593105543	-122.441521619665352
14316	2020-03-03 22:02:01	2020-03-03	Dr. Jermaine Macejkovic	dr.jermaine.macejkovic@woohoo.com	Tucson	Arizona	3096759414716028424	4dde61150067406dd7c785d5ad1d8f4b	VISA 16 digit	32.0642364491283942	-110.933271345146366
14317	2020-03-03 22:16:32	2020-03-03	Linsey Shanahan	linsey.shanahan@geemail.com	Vista	California	4068312479916700	ff7649576d24ee2da991631f15c7a203	JCB 16 digit	33.1189605485629315	-117.142153922427823
14318	2020-03-03 22:18:10	2020-03-03	Hershel Becker-Funk	hershel.becker.funk@geemail.com	Tempe	Arizona	4201806989391708	a10987dd15a0c1cd5e7a2d3a2e9105c8	Voyager	33.4410105987839401	-111.944524691908796
14319	2020-03-03 22:23:53	2020-03-03	Shepherd Stoltenberg-Kessler	shepherd.stoltenberg.kessler@warmmail.com	San Francisco	California	4696506221889905	e474d909fbe844f7bdffa3416f4e0835	VISA 16 digit	37.7638973979253763	-122.446789923895537
14320	2020-03-03 22:34:05	2020-03-03	Bob Dooley-Robel	bob.dooley.robel@geemail.com	Houston	Texas	3088389352845599345	949c595abc199b00d3bd33d59a1ceb62	Voyager	29.7999051460608833	-95.4173853140804908
14321	2020-03-03 22:52:55	2020-03-03	Buell Frami	buell.frami@geemail.com	Tempe	Arizona	639051052659540	5d5337b60804b0c5fc6130fc40277fa8	American Express	33.4035979242451475	-111.93767321976199
14322	2020-03-03 23:07:20	2020-03-03	Braeden Casper	braeden.casper@woohoo.com	Phoenix	Arizona	4485487882066940	02a0382e86cb44e8fb126b5300d6005c	Mastercard	33.5291471857510501	-112.106386030039204
14323	2020-03-03 23:07:20	2020-03-03	Mr. Hattie Gleichner Jr.	mr.hattie.gleichner.jr.@warmmail.com	Houston	Texas	3789829788292486	a26468c50cbf07a58cb3eedc8247b58c	American Express	29.7853274750135846	-95.3653132895022679
14324	2020-03-03 23:21:55	2020-03-03	Timmie Hettinger	timmie.hettinger@woohoo.com	New York	New York	869994396110661450	e2ed56d131a3350f9edd0fbce4af36db	Mastercard	40.6737686760481409	-73.8540587142936857
14325	2020-03-03 23:31:57	2020-03-03	Hermann Jakubowski	hermann.jakubowski@geemail.com	Chicago	Illinois	3055362776482647	a76005ab708c2909f6076e059412e9d7	JCB 15 digit	41.9269439028412094	-87.6607864056278032
14326	2020-03-03 23:34:52	2020-03-03	Ambrose Hahn-Eichmann	ambrose.hahn.eichmann@geemail.com	San Francisco	California	869905452386696114	2ac21c0c1a2650095a756924bd02c1b9	American Express	37.7795659819333167	-122.413995028965502
14327	2020-03-03 23:34:56	2020-03-03	Alec Dietrich	alec.dietrich@geemail.com	San Francisco	California	639028270844377	fea009579dfeb99bff0d8dc82a12d7c4	Mastercard	37.7772636377228395	-122.401918036075301
14328	2020-03-03 23:42:51	2020-03-03	Andres Spinka	andres.spinka@geemail.com	San Francisco	California	3112726948577589438	0a8ac023eea13dd4db601fbbcf034b79	JCB 16 digit	37.7599612237806141	-122.396010346210431
14329	2020-03-03 23:55:02	2020-03-03	Cyndi Carter-Jacobs	cyndi.carter.jacobs@geemail.com	Houston	Texas	4356044461653618	ae6977a532547f5ebc318bed8300cc9a	JCB 16 digit	29.8079220324832939	-95.4420145163327476
14330	2020-03-03 23:56:45	2020-03-03	Hertha Murazik	hertha.murazik@warmmail.com	New York	New York	180037059154492725	3fc267e68d57ba382f1d6dcd76c3e6a0	JCB 15 digit	40.7416600281596146	-73.9331948511198078
14331	2020-03-04 00:09:35	2020-03-04	Stefanie Beatty	stefanie.beatty@geemail.com	Oklahoma City	Oklahoma	3096771906147977990	e1e627890237e94c661a3daf6d2913c0	JCB 16 digit	35.517826375682283	-97.5600861647993298
14332	2020-03-04 00:12:04	2020-03-04	Blake Conn	blake.conn@warmmail.com	Los Angeles	California	4538993388791	380c8e2f99b6b28f28be7b287a7cadf7	Diners Club / Carte Blanche	33.9863834104366589	-118.403143343654648
14333	2020-03-04 00:21:04	2020-03-04	Mr. Kelly Morissette V	mr.kelly.morissette.v@geemail.com	Henderson	Nevada	3009855136571435	d140ce46b11d336cf06412ec842b16ab	VISA 13 digit	35.9193693184226746	-114.937129460104558
14334	2020-03-04 00:28:19	2020-03-04	Colbert Kshlerin	colbert.kshlerin@warmmail.com	Oakland	California	210042920972528235	5328513874a1c229ae5475b049de7d94	VISA 16 digit	37.749312971899883	-122.284362557869301
14335	2020-03-04 01:13:43	2020-03-04	Deonta Tillman V	deonta.tillman.v@warmmail.com	Houston	Texas	6011361741137439180	1cf996973d2d8aedf87f85c3442baa41	American Express	29.8163119592316441	-95.4744666960105377
14336	2020-03-04 01:20:21	2020-03-04	Doug Heller	doug.heller@warmmail.com	Tacoma	Washington	4957502110709159	5acf24c58bf62cda6b59378b10501de5	JCB 16 digit	47.2528366285029833	-122.507688056607918
14337	2020-03-04 01:20:56	2020-03-04	Cammie Leuschke	cammie.leuschke@woohoo.com	Thousand Oaks	California	4266514448671205	e09f0ae8dd028697272e4f8790a9b6e9	Discover	34.1943030610021239	-118.816333383406331
14338	2020-03-04 02:17:02	2020-03-04	Mignon Cummings-Steuber	mignon.cummings.steuber@geemail.com	New York	New York	210026932001663172	905307c63838143f3b1fb43b5080a660	Maestro	40.6260420512165865	-74.0296387877210975
14339	2020-03-04 03:11:48	2020-03-04	Clyde Hickle IV	clyde.hickle.iv@warmmail.com	San Francisco	California	53293555646979939	24d2d9f27b1c79d67cd0f79d870cf57c	VISA 13 digit	37.8007653597554807	-122.417949567584827
14340	2020-03-04 03:25:01	2020-03-04	Mr. Dilan Block	mr.dilan.block@geemail.com	San Francisco	California	4053685225607815	da86308928773c75558eb16a51a1d726	Mastercard	37.7904148889060281	-122.4239089397703
14341	2020-03-04 04:00:59	2020-03-04	Kirby Yost	kirby.yost@geemail.com	Manchester	New Hampshire	3158338047851421077	a5ff0c0ee0d313b818058647f4e0c1b6	Diners Club / Carte Blanche	43.068813650969048	-71.4051877107828972
14342	2020-03-04 04:24:03	2020-03-04	Lucio Toy-Huels	lucio.toy.huels@geemail.com	Houston	Texas	180068538490013578	81e8e8dde200d17719c60c8e4308bb61	American Express	29.6910264620169997	-95.3421494363356459
14343	2020-03-04 04:33:47	2020-03-04	Damon Macejkovic	damon.macejkovic@geemail.com	Minneapolis	Minnesota	869920732922724319	51e5f411f4045c0977fe9e6053e6193c	VISA 13 digit	44.8930957307193381	-93.1713061437282732
14344	2020-03-04 04:41:52	2020-03-04	Merrill Bashirian	merrill.bashirian@warmmail.com	Tulsa	Oklahoma	4359325001139	b51d4a174424bd909082d9e590c20ac4	Mastercard	36.0471911708727433	-95.8794953389514149
14345	2020-03-04 05:41:56	2020-03-04	Izola Mertz-Prohaska	izola.mertz.prohaska@geemail.com	Houston	Texas	869904949387923273	3319cf0d2f07f9a46f6a439d8b64d735	VISA 13 digit	29.8059340054247528	-95.3318701198339511
14346	2020-03-04 05:46:19	2020-03-04	Dr. Kolby Tromp II	dr.kolby.tromp.ii@geemail.com	San Francisco	California	676355943195614	a72a16eab5812cf0727a25ca04eb0a8f	Maestro	37.7438535913057081	-122.438748771027562
14347	2020-03-04 06:03:16	2020-03-04	Dr. Loyce Schinner DDS	dr.loyce.schinner.dds@geemail.com	Fontana	California	4890723416507416	4d45d330482770c1491e45f08f9ed879	JCB 16 digit	34.0513387118615256	-117.421102383667233
14348	2020-03-04 06:13:57	2020-03-04	Mr. Troy Ullrich MD	mr.troy.ullrich.md@geemail.com	Chicago	Illinois	3337070254477030066	ab75f7327c26ef2d0ddcadc5bdee16a6	Voyager	41.8379144059330272	-87.639270679422836
14349	2020-03-04 06:26:28	2020-03-04	Rodger Heidenreich V	rodger.heidenreich.v@geemail.com	Tulsa	Oklahoma	3088131273314778197	7c414b1540745d24e593e0197ac17406	Diners Club / Carte Blanche	36.0819080195758488	-95.884458691389483
14350	2020-03-04 06:33:04	2020-03-04	Gearld Eichmann Jr.	gearld.eichmann.jr.@geemail.com	Little Rock	Arkansas	4491111476738894	54e7c8d7418ae28f94dae9e7a7b011ac	American Express	34.7822712345324447	-92.4263547451108707
14351	2020-03-04 06:36:11	2020-03-04	Miss Elza Denesik PhD	miss.elza.denesik.phd@geemail.com	Houston	Texas	3088466732331274147	b37a25ab19dd4b2ea8360d4acd5879f2	Discover	29.7611214479509734	-95.347181504314392
14352	2020-03-04 06:36:37	2020-03-04	Ms. Kyara Morar DDS	ms.kyara.morar.dds@geemail.com	New York	New York	54632350912099947	801ad0c6496b9eb429c8b26da6cb7659	VISA 16 digit	40.6631914078481458	-74.0319586402632268
14353	2020-03-04 06:44:53	2020-03-04	Mr. Fuller Corwin	mr.fuller.corwin@geemail.com	Hialeah	Florida	52493431713371822	4dcc37e960f495e82dd199be348ae0f8	VISA 13 digit	25.8864986664127557	-80.344206986333802
14354	2020-03-04 06:57:35	2020-03-04	Wendell Fahey	wendell.fahey@geemail.com	Los Angeles	California	4364617490592459	e80117836f4fab74662a6186a98b13e6	Maestro	34.0123064268246296	-118.483236966560781
14355	2020-03-04 07:04:56	2020-03-04	Cherry Konopelski	cherry.konopelski@geemail.com	Allen	Texas	210004537085716055	694dbc18faf387d586cede24190196bb	JCB 16 digit	33.1065698890972868	-96.6390996673557936
14356	2020-03-04 07:29:32	2020-03-04	Ms. Jadyn Deckow	ms.jadyn.deckow@geemail.com	Cary	North Carolina	3020251358392503	93b2481464d87a0fac3833445bc18016	JCB 15 digit	35.7368604973997961	-78.8262041498992545
14357	2020-03-04 07:33:35	2020-03-04	Delma Roberts	delma.roberts@geemail.com	Midland	Texas	3088147626688013446	34d6bac7b3d7bc26a7247db202223c05	JCB 16 digit	32.0702248112022872	-102.049189397854732
14358	2020-03-04 08:27:01	2020-03-04	Teddie Sporer	teddie.sporer@warmmail.com	San Francisco	California	4809224816698	b965d8b3de3a017569bd6b1f1ba9831f	JCB 16 digit	37.8012751776830953	-122.45163350727465
14359	2020-03-04 08:34:06	2020-03-04	Deasia Kuhn	deasia.kuhn@warmmail.com	Tucson	Arizona	3528068280176419908	483ebd56ac89bb788a4b1ef486d11d8b	American Express	32.0905579527415341	-110.803878141124173
14360	2020-03-04 08:56:08	2020-03-04	Delia Hudson	delia.hudson@warmmail.com	Fargo	North Dakota	6011944724265180608	9edd6ad9e359b28c0f5c3ef3a8d50623	Voyager	46.9527166714191466	-96.8568688908088831
14361	2020-03-04 08:58:50	2020-03-04	Nevin Kohler	nevin.kohler@geemail.com	San Jose	California	3055477359753139	df6453d39e663d4f34e8a440bd993951	VISA 16 digit	37.3354677017599386	-121.870209449551623
14362	2020-03-04 09:26:39	2020-03-04	Keven Cartwright	keven.cartwright@warmmail.com	San Francisco	California	4145953970583379	2bbf724f14d5b5edde274a9a783a5e54	JCB 15 digit	37.7607410669214971	-122.410044676831376
14363	2020-03-04 09:45:36	2020-03-04	Mr. Wayde Wiza III	mr.wayde.wiza.iii@warmmail.com	Bellevue	Washington	3337209952896445575	098a9aa58887a566759466e8704f1875	Voyager	47.5986471460849074	-122.229509929805985
14364	2020-03-04 09:54:42	2020-03-04	Mara Rath DVM	mara.rath.dvm@warmmail.com	San Francisco	California	4142764133806208	a244367101735cedf1e6f8f134cd9b65	Mastercard	37.7834483024533156	-122.429381615742969
14365	2020-03-04 10:16:00	2020-03-04	Kelli Nicolas	kelli.nicolas@woohoo.com	South Bend	Indiana	52579955834464436	4bac4c8cc9468f4ab80edd390f9aa393	American Express	41.7117061109893044	-86.3062655427549146
14366	2020-03-04 10:22:12	2020-03-04	Francine Leffler	francine.leffler@geemail.com	Huntington Beach	California	180062337630260140	dff957de27a708a59fdfa0db9da4a9a1	Diners Club / Carte Blanche	33.7252361123491085	-117.947408318625008
14367	2020-03-04 10:30:30	2020-03-04	Mr. Almus Torphy	mr.almus.torphy@geemail.com	Allentown	Pennsylvania	4006226225477277	609f1b2a0f3744611b8bbe3abf9ae9ef	VISA 16 digit	40.6339361960779897	-75.5665559659261135
14368	2020-03-04 10:38:49	2020-03-04	Ms. Lorri Nienow	ms.lorri.nienow@warmmail.com	Memphis	Tennessee	675995078941929	bcc8dc41d87069f6c536ddfdb67a322d	Mastercard	35.2017309364464168	-89.9666841678578493
14369	2020-03-04 10:59:11	2020-03-04	Judd Kerluke	judd.kerluke@geemail.com	Topeka	Kansas	4164223514143668	12a35c5e8a491e94ca41082a8e9481ba	VISA 13 digit	39.0418603774558761	-95.6702574953146296
14370	2020-03-04 11:06:10	2020-03-04	Vito Grimes I	vito.grimes.i@geemail.com	San Francisco	California	869958503256669924	77af9ebbbf2abc310de82293e507c09c	JCB 16 digit	37.8250846479406349	-122.432377705598952
14371	2020-03-04 11:17:34	2020-03-04	Glover Kirlin DDS	glover.kirlin.dds@warmmail.com	San Francisco	California	4009854168311299	c77d8ba5965e7e2d0900e4a5a1898642	Maestro	37.7683966246438487	-122.439007605300972
14372	2020-03-04 11:25:21	2020-03-04	Rollie Bartoletti	rollie.bartoletti@woohoo.com	Pittsburgh	Pennsylvania	4957657848312633	addbba32c291c1fa0e008ec96ef46ef7	Voyager	40.4069680335421069	-79.9947096092797807
14373	2020-03-04 11:30:25	2020-03-04	Clarnce Bode DVM	clarnce.bode.dvm@geemail.com	Philadelphia	Pennsylvania	180027124119537675	aad98d79de71ec549be160ae58274fcc	VISA 16 digit	39.9779382680501811	-75.2129159770339726
14374	2020-03-04 11:52:11	2020-03-04	Brock Baumbach	brock.baumbach@geemail.com	Lansing	Michigan	4089702656920654	5caaeca028d1a0a232984cfd9107a1e5	Diners Club / Carte Blanche	42.6930726482842147	-84.4778810924973271
14375	2020-03-04 12:00:38	2020-03-04	Dr. Brigette Dickinson	dr.brigette.dickinson@geemail.com	San Diego	California	53450859035795925	fb52a465c9ad6294dfb2132f28b41078	JCB 15 digit	32.8149018021833143	-117.187301030838867
14376	2020-03-04 12:01:58	2020-03-04	Carlota Fritsch	carlota.fritsch@geemail.com	Fort Worth	Texas	4558082072999	0209fcfbbad21452f8056e230fc27ab2	American Express	32.8707393048387004	-97.3294417265158103
14377	2020-03-04 12:10:53	2020-03-04	Mychal Quigley-Torp	mychal.quigley.torp@geemail.com	Oklahoma City	Oklahoma	6011225457700076335	a9d681da9f63b6f827df185778c4b832	VISA 16 digit	35.4561637082979075	-97.4837045520905434
14378	2020-03-04 12:14:11	2020-03-04	Deshawn Treutel	deshawn.treutel@geemail.com	San Francisco	California	3096394588998238065	d47ef4ce4a0a7464757bef6fb12ae651	American Express	37.7796854437464944	-122.438655937297909
14379	2020-03-04 12:15:48	2020-03-04	Alyssia Rath	alyssia.rath@woohoo.com	Glendale	California	210023695600144562	12f7316a488a35f16fffb3303cd3cf7c	JCB 16 digit	34.154768173604829	-118.269830528916046
14380	2020-03-04 12:26:28	2020-03-04	Jacoby Flatley DDS	jacoby.flatley.dds@woohoo.com	Glendale	California	676313056112546	a0bd7e765c79927159b985d46e7de4a3	American Express	34.0979095527656355	-118.307209958312285
14381	2020-03-04 12:32:58	2020-03-04	Simona Gerlach	simona.gerlach@geemail.com	Lowell	Massachusetts	4652147920282	59457dd74f8fc46f39794d35bb00afd6	VISA 16 digit	42.7047726034987747	-71.4145095399919967
14382	2020-03-04 12:40:05	2020-03-04	Dr. Ewell Gorczany V	dr.ewell.gorczany.v@geemail.com	New Orleans	Louisiana	3792423671555269	1377e0bf512c96d97fef03e9ed0ede1b	Discover	30.1296053358368567	-90.0186334656812193
14383	2020-03-04 12:47:58	2020-03-04	Ofelia Prohaska	ofelia.prohaska@woohoo.com	Tallahassee	Florida	4256223603542803	550048030f4bd27e2c116293abf933d3	JCB 16 digit	30.4462760895978661	-84.3407064769897659
14384	2020-03-04 12:50:11	2020-03-04	Tamica Weissnat	tamica.weissnat@geemail.com	Round Rock	Texas	4730397443731317	6c4bb98660bc580b08adce823b7bfb9c	JCB 16 digit	30.5803971254404665	-97.6934089392740219
14385	2020-03-04 12:58:17	2020-03-04	Artie Kshlerin	artie.kshlerin@geemail.com	Berkeley	California	4070463857816	9fa1ee8ef7a6fc0499666e19b4cce5e0	Discover	37.8409876603257942	-122.241745334929092
14386	2020-03-04 13:01:58	2020-03-04	Chanel Moore	chanel.moore@geemail.com	Chula Vista	California	3032287884924995	b469a6a434929fb96219e56b40d25e1e	Diners Club / Carte Blanche	32.6646970959611238	-117.087378828297176
14387	2020-03-04 13:13:36	2020-03-04	Dillan Bahringer	dillan.bahringer@geemail.com	Milwaukee	Wisconsin	3096732308684966536	2bc02cb1c18ca0cc1ab8facf8453558e	Voyager	42.9765089101709421	-87.9718803395617783
14388	2020-03-04 13:25:44	2020-03-04	Miss Bonny Treutel PhD	miss.bonny.treutel.phd@geemail.com	San Antonio	Texas	55756854195632050	32e1c7cbca24ea2022923889f84202c2	Diners Club / Carte Blanche	29.5038164841081958	-98.5866895691793417
14389	2020-03-04 14:16:42	2020-03-04	Cherrelle Boyle	cherrelle.boyle@woohoo.com	Garden Grove	California	3528694403793575686	43ec80402b4bb452da2e3a3bc5059d0a	VISA 16 digit	33.8483248818956284	-117.909606328794723
14390	2020-03-04 14:42:20	2020-03-04	Laci Murphy	laci.murphy@geemail.com	Kansas City	Missouri	3457349429968582	73c05d5feffd00c8125a8d125771232d	Diners Club / Carte Blanche	39.034369597195095	-94.6132159268707085
14391	2020-03-04 14:54:41	2020-03-04	Grayson Bogisich	grayson.bogisich@geemail.com	San Francisco	California	3767451844957360	f059d7cb570634f6ba915d98a5fcae60	Maestro	37.7797888953309311	-122.480167205783118
14392	2020-03-04 14:54:44	2020-03-04	Adin Schmitt	adin.schmitt@geemail.com	San Francisco	California	180046863207215978	c9febb1008081b1f8ec482bd63d416fc	VISA 16 digit	37.7911728502542488	-122.384201704613048
14393	2020-03-04 15:32:20	2020-03-04	Jasiah Bednar-Pouros	jasiah.bednar.pouros@warmmail.com	San Francisco	California	51405480477865526	cdda9a78b79559ffcb7d46b6b6191d20	VISA 16 digit	37.7590631097630123	-122.443635210835097
14394	2020-03-04 15:38:25	2020-03-04	Vick Marquardt	vick.marquardt@geemail.com	Tulsa	Oklahoma	54419927888395190	b57c03afa000b4d3c89f9fad50ca72a2	JCB 16 digit	36.1175406346931993	-95.9198530379638044
14395	2020-03-04 15:46:12	2020-03-04	Mr. Malcolm Zieme DVM	mr.malcolm.zieme.dvm@geemail.com	Kenosha	Wisconsin	3112586351074591347	198573711c7d2db86c8f2436bf58fb35	Maestro	42.5595583868984164	-87.9111644034035606
14396	2020-03-04 15:59:33	2020-03-04	Hayward Mertz	hayward.mertz@geemail.com	New York	New York	3528534638316332651	c11a1abc23aa85ceb8ad5601ed3de736	VISA 16 digit	40.6366041158083817	-73.947115211038664
14397	2020-03-04 16:07:55	2020-03-04	Cullen Herman-Yundt	cullen.herman.yundt@geemail.com	Pittsburgh	Pennsylvania	676381495587693	5f47a395821480cc31669ab6bcaa1079	Diners Club / Carte Blanche	40.3538709345694642	-79.9375753184951918
14398	2020-03-04 16:26:12	2020-03-04	Tracee Lueilwitz	tracee.lueilwitz@woohoo.com	Alexandria	Virginia	503867993817088	3029b73baa84466721325f265153f6b7	Mastercard	38.8065080348052049	-77.106267988214654
14399	2020-03-04 16:30:12	2020-03-04	Dr. Grant O'Kon DDS	dr.grant.o'kon.dds@geemail.com	San Francisco	California	180017382709743705	2258b034ce04de9c3892f6fa640f0c9d	Discover	37.7464547708985521	-122.418646072425943
14400	2020-03-04 17:02:24	2020-03-04	Mr. Sharif Kuphal III	mr.sharif.kuphal.iii@geemail.com	San Jose	California	4736241360768338	76b1cfbb1de86317735cc3e89b3418cd	Mastercard	37.327570349192996	-121.896893567939841
14401	2020-03-04 17:08:53	2020-03-04	Doctor Kemmer	doctor.kemmer@warmmail.com	Port St. Lucie	Florida	4386290121733183	cb192ced22642aa860b8141b96bab123	JCB 16 digit	27.1924190356530247	-80.396511066480727
14402	2020-03-04 17:21:15	2020-03-04	Mr. Jerod Schulist PhD	mr.jerod.schulist.phd@warmmail.com	New York	New York	210054874981608675	7d31c91a31488d48edf08ca2ff3973a2	Voyager	40.6552974597308747	-73.85691435624733
14403	2020-03-04 17:42:14	2020-03-04	Leopoldo Klocko	leopoldo.klocko@geemail.com	San Antonio	Texas	4619502818308924	dc708cf7723e0a03c55df73de4a36ade	VISA 16 digit	29.4347324771877368	-98.5957628219690179
14404	2020-03-04 17:59:32	2020-03-04	Mr. Coleton O'Keefe DVM	mr.coleton.o'keefe.dvm@woohoo.com	Berkeley	California	4898775272311491	683618259c3c9273427478f7ed044f5e	VISA 13 digit	37.9028684131513458	-122.242830153508692
14405	2020-03-04 18:15:57	2020-03-04	Dr. Galen Waters I	dr.galen.waters.i@geemail.com	Jacksonville	Florida	4030387575464	54e5994423b340960cbc4f58fe1ae5ab	VISA 13 digit	30.4096143981959663	-81.730830024795992
14406	2020-03-04 18:36:50	2020-03-04	Dr. Heyward Hermiston	dr.heyward.hermiston@warmmail.com	Berkeley	California	869997930094994383	f23d59da7419a4cfab7a816410d1efd1	Maestro	37.8491128739601734	-122.268137690019444
14407	2020-03-04 18:49:47	2020-03-04	Houston Mueller	houston.mueller@geemail.com	San Francisco	California	676144784480103	37555a599a800229b0a131427a264e2a	JCB 16 digit	37.7687004478599562	-122.420685248289757
14408	2020-03-04 18:51:24	2020-03-04	Wayman Wilderman DVM	wayman.wilderman.dvm@geemail.com	Bakersfield	California	3112443627895532229	20e36cc998e14e50413890c9575a8257	JCB 15 digit	35.329942707921191	-119.008378742103645
14409	2020-03-04 19:05:59	2020-03-04	Mr. Derwin Haley IV	mr.derwin.haley.iv@geemail.com	Oakland	California	3719572219683676	a13b4d34ef0c107fbfc2a46128e8d913	Voyager	37.8253584396124438	-122.256640050040446
14410	2020-03-04 19:19:29	2020-03-04	Albertina Corwin	albertina.corwin@geemail.com	Oakland	California	3096400007711879297	e257d693a6bc646d945b04adcca061fe	Voyager	37.8083646954577048	-122.281864989848344
14411	2020-03-04 19:51:02	2020-03-04	Joetta Hills PhD	joetta.hills.phd@woohoo.com	Lowell	Massachusetts	561213911868985	ad93fdbfbbf46461ec611851d3a8e1fe	VISA 16 digit	42.5891587712205961	-71.2967141352467308
14412	2020-03-04 19:52:51	2020-03-04	Shelley Block	shelley.block@geemail.com	Syracuse	New York	589333967877292	77f4a6a75482d2af6b4ed318245ec764	Voyager	42.9665695014726339	-76.0951877001453312
14413	2020-03-04 20:07:15	2020-03-04	Dayami Sipes	dayami.sipes@woohoo.com	New York	New York	3112207633003559027	ad66dbb019b9fc84a4a9bbd7c4f3ab27	VISA 16 digit	40.7018408047258831	-74.0028361629124731
14414	2020-03-04 20:21:49	2020-03-04	Linus Jenkins	linus.jenkins@geemail.com	Honolulu	Hawaii	3038259331297857	fe97223dcaf60c426fcd7a00bffd7359	JCB 15 digit	21.2404179217975582	-157.81478619694002
14415	2020-03-04 20:24:50	2020-03-04	Alexa Thompson	alexa.thompson@geemail.com	Newport News	Virginia	869936472805082038	3e67ab47a91b4ba0496dcd35e7e8b8cd	Discover	37.131666395104304	-76.5447180661633695
14416	2020-03-04 20:25:29	2020-03-04	Cannie Hayes	cannie.hayes@geemail.com	Houston	Texas	3337250760695180469	615f0f8977f9e427f0679ca2bfe3c813	Maestro	29.7823497727591544	-95.300577202440806
14417	2020-03-04 20:27:46	2020-03-04	Carmine Green	carmine.green@warmmail.com	San Antonio	Texas	4603955667655	833ff6b755327d3b9c83a8609e708a8a	Diners Club / Carte Blanche	29.4167184894043956	-98.4387913351714587
14418	2020-03-04 20:29:35	2020-03-04	Tonia Howe	tonia.howe@geemail.com	Detroit	Michigan	869937853321854621	425fca8686f0fe6768e19ccdd128b8d7	American Express	42.4140125700198141	-83.0144866689227428
14419	2020-03-04 20:33:54	2020-03-04	Isla Reinger DDS	isla.reinger.dds@geemail.com	Norman	Oklahoma	3158071887301848291	03d5923e766a5ecb35f042eb8a942a3e	JCB 16 digit	35.1809894138522452	-97.4126149548470863
14420	2020-03-04 20:36:59	2020-03-04	America McKenzie	america.mckenzie@woohoo.com	Denver	Colorado	3096709300995883822	b769fd62c90280c4a03e920807ec7b4e	JCB 15 digit	39.781514305626601	-104.789398846986145
14421	2020-03-04 20:40:06	2020-03-04	Dr. Clearence Hegmann I	dr.clearence.hegmann.i@geemail.com	Henderson	Nevada	4100620482792	e4b31a1a49626dba668b56ea010936d4	JCB 16 digit	35.9394131664119669	-114.993875090374431
14422	2020-03-04 20:45:37	2020-03-04	Corinne Boyer DDS	corinne.boyer.dds@geemail.com	Lowell	Massachusetts	3337832188952060686	ea53b9519f3d8bb4a1b24c83c66c21de	Maestro	42.6082311108578011	-71.2806571793150141
14423	2020-03-04 21:03:40	2020-03-04	Shelba Anderson DVM	shelba.anderson.dvm@warmmail.com	Lafayette	Louisiana	4564990343373007	a442f719266548c37c41d10e4ecd7a7a	Diners Club / Carte Blanche	30.2348042754899708	-92.075796604095018
14424	2020-03-04 21:16:28	2020-03-04	Easton Turcotte	easton.turcotte@geemail.com	Durham	North Carolina	180081343727684116	2d3d9f6c96deeaf9fb05f302b16e6541	American Express	35.9071957775171811	-78.8807762971051005
14425	2020-03-04 21:32:45	2020-03-04	Mr. Darryn Morar DVM	mr.darryn.morar.dvm@geemail.com	Berkeley	California	53233512008116983	da110023f05867ea366737084da76bb2	Discover	37.8961282078587089	-122.308477885792314
14426	2020-03-04 21:35:33	2020-03-04	Wendel Lehner	wendel.lehner@geemail.com	Tucson	Arizona	060481493433304	448ebc41e8fc198759de55195f36993a	VISA 16 digit	32.1234609711956267	-110.879751860233398
14427	2020-03-04 21:37:45	2020-03-04	Delmer Bernhard	delmer.bernhard@geemail.com	San Francisco	California	4899451516414496	e9a631466b0cd4908ce0810dac0cdbb3	JCB 16 digit	37.7806682179386684	-122.456952326540261
14428	2020-03-04 21:45:57	2020-03-04	Thomasina Labadie DDS	thomasina.labadie.dds@geemail.com	Corona	California	3030641909590045	a030b5f117d6a11b0f8d27f4f99af0ee	VISA 16 digit	33.8869441090039913	-117.601193573625764
14429	2020-03-04 22:10:02	2020-03-04	Kieth Greenfelder	kieth.greenfelder@woohoo.com	Jurupa Valley	California	3528674237503250303	5b6e67cc0b97729f546029fe829e067f	JCB 16 digit	34.0227777060516203	-117.526956797719379
14430	2020-03-04 22:10:06	2020-03-04	Mr. Anibal Jakubowski	mr.anibal.jakubowski@warmmail.com	Columbia	South Carolina	4676001709672134	9bd088061a29794e93285bb15478abe8	Maestro	33.9291325707718698	-80.9875099223591377
14431	2020-03-04 22:20:56	2020-03-04	Mercy Beatty	mercy.beatty@geemail.com	Tampa	Florida	4193185082980877	d80d22dd3d82738ecde2da8670d80289	JCB 15 digit	28.0156935551784905	-82.4308884549166976
14432	2020-03-04 23:03:06	2020-03-04	Tiney Lindgren	tiney.lindgren@geemail.com	San Francisco	California	4398625521446	310510dff5b7ba148e7fca1d5fde5bf1	VISA 13 digit	37.789695533426908	-122.414455393852947
14433	2020-03-04 23:32:42	2020-03-04	Savannah Durgan	savannah.durgan@geemail.com	Memphis	Tennessee	869914533267043283	e02ae52a0eb4028be0dee45fcf7256bf	Mastercard	35.1937635195042944	-90.0528013354424388
14434	2020-03-04 23:34:15	2020-03-04	Vick Shanahan	vick.shanahan@geemail.com	Omaha	Nebraska	4847315234397	59263d0e5cd9b7bf5a556b73f27613a4	Voyager	41.256415918251129	-96.0842844335477793
14435	2020-03-04 23:50:58	2020-03-04	Ervin Halvorson	ervin.halvorson@geemail.com	Portland	Oregon	4360685622921478	a8639cc34f62aa7d2d2e6d7041161956	American Express	45.6287162524070595	-122.712845642725014
14436	2020-03-05 00:06:23	2020-03-05	Kris Langworth	kris.langworth@geemail.com	Philadelphia	Pennsylvania	3781069823937708	fe89a3e606ec9d2c1ecec474a3dfce7a	Discover	39.9204577275510886	-75.1219473267804858
14437	2020-03-05 00:13:41	2020-03-05	Celestia Murphy	celestia.murphy@geemail.com	Indianapolis	Indiana	869990673362455094	335686757dc66fcec6359cb19ce6f911	Voyager	39.6819631437778426	-86.2330021016500865
14438	2020-03-05 00:17:29	2020-03-05	Jade Rempel MD	jade.rempel.md@geemail.com	New York	New York	561216246490805	e71331d00134e76cfb022f1437cde616	Diners Club / Carte Blanche	40.5826831580828866	-74.0230139127362463
14439	2020-03-05 00:21:56	2020-03-05	Rhys Quitzon-Runolfsson	rhys.quitzon.runolfsson@geemail.com	Charlotte	North Carolina	869995772682071014	f918e8425e0a0d48d63046a35f20d5c0	JCB 16 digit	35.2480718249242742	-80.9062543974667818
14440	2020-03-05 00:34:32	2020-03-05	Victor Kub	victor.kub@woohoo.com	Wilmington	North Carolina	4774820546824371	773fc56e32adce4e6fbe1afd8e571f60	VISA 16 digit	34.1811759124796879	-77.971056291832781
14441	2020-03-05 00:35:03	2020-03-05	Alcee Rolfson	alcee.rolfson@woohoo.com	Philadelphia	Pennsylvania	210020617395386300	e5f61da22cf6f0e189b51296de3c7946	Discover	39.9674055939964958	-75.1311936904575788
14442	2020-03-05 01:05:59	2020-03-05	Dennie Langosh	dennie.langosh@geemail.com	Seattle	Washington	4319024575818527	41def4fddd6b74e39260721138465ac1	JCB 15 digit	47.679999437920749	-122.403587931293615
14443	2020-03-05 01:06:39	2020-03-05	Linn Moore	linn.moore@geemail.com	Tallahassee	Florida	3088341755535504804	6feba4011115bcc04c20ce43b8694371	JCB 16 digit	30.4121897351484769	-84.1932733794689199
14444	2020-03-05 01:06:47	2020-03-05	Mrs. Carroll Cole	mrs.carroll.cole@geemail.com	Berkeley	California	502006491639750	a91282dae91759c350af753c474a765a	Maestro	37.9050084659872013	-122.254359465132467
14445	2020-03-05 01:43:36	2020-03-05	Mr. Daulton Schaefer	mr.daulton.schaefer@geemail.com	Oakland	California	6011858607467565292	57967701bfb2a1e3af6c5c12170e3442	VISA 16 digit	37.7895253094666757	-122.300931549257683
14446	2020-03-05 01:50:08	2020-03-05	Jaycob Bosco	jaycob.bosco@geemail.com	New York	New York	3459069255846391	5a6c61190407ced305bbc451107ea84d	Diners Club / Carte Blanche	40.6463756621573111	-73.8825736457843334
14447	2020-03-05 01:52:21	2020-03-05	Robert Medhurst	robert.medhurst@geemail.com	Surprise	Arizona	180048819184844030	b16e1f225c384145cf0eeece5238cde2	JCB 15 digit	33.6473151068430383	-112.367582518537333
14448	2020-03-05 02:00:23	2020-03-05	Tatia Osinski	tatia.osinski@geemail.com	Aurora	Illinois	3088576752858336696	cba1cc2e860125b6527c5f0970a440de	Voyager	41.8145869787540292	-88.3282382326129749
14449	2020-03-05 02:30:30	2020-03-05	Nira Powlowski	nira.powlowski@geemail.com	San Francisco	California	3088001004802499146	56b7658a575ab723c9f90b4ec863b575	VISA 13 digit	37.7801839161167408	-122.441827682423849
14450	2020-03-05 02:39:16	2020-03-05	Lindsey Emmerich	lindsey.emmerich@geemail.com	Phoenix	Arizona	676208266133837	70e20cb318f6daebb1206a01b6a1ad32	VISA 13 digit	33.6323455889176586	-112.041249217970673
14451	2020-03-05 02:51:55	2020-03-05	Harrison Heller V	harrison.heller.v@geemail.com	San Francisco	California	060409727674690	8ef4f2693d943d850837660711759c53	Voyager	37.7672596946552872	-122.430640647436022
14452	2020-03-05 03:18:34	2020-03-05	Amari White MD	amari.white.md@woohoo.com	Escondido	California	3096343870625782489	693343e48d30091874c8c1c7d5bedd1f	JCB 15 digit	33.1109185604605827	-117.042261893372981
14453	2020-03-05 03:25:10	2020-03-05	Fawn Corwin	fawn.corwin@geemail.com	Midland	Texas	4937004593828007	40307f542fbaba3a12f71a42a11c2476	Mastercard	31.9848321648970249	-102.026903279194613
14454	2020-03-05 03:26:47	2020-03-05	Mckenzie Howell-Sawayn	mckenzie.howell.sawayn@geemail.com	New York	New York	4929027374989581	5365c8ccb10dd9bbaa53a61d34d33404	JCB 16 digit	40.5854524075277112	-73.9015930384758803
14455	2020-03-05 03:31:31	2020-03-05	Maebell Schmitt	maebell.schmitt@warmmail.com	San Francisco	California	3096176026619727152	d0879885a7e03126b046f963c0033674	Maestro	37.7922703153913773	-122.422231360061787
14456	2020-03-05 03:41:04	2020-03-05	Dr. Agustin Lebsack Jr.	dr.agustin.lebsack.jr.@woohoo.com	Chicago	Illinois	3044386949217573	4f17770d194467533913240447ee5c9d	VISA 16 digit	41.891342703609169	-87.7423839380528676
14457	2020-03-05 03:46:45	2020-03-05	Eber Schumm	eber.schumm@geemail.com	San Francisco	California	54378679650162758	071040c4387a777cd3b895ee66d90fd9	JCB 15 digit	37.755116355924244	-122.453675445371587
14458	2020-03-05 03:52:27	2020-03-05	Dr. Isreal Dicki I	dr.isreal.dicki.i@geemail.com	San Antonio	Texas	4129883001189	54a6fa43064fa9003b7326a5a8902316	Maestro	29.5509284833051282	-98.5201671887490846
14459	2020-03-05 03:55:27	2020-03-05	Mr. Emilio Howe III	mr.emilio.howe.iii@geemail.com	Albuquerque	New Mexico	3528832298811566847	5ec3e03725c384a71a3b1c33d91f132e	JCB 16 digit	35.0921275720134389	-106.741240742530309
14460	2020-03-05 04:04:22	2020-03-05	Carri Morar	carri.morar@woohoo.com	Akron	Ohio	869991903803375422	4a0da61b6f21e8f6baf81a4da863a867	Voyager	41.0200714903250372	-81.5068154290631384
14461	2020-03-05 04:14:35	2020-03-05	Myranda Willms	myranda.willms@warmmail.com	New York	New York	51228479690973690	2850c5f8c2a239e0f850ee2c1aa179f8	Discover	40.6902869788222006	-73.9401055687002753
14462	2020-03-05 04:45:21	2020-03-05	Dr. Steward Von	dr.steward.von@geemail.com	San Francisco	California	210099380437995614	3a53dd0ff58621c46dbd36e80e4e3cd7	Maestro	37.7683818649736622	-122.426497568916716
14463	2020-03-05 04:56:17	2020-03-05	Mr. Caden Quigley V	mr.caden.quigley.v@geemail.com	San Francisco	California	675932723985936	a9b083cb3865820fd19f59b41b1c5f77	American Express	37.7743680234027224	-122.415934076975958
14464	2020-03-05 05:01:12	2020-03-05	Dr. Kai Tillman V	dr.kai.tillman.v@geemail.com	San Jose	California	676231988597832	dcb09cdc6825c4f55f196dfbea055622	VISA 13 digit	37.3841162390362456	-121.913210812233018
14465	2020-03-05 05:54:56	2020-03-05	Ethelene Kirlin DVM	ethelene.kirlin.dvm@woohoo.com	Grand Prairie	Texas	3754811474745788	48eaba6bfb6d7067edeb496c0c5ac9b7	VISA 16 digit	32.7225731943786187	-97.0737818579994212
14466	2020-03-05 05:55:41	2020-03-05	Mrs. Mallory Klein	mrs.mallory.klein@geemail.com	Cincinnati	Ohio	6011698029230252781	9baf02a599eade357c882b7ca8830260	VISA 16 digit	39.0635631018549176	-84.4865352859526837
14467	2020-03-05 06:03:52	2020-03-05	Harper Johns	harper.johns@geemail.com	Seattle	Washington	4275870741431948	2763fb419c315d838a447b98d3561180	Voyager	47.5884175370372802	-122.360543264254545
14468	2020-03-05 06:05:42	2020-03-05	Hiram Rath IV	hiram.rath.iv@warmmail.com	Oakland	California	3158957531646668720	5f110cddbc9c1c3eecc86b764f9bd6bd	JCB 16 digit	37.8011821985344838	-122.248594248590877
14469	2020-03-05 06:26:25	2020-03-05	Dr. Madelynn Zemlak DDS	dr.madelynn.zemlak.dds@geemail.com	Dallas	Texas	3018317248550683	a3306888f01e27f72c94b0f35b95edc6	VISA 16 digit	32.8095561134435272	-96.7001181957274554
14470	2020-03-05 06:31:52	2020-03-05	Ivory O'Keefe	ivory.o'keefe@geemail.com	New York	New York	6011019799574515371	18a0f89cccd52907da159b0f70ce9def	VISA 16 digit	40.6813124969825139	-73.9733205295063527
14471	2020-03-05 06:45:49	2020-03-05	Debra Keebler	debra.keebler@warmmail.com	Fort Worth	Texas	210064812834410558	814690a392010173a9c753d01b3e3d37	Mastercard	32.7980960736572769	-97.4182350643731638
14472	2020-03-05 06:48:32	2020-03-05	Rondal Armstrong	rondal.armstrong@warmmail.com	San Francisco	California	4606254922218	06ac726deae0630ea68d2cd22cf24a57	Discover	37.7333291774649737	-122.456738603224764
14473	2020-03-05 06:48:43	2020-03-05	Milburn Becker	milburn.becker@geemail.com	Austin	Texas	3437546345265523	eb2ec21684aa11043ddd846ecf149b35	VISA 16 digit	30.3051234328780303	-97.7187218160141242
14474	2020-03-05 06:49:50	2020-03-05	Aleta Stokes	aleta.stokes@geemail.com	Denton	Texas	3096375698244955298	d5601bc8a5d4d4b1600495c0a92cebe5	JCB 16 digit	33.2814606871254739	-97.0547058525621935
14475	2020-03-05 07:01:24	2020-03-05	Durell Kunde	durell.kunde@warmmail.com	Springfield	Massachusetts	3528252478681264449	b7b83857215e72af725817ca713b7a4a	Mastercard	42.1298001905176775	-72.6381989382766307
14476	2020-03-05 07:03:41	2020-03-05	Mr. Bernie Runolfsdottir I	mr.bernie.runolfsdottir.i@warmmail.com	Chicago	Illinois	3712735964741638	fdfc237f0a0172ac9d0382f508bf48fa	VISA 16 digit	41.8434297529816632	-87.6165003879491167
14477	2020-03-05 07:06:26	2020-03-05	Thedore Dare-Abbott	thedore.dare.abbott@geemail.com	Port St. Lucie	Florida	3088100862509534923	bea42cfcded76a8a237beb6b2aadbaf8	VISA 16 digit	27.3646313483029608	-80.3309325649023123
14478	2020-03-05 07:34:40	2020-03-05	Tianna Nikolaus-Morissette	tianna.nikolaus.morissette@woohoo.com	Louisville	Kentucky	180028585098072976	40841330fc0a1d25135eb341f739dbd7	JCB 16 digit	38.1605790634542714	-85.7185918787565129
14479	2020-03-05 07:42:26	2020-03-05	Foy O'Connell	foy.o'connell@geemail.com	Fresno	California	561226052854549	72ddefa9af44971568a9e27586e0aed9	Mastercard	36.8535447375722214	-119.734449490123993
14480	2020-03-05 08:26:04	2020-03-05	Americo Rodriguez	americo.rodriguez@geemail.com	San Francisco	California	869970263540145074	68de69e82128ac1e2612bf37dfb363c1	VISA 16 digit	37.7662061376952636	-122.43197976696591
14481	2020-03-05 08:32:06	2020-03-05	Ballard Gaylord	ballard.gaylord@warmmail.com	Corpus Christi	Texas	3048169823862979	acf03d691b0aba36188844843c7bc25c	JCB 16 digit	27.6738082788821309	-97.2330422123722684
14482	2020-03-05 08:53:04	2020-03-05	Aaden Leannon	aaden.leannon@warmmail.com	New York	New York	4844261534671415	bf517ddfbecc75b9d5e071a26dce314b	JCB 16 digit	40.6974853145182109	-74.0202502473153174
14483	2020-03-05 09:13:42	2020-03-05	Lucina Jaskolski	lucina.jaskolski@geemail.com	College Station	Texas	4015294085921	8b5dfd57b698a2dd9c0ad58c34f49bb1	JCB 15 digit	30.6719821860127162	-96.2899974512249344
14484	2020-03-05 09:21:39	2020-03-05	Cindy Hermann	cindy.hermann@geemail.com	Cedar Rapids	Iowa	4159180371203760	652feb45fae16fe55b26e52404b1f2c1	JCB 16 digit	42.0341495941001924	-91.673330567364772
14485	2020-03-05 09:35:00	2020-03-05	Arvid Bartoletti	arvid.bartoletti@warmmail.com	Berkeley	California	180012894407232992	118074888b000b7eac658f31a0ac5efa	VISA 16 digit	37.860357938108443	-122.275146562842878
14486	2020-03-05 09:37:41	2020-03-05	Earle Cartwright Sr.	earle.cartwright.sr.@geemail.com	Cincinnati	Ohio	676289381341125	598d07f75b558b816f431fe0a93ee836	VISA 16 digit	39.2392256401244524	-84.4867327362570819
14487	2020-03-05 09:41:10	2020-03-05	Ursula Jacobson	ursula.jacobson@geemail.com	San Francisco	California	4439624224990521	efbaabb7e62fda49e8a8899b379c8603	Mastercard	37.7634927559234441	-122.389924897183846
14488	2020-03-05 10:16:48	2020-03-05	Lester Zieme	lester.zieme@woohoo.com	Tulsa	Oklahoma	4976038269696688	28f32bd77668c2b99f506a551f51d82b	American Express	36.0631294511161684	-95.9622768908228636
14489	2020-03-05 11:02:52	2020-03-05	Robert Upton	robert.upton@geemail.com	New York	New York	180069786795018342	34e1be3392b3e2a98989a173680f16f6	JCB 16 digit	40.7118282108325502	-73.9029985224723731
14490	2020-03-05 11:18:24	2020-03-05	Mrs. Debbie Schimmel DDS	mrs.debbie.schimmel.dds@geemail.com	Memphis	Tennessee	52459638817623641	32ffc7231384465c67ae214a5988dafc	American Express	35.0034592584308228	-90.0415811716370342
14491	2020-03-05 11:24:40	2020-03-05	Sydnee Nicolas DVM	sydnee.nicolas.dvm@geemail.com	Boston	Massachusetts	51946552473404777	1325c4fe8414ccfd270e03d49c188fc8	Maestro	42.2433176570273972	-71.0794727854382273
14492	2020-03-05 11:53:47	2020-03-05	Stanton Kris	stanton.kris@warmmail.com	Los Angeles	California	210073381623285554	cd929c6925ef5bf55c0900a0fcb7d35a	Discover	34.0716850798908624	-118.503392456610868
14493	2020-03-05 12:30:05	2020-03-05	Bradyn Boyle	bradyn.boyle@geemail.com	Syracuse	New York	4673677481859545	9213f790f7a0a35233e3354f67c3fac3	Mastercard	43.0062425649575886	-76.1731561210252437
14494	2020-03-05 12:53:33	2020-03-05	Lacey Walter	lacey.walter@geemail.com	Charlotte	North Carolina	55337874757332251	561c09a2c6e75bc863eae908a9b876cf	VISA 16 digit	35.2560637485023562	-80.9112556563168823
14495	2020-03-05 13:08:30	2020-03-05	Anabelle Krajcik	anabelle.krajcik@woohoo.com	Mobile	Alabama	3738630659241277	e77f38e4929f18259c7fdc311cc2b7cc	JCB 16 digit	30.6938432953428446	-88.087230082847924
14496	2020-03-05 14:09:32	2020-03-05	Arah Mills-Feeney	arah.mills.feeney@geemail.com	Garden Grove	California	210081724720950184	097779cc8671847c40d1c6ba4bf8b4d0	JCB 15 digit	33.8565480245102179	-117.93920699814521
14497	2020-03-05 14:12:19	2020-03-05	Metha Nienow	metha.nienow@geemail.com	Jackson	Mississippi	3088979623293055428	b862ca4c8624049dff12702bf3741b7b	JCB 16 digit	32.3364227051094204	-90.1211741424139632
14498	2020-03-05 14:13:11	2020-03-05	Roderick Cassin V	roderick.cassin.v@geemail.com	Los Angeles	California	3024031243933976	1e6fb15fc9157203ae960b4cdfc721f6	VISA 16 digit	33.9698687481094126	-118.451964232464505
14499	2020-03-05 14:38:26	2020-03-05	Emmett Denesik	emmett.denesik@geemail.com	San Angelo	Texas	3035051796661245	b0d5c488b17539ff56486d7ec011bd9c	VISA 16 digit	31.5388551722433412	-100.462001521104952
14500	2020-03-05 15:48:20	2020-03-05	Blair Glover	blair.glover@woohoo.com	Phoenix	Arizona	51991389774280422	bdc2e0e8127c0ab6e6dfe49db8cd0d4c	American Express	33.5816463538378471	-112.141275308367241
14501	2020-03-05 15:49:48	2020-03-05	Ladarius Gusikowski IV	ladarius.gusikowski.iv@woohoo.com	San Francisco	California	3158966817756875646	3cb67e43bc3b47118affabab7ca1423a	JCB 16 digit	37.7695061955900329	-122.41911808876678
14502	2020-03-05 16:09:35	2020-03-05	Louvenia Nikolaus	louvenia.nikolaus@warmmail.com	Fort Wayne	Indiana	54241567998471772	a9f6f0fb5e4187f6efbeb7e90eaa32de	VISA 13 digit	41.1268741607449968	-85.0491334594540263
14503	2020-03-05 16:10:18	2020-03-05	Mr. Palmer Beatty DVM	mr.palmer.beatty.dvm@geemail.com	Newport News	Virginia	676289685222575	eb6964dfbc68268e54bfe59736325eba	Discover	37.1260685353901252	-76.4751052796635804
14504	2020-03-05 16:11:54	2020-03-05	Pandora Lindgren	pandora.lindgren@woohoo.com	Colorado Springs	Colorado	3088874633447577686	66d1481c66bb9b6fcb7ed8e130e17dea	Maestro	38.9565021050211016	-104.72521379596256
14505	2020-03-05 16:20:43	2020-03-05	Norman Stokes-Langworth	norman.stokes.langworth@geemail.com	Charlotte	North Carolina	3096022048471558992	ccea92e4c0c4f99d3a5e1026f73f12e2	JCB 15 digit	35.3053541993975628	-80.8107499992419065
14506	2020-03-05 16:21:57	2020-03-05	Diallo Mitchell	diallo.mitchell@geemail.com	Tuscaloosa	Alabama	4612728976442	4ba9a88ed9a22e3d37c49d79b65189e9	JCB 15 digit	33.2500343600809529	-87.6275306127131017
14507	2020-03-05 17:07:19	2020-03-05	Ruthe Yundt-Bogisich	ruthe.yundt.bogisich@geemail.com	Houston	Texas	869985136616669693	d9f7b2ae3d4beeaa45306e7019c7081a	VISA 16 digit	29.8266294461287558	-95.4456215903643539
14508	2020-03-05 17:07:32	2020-03-05	Reinaldo Cartwright	reinaldo.cartwright@geemail.com	Buffalo	New York	4559133836941686	de80d57741fe5aee4c37e2c51da4f899	Maestro	42.9225472951028451	-78.7994235740441837
14509	2020-03-05 17:18:20	2020-03-05	Paola Heller	paola.heller@geemail.com	San Francisco	California	503895441688793	410fa0189eedd30ecb807402c4daf730	Diners Club / Carte Blanche	37.7832012681110427	-122.427677784659238
14510	2020-03-05 17:23:15	2020-03-05	Kerwin Gaylord	kerwin.gaylord@geemail.com	San Francisco	California	4168474488625018	126c04d55176b3927e172da6a78d38c1	JCB 16 digit	37.8014495605311538	-122.458122709567789
14511	2020-03-05 18:08:59	2020-03-05	Miss Karie Blanda MD	miss.karie.blanda.md@geemail.com	Milwaukee	Wisconsin	4866865330909804	cfe585b183b89fd46bb8ea1a8679f35f	JCB 16 digit	43.122625468912716	-87.8870468043822797
14512	2020-03-05 18:23:44	2020-03-05	Archer Schimmel V	archer.schimmel.v@geemail.com	San Francisco	California	4768865725824179	83a01277e5f3470accf617b867209473	VISA 16 digit	37.7838862890240179	-122.384321258911172
14513	2020-03-05 18:48:46	2020-03-05	Joselyn Altenwerth	joselyn.altenwerth@woohoo.com	Springfield	Missouri	4343447506466688	cb14b08c64e79d28e44ea18a8cea9cc7	JCB 16 digit	37.1591737456347815	-93.2562162843357783
14514	2020-03-05 18:56:36	2020-03-05	Miss Cheyenne Bergstrom MD	miss.cheyenne.bergstrom.md@geemail.com	Denver	Colorado	4735718137350749	35acc5d281bcea341b2a5fea21ddcd1e	VISA 13 digit	39.7717531979601802	-104.793817679049823
14515	2020-03-05 19:14:38	2020-03-05	Elaine Pouros-Jaskolski	elaine.pouros.jaskolski@woohoo.com	Oklahoma City	Oklahoma	3770867963499139	cae1c9b5f1922ce1b220ddb5f33740b7	Voyager	35.5195012019392138	-97.4949755641061842
14516	2020-03-05 19:35:46	2020-03-05	Alphonsine Stokes	alphonsine.stokes@geemail.com	Spokane	Washington	639078497938627	3895ce466eb7126e98597acd70598e71	American Express	47.5922579330630597	-117.335286669283363
14517	2020-03-05 19:55:55	2020-03-05	Percival Conn	percival.conn@woohoo.com	Stockton	California	4483519978512569	43c0f4fb2a6c9c3bcadd310e80e6edfe	Discover	37.9167988347087075	-121.314660042858861
14518	2020-03-05 20:09:34	2020-03-05	Dominik Turcotte	dominik.turcotte@geemail.com	Fayetteville	North Carolina	6011498562887564548	ad22c05503753861ce65482f0807f2cf	JCB 16 digit	35.1256564023226474	-78.9666126649491531
14519	2020-03-05 20:23:57	2020-03-05	Jeanna Hoppe	jeanna.hoppe@geemail.com	Berkeley	California	6011685611638701710	40c6bcbf157c08d68edfbe2d64493b73	Diners Club / Carte Blanche	37.8901235290482816	-122.290509101055861
14520	2020-03-05 20:27:05	2020-03-05	Lane Bergnaum	lane.bergnaum@geemail.com	Oxnard	California	869901776763614314	efa5525a3fbc315eb91091fc96db6c80	Mastercard	34.1253896061751973	-119.221833049869531
14521	2020-03-05 20:32:17	2020-03-05	Alline Deckow	alline.deckow@geemail.com	San Francisco	California	3046293702512166	786583bf0286d186eb3e75135675b6d9	Diners Club / Carte Blanche	37.8087158725831358	-122.454967285256672
14522	2020-03-05 21:08:32	2020-03-05	Rupert Dooley	rupert.dooley@geemail.com	Hollywood	Florida	6011478142048569266	8f0d8dc86b414399ebe61d7dce155a65	JCB 16 digit	26.0328682776950302	-80.1203908357586698
14523	2020-03-05 21:31:31	2020-03-05	Konner Bednar-Haag	konner.bednar.haag@warmmail.com	Oakland	California	6011171768366258759	0046c54d488c8a8bb2255cf48d561c42	VISA 16 digit	37.814605057428146	-122.28034467970123
14524	2020-03-05 21:46:53	2020-03-05	Margurite Heidenreich	margurite.heidenreich@geemail.com	San Francisco	California	3158774142997760214	f5c8d8c7180669548962378c8c5cf71b	JCB 16 digit	37.7909860883340372	-122.421218865890395
14525	2020-03-05 21:57:22	2020-03-05	Marylin Stracke-Stroman	marylin.stracke.stroman@geemail.com	Jacksonville	Florida	3158588758446689963	87da5f3667965cbe64e94064b30d8c6a	VISA 16 digit	30.3596212334051714	-81.6189619524948426
14526	2020-03-05 22:09:11	2020-03-05	Wellington Schmitt Sr.	wellington.schmitt.sr.@woohoo.com	San Francisco	California	3096086923571272939	41a115141338d7cd365646be6cb7326c	Discover	37.7638544238830107	-122.431276030926796
14527	2020-03-05 22:14:47	2020-03-05	Evon Hills DDS	evon.hills.dds@warmmail.com	Corona	California	210053885794232785	153daab28ca3c2cbbc7ee912e5c0d843	American Express	33.9613929575663107	-117.585121655065564
14528	2020-03-05 22:17:11	2020-03-05	Hervey Buckridge	hervey.buckridge@geemail.com	San Francisco	California	4415723736844933	1e7c3536b9fba23cfb129bdf4200870a	VISA 13 digit	37.7762146240043037	-122.378577243200525
14529	2020-03-05 22:18:02	2020-03-05	Phoebe Turner	phoebe.turner@warmmail.com	Fontana	California	869909652570558394	1febd850bc750722eac3640b2339a22a	JCB 16 digit	34.0579935484249177	-117.48815523449295
14530	2020-03-05 22:25:56	2020-03-05	Miss Bethann Cassin PhD	miss.bethann.cassin.phd@geemail.com	Oceanside	California	3051614761428256	ddf8c1b6ced4c9300a8b563f642a3bfc	VISA 13 digit	33.2282320748902862	-117.235764858879904
14531	2020-03-05 22:26:22	2020-03-05	Leon Runolfsdottir	leon.runolfsdottir@woohoo.com	San Francisco	California	3528716038014333483	38021478d93f33011bb97be1f1dab1cc	Discover	37.78473445318442	-122.392522477355143
14532	2020-03-05 22:26:34	2020-03-05	Myah Wolf MD	myah.wolf.md@geemail.com	Santa Rosa	California	4505786534188	2dbc8be45495e1db5271fad1c2954a04	Voyager	38.3491491352796601	-122.721663033940274
14533	2020-03-05 23:14:35	2020-03-05	Trudy Howell	trudy.howell@geemail.com	Mobile	Alabama	3112408109389711968	95513d26acddb3257872195417db43cc	Diners Club / Carte Blanche	30.7323852159656568	-88.0826782778043338
14534	2020-03-05 23:19:02	2020-03-05	Kristopher Kunde	kristopher.kunde@geemail.com	Torrance	California	52165615970088684	f9a58f950dd9323542137eaf818e0129	Maestro	33.9117641842365245	-118.417407615588601
14535	2020-03-05 23:31:46	2020-03-05	Milburn Schoen	milburn.schoen@geemail.com	Cincinnati	Ohio	51565500450113465	e23885e3787de1ce9c6a7f7aff37f8e7	JCB 16 digit	39.0697040276832865	-84.5184839901320544
14536	2020-03-05 23:32:50	2020-03-05	Dominque King MD	dominque.king.md@geemail.com	Temecula	California	869931802876858566	c15df86549de7811796be809b4a85a5b	VISA 13 digit	33.5613647299487141	-117.095499304421992
14537	2020-03-05 23:34:27	2020-03-05	Garrett Kassulke	garrett.kassulke@geemail.com	New York	New York	639056375374727	9a9a3eb84aa523a87adadd6db4d0cdf9	Maestro	40.6871874369904418	-73.9587819661840769
14538	2020-03-05 23:40:48	2020-03-05	Dr. Shelly Goldner	dr.shelly.goldner@geemail.com	Torrance	California	4476120043916	412b360ed3d33134b8f7b054f5fc9b92	JCB 16 digit	33.8122938681766385	-118.252181375784417
14539	2020-03-05 23:58:03	2020-03-05	Mr. Sie Fahey II	mr.sie.fahey.ii@geemail.com	Detroit	Michigan	6011429952804733850	e1514cf4ec20a5f2ed826ba011a3907a	JCB 16 digit	42.4281564816292374	-83.1062800800547024
14540	2020-03-06 00:02:18	2020-03-06	Amir Carroll	amir.carroll@geemail.com	Miami	Florida	3158686714196830936	360f7762926359a854449e532402caa0	Maestro	25.7006709231667223	-80.152750776509194
14541	2020-03-06 00:17:54	2020-03-06	Easton Denesik	easton.denesik@geemail.com	Colorado Springs	Colorado	4811174549272229	ac6216825dc6925ea06989fdabf345cf	Diners Club / Carte Blanche	38.8361993138261141	-104.820614201265201
14542	2020-03-06 00:22:37	2020-03-06	Jethro Cruickshank	jethro.cruickshank@woohoo.com	San Diego	California	4709839147368596	8e49682bdbddf6709983371a0f57aa00	Discover	32.8707415498394511	-117.105529147423809
14543	2020-03-06 00:24:39	2020-03-06	Adalyn Mante-Gerhold	adalyn.mante.gerhold@geemail.com	Oklahoma City	Oklahoma	3027626548288377	c00044f3de8e0cdb5a9e2ebf57514c93	VISA 13 digit	35.4228054022792733	-97.5360992663435695
14544	2020-03-06 00:24:59	2020-03-06	Mitchell Treutel-Lemke	mitchell.treutel.lemke@geemail.com	Tampa	Florida	4534229297133050	4a48531400fbcff0e74d0a66279b6ce4	VISA 13 digit	27.8721856815855951	-82.5164802811786444
14545	2020-03-06 00:35:43	2020-03-06	Ms. Pluma Koss	ms.pluma.koss@geemail.com	Colorado Springs	Colorado	3112808947289522563	55962173ec3eb7d868277770c4423666	VISA 16 digit	38.8596378293402509	-104.690162436027819
14546	2020-03-06 00:35:44	2020-03-06	Jayme Grant	jayme.grant@geemail.com	San Francisco	California	3791553591439276	836e4762738626584402a93b1455c523	JCB 16 digit	37.8175739553006878	-122.414017689003757
14547	2020-03-06 00:47:58	2020-03-06	Celena Sawayn	celena.sawayn@geemail.com	Lewisville	Texas	3780453768697629	5f816ed2d45b646b919b85c6eb7b1ee6	Discover	32.9944143112268264	-96.9484461922228462
14548	2020-03-06 00:50:20	2020-03-06	Gibson Kirlin	gibson.kirlin@woohoo.com	Omaha	Nebraska	3528849583828226845	b38dd153c31c250b78fb272eac246d71	VISA 16 digit	41.3515274281758849	-95.9818899332195627
14549	2020-03-06 01:09:51	2020-03-06	Desirae Moen	desirae.moen@geemail.com	San Francisco	California	3088736721445457767	f606be835f4c438d2f9c4fc6927165e4	Discover	37.7952969008803024	-122.424053481727526
14550	2020-03-06 01:10:55	2020-03-06	Darin Dooley-Douglas	darin.dooley.douglas@woohoo.com	Miami Gardens	Florida	180087880632030962	b307182e1312879f9851437bcd2db982	Voyager	25.8623431281592673	-80.275482782047618
14551	2020-03-06 01:13:50	2020-03-06	Ms. Alla Carroll PhD	ms.alla.carroll.phd@warmmail.com	Las Cruces	New Mexico	589388244716267	2f51311c6b8476b828b3500f1e208533	JCB 16 digit	32.2405232582740453	-106.831343030848345
14552	2020-03-06 01:14:27	2020-03-06	Marleen Strosin	marleen.strosin@geemail.com	Miami Gardens	Florida	3760203627851378	de09c448b1c66f3f37523cf362248185	Maestro	25.8626117393314807	-80.2166828059371539
14553	2020-03-06 01:37:17	2020-03-06	Reagan Bashirian-Zemlak	reagan.bashirian.zemlak@geemail.com	Denver	Colorado	4827658799442112	0a5454f4677e0052864e552f2b8364bc	JCB 15 digit	39.783126147562264	-104.822046608316157
14554	2020-03-06 02:33:36	2020-03-06	Mr. Hadley Marquardt	mr.hadley.marquardt@woohoo.com	Chicago	Illinois	3528502808129483045	073227ba0b085dddc869e7e1c86129fa	Mastercard	41.8745878679513979	-87.6868794494338317
14555	2020-03-06 02:33:46	2020-03-06	Dr. Epifanio Marks	dr.epifanio.marks@geemail.com	Fargo	North Dakota	54457075274855220	048aa1f86c89fd4fad1a69ffe230fec6	JCB 15 digit	46.7814172848824441	-96.8702134116981171
14556	2020-03-06 02:47:07	2020-03-06	Dr. Rhiannon Blick	dr.rhiannon.blick@woohoo.com	Phoenix	Arizona	3088966715596404363	eb9d210d03ef850cf090f224b9d196f6	Diners Club / Carte Blanche	33.6362897215344034	-112.183120686507237
14557	2020-03-06 02:53:13	2020-03-06	Lesley Bechtelar	lesley.bechtelar@geemail.com	Montgomery	Alabama	55437712453013925	f7f779acad867d5be89114ad78bfa9fb	VISA 16 digit	32.2625373754117675	-86.2668511528208768
14558	2020-03-06 03:09:25	2020-03-06	Andreas Rutherford	andreas.rutherford@woohoo.com	San Francisco	California	180068435159420436	e5c647d3b7bae53b40fb311a9768f5b6	American Express	37.7547448886141837	-122.436711126398251
14559	2020-03-06 03:29:20	2020-03-06	Ms. Ivory Corkery	ms.ivory.corkery@geemail.com	San Francisco	California	060437669304372	845322424af9a8099efb3e99206d1996	VISA 13 digit	37.8123381981102611	-122.429476836525112
14560	2020-03-06 03:31:44	2020-03-06	Dessie Turner	dessie.turner@geemail.com	Jersey City	New Jersey	589398877086896	d1e6b259e945dfa478d3a3313d70d651	JCB 16 digit	40.7248991379920398	-74.0053559221282597
14561	2020-03-06 03:32:15	2020-03-06	Timmie Bauch	timmie.bauch@geemail.com	Bakersfield	California	6011343892998874057	dcb799d9ce0d815feeff80dcfa30dee7	JCB 16 digit	35.3007320340432216	-119.08107075558901
14562	2020-03-06 03:40:30	2020-03-06	Ham Gorczany	ham.gorczany@warmmail.com	Oakland	California	4367260129577554	be65481bf428242dab2ec1147570d4a2	JCB 16 digit	37.8308578047284243	-122.25791335736551
14563	2020-03-06 04:02:26	2020-03-06	Mr. Markus Connelly	mr.markus.connelly@woohoo.com	Topeka	Kansas	3112411097282976678	7bfd5cb317d59a1e137f01854fc2dce3	VISA 16 digit	39.0483215808801347	-95.713565792812787
14564	2020-03-06 04:06:50	2020-03-06	Karyn Brakus	karyn.brakus@woohoo.com	Scottsdale	Arizona	180030966742997949	1fa525f0ce3723ec13eb6ac10733b2dd	JCB 16 digit	33.6347719274584236	-111.84291079435161
14565	2020-03-06 04:09:23	2020-03-06	Brendon Brekke	brendon.brekke@geemail.com	New York	New York	4960438517719977	9153ce0b1c112e2047778816fd18e779	Discover	40.5707419153060727	-73.9352481348801405
14566	2020-03-06 04:26:53	2020-03-06	Kristen Quitzon	kristen.quitzon@geemail.com	Surprise	Arizona	3031075615929388	9acc74168d78de84004afe8e298dc5b8	American Express	33.6546301595628279	-112.441015319921817
14567	2020-03-06 04:34:08	2020-03-06	Jamar Corwin	jamar.corwin@geemail.com	Frisco	Texas	869998208014195699	984392d49f0cfb68000b8bb1c369d85b	VISA 16 digit	33.106085403728855	-96.9037918786726777
14568	2020-03-06 04:39:02	2020-03-06	Twila Ferry	twila.ferry@woohoo.com	Oakland	California	3754231294971771	3ebdcbb6a207cb335ccf7240b36dfe03	Maestro	37.8019284769344281	-122.281245843826056
14569	2020-03-06 04:41:01	2020-03-06	Hana Rath-Moen	hana.rath.moen@geemail.com	San Francisco	California	3158268468046603466	fba816232488f191b0d294366d2eeb31	Voyager	37.7670179478960861	-122.436090839399384
14570	2020-03-06 04:46:42	2020-03-06	Reece Lindgren-Schumm	reece.lindgren.schumm@warmmail.com	San Francisco	California	3528800128742435671	40345ddbe3e118e04e6af4172670870d	American Express	37.7852192784262826	-122.430937278474261
14571	2020-03-06 05:15:17	2020-03-06	Derick Stamm	derick.stamm@woohoo.com	Frisco	Texas	3088472810690727822	056e1246583cab91f909f78df13a732e	JCB 15 digit	33.1305972601749019	-96.7944608076218458
14572	2020-03-06 05:28:08	2020-03-06	Nicolas Nitzsche	nicolas.nitzsche@warmmail.com	San Francisco	California	180061350884750626	b304e3c187103eb4d92063a8a475f9c5	Maestro	37.8144676239923641	-122.416403741480238
14573	2020-03-06 05:32:31	2020-03-06	Mell Morar	mell.morar@geemail.com	San Francisco	California	3337873320568222976	9907024e7d9a14ba5b27f6cd91c598b0	VISA 16 digit	37.7871300162718313	-122.430687758863499
14574	2020-03-06 05:42:16	2020-03-06	Azaria Ortiz MD	azaria.ortiz.md@geemail.com	Las Vegas	Nevada	210086461422708165	1b7050f5a24b043fc8702d01f644610a	VISA 16 digit	36.2796602380562589	-115.227477802962426
14575	2020-03-06 06:12:02	2020-03-06	Deangelo Dicki II	deangelo.dicki.ii@geemail.com	Jacksonville	Florida	4920817390321416	2b59fda91d7b8a5e4e3f188a42dd01fc	Mastercard	30.3020635913178324	-81.7195093412961882
14576	2020-03-06 06:12:16	2020-03-06	Mrs. Blanca Marquardt PhD	mrs.blanca.marquardt.phd@geemail.com	Raleigh	North Carolina	676234978357266	ec01a8f0baead8da021c11a735f482ad	Mastercard	35.7496275847911775	-78.6315834939882166
14577	2020-03-06 06:15:17	2020-03-06	Jayson Predovic	jayson.predovic@warmmail.com	San Jose	California	4273727556907028	0c42508130fc9b6b825a089de148bfeb	JCB 16 digit	37.2409716798745123	-121.844690055515244
14578	2020-03-06 06:20:39	2020-03-06	Christal Hills	christal.hills@warmmail.com	San Francisco	California	3088968023904553007	89c88af006d5b0d7ed5317c4168dff0a	VISA 16 digit	37.7773856536069133	-122.425341334605918
14579	2020-03-06 06:37:06	2020-03-06	Ms. Susanna Kuhlman DVM	ms.susanna.kuhlman.dvm@geemail.com	Santa Ana	California	51818415858070776	0b1f26c94caafe4da20c91b68945440d	Maestro	33.639271998369324	-117.873539881354191
14580	2020-03-06 06:42:58	2020-03-06	Dr. Claus Koelpin	dr.claus.koelpin@geemail.com	Richmond	Virginia	869904141264105329	c04cd6cd71496b2ce9532f0f6744a506	VISA 16 digit	37.4888242013506598	-77.4655819282624805
14581	2020-03-06 06:53:47	2020-03-06	Dr. Kael Brekke PhD	dr.kael.brekke.phd@geemail.com	Yonkers	New York	6011274295341664360	9cfabfde379c1c557011d2637bc2b25d	JCB 16 digit	41.0271768284697131	-73.8176644508611446
14582	2020-03-06 07:10:51	2020-03-06	Ida Farrell	ida.farrell@woohoo.com	New York	New York	3088946597622623314	92472b244cc54aaf3aa228edb832250c	JCB 15 digit	40.7068913370128698	-73.9036992805439894
14583	2020-03-06 07:19:01	2020-03-06	Joetta Lemke	joetta.lemke@geemail.com	San Francisco	California	589349958848332	c1254832120206310ac723a79ae9e61a	American Express	37.7712289334824902	-122.39276609930333
14584	2020-03-06 07:36:03	2020-03-06	Ms. Verdie Boehm	ms.verdie.boehm@geemail.com	New York	New York	3480156910780769	ec6eaaa09de85b6e955210cd1539ac42	Maestro	40.6984563158117254	-73.9741554966092139
14585	2020-03-06 07:38:24	2020-03-06	Myrl Toy	myrl.toy@geemail.com	San Francisco	California	3763264451529990	b97ae7c443e0bf4b7a6c2e2853268d79	JCB 16 digit	37.7683542375988281	-122.433961963115181
14586	2020-03-06 07:45:19	2020-03-06	Nicholas Kreiger MD	nicholas.kreiger.md@warmmail.com	Oakland	California	3006504816500800	8ca17d3afecbad906969bf6588fe022f	VISA 16 digit	37.8135315518423027	-122.285347181395693
14587	2020-03-06 07:56:17	2020-03-06	Cassidy Rau	cassidy.rau@geemail.com	Philadelphia	Pennsylvania	4098436485395098	eedd74430794e496c06e907be65db45b	Maestro	39.9381578831892483	-75.1491701970707737
14588	2020-03-06 08:50:45	2020-03-06	Marcelo Kassulke	marcelo.kassulke@geemail.com	Plano	Texas	639098295802650	c229e292ed316df873021988334ee469	JCB 15 digit	32.98434833358899	-96.7782434122353834
14589	2020-03-06 08:54:27	2020-03-06	Autry Ziemann	autry.ziemann@geemail.com	Jurupa Valley	California	6011125367673890581	073f5f70709f85347b7248660693188f	VISA 16 digit	33.9078251313813013	-117.554815613946317
14590	2020-03-06 08:56:01	2020-03-06	Weaver Gerhold	weaver.gerhold@geemail.com	Albuquerque	New Mexico	3707023406377395	54871b1e04bcfcdca2c1f0b9185b5b05	Diners Club / Carte Blanche	35.1277254071220781	-106.685618004629021
14591	2020-03-06 09:04:04	2020-03-06	Mr. Raven Becker	mr.raven.becker@warmmail.com	Dallas	Texas	52815374024497392	5a85fd8706103c7a0c26647326f134f5	JCB 16 digit	32.8609108306739515	-96.8478720102887536
14592	2020-03-06 09:16:23	2020-03-06	Dewey Howe	dewey.howe@geemail.com	San Diego	California	3454186544210430	e257ab5a825bd87df67ed7eb1ce82ee8	American Express	32.8394634853184257	-117.203170670140537
14593	2020-03-06 09:19:01	2020-03-06	Claudia Emard	claudia.emard@geemail.com	Berkeley	California	3096270265454882863	778f22ede8178ece57f82a2886aca0e2	Discover	37.8353126410454195	-122.281521754872088
14594	2020-03-06 09:19:15	2020-03-06	Mr. Rahsaan Schinner	mr.rahsaan.schinner@warmmail.com	San Francisco	California	210041888241901288	5ff8b59ab3a54a5d8f5f613f2a49e585	JCB 16 digit	37.7615259548666202	-122.447820961887047
14595	2020-03-06 09:38:09	2020-03-06	Ms. Demi Purdy PhD	ms.demi.purdy.phd@warmmail.com	North Las Vegas	Nevada	3752509023861914	251dcd8d5206f228b4c76f0dcb12a5bd	VISA 16 digit	36.2436729441087664	-115.003722439122953
14596	2020-03-06 09:53:58	2020-03-06	Luther Windler	luther.windler@geemail.com	New York	New York	4368628304460490	e483a74f94e4ce3b73dd76b4e6cdac1b	JCB 15 digit	40.7608481302149599	-73.9325989161048085
14597	2020-03-06 09:58:26	2020-03-06	Elouise Nitzsche DVM	elouise.nitzsche.dvm@warmmail.com	New York	New York	180023045745475069	b72968f7d35da2f90186662202575d12	Mastercard	40.6351242509894064	-74.0048160235758843
14598	2020-03-06 10:07:01	2020-03-06	Manuelita Wolf	manuelita.wolf@geemail.com	Albuquerque	New Mexico	869914357091769297	5a5b0fc4469c57c992ee32fef674e50a	VISA 16 digit	35.0860610250517766	-106.679439117626856
14599	2020-03-06 10:10:37	2020-03-06	Tiffanie Kuhlman	tiffanie.kuhlman@warmmail.com	Louisville	Kentucky	4105224449072743	85668c997c943920b97da57f1385b426	American Express	38.0851334764990952	-85.7385220296751811
14600	2020-03-06 10:11:46	2020-03-06	Mariel Bins	mariel.bins@geemail.com	Columbus	Ohio	210006628079994598	23c78e6d3344673340c33075a7b4430c	VISA 13 digit	39.894724696739388	-82.9983064973961575
14601	2020-03-06 10:34:26	2020-03-06	Waverly Rau	waverly.rau@warmmail.com	San Francisco	California	52900770452823759	43969843d08d93f50df510a56d196867	VISA 16 digit	37.7739487752461898	-122.465641656190769
14602	2020-03-06 10:36:47	2020-03-06	Dr. Remington Connelly DDS	dr.remington.connelly.dds@woohoo.com	Fontana	California	869912528088741661	470bcab9d1691ddb4816822fe2869ece	Diners Club / Carte Blanche	34.0381734816506523	-117.38255887607076
14603	2020-03-06 10:48:03	2020-03-06	Fuller Glover	fuller.glover@geemail.com	San Francisco	California	4936407943558672	957fd4c809ee647e4529056844e671cc	VISA 16 digit	37.7775000868962678	-122.420958737690768
14604	2020-03-06 10:56:08	2020-03-06	Martina Ruecker DVM	martina.ruecker.dvm@warmmail.com	Oakland	California	3337855337604674939	6caf99ea9489007cd8513b7608d0f1ff	VISA 13 digit	37.8280380840294868	-122.2587337581013
14605	2020-03-06 11:00:15	2020-03-06	Burnell Bogisich DVM	burnell.bogisich.dvm@warmmail.com	Minneapolis	Minnesota	3337114400227146870	013e7d8e43f003a266054dc19276501d	American Express	45.0392062719065649	-93.1879130321361089
14606	2020-03-06 11:34:09	2020-03-06	Cicero Rohan PhD	cicero.rohan.phd@geemail.com	Hialeah	Florida	639033564734755	3bf2bad9e2685706608edb1a6db3ecae	Discover	25.7900401454862234	-80.2643985007326961
14607	2020-03-06 11:46:09	2020-03-06	Miss Jackie Sporer PhD	miss.jackie.sporer.phd@geemail.com	Sterling Heights	Michigan	210025685088361869	78d1de0f028cd6118cfeed1740f7c0e3	Maestro	42.5643554604228598	-83.0604315394230213
14608	2020-03-06 11:49:43	2020-03-06	Ham Rath PhD	ham.rath.phd@geemail.com	Plano	Texas	180061525273011462	beaa3da62889d23d85ef97f82e98f2fa	VISA 16 digit	33.0508810651108647	-96.6846714384105042
14609	2020-03-06 11:57:49	2020-03-06	Miss Sabra Aufderhar	miss.sabra.aufderhar@geemail.com	Detroit	Michigan	3158307215533456541	550b1a94985ac87d0a333579f02c0443	VISA 16 digit	42.4645275913104427	-83.0284933392543252
14610	2020-03-06 12:10:41	2020-03-06	Grady Ebert	grady.ebert@geemail.com	Riverside	California	3112772100199631833	2cac4203ba39ca1056a2489f347eeae4	Voyager	33.9377165462303907	-117.455387987985077
14611	2020-03-06 12:12:28	2020-03-06	Dr. Karissa Emard DVM	dr.karissa.emard.dvm@geemail.com	Colorado Springs	Colorado	869975809705725020	ec28f7afefb57754233169bd724dad34	Voyager	38.8363055720508115	-104.767382620430368
14612	2020-03-06 12:19:21	2020-03-06	Jocelyne Carter-Murazik	jocelyne.carter.murazik@geemail.com	Chesapeake	Virginia	3412819213087843	a44db7af9c5d679cf8464be621469e6c	Maestro	36.6239943735074291	-76.3605803808972183
14613	2020-03-06 12:29:14	2020-03-06	Mr. Chadwick Wisozk PhD	mr.chadwick.wisozk.phd@woohoo.com	New York	New York	4338995547241	6587212a1e89d6590e6730df08893ff0	VISA 16 digit	40.6152359547317019	-73.9068544237770055
14614	2020-03-06 12:54:51	2020-03-06	Autumn Lind MD	autumn.lind.md@geemail.com	Los Angeles	California	55138395672420923	4e7e217d1c0106a0ceed5ef80de43209	Mastercard	34.118913931665567	-118.387245962488649
14615	2020-03-06 12:56:07	2020-03-06	Trena Leannon	trena.leannon@woohoo.com	Denver	Colorado	3158328642067894612	bc415b77084190ae03f131d2b9778c77	VISA 16 digit	39.7344049200467708	-104.828602685617653
14616	2020-03-06 13:08:23	2020-03-06	Syble Tillman	syble.tillman@woohoo.com	San Francisco	California	3746065044028867	00b05b600e19e9ff2ca1c1ae46aed1d8	Discover	37.7686649674639625	-122.411363770879717
14617	2020-03-06 13:09:32	2020-03-06	Dorinda Schneider	dorinda.schneider@warmmail.com	Arvada	Colorado	4011793980571	d2fca22f8a442873e7c41c5dbbb5c7f8	VISA 16 digit	39.8862139582343431	-105.069340587171908
14618	2020-03-06 13:45:15	2020-03-06	Johanna Schoen PhD	johanna.schoen.phd@geemail.com	San Diego	California	53157231944289505	850cf8f5d484b044d5424235b289c55f	JCB 16 digit	32.755518813577666	-117.04570029847325
14619	2020-03-06 13:45:29	2020-03-06	Miguelangel Renner	miguelangel.renner@woohoo.com	San Francisco	California	4977940567661	6e55ccdcade261c3eb5a186f6cdbc7db	American Express	37.7466184109790248	-122.408119325061364
14620	2020-03-06 13:52:49	2020-03-06	Miss Stephani Hessel	miss.stephani.hessel@geemail.com	Baltimore	Maryland	180044294963240384	b5e80c1a56a22085dd19c51e3d24d2ef	VISA 16 digit	39.2659971964545491	-76.5500169722381969
14621	2020-03-06 13:57:07	2020-03-06	Dr. Saul Williamson	dr.saul.williamson@geemail.com	Pasadena	Texas	869991591793287556	2f332908796401e8b1bd7d67bb9ac4fd	JCB 16 digit	29.6378958230245857	-95.1496343435667455
14622	2020-03-06 14:05:42	2020-03-06	Winthrop Feest	winthrop.feest@geemail.com	Oakland	California	3057060509932023	5852152034b0aa7d567618b5f3e0ab7e	Maestro	37.789516909316589	-122.259126343431845
14623	2020-03-06 14:08:37	2020-03-06	Arron Hartmann	arron.hartmann@geemail.com	Elk Grove	California	3088528401170780442	ecf253a2f0a6a02dadeb0e9ccad53257	VISA 16 digit	38.4314835103046164	-121.288685062145817
14624	2020-03-06 15:06:09	2020-03-06	Shyheim Nikolaus	shyheim.nikolaus@geemail.com	San Francisco	California	6011311112661293685	442df939a770189d7de5dec8c2030a57	Voyager	37.7486818348582105	-122.436840906144994
14625	2020-03-06 15:10:06	2020-03-06	Deven Botsford	deven.botsford@geemail.com	Nashville	Tennessee	4642965434607	6921b684a2cbb81a72e5de41ace04ac4	VISA 16 digit	36.1336593154940715	-86.7354354317672573
14626	2020-03-06 15:11:38	2020-03-06	Mr. Giuseppe Zboncak	mr.giuseppe.zboncak@geemail.com	Davie	Florida	54690590743946340	c448fdbbd694c2bd98bc707cce0e2c48	Mastercard	26.0089450446221981	-80.3278839164785978
14627	2020-03-06 15:34:05	2020-03-06	Dr. Wellington Hand	dr.wellington.hand@geemail.com	Savannah	Georgia	3158832933305561207	eb033975b204cd4b2e78ac68132960eb	JCB 15 digit	32.0482879637367972	-81.0827893088724494
14628	2020-03-06 15:43:28	2020-03-06	Thyra Gislason-Stanton	thyra.gislason.stanton@geemail.com	San Francisco	California	3528182741437240426	f5b8c08763f7f4b54ad6452b06a4805c	JCB 16 digit	37.7925865741855489	-122.431694933350684
14629	2020-03-06 16:11:51	2020-03-06	Mr. Ozie Roob	mr.ozie.roob@warmmail.com	Killeen	Texas	3158868798520042961	49561298a2ad23a557bd80fd9785dce0	American Express	31.0809050027046361	-97.7152978994119934
14630	2020-03-06 16:14:30	2020-03-06	Marlyn Schamberger-Kuphal	marlyn.schamberger.kuphal@geemail.com	Sparks	Nevada	4606629448755136	9c31f8b2713d2491ab96bc0a3d6d3d26	Diners Club / Carte Blanche	39.5643685259629052	-119.811485854847732
14631	2020-03-06 16:27:00	2020-03-06	Toney Kassulke	toney.kassulke@geemail.com	Mesa	Arizona	869958771015983668	33ac5c28019a056b53edf357f0036c0b	JCB 15 digit	33.3128899667091645	-111.764435707207397
14632	2020-03-06 16:50:41	2020-03-06	Raphael Stamm	raphael.stamm@geemail.com	New York	New York	3798962799909936	151133dbc0151ea4f2ac8694548b4798	VISA 16 digit	40.6683248898703624	-73.9159166572511168
14633	2020-03-06 17:16:41	2020-03-06	Sal Corkery	sal.corkery@geemail.com	Miami	Florida	4331192664250755	10fe001006f79858c9283d3b9b94dae6	Discover	25.757038798709214	-80.2219989063557222
14634	2020-03-06 17:26:33	2020-03-06	Janet McClure	janet.mcclure@geemail.com	Laredo	Texas	639023465942789	8427bc5c9eaf4f3130adfb4cb8a0455e	JCB 16 digit	27.4755164650917081	-99.4336287362974076
14635	2020-03-06 17:33:06	2020-03-06	Isadore Marquardt	isadore.marquardt@geemail.com	Houston	Texas	675957346883325	fee7f82b44ec10411f23ec2bd9eafebd	Mastercard	29.788815758292003	-95.4796493340764272
14636	2020-03-06 17:45:28	2020-03-06	Payten Kreiger	payten.kreiger@geemail.com	Mesa	Arizona	3463172784185168	e358562aa92746d7e34c2dffae91a711	Voyager	33.3288003937952197	-111.659732684854049
14637	2020-03-06 17:53:42	2020-03-06	Mrs. Tina Conroy PhD	mrs.tina.conroy.phd@geemail.com	Houston	Texas	3765324899932236	d5b2d443c56163d1f976e81b9f8f66d4	Maestro	29.8444756367322057	-95.3496250704877042
14638	2020-03-06 18:00:26	2020-03-06	Anderson Feest	anderson.feest@geemail.com	San Diego	California	3047682013360894	69b47fdad59f089487764a9a5dbc0c11	American Express	32.7296166886176891	-117.131136461431169
14639	2020-03-06 18:18:06	2020-03-06	Fount Schoen	fount.schoen@geemail.com	Chula Vista	California	3425134895517355	29f10e39fae1e4755ab06a7599355c94	American Express	32.5429245996519896	-117.007446316885563
14640	2020-03-06 18:30:04	2020-03-06	Carey Kerluke	carey.kerluke@woohoo.com	San Antonio	Texas	3112297648387997594	528f8788535273f899ad666f7eee82a7	VISA 13 digit	29.4184141769144674	-98.509220817435903
14641	2020-03-06 18:35:10	2020-03-06	Taj Will II	taj.will.ii@woohoo.com	San Francisco	California	4602809650586	f6f69a86d625cadcb24e881887af123f	Mastercard	37.7554734426109917	-122.435404832886164
14642	2020-03-06 18:58:52	2020-03-06	Wilford Rippin	wilford.rippin@geemail.com	San Francisco	California	4692076094402	a03e2f519ed203c2e4db0bf2f835f867	Voyager	37.7525013372186677	-122.437413244147038
14643	2020-03-06 19:15:11	2020-03-06	Mr. Dane Moen IV	mr.dane.moen.iv@woohoo.com	Fremont	California	503814417906113	01b22243c3b2422e6aa497f80a5d6831	Mastercard	37.4568853976372651	-121.99976725182384
14644	2020-03-06 19:37:45	2020-03-06	Nikolas Crist	nikolas.crist@geemail.com	Pompano Beach	Florida	3026575040301801	3634e212e8e589f54004ad815d83472c	JCB 16 digit	26.182752508417142	-80.1733140106625797
14645	2020-03-06 19:40:51	2020-03-06	Lelia Parisian DDS	lelia.parisian.dds@woohoo.com	San Francisco	California	3528022734038279590	c2504e02a9b3c16ba5103ed400ec1f7f	Mastercard	37.7708555455714077	-122.405996173192008
14646	2020-03-06 19:53:43	2020-03-06	Zeta Glover	zeta.glover@geemail.com	Reno	Nevada	630461254725767	b4a1e35ac11e43d5cbc049b8c622541c	VISA 16 digit	39.6115664301052703	-119.81445283635297
14647	2020-03-06 20:16:04	2020-03-06	Demetrios Herman	demetrios.herman@geemail.com	San Diego	California	51390973798595597	232c485789716cb3b7f18513bc693f4c	VISA 16 digit	32.8904204505562774	-117.166572034209977
14648	2020-03-06 20:22:14	2020-03-06	Ms. Elmyra Roob	ms.elmyra.roob@geemail.com	Philadelphia	Pennsylvania	180008569044782890	0543c88f702dce92c5f2abc461451682	VISA 13 digit	40.0806125956080876	-75.0432743766244528
14649	2020-03-06 20:41:28	2020-03-06	Bradford Kulas	bradford.kulas@geemail.com	Thornton	Colorado	180015147991616543	f3c5c401102259c6c541e46a78b535d2	Discover	39.9396630993910193	-104.846727631350234
14650	2020-03-06 20:42:19	2020-03-06	Lucien Auer	lucien.auer@geemail.com	Corpus Christi	Texas	4582863174963683	401868b60d54bcb5d85665a08c109c8f	JCB 16 digit	27.7523437588412314	-97.2376654201015782
14651	2020-03-06 20:46:17	2020-03-06	Hudson Ankunding	hudson.ankunding@warmmail.com	Winston–Salem	North Carolina	3029653291713953	d3f5269ed89739c7edb3c7c77e7492cb	Discover	36.1066007262792397	-80.1634017037823696
14652	2020-03-06 20:50:57	2020-03-06	Dejuan Rempel	dejuan.rempel@geemail.com	Oakland	California	52585140243788160	345c6cef2b859697c0dea5ed1cf112fb	VISA 16 digit	37.8378974899635878	-122.289663177137726
14653	2020-03-06 21:01:31	2020-03-06	Hosea Grant	hosea.grant@geemail.com	Peoria	Illinois	3019944347860058	e306d8c73544a6b6bcf2fbaca062e08e	Mastercard	40.8138377032577964	-89.5905797638814931
14654	2020-03-06 21:27:19	2020-03-06	Mechelle Gleason	mechelle.gleason@woohoo.com	New York	New York	4652064802704012	c4f0eda2226591a42d846ce7e0774f39	VISA 13 digit	40.7307111976426057	-73.9037797429494532
14655	2020-03-06 21:37:36	2020-03-06	Golden Rogahn I	golden.rogahn.i@woohoo.com	New York	New York	3765154753272803	43bed895831fecc850dafb4ca8cd25cd	JCB 16 digit	40.6189326380137317	-73.873657179008049
14656	2020-03-06 21:38:03	2020-03-06	Malcom Lubowitz	malcom.lubowitz@geemail.com	Oceanside	California	4388418530415	e2b0f8cbf0cfaf1df344c937e5fd6453	JCB 16 digit	33.3061963858436769	-117.237361040486775
14657	2020-03-06 21:50:41	2020-03-06	Caprice Considine	caprice.considine@woohoo.com	Aurora	Illinois	3112205151031031648	801d69c8120e112fc8ea17e497a4dd5a	Discover	41.847445490559565	-88.2649751848936006
14658	2020-03-06 22:09:12	2020-03-06	Sylvia Jenkins	sylvia.jenkins@woohoo.com	Fort Lauderdale	Florida	54150310237366084	daf36e6b7a0cce3d64e93ab9eecb44e2	JCB 15 digit	26.0448176179535693	-80.1656805422909571
14659	2020-03-06 22:34:41	2020-03-06	Darrick Kilback	darrick.kilback@geemail.com	Phoenix	Arizona	54675869220725313	2f8014d803a874dec476e8e8ce99e6f0	VISA 16 digit	33.5449344721090057	-112.055874107072512
14660	2020-03-06 22:36:04	2020-03-06	Marilyn Koelpin	marilyn.koelpin@geemail.com	Portland	Oregon	3088916126536482041	9d263a082935a52b10d9baecea91a114	VISA 13 digit	45.463519668661057	-122.640041475836199
14661	2020-03-06 22:47:09	2020-03-06	Laverna Spencer-Reilly	laverna.spencer.reilly@geemail.com	San Francisco	California	4260261283630286	ce5ee0059730f720d7ac1136b50c1cc3	Maestro	37.7704268794555489	-122.438550102535856
14662	2020-03-06 22:47:47	2020-03-06	Florencio Smitham DDS	florencio.smitham.dds@woohoo.com	San Francisco	California	3096100369378304743	41965653109dc1130117f6d12053969e	JCB 16 digit	37.7596973917065242	-122.407066811113097
14663	2020-03-06 22:59:27	2020-03-06	Arba Shields	arba.shields@geemail.com	Denver	Colorado	4417757512939150	099abdb8744dd3b3dbe6705e2ebfe46c	American Express	39.7519498588569462	-104.8663808136493
14664	2020-03-06 23:08:37	2020-03-06	Miss Aliyah Kohler	miss.aliyah.kohler@geemail.com	Raleigh	North Carolina	6011086493434995258	6a0eec75e64cf09c128d0ca7023bfb4d	VISA 16 digit	35.8225140363112047	-78.5609183701623266
14665	2020-03-06 23:14:51	2020-03-06	Ms. Jeanette D'Amore	ms.jeanette.d'amore@geemail.com	Seattle	Washington	51398241550202105	c778341be0f6c59ba5d5f0ff6ed2dbc4	American Express	47.6307334151510133	-122.305736893361058
14666	2020-03-06 23:22:24	2020-03-06	Alexis Rempel	alexis.rempel@geemail.com	San Francisco	California	869966396582754753	d3e7815c701ffb086d13b8aa153e4183	JCB 16 digit	37.7453673622959158	-122.44005449207819
14667	2020-03-06 23:35:56	2020-03-06	Abigail Ward	abigail.ward@geemail.com	Richmond	Virginia	3112466607201596938	d5a71e2da66b1b4705105d3ff70801b6	VISA 16 digit	37.5588071605876053	-77.3908986644577226
14668	2020-03-06 23:42:57	2020-03-06	Shawnda Hilpert-Turcotte	shawnda.hilpert.turcotte@geemail.com	Tallahassee	Florida	180044922178513209	ecd43faf64f55460453565656bb665c6	VISA 13 digit	30.5052277322880947	-84.3224252374857599
14669	2020-03-06 23:50:45	2020-03-06	Alyse Cremin	alyse.cremin@geemail.com	Nashville	Tennessee	676340398950820	b05d090125356744d9346178e7f7d990	Discover	36.0798144543200721	-86.8705201562400902
14670	2020-03-06 23:53:53	2020-03-06	Loretto Smitham	loretto.smitham@geemail.com	New York	New York	3479054224499502	c3dd90968b14612855b97a1e44965fcd	American Express	40.5649209864195441	-73.9913188519783347
14671	2020-03-06 23:58:58	2020-03-06	Mr. Fayette Goodwin	mr.fayette.goodwin@warmmail.com	Oakland	California	3158383298683434879	4637a717d0da6767c56bf7cde0c81127	American Express	37.8364157237966978	-122.255411188804672
14672	2020-03-07 00:06:32	2020-03-07	Deloris Wintheiser	deloris.wintheiser@geemail.com	New York	New York	3112319332987741439	c24e94c2e4d5f1c4a8e3534a8f33a2a9	Maestro	40.5714937562346449	-73.9406835623446881
14673	2020-03-07 00:18:48	2020-03-07	Gertrude Rodriguez	gertrude.rodriguez@geemail.com	San Francisco	California	3720915748410250	6c1385cea6be2b3d7d69067586c580cd	JCB 16 digit	37.7602257077723422	-122.439204036896513
14674	2020-03-07 00:29:10	2020-03-07	Mr. Aubrey Kertzmann	mr.aubrey.kertzmann@geemail.com	Elgin	Illinois	869991895763083113	015ed16222214d44e8033b91a70b91f9	American Express	42.0491607121475042	-88.2737213222131203
14675	2020-03-07 00:44:46	2020-03-07	Shannon Hilpert DVM	shannon.hilpert.dvm@geemail.com	New York	New York	501885276178796	e0666ea6d89cb324a5b337cba2ec3c51	Voyager	40.597344672143457	-73.9411752741213917
14676	2020-03-07 00:47:33	2020-03-07	Wilfrid Watsica	wilfrid.watsica@geemail.com	Bakersfield	California	589379692462066	b17ccc7f31142c60c31959ff537a2b4c	VISA 16 digit	35.35211193255968	-119.021730656250568
14677	2020-03-07 00:57:44	2020-03-07	Mr. Hughie Mante DDS	mr.hughie.mante.dds@geemail.com	Stockton	California	869923775870063930	90040fe56855452e98f69ec481177e17	Voyager	37.9561179661855093	-121.40995638585575
14678	2020-03-07 00:59:46	2020-03-07	Dr. Launa Leannon DVM	dr.launa.leannon.dvm@geemail.com	Baltimore	Maryland	3088637137859187990	6deee0a6085fb58b714969b146bd4e44	VISA 16 digit	39.3001237051095771	-76.6122638806719323
14679	2020-03-07 01:07:56	2020-03-07	Lindsey Schmidt-Mosciski	lindsey.schmidt.mosciski@geemail.com	San Francisco	California	3023545978542786	7b3b4a3401e743f499fad2de275132e4	JCB 16 digit	37.7454450348794026	-122.423419429328462
14680	2020-03-07 01:17:06	2020-03-07	Ms. Jessenia Reichel MD	ms.jessenia.reichel.md@warmmail.com	Denver	Colorado	6011248814914304288	7b492e11b19145e4c275bb786ad02619	Discover	39.7475009226757976	-104.956659889758015
14681	2020-03-07 01:53:08	2020-03-07	Emerson Kirlin MD	emerson.kirlin.md@geemail.com	San Francisco	California	3733954400143169	22a6a5b28c799ab2cc6484ae6a66d9bd	VISA 16 digit	37.8036299785527206	-122.439169312907978
14682	2020-03-07 01:57:40	2020-03-07	Azaria Larson	azaria.larson@geemail.com	Bakersfield	California	4061356157442809	c38bf5a875ba6800b69ce76ce9baeccb	Voyager	35.2765290368523452	-118.996833146576947
14683	2020-03-07 02:16:14	2020-03-07	Darien Schultz	darien.schultz@geemail.com	Modesto	California	639013222216114	76945976f6fccd24c3d11515f19214b0	VISA 13 digit	37.6413923304062337	-120.952212901666755
14684	2020-03-07 02:21:24	2020-03-07	Greyson Bins	greyson.bins@warmmail.com	Chicago	Illinois	4492735959537164	186fcb766a450994adef878c5e61f873	Diners Club / Carte Blanche	41.8799049882985699	-87.5873684905033514
14685	2020-03-07 02:23:24	2020-03-07	Jeryl Herzog DVM	jeryl.herzog.dvm@geemail.com	San Francisco	California	4247164048503	cbf761dadd7c1486c04c5a32b075e45d	Voyager	37.7894868407110849	-122.445286389723833
14686	2020-03-07 02:32:22	2020-03-07	Shardae Steuber	shardae.steuber@geemail.com	Arlington	Texas	3496595687738496	c598e5241e804004407145487f8cea8f	JCB 16 digit	32.6153227576769851	-97.096328037141646
14687	2020-03-07 02:57:39	2020-03-07	Mrs. Helen Von	mrs.helen.von@geemail.com	San Antonio	Texas	3528532693904463089	a0ba8027c89e9fb23baac48fa1babf42	Discover	29.4924280115474033	-98.6005779234994151
14688	2020-03-07 03:02:39	2020-03-07	Darryll Mraz	darryll.mraz@geemail.com	San Francisco	California	589395100430347	41d5b0c89a39e9cb5666967a4a3c3d70	American Express	37.7637456071890156	-122.464728942598995
14689	2020-03-07 03:21:47	2020-03-07	Azul Brown	azul.brown@geemail.com	San Francisco	California	4169207311546517	bf92c17b08455f07ef93a69265a37d47	JCB 15 digit	37.7465830822097459	-122.370212921485418
14690	2020-03-07 03:23:10	2020-03-07	Dr. Clovis Harris	dr.clovis.harris@geemail.com	Overland Park	Kansas	180067899914344069	b7ea0b3135478dab5a52f8008fb0dcd4	VISA 16 digit	38.8498324786648155	-94.7615632846526807
14691	2020-03-07 03:24:17	2020-03-07	Aldona Kozey	aldona.kozey@geemail.com	New York	New York	3112536161046456920	f9d8da945cbe124a2fdc4a1105fc5738	VISA 16 digit	40.7045394090227788	-74.0374040657084436
14692	2020-03-07 03:28:30	2020-03-07	Kristy Torp	kristy.torp@geemail.com	Providence	Rhode Island	210093071622381829	e089c49c935b2c389d0dee2a3526a612	Discover	41.8142344394553405	-71.3917125564917967
14693	2020-03-07 03:46:04	2020-03-07	Biddie Doyle MD	biddie.doyle.md@warmmail.com	San Francisco	California	6011946891627959462	884643f8e7af8f2013f379751bd8aea4	VISA 16 digit	37.7528953936133078	-122.437546388226849
14694	2020-03-07 04:00:17	2020-03-07	Cash Lockman	cash.lockman@woohoo.com	Hillsboro	Oregon	869933508519953072	6f9ca60a5cdedc1175df2fe77ce499d2	Discover	45.4532982348669279	-122.953499679981547
14695	2020-03-07 04:06:39	2020-03-07	Clemence Trantow I	clemence.trantow.i@warmmail.com	Fresno	California	6011315430848220884	9184da69061c6dac756e0fc138721006	Discover	36.8068007544953346	-119.731937618797275
14696	2020-03-07 04:26:06	2020-03-07	Karina Harber	karina.harber@geemail.com	San Diego	California	4656676146745330	db8094b5365ed77188b6e897685b41ed	JCB 15 digit	32.8328596651155493	-117.073233854109432
14697	2020-03-07 04:31:14	2020-03-07	Lydell Dickens IV	lydell.dickens.iv@warmmail.com	Fort Worth	Texas	3528788313869693387	ba9df0daed1ea9613d59dca28d5c5160	American Express	32.7711997794974579	-97.4044363101765498
14698	2020-03-07 04:32:29	2020-03-07	Bo Kunze-Schinner	bo.kunze.schinner@woohoo.com	San Jose	California	3409166836614669	f38cf2e17179c96b3258d0ae1603a23b	JCB 16 digit	37.2847768318194923	-121.742327857831114
14699	2020-03-07 05:22:57	2020-03-07	Mr. Carlyle Hintz	mr.carlyle.hintz@geemail.com	Lubbock	Texas	6011665888848822940	63ca737f4ad1ca494c45703269058282	American Express	33.6469912124373067	-101.882183620418246
14700	2020-03-07 05:28:54	2020-03-07	Wanda Luettgen	wanda.luettgen@geemail.com	Inglewood	California	3029654329349612	7c3a62dc4e9894beb7b66aea0e2894cc	Maestro	34.0376366888418787	-118.388850053961576
14701	2020-03-07 06:05:59	2020-03-07	Dr. Regan Kunde	dr.regan.kunde@geemail.com	San Francisco	California	3088403660450865419	35c8c38f8562cb9891ed9a86bc6a0d2e	Voyager	37.8040066816353502	-122.439401649504376
14702	2020-03-07 06:13:16	2020-03-07	Stevie Ebert	stevie.ebert@geemail.com	Bakersfield	California	6011600571147147338	ce1a8ad189fe46466e7d0706aeb06ef1	VISA 16 digit	35.2757941575430323	-118.966430420083171
14703	2020-03-07 06:16:37	2020-03-07	Urban Kuvalis	urban.kuvalis@geemail.com	Green Bay	Wisconsin	589396590470215	61a1c068841c34e73e7590b452014b6d	American Express	44.4953194571722292	-87.8909364912945819
14704	2020-03-07 06:25:06	2020-03-07	Darian Weissnat	darian.weissnat@geemail.com	Knoxville	Tennessee	4396831796838258	47ad63dbebc2cf1884f2a415bbe403c1	Voyager	36.0556687953479624	-84.000165124771371
14705	2020-03-07 06:38:52	2020-03-07	Bynum Streich PhD	bynum.streich.phd@geemail.com	Topeka	Kansas	3088621334067254658	a37770977205113a25a527df9854a0ba	Diners Club / Carte Blanche	39.1152492550134667	-95.5969365332450707
14706	2020-03-07 06:40:18	2020-03-07	Lucious Hickle	lucious.hickle@geemail.com	San Francisco	California	4991515403437062	7ae02bdeb2c0586d876abffdebae0d7e	Discover	37.7649233269830944	-122.450122183332184
14707	2020-03-07 06:53:03	2020-03-07	Shayna Kassulke	shayna.kassulke@woohoo.com	Savannah	Georgia	869903291495191266	e89ce5dcea223a80820ebe6324f122a9	Diners Club / Carte Blanche	32.0564789155125567	-81.1609894102592051
14708	2020-03-07 07:13:43	2020-03-07	Oma Dickens DDS	oma.dickens.dds@geemail.com	Austin	Texas	3050194566383809	6b6789b07058bd194bfd05006b941b5b	Maestro	30.3172646782953272	-97.7693778455030156
14709	2020-03-07 07:23:08	2020-03-07	Dr. Almer Hermann V	dr.almer.hermann.v@woohoo.com	Las Vegas	Nevada	3043748145283819	51f3ba64bba694b9a060fe51c612ae73	VISA 13 digit	36.1587539906714071	-115.293551268309727
14710	2020-03-07 07:34:42	2020-03-07	Gail Senger	gail.senger@geemail.com	San Francisco	California	6011785336859562257	d3951f27ecfed7e4db34f8d3a1a49dbd	VISA 16 digit	37.7613960749955524	-122.431512797764469
14711	2020-03-07 07:42:01	2020-03-07	Yoselin Skiles	yoselin.skiles@woohoo.com	Sacramento	California	503874079781485	3c4f26bd8a17c9861a14edc485f50a61	Voyager	38.631277056530493	-121.550812168350816
14712	2020-03-07 07:44:32	2020-03-07	Justyn Buckridge	justyn.buckridge@geemail.com	Nashville	Tennessee	210006936453577545	eb1e3e4f841062e1952864107b4878a9	VISA 13 digit	36.2239391159389115	-86.7622480031475334
14713	2020-03-07 07:50:00	2020-03-07	Kaylynn Stehr PhD	kaylynn.stehr.phd@woohoo.com	Oakland	California	3088324405625583737	0ba021d035256ccf3a5731d15a89777e	VISA 16 digit	37.7878512435566662	-122.254066700501937
14714	2020-03-07 07:53:03	2020-03-07	Stoney Lueilwitz	stoney.lueilwitz@geemail.com	San Francisco	California	4570650122121546	057ab7b5adab7a577f707fa34ae260ef	Maestro	37.7760490694491793	-122.435511980861207
14715	2020-03-07 07:57:43	2020-03-07	Arlene Streich	arlene.streich@geemail.com	Daly City	California	4403612152300203	64febe14e6a5e23006f450575b21f157	VISA 16 digit	37.6303315317179994	-122.454102856535471
14716	2020-03-07 08:32:51	2020-03-07	Dr. Chester Botsford Jr.	dr.chester.botsford.jr.@geemail.com	Salem	Oregon	3112679752477786384	ca85a0faedfbd6376b8f4f6293c3c8a0	VISA 16 digit	44.9437039492454318	-122.942304390498251
14717	2020-03-07 08:51:23	2020-03-07	Miss Drew Armstrong	miss.drew.armstrong@warmmail.com	Palm Bay	Florida	4133710146849207	c6d7fe52a8ef3cb35ec25be698dbc084	Maestro	27.9139722614869505	-80.5899805257864301
14718	2020-03-07 09:01:08	2020-03-07	Dr. Irwin Bruen Jr.	dr.irwin.bruen.jr.@geemail.com	Elk Grove	California	3096753936109128003	a7d9abb8a5262724a189e01517d46090	VISA 16 digit	38.502503420906514	-121.483979270178835
14719	2020-03-07 09:09:09	2020-03-07	Cristy Rutherford DVM	cristy.rutherford.dvm@geemail.com	Hialeah	Florida	180011347247450879	481a152ddefc82e59ed4fbc944ec9c49	Maestro	25.9141101137246963	-80.3661052142638681
14720	2020-03-07 09:09:30	2020-03-07	Dr. Tanisha Roberts DVM	dr.tanisha.roberts.dvm@geemail.com	Mesa	Arizona	4434985864400898	83cccbef5f97e32cec58988c95b24c0b	Voyager	33.3077190402574814	-111.692451295198495
14721	2020-03-07 09:52:55	2020-03-07	Dawson Wiegand	dawson.wiegand@warmmail.com	New York	New York	4482834566615752	7a237b55d51c08b5fe5af560aeaccdaf	JCB 16 digit	40.7502378762457482	-73.9984150856163296
14722	2020-03-07 10:19:31	2020-03-07	Atha Satterfield	atha.satterfield@geemail.com	San Francisco	California	501834981639486	813df35ec96c4eea9a549e3b3d5e91f9	VISA 16 digit	37.7632577629456776	-122.440280279891596
14723	2020-03-07 10:31:42	2020-03-07	Sylvia Pfeffer	sylvia.pfeffer@geemail.com	Frisco	Texas	4007145266539960	d986606cfe576b31a70f3da3e990d059	Voyager	33.2002981059715125	-96.8394082371354017
14724	2020-03-07 11:05:57	2020-03-07	Sanai Schmeler DDS	sanai.schmeler.dds@geemail.com	Fresno	California	869936546953261534	994ad992d016555caa2b0f0d36e2bd5f	VISA 16 digit	36.8599075463473795	-119.814250505540159
14725	2020-03-07 11:10:29	2020-03-07	Betty Hyatt	betty.hyatt@geemail.com	Killeen	Texas	4079164961905908	94c4b70f5a04e21728e2471e0de7fb49	Diners Club / Carte Blanche	31.060470781125872	-97.6540759219955703
14726	2020-03-07 11:23:42	2020-03-07	Isla Kirlin-McDermott	isla.kirlin.mcdermott@woohoo.com	Provo	Utah	3042242343109548	dc220dda76e8476e60eccbbfeb154d1c	VISA 16 digit	40.2083222602747412	-111.61938360339515
14727	2020-03-07 11:33:22	2020-03-07	Luna Ernser	luna.ernser@warmmail.com	Des Moines	Iowa	3088527723019863860	715a58a66ee8d0ed4762acf3180e3b78	Maestro	41.6272306789387017	-93.5404014851477115
14728	2020-03-07 11:36:14	2020-03-07	Ahmad Rohan	ahmad.rohan@geemail.com	Downey	California	3053546161651673	3d3a711e13bc8b80423768d45b3f245d	Maestro	33.9270302866369491	-118.161745009768381
14729	2020-03-07 11:37:03	2020-03-07	Esmeralda Stamm	esmeralda.stamm@geemail.com	Minneapolis	Minnesota	4005401797434797	c4b285efe546a2481a04dfced43bb791	Mastercard	45.0163446347780507	-93.3468633476450975
14730	2020-03-07 11:43:25	2020-03-07	Simona Stamm	simona.stamm@geemail.com	Madison	Wisconsin	4735004085853624	357f60bb0f9b7ceea4e0e6f496ad77ca	JCB 15 digit	43.1466889749255031	-89.4637714924641045
14731	2020-03-07 11:57:51	2020-03-07	Casen Klein	casen.klein@geemail.com	Chicago	Illinois	561288015371706	6a1d132259d62bd7436bc8b0cee8d9f7	JCB 16 digit	41.7860189284034078	-87.5828512613691288
14732	2020-03-07 12:07:17	2020-03-07	Areli Treutel MD	areli.treutel.md@warmmail.com	El Cajon	California	3003447766885933	368b5e4b3a21e7e7b74a5ae2909ab1f2	Diners Club / Carte Blanche	32.7962493428967861	-116.965449235699708
14733	2020-03-07 12:27:58	2020-03-07	Barb Rosenbaum	barb.rosenbaum@woohoo.com	Berkeley	California	6011145441590704807	120a7f3005b6158011aa482937207170	American Express	37.8622565119275407	-122.286784607415882
14734	2020-03-07 13:01:22	2020-03-07	Rutha Cassin	rutha.cassin@geemail.com	Berkeley	California	869905074197982630	020f52fb5af41b42773d8bc777dcceb5	VISA 16 digit	37.8618312186719592	-122.247668048760147
14735	2020-03-07 13:06:30	2020-03-07	Hillery Dickinson	hillery.dickinson@geemail.com	San Francisco	California	6011474278239008260	94eeeff3417b1c29380a1bdff071f65c	American Express	37.8034061595846893	-122.381848396321175
14736	2020-03-07 13:25:32	2020-03-07	Lanita Weber-Lebsack	lanita.weber.lebsack@geemail.com	Philadelphia	Pennsylvania	4485975211551	759e40c53ff907f00c1b5fb6387b5c85	JCB 16 digit	40.0426250058185289	-75.2212820360802112
14737	2020-03-07 13:45:55	2020-03-07	Daisy Smith	daisy.smith@woohoo.com	Tyler	Texas	6011002595783071472	5a2526d3747d88b2f576b1e2d1621fc7	Diners Club / Carte Blanche	32.3856402492199109	-95.2089338083393812
14738	2020-03-07 13:59:19	2020-03-07	Saniya Kerluke	saniya.kerluke@geemail.com	New York	New York	52389250825512868	df2d12696d79cd5168081b053741fd43	VISA 16 digit	40.6942796820532493	-73.8393809920072499
14739	2020-03-07 14:05:30	2020-03-07	Hedwig Doyle	hedwig.doyle@geemail.com	Hartford	Connecticut	4957336351124707	fffd3ba05ccbebd95b77002f8d13c11b	Diners Club / Carte Blanche	41.8308223912507344	-72.6214881607223361
14740	2020-03-07 14:10:45	2020-03-07	Kandice McClure	kandice.mcclure@geemail.com	Riverside	California	6011319232965852903	a8cb88bf056cdca2141cd6998e4e7a25	Mastercard	34.0378533016838105	-117.429641925121459
14741	2020-03-07 14:18:05	2020-03-07	Bettyjane Koch-Hansen	bettyjane.koch.hansen@geemail.com	Ventura	California	3096589584495355077	6080111c055b437b896a44e8cc542a0e	VISA 13 digit	34.2907352661874185	-119.285861309162158
14742	2020-03-07 14:18:39	2020-03-07	Armani O'Kon-DuBuque	armani.o'kon.dubuque@geemail.com	Antioch	California	6011827000240485921	c3c2fea2908167d503c9e738ff239b2b	JCB 16 digit	37.9860868387654449	-121.798111217579617
14743	2020-03-07 14:33:09	2020-03-07	Gracie Schuster	gracie.schuster@geemail.com	Worcester	Massachusetts	869965318304278797	56c9b6c01f67ff4c5a0daaef7a402321	JCB 16 digit	42.2861435581166276	-71.8072233969133293
14744	2020-03-07 14:40:16	2020-03-07	Miss Nicki Roberts DDS	miss.nicki.roberts.dds@geemail.com	Rochester	New York	51528200700935520	1ede06907c969b896bf543f9d95338c0	Voyager	43.0738656710345253	-77.579202741408352
14745	2020-03-07 14:45:24	2020-03-07	Mr. Julien Rippin Sr.	mr.julien.rippin.sr.@woohoo.com	San Diego	California	3754034260281203	0f7cc154ef9714935c57ffea403c73dc	JCB 16 digit	32.7297167315680539	-117.204702814240008
14746	2020-03-07 14:47:35	2020-03-07	Pryor Mohr-Moen	pryor.mohr.moen@geemail.com	Santa Clarita	California	3337138457887872114	107682aae5f0a50e4fc5b59b04242edc	VISA 13 digit	34.402002565629779	-118.415290985499325
14747	2020-03-07 14:55:10	2020-03-07	Shasta Jacobi-Farrell	shasta.jacobi.farrell@geemail.com	Wilmington	North Carolina	3112632456506769660	139c5e69ca08aaf805356fa64d13a701	American Express	34.1882135847870288	-77.8375994043882997
14748	2020-03-07 15:02:50	2020-03-07	Rakeem Marvin DDS	rakeem.marvin.dds@geemail.com	Cleveland	Ohio	6011971892021837435	1bd28c6c35284b7285418a766f618903	American Express	41.4498498334400338	-81.7413308851659366
14749	2020-03-07 15:04:21	2020-03-07	Ms. Margarita Heller MD	ms.margarita.heller.md@geemail.com	Glendale	California	6011772235301142939	896e9bd819149de99374708fc5b103e2	JCB 16 digit	34.1237563485033775	-118.339437838028374
14750	2020-03-07 15:13:06	2020-03-07	Nathanial Terry Sr.	nathanial.terry.sr.@geemail.com	Greensboro	North Carolina	869939386984299949	4e9568f475e46d209f8b0735cda019e7	JCB 16 digit	36.1819672601878679	-79.7630514394473238
14751	2020-03-07 15:19:39	2020-03-07	Kaelynn Ryan	kaelynn.ryan@geemail.com	San Francisco	California	3437772064180996	2d9585e7edbedb89514c0aaa7c9eed43	American Express	37.7874537916090532	-122.394460770517611
14752	2020-03-07 15:21:31	2020-03-07	Misti Batz DVM	misti.batz.dvm@geemail.com	New York	New York	3158703491882163760	6d75aaca19fe6c71de74be9afa9aa663	VISA 16 digit	40.6603503234442343	-73.9435425565008018
14753	2020-03-07 15:28:32	2020-03-07	Jayne Luettgen	jayne.luettgen@geemail.com	Berkeley	California	869938883681268434	d1b6983aa551ec3260e94a974efba3e9	JCB 15 digit	37.8419196363450823	-122.274822176197659
14754	2020-03-07 15:30:25	2020-03-07	Belinda Lowe	belinda.lowe@geemail.com	San Diego	California	503809395336077	37dfb0a03ff556425d695a5692d2d395	Voyager	32.7757103965684777	-117.122389995809655
14755	2020-03-07 15:36:08	2020-03-07	Hadassah Wiza	hadassah.wiza@warmmail.com	Fort Worth	Texas	869983530761996475	abdf5c0eb89bf2f76ef9360c41b3fe98	Maestro	32.8219416870791463	-97.3568723755709868
14756	2020-03-07 15:55:40	2020-03-07	Andrae Wintheiser	andrae.wintheiser@geemail.com	Berkeley	California	3528111589260871197	c0f34fdf118baef68099991933a25df9	Diners Club / Carte Blanche	37.880677773297009	-122.28821298592095
14757	2020-03-07 16:21:03	2020-03-07	Ludie Boyer-Weimann	ludie.boyer.weimann@geemail.com	Chesapeake	Virginia	869932975401363374	35891057b6fc0bcb808d185cd97d720d	Voyager	36.7771837223093954	-76.325013537782425
14758	2020-03-07 16:30:07	2020-03-07	Marcelino Baumbach	marcelino.baumbach@geemail.com	Seattle	Washington	3088659709489458570	c48dfba2dd9b1b8deec308e412c11456	Maestro	47.6973159497994956	-122.38771266140192
14759	2020-03-07 16:34:34	2020-03-07	Annabel Bins	annabel.bins@geemail.com	Pasadena	Texas	4052144627085635	66196a089bb237c15989fef2bf3f78c5	VISA 16 digit	29.615585237309709	-95.0978984388004989
14760	2020-03-07 16:43:47	2020-03-07	Corinna Grant	corinna.grant@geemail.com	San Francisco	California	3009067334936747	098aaa5dc94518a8ff95888ecd1dc6ef	Discover	37.7737082888860201	-122.44407368380638
14761	2020-03-07 17:00:14	2020-03-07	Vic Fisher	vic.fisher@geemail.com	Ontario	California	4857120345336549	45220a540ec8ef5ad11ad459e56eb988	VISA 13 digit	34.0762843548931187	-117.532743023951355
14762	2020-03-07 17:09:37	2020-03-07	Shaquana Stoltenberg	shaquana.stoltenberg@geemail.com	San Francisco	California	3705933152137177	4e73009b250ad55bca010d10a09ebae5	Voyager	37.736421897228098	-122.456702312806812
14763	2020-03-07 17:16:06	2020-03-07	Annmarie Emard	annmarie.emard@geemail.com	Paterson	New Jersey	676348873156888	fbfae1dcb397ae9551899cacf3a55b1d	JCB 16 digit	40.9364785761527727	-74.228727128028126
14764	2020-03-07 17:19:22	2020-03-07	Treena Bernier	treena.bernier@geemail.com	Oakland	California	3418739342693853	6d4a3942ee5503ce8500e5b50100d806	American Express	37.830583194402621	-122.230532056180763
14765	2020-03-07 17:33:41	2020-03-07	Dr. Jonah Howell I	dr.jonah.howell.i@geemail.com	Lakeland	Florida	6011723026061855061	01c282f75bcbfb8d2167b246f66b35d1	Voyager	28.0020386064723112	-81.9068724132493031
14766	2020-03-07 17:34:55	2020-03-07	Quinten Cruickshank V	quinten.cruickshank.v@woohoo.com	Eugene	Oregon	4334018416719432	8da950b9ac479834594d84d8e0c942cd	Maestro	44.0155354064617299	-123.103429487998412
14767	2020-03-07 17:36:57	2020-03-07	Terri Cummings	terri.cummings@woohoo.com	San Francisco	California	3088816890535832339	dce962f3cda8eef10b1469637e35f17b	VISA 16 digit	37.7344693380432474	-122.437828103546735
14768	2020-03-07 18:12:16	2020-03-07	Leeroy Roob II	leeroy.roob.ii@geemail.com	Boston	Massachusetts	4583649681178272	7d3eba057fa8f8370403d287434cb04e	Diners Club / Carte Blanche	42.3512431419622146	-70.9468367334872454
14769	2020-03-07 18:37:40	2020-03-07	Electa Goodwin PhD	electa.goodwin.phd@woohoo.com	Tucson	Arizona	4505295410178822	3530bc20f6865a7f2d9fb0f1b29c86a1	VISA 16 digit	32.0559079905081532	-110.883104522828376
14770	2020-03-07 18:43:11	2020-03-07	Vivienne Will	vivienne.will@warmmail.com	Elizabeth	New Jersey	3088003547900434892	4ea9b1be83466ff750283811da43a420	VISA 13 digit	40.7146408367563097	-74.1903685880769075
14771	2020-03-07 18:48:22	2020-03-07	Guillermo Barrows	guillermo.barrows@geemail.com	San Francisco	California	3055784127849747	038e1ded55399e5e3197522c4edb0d22	Voyager	37.7960302792627871	-122.430545044805839
14772	2020-03-07 18:49:05	2020-03-07	Fredrick Volkman Jr.	fredrick.volkman.jr.@geemail.com	Fresno	California	3477644282299109	996df32a967a2251b333917bc903fc8d	Discover	36.883547883002457	-119.711408579825985
14773	2020-03-07 19:06:37	2020-03-07	Ashby Bogisich	ashby.bogisich@geemail.com	Columbus	Georgia	4385420987539355	fb67aaaeba9680297f158004cb8751ac	JCB 16 digit	32.5902325823482073	-84.7761869807425796
14774	2020-03-07 19:10:51	2020-03-07	Daron Yundt	daron.yundt@geemail.com	San Francisco	California	3054458179428301	3c121c32c90490b5716366cf3ff95e13	Diners Club / Carte Blanche	37.7835200881991398	-122.453075595314701
14775	2020-03-07 19:12:43	2020-03-07	Charles Wintheiser	charles.wintheiser@geemail.com	New York	New York	3096609465275524874	5b95608dcc44dd197681bad647b6c579	JCB 15 digit	40.6409036585818981	-73.8612266865920191
14776	2020-03-07 19:37:15	2020-03-07	Burnice Runte	burnice.runte@geemail.com	Pueblo	Colorado	869965932098416528	6474042751d4a7b1ec8ff738ce45a6ec	JCB 16 digit	38.2262303771428762	-104.676428789026289
14777	2020-03-07 20:01:26	2020-03-07	Chancey Beatty	chancey.beatty@geemail.com	Los Angeles	California	3096365443792341274	1a98decfd3661582fbadb4f3e0941d05	VISA 13 digit	34.0726903381623316	-118.321091135963044
14778	2020-03-07 20:19:20	2020-03-07	Jami Abernathy	jami.abernathy@woohoo.com	Knoxville	Tennessee	4371717759385156	65f9212ba1f74799a6414cb0aa55ad15	Diners Club / Carte Blanche	36.0674146174982226	-83.8851848121482817
14779	2020-03-07 20:20:42	2020-03-07	Nova Heller	nova.heller@geemail.com	Miami	Florida	3088411234540671599	7ca307d1fc8856f9b3f2c6e99767646d	American Express	25.792446751300993	-80.2733009058389797
14780	2020-03-07 20:28:02	2020-03-07	Regan Hauck	regan.hauck@geemail.com	Arlington	Texas	4064922589243	04531f7b6a1c3d0ef028ad8e22afa504	VISA 16 digit	32.6889991902064523	-97.0729517341151933
14781	2020-03-07 20:40:56	2020-03-07	Estes Shanahan	estes.shanahan@geemail.com	Fort Worth	Texas	869978764194100184	19024c73f44e068ab32cd9dba1de366a	American Express	32.7150065795108702	-97.4146034260567291
14782	2020-03-07 20:43:41	2020-03-07	Ezzard Welch	ezzard.welch@warmmail.com	San Francisco	California	4322645234849118	76c6e0c6753c620fdc9497cc3c335f4b	VISA 13 digit	37.7506806203051184	-122.45095139054655
14783	2020-03-07 20:46:47	2020-03-07	Arlie Bernhard Jr.	arlie.bernhard.jr.@geemail.com	Rockford	Illinois	3337153923607804869	a091d2ccc058a1dcab092267f9a965d7	VISA 16 digit	42.3189626388728612	-89.1616424779225127
14784	2020-03-07 20:50:01	2020-03-07	Bernardo Robel	bernardo.robel@geemail.com	Washington	District of Columbia	3040768067021214	0cd766df2bf63045dadd75c5edac1c3f	VISA 16 digit	38.8075100864082572	-76.9421740745872285
14785	2020-03-07 20:53:03	2020-03-07	Jerry Boyer	jerry.boyer@geemail.com	Virginia Beach	Virginia	060489801701700	e4b916424bff408c25b6b39572c5a5e4	Maestro	36.7002468038070973	-76.0957577140208343
14786	2020-03-07 20:58:44	2020-03-07	Milagros Dicki-Howell	milagros.dicki.howell@warmmail.com	Atlanta	Georgia	503851114071114	bcbd1d2d09e93a083f5338f3de5ce67f	VISA 16 digit	33.7404308769661938	-84.4300198454454573
14787	2020-03-07 21:05:09	2020-03-07	Susann Mante	susann.mante@warmmail.com	Virginia Beach	Virginia	4345576973980504	f6fe8c6810e80b0c1a92e310390e88d6	VISA 16 digit	36.7244151015952269	-75.9651512899573902
14788	2020-03-07 21:39:16	2020-03-07	Dr. Olie Rice	dr.olie.rice@geemail.com	Tallahassee	Florida	3704456971178157	3c1875b71a28b05a3dc16c58f3bf4887	Discover	30.3644517517205337	-84.216025313643371
14789	2020-03-07 22:02:42	2020-03-07	Baxter Dare	baxter.dare@warmmail.com	Jacksonville	Florida	869965931837930443	c76e81ca44a45c18e359bd6a92adc23f	Discover	30.353534783428163	-81.6771573544092604
14790	2020-03-07 22:03:03	2020-03-07	Cohen Hermiston-Schmitt	cohen.hermiston.schmitt@geemail.com	Fort Worth	Texas	210004508390564829	51be997c378006520c0cc32fa0b9a194	JCB 15 digit	32.7212231948096317	-97.3278379420571014
14791	2020-03-07 22:05:19	2020-03-07	Amiyah Ondricka	amiyah.ondricka@woohoo.com	San Francisco	California	4653727208227072	878a0287c7d1d443f01df6cfe6966572	Diners Club / Carte Blanche	37.7647850649592343	-122.458284470953089
14792	2020-03-07 22:09:21	2020-03-07	Leon Dietrich	leon.dietrich@geemail.com	Tucson	Arizona	060435262711134	53885e74f7897bf40f30ab4331fa9bff	JCB 16 digit	32.0809026305604732	-110.855315689392754
14793	2020-03-07 22:13:12	2020-03-07	Celine Pouros	celine.pouros@warmmail.com	Little Rock	Arkansas	4134308976297248	c79202281162e1255ca1e81aef184a88	JCB 15 digit	34.7272176440149565	-92.3650071643166228
14794	2020-03-07 22:15:51	2020-03-07	Ms. Ednah Mohr	ms.ednah.mohr@warmmail.com	Albuquerque	New Mexico	3528880072720658255	0de1e38a94cebaa953dc10cc6dbaccad	Voyager	35.2041337973572368	-106.606740033307673
14795	2020-03-07 22:17:17	2020-03-07	Chelsey Parisian	chelsey.parisian@geemail.com	New York	New York	4163443413327102	4d27fdfa5744537ca5b93af9e09f39df	American Express	40.7626488547995649	-73.912765703246734
14796	2020-03-07 22:50:19	2020-03-07	Ivy Little	ivy.little@geemail.com	Fort Wayne	Indiana	4025268597085509	09bcccd6b1d2b72d1f3d4c15150b6b32	VISA 16 digit	41.0802305648818589	-85.1083032294861965
14797	2020-03-07 23:13:40	2020-03-07	Dr. Link Stark	dr.link.stark@warmmail.com	Oakland	California	180080334552776177	4bcfc0500af2de97695a27905d132b75	VISA 16 digit	37.8033255930617429	-122.278330317001291
14798	2020-03-07 23:16:41	2020-03-07	Jesse Becker-Hessel	jesse.becker.hessel@geemail.com	Roseville	California	4241569982266606	53b05335da7734d43b2049c00ad3db75	JCB 16 digit	38.8279666181243925	-121.415999589183926
14799	2020-03-07 23:19:09	2020-03-07	Miss Frederica Jast	miss.frederica.jast@woohoo.com	Memphis	Tennessee	4597018767524094	5177991746af29ba9cfeefa7506b2988	Maestro	35.1637982965514055	-89.974853250642866
14800	2020-03-07 23:29:28	2020-03-07	Savana Walsh	savana.walsh@geemail.com	Clearwater	Florida	3158717049174043688	b59143503def5af8c6892a442f937d08	Diners Club / Carte Blanche	27.8903068649709205	-82.7920034222569257
14801	2020-03-07 23:45:31	2020-03-07	Dedra Schultz	dedra.schultz@geemail.com	San Francisco	California	676196627638099	828deb5bd02622f14fe25cdbc339e390	JCB 16 digit	37.7900198792018074	-122.453215443540145
14802	2020-03-07 23:48:01	2020-03-07	Allyssa Bode DDS	allyssa.bode.dds@geemail.com	Fort Worth	Texas	4338132878665	a9d53a392d64e3d29f7fda3909c71492	VISA 16 digit	32.6931289739031357	-97.2652424546711103
14803	2020-03-08 00:17:53	2020-03-08	Dr. Rayford Robel III	dr.rayford.robel.iii@woohoo.com	Dallas	Texas	3112065301000093801	f395d59e0be7e19a89358afd6ddac3ae	VISA 16 digit	32.825474155302345	-96.7650632582567596
14804	2020-03-08 00:24:29	2020-03-08	Deirdre Medhurst	deirdre.medhurst@geemail.com	San Francisco	California	6011585708296458707	eea8d066a83b6c45c2a813d36d6f4042	VISA 16 digit	37.7633273201790516	-122.458173397047176
14805	2020-03-08 00:28:19	2020-03-08	Ashtyn Kovacek-Hickle	ashtyn.kovacek.hickle@geemail.com	Los Angeles	California	6011968719897505454	8306a968ad6ffac4f52b5ef06495ecf7	JCB 15 digit	33.9576844136096483	-118.344553871126095
14806	2020-03-08 00:31:30	2020-03-08	Dr. Irving Tremblay PhD	dr.irving.tremblay.phd@geemail.com	Memphis	Tennessee	4620031082394	d47bcaaea4d76adc894dfc3946a861b6	VISA 13 digit	35.0192317361079191	-89.9678546539299191
14807	2020-03-08 00:36:06	2020-03-08	Miss Araminta King MD	miss.araminta.king.md@woohoo.com	Columbus	Georgia	210003978900569579	db9e1ae2e29508cd502c7c215a757a48	JCB 15 digit	32.4261517887979736	-84.8326558710705427
14808	2020-03-08 00:39:23	2020-03-08	Manilla Kemmer	manilla.kemmer@warmmail.com	Las Vegas	Nevada	53726732399262162	ae5a9174923d9b1b3b3b938cbe675fd3	JCB 15 digit	36.1672135458894033	-115.215701527448743
14809	2020-03-08 01:00:39	2020-03-08	Aryanna Thiel	aryanna.thiel@geemail.com	Chicago	Illinois	3785749150867224	6424341dbd0dbdcbb3b300ea6ad51279	Diners Club / Carte Blanche	41.7602247842889298	-87.6972977567959475
14810	2020-03-08 01:07:11	2020-03-08	Lizette Tromp	lizette.tromp@warmmail.com	Santa Ana	California	869977845352022590	b63783d9449014be0ddcfb06b7fabc33	JCB 16 digit	33.6697299086593063	-117.979651786193244
14811	2020-03-08 01:10:03	2020-03-08	Arah Runte	arah.runte@geemail.com	Vancouver	Washington	55173254150724577	117d4892e945c17240d226fb6cbed257	Diners Club / Carte Blanche	45.6923159085284922	-122.655679878738511
14812	2020-03-08 01:31:03	2020-03-08	Mrs. Lovey Reichert MD	mrs.lovey.reichert.md@warmmail.com	Fort Worth	Texas	210065718279746738	fad6a2f441582ce9cfa7853c38651753	Discover	32.8695697868764398	-97.2947622802861076
14813	2020-03-08 01:45:38	2020-03-08	Ophelia Adams	ophelia.adams@geemail.com	Mobile	Alabama	4819236794056	c71ed73fd1a3d345f8b419323098f45b	JCB 16 digit	30.5705195279434321	-88.0462274359211392
14814	2020-03-08 01:51:46	2020-03-08	Zackary Bins	zackary.bins@geemail.com	Fresno	California	4833724776244	9e87d7add03fda4cde60c6ccfd8889ee	JCB 15 digit	36.830102583753316	-119.87363002478294
14815	2020-03-08 02:34:14	2020-03-08	Shelbie Trantow	shelbie.trantow@warmmail.com	Detroit	Michigan	869952763860821735	aafca692e083d6427c021e8f8af1da65	JCB 16 digit	42.3107278637513531	-83.1274775058150226
14816	2020-03-08 02:48:04	2020-03-08	Littleton Renner	littleton.renner@woohoo.com	Murrieta	California	210019729723656453	33ce4bfde040c0d029fd793d09f14237	JCB 16 digit	33.5361592118725156	-117.137993596065414
14817	2020-03-08 02:51:51	2020-03-08	Jelani Bernhard-Rosenbaum	jelani.bernhard.rosenbaum@geemail.com	Columbus	Ohio	4367616544717	1e3321a4b46c3741e3cd81c6fbdb9cfa	Voyager	40.0142974142495547	-83.0113807207208225
14818	2020-03-08 03:04:07	2020-03-08	Mr. Garrick Lindgren	mr.garrick.lindgren@woohoo.com	Arlington	Texas	4865992864963	14844f9056e0538e5e18c6951c3a2edc	Mastercard	32.7950456973414859	-97.1824399791218383
14819	2020-03-08 03:05:43	2020-03-08	Cyndi Goodwin	cyndi.goodwin@geemail.com	Washington	District of Columbia	210036683812556646	b5ac4f14def2f83c7f6515a69cbe3adc	Voyager	38.9333173292022181	-77.0717509232673876
14820	2020-03-08 03:27:53	2020-03-08	Rhianna Runte PhD	rhianna.runte.phd@warmmail.com	New York	New York	589373838042981	c955c33cc7fbd339278a05dab0b6d59e	VISA 16 digit	40.7235015012081689	-73.9434217662911806
14821	2020-03-08 03:32:00	2020-03-08	Volney Krajcik III	volney.krajcik.iii@geemail.com	San Diego	California	3015960898526256	5ae32c951f28b0f0d3e95fb282da8b9a	JCB 16 digit	32.8238450334474479	-117.124242920186376
14822	2020-03-08 04:03:35	2020-03-08	Ms. Shanita Brekke PhD	ms.shanita.brekke.phd@geemail.com	Cape Coral	Florida	3096829769335455829	d08f9b2e192936a5b2d29bb84f5cd947	Mastercard	26.6987818937253216	-81.9824045622326452
14823	2020-03-08 04:29:04	2020-03-08	Brooklynn McCullough	brooklynn.mccullough@geemail.com	San Francisco	California	51900135685037371	80796e449155a93662ebdaa5d8f756e3	VISA 16 digit	37.7947573955032183	-122.442655960031928
14824	2020-03-08 04:32:39	2020-03-08	Needham Bergstrom-Jenkins	needham.bergstrom.jenkins@warmmail.com	Oakland	California	869927035510394187	def4a8aa7a848292508c72ae8412a361	VISA 16 digit	37.8229227128969114	-122.256141376454124
14825	2020-03-08 04:40:04	2020-03-08	Mrs. Cassidy Friesen	mrs.cassidy.friesen@woohoo.com	Cary	North Carolina	3337136679176932240	7e48631c66e1e1caf0aa39dc57be0af9	JCB 15 digit	35.7586040009386892	-78.8917430102910799
14826	2020-03-08 04:45:33	2020-03-08	Evonne Heaney	evonne.heaney@warmmail.com	New York	New York	869979474106021291	3d13d5fbf48e996dec2635b9a2c1c82d	VISA 13 digit	40.6806795001719124	-73.9264504545729579
14827	2020-03-08 05:03:58	2020-03-08	Ariane Kub-Goodwin	ariane.kub.goodwin@woohoo.com	Denver	Colorado	4337323495069742	dba18b781643aa5ebbfeac077eca62db	VISA 16 digit	39.7205660236120224	-104.853441788560161
14828	2020-03-08 05:12:28	2020-03-08	Cindy Sanford	cindy.sanford@geemail.com	Grand Rapids	Michigan	869957032338940138	7718b3e7c9b328cb3575c8165995bd57	Voyager	43.0424737581785735	-85.6044568458240605
14829	2020-03-08 05:21:50	2020-03-08	Miss Blanca Kuhn MD	miss.blanca.kuhn.md@geemail.com	Fort Worth	Texas	869902047185217600	984297e8ae42d4cd7de22a205ba4726c	JCB 16 digit	32.806637812085448	-97.4237093459636014
14830	2020-03-08 05:29:39	2020-03-08	Ardell Koss	ardell.koss@geemail.com	Berkeley	California	869935967511063652	52e7ce5f2ff240cc01b592fb68e17b26	JCB 15 digit	37.8698303852708094	-122.26425030488808
14831	2020-03-08 05:50:18	2020-03-08	Ms. Tricia Dare MD	ms.tricia.dare.md@geemail.com	Austin	Texas	869907882852200967	4ddb040281b27c63636151bf6edbf854	JCB 15 digit	30.2685743899211275	-97.8129150987375624
14832	2020-03-08 06:17:24	2020-03-08	Aura Morissette-Nader	aura.morissette.nader@woohoo.com	Palm Bay	Florida	210015330514341837	9079f97f00f002746680216f4ed7e86d	JCB 16 digit	27.8994837978709498	-80.6783089350745115
14833	2020-03-08 06:19:38	2020-03-08	Ernie Kuhlman	ernie.kuhlman@geemail.com	Chicago	Illinois	4704380362307022	34251a8db6e705d5c2ae8cde74d84811	VISA 13 digit	41.8883365706842383	-87.6395503875363602
14834	2020-03-08 06:36:30	2020-03-08	Nannie Greenholt	nannie.greenholt@woohoo.com	Salt Lake City	Utah	4164214707166061	18672251e26b0a0c708e264a5feddfc1	VISA 13 digit	40.6897409017808727	-111.950518621778116
14835	2020-03-08 06:52:27	2020-03-08	Kristopher Donnelly	kristopher.donnelly@woohoo.com	Milwaukee	Wisconsin	4773608720753	df82be92f6f1310238c8e4afba63c855	JCB 16 digit	43.018641159645469	-87.9699016663346498
14836	2020-03-08 07:12:10	2020-03-08	Dr. Susie Wilderman DVM	dr.susie.wilderman.dvm@geemail.com	Phoenix	Arizona	180021455782728407	48a995f3d52e7c9344b5bc4cdf1d7a6f	Mastercard	33.6235011032249815	-112.007031467084218
14837	2020-03-08 07:13:25	2020-03-08	Jeffie Zboncak	jeffie.zboncak@geemail.com	Miami	Florida	6011440702987971669	98de615862c475dbf0ddeb79f2f63289	Discover	25.6939324660830231	-80.3081206143707078
14838	2020-03-08 07:37:27	2020-03-08	Arline Runolfsson	arline.runolfsson@woohoo.com	Durham	North Carolina	53739243588795025	40d4d4efb324e50d8cb8eb89edac089a	American Express	35.9933728446498478	-78.9702491939436726
14839	2020-03-08 07:45:19	2020-03-08	Dr. Denny Murazik	dr.denny.murazik@warmmail.com	New York	New York	3451167589114458	a11a7b5222ba41508f6de1b6ffb35238	Maestro	40.5745142183955778	-73.9314978551015258
14840	2020-03-08 07:52:15	2020-03-08	Darrel Doyle	darrel.doyle@warmmail.com	San Francisco	California	3023811831951964	6449759cf411cf2909c35a66a5254233	Discover	37.7844028169599326	-122.428768528364358
14841	2020-03-08 08:04:47	2020-03-08	Carley Langosh-Leannon	carley.langosh.leannon@warmmail.com	San Francisco	California	4498051061758	87b2937e033bb0c2c2949170955f9b85	VISA 16 digit	37.7564252481698688	-122.39151448105828
14842	2020-03-08 08:08:35	2020-03-08	Dr. Delma Langosh MD	dr.delma.langosh.md@woohoo.com	Chattanooga	Tennessee	54515120028346652	3f9ece2fea0e20c5613706304699ab7e	Diners Club / Carte Blanche	35.0446467191763276	-85.2656387470956929
14843	2020-03-08 08:32:40	2020-03-08	Dr. Helyn Greenholt DVM	dr.helyn.greenholt.dvm@geemail.com	San Francisco	California	4215201290487	6e9d74f6bb559e0e621d7417185f8e02	Mastercard	37.7730577719084266	-122.432866714304438
14844	2020-03-08 08:44:24	2020-03-08	Mr. Hyman Heidenreich	mr.hyman.heidenreich@geemail.com	Denton	Texas	3004495683396988	663e1c04b23be8560a5d7267eb1cfe67	Diners Club / Carte Blanche	33.1672535749882442	-97.1224862698592233
14845	2020-03-08 08:58:24	2020-03-08	Jillian Cassin	jillian.cassin@geemail.com	San Francisco	California	3096787949713586003	54a7392246e46eff3427eadda470b706	Diners Club / Carte Blanche	37.785490428144108	-122.451643123145203
14846	2020-03-08 08:59:24	2020-03-08	Camren Jacobson	camren.jacobson@geemail.com	Stamford	Connecticut	3337405171651116840	1d5f21e15720597e6d4ed574541edfa5	VISA 16 digit	41.0848284648615873	-73.543434615949181
14847	2020-03-08 09:03:25	2020-03-08	Whitney Nicolas	whitney.nicolas@geemail.com	New York	New York	3158539013559624021	ca1632d55d9cecb72dd0d77950f3804c	Discover	40.6611529879495492	-73.855866169872499
14848	2020-03-08 09:04:14	2020-03-08	Haley Reichert	haley.reichert@warmmail.com	San Francisco	California	4991498007091066	4051415777ee6430338a959561dd021f	Diners Club / Carte Blanche	37.7956367178199883	-122.466492761200954
14849	2020-03-08 09:07:30	2020-03-08	Napoleon VonRueden III	napoleon.vonrueden.iii@woohoo.com	St. Louis	Missouri	4204135673403026	64e0a9ee0dd91aad69dca666cb36b2d3	JCB 15 digit	38.5848195390000939	-90.2695954239465408
14850	2020-03-08 09:30:42	2020-03-08	Starla Schumm	starla.schumm@woohoo.com	North Las Vegas	Nevada	869964032304284041	737a9ef24bda251e49d3bccdfd009f6a	Mastercard	36.2132980263017075	-115.053272845198961
14851	2020-03-08 09:31:08	2020-03-08	Trevin Wuckert II	trevin.wuckert.ii@woohoo.com	San Francisco	California	4044022580982934	01b0b28aea8b9194037fa0591a2034c8	VISA 16 digit	37.7777343419285998	-122.476074962837615
14852	2020-03-08 09:32:35	2020-03-08	Ms. Candy Wilkinson	ms.candy.wilkinson@geemail.com	Greeley	Colorado	630496784243865	3192ddf05a378d25a48fea297ef96927	VISA 16 digit	40.3445537462431929	-104.790118954268095
14853	2020-03-08 09:53:02	2020-03-08	Marco Langworth	marco.langworth@woohoo.com	Lakewood	Colorado	3458635750927836	37ec28b77ff3b59cddca7d85542845c4	American Express	39.7142232400305559	-105.14381659161522
14854	2020-03-08 10:02:29	2020-03-08	Lulla Wintheiser	lulla.wintheiser@geemail.com	Colorado Springs	Colorado	210085885341794537	27225e817e16302fe80355c8b6ddd27f	VISA 16 digit	38.911039966629076	-104.701643533880642
14855	2020-03-08 10:09:23	2020-03-08	Dr. Mont Shanahan PhD	dr.mont.shanahan.phd@geemail.com	Denver	Colorado	3055563961896208	768e983969d4a541210d656799edd925	Diners Club / Carte Blanche	39.7498168229643198	-104.920553458273787
14856	2020-03-08 10:10:14	2020-03-08	Elex Keebler-Luettgen	elex.keebler.luettgen@geemail.com	Houston	Texas	4003272627718044	f5215927a2a229db714b28d3fd526ee1	VISA 16 digit	29.8043073526196167	-95.3252815869186065
14857	2020-03-08 10:34:33	2020-03-08	Miss Eleonore Altenwerth PhD	miss.eleonore.altenwerth.phd@geemail.com	Columbus	Ohio	869993130204469400	997426aa056fc91c6b5eca57921a807b	Discover	39.9489272212188666	-82.9230190993521461
14858	2020-03-08 10:43:28	2020-03-08	Kason Macejkovic	kason.macejkovic@geemail.com	San Francisco	California	4834821929892	5404ddf43f776a5be9fd83f1bcebb4a6	Mastercard	37.7767894747748088	-122.438936808009529
14859	2020-03-08 10:44:46	2020-03-08	Ozzie Strosin-Smith	ozzie.strosin.smith@geemail.com	Gainesville	Florida	869952774215700326	20e9afd4fdd95122a20e1ca49f10e224	VISA 16 digit	29.6958382448472058	-82.3313844452951145
14860	2020-03-08 10:53:38	2020-03-08	Ms. Glenda Walsh	ms.glenda.walsh@geemail.com	Joliet	Illinois	3337961892947832389	d057b47babf7ae5d12450206d00f4caa	Diners Club / Carte Blanche	41.5050160169459872	-88.2327494598563646
14861	2020-03-08 11:08:52	2020-03-08	Toya Runolfsson	toya.runolfsson@warmmail.com	Richmond	Virginia	180002246610115062	61a21224b3d058320bfa1152e465f7b1	Maestro	37.535795900620144	-77.4047758415564857
14862	2020-03-08 11:14:53	2020-03-08	Shelbie Ortiz	shelbie.ortiz@geemail.com	New York	New York	3337397521616332900	5bc661ba90ad8ef042e7ce05201a81af	Discover	40.7185139830913414	-73.9548645958200126
14863	2020-03-08 11:54:22	2020-03-08	Waldo Rempel	waldo.rempel@geemail.com	Aurora	Colorado	3337410456137175715	34ff94263e8ff68d48d8327a2b0082d6	VISA 13 digit	39.7831683024410196	-104.687692699407037
14864	2020-03-08 11:57:48	2020-03-08	Kristoffer Bednar-Reichel	kristoffer.bednar.reichel@geemail.com	Tyler	Texas	4985321531178035	1d85989cd818da3b0461411e11a0ba69	Diners Club / Carte Blanche	32.3318516384858654	-95.3258231356382311
14865	2020-03-08 11:59:15	2020-03-08	Karina Lowe	karina.lowe@geemail.com	Springfield	Massachusetts	3481543776623150	b9df01ddaac3d55ca02b6c19398054a2	JCB 16 digit	42.1370361186303199	-72.4844551100954533
14866	2020-03-08 12:05:23	2020-03-08	Dr. Justin Ullrich V	dr.justin.ullrich.v@geemail.com	Springfield	Missouri	3052957309321072	07ecc9e3d47a40370370337f6b206d08	American Express	37.1893807980425706	-93.2495066967152155
14867	2020-03-08 12:17:22	2020-03-08	Natosha Kessler	natosha.kessler@geemail.com	Fort Worth	Texas	869907967405313514	baf72936079a3b271f96ae86dd0afb85	JCB 15 digit	32.73994380888157	-97.3481502906706169
14868	2020-03-08 12:36:49	2020-03-08	Vander Mraz MD	vander.mraz.md@woohoo.com	Elgin	Illinois	180089181258172040	6f05ee940224c30fe2b56d29d7f12d9d	JCB 15 digit	42.0310378313813331	-88.3837883551426273
14869	2020-03-08 13:14:57	2020-03-08	Manson Johnson III	manson.johnson.iii@geemail.com	Yonkers	New York	3498490727067171	f5400c53a77f44b8cfb4190c45eb41bd	Diners Club / Carte Blanche	40.9067914309646952	-73.8292342009838762
14870	2020-03-08 13:24:13	2020-03-08	Scottie Cruickshank	scottie.cruickshank@geemail.com	Salt Lake City	Utah	502012281199500	22e69852c3e56ebcc376b3e6732edfb7	Discover	40.8278991876315303	-111.883515166392542
14871	2020-03-08 13:28:51	2020-03-08	Carlisle Morar	carlisle.morar@geemail.com	San Francisco	California	869913644969883636	4b1cadbeba243d683577437c779087aa	Maestro	37.73487003215876	-122.438535994909657
14872	2020-03-08 13:36:24	2020-03-08	Earlene Jones	earlene.jones@woohoo.com	Saint Paul	Minnesota	6011604156962684106	7e5cae05115b84cd236a6df4c770f689	Maestro	44.8908963918160637	-93.0419349985927369
14873	2020-03-08 13:47:10	2020-03-08	Valentine McLaughlin	valentine.mclaughlin@woohoo.com	Phoenix	Arizona	52508815392734677	b5b37c4c266cd02dc540d8ce12bffccd	VISA 16 digit	33.6549137765008979	-112.145071292614944
14874	2020-03-08 14:27:03	2020-03-08	Kaiden Carter	kaiden.carter@geemail.com	Irving	Texas	4148760119989	e04cad68b59ae006b5b2a38bfa680266	Voyager	32.7705143874462692	-96.9688042967859616
14875	2020-03-08 14:40:33	2020-03-08	Vester Wintheiser	vester.wintheiser@woohoo.com	Dallas	Texas	3057398450760864	e0172743b175498b087f2c781a45a124	VISA 13 digit	32.8402557933509343	-96.810825855048364
14876	2020-03-08 14:43:18	2020-03-08	Sibbie Hauck	sibbie.hauck@warmmail.com	Chandler	Arizona	180041407129173264	7ac8278205ac87b7cca376b8c3087097	JCB 16 digit	33.3585998038850704	-111.944986337272084
14877	2020-03-08 14:44:19	2020-03-08	Miss Sage Gerhold MD	miss.sage.gerhold.md@geemail.com	San Francisco	California	4878725249131302	7c034aa45f8c7a2602594292781ce4fe	JCB 16 digit	37.7771347318134758	-122.432956192142584
14878	2020-03-08 14:59:12	2020-03-08	Roswell Beatty	roswell.beatty@geemail.com	Green Bay	Wisconsin	676376884500513	856a59c94f70e8da7414ad7b6ed8316d	Voyager	44.4998974171530435	-87.9337315732900038
14879	2020-03-08 15:00:13	2020-03-08	Maralyn Nitzsche	maralyn.nitzsche@warmmail.com	Springfield	Massachusetts	4241801619749443	5e433a0e2773edc0007357a183401ac7	American Express	42.1516474363133256	-72.5567523903306579
14880	2020-03-08 15:05:00	2020-03-08	Jonathan Wiza DVM	jonathan.wiza.dvm@geemail.com	Oakland	California	3043082945065733	f1e7e1754875d00de70cb472e719f765	VISA 13 digit	37.8254234910342291	-122.256363448280084
14881	2020-03-08 15:13:30	2020-03-08	Shaina Borer	shaina.borer@woohoo.com	Charlotte	North Carolina	53154617420250859	a46de6aabe14887a0b099ae03bf61e38	VISA 16 digit	35.1321833122774976	-80.8949292744919717
14882	2020-03-08 15:16:09	2020-03-08	Dr. Margarita Jones	dr.margarita.jones@warmmail.com	Las Vegas	Nevada	51063250621678361	5cb714f73d5c117dcd380ca8ac82c50d	VISA 16 digit	36.2082984801948058	-115.261083567629001
14883	2020-03-08 15:38:15	2020-03-08	Evert Douglas-Luettgen	evert.douglas.luettgen@geemail.com	San Mateo	California	210034930364693281	10e0140038b389a99afb105e104d6052	VISA 16 digit	37.5971921702727627	-122.260620730588585
14884	2020-03-08 15:49:43	2020-03-08	Miss Patricia Davis DDS	miss.patricia.davis.dds@geemail.com	Berkeley	California	3528017820828001323	5c9ea31833589552bad897669c5f9439	JCB 15 digit	37.8667985048595881	-122.282892076296363
14885	2020-03-08 15:50:35	2020-03-08	Abie Morissette-Schmeler	abie.morissette.schmeler@woohoo.com	San Francisco	California	3025145707266514	757c1228ede94bedd4fd77c125dfee83	VISA 16 digit	37.7829339014052579	-122.381414784421295
14886	2020-03-08 16:24:15	2020-03-08	Ms. Thora Kiehn DVM	ms.thora.kiehn.dvm@warmmail.com	Houston	Texas	6011952338705149625	434a43f728cc30ddad7b06fbe265862f	VISA 16 digit	29.84739432568513	-95.3874462748427021
14887	2020-03-08 16:24:21	2020-03-08	Tishie Kub	tishie.kub@geemail.com	San Francisco	California	869992836949164095	20f19f97d3a585323ca645c68cb1022c	Mastercard	37.7698832002176061	-122.398510844548483
14888	2020-03-08 16:30:14	2020-03-08	Sada Swaniawski	sada.swaniawski@geemail.com	San Francisco	California	502056495778286	20f9fe51a62526272b0f4c900eae2e34	Voyager	37.7667373802521453	-122.44371864769866
14889	2020-03-08 16:30:48	2020-03-08	Carlos Farrell	carlos.farrell@geemail.com	Anaheim	California	6011183835411154451	5d6502cfeafd5d665bc777ffe2161a74	VISA 13 digit	33.9343972769863882	-117.736405946754289
14890	2020-03-08 16:39:04	2020-03-08	Risa Green DVM	risa.green.dvm@woohoo.com	Richardson	Texas	4894130361263308	bf287fda4dddaca2ab3c97279f1409c9	Discover	33.0338421731956302	-96.7128552625183033
14891	2020-03-08 16:39:32	2020-03-08	Dakotah Muller	dakotah.muller@geemail.com	New Orleans	Louisiana	4553382979445510	440f46e3a9c6acc0c7bce2ead14cd8c3	JCB 16 digit	30.1305633199881768	-89.9000191097874222
14892	2020-03-08 16:40:26	2020-03-08	Gustave Kihn-Pacocha	gustave.kihn.pacocha@woohoo.com	Jacksonville	Florida	3112832174560301563	17bb9239d07b83a9444458d211225925	Maestro	30.2904462458617978	-81.6740889699276664
14893	2020-03-08 16:45:53	2020-03-08	Darnell Labadie	darnell.labadie@geemail.com	Charlotte	North Carolina	3088971968423078057	dbb8364ee416258ce9832b43386b4f3c	VISA 13 digit	35.1163506372153762	-80.8909302538670687
14894	2020-03-08 16:47:16	2020-03-08	Joanie Hudson	joanie.hudson@warmmail.com	Lakeland	Florida	210020152446920790	8bde72f5dcaf57d8aa33c02ecd6ab20c	Discover	28.0958148906771079	-81.9291003747727729
14895	2020-03-08 16:57:06	2020-03-08	Ms. Shaylee Mertz	ms.shaylee.mertz@warmmail.com	Philadelphia	Pennsylvania	4340909655159516	bedda0a7dc16e27aee436e03db558b17	VISA 16 digit	39.9890540370676675	-75.0731516293149497
14896	2020-03-08 17:06:24	2020-03-08	Elna Funk MD	elna.funk.md@woohoo.com	Miami	Florida	4627220077945	4b29be328cc982a079ef5645dd05f11a	VISA 13 digit	25.8152074286852056	-80.2975483511913666
14897	2020-03-08 17:11:53	2020-03-08	Gale Labadie	gale.labadie@woohoo.com	Hialeah	Florida	3753335741268680	81ac7adc08683800cb68c405724fd10f	Mastercard	25.7925717096753431	-80.3371076363973202
14898	2020-03-08 17:31:23	2020-03-08	Irma Kirlin DDS	irma.kirlin.dds@woohoo.com	San Francisco	California	52854066832322950	423193a748b9693822b90ed52b3c4296	Mastercard	37.7781439689438514	-122.420733523248259
14899	2020-03-08 17:31:59	2020-03-08	Lannie Gerlach	lannie.gerlach@warmmail.com	North Las Vegas	Nevada	3459992691629297	8334bf55a657625d5250c3570559de79	Mastercard	36.2197361415874184	-115.128555751660471
14900	2020-03-08 17:42:55	2020-03-08	Tatiana Funk	tatiana.funk@geemail.com	Atlanta	Georgia	210065825149041354	ecdebe2cec9dac131f8c6290ceef7923	American Express	33.7445773657687056	-84.4598120044030338
14901	2020-03-08 18:04:20	2020-03-08	Jame Rutherford	jame.rutherford@geemail.com	Madison	Wisconsin	3732323461238147	a6a554eda330297f67cf0ddfe825b48a	VISA 13 digit	43.1090798955384642	-89.3489083571709699
14902	2020-03-08 18:16:55	2020-03-08	Claud Ondricka	claud.ondricka@geemail.com	Miami	Florida	4114949356595	17af7d84ad2b00553efdbbd408ec3289	American Express	25.7684186655700209	-80.2017992661208012
14903	2020-03-08 18:33:02	2020-03-08	Mrs. Yamilex Hintz	mrs.yamilex.hintz@woohoo.com	San Francisco	California	502007071653476	9765caceeaadb8921954788182fc5f96	JCB 16 digit	37.7814120529302997	-122.398157125398868
14904	2020-03-08 18:50:44	2020-03-08	Mr. Dalvin Yost Sr.	mr.dalvin.yost.sr.@geemail.com	San Francisco	California	4585099672156	070b81fdfd6983e7ee6bdf1f1cf69310	American Express	37.786630081515213	-122.436671361432516
14905	2020-03-08 18:52:57	2020-03-08	Daquan Rau	daquan.rau@geemail.com	Aurora	Illinois	501890533897964	efbeec0e7f6afcffcb17d46c7c35ca59	Maestro	41.8395662192013091	-88.2151147931277677
14906	2020-03-08 19:04:02	2020-03-08	Hurley Kreiger	hurley.kreiger@geemail.com	San Francisco	California	180081252200333994	7843acf8fcd5c9ce0ff740a5e02282c3	Mastercard	37.7567607889317358	-122.436935148380201
14907	2020-03-08 19:12:46	2020-03-08	Irvin D'Amore	irvin.d'amore@woohoo.com	Oklahoma City	Oklahoma	3788148084952995	3cb033fd8987e30028834101880e0752	American Express	35.4401089860968312	-97.4328896960139303
14908	2020-03-08 19:13:04	2020-03-08	Lilburn Johns	lilburn.johns@geemail.com	Evansville	Indiana	52333237826039386	b4f5c1ec10ccf22864a0bb396ca2a6c8	Voyager	38.0735413463924033	-87.6170821444530077
14909	2020-03-08 19:38:23	2020-03-08	Fabiola Bahringer	fabiola.bahringer@geemail.com	Charlotte	North Carolina	3112401658353940042	1e988872ebb0faa7ecd6785c595af93e	JCB 16 digit	35.2472338236656029	-80.8765230023712007
14910	2020-03-08 19:39:35	2020-03-08	Dr. Burrel Bogisich	dr.burrel.bogisich@geemail.com	Jacksonville	Florida	6011146755556075863	c1f387b81a7ee4f2cc668a434596e34d	Voyager	30.4344122584030039	-81.7270822787735653
14911	2020-03-08 19:43:49	2020-03-08	Bird Sauer	bird.sauer@geemail.com	Arlington	Texas	561261274124447	4a9afc1dfb2b4468e0578cdba406d95b	VISA 16 digit	32.7536541163705266	-97.1132072859004154
14912	2020-03-08 19:58:28	2020-03-08	Dr. Bennie Hilpert	dr.bennie.hilpert@warmmail.com	Portland	Oregon	060409023224539	78773847cc51d7c812591b74775d3fa9	JCB 16 digit	45.4546883458159883	-122.57859168304131
14913	2020-03-08 20:08:53	2020-03-08	Dr. Ricki Dibbert	dr.ricki.dibbert@geemail.com	San Francisco	California	589361293386753	fe41c079de8e2b3b9100702c8cdfe538	Diners Club / Carte Blanche	37.7145601497337992	-122.440569012991816
14914	2020-03-08 20:14:45	2020-03-08	Hellen Greenholt-Schmidt	hellen.greenholt.schmidt@warmmail.com	Phoenix	Arizona	3032404600690103	ec8637a3062ecb72e9b5e48d1c390177	VISA 16 digit	33.4845820655513577	-112.068869729658971
14915	2020-03-08 20:16:46	2020-03-08	Trinity Wiza	trinity.wiza@geemail.com	Detroit	Michigan	4138344945066	20ea68f641b8fa836c816b860127f7bc	American Express	42.385428088150924	-83.0421902368895672
14916	2020-03-08 20:33:00	2020-03-08	Ms. Mary Lind	ms.mary.lind@geemail.com	Philadelphia	Pennsylvania	3738342766962551	4c8ea0b447e695ebd975445a885ed07b	Diners Club / Carte Blanche	40.0255870036274217	-75.1218431411210474
14917	2020-03-08 21:28:57	2020-03-08	Antoinette Boyle	antoinette.boyle@warmmail.com	Killeen	Texas	3088336079657511654	c92c557ccc1415609e576977b82200c9	Mastercard	31.1514264675553889	-97.6350105005949729
14918	2020-03-08 21:37:11	2020-03-08	Zayden Hintz	zayden.hintz@geemail.com	Berkeley	California	52612210420870144	a0e4fcda59f48c598eba6f43a3c05283	VISA 13 digit	37.8722588727403817	-122.279486873199332
14919	2020-03-08 21:43:31	2020-03-08	Mrs. Louann Bayer	mrs.louann.bayer@geemail.com	San Francisco	California	3042281849522572	bc069bbc3cbaff9b77028f769bff73ec	Mastercard	37.7601651387189392	-122.428277015512052
14920	2020-03-08 21:50:22	2020-03-08	Miss Valeria Weber	miss.valeria.weber@geemail.com	Kansas City	Missouri	4530104157685636	9c5d3455ba4d018be98f26a4612244bc	JCB 16 digit	39.0672319300774546	-94.642558254696425
14921	2020-03-08 22:01:13	2020-03-08	Ena Christiansen	ena.christiansen@geemail.com	Berkeley	California	060412231715090	b25a9e65d2f71ac5d7f6717c36ccee33	American Express	37.8705253635677792	-122.319571226379139
14922	2020-03-08 22:05:31	2020-03-08	Dominick Corwin	dominick.corwin@warmmail.com	San Antonio	Texas	6011639269317485357	f0d7433e4be34b07454abfae1c611938	Diners Club / Carte Blanche	29.5423905993416902	-98.6215946100953857
14923	2020-03-08 22:12:30	2020-03-08	Talmadge Keeling	talmadge.keeling@geemail.com	Berkeley	California	55432279996296248	5c7cc65223fd0e7f944d82b9b5f8ae92	VISA 13 digit	37.8442997605907365	-122.272621716582947
14924	2020-03-08 22:21:21	2020-03-08	Berta Hilll	berta.hilll@warmmail.com	Seattle	Washington	3528086128905303802	1190e07de4025f150c9beab0b19af090	JCB 16 digit	47.6332637689001857	-122.303598939759283
14925	2020-03-08 22:35:12	2020-03-08	Georgeanna Mraz	georgeanna.mraz@geemail.com	Fort Worth	Texas	4845692530585	c5679320608d03871e2f6836c07e99be	VISA 16 digit	32.7539159386474665	-97.3188511124633209
14926	2020-03-08 22:36:36	2020-03-08	Quint Cartwright	quint.cartwright@geemail.com	San Francisco	California	3040246818628140	a26661ccee05fd1f32b4098d48c4b46f	JCB 16 digit	37.7898629274888265	-122.43495773166795
14927	2020-03-08 22:50:23	2020-03-08	Miss Elvina Kilback	miss.elvina.kilback@geemail.com	Vacaville	California	3088192896036487287	7f5e5ab3f4b4942f8e9b9274627cff7c	American Express	38.3887662455100624	-121.884180199063579
14928	2020-03-08 23:03:50	2020-03-08	Rahul Dicki	rahul.dicki@warmmail.com	New York	New York	6011666928942966091	f42132a4d11adc6e864a3bbf4927436e	Diners Club / Carte Blanche	40.6157204383276422	-73.9490853967506467
14929	2020-03-08 23:10:47	2020-03-08	Saul Wunsch Sr.	saul.wunsch.sr.@geemail.com	Tulsa	Oklahoma	060432324074973	43f50b23aafd62d250428c54c285cd28	Diners Club / Carte Blanche	36.0781038708887962	-95.8892327059015628
14930	2020-03-08 23:19:36	2020-03-08	Mrs. Cathrine Rippin DVM	mrs.cathrine.rippin.dvm@warmmail.com	Louisville	Kentucky	4970962555398400	2eb8b9ae28a5a70e8e0332fa4569ec7c	Voyager	38.2155492030452919	-85.5536991647515492
14931	2020-03-08 23:24:52	2020-03-08	Milas Mayer PhD	milas.mayer.phd@geemail.com	Vancouver	Washington	4719046971781369	98f24d0860634ecca7d102470d10cf51	American Express	45.6412948506023781	-122.547551141406217
14932	2020-03-08 23:28:18	2020-03-08	Consuelo Halvorson	consuelo.halvorson@geemail.com	New York	New York	54602521918333755	08c7dd03739c367c0e821dfaad3e5717	VISA 16 digit	40.582132015213368	-74.0195201253879844
14933	2020-03-08 23:54:03	2020-03-08	Dr. Vaughn Hilll PhD	dr.vaughn.hilll.phd@geemail.com	Washington	District of Columbia	3528731868194658320	bbce96a15a3b7823fb2b0cc826eb48fa	Voyager	38.9049493201341505	-76.9896566470831658
14934	2020-03-09 00:03:57	2020-03-09	Hanna Murphy	hanna.murphy@warmmail.com	Temecula	California	3158940295627100752	4317f3e9d3955294a8c8b6a0b2ff82a6	VISA 13 digit	33.5830876393843454	-117.209315900849916
14935	2020-03-09 00:09:20	2020-03-09	Christ Gulgowski	christ.gulgowski@geemail.com	Columbus	Ohio	54226848817900988	43408f073b20f180f57dbc7913d68433	American Express	39.9137117862280419	-83.0792545968901379
14936	2020-03-09 01:12:47	2020-03-09	Felix Williamson	felix.williamson@geemail.com	Washington	District of Columbia	210060140717367099	f8dca7317f53234f58e2d3ad910cefa5	Mastercard	38.9350229471255105	-77.0968554585453205
14937	2020-03-09 01:33:04	2020-03-09	Vicky O'Conner	vicky.o'conner@woohoo.com	Athens	Georgia	4583684425874	11c28eaf67875c5ddfef7797b42ea208	Diners Club / Carte Blanche	34.0335151133783143	-83.3993205878999078
14938	2020-03-09 01:38:47	2020-03-09	Latoyia Murazik DVM	latoyia.murazik.dvm@geemail.com	Ontario	California	52021907168839406	1b8b45145ebfc87097df4be16f4db279	JCB 15 digit	33.9807777712732531	-117.605492956667021
14939	2020-03-09 01:53:41	2020-03-09	Milo Fadel	milo.fadel@geemail.com	Centennial	Colorado	4954773698400	c6e96b11c0991102f27a0fdbfc8cacff	VISA 16 digit	39.6042293296702255	-104.81138842379525
14940	2020-03-09 02:12:27	2020-03-09	Tia Hauck	tia.hauck@geemail.com	Long Beach	California	3043623819846631	21169f985943ea5e1df5a116fa621395	Mastercard	33.740637529949467	-118.116515812107551
14941	2020-03-09 02:25:06	2020-03-09	Schuyler Littel	schuyler.littel@geemail.com	Round Rock	Texas	502036974120341	c4d43edb1dc7e4ae42f2884becb5af92	Discover	30.4835069695159824	-97.6584765546340492
14942	2020-03-09 02:54:52	2020-03-09	Dr. Beryl Trantow	dr.beryl.trantow@geemail.com	Washington	District of Columbia	869925070685646865	f89cc65fbecbd125502897c28203810f	American Express	38.8193736964635576	-77.038293914797535
14943	2020-03-09 02:57:26	2020-03-09	Sheyla Goodwin	sheyla.goodwin@woohoo.com	Tucson	Arizona	676264974650232	62b542aa9342fd18aafa15a508c30a4b	Maestro	32.0867013785563415	-110.947833339380466
14944	2020-03-09 03:24:48	2020-03-09	Mrs. Deetta Wolff	mrs.deetta.wolff@geemail.com	Tulsa	Oklahoma	3112166610620873808	44c4a746c4cb4adc32e928a4f4f32fac	VISA 16 digit	36.0490967478506263	-95.9053747383832871
14945	2020-03-09 03:35:43	2020-03-09	Clare Jacobson	clare.jacobson@geemail.com	New York	New York	54764415423708482	7b359981ed1e55f2c4ab1a28e5874d7f	Voyager	40.7560644749775491	-73.952720810695368
14946	2020-03-09 03:39:47	2020-03-09	Robley Lesch	robley.lesch@geemail.com	Cleveland	Ohio	180024429817845285	f2864cb402ae8bf7c9bb80547edb8529	Mastercard	41.5760755908992081	-81.7085353001259307
14947	2020-03-09 03:52:48	2020-03-09	Mrs. Siena Nader DVM	mrs.siena.nader.dvm@geemail.com	San Francisco	California	4428865223478256	36f37c52f328f408fc1c93577a95971e	Mastercard	37.7792403828447334	-122.424168916347142
14948	2020-03-09 03:53:48	2020-03-09	Oline Swift DDS	oline.swift.dds@warmmail.com	Chattanooga	Tennessee	210072313768206203	8ae89320a56b2336197387100a6eadbd	Discover	35.0080248118229207	-85.2014461087357233
14949	2020-03-09 03:54:14	2020-03-09	Mack Grant	mack.grant@geemail.com	Louisville	Kentucky	6011582059326302546	d84b44842ec81fe32a6eb32d6e6553ad	JCB 16 digit	38.1897940497748536	-85.6942218464870109
14950	2020-03-09 04:00:20	2020-03-09	Richard Leannon	richard.leannon@geemail.com	San Jose	California	869972308687234328	4d68ea71b9a930170e9dfa36ecbffed4	VISA 13 digit	37.2165999976273625	-121.774358976980295
14951	2020-03-09 04:08:09	2020-03-09	Leigh Sauer	leigh.sauer@geemail.com	Philadelphia	Pennsylvania	210078757412304844	6f5c9615408b56cd3b6748265c98bc17	Mastercard	40.0597600388765329	-75.1981516676388679
14952	2020-03-09 04:18:43	2020-03-09	Renard Wuckert	renard.wuckert@geemail.com	Arlington	Texas	3402061359396967	39415e68d25f3b5c4ac4520044543c62	Mastercard	32.6048435174178337	-97.1033479116417482
14953	2020-03-09 04:34:11	2020-03-09	Tiffani Simonis	tiffani.simonis@geemail.com	Fresno	California	3337202272531048040	e61e6e73941e9dfa79d0ed219a764a8c	Mastercard	36.7110461974389821	-119.88969608569667
14954	2020-03-09 04:35:08	2020-03-09	Nana DuBuque	nana.dubuque@geemail.com	Dayton	Ohio	4690078055512	ce2291a440a39032955fe53baae8f2e1	Diners Club / Carte Blanche	39.7638129630848738	-84.1512174857039099
14955	2020-03-09 04:35:56	2020-03-09	Mr. Mckinley Armstrong	mr.mckinley.armstrong@warmmail.com	Killeen	Texas	4819407696419611	9f381186dddeffe4a139ee6b72ca0c85	American Express	31.0338762250028566	-97.6350691302847054
14956	2020-03-09 04:41:48	2020-03-09	Enid Metz	enid.metz@geemail.com	San Francisco	California	180081169471076476	36974cdacae03f4796c728bee4633cf2	Mastercard	37.7753820779661211	-122.449203022146065
14957	2020-03-09 05:03:11	2020-03-09	Ms. Dennie Heidenreich DDS	ms.dennie.heidenreich.dds@geemail.com	Laredo	Texas	4401898579834	875b9875bf6d835299d768f7f98b7369	VISA 16 digit	27.5783586062207817	-99.4361636020250614
14958	2020-03-09 05:52:55	2020-03-09	Eugenio Kilback	eugenio.kilback@warmmail.com	Laredo	Texas	4724558385032448	7f1228c9948888bb2fdc4859c31c74e6	Mastercard	27.4689235899779973	-99.3895781336825337
14959	2020-03-09 05:59:30	2020-03-09	Tania Batz	tania.batz@geemail.com	Pearland	Texas	3088806373340527115	9c97b14e4dc02b2087ca400d628e8cf9	JCB 15 digit	29.5625259377799949	-95.4175447745103327
14960	2020-03-09 06:00:43	2020-03-09	Dr. Cathern Rolfson DVM	dr.cathern.rolfson.dvm@geemail.com	Houston	Texas	869962784901971055	58a09ac3270109a3dd6b4f5c54896928	VISA 13 digit	29.7766573187042027	-95.4153455100968557
14961	2020-03-09 06:13:45	2020-03-09	Hayward Gibson	hayward.gibson@woohoo.com	Houston	Texas	180070355454259147	65aeadfd7995377a2f24b74c97b69ca1	VISA 16 digit	29.7588976027987897	-95.3717505094610232
14962	2020-03-09 06:36:57	2020-03-09	Mrs. Eartha Prosacco	mrs.eartha.prosacco@geemail.com	Los Angeles	California	4321843240751060	b3f3da003164d982891a2592831795c1	Voyager	33.9671361954748576	-118.371122813317172
14963	2020-03-09 06:50:45	2020-03-09	Roxie Pfannerstill	roxie.pfannerstill@geemail.com	Huntsville	Alabama	4977489972241511	386bf8f9d32a87ad40ae928d76fe86e7	VISA 16 digit	34.729376023985445	-86.6643720568176406
14964	2020-03-09 07:16:44	2020-03-09	Freddy Luettgen	freddy.luettgen@geemail.com	Springfield	Missouri	675974768793965	22882804d2a177d00a7f53ee569613b2	VISA 13 digit	37.1420203569538927	-93.3016185854852296
14965	2020-03-09 07:26:44	2020-03-09	Vallie Langworth DDS	vallie.langworth.dds@geemail.com	Scottsdale	Arizona	3088725617953300956	e55c8750352b660f6e259a49468bee91	Maestro	33.7259611463297162	-111.877548716493322
14966	2020-03-09 07:47:55	2020-03-09	Miss Naoma Moen DDS	miss.naoma.moen.dds@warmmail.com	Berkeley	California	55308261025947398	58bd14012a747a26574b0d056578ec6e	JCB 16 digit	37.9000712512937525	-122.265897391551121
14967	2020-03-09 07:48:00	2020-03-09	Clementine Stanton-Mraz	clementine.stanton.mraz@geemail.com	Seattle	Washington	639072696940625	b838351889b69abc97181d814569d3da	JCB 16 digit	47.696558160047978	-122.29790193027965
14968	2020-03-09 07:52:08	2020-03-09	Timmie Kozey	timmie.kozey@geemail.com	Milwaukee	Wisconsin	060452234017615	f49c04320ae7ea385be7882331c198b0	VISA 13 digit	43.1025162394244177	-87.8740601064737916
14969	2020-03-09 07:58:37	2020-03-09	Mr. Harding O'Kon	mr.harding.o'kon@geemail.com	San Francisco	California	3528933489124613172	5d933a10ef19c200ab543d5493b15bad	JCB 15 digit	37.7696729679779679	-122.42047979296936
14970	2020-03-09 08:09:00	2020-03-09	Manning Sauer	manning.sauer@geemail.com	San Francisco	California	4085610266119019	1bef37dd77456610ccec815543f37fd2	JCB 16 digit	37.7751220075286582	-122.421529745983065
14971	2020-03-09 08:12:34	2020-03-09	Mr. Ogden Hane	mr.ogden.hane@geemail.com	Albuquerque	New Mexico	4837119125642543	9a1ce93498a6e5979f7bf39cf03f3822	Diners Club / Carte Blanche	35.1726994456391822	-106.67655073325858
14972	2020-03-09 08:53:13	2020-03-09	Clarance Daugherty	clarance.daugherty@geemail.com	San Francisco	California	3728321381958113	9989d1a29553c19367489b6aadb076cd	Maestro	37.7808865989057807	-122.439617111121862
14973	2020-03-09 09:24:59	2020-03-09	Enrico Kihn	enrico.kihn@woohoo.com	Los Angeles	California	869994678753853241	b60f8f32327a255cda50f10cab6b1392	Maestro	33.9257212413806428	-118.400180599604909
14974	2020-03-09 09:48:08	2020-03-09	Cordia Stiedemann	cordia.stiedemann@warmmail.com	San Francisco	California	3050880738119002	d4dfcd678dfc0404597a90ee9cf4cb89	American Express	37.7665921464573202	-122.445202044396112
14975	2020-03-09 09:52:40	2020-03-09	Arron Nikolaus	arron.nikolaus@geemail.com	Oakland	California	4451305443010878	81f685ff7143d70d2f1c95092e210855	VISA 16 digit	37.8152611806581049	-122.233201005236666
14976	2020-03-09 10:13:51	2020-03-09	Daphne Jacobs-Gleason	daphne.jacobs.gleason@geemail.com	Spokane	Washington	6011216839084944306	2d0a77332246479230e9df29bf8c0726	Mastercard	47.756993080606307	-117.420932902804765
14977	2020-03-09 10:21:45	2020-03-09	Mrs. Allean Harber	mrs.allean.harber@geemail.com	Wilmington	North Carolina	589316682500679	71dc11e0ad003811a3ec731ee002bd71	JCB 16 digit	34.135573852835968	-77.8057179904069756
14978	2020-03-09 10:54:23	2020-03-09	Brooklyn Grimes	brooklyn.grimes@geemail.com	Indianapolis	Indiana	060472150388527	5468302c3a6be1ea8fcdbeede515e0c0	JCB 16 digit	39.6784042489256663	-86.2454348494965615
14979	2020-03-09 11:02:24	2020-03-09	Karina Schneider	karina.schneider@geemail.com	Knoxville	Tennessee	3112709540624079140	4c406ea233a3471a5e74f428582f7765	VISA 16 digit	36.0397475726034529	-83.965999922736728
14980	2020-03-09 11:04:38	2020-03-09	Dot Mayert	dot.mayert@geemail.com	Durham	North Carolina	3026940292634913	47fb48b4ad4779a8aa405c6c8d6a935f	JCB 15 digit	35.9190389936104424	-78.9601748994920456
14981	2020-03-09 11:12:25	2020-03-09	Trace Shields	trace.shields@geemail.com	San Francisco	California	6011837556622246056	3d4028e9b1372698b46edd55255e93e4	Voyager	37.7783439920612452	-122.421367411079814
14982	2020-03-09 12:04:48	2020-03-09	Helena Kuhn DVM	helena.kuhn.dvm@geemail.com	Berkeley	California	4584182356090621	580f74f0f8d144d8c8c04baa2820835d	Maestro	37.8709934643063448	-122.235166584793348
14983	2020-03-09 12:26:40	2020-03-09	Norman Heller	norman.heller@geemail.com	Tampa	Florida	4498495002295799	3dba23411adaa788e1ce00cce6e54284	JCB 16 digit	27.9037161613929996	-82.4242357611868499
14984	2020-03-09 12:30:18	2020-03-09	Dr. Bradly Spencer V	dr.bradly.spencer.v@woohoo.com	Fayetteville	North Carolina	676309300493724	25fbaf48e15482df3c4afc9d29d56532	VISA 16 digit	35.1799038199029823	-78.9658605111427647
14985	2020-03-09 12:31:10	2020-03-09	German Little Jr.	german.little.jr.@geemail.com	Austin	Texas	6011932667948100200	868246c40d150a3235e18b0cc1442965	JCB 15 digit	30.3630623627115028	-97.6975318846531309
14986	2020-03-09 12:32:02	2020-03-09	Kylee Feil	kylee.feil@warmmail.com	San Francisco	California	3037147632780740	0a24f4d14717231d2ef69d98069aa4fb	JCB 15 digit	37.7490864712793552	-122.430708547617527
14987	2020-03-09 13:04:47	2020-03-09	Mitch Brown	mitch.brown@geemail.com	Port St. Lucie	Florida	4033966190732738	0cd362c61db75388469319c4fed45246	JCB 16 digit	27.3585912822414201	-80.4833445865746597
14988	2020-03-09 13:25:10	2020-03-09	Finley Stracke	finley.stracke@geemail.com	San Francisco	California	6011202276967336977	9ed065126f07c895693c5f3cffee0f13	VISA 13 digit	37.7415550171010352	-122.456273887551603
14989	2020-03-09 13:29:59	2020-03-09	Reilly Corwin-O'Keefe	reilly.corwin.o'keefe@geemail.com	Surprise	Arizona	676345150186166	43a0a0b8d69877a3c5b51f85b4b926c4	Voyager	33.6409499970026289	-112.391544116730614
14990	2020-03-09 13:47:16	2020-03-09	Gussie Fadel-Zulauf	gussie.fadel.zulauf@geemail.com	Columbia	South Carolina	3463522682073132	d3674886f7d1c8bd1e5134b1f2056cdd	Voyager	33.9642983638014613	-80.9216079761292804
14991	2020-03-09 13:59:28	2020-03-09	Alcee Reichert	alcee.reichert@geemail.com	New York	New York	3417150398348262	36f025907136b7c8c00ef6256beceb9a	Maestro	40.5820872815083717	-73.8730729145359248
14992	2020-03-09 14:02:18	2020-03-09	Mr. Lou Kilback MD	mr.lou.kilback.md@geemail.com	Baton Rouge	Louisiana	3431906656403855	e95c4a0e9b6d8210780455bc4166a9b9	VISA 13 digit	30.5320238015826781	-91.0723759897161216
14993	2020-03-09 14:06:38	2020-03-09	Vertie Wunsch	vertie.wunsch@geemail.com	New York	New York	869951130072069084	738ae7e90724d5b47cb3a168291fdce4	VISA 16 digit	40.6717171606365611	-73.9587804566964451
14994	2020-03-09 14:21:11	2020-03-09	Vashon Bayer	vashon.bayer@geemail.com	Orange	California	3158360389371003204	7f2ece26dd79e79d1c6bed00af7f8a90	JCB 16 digit	33.8380057854931806	-117.804755759435892
14995	2020-03-09 14:23:16	2020-03-09	Texanna Hayes	texanna.hayes@warmmail.com	Bellevue	Washington	6011650411065249460	a55b48980930e3172b95045430238fbf	Voyager	47.515582501953098	-122.076462146971366
14996	2020-03-09 14:24:20	2020-03-09	Chauncy Parker	chauncy.parker@geemail.com	Milwaukee	Wisconsin	4558433590517	11bc90aa2f46c36fe15db0d6fbaa08af	JCB 15 digit	43.0659403106749039	-88.0257220840647818
14997	2020-03-09 14:56:20	2020-03-09	Ms. Yessenia Ritchie	ms.yessenia.ritchie@geemail.com	Berkeley	California	6011656899041170848	0b1653fb3be834e713fc449eee22db1f	Maestro	37.8711635732187162	-122.273776028986916
14998	2020-03-09 14:56:29	2020-03-09	Abelardo Medhurst	abelardo.medhurst@geemail.com	San Francisco	California	53484700736145509	24f9ffb9d195e889a3229c5c1055f05a	JCB 16 digit	37.7754243036692117	-122.455758590560507
14999	2020-03-09 15:03:25	2020-03-09	Marshal Wilkinson MD	marshal.wilkinson.md@geemail.com	Laredo	Texas	6011943871455255376	ba159ef6914e16787b3b88a0aed58ce6	Diners Club / Carte Blanche	27.5362772794622934	-99.4300802838995992
15000	2020-03-09 15:17:34	2020-03-09	Mr. Genie Grant Sr.	mr.genie.grant.sr.@geemail.com	San Diego	California	53127535568745825	911820f4804274194566e4a2aaa7b0a8	Diners Club / Carte Blanche	32.7363403524339205	-117.188671680577102
15001	2020-03-09 15:27:27	2020-03-09	Louisa Koelpin DVM	louisa.koelpin.dvm@geemail.com	Dallas	Texas	3025079259713336	863c0d97d00dda9aabd71a274b63bf90	VISA 13 digit	32.8036062803857078	-96.8270973169207565
15002	2020-03-09 15:54:12	2020-03-09	Djuna Ryan	djuna.ryan@warmmail.com	Fort Worth	Texas	3088248415544978853	b49e3353de488d18a541777ae776ed55	JCB 15 digit	32.7280083843562792	-97.3835795947171761
15003	2020-03-09 16:00:57	2020-03-09	Madisyn King-Price	madisyn.king.price@geemail.com	Oakland	California	676175853117184	8a78553107dae6d6a70e2842016917c1	Voyager	37.7976961999226688	-122.247654914213086
15004	2020-03-09 16:07:04	2020-03-09	Sheryl Hegmann	sheryl.hegmann@woohoo.com	Atlanta	Georgia	4835378185002	e2c793a6931cf0d526aec46a17019e25	Discover	33.8200799150668132	-84.4985799373638002
15005	2020-03-09 16:07:14	2020-03-09	Rodger Feil	rodger.feil@geemail.com	Houston	Texas	4201542762152120	db3a6289a31c06bf27ee03e453657460	VISA 16 digit	29.8836900693908341	-95.3945149700637955
15006	2020-03-09 16:10:18	2020-03-09	Angelic Kilback	angelic.kilback@geemail.com	New York	New York	4397755653243626	dca236441b45784a0ad49703a3947a37	VISA 16 digit	40.5685720370374625	-73.9543687723938348
15007	2020-03-09 16:13:57	2020-03-09	Darrian Maggio	darrian.maggio@geemail.com	Moreno Valley	California	4112304396885130	30a00ed42359157770e517c739cc968e	JCB 16 digit	33.9857671053141317	-117.207642859822883
15008	2020-03-09 16:26:39	2020-03-09	Mr. Estel D'Amore Sr.	mr.estel.d'amore.sr.@geemail.com	Winston–Salem	North Carolina	3433379050608008	19f83977f1bbab78e9d496232c164061	VISA 16 digit	36.0304432400267558	-80.2648472787942637
15009	2020-03-09 16:47:54	2020-03-09	Ally Toy	ally.toy@warmmail.com	New York	New York	501825715750243	6235dcda1f78a2bd8ede485a3b661056	American Express	40.6234855508655315	-73.9545039938658419
15010	2020-03-09 16:51:34	2020-03-09	Dr. Genaro Romaguera MD	dr.genaro.romaguera.md@geemail.com	Carlsbad	California	3484690682293466	2c00beabfb7771ac64e197de4fb5b76f	American Express	33.0963463823251445	-117.216415113189441
15011	2020-03-09 17:02:43	2020-03-09	Elgie Rath	elgie.rath@geemail.com	Wichita	Kansas	180093039048139238	faca793c02571050884a1d36ad7d9dff	Mastercard	37.6246368437882523	-97.3733371049366951
15012	2020-03-09 17:06:35	2020-03-09	Reino Kub	reino.kub@geemail.com	Pomona	California	210017883424303717	8860533c277b52c122200f8357c02420	JCB 15 digit	33.9716759592797644	-117.684900772847612
15013	2020-03-09 17:43:55	2020-03-09	Matthias Mohr	matthias.mohr@geemail.com	Chicago	Illinois	3337844395160883991	88a89c93c1b853bba9ab25f0177f4388	JCB 15 digit	41.8501346997752819	-87.7757802384004009
15014	2020-03-09 17:44:53	2020-03-09	Benji Mertz	benji.mertz@geemail.com	Chula Vista	California	869986962812532032	03a4099cda56a131320981b4fb2af49a	Diners Club / Carte Blanche	32.6710680111542331	-117.069042109488322
15015	2020-03-09 17:50:46	2020-03-09	Cornie Altenwerth	cornie.altenwerth@geemail.com	Los Angeles	California	4511441874357	7dda57de3b3067394ddace6423416992	JCB 16 digit	34.0885823195200359	-118.472121442993355
15016	2020-03-09 17:52:55	2020-03-09	Gianna Pfeffer-Skiles	gianna.pfeffer.skiles@geemail.com	Arlington	Texas	4778755467844725	a690c1946f1e6290c99be55daed5e87f	Mastercard	32.7209928070444604	-97.1650226234018817
15017	2020-03-09 17:56:33	2020-03-09	Letty Emmerich MD	letty.emmerich.md@woohoo.com	Gainesville	Florida	4071072671803776	ef9da568b28221c774190cfda4ce0205	Voyager	29.5942499721713368	-82.2830734055828401
15018	2020-03-09 18:04:20	2020-03-09	Dr. Lennon Hahn Jr.	dr.lennon.hahn.jr.@geemail.com	Oklahoma City	Oklahoma	503841284326554	f4b9b35117d165b6951afb5ea8b2a22b	Maestro	35.4155416709747186	-97.5119153555378375
15019	2020-03-09 18:06:47	2020-03-09	Mr. Bryant Kilback I	mr.bryant.kilback.i@warmmail.com	New York	New York	210085200883115689	87954579a0056abc5045735229eeb09c	JCB 16 digit	40.670264838332308	-73.8851986376929943
15020	2020-03-09 18:21:14	2020-03-09	Modena Cole	modena.cole@geemail.com	New York	New York	3729996270129964	1cba27a11f93370810ae9cbe5836bc2b	Diners Club / Carte Blanche	40.755070936329659	-73.9636762705061557
15021	2020-03-09 18:45:10	2020-03-09	Kisha Heller	kisha.heller@geemail.com	San Francisco	California	4778701461380951	f859ee77d1288e1c6d54f64dd5528756	JCB 15 digit	37.7732033603428263	-122.431913691338877
15022	2020-03-09 18:47:03	2020-03-09	Kimberly Carroll-Towne	kimberly.carroll.towne@woohoo.com	South Bend	Indiana	3528437842493780611	d1b0dade6450100eaab371493b498252	JCB 15 digit	41.7157808585237717	-86.2348556250855438
15023	2020-03-09 19:02:24	2020-03-09	Bruce Weber	bruce.weber@geemail.com	San Francisco	California	4512515653792	f688dbce878ad8036d01cce51d5d3447	American Express	37.7346211871294557	-122.473293972451515
15024	2020-03-09 19:17:13	2020-03-09	Norbert Haley-Nader	norbert.haley.nader@geemail.com	Oakland	California	3528304828185729479	22fdc93b5af88f9d2dcd114400d47f52	Discover	37.8056624368731633	-122.270373929032687
15025	2020-03-09 19:34:49	2020-03-09	Jonatan Hand-Quigley	jonatan.hand.quigley@geemail.com	Nashville	Tennessee	3743079569590212	3a4bcb56566e9bbbc64178a371d663f9	Maestro	36.187860361452401	-86.7246614158526086
15026	2020-03-09 19:51:44	2020-03-09	Demetri Collins	demetri.collins@geemail.com	San Francisco	California	3158744574814484510	b6163df9493740e40e22052c8d5bb142	Voyager	37.7931315343620682	-122.452634282916122
15027	2020-03-09 20:25:36	2020-03-09	Atha Schoen DVM	atha.schoen.dvm@woohoo.com	Reno	Nevada	4164506942816	642caf2bef82225e641db4779ee4e502	VISA 13 digit	39.5939003006633428	-119.823426054434478
15028	2020-03-09 20:52:23	2020-03-09	Roosevelt Bosco	roosevelt.bosco@geemail.com	San Francisco	California	4420085736420715	4824fa469055bd488a65c6306b3bac0c	Voyager	37.772932094533445	-122.433866852950047
15029	2020-03-09 21:03:09	2020-03-09	Jarrod Leuschke	jarrod.leuschke@woohoo.com	San Francisco	California	639082935498764	74a27677113c53e94ccab2bc9474795e	JCB 16 digit	37.778197845325252	-122.440721023801572
15030	2020-03-09 21:31:29	2020-03-09	Eugenie Nitzsche DVM	eugenie.nitzsche.dvm@geemail.com	Fresno	California	3013771727836473	1949c8882fa9728331a0b1ee537c3af5	JCB 16 digit	36.7094630836848168	-119.752272813917699
15031	2020-03-09 21:35:13	2020-03-09	Mara Toy	mara.toy@warmmail.com	New York	New York	3713763522479144	af31ea4a5ba9d9441b73e0939235eec1	JCB 15 digit	40.7108053293302632	-73.8726603898581118
15032	2020-03-09 21:41:58	2020-03-09	Draven Block Jr.	draven.block.jr.@geemail.com	New York	New York	180029996425784812	c85d8ef5a4a9188d8cf8e04852a8e5ad	VISA 13 digit	40.6480751994289449	-73.8947563877224951
15033	2020-03-09 21:48:20	2020-03-09	Gaetano Quigley	gaetano.quigley@geemail.com	Des Moines	Iowa	4603340548557256	5b2a6cb2e676d5d20fbab7314d7ca4fd	JCB 16 digit	41.5335874445479405	-93.5420489703815434
15034	2020-03-09 21:53:54	2020-03-09	Ariella Baumbach	ariella.baumbach@geemail.com	San Francisco	California	676164104952342	0923fd1fe1cb945f5458cecac056729b	Discover	37.7367654052187831	-122.422491532739045
15035	2020-03-09 22:04:39	2020-03-09	Beckie Glover	beckie.glover@geemail.com	Chesapeake	Virginia	54362079345800045	6bf82b0baeb6fcac656f9a6cef36b31c	Maestro	36.6144549124181253	-76.2134756864357712
15036	2020-03-09 22:10:10	2020-03-09	Jaleel Hills	jaleel.hills@woohoo.com	New York	New York	3444864209683082	e447f08f4a5aa9a2a1e01f4c12a42687	Discover	40.6482542110830565	-73.8751074224140467
15037	2020-03-09 22:47:31	2020-03-09	Albin Welch	albin.welch@woohoo.com	Richmond	Virginia	4790512619454232	4b5a06ce862767c5b17249bad269103f	Maestro	37.5134763451512896	-77.4351715928167152
15038	2020-03-09 22:52:33	2020-03-09	Bradyn Blanda	bradyn.blanda@warmmail.com	San Francisco	California	3088096235547571874	b24f612712dece292a5b7ae98a6dfe24	Diners Club / Carte Blanche	37.7784543079717494	-122.426621751604074
15039	2020-03-09 23:24:00	2020-03-09	Mrs. Veta Nader	mrs.veta.nader@warmmail.com	Wilmington	North Carolina	3096293101264008600	41952735f512d62e9a6796a2d3ff9ba9	VISA 16 digit	34.1831478557836306	-77.9794859339475721
15040	2020-03-09 23:28:09	2020-03-09	Logan Kozey	logan.kozey@geemail.com	Oakland	California	4518314386039	a20d3ba74a0e896bc4d95e96ba58d184	VISA 16 digit	37.8164905524693253	-122.285777145434011
15041	2020-03-09 23:42:34	2020-03-09	Cale Marvin	cale.marvin@woohoo.com	Indianapolis	Indiana	3475127886102277	a56eec1b07f2d9e08e3ea5b4b511d9bd	JCB 16 digit	39.7616276037421059	-86.1219066754184581
15042	2020-03-09 23:46:13	2020-03-09	Mitzi Pollich	mitzi.pollich@warmmail.com	New York	New York	6011201139687770696	075459fb97a2208a14d57189e808cdce	Voyager	40.6795309770144513	-73.9505487017229228
15043	2020-03-10 00:21:42	2020-03-10	Camille Mueller	camille.mueller@geemail.com	Pueblo	Colorado	869991180861588168	10c61fcc2e2a1d2aa574e93c906cb6c2	JCB 16 digit	38.3616874450329703	-104.689209730257474
15044	2020-03-10 00:31:59	2020-03-10	Jacques Johns	jacques.johns@geemail.com	San Bernardino	California	180090202966061049	585868a80073ac80d09cb44e75e05ca0	JCB 16 digit	34.1702841732449798	-117.31253582078628
15045	2020-03-10 00:34:38	2020-03-10	Ruie Parisian	ruie.parisian@geemail.com	Los Angeles	California	502068865316035	3fad370f69b21ddabf3a99ad613ebc48	JCB 16 digit	34.0647996946569478	-118.509242031675939
15046	2020-03-10 00:42:45	2020-03-10	Vernice Abernathy	vernice.abernathy@geemail.com	San Francisco	California	3158993633810343464	03774efe2d4c8b546693e7e4d239e7bc	Discover	37.754546519088052	-122.411910856105266
15047	2020-03-10 00:51:25	2020-03-10	Ms. Gwyn Leuschke DVM	ms.gwyn.leuschke.dvm@geemail.com	Cary	North Carolina	3460291477112173	ebcc853b73c9745130fceb4137116d58	JCB 16 digit	35.8693991733822983	-78.8586415247611683
15048	2020-03-10 00:57:09	2020-03-10	Buck Swift V	buck.swift.v@geemail.com	San Francisco	California	4767530914672174	f1e92428494c4b4b2a579303cca862ed	American Express	37.7779997419974904	-122.449889317103299
15049	2020-03-10 01:03:23	2020-03-10	Keyshawn Upton	keyshawn.upton@warmmail.com	Los Angeles	California	4986846575116193	04cbcf4251c61992c1d16203f81be830	Voyager	34.1167100664559726	-118.332616232660783
15050	2020-03-10 01:09:38	2020-03-10	Ms. Raven Reynolds	ms.raven.reynolds@geemail.com	Boise	Idaho	3088786422447105244	74c4dad54f98d956432b34273063e064	Diners Club / Carte Blanche	43.5466866157155508	-116.205802273164323
15051	2020-03-10 01:11:15	2020-03-10	Sampson Thiel	sampson.thiel@woohoo.com	Everett	Washington	502089315377344	b85688e0e424fadf92130323d1df750c	VISA 16 digit	48.0083984351608919	-122.290090390959378
15052	2020-03-10 01:13:41	2020-03-10	Levon Greenholt	levon.greenholt@geemail.com	San Francisco	California	3051619179146887	6a564e04c89b4a5c1c50fb6159ecd24b	VISA 16 digit	37.7554941350025075	-122.449503565159887
15053	2020-03-10 01:19:22	2020-03-10	Bliss Block	bliss.block@geemail.com	New York	New York	3018551353011277	67dc0d2f2415f9997a4b920fb46f7567	Maestro	40.7231634437795691	-74.0328382844000998
15054	2020-03-10 01:30:22	2020-03-10	Ozie Dicki DDS	ozie.dicki.dds@geemail.com	Philadelphia	Pennsylvania	4041104836683	6c1373e160c165a5195857b5c181f9dd	Voyager	40.00391886694878	-75.0610896946761841
15055	2020-03-10 01:33:56	2020-03-10	Laureen Parker	laureen.parker@geemail.com	Jacksonville	Florida	3337093424625345400	cf238ef028746d4fca920813e4892847	Diners Club / Carte Blanche	30.3665176149975515	-81.658494310088841
15056	2020-03-10 01:44:16	2020-03-10	Mrs. Phoebe Bahringer PhD	mrs.phoebe.bahringer.phd@geemail.com	San Francisco	California	3112011084501904180	bafd372697c34a04b2c927f9cd3a9523	VISA 16 digit	37.7884412136031855	-122.462569121912139
15057	2020-03-10 01:44:26	2020-03-10	Rudolfo Kshlerin	rudolfo.kshlerin@geemail.com	Dayton	Ohio	210086249511608291	cba13a3582631a8c83a7f52d7562f44a	Discover	39.7755016505509644	-84.210150972679628
15058	2020-03-10 01:47:36	2020-03-10	Briana Howe	briana.howe@geemail.com	Fullerton	California	869923760636753768	c39c161eafe6c96e16a046a10f1d132c	Mastercard	33.89056788721755	-117.893483151515937
15059	2020-03-10 02:18:09	2020-03-10	Dr. Darcy Macejkovic	dr.darcy.macejkovic@geemail.com	Columbus	Ohio	210013961368663439	98c4604fea452fc2bf3623d56640960d	Maestro	39.9509849651761328	-83.0559598512250972
15060	2020-03-10 02:21:46	2020-03-10	Dr. Ramsey Sawayn V	dr.ramsey.sawayn.v@geemail.com	Olathe	Kansas	53384850779843006	2310e2bb317e7f94e579b3424dfa178b	Mastercard	38.9610784230876774	-94.7665829598605711
15061	2020-03-10 02:32:40	2020-03-10	Mrs. Florine Braun DVM	mrs.florine.braun.dvm@geemail.com	Houston	Texas	4136837037862	53c5a02e11d89aecc9c7de2294513e89	Maestro	29.8458186150606721	-95.2949572862606544
15062	2020-03-10 02:41:25	2020-03-10	Ethel VonRueden	ethel.vonrueden@geemail.com	San Francisco	California	3112454845586802414	1759dc5865c6a149629eb8c95ef14ff0	Voyager	37.7684349063929758	-122.404289119941765
15063	2020-03-10 02:49:15	2020-03-10	Caiden Leffler-Tillman	caiden.leffler.tillman@geemail.com	San Francisco	California	4635128936060617	e14d7e1bcc4cea4b0668eab84f7d531d	Diners Club / Carte Blanche	37.7652837404296164	-122.421984912039903
15064	2020-03-10 02:56:32	2020-03-10	Dotty Wunsch	dotty.wunsch@geemail.com	Palmdale	California	3459827666461948	2afc4060da98bee83a7977c862a2daa0	VISA 16 digit	34.5697368891295085	-118.107413659663507
15065	2020-03-10 03:05:27	2020-03-10	Miss Belle Moen DDS	miss.belle.moen.dds@geemail.com	Round Rock	Texas	4922730877441	5f71ed97ad25f2c1db45107e8f37b6cf	JCB 15 digit	30.4617161146502973	-97.5814264358803598
15066	2020-03-10 03:17:03	2020-03-10	Brea Armstrong	brea.armstrong@geemail.com	New York	New York	675916302163650	3b09d24ead4576d28588019b3bd40263	Mastercard	40.6062062207832923	-73.9216859946854328
15067	2020-03-10 03:26:10	2020-03-10	Rossie Bechtelar	rossie.bechtelar@geemail.com	San Francisco	California	630468807244808	8442c0d925699c83de55e56f41ae7b6c	Maestro	37.812051571601458	-122.468869931706351
15068	2020-03-10 03:33:36	2020-03-10	Verdie Douglas	verdie.douglas@geemail.com	San Francisco	California	4198577818445842	84d60585eb4ec0f8b7253dd2237e0ab5	JCB 16 digit	37.7766749931627004	-122.433240279525833
15069	2020-03-10 03:50:02	2020-03-10	Jasen Sauer-Hoppe	jasen.sauer.hoppe@geemail.com	Riverside	California	3795447250715736	9ba96381b463aa90bdeae562f81277b4	Voyager	33.918592157209666	-117.426987497924628
15070	2020-03-10 04:05:58	2020-03-10	Bishop Towne	bishop.towne@geemail.com	Garden Grove	California	3337666705728771808	f7ad9493b07b1a638b235a31c8a78ffa	JCB 15 digit	33.7276605027552634	-117.943370118413114
15071	2020-03-10 04:15:12	2020-03-10	Collins Fahey	collins.fahey@geemail.com	Fayetteville	North Carolina	4664866665410	6ba5b06684a197d068db14a4a74a93a2	Voyager	34.9965255544774223	-78.9832582085523711
15072	2020-03-10 04:40:57	2020-03-10	Clemence Spinka DDS	clemence.spinka.dds@woohoo.com	San Jose	California	869903648273455884	2b0815b599a37cb41dfa6ab38899a180	Discover	37.246456832374264	-121.81830750799142
15073	2020-03-10 04:59:06	2020-03-10	Claire Kling MD	claire.kling.md@geemail.com	Antioch	California	4132678386833598	da66fd195ecbc8e6e4dfcc30d21865ff	Discover	37.9604423829618867	-121.824073400133102
15074	2020-03-10 05:04:17	2020-03-10	Lella Fadel DVM	lella.fadel.dvm@geemail.com	Orlando	Florida	55916863440609612	1d642136ea1c6698d4138690a3473e07	American Express	28.5061512149669234	-81.3432715400554258
15075	2020-03-10 05:08:07	2020-03-10	Suzette Adams	suzette.adams@geemail.com	San Diego	California	4550473016735	7a0e4ddc56ecf9c0d86e5b03048ef7a1	JCB 16 digit	32.7909358028855209	-117.198192021101718
15076	2020-03-10 05:19:13	2020-03-10	Monique Dibbert	monique.dibbert@geemail.com	Houston	Texas	4243736522935	d86cdb0c72d0704ea0995cd38e16f141	VISA 16 digit	29.7713149359993636	-95.3044809190571272
15077	2020-03-10 05:21:22	2020-03-10	Shannon Nolan MD	shannon.nolan.md@geemail.com	Rochester	Minnesota	869940936901591906	d32076911dbff94d1d6c1644fd31e264	Discover	44.0574351154170927	-92.5292724938251041
15078	2020-03-10 05:46:57	2020-03-10	Exa Gibson	exa.gibson@geemail.com	Chicago	Illinois	3003603491539886	5cb9426a2555f03d6dcfcc61791f646a	VISA 16 digit	41.8873189169749622	-87.736392104349278
15079	2020-03-10 06:06:48	2020-03-10	Jamie Nolan	jamie.nolan@geemail.com	Port St. Lucie	Florida	3337672484954305986	adf2471979b26572d23529adb87137cd	Discover	27.2771816088020813	-80.2999363462060671
15080	2020-03-10 06:14:40	2020-03-10	Fernand Feeney	fernand.feeney@geemail.com	Fort Collins	Colorado	4424651081502302	056ad99667408b1c02d95ed1af458143	VISA 13 digit	40.457722339608523	-105.139410511725771
15081	2020-03-10 06:24:06	2020-03-10	Riley Skiles	riley.skiles@geemail.com	Anchorage	Alaska	210048392634094069	39250198809bfac5d9b669268cf31913	VISA 13 digit	61.2044700294483448	-149.309225791332494
15082	2020-03-10 06:45:56	2020-03-10	Deyanira Hessel-Kuhn	deyanira.hessel.kuhn@warmmail.com	Oakland	California	3032218721612626	8b7bdf244da1f32639216a99a27f3a76	American Express	37.8152747567776117	-122.263337407724777
15083	2020-03-10 06:48:19	2020-03-10	Jerald Hoeger	jerald.hoeger@geemail.com	New York	New York	869940405329580784	254655efc98e1b0b7a1bf7bb69d9782c	American Express	40.5922185783032319	-73.9606376473221871
15084	2020-03-10 06:50:25	2020-03-10	Payten Haag-Bruen	payten.haag.bruen@geemail.com	Irving	Texas	3337715994385917570	cae6bc0b4f77871d542e5bbd5da56504	Discover	32.7603719954330472	-97.0063379648420891
15085	2020-03-10 06:51:38	2020-03-10	Affie Rice	affie.rice@geemail.com	Odessa	Texas	3488724398669002	84b545c3a747977681e273fcc4d3e8f4	Mastercard	31.887674011943119	-102.419405427217853
15086	2020-03-10 06:54:39	2020-03-10	Nellie Greenholt MD	nellie.greenholt.md@geemail.com	Phoenix	Arizona	3528946763683988232	39172b7f2fd138f97b7c06c2c700bf34	Voyager	33.5514438774369665	-112.006358397744975
15087	2020-03-10 06:58:40	2020-03-10	Dr. Lular O'Keefe	dr.lular.o'keefe@geemail.com	Cary	North Carolina	53142959816615997	7852ffc4902dedbe270638b69b53e22e	Maestro	35.8528899780582648	-78.7511212548792372
15088	2020-03-10 07:16:07	2020-03-10	Mathilde Pfeffer	mathilde.pfeffer@geemail.com	Kansas City	Kansas	676357486946635	eff602941aa9d67eab2961403d471a8f	JCB 16 digit	39.0571411252860017	-94.6483128004178411
15089	2020-03-10 07:20:14	2020-03-10	Izola Rolfson	izola.rolfson@geemail.com	Little Rock	Arkansas	501875088042363	33bce9827f56d74a549feb1d94166611	Maestro	34.6278363731034133	-92.415272241305928
15090	2020-03-10 07:20:26	2020-03-10	Creed Kerluke	creed.kerluke@geemail.com	Oakland	California	3047038402486172	5afdb0b740c789f2022f4c2a38f0f3f3	Maestro	37.784468171734467	-122.260697033882934
15091	2020-03-10 07:22:29	2020-03-10	Leona Kovacek	leona.kovacek@woohoo.com	Salem	Oregon	3158674263683178841	49167309b2df53828fcabf8c3604bfa9	JCB 15 digit	44.9826250109624084	-122.957597094883027
15092	2020-03-10 07:27:14	2020-03-10	Dr. Rakeem Doyle DDS	dr.rakeem.doyle.dds@geemail.com	Peoria	Arizona	639022297064622	5ced37cc1940d8d9629e3b684d5e06b2	Discover	33.8437860326178352	-112.231418579995633
15093	2020-03-10 08:15:37	2020-03-10	Dr. Keandre Prosacco III	dr.keandre.prosacco.iii@geemail.com	Syracuse	New York	3426564451168319	0b016191752d9e37d5b0b1c5f06ad5d6	Mastercard	42.9835071775447517	-76.0559145290184802
15094	2020-03-10 08:27:40	2020-03-10	Gaylene Mertz DDS	gaylene.mertz.dds@geemail.com	Oakland	California	869946609568109874	ab7d92015e241f3062169bf3c997ea3a	Discover	37.8490416346935703	-122.272964375187954
15095	2020-03-10 08:29:52	2020-03-10	Solomon Kuhic Sr.	solomon.kuhic.sr.@warmmail.com	Houston	Texas	630413545347547	50e8e3dc5844970ccddc69f7e6217942	Discover	29.7328192038539783	-95.4343373132418833
15096	2020-03-10 08:31:22	2020-03-10	Exa Baumbach DVM	exa.baumbach.dvm@geemail.com	Wichita	Kansas	180041541562134795	8a815ec971801d746b60b2c1f2744cbf	Voyager	37.6436576104134346	-97.3049261902660163
15097	2020-03-10 08:33:38	2020-03-10	Alford Ziemann	alford.ziemann@warmmail.com	San Francisco	California	3026502100809655	1e04ed4f965085f10936c9ac8a9f12e5	JCB 16 digit	37.755297770880162	-122.455851330644862
15098	2020-03-10 08:36:11	2020-03-10	Mr. Desean Green DDS	mr.desean.green.dds@woohoo.com	San Antonio	Texas	3453003678390360	4770214b491629c10f84533f77ac28a5	VISA 16 digit	29.5365649972647439	-98.592628042569757
15099	2020-03-10 08:46:43	2020-03-10	Arlyn Legros	arlyn.legros@warmmail.com	Seattle	Washington	589319598840304	9c397959ecadc245d4d7cc773a534c3c	Mastercard	47.6220156977344331	-122.433055664451416
15100	2020-03-10 08:47:57	2020-03-10	Storm Huels	storm.huels@geemail.com	Pembroke Pines	Florida	4414748165094792	d891fdcb9aea4a8959c9ac88b0ab8409	VISA 13 digit	25.9386758339162924	-80.3793554371591625
15101	2020-03-10 09:15:30	2020-03-10	Hayden Jacobs	hayden.jacobs@geemail.com	Bakersfield	California	3713251663939464	f7b012ee1fbd89c8e43b245d2a3a3f23	VISA 16 digit	35.2634620384022597	-118.977189921102664
15102	2020-03-10 09:24:44	2020-03-10	Bird Walker DVM	bird.walker.dvm@geemail.com	Oklahoma City	Oklahoma	3767507627382231	c651ec437f2c9420a63e2eb62738b790	JCB 16 digit	35.4232794265639086	-97.4278331566497684
15103	2020-03-10 09:32:45	2020-03-10	Caiden Koelpin	caiden.koelpin@geemail.com	Charlotte	North Carolina	3031387379234883	a45aab2aafacae6a7a2a3146acba0278	VISA 13 digit	35.1562740244224656	-80.8200732026658955
15104	2020-03-10 09:49:48	2020-03-10	Gustavus Runolfsdottir	gustavus.runolfsdottir@geemail.com	Charlotte	North Carolina	869978044779379705	a13086c827c96c8fe45673dd718aab77	Discover	35.2767438995905209	-80.7530837120898042
15105	2020-03-10 09:51:05	2020-03-10	Marry Waters	marry.waters@geemail.com	Laredo	Texas	4541649958926	7e3ae009803906fb5c649ff9aca93d8b	VISA 16 digit	27.5171630858160583	-99.5155087889645245
15106	2020-03-10 09:55:00	2020-03-10	Yasmeen Pouros	yasmeen.pouros@geemail.com	Palmdale	California	210041641477467510	f032982802ec84b3b75abfa94225abd7	VISA 13 digit	34.6696388942506175	-118.203063789335644
15107	2020-03-10 10:10:48	2020-03-10	Jacey Towne DDS	jacey.towne.dds@warmmail.com	Vista	California	4200729306988355	77dc2e447943d3e31c539ce61a819bce	Mastercard	33.1328890516869734	-117.243905308150133
15108	2020-03-10 10:16:55	2020-03-10	Jayden Gutkowski	jayden.gutkowski@woohoo.com	Norman	Oklahoma	4984634324124912	e2079883625a6eafdcb0b9b2cbb83e7c	American Express	35.2417224985122672	-97.2917687503408644
15109	2020-03-10 10:34:37	2020-03-10	Daniel Grant-Miller	daniel.grant.miller@warmmail.com	San Francisco	California	3486675782818534	2fac3f24a8c49b32ef1614fe631d6e79	VISA 16 digit	37.7804931925286809	-122.428015579983111
15110	2020-03-10 10:56:44	2020-03-10	Lilburn Jones	lilburn.jones@geemail.com	Oakland	California	6011302038121590637	cfe6a59a025444dbe5150535697f7a13	JCB 15 digit	37.806247211236844	-122.283340097492584
15111	2020-03-10 10:58:04	2020-03-10	Destry Haag	destry.haag@geemail.com	San Antonio	Texas	3112087984674720926	0c9ead1f422b715fca805966dcaebb8c	VISA 16 digit	29.3862077003881339	-98.5306235361680365
15112	2020-03-10 11:02:38	2020-03-10	Acie Gerlach Sr.	acie.gerlach.sr.@warmmail.com	Austin	Texas	869940467304131132	9791895b30a5d4e3516f36b841cfdb41	VISA 16 digit	30.2356876872606577	-97.726958198636396
15113	2020-03-10 11:06:35	2020-03-10	Omar Gerlach	omar.gerlach@woohoo.com	Fayetteville	North Carolina	3051824575690781	0edd13f46252b980167044724e917688	Maestro	35.1657070741310704	-79.0602356900125756
15114	2020-03-10 11:12:42	2020-03-10	Caddie Jakubowski	caddie.jakubowski@woohoo.com	Los Angeles	California	4204139863607	09e4e8645153407e56497a68910c436a	JCB 16 digit	34.0423492030106445	-118.310859242546556
15115	2020-03-10 11:12:54	2020-03-10	Ms. Eugenia Jenkins	ms.eugenia.jenkins@geemail.com	Charlotte	North Carolina	4170314150794054	ce488c68b039f30792c217408ae99c72	JCB 15 digit	35.1230100595645567	-80.7675715283900502
15116	2020-03-10 11:19:16	2020-03-10	Dr. Bell Schamberger	dr.bell.schamberger@warmmail.com	Tuscaloosa	Alabama	3751424543272009	64369bc80dd6bf4baa3ea34e4fad82cd	Voyager	33.2105553365368351	-87.4684585176970728
15117	2020-03-10 11:23:38	2020-03-10	Alexa Strosin	alexa.strosin@warmmail.com	San Francisco	California	503835799544750	1ef0ca7e789496892d2407f19aa64c54	Diners Club / Carte Blanche	37.7839921767062847	-122.412425937814092
15159	2020-03-10 17:55:52	2020-03-10	Della Runolfsdottir	della.runolfsdottir@geemail.com	New York	New York	676383179054461	dd734fa4b8d99bd3e2002391f8ab22a6	Voyager	40.727191711239513	-73.8942158183909896
15118	2020-03-10 11:51:31	2020-03-10	Kendrick Steuber-Predovic	kendrick.steuber.predovic@geemail.com	New York	New York	4695617316170241	5384d6dfe2bad094e9fbb059ee889ddc	VISA 16 digit	40.5795762729588887	-73.9184999984584721
15119	2020-03-10 12:01:53	2020-03-10	Lahoma Lockman	lahoma.lockman@geemail.com	Independence	Missouri	6011164355781444211	f0abd56108bdbf6d241c7588a2062000	VISA 13 digit	39.1609384213127214	-94.2848603806275776
15120	2020-03-10 12:17:29	2020-03-10	Effa Volkman	effa.volkman@woohoo.com	San Francisco	California	4840141689034862	c7f6130a49a8f9974f6157636dcc6396	VISA 13 digit	37.7757645659322634	-122.429283554657161
15121	2020-03-10 12:31:36	2020-03-10	Tamya Murphy	tamya.murphy@woohoo.com	Chicago	Illinois	6011903302584300089	b11bc47c13ba4681f07e4bc29c241a3f	Discover	41.8712372727993909	-87.6310911285255116
15122	2020-03-10 12:34:43	2020-03-10	Hurbert Doyle-Bernier	hurbert.doyle.bernier@geemail.com	Round Rock	Texas	4879546157980	192c26a537c06d6a486ddb90e7406410	JCB 16 digit	30.436889040856439	-97.7607707562241615
15123	2020-03-10 12:48:15	2020-03-10	Mena Howe	mena.howe@geemail.com	Louisville	Kentucky	869943733483266412	8de66a1958fe8f12c3bd133de85063c4	Diners Club / Carte Blanche	38.1919215926337969	-85.5795922577451904
15124	2020-03-10 12:53:13	2020-03-10	Dr. Lula Schaefer	dr.lula.schaefer@geemail.com	Las Cruces	New Mexico	210005290552505788	ec22f7c6cf13ca7878c904137f3ffef8	American Express	32.2437512391746068	-106.751067736011734
15125	2020-03-10 12:53:37	2020-03-10	Tollie Lebsack	tollie.lebsack@geemail.com	Charlotte	North Carolina	3030591645010966	91d35cb63a8e728ee11fb4f691a618c2	JCB 16 digit	35.1978849997997258	-80.8428229302111987
15126	2020-03-10 13:27:55	2020-03-10	Dr. Von Wunsch	dr.von.wunsch@geemail.com	Richardson	Texas	3112463178001367485	e8071ae6ec9fe8a1b45b3ce1e87cd2d0	JCB 16 digit	33.0149654342096284	-96.7641248171445056
15127	2020-03-10 13:43:31	2020-03-10	Corey Wintheiser	corey.wintheiser@geemail.com	Phoenix	Arizona	52967584700687423	b5b42a980f8af1db09c3a266393f3070	Voyager	33.5800629143070424	-112.118887938551978
15128	2020-03-10 13:45:22	2020-03-10	Duard Marvin	duard.marvin@warmmail.com	Salt Lake City	Utah	4736757166755	d0ea564faa2acb7a8b1fda042e6f274a	Mastercard	40.8447992654662571	-111.838284953771151
15129	2020-03-10 14:06:38	2020-03-10	Harlen Dooley	harlen.dooley@woohoo.com	San Francisco	California	4223209320564436	2295fc222c54452a5e293db330990012	VISA 13 digit	37.8199434881816074	-122.4474293563662
15130	2020-03-10 14:43:17	2020-03-10	Contina Wintheiser PhD	contina.wintheiser.phd@geemail.com	San Francisco	California	54267190912220651	346156cb741b3ab7d6150a019110b879	Maestro	37.7783184976332791	-122.421574229491526
15131	2020-03-10 14:47:16	2020-03-10	Kelan Harris	kelan.harris@geemail.com	Las Vegas	Nevada	210090188505772636	5adfc6da81e20d181a22096803937c4b	Discover	36.3005393319863785	-115.208558298249159
15132	2020-03-10 14:48:15	2020-03-10	Elinor Smitham-Little	elinor.smitham.little@geemail.com	Hayward	California	54423517847422781	971d482bf564c4dbf73fddb1201060da	Discover	37.6850914463855347	-122.089316819121692
15133	2020-03-10 14:48:44	2020-03-10	Maybell Treutel	maybell.treutel@woohoo.com	Chicago	Illinois	3158489658783713774	666d4e6a635e8f4f55749e9279986081	Maestro	41.7522912536583846	-87.7426389780856653
15134	2020-03-10 14:51:53	2020-03-10	Keshawn Kunze	keshawn.kunze@warmmail.com	Chicago	Illinois	3096124177144065957	f5fd8e94b681eaa6ce65238937320087	Voyager	41.858440655034407	-87.5899530665047479
15135	2020-03-10 14:53:12	2020-03-10	Eston Marquardt	eston.marquardt@geemail.com	Olathe	Kansas	3088078657852215536	21678fd6a094900965a2387fe39cc998	VISA 13 digit	38.9241654567543449	-94.8106796174012203
15136	2020-03-10 14:56:47	2020-03-10	Frederick Goodwin	frederick.goodwin@geemail.com	Aurora	Colorado	3796496856578112	8bc0aa373640de1070e298fbbe1ab0a2	VISA 16 digit	39.7561323985103527	-104.632521262031801
15137	2020-03-10 15:01:26	2020-03-10	Demetrius Hyatt	demetrius.hyatt@geemail.com	Houston	Texas	4434528199689023	49f5e619c8523a4f9b7262b259d1b971	Discover	29.740025585059449	-95.4830915411949235
15138	2020-03-10 15:03:23	2020-03-10	Jerome Baumbach	jerome.baumbach@geemail.com	Scottsdale	Arizona	869930110107674393	75a9b07d371dba5ab23edcb476eb8155	Mastercard	33.639722585690393	-111.791091837218403
15139	2020-03-10 15:07:57	2020-03-10	Ballard Johnston II	ballard.johnston.ii@geemail.com	Lansing	Michigan	3528423882320338247	68b0d7fdd38132e24a7e12ac249719e2	Maestro	42.8063816679950833	-84.6407717967994415
15140	2020-03-10 15:10:20	2020-03-10	Lossie Roob DDS	lossie.roob.dds@woohoo.com	Philadelphia	Pennsylvania	3022184084832252	d494bb57f46d1309ed7530d4036e1df2	Diners Club / Carte Blanche	40.0343106483533973	-75.0433768088828828
15141	2020-03-10 15:24:42	2020-03-10	Ms. Lucetta Sauer	ms.lucetta.sauer@geemail.com	Chandler	Arizona	6011993621292999317	3f2fe065ee4e1a94eb849741a1b67088	VISA 16 digit	33.3536837743684629	-111.802838604885707
15142	2020-03-10 15:33:11	2020-03-10	Benjman Jast-Aufderhar	benjman.jast.aufderhar@warmmail.com	Vacaville	California	589388676854248	766e047b1d1916bff56bbb8e7d9f661d	VISA 13 digit	38.3284825735852124	-121.94922657919787
15143	2020-03-10 15:36:36	2020-03-10	Leeroy Schultz	leeroy.schultz@woohoo.com	Boulder	Colorado	639006656324651	24d605f31440f8e95a4db5a507b3f6bd	VISA 16 digit	40.0329471978340337	-105.323330427907038
15144	2020-03-10 15:47:14	2020-03-10	Mr. Garnet Howe V	mr.garnet.howe.v@geemail.com	Vista	California	51785558689241899	16e6de3daf02a289e62625609b46ecf2	American Express	33.2523818833734879	-117.284481585078325
15145	2020-03-10 15:51:09	2020-03-10	Clarence Braun	clarence.braun@woohoo.com	Grand Rapids	Michigan	3042696367289397	98ce78d93d1be212066903a8d11801c5	JCB 16 digit	42.9417796375498142	-85.6705348438717493
15146	2020-03-10 16:03:32	2020-03-10	Evertt Fritsch	evertt.fritsch@geemail.com	Tucson	Arizona	4635670375132522	c46773d8b054fae50369d1d5831540cf	VISA 16 digit	32.0884552536573295	-110.897010892931746
15147	2020-03-10 16:03:46	2020-03-10	Eber Nicolas	eber.nicolas@geemail.com	Lincoln	Nebraska	3112961694226189725	235acc894d2706366173cdeac04d3d83	Discover	40.8112714419625675	-96.6799769236400692
15148	2020-03-10 16:07:14	2020-03-10	Judah Kirlin	judah.kirlin@geemail.com	Worcester	Massachusetts	3337298288915647962	88b8095f2c5a94089e6b216e994aff3c	Mastercard	42.3431240517348044	-71.8198199623983413
15149	2020-03-10 16:14:22	2020-03-10	Merle Hermiston	merle.hermiston@geemail.com	Houston	Texas	630473925864628	b6c12bcf74e407439009e03c27743b24	Diners Club / Carte Blanche	29.7046666738189771	-95.3685143129915076
15150	2020-03-10 16:17:28	2020-03-10	Tyron Roob	tyron.roob@warmmail.com	Jersey City	New Jersey	4815059044293075	6201f81113e0bc5cd64eebb759b93133	Voyager	40.7100889542080466	-74.0767066003710113
15151	2020-03-10 16:27:39	2020-03-10	Mr. Skip Osinski	mr.skip.osinski@woohoo.com	Huntsville	Alabama	3337100262272763207	094e801849582db14d6fe12cad90875d	JCB 16 digit	34.7227866431474652	-86.7246908998601214
15152	2020-03-10 16:27:46	2020-03-10	Blair Emard	blair.emard@warmmail.com	Washington	District of Columbia	180039611124558056	10779867b698ecd028b46e0c76ad3c36	VISA 13 digit	38.8846652784649294	-76.9372318176765049
15153	2020-03-10 16:51:50	2020-03-10	Eulalia Yost	eulalia.yost@geemail.com	Austin	Texas	3088296738518513419	a81e5da1e67c2aed80ad05f51cf8e872	Voyager	30.2354105852205279	-97.7318778251070626
15154	2020-03-10 16:54:45	2020-03-10	Daxton Hodkiewicz DVM	daxton.hodkiewicz.dvm@geemail.com	Hialeah	Florida	869916249363157137	acbe86d6ed05d8b91e657d6248302f5a	JCB 16 digit	25.9077244212828575	-80.2961456459850069
15155	2020-03-10 17:19:55	2020-03-10	Jarett Collier-Ullrich	jarett.collier.ullrich@woohoo.com	San Diego	California	3448630387527714	51dcd5979d6d002749afef3a5dbffb11	Mastercard	32.7782382607061393	-117.149383480418479
15156	2020-03-10 17:27:15	2020-03-10	Tamie Crooks	tamie.crooks@woohoo.com	New York	New York	676304541161784	0c015359ca515c918e6917030ab5ccea	Discover	40.7254838802609598	-74.0238253592874855
15157	2020-03-10 17:31:29	2020-03-10	Mr. Denis Larson	mr.denis.larson@woohoo.com	Houston	Texas	3088291562411638189	3f23e73eaa922cc75a594bebc22eaad4	JCB 16 digit	29.6920562430828809	-95.3160619481947293
15158	2020-03-10 17:45:02	2020-03-10	Harrie Spinka	harrie.spinka@woohoo.com	San Francisco	California	210030818681264510	551760e8d872ab4ae62511a4ef180f82	JCB 16 digit	37.7963477218424089	-122.461270971985655
15160	2020-03-10 18:15:49	2020-03-10	Alaina Leannon-Torphy	alaina.leannon.torphy@geemail.com	San Francisco	California	55191760399673936	6955a309a9e76c5c56a28a03b1f71e86	JCB 16 digit	37.7628859899586331	-122.438209602862784
15161	2020-03-10 18:37:25	2020-03-10	Miss Taraji Howe	miss.taraji.howe@geemail.com	Mesa	Arizona	4172817448880988	460a90f0ad2ab560509c6b536aedbf80	American Express	33.4905009448207878	-111.786093895591421
15162	2020-03-10 18:57:54	2020-03-10	Cade Schulist	cade.schulist@geemail.com	Oakland	California	869925429978804062	04645e22a72811a78057dbe16bde49cb	JCB 15 digit	37.7942399412702699	-122.296550977061372
15163	2020-03-10 18:59:55	2020-03-10	Miss Malissie O'Keefe MD	miss.malissie.o'keefe.md@geemail.com	Fort Worth	Texas	4569435043710	dc1b9616145ce88818e5171136efe10d	Maestro	32.8754038023818325	-97.360309377155076
15164	2020-03-10 19:02:32	2020-03-10	Joellen King	joellen.king@woohoo.com	Pompano Beach	Florida	3746365444668324	96dd3a34b249c646fe05d7dce3dc8c00	JCB 15 digit	26.193517579350992	-80.0429050369501027
15165	2020-03-10 19:08:01	2020-03-10	Aarav Mills	aarav.mills@geemail.com	Fresno	California	3005177025851271	3cb6a04ea41bcc7cac79d7d0dfd8ce2a	Mastercard	36.7315644000530241	-119.851595127313956
15166	2020-03-10 19:16:57	2020-03-10	Okey O'Hara III	okey.o'hara.iii@geemail.com	Oakland	California	54508489788837047	0cd69cc34a35bd9a21698061016a6dc5	Mastercard	37.8142264343002594	-122.280790305687134
15167	2020-03-10 19:42:49	2020-03-10	Dr. Derrell Botsford Jr.	dr.derrell.botsford.jr.@geemail.com	Chicago	Illinois	3460634771642645	bec0d00920e6e830383c302e399af288	Maestro	41.866445426812767	-87.7517541393667386
15168	2020-03-10 19:56:29	2020-03-10	Deven Lindgren	deven.lindgren@geemail.com	Jacksonville	Florida	869914939649477919	ef2f11e989e8471e4a51b7463dd52622	Discover	30.4028599013626568	-81.5751585866402849
15169	2020-03-10 20:15:03	2020-03-10	Blanchie Heller	blanchie.heller@woohoo.com	Los Angeles	California	4283262195458	653e0ccce408c4eeb0ebe5cc6606e39c	VISA 16 digit	33.9439091535151007	-118.501931605254484
15170	2020-03-10 20:36:41	2020-03-10	Braydon Littel V	braydon.littel.v@geemail.com	Salt Lake City	Utah	4865719169337986	6e66b47f24d8feb74a1390cec7cfea1b	JCB 15 digit	40.7175679707113645	-112.004310480033979
15171	2020-03-10 20:39:14	2020-03-10	Iva Emard	iva.emard@geemail.com	Irvine	California	4729609177399043	2306520686be636b916aff84004b9479	JCB 15 digit	33.6978922148250106	-117.732137463382628
15172	2020-03-10 20:53:05	2020-03-10	Mrs. Floy Mitchell	mrs.floy.mitchell@geemail.com	San Francisco	California	3046854713532442	b36f34a614ab58535727c189a770186a	JCB 16 digit	37.7828106391711174	-122.421334708446338
15173	2020-03-10 21:04:05	2020-03-10	Mrs. Nell Dietrich	mrs.nell.dietrich@geemail.com	Indianapolis	Indiana	3405772362826652	dbf012fef8d91f1bc3f27a757acd1ab6	American Express	39.6932772506967169	-86.2351261039000008
15174	2020-03-10 21:10:33	2020-03-10	Jeannine Schmidt	jeannine.schmidt@woohoo.com	Kansas City	Missouri	4526386732872658	f3b781c9ae5f7f4d75b6f14264179f62	Discover	39.1379082246985348	-94.5548083812221876
15175	2020-03-10 21:17:17	2020-03-10	Mrs. Amber Nienow	mrs.amber.nienow@geemail.com	Louisville	Kentucky	869957606771838022	773446ee5033c39996ecf0b302e3451d	JCB 16 digit	38.114248236678165	-85.7057241180982459
15176	2020-03-10 21:17:31	2020-03-10	Alec Abernathy	alec.abernathy@geemail.com	Phoenix	Arizona	4434142258389804	3430de7ab14dcc806bda4ac811fbeb98	Mastercard	33.5757695941653154	-112.124814582003665
15177	2020-03-10 21:30:46	2020-03-10	Ms. Dahlia Jacobs DVM	ms.dahlia.jacobs.dvm@warmmail.com	Jackson	Mississippi	51016178818807675	ee12f61f210833deec6d698fe519abc4	VISA 16 digit	32.3853709090679942	-90.1151979207966463
15178	2020-03-10 21:33:54	2020-03-10	Jewel Schultz-Murazik	jewel.schultz.murazik@geemail.com	Orange	California	4431594077747641	5fc346a871582083b780ac8c21abc26f	VISA 16 digit	33.6929415726456796	-117.952324835361168
15179	2020-03-10 21:39:38	2020-03-10	Aedan Lang	aedan.lang@warmmail.com	Los Angeles	California	4257000079778	1043416e220037af407db7ffebf6a454	JCB 16 digit	34.0781582764215756	-118.46811580802239
15180	2020-03-10 21:49:03	2020-03-10	Ronin Smith	ronin.smith@woohoo.com	El Paso	Texas	4952829835526930	81c315af00e22c966af9150a98de47df	Voyager	31.8752621021881701	-106.484061839895332
15181	2020-03-10 21:51:26	2020-03-10	Mack Kshlerin	mack.kshlerin@warmmail.com	Hialeah	Florida	3796327068303843	a6eced92c412e9777dc52b3d3eebce94	Voyager	25.8628365640971829	-80.2490434986442267
15182	2020-03-10 21:53:30	2020-03-10	Arnie Farrell	arnie.farrell@geemail.com	Providence	Rhode Island	6011340212717492656	5416a91bacf2e89f77249e98330031f8	Voyager	41.83880927449502	-71.3614822391338635
15183	2020-03-10 22:00:24	2020-03-10	Miss Star Quigley PhD	miss.star.quigley.phd@geemail.com	Jacksonville	Florida	3005073789392851	ad8dfae23a317cecfe7bc42b6e367df1	American Express	30.3058988404512419	-81.6706754508506521
15184	2020-03-10 22:08:45	2020-03-10	Mrs. Monica Wiza PhD	mrs.monica.wiza.phd@geemail.com	Columbus	Ohio	3005567167109308	fe8c75a93d096d5c5e966eb5898ea43f	Mastercard	40.0061340525325377	-82.9007325666260044
15185	2020-03-10 22:37:12	2020-03-10	Eulalie Miller	eulalie.miller@geemail.com	Long Beach	California	3058531302578261	6bab506a69f9891c85c21a4e1a5c3c8b	American Express	33.7115971273563773	-118.093276581929246
15186	2020-03-10 22:42:48	2020-03-10	Mohamed McGlynn	mohamed.mcglynn@geemail.com	San Francisco	California	4159258777059224	7417a33608c590ffebf4ad2d8b3d77ad	Voyager	37.7538874187424298	-122.444772613283206
15187	2020-03-10 22:45:12	2020-03-10	Danae Hegmann	danae.hegmann@woohoo.com	San Francisco	California	676349712765996	ae27d59d9cc801c41dcc0cd66d200687	VISA 16 digit	37.8038479708497022	-122.451930728879191
15188	2020-03-10 22:54:35	2020-03-10	Brooklyn Miller-Bins	brooklyn.miller.bins@geemail.com	Jersey City	New Jersey	55292338231889974	07404b1b43ce9eeab33f849abef7ceb5	VISA 16 digit	40.8051552157323769	-74.0048582834612603
15189	2020-03-10 23:03:15	2020-03-10	Vickie Kiehn	vickie.kiehn@geemail.com	Nashville	Tennessee	4692577922510524	de42142fe7c4edfcc308e89b23576c85	Maestro	36.0853009129997346	-86.8513026120979248
15190	2020-03-10 23:14:22	2020-03-10	Coleton McGlynn	coleton.mcglynn@woohoo.com	Little Rock	Arkansas	51426683533164561	89675058ad5e01b3656860a6e8ec5ff8	JCB 15 digit	34.759494632323829	-92.2676017271228091
15191	2020-03-10 23:44:44	2020-03-10	Roswell Corwin	roswell.corwin@geemail.com	Colorado Springs	Colorado	3006067259423328	ab38fd288750aeb31d6cbb9d832ae238	Maestro	38.8819949751302616	-104.668942432028061
15192	2020-03-11 00:07:12	2020-03-11	Gay Senger-Wiegand	gay.senger.wiegand@geemail.com	Tuscaloosa	Alabama	869990863018750572	bd16b7283cf76918c7001487d6cd5647	American Express	33.1111232987195265	-87.441912059961254
15193	2020-03-11 00:12:58	2020-03-11	Kareem Okuneva	kareem.okuneva@warmmail.com	Dallas	Texas	51961619754183154	7b12ac2ce47dd0b2f1e798747bcca61c	Maestro	32.8569389160528829	-96.8647240721583245
15194	2020-03-11 00:53:53	2020-03-11	Liz Lehner	liz.lehner@warmmail.com	San Francisco	California	6011505658252663146	11b13b1965436995efc4257472fc8f2a	VISA 13 digit	37.7471039957694359	-122.412900404182068
15195	2020-03-11 01:04:07	2020-03-11	Fronie Konopelski	fronie.konopelski@geemail.com	Lowell	Massachusetts	869933504606962951	cacf1ac3ea4b9b8879ff88e010162860	VISA 16 digit	42.7112418488003343	-71.3631211961492937
15196	2020-03-11 01:05:50	2020-03-11	Danica Gleichner	danica.gleichner@geemail.com	San Francisco	California	3528955285963652963	686ec3a47a9906fb60d7761dfb888a65	American Express	37.7647638750508747	-122.413548436167929
15197	2020-03-11 01:08:35	2020-03-11	Cornel Doyle	cornel.doyle@geemail.com	Kansas City	Kansas	869916217341410662	a542632244a7fe4813bbcdf40093d9c9	Diners Club / Carte Blanche	39.0448059107549525	-94.8018960426032464
15198	2020-03-11 01:11:19	2020-03-11	Davion Pfeffer	davion.pfeffer@geemail.com	Norwalk	California	4007762805300884	19e3e3925aaa0be2703d9430024109f9	VISA 16 digit	33.8411744574666074	-118.014812507856632
15199	2020-03-11 01:17:59	2020-03-11	Yasmin Little	yasmin.little@geemail.com	Raleigh	North Carolina	3096644179489152979	472d94b217e1e079180aba26c5e63928	VISA 16 digit	35.7815552729781672	-78.7309122114844655
15200	2020-03-11 01:39:59	2020-03-11	Claud Gleason PhD	claud.gleason.phd@woohoo.com	San Francisco	California	52398194162060132	f6799a02bf9cc665e6615c5e8e7e627c	Voyager	37.7961623121652863	-122.435692332068101
15201	2020-03-11 01:50:39	2020-03-11	Dylan Fisher DDS	dylan.fisher.dds@geemail.com	Waterbury	Connecticut	52596736751857987	4e2524eb348b0e8539a92b22386d5f32	VISA 16 digit	41.5188190709371128	-72.9684042819689864
15202	2020-03-11 01:56:47	2020-03-11	Amma Ortiz	amma.ortiz@woohoo.com	Oakland	California	561239510090671	e0ab6287c14e81162b5c2d9d6c9adf25	JCB 16 digit	37.8119263023487449	-122.283290934359798
15203	2020-03-11 02:34:50	2020-03-11	Jaxen Anderson	jaxen.anderson@woohoo.com	Palm Bay	Florida	3024130707037298	40fc9d030cc213094701eb6b9198f2f9	Discover	27.9122086108516925	-80.7241325122605957
15204	2020-03-11 02:39:41	2020-03-11	Ethelene Wuckert PhD	ethelene.wuckert.phd@geemail.com	Minneapolis	Minnesota	3029893359990685	ea5610791452fb70757e89b0b9ee0d77	VISA 13 digit	44.9842267762023909	-93.3531232788965042
15205	2020-03-11 02:39:43	2020-03-11	Reese Pagac	reese.pagac@woohoo.com	Lewisville	Texas	3158735694976663015	a9fa720d0be499817c18c13233a76b62	JCB 15 digit	32.9582325928363957	-96.9906061501272063
15206	2020-03-11 02:59:06	2020-03-11	Liliana Kozey	liliana.kozey@geemail.com	Oakland	California	3337514013062328887	b3417dffc9897e6aabf4aefe106c601e	JCB 16 digit	37.8229768559751349	-122.273877790935245
15207	2020-03-11 03:03:28	2020-03-11	Veda McLaughlin	veda.mclaughlin@geemail.com	Berkeley	California	3012206021493979	a0cb3eeac9fc66b907f6aa2c8e1af671	VISA 16 digit	37.8973881297311692	-122.257957325434901
15208	2020-03-11 03:12:12	2020-03-11	Alferd Schultz	alferd.schultz@geemail.com	Houston	Texas	54791531615283048	15856c8cf2c074828d0429cca208e63e	VISA 13 digit	29.7858758646607384	-95.4775201376076836
15209	2020-03-11 03:14:20	2020-03-11	Jayce Wilkinson	jayce.wilkinson@geemail.com	Broken Arrow	Oklahoma	869907928135039209	9514e153d367807956baf8fde487f297	VISA 16 digit	35.9983793190922583	-95.750526067795235
15210	2020-03-11 03:31:45	2020-03-11	Heber Ward	heber.ward@warmmail.com	Round Rock	Texas	6011272252200610424	8e386fa9c98bede34cedce7c682b4b1c	VISA 16 digit	30.5838877840571115	-97.5900948101505605
15211	2020-03-11 03:33:20	2020-03-11	Shirley Olson	shirley.olson@geemail.com	New York	New York	502078938001498	b53e8041fbb1e6fe938bcb42d68bc161	Voyager	40.6584180386494864	-73.8389325492911013
15212	2020-03-11 03:38:51	2020-03-11	Deneen Wolf	deneen.wolf@geemail.com	New York	New York	4790525398385419	e18e3b4ec2a9c34045e4c833eed8d684	Discover	40.736460229078304	-73.9481362771138464
15213	2020-03-11 04:02:06	2020-03-11	Ednah Prohaska	ednah.prohaska@woohoo.com	Hollywood	Florida	4675252317566850	cb7680afb2e72dd9986d0249ae0a2348	Mastercard	25.9337402944862845	-80.114898405950882
15214	2020-03-11 04:27:08	2020-03-11	Robley Turner III	robley.turner.iii@woohoo.com	Lexington	Kentucky	869909423782472042	122cefa7ccc30f0ed2c9d43fb180b51b	JCB 16 digit	37.9715695034589658	-84.4971504834845604
15215	2020-03-11 04:32:53	2020-03-11	Ladarius Klein	ladarius.klein@geemail.com	Dallas	Texas	3088348466083301477	17fc279550ec08b6ea5187a78f83a23a	Maestro	32.8253722476113623	-96.7249070677869014
15216	2020-03-11 04:35:29	2020-03-11	Mr. Brenden Ward	mr.brenden.ward@warmmail.com	San Francisco	California	180009694859139223	ca345cf8177a5ea5005211d9b2be35a3	Diners Club / Carte Blanche	37.7812953859753904	-122.427127288865265
15217	2020-03-11 05:08:47	2020-03-11	Debi Reichel	debi.reichel@geemail.com	Santa Ana	California	3021775843095783	62484fc4a239f2b68d0e90229406ebd4	Discover	33.8311963995091602	-117.86508492542616
15218	2020-03-11 05:10:31	2020-03-11	Amerigo Johnson	amerigo.johnson@woohoo.com	Jacksonville	Florida	4197614369910	6eafd602c5d92650054676d658c9862f	Mastercard	30.3776050602603718	-81.6005692950993904
15219	2020-03-11 05:33:33	2020-03-11	Lester Gibson DDS	lester.gibson.dds@geemail.com	Oakland	California	55204869669090633	113c58c1ef18295a406b81551374169e	JCB 16 digit	37.8265817518780736	-122.286968707016399
15220	2020-03-11 05:35:24	2020-03-11	Dr. Helena Monahan	dr.helena.monahan@warmmail.com	Richmond	California	3716148509281068	6f45dbbb859bd1afe6f845028929c142	VISA 16 digit	37.8676965219389672	-122.397104946788772
15221	2020-03-11 05:35:47	2020-03-11	Mr. Rene Hahn MD	mr.rene.hahn.md@warmmail.com	San Francisco	California	4986821165783793	0f07659a5dda755097f1cc87de643145	Diners Club / Carte Blanche	37.7911174583487508	-122.440120643503406
15222	2020-03-11 05:44:16	2020-03-11	Dr. Omari Terry DDS	dr.omari.terry.dds@warmmail.com	San Francisco	California	52740211713830378	e46868e55148bd45a978a46f38612ef9	VISA 13 digit	37.8066632445750272	-122.441136490589244
15223	2020-03-11 05:48:36	2020-03-11	Carlene Blick MD	carlene.blick.md@geemail.com	Berkeley	California	6011560717136208163	ba305e1771487e57f3fe9270cbc44be0	Mastercard	37.8928668118827545	-122.310245554621986
15224	2020-03-11 06:04:43	2020-03-11	Andra Dare	andra.dare@geemail.com	Athens	Georgia	4104425671909368	c7e9440806b637a365ecc47444795f32	VISA 16 digit	33.9385143502339659	-83.391967425320658
15225	2020-03-11 06:06:47	2020-03-11	Cornell Bogan-Pagac	cornell.bogan.pagac@geemail.com	Lincoln	Nebraska	561209849130779	cf28c97d0552d8ed5f1d5400321e8010	Voyager	40.7292315675895651	-96.7416276311662102
15226	2020-03-11 06:11:04	2020-03-11	Giovanna Prosacco	giovanna.prosacco@geemail.com	Irving	Texas	6011293884498124638	ed00ad3c5ca653e39ddc57eb2d5502a4	Mastercard	32.9361055695869069	-96.9369473258778385
15227	2020-03-11 06:15:17	2020-03-11	Mr. Waverly Beier	mr.waverly.beier@woohoo.com	Carrollton	Texas	4125293560507569	0e21964df4ae120cf650a9662de7fa17	American Express	33.0387587587270843	-96.8532274115692786
15228	2020-03-11 06:28:02	2020-03-11	Jamey Moore	jamey.moore@geemail.com	Santa Rosa	California	4371152369737	d247f3b195ae69f117b8de3299592501	VISA 13 digit	38.4520862152922902	-122.769407988457388
15229	2020-03-11 06:34:46	2020-03-11	Flonnie Fadel-Bode	flonnie.fadel.bode@geemail.com	Irvine	California	869969130956283850	6d26f75c425bba7096ba83d5f6badbef	Diners Club / Carte Blanche	33.6959167161040014	-117.818158537523075
15230	2020-03-11 06:58:02	2020-03-11	Kallie McKenzie PhD	kallie.mckenzie.phd@geemail.com	Milwaukee	Wisconsin	3027111681882138	9416e1253c18be3b66df91b6a135ae8d	JCB 15 digit	43.1056994654323873	-87.9377033044219019
15231	2020-03-11 07:00:30	2020-03-11	Murl Kertzmann	murl.kertzmann@geemail.com	Los Angeles	California	4018815540390	c46dda41bdb0b659181a5efa9ae958c0	VISA 16 digit	34.1135974815446872	-118.443697064741698
15232	2020-03-11 07:06:25	2020-03-11	Damari Kerluke	damari.kerluke@geemail.com	Frisco	Texas	210050561098588973	46a0743ec10d763e3da48925e48d7665	VISA 16 digit	33.1223947674032289	-96.8551281903613273
15233	2020-03-11 07:13:44	2020-03-11	Aubra Kunde	aubra.kunde@geemail.com	Davenport	Iowa	3050609762845137	8d19deb449add39ab8a6a1034b891361	JCB 16 digit	41.5331588271804151	-90.5863050742968881
15234	2020-03-11 07:22:45	2020-03-11	Mrs. Makayla Treutel DDS	mrs.makayla.treutel.dds@warmmail.com	Fresno	California	4280449755076718	9440610db4a25d9c70ddd1f529a5f8d6	VISA 16 digit	36.7146314562637386	-119.778791878662631
15235	2020-03-11 07:26:26	2020-03-11	Birdella Fritsch-Altenwerth	birdella.fritsch.altenwerth@geemail.com	El Paso	Texas	4626736271963251	0c0aa51da32c00819a36fe790e18eef6	VISA 16 digit	31.8786108880132453	-106.390868712959815
15236	2020-03-11 07:33:59	2020-03-11	Eldridge Rempel I	eldridge.rempel.i@geemail.com	Fort Wayne	Indiana	4444086019060212	d7f7d94c383c972e0980dfb77d0ebe96	VISA 13 digit	41.1747513757336918	-85.1996659240905245
15237	2020-03-11 07:38:07	2020-03-11	Honora Cartwright	honora.cartwright@geemail.com	Columbia	South Carolina	3027922846154027	dbbfe8fed7175ff1e0343c1190bb45ed	VISA 16 digit	34.0279821949344097	-80.8727280902229211
15238	2020-03-11 07:55:04	2020-03-11	Alonza Kuhic	alonza.kuhic@woohoo.com	Tulsa	Oklahoma	4215759618591665	c9691d72bc19a4fdc53bee0b9165a5f9	Voyager	36.1174135936327261	-95.8917128582905889
15239	2020-03-11 07:57:00	2020-03-11	Dr. Mathilda Schroeder DDS	dr.mathilda.schroeder.dds@warmmail.com	Indianapolis	Indiana	3490958931969505	a7456fab555d0cb2b4d88bfb542a65c1	Discover	39.8397964811425638	-86.161982960693166
15240	2020-03-11 08:26:23	2020-03-11	Eveline Welch	eveline.welch@geemail.com	El Paso	Texas	4495201097229	b55d9fca912d6f07b47e49d20b6ebd76	JCB 16 digit	31.7903525599107155	-106.373621133573366
15241	2020-03-11 09:05:25	2020-03-11	Buffy Purdy	buffy.purdy@geemail.com	Palmdale	California	3433027649277195	8d8adf5d8de5df062a787bf76bf5bd41	JCB 15 digit	34.5867131428178425	-118.00869469344579
15242	2020-03-11 09:07:56	2020-03-11	Ardell Powlowski-Nitzsche	ardell.powlowski.nitzsche@woohoo.com	Santa Rosa	California	6011077650833509177	116612a8579d72140c8e322f29f442fa	VISA 13 digit	38.3659483028233055	-122.671364040511108
15243	2020-03-11 09:36:52	2020-03-11	Khalil Leuschke	khalil.leuschke@geemail.com	San Francisco	California	4634383037799	9d961804c5b8e393386ffacd6fb202b7	VISA 16 digit	37.7646728093003574	-122.440670251068781
15244	2020-03-11 09:38:11	2020-03-11	Yadiel Hand-Wunsch	yadiel.hand.wunsch@warmmail.com	Cape Coral	Florida	3158511153174909662	c62c49761f242bbb34b2070c2b813a41	VISA 16 digit	26.6224587375268342	-82.0596679460793723
15245	2020-03-11 09:42:47	2020-03-11	Dr. Ace Satterfield II	dr.ace.satterfield.ii@geemail.com	Philadelphia	Pennsylvania	3528147724601466039	8974fde45db04119d0ddcd9ab3973d0b	Voyager	40.0070182905491407	-75.1510087311633015
15246	2020-03-11 09:56:24	2020-03-11	Michell Shanahan	michell.shanahan@geemail.com	San Francisco	California	3792248941273801	09076d0869ba1ddafa52e3cf4e10d00e	JCB 15 digit	37.7822020436927559	-122.442174044291349
15247	2020-03-11 10:14:24	2020-03-11	Vivian Walker-Boyle	vivian.walker.boyle@geemail.com	Portland	Oregon	3026842553100016	722c666e763df60a8433320596845b3e	JCB 16 digit	45.5040884896535403	-122.62854210874066
15248	2020-03-11 10:32:11	2020-03-11	Dr. Garvin Kirlin	dr.garvin.kirlin@warmmail.com	Montgomery	Alabama	6011077210118826885	057271a27c3b94edaa12bbd272883d44	Mastercard	32.3408593709979186	-86.2856423107128592
15249	2020-03-11 10:33:55	2020-03-11	Orley Hansen III	orley.hansen.iii@geemail.com	Omaha	Nebraska	561264320067305	c0a0100eefe05e5f98d1c34ddf62eb48	Discover	41.2155336384806787	-95.970880662661429
15250	2020-03-11 10:43:39	2020-03-11	Oswaldo Bernier Jr.	oswaldo.bernier.jr.@geemail.com	Columbus	Ohio	4560650841235	5d897c29901be415e1d52660fe6213fb	Mastercard	40.0655611275739929	-83.0335752530258162
15251	2020-03-11 11:00:05	2020-03-11	Eleanore Treutel	eleanore.treutel@woohoo.com	Chula Vista	California	6011852300817219663	1cf7016db9679eb95c90cbe2249893d9	JCB 16 digit	32.5394592071182984	-117.083000951050593
15252	2020-03-11 11:24:09	2020-03-11	Electa Welch-Douglas	electa.welch.douglas@geemail.com	San Francisco	California	3158265556769695181	42070b1e30127c914026c725001baa6d	Mastercard	37.748481395988783	-122.419165589290998
15253	2020-03-11 11:33:30	2020-03-11	Melvina Weber	melvina.weber@geemail.com	Los Angeles	California	180099682890355305	3d4b0f9361ab98cbe24043a3eb1ecd8c	JCB 16 digit	33.9629046658385505	-118.406239763599999
15254	2020-03-11 11:49:27	2020-03-11	Lucious Pfannerstill	lucious.pfannerstill@woohoo.com	Tulsa	Oklahoma	4125417686340486	59a38ea5fb0aa7367872654473693499	JCB 16 digit	36.0837570786844921	-95.9982100537933434
15255	2020-03-11 11:50:10	2020-03-11	Samir Kuphal	samir.kuphal@geemail.com	Lexington	Kentucky	6011131693139273035	c3db95f6db18867415009794251fd31e	JCB 16 digit	38.128105317369851	-84.5306715995438367
15256	2020-03-11 11:55:41	2020-03-11	Arch Hoeger	arch.hoeger@geemail.com	Houston	Texas	3037648346017659	ee6800ecb48d90703b9f1d3985945dc5	Mastercard	29.7939194960597895	-95.3467870315551806
15257	2020-03-11 12:18:58	2020-03-11	Christie Mitchell	christie.mitchell@geemail.com	Chicago	Illinois	180091904489317530	a77ead42b46804dc3b84e6d9ff96d5ec	VISA 16 digit	41.8371555957313674	-87.6436450679816232
15258	2020-03-11 12:29:19	2020-03-11	Zachariah Bailey-Mayer	zachariah.bailey.mayer@geemail.com	Newark	New Jersey	676254001418752	834003cf1d162fe6d07beb899acc12de	American Express	40.7890596821352887	-74.2040333766698836
15259	2020-03-11 12:38:52	2020-03-11	Collis Koelpin I	collis.koelpin.i@warmmail.com	San Francisco	California	3058990069997645	28ef7b45fa1456dfce7274314dc3c3cf	Voyager	37.7535495774094443	-122.389880753310408
15260	2020-03-11 13:02:54	2020-03-11	Dr. Corene Welch DVM	dr.corene.welch.dvm@geemail.com	San Francisco	California	4681471871687181	fe5a23f2439a9776d6366ace3499d46d	JCB 15 digit	37.7851525315153012	-122.441305512682177
15261	2020-03-11 13:23:49	2020-03-11	Ms. Kathaleen Lowe	ms.kathaleen.lowe@geemail.com	Laredo	Texas	639035239234855	a872595a333ea25298d96fe8959f4a4f	Voyager	27.521377353667841	-99.4052272028762758
15262	2020-03-11 13:34:00	2020-03-11	Aleena Gerhold	aleena.gerhold@geemail.com	Montgomery	Alabama	3050773684404504	09a6435ab61faeae52fb14e25e622972	VISA 13 digit	32.2902064074229429	-86.2519154268935324
15263	2020-03-11 13:39:12	2020-03-11	Elmore Kshlerin-Grady	elmore.kshlerin.grady@geemail.com	Lincoln	Nebraska	3001844081481277	b05c39b5f57f6e1d93444cf67991e6bb	VISA 16 digit	40.8059298074357173	-96.7653588642992162
15264	2020-03-11 13:47:05	2020-03-11	Kimora Gleichner	kimora.gleichner@warmmail.com	San Francisco	California	210097799320755219	7b856324a0137e3e3ee5b02562afeb9c	Maestro	37.7335419481066197	-122.415985277137978
15265	2020-03-11 13:50:19	2020-03-11	Manie Ankunding	manie.ankunding@geemail.com	San Francisco	California	3438396369417124	599c5d9f6e2ef0222e367843497232f4	Diners Club / Carte Blanche	37.7767138246115053	-122.425507194111162
15266	2020-03-11 14:17:19	2020-03-11	Florencio Thompson	florencio.thompson@geemail.com	Tampa	Florida	630484667194801	ed4c3b73b527f64083a1882b634090e7	JCB 16 digit	28.004195138777046	-82.5326696485027611
15267	2020-03-11 14:20:42	2020-03-11	Georganna King-Terry	georganna.king.terry@geemail.com	Berkeley	California	4373074793648	7a434288c9c261f635aea69e5cdee51c	Maestro	37.8316765267025232	-122.260235816286823
15268	2020-03-11 14:26:38	2020-03-11	Felton Kuvalis-Reichel	felton.kuvalis.reichel@geemail.com	Renton	Washington	52742166654268566	03272c2a24c342f02ba8c179c19c8cb2	JCB 15 digit	47.3915304408468359	-122.175033492369565
15269	2020-03-11 14:27:21	2020-03-11	Roxie Swift	roxie.swift@woohoo.com	Hialeah	Florida	3112222387617206571	968c1a0be86c8064f07723e7ac94f28f	JCB 16 digit	25.8319939486660068	-80.3026215833980501
15270	2020-03-11 14:34:06	2020-03-11	Corrie Klein	corrie.klein@warmmail.com	Columbus	Ohio	3028020999609696	ee55c595c2fd5985c82d387ee72d8b0e	Mastercard	39.9101590380117273	-83.0573091004744271
15271	2020-03-11 14:44:58	2020-03-11	Mr. Osvaldo Conn	mr.osvaldo.conn@geemail.com	Rochester	New York	4859002834471896	42fcb0ba2ff0f74e2b6d182638f832aa	JCB 16 digit	43.1624170527771085	-77.7041993667610029
15272	2020-03-11 15:09:10	2020-03-11	Gisele Abernathy	gisele.abernathy@geemail.com	San Francisco	California	3112316767678448054	624c15cb9be1d6d0ace1dcba4344664b	Mastercard	37.7573988261904958	-122.435801343208766
15273	2020-03-11 15:26:22	2020-03-11	Dr. Halbert Stokes	dr.halbert.stokes@geemail.com	North Charleston	South Carolina	6011500729019929222	22124aca85f05a7a61968f2031e72daa	VISA 16 digit	32.9750063874453332	-80.0203711285348902
15274	2020-03-11 15:33:38	2020-03-11	Meghan Lueilwitz	meghan.lueilwitz@geemail.com	Grand Prairie	Texas	3088297888570689869	ebf18859ea88308ef5d37cdcc0fbce4e	VISA 13 digit	32.7661438894975916	-97.0468457872852781
15275	2020-03-11 15:58:14	2020-03-11	Erin Davis	erin.davis@warmmail.com	Chula Vista	California	4178992677017	c2dd8db6b431e315aecb5e8c0f82c138	VISA 13 digit	32.6808981430016416	-116.998321875301002
15276	2020-03-11 16:09:36	2020-03-11	Mr. Marius Leffler	mr.marius.leffler@woohoo.com	High Point	North Carolina	6011192963900274835	6bc26098bd40a4f41d90077f037f6712	Mastercard	36.0061930993199368	-79.9158654451109385
15277	2020-03-11 16:10:59	2020-03-11	Jay Romaguera DVM	jay.romaguera.dvm@warmmail.com	Independence	Missouri	561296968398105	96245adcb962d317d01ca03c561e1e4d	VISA 13 digit	39.0928507496621478	-94.2789154412973573
15278	2020-03-11 16:12:45	2020-03-11	Mr. Esley Rosenbaum	mr.esley.rosenbaum@geemail.com	Berkeley	California	210056072958901078	511a37245e6b4053ac52dc7b3f9b74b4	Discover	37.8753480276651828	-122.327115188743804
15279	2020-03-11 16:23:39	2020-03-11	Michale McGlynn	michale.mcglynn@geemail.com	Irvine	California	4768822486082	724f0d052735e63f49eb2beb1e01218f	JCB 16 digit	33.6922270728755748	-117.696640191228312
15280	2020-03-11 16:26:43	2020-03-11	Arnett Herman	arnett.herman@geemail.com	Austin	Texas	3096371861723058471	79ab45722a273f1a74123011bc15b723	Maestro	30.3219102736223469	-97.7089318649616132
15281	2020-03-11 16:48:59	2020-03-11	Mrs. Rosalinda McCullough PhD	mrs.rosalinda.mccullough.phd@geemail.com	Riverside	California	6011650137478089306	3515492bdcb1ec37b3231567ff03e312	JCB 15 digit	33.8953100360877784	-117.473973948784916
15282	2020-03-11 16:52:50	2020-03-11	Dr. Karson Jacobson II	dr.karson.jacobson.ii@geemail.com	Glendale	Arizona	3744773550824957	9a98ddaa0dcc5456387625a435c0586d	Mastercard	33.4879674681223918	-112.129226552301645
15283	2020-03-11 17:07:48	2020-03-11	Mr. Asberry Hudson	mr.asberry.hudson@warmmail.com	Pasadena	Texas	6011765253379057987	7c529b04b420c984643e65735b56c1e1	Mastercard	29.6586568495132035	-95.1585674177803043
15284	2020-03-11 17:18:00	2020-03-11	Ms. Ivana Schumm	ms.ivana.schumm@warmmail.com	Orange	California	3528119464020994667	b5426bf70454a256e4a77da6752dd57b	Diners Club / Carte Blanche	33.7299073521401738	-117.878984934567654
15285	2020-03-11 17:22:21	2020-03-11	Maxie Blick	maxie.blick@warmmail.com	San Francisco	California	6011494183249502102	41dbc8c8d3f6845478877bb23a81cd6a	JCB 15 digit	37.7551890517422493	-122.418579798527944
15286	2020-03-11 17:36:48	2020-03-11	Lou Pacocha-Terry	lou.pacocha.terry@warmmail.com	Ann Arbor	Michigan	3112688282116505705	4eb30b8592b172dd7b8a5d839a65b85d	Diners Club / Carte Blanche	42.2238941215969632	-83.7204429922733482
15287	2020-03-11 18:02:16	2020-03-11	Deontae Koelpin	deontae.koelpin@geemail.com	New York	New York	210090898115727867	b41230c0e6515222d0c9906156ac5422	American Express	40.7113962159249922	-73.9119299627736126
15288	2020-03-11 18:18:14	2020-03-11	Raquan Greenfelder	raquan.greenfelder@geemail.com	Alexandria	Virginia	3096265476228760619	09937d95d1560ef63cd3e440cacd5298	Maestro	38.8212493126861702	-77.0661245923474496
15289	2020-03-11 19:11:17	2020-03-11	Ms. Ursula Windler	ms.ursula.windler@warmmail.com	Charlotte	North Carolina	502083696248109	2e0ef59bd92fa42acb67081f8dc35d14	JCB 16 digit	35.3077188745394324	-80.7686329963095488
15290	2020-03-11 19:13:41	2020-03-11	Dorotha Weimann-Streich	dorotha.weimann.streich@woohoo.com	St. Petersburg	Florida	4779739037638071	1025b7b5eca9e25773e990ecedf4d7d2	Mastercard	27.7495657768920054	-82.6735719133991722
15291	2020-03-11 19:38:00	2020-03-11	Danny Connelly	danny.connelly@geemail.com	Brownsville	Texas	4535058615001	29fd217c1e871661943d42dcaa56546b	JCB 16 digit	25.9814252933565513	-97.5014158431626896
15292	2020-03-11 19:43:15	2020-03-11	Tyrel Lind	tyrel.lind@geemail.com	San Francisco	California	060462909788002	1107885eeb80442a1f24b35ea9787832	VISA 16 digit	37.7609751857342957	-122.444143584934707
15293	2020-03-11 19:59:49	2020-03-11	Miss Oneida Barrows	miss.oneida.barrows@warmmail.com	New York	New York	6011755861795041831	81c79a91fc46285df022296bce3aa02a	Voyager	40.7473181570172329	-73.9537485925376359
15294	2020-03-11 20:08:27	2020-03-11	Eleanor Konopelski	eleanor.konopelski@geemail.com	New York	New York	6011146643351212958	ad12a4c3d4dae8cadc61375ab7855908	JCB 16 digit	40.652603237772361	-73.9779896454781323
15295	2020-03-11 20:44:54	2020-03-11	Laurie McClure	laurie.mcclure@warmmail.com	Los Angeles	California	3423222995706952	0e955b167463943d0ded59ee2461a54c	American Express	33.9240198870521041	-118.366832767705617
15296	2020-03-11 20:48:03	2020-03-11	Ms. Shirl Parisian	ms.shirl.parisian@warmmail.com	North Las Vegas	Nevada	3337125065235373381	f21fa2a8eb0aa625298dc04d75d1ce32	VISA 16 digit	36.3090244828414157	-115.040852120354401
15297	2020-03-11 20:59:03	2020-03-11	Ellen Kunze	ellen.kunze@woohoo.com	Indianapolis	Indiana	3158824579251892995	5342843dc2a5a5fbe25ad3844cf788c1	Maestro	39.859232822480422	-86.1145344959307408
15298	2020-03-11 21:03:21	2020-03-11	Dr. Izaiah Dibbert DVM	dr.izaiah.dibbert.dvm@geemail.com	Meridian	Idaho	3053153303246114	fb47e839dbc1cf1259b7da99b1f20366	JCB 15 digit	43.5596579766374035	-116.460105581808463
15299	2020-03-11 21:28:13	2020-03-11	Misael Berge	misael.berge@geemail.com	Omaha	Nebraska	3031745567719611	46b72be8d37fd24cf551b00cbbb5424e	Mastercard	41.3171295186650056	-96.081806452397629
15300	2020-03-11 21:54:12	2020-03-11	Dr. Evelyn Schneider DVM	dr.evelyn.schneider.dvm@geemail.com	Nashville	Tennessee	3337589842152723916	df5c2629aeaf07427ddf215edf4e3051	JCB 15 digit	36.1945049238514116	-86.7404048573132513
15301	2020-03-11 22:03:52	2020-03-11	Oda Ritchie DDS	oda.ritchie.dds@warmmail.com	Long Beach	California	3436313858737690	6b9d9c2c865f0e67f430e0d44bb13f9b	Mastercard	33.8510462542816981	-118.070433744571361
15302	2020-03-11 22:10:30	2020-03-11	Dr. Elonzo Ziemann II	dr.elonzo.ziemann.ii@geemail.com	Sunnyvale	California	4849892039541359	7295a39358a8ba7ff777ac37893c61d4	Diners Club / Carte Blanche	37.3362950665868851	-121.950744280797622
15303	2020-03-11 22:22:45	2020-03-11	Buck Stehr IV	buck.stehr.iv@geemail.com	Santa Maria	California	4470770919599919	8e2d12932db032688aac50690d876198	American Express	34.8762736129172168	-120.363854972963409
15304	2020-03-11 22:33:42	2020-03-11	Emaline Kunze	emaline.kunze@geemail.com	Louisville	Kentucky	3096783835766833935	8d454109683c71c344249e974b2ee0be	Maestro	38.203873672326651	-85.6497704912513598
15305	2020-03-11 22:47:13	2020-03-11	Gladstone Christiansen	gladstone.christiansen@geemail.com	Denver	Colorado	4504433262509	7dedec79087160568dccb3fe4477be15	Maestro	39.7922047374356538	-104.883140983177725
15306	2020-03-11 23:00:15	2020-03-11	Council Wunsch	council.wunsch@woohoo.com	Nashville	Tennessee	869990362860563225	ddbf88d012e432b5e6e37cbb1e250453	Voyager	36.0868794364977603	-86.7586090584192391
15307	2020-03-11 23:01:31	2020-03-11	Damon Brakus	damon.brakus@woohoo.com	Charlotte	North Carolina	501896225800687	f35716b672d22209ea01e8cfd3189cbd	JCB 15 digit	35.1459834281608465	-80.9287372978348287
15308	2020-03-11 23:09:23	2020-03-11	Elinor Carroll	elinor.carroll@geemail.com	Stamford	Connecticut	675961094810282	560344bb0bac6667f749d15ed58b9442	Discover	40.9853331251885749	-73.4664362041782653
15309	2020-03-11 23:11:02	2020-03-11	Jaimie Cartwright	jaimie.cartwright@geemail.com	San Francisco	California	4931659127954458	22081d1ead0bba2233093340a7c15d7f	Discover	37.7808899096964481	-122.413862896575324
15310	2020-03-11 23:20:29	2020-03-11	Kaaren Schmitt	kaaren.schmitt@geemail.com	Topeka	Kansas	869937499182748765	7732775b887c5235e501b42fe598fdb5	Diners Club / Carte Blanche	39.0778298474781209	-95.7951093655720456
15311	2020-03-11 23:24:23	2020-03-11	Norine Corkery	norine.corkery@geemail.com	Chandler	Arizona	6011120790615671741	3f2ad5de3aa2c51c424ca1ab262217d5	JCB 15 digit	33.283743089353294	-111.936105760594458
15312	2020-03-11 23:42:34	2020-03-11	Winnie Prosacco	winnie.prosacco@warmmail.com	Houston	Texas	210065218181475633	c5d1851217ff1ba80eb2c42d4fbc0b37	Discover	29.7808632691469057	-95.3781651237063102
15313	2020-03-11 23:45:00	2020-03-11	Ruthann Jacobson	ruthann.jacobson@geemail.com	Memphis	Tennessee	4944055485231438	d15e7b1671e7c0e8e742d78db78dac78	VISA 16 digit	35.0291817749917556	-89.9011633400130989
15314	2020-03-12 00:13:37	2020-03-12	Cory Hodkiewicz	cory.hodkiewicz@geemail.com	Cape Coral	Florida	502023873622668	88f0cacf5e3096d637a5027ff209d0f2	Mastercard	26.6312898766685286	-82.0639015118196653
15315	2020-03-12 00:26:10	2020-03-12	Zoa Waelchi	zoa.waelchi@geemail.com	Albuquerque	New Mexico	869904933201076187	822ce9470472cf52cb329d1c1c33b75b	Discover	35.0638488910760771	-106.564893863962595
15316	2020-03-12 00:28:50	2020-03-12	Lorenzo Daugherty	lorenzo.daugherty@geemail.com	San Francisco	California	6011514941065612016	c49999ea2a7195921f2d61df21301937	VISA 16 digit	37.7570929501551689	-122.416212485877423
15317	2020-03-12 00:34:59	2020-03-12	Margurite Konopelski	margurite.konopelski@geemail.com	Simi Valley	California	4723270544786242	bbe84fb0eca88e37be64c61086e27739	Voyager	34.3325243317294877	-118.837694217091439
15318	2020-03-12 00:43:12	2020-03-12	Mr. Maceo Kertzmann	mr.maceo.kertzmann@woohoo.com	New York	New York	3112639847548127995	f2f62854417f30ca63ed762df93c8f77	Maestro	40.576825242465361	-73.9681584606774152
15319	2020-03-12 00:55:24	2020-03-12	Rick Jast	rick.jast@geemail.com	San Francisco	California	3791841515846068	0dbed9f3ae1f4f36da8d174457091c32	VISA 13 digit	37.7790053729491362	-122.449941756218749
15320	2020-03-12 01:10:51	2020-03-12	Nat Smitham	nat.smitham@geemail.com	New York	New York	639025503840800	49b1b233c94b25b0c520f1622a014401	VISA 16 digit	40.596954846637324	-73.8681531768653485
15321	2020-03-12 01:11:48	2020-03-12	Bowman Ritchie	bowman.ritchie@woohoo.com	Inglewood	California	3158177497725317619	93e9682658054a0c594a9011e7dba8ee	VISA 16 digit	33.921389783710616	-118.257998105560617
15322	2020-03-12 01:20:08	2020-03-12	Alexander Reichert	alexander.reichert@geemail.com	Tucson	Arizona	4416347814780	2d292edfd8db33003dc862b4d0b08209	VISA 13 digit	32.2268716349307454	-110.905003111925339
15323	2020-03-12 01:20:38	2020-03-12	Dr. Jermaine Howell	dr.jermaine.howell@warmmail.com	Riverside	California	3337023723697476554	6bae227e56b2717071432bdc60a5a981	VISA 16 digit	33.8894465797994258	-117.465711222073807
15324	2020-03-12 01:21:16	2020-03-12	Arvo Mayert-Harris	arvo.mayert.harris@woohoo.com	Athens	Georgia	3096463798171058406	423c46a586d5d2892f436ad8084f9d7b	VISA 16 digit	34.0298656279876823	-83.325395521160587
15325	2020-03-12 01:44:48	2020-03-12	Markel Hartmann-Abshire	markel.hartmann.abshire@geemail.com	Elgin	Illinois	210007635978357701	54aced2825c3f3c232f0a4ec293664f7	Mastercard	42.0979737159613521	-88.3324477629091689
15326	2020-03-12 02:00:08	2020-03-12	Woodson Schuppe	woodson.schuppe@geemail.com	San Francisco	California	53682165556987796	842ae7c7d3555787457da52b7c15f18e	Voyager	37.7456179133070293	-122.439599037474835
15327	2020-03-12 02:09:22	2020-03-12	Joshua DuBuque	joshua.dubuque@geemail.com	Clearwater	Florida	869924633365150903	bc362c4d9f90abc3d0ff7f83ec537e9b	Diners Club / Carte Blanche	27.8808935814198087	-82.7532751195397225
15328	2020-03-12 02:19:47	2020-03-12	Enrico Stamm	enrico.stamm@geemail.com	San Francisco	California	3030114345284698	1e9ca9049679a2be76e15e492d39820c	Mastercard	37.7644698152162448	-122.430211624175499
15329	2020-03-12 02:36:43	2020-03-12	Cristy Considine MD	cristy.considine.md@warmmail.com	San Francisco	California	4525919056367912	41609fed17956bab12f050e101689f6f	Discover	37.7691858251948673	-122.457030247475316
15330	2020-03-12 02:58:58	2020-03-12	Dr. Benjiman Stokes I	dr.benjiman.stokes.i@geemail.com	New York	New York	54763481460471443	befefc619bb1c077806ee5c5336852ed	JCB 15 digit	40.7031450179629033	-74.0193403018068494
15331	2020-03-12 02:59:45	2020-03-12	Benita Schroeder	benita.schroeder@geemail.com	Oakland	California	869931060399010963	d73fcf38025fe42b5230308a8e62841a	JCB 16 digit	37.799826503998851	-122.232891579831247
15332	2020-03-12 03:09:09	2020-03-12	Dr. Antone Ferry	dr.antone.ferry@geemail.com	Pomona	California	180053213853477409	5522f9031c44eb25ca897bff9a347e81	JCB 16 digit	34.0656460078004741	-117.66807439499199
15333	2020-03-12 03:19:43	2020-03-12	Bonny Maggio	bonny.maggio@geemail.com	Milwaukee	Wisconsin	3744015794223772	0ae4fe638b904edfeee5acebf0dc75b7	VISA 16 digit	43.1496919555209573	-87.9749140662707418
15334	2020-03-12 03:40:08	2020-03-12	Marchello Blanda-Little	marchello.blanda.little@geemail.com	Seattle	Washington	3088051519696367454	a3144d1702a0282a913f12d0ca723ab1	VISA 13 digit	47.5725140836481017	-122.316619106094905
15335	2020-03-12 04:02:46	2020-03-12	Bette Bernier	bette.bernier@woohoo.com	Visalia	California	3158710587034016573	b5239f90d944b6c0a80681db0c26ada9	VISA 13 digit	36.3184235633771877	-119.389986650332446
15336	2020-03-12 04:19:25	2020-03-12	Ms. Angelique Schmeler DDS	ms.angelique.schmeler.dds@woohoo.com	Los Angeles	California	3708501372345065	d373a7741ee7c9340f8d2ca35ca126ff	Discover	34.0693084611423274	-118.443845744104308
15337	2020-03-12 04:19:58	2020-03-12	Oral Braun	oral.braun@warmmail.com	Los Angeles	California	3112161446074964339	053f366bd29adcf68698239d6c33fa57	Voyager	33.9957161937706118	-118.391051409672201
15338	2020-03-12 04:27:24	2020-03-12	Mr. Cory Crooks MD	mr.cory.crooks.md@geemail.com	Ontario	California	3052832198515235	d4b4dc3a8b3f8b2e8198b5e9b2b5b34f	Maestro	33.9608415628928668	-117.61059172862285
15339	2020-03-12 04:38:00	2020-03-12	Karis Casper	karis.casper@geemail.com	Fort Worth	Texas	3046789922914942	24124a04ce32967027b4067f880da401	Discover	32.7013619632516068	-97.3596185068886655
15340	2020-03-12 04:41:54	2020-03-12	Mrs. Madilyn Waelchi PhD	mrs.madilyn.waelchi.phd@geemail.com	San Francisco	California	4910191722339195	05f04045ae61d0abd5e3f639affb6cb8	VISA 13 digit	37.8029074378257661	-122.432064714585536
15341	2020-03-12 04:45:19	2020-03-12	Holland Mills	holland.mills@geemail.com	Honolulu	Hawaii	4548862360071502	9096616ec5c42df3d55815ef5f50d23d	VISA 13 digit	21.2587694721046851	-157.884959210802236
15342	2020-03-12 05:08:41	2020-03-12	Lillian Stanton-Renner	lillian.stanton.renner@warmmail.com	Downey	California	3528666268620250157	0f2174ff9d4cc92ab1760f9960ff2d76	JCB 16 digit	33.8537004039872471	-118.217721683263406
15343	2020-03-12 05:31:21	2020-03-12	Mr. Greggory Nitzsche Sr.	mr.greggory.nitzsche.sr.@geemail.com	Santa Clarita	California	4736954093508629	074939443d717b08b59171b17b236f47	Diners Club / Carte Blanche	34.3933193016536549	-118.459481717004252
15344	2020-03-12 05:36:25	2020-03-12	Gwyneth Smitham	gwyneth.smitham@geemail.com	Colorado Springs	Colorado	6011742953243503474	90cee9cd572e81f03ed840ae688949af	Mastercard	38.9439961431130754	-104.724100873821229
15345	2020-03-12 06:07:50	2020-03-12	Mr. Alton Lindgren DVM	mr.alton.lindgren.dvm@geemail.com	El Paso	Texas	4487380683994	118cfa84a15566b799771b4ce2249bec	VISA 16 digit	31.8426378031555579	-106.359158642122523
15346	2020-03-12 06:13:01	2020-03-12	Matias Gerlach	matias.gerlach@geemail.com	El Paso	Texas	869963041625591951	b052c82b348e736a7a61a136ceadb712	JCB 16 digit	31.777390566404538	-106.46532842539996
15347	2020-03-12 06:40:16	2020-03-12	Mr. Dereck Bogan	mr.dereck.bogan@geemail.com	Las Vegas	Nevada	210081552355938798	a6d2298e62699fd733f912cd91fb9b1e	JCB 15 digit	36.3186538464024622	-115.320625362472981
15348	2020-03-12 06:56:56	2020-03-12	Antonette Carroll	antonette.carroll@geemail.com	Louisville	Kentucky	51809802946228709	21e7f5c89ba4bbed0d49503af3f9a1c9	VISA 16 digit	38.0968421385992286	-85.7343954423047592
15349	2020-03-12 07:15:22	2020-03-12	Emelie Wilderman	emelie.wilderman@geemail.com	Memphis	Tennessee	676258915390445	85935c81e5a26601368ac5d12b40c492	VISA 16 digit	35.0154888697035602	-89.9561602481897893
15350	2020-03-12 07:16:47	2020-03-12	Reed Harvey-Ortiz	reed.harvey.ortiz@geemail.com	Seattle	Washington	3041053771477450	536d914811978a6970f81d45fb18cf07	Mastercard	47.6645179501194534	-122.334588360778611
15351	2020-03-12 07:31:56	2020-03-12	Elbridge Deckow	elbridge.deckow@warmmail.com	San Francisco	California	869995314004098639	0f74e8c4229704ab029c997588c9c32e	Maestro	37.7543759833404593	-122.397604666679925
15352	2020-03-12 07:47:38	2020-03-12	Tameka Schamberger	tameka.schamberger@warmmail.com	Yonkers	New York	180000220367196106	4da4c6db5700d3c0ab1566794d318e10	Maestro	40.9342138475008355	-73.886716469458861
15353	2020-03-12 07:51:55	2020-03-12	Ruffus Lind DVM	ruffus.lind.dvm@geemail.com	Waco	Texas	3528597238844490966	a6e2e5a9a81d44330822c9ee0ebf6719	JCB 16 digit	31.5341884000435471	-97.1877085644416638
15354	2020-03-12 08:02:31	2020-03-12	Dominique Kutch	dominique.kutch@warmmail.com	New York	New York	4654783964106421	9c43dcc6c500dae62af60639867eccff	VISA 16 digit	40.7579352781865722	-73.9673258931271675
15355	2020-03-12 08:05:52	2020-03-12	Zola Lakin-Bayer	zola.lakin.bayer@geemail.com	Anchorage	Alaska	3427585057720244	dd7d155210d1368b2a7b11680e61ac72	Diners Club / Carte Blanche	61.1158269609075049	-149.185865348915769
15356	2020-03-12 08:15:18	2020-03-12	Diya Rempel	diya.rempel@geemail.com	Houston	Texas	3337849000352882943	e14d9134c1fa7c88a3bbeaff1ce043c9	Discover	29.8540991632346078	-95.4165078132893854
15357	2020-03-12 08:53:00	2020-03-12	Arlis Swift	arlis.swift@warmmail.com	San Francisco	California	3049035736869139	eeb8ca35a4768a198b320d140ef3cef1	VISA 16 digit	37.7841976820760337	-122.44313776164897
15358	2020-03-12 08:56:04	2020-03-12	Jaquan Russel	jaquan.russel@warmmail.com	San Francisco	California	3528178595704175301	d59520cc19fb57978081af28c89ccfc4	Voyager	37.7458480179414479	-122.446866582243672
15359	2020-03-12 09:10:24	2020-03-12	Delfina Langworth	delfina.langworth@warmmail.com	Atlanta	Georgia	869959229020944331	24dfcdbc371fe26557c371be73bf989a	VISA 16 digit	33.7085997918896396	-84.5126392954539511
15360	2020-03-12 09:10:59	2020-03-12	Melville Predovic	melville.predovic@geemail.com	Mesa	Arizona	4649538770909030	76e494a7fb00f904f8c54e3d1070be81	Discover	33.3476815041765562	-111.774229867558546
15361	2020-03-12 09:15:35	2020-03-12	Mrs. Lela Weber	mrs.lela.weber@geemail.com	San Francisco	California	3112451954290550856	5b477a6d4a7c1fa1d996bc762db72ad3	VISA 16 digit	37.7823727648084784	-122.446570470880815
15362	2020-03-12 09:15:48	2020-03-12	Zebulon Torp	zebulon.torp@warmmail.com	Peoria	Arizona	4987775714068255	20aca5854d74bfee1d2485f5736c8730	VISA 16 digit	33.8806598988164254	-112.271790281349794
15363	2020-03-12 09:50:11	2020-03-12	Kolton Schoen III	kolton.schoen.iii@geemail.com	Orange	California	54468099618743691	665feaf0c6f68ac552f5207e7d888e4c	Diners Club / Carte Blanche	33.8274971847776342	-117.898039394115287
15364	2020-03-12 09:50:40	2020-03-12	Yaretzi Kshlerin	yaretzi.kshlerin@geemail.com	Palmdale	California	6011695373079760584	8a63aa302ce0d5bc7ae5ca716b0651a5	Diners Club / Carte Blanche	34.5456909980941589	-118.107895468687275
15365	2020-03-12 10:09:53	2020-03-12	Mrs. Shaniya Kuphal DDS	mrs.shaniya.kuphal.dds@geemail.com	Washington	District of Columbia	51518175200602865	5cfa64c92254f923abd4d45896132080	VISA 13 digit	38.9381076530817865	-77.0779497832272256
15366	2020-03-12 10:10:36	2020-03-12	Mafalda Ryan DVM	mafalda.ryan.dvm@geemail.com	Memphis	Tennessee	3734354071441407	3c8b849dceb43a14c8a7005a2f850bf6	Voyager	35.1754089083123986	-89.9280520433351427
15367	2020-03-12 10:16:00	2020-03-12	Miss Abby Cummerata DVM	miss.abby.cummerata.dvm@woohoo.com	San Angelo	Texas	3787134589054579	872c5b08ceef313b97e78ff16b05f415	JCB 16 digit	31.4093913013268242	-100.438883435644215
15368	2020-03-12 10:37:53	2020-03-12	Mrs. Rylan Balistreri	mrs.rylan.balistreri@woohoo.com	New York	New York	6011531777490256824	721764e7b951004080e697f48827df4c	JCB 15 digit	40.5883403579927986	-73.8659409047000111
15369	2020-03-12 10:38:54	2020-03-12	Nya Schumm	nya.schumm@geemail.com	Winston–Salem	North Carolina	4926669826849294	ccdece1dd15859628f44c231efa94429	Discover	36.0802703972671139	-80.2682546866256672
15370	2020-03-12 11:06:22	2020-03-12	Herb Bechtelar	herb.bechtelar@warmmail.com	San Francisco	California	210046144636851976	5da52c020f70e80bc0d868f632f16863	JCB 16 digit	37.8224197563418869	-122.399693630107734
15371	2020-03-12 11:10:13	2020-03-12	Mrs. Eulalie Jaskolski PhD	mrs.eulalie.jaskolski.phd@geemail.com	Moreno Valley	California	3007959308207679	2e2031aab489583f2a9badb81863c7ba	JCB 16 digit	33.9287762664716652	-117.23429830218366
15372	2020-03-12 11:29:44	2020-03-12	Mr. Arvo Pfeffer V	mr.arvo.pfeffer.v@geemail.com	Louisville	Kentucky	3712534359889106	9a5fcb8662fc70ac5213ce7986323438	Discover	38.1154552567187679	-85.7119994441583799
15373	2020-03-12 11:33:08	2020-03-12	Elfie Bahringer	elfie.bahringer@geemail.com	Oakland	California	52996939857841352	19878863b3253b702637546d8c72d7bd	Voyager	37.8176197488609489	-122.271500055681102
15374	2020-03-12 12:03:41	2020-03-12	Randy Sauer	randy.sauer@geemail.com	Houston	Texas	3037914885911458	ce22994d112311ebc417019ee5eeb6ce	Discover	29.7309413940723992	-95.4467070239610962
15375	2020-03-12 12:10:38	2020-03-12	Jonathon Gutmann	jonathon.gutmann@geemail.com	Fort Worth	Texas	3002011355025458	f97ed7eaf85f64db947fc17db164c811	VISA 16 digit	32.738906910927966	-97.3757912412106919
15376	2020-03-12 12:11:07	2020-03-12	Dorotha Monahan	dorotha.monahan@geemail.com	Mesa	Arizona	4679209376079	bba18752c3379cd1b869eaa3eac137e9	American Express	33.3586543587181694	-111.789119109686084
15377	2020-03-12 12:24:13	2020-03-12	Destany Schaefer	destany.schaefer@geemail.com	Grand Prairie	Texas	869926418936382328	0ce160bc758931b3f5887350c625404f	VISA 16 digit	32.7216566705662757	-97.0679047542963218
15378	2020-03-12 12:39:21	2020-03-12	Cesar Schinner PhD	cesar.schinner.phd@geemail.com	Los Angeles	California	6011691184295069435	d8f29ae4bf32a5dbda3f4cb9fc9753c9	VISA 13 digit	34.0706693166267129	-118.469681512843067
15379	2020-03-12 12:54:33	2020-03-12	Sherwood Reichert	sherwood.reichert@woohoo.com	San Francisco	California	3112441482327905300	0253c29860d75ace92be97a3156e2e26	Mastercard	37.7611927190223042	-122.419893443145753
15380	2020-03-12 12:58:45	2020-03-12	Holden Schmidt-Bode	holden.schmidt.bode@geemail.com	Tyler	Texas	3528779899098854601	2e6cc7e9628978d1a5f5953312c3b9a4	JCB 16 digit	32.4157950797632353	-95.2083997508618864
15381	2020-03-12 13:21:35	2020-03-12	Young Bartoletti	young.bartoletti@geemail.com	San Francisco	California	4437696983036078	b861e2c038c6f56a6a9e42cb222d7ddd	VISA 16 digit	37.7380668265387769	-122.421004596413397
15382	2020-03-12 13:26:22	2020-03-12	Richard Heathcote	richard.heathcote@geemail.com	Charlotte	North Carolina	6011317952158921882	1fe47ce26feee9d7e8d277c59e51dc6a	VISA 13 digit	35.2120530609294775	-80.842092345556253
15383	2020-03-12 13:45:38	2020-03-12	Trumaine Hamill	trumaine.hamill@warmmail.com	Hampton	Virginia	53216449561756742	092deaa16df9cde89ea3fa0cdf8dae72	JCB 16 digit	37.0196378050390678	-76.3301928888637633
15384	2020-03-12 13:48:31	2020-03-12	Gage West	gage.west@warmmail.com	Garland	Texas	3088588218938635990	efaa0de8a5ad934b117050a0205465e1	Mastercard	32.9358541618335963	-96.6403515305530334
15385	2020-03-12 13:50:25	2020-03-12	Darrius Barrows	darrius.barrows@geemail.com	San Francisco	California	4490114617981	180cbf90013a886c47ff88bff8786199	JCB 16 digit	37.81507901313514	-122.423558260558778
15386	2020-03-12 13:56:06	2020-03-12	Dorthea Dibbert	dorthea.dibbert@geemail.com	Cincinnati	Ohio	4275064437435	d4a3eed07682806e14d47e8d42ae1031	JCB 16 digit	39.2248670488826932	-84.4816108196779965
15387	2020-03-12 14:03:41	2020-03-12	Miss Maura Pfannerstill	miss.maura.pfannerstill@geemail.com	New York	New York	180043316811264620	93702359c1cba8c0dcba0e196b523ae2	VISA 16 digit	40.5964940557014202	-73.9422952094942332
15388	2020-03-12 14:07:51	2020-03-12	Dr. Ishmael Walter Jr.	dr.ishmael.walter.jr.@warmmail.com	Oakland	California	869990520068791431	1fdb34972a4b22d65c187ec1316a68cf	VISA 13 digit	37.8036721162759974	-122.293360062426146
15389	2020-03-12 14:13:45	2020-03-12	Toriano Batz-Schiller	toriano.batz.schiller@geemail.com	Los Angeles	California	4112835197370	ed0dfaa5137662569c7aaded1fe988db	JCB 16 digit	34.1184341740660315	-118.433650284632293
15390	2020-03-12 14:16:28	2020-03-12	Halle Bergstrom	halle.bergstrom@woohoo.com	New York	New York	55425623691956607	c21e46b79dd3e681066c58bf5144e621	Mastercard	40.6001596499457946	-73.9626073214121078
15391	2020-03-12 14:23:19	2020-03-12	Dorian Franecki	dorian.franecki@geemail.com	Kansas City	Missouri	3528397753490120602	a55ea82f3ee0a2f8098c1a1c0d3db503	JCB 16 digit	39.0614009326159959	-94.4657640952840438
15392	2020-03-12 14:32:42	2020-03-12	Mohammed Oberbrunner	mohammed.oberbrunner@geemail.com	Memphis	Tennessee	4097337602755	e05e2be6d84f4f31a01f4091bc5eef38	Discover	35.1025979822102983	-89.9116140481341688
15393	2020-03-12 14:34:22	2020-03-12	Adele Kiehn	adele.kiehn@geemail.com	Las Vegas	Nevada	3402373452202947	94013988724d7705b8788b5112cff1bb	VISA 13 digit	36.239602269242333	-115.352981530849263
15394	2020-03-12 14:39:14	2020-03-12	Rachael Hartmann	rachael.hartmann@geemail.com	San Francisco	California	639063579930718	83d6f1547af72f69c006cb589f7c0efb	JCB 15 digit	37.8129486160552517	-122.399214262343563
15395	2020-03-12 14:51:11	2020-03-12	Cristina Reynolds	cristina.reynolds@geemail.com	Berkeley	California	180072561494747391	68546c9fa77ec67c856ef4728b576643	American Express	37.8370415128958655	-122.23982884533541
15396	2020-03-12 14:54:06	2020-03-12	Dr. Natalie Nienow DDS	dr.natalie.nienow.dds@geemail.com	Santa Ana	California	3023230080905516	995cbec0ecda314f02698cb111fd4f3c	Mastercard	33.6932776761345565	-117.970647729180754
15397	2020-03-12 15:04:32	2020-03-12	Hattie Johnson	hattie.johnson@geemail.com	New York	New York	3112770276125201958	9dd03e8fea0f8050e4a75829cf1fa315	Diners Club / Carte Blanche	40.7467563547417484	-73.8600029563426972
15398	2020-03-12 15:10:44	2020-03-12	Cruz Schinner	cruz.schinner@geemail.com	Lafayette	Louisiana	3337921727958055398	102a6b6d2cb830c95ec072461d3972b0	Voyager	30.1540627272777257	-92.0420068685281905
15399	2020-03-12 15:46:39	2020-03-12	Venita Casper	venita.casper@geemail.com	Grand Rapids	Michigan	4076076375508537	a15c195eac3e07a4614fb144aa51aac7	Voyager	42.9505057557288552	-85.645255075455097
15400	2020-03-12 15:50:55	2020-03-12	Ivonne Barrows	ivonne.barrows@warmmail.com	San Francisco	California	4661617204002308	c0e1b51de9c3c8db2d5ebf2e2b7595ee	VISA 16 digit	37.7848696578449434	-122.448126911983451
15401	2020-03-12 16:07:34	2020-03-12	Brittnee Feest-Kutch	brittnee.feest.kutch@geemail.com	Rockford	Illinois	676247145364213	2c2725713ab9a757f029809a04530924	American Express	42.2611740496020758	-89.1605559879731402
15402	2020-03-12 16:23:34	2020-03-12	Giada Spinka	giada.spinka@geemail.com	New York	New York	3000464121647174	b3cb7a7da64e6953210cb92220afc579	Voyager	40.6483406159319003	-73.9263706955954376
15403	2020-03-12 16:40:48	2020-03-12	Griffith Bosco-Rogahn	griffith.bosco.rogahn@woohoo.com	Eugene	Oregon	3754001626673241	3331af05ff8e964faec60a219a377b80	VISA 16 digit	43.9709423942219431	-123.017085385321465
15404	2020-03-12 16:44:07	2020-03-12	Roseanna Kuphal-Kirlin	roseanna.kuphal.kirlin@woohoo.com	Phoenix	Arizona	6011070681139586368	5aaef3cd1905b6dafeb4d95547c9c22a	Voyager	33.5736632585458494	-112.139870083790655
15405	2020-03-12 16:54:47	2020-03-12	Tyreke Wisozk	tyreke.wisozk@geemail.com	Oakland	California	4378576840631	908e7ee9c09a9e293fc5e5f5d8a50a6c	JCB 16 digit	37.7992799110140467	-122.274816683111467
15406	2020-03-12 17:00:29	2020-03-12	Dr. Enzo Hane	dr.enzo.hane@woohoo.com	Glendale	California	4969639822246991	975f0dfba47d8673f90b2d1d44e30251	VISA 13 digit	34.2789674909073838	-118.161941564026478
15407	2020-03-12 17:00:33	2020-03-12	Pedro Hartmann II	pedro.hartmann.ii@warmmail.com	North Las Vegas	Nevada	630489094185777	2ffa724eb7f65d6569ab9dac970080e9	Discover	36.3722818826481671	-115.147475361799451
15408	2020-03-12 17:00:52	2020-03-12	Irving Gutmann	irving.gutmann@geemail.com	Dallas	Texas	3112121347041864751	30f247306c4fca291dd3c181e5049f29	Discover	32.8073825047157754	-96.7741688325032499
15409	2020-03-12 17:20:16	2020-03-12	Mr. Jeb Ritchie	mr.jeb.ritchie@warmmail.com	Los Angeles	California	4222388926386252	296d485583e3d2da3945c07b74342397	JCB 15 digit	34.1140947430726129	-118.422759475604806
15410	2020-03-12 17:21:00	2020-03-12	Arsenio Feil	arsenio.feil@geemail.com	Pembroke Pines	Florida	210068542571152859	5f58f11a0e1d693fd2f7bc55b00879d2	Discover	25.9273441801350586	-80.2411385431323225
15411	2020-03-12 17:27:31	2020-03-12	China Hand	china.hand@geemail.com	Sandy Springs	Georgia	54070801894407481	587615900b3af4c9dc7cc178b59ef9ed	Discover	33.9523023292478143	-84.3019399425562455
15412	2020-03-12 17:34:43	2020-03-12	Dr. Signa Ondricka	dr.signa.ondricka@geemail.com	Des Moines	Iowa	4448858643915326	3cd40161cecd98818dcdebbc809280ca	Voyager	41.6516926738176494	-93.6108545331329225
15413	2020-03-12 17:52:59	2020-03-12	Dr. Kunta Daniel	dr.kunta.daniel@woohoo.com	Cincinnati	Ohio	4067889540497	6e48deadb1d79ab67336a928a01e7547	Maestro	39.1806824334196762	-84.5347049559738366
15414	2020-03-12 18:01:34	2020-03-12	Burl Nader	burl.nader@geemail.com	Los Angeles	California	4491697053610852	8794ed8bc8aa9f4a4e11e02a738f54f6	American Express	33.9845219780091199	-118.471071915281186
15415	2020-03-12 18:02:32	2020-03-12	Cleone Adams	cleone.adams@woohoo.com	New York	New York	676104447469349	368d2be9a5c83c91f5a5a4e593d7fc36	VISA 16 digit	40.658836903398857	-73.9856930632505509
15416	2020-03-12 18:06:50	2020-03-12	Desiree Schinner	desiree.schinner@geemail.com	Dallas	Texas	3112784140264064375	67fc3c2874f0bef5907e353023f9c925	VISA 13 digit	32.8417275508672049	-96.7103877562060887
15417	2020-03-12 18:07:46	2020-03-12	Orilla Jenkins	orilla.jenkins@geemail.com	Santa Rosa	California	561279273617104	20592b1b5ca8c76636a5a362db07c73a	JCB 16 digit	38.4170200587373287	-122.733574734559667
15418	2020-03-12 18:21:40	2020-03-12	Adyson O'Hara	adyson.o'hara@geemail.com	Houston	Texas	180047130792071284	3d392d626cf9617c1e9e56ff3a704779	JCB 16 digit	29.7917898639183498	-95.4025408376488855
15419	2020-03-12 19:38:29	2020-03-12	Opha Marquardt-Feest	opha.marquardt.feest@woohoo.com	Norfolk	Virginia	3755803857976782	c4537ae66dcf5e8e3a834a0ce938977e	VISA 16 digit	36.9245855928882989	-76.2212329237259922
15420	2020-03-12 19:49:02	2020-03-12	Lary Lindgren	lary.lindgren@geemail.com	Las Vegas	Nevada	869967756212601964	0d5d5052606678234aa0b4f0180b6c94	VISA 16 digit	36.2726429985005367	-115.34039881757684
15421	2020-03-12 20:00:26	2020-03-12	Dr. Littleton Runolfsdottir	dr.littleton.runolfsdottir@woohoo.com	Richardson	Texas	4483555031648	f4d80dc1af2e6faefc6ec58a913555c9	American Express	32.9675258457429692	-96.753471433347471
15422	2020-03-12 20:28:28	2020-03-12	Halley Willms	halley.willms@warmmail.com	Dallas	Texas	6011621975946361054	05456d459e30880076ea02e5466b9ad3	Diners Club / Carte Blanche	32.7930729586903027	-96.7889794412963056
15423	2020-03-12 20:31:43	2020-03-12	Estefany Orn	estefany.orn@warmmail.com	Albuquerque	New Mexico	4636940579273045	2bdf7d3e596f77cb6615a1969bfc5639	JCB 16 digit	35.1607142730284536	-106.628035201465337
15424	2020-03-12 20:44:41	2020-03-12	Terra Moen	terra.moen@geemail.com	Tacoma	Washington	3743404452330296	a95ac7eefd52a755b5c3e92cea97df9c	Mastercard	47.2716031152874265	-122.530730837932978
15425	2020-03-12 21:02:11	2020-03-12	Alesia Durgan	alesia.durgan@warmmail.com	Los Angeles	California	4845619907711556	0fa77a677d342de426967cd2061ae5a9	Voyager	34.0865316951978912	-118.329301080712298
15426	2020-03-12 21:05:56	2020-03-12	Roxy Beatty	roxy.beatty@warmmail.com	Phoenix	Arizona	4493324684091489	6bb4ec73e38405955d4bccf79a7dbb00	JCB 16 digit	33.6018245339326569	-112.120358522974328
15427	2020-03-12 21:26:48	2020-03-12	Shania Bechtelar	shania.bechtelar@geemail.com	Independence	Missouri	3158187215725540248	66d888109ed53e80634affefd3ccb0ad	JCB 16 digit	39.1020480236057253	-94.3041377264357976
15428	2020-03-12 21:32:45	2020-03-12	Clovis Erdman DVM	clovis.erdman.dvm@warmmail.com	Washington	District of Columbia	3491931672574346	703687559bd3beb86e618ff0fe1fe16f	VISA 16 digit	38.8970882481694247	-76.9861284293912433
15429	2020-03-12 21:49:48	2020-03-12	Mr. Blair Sanford	mr.blair.sanford@geemail.com	Los Angeles	California	6011219102062272399	d05161c328b65ef3694a5d6fd00d1393	Voyager	33.9719726276915495	-118.455448658763615
15430	2020-03-12 22:03:39	2020-03-12	Dr. Marti Roob MD	dr.marti.roob.md@woohoo.com	Paterson	New Jersey	4018383345057	d939f8598f527df5d08c2afde3a7458d	Discover	40.8565925946414481	-74.2360570973690699
15431	2020-03-12 22:04:21	2020-03-12	Roberta Durgan PhD	roberta.durgan.phd@warmmail.com	Oakland	California	51109818523753692	c3493cd9f25d77c7e956239dcd23727a	VISA 16 digit	37.8064919820260599	-122.320042083131256
15432	2020-03-12 22:21:22	2020-03-12	Dr. Marcus Hermann	dr.marcus.hermann@woohoo.com	Tampa	Florida	6011334565038601943	4b2b293775b72132c32adc225efd8ac9	Voyager	27.9572089191641631	-82.4023801201235386
15433	2020-03-12 22:28:00	2020-03-12	Dr. Mell Franecki	dr.mell.franecki@geemail.com	Pittsburgh	Pennsylvania	6011811299581005136	34751e51bd1e70bad58121adf490307e	JCB 16 digit	40.4453708666332048	-80.0631158363711108
15434	2020-03-12 22:48:09	2020-03-12	Koen McClure PhD	koen.mcclure.phd@geemail.com	San Francisco	California	675954287614918	081a85e59ad21759289565a4908e2f27	Maestro	37.7810481746203592	-122.437518161864475
15435	2020-03-12 22:56:51	2020-03-12	Clement Schmidt	clement.schmidt@geemail.com	Houston	Texas	3430245715606815	b1a9ddaa67214b76a9dbabed3ee01ffa	Voyager	29.7297389636360094	-95.4544444666259011
15436	2020-03-12 23:05:27	2020-03-12	Mickey Windler	mickey.windler@geemail.com	Port St. Lucie	Florida	210086702945504742	ac999cb14478dd874a727940536f7359	JCB 16 digit	27.3679796142637741	-80.4478738820731678
15437	2020-03-12 23:18:16	2020-03-12	Isla Kunde	isla.kunde@geemail.com	Richardson	Texas	4441020172184405	4fea2872aba80f163c898a3915c780af	JCB 15 digit	32.9139467024013399	-96.8005622866325126
15438	2020-03-12 23:18:52	2020-03-12	Allen Cremin	allen.cremin@warmmail.com	Saint Paul	Minnesota	4256107568162634	79c7da38de0aea5760cfb3281d96e02c	Diners Club / Carte Blanche	45.0353569146186103	-93.0058827210482235
15439	2020-03-12 23:48:07	2020-03-12	Darby Greenholt	darby.greenholt@geemail.com	San Francisco	California	3790141924130928	e91764c5a7d26ed11f629697a739e3c3	Diners Club / Carte Blanche	37.8054065542168303	-122.451954946219701
15440	2020-03-12 23:53:45	2020-03-12	Shanelle Brakus	shanelle.brakus@geemail.com	San Francisco	California	561207339113594	23529633eca324899ea28ca7ac22c4b5	Mastercard	37.7377067783587776	-122.435873506359968
15441	2020-03-13 01:26:01	2020-03-13	Samir Runolfsson	samir.runolfsson@geemail.com	New York	New York	210074501101342713	cb12a0cdd550e98b1596b17395f0e600	Voyager	40.7118393127564318	-73.9601078294113279
15442	2020-03-13 01:39:41	2020-03-13	Santos Lockman	santos.lockman@woohoo.com	Scottsdale	Arizona	3035133561082508	a7142a824b8136194745301733f5ec01	JCB 16 digit	33.6284746203694525	-111.914992393829294
15443	2020-03-13 01:45:27	2020-03-13	Dr. Cassie Grady PhD	dr.cassie.grady.phd@geemail.com	Charlotte	North Carolina	3096658280130011144	87b22a146fe3fdc2384f433f74469b15	JCB 15 digit	35.2300815279383173	-80.8702852587159811
15444	2020-03-13 01:54:45	2020-03-13	Jayson Mante	jayson.mante@geemail.com	New York	New York	3112464912668614246	5f832d7a16e472ce34e416f95188e4cd	VISA 16 digit	40.6924827068801989	-73.9102038189198822
15445	2020-03-13 02:21:17	2020-03-13	Gasper Strosin DVM	gasper.strosin.dvm@geemail.com	Beaumont	Texas	6011943515493408220	5c892dafd4e82208f956c5eeeeca13f8	VISA 13 digit	30.0831106970157478	-94.075875912585488
15446	2020-03-13 02:28:48	2020-03-13	Odie Dibbert-Jenkins	odie.dibbert.jenkins@warmmail.com	San Francisco	California	639088839184046	a707964db708d3951afe66e46c9799dd	JCB 16 digit	37.782739643588144	-122.443665028761984
15447	2020-03-13 02:54:31	2020-03-13	Duane Bode	duane.bode@geemail.com	Tacoma	Washington	3050588438128583	b305b2a366cda9d08af9997ada5f363b	JCB 16 digit	47.3452353665724388	-122.455094570410623
15448	2020-03-13 02:57:16	2020-03-13	Hershel Beahan	hershel.beahan@geemail.com	Dallas	Texas	3337946093557665389	60b1b7a58eeaf1e93db33b0a383d7297	VISA 13 digit	32.7733456907134553	-96.7505669238008466
15449	2020-03-13 03:00:25	2020-03-13	Ewin Miller	ewin.miller@geemail.com	San Francisco	California	060471672842664	1ca501284b7d28a729cbb5ffc923d23f	JCB 16 digit	37.7664025414303453	-122.428412902467713
15450	2020-03-13 03:01:13	2020-03-13	Merton Hansen	merton.hansen@geemail.com	San Francisco	California	3337114952478261733	3278f764db0b1ffea69099ca2f86a181	VISA 16 digit	37.7895045281966517	-122.49278409342574
15451	2020-03-13 03:14:51	2020-03-13	Ms. Cathryn Windler	ms.cathryn.windler@geemail.com	Portland	Oregon	54049677019321775	fec6f0a9868e473e122e2f052b058710	VISA 16 digit	45.4498535040654232	-122.636439265636739
15452	2020-03-13 03:20:57	2020-03-13	Tasia Pagac	tasia.pagac@geemail.com	Plano	Texas	180094229513495350	e740ad86f80f1a7e990c3abeac95e750	Diners Club / Carte Blanche	33.0045849407643104	-96.7774296445488886
15453	2020-03-13 03:28:51	2020-03-13	Patty McCullough	patty.mccullough@geemail.com	Sioux Falls	South Dakota	4524241039287146	b39f661ca5459c607fe949174463735d	Voyager	43.5576658409640203	-96.78464535560272
15454	2020-03-13 03:41:30	2020-03-13	Windell Lind	windell.lind@woohoo.com	Washington	District of Columbia	3337578189907334901	2afa5ad8f0e63caee9b40e394d84a9bb	VISA 16 digit	38.8158203230503958	-77.0581572506789172
15455	2020-03-13 03:51:18	2020-03-13	Dr. Exie Considine MD	dr.exie.considine.md@woohoo.com	Phoenix	Arizona	6011645324702181798	bd039d0388af20d5e867f2b9495e0037	VISA 13 digit	33.504576597495749	-112.121404043205459
15456	2020-03-13 04:16:49	2020-03-13	Annetta Blick	annetta.blick@geemail.com	San Francisco	California	4976842887953	e13aaf20294358d12d4c9020dd0ebabf	VISA 16 digit	37.8093563063192164	-122.446358379353597
15457	2020-03-13 04:49:58	2020-03-13	Akeelah Hilll	akeelah.hilll@geemail.com	Seattle	Washington	4092851342355422	30ffa4500f167b7d111c92ec521fb937	Maestro	47.6461628768984227	-122.298273796207823
15458	2020-03-13 04:51:58	2020-03-13	Lawton Adams	lawton.adams@warmmail.com	Gainesville	Florida	3038305121490077	287b8646223a4adadbb7f41cd2980d92	Voyager	29.7558097872707989	-82.2984245267570032
15459	2020-03-13 04:52:21	2020-03-13	Link Bayer DDS	link.bayer.dds@geemail.com	St. Louis	Missouri	869976680385120157	d1e315a9526de089c7ca7d9aa4a8de55	Maestro	38.6420000882975785	-90.2741484763570128
15460	2020-03-13 04:52:52	2020-03-13	Lizette O'Connell	lizette.o'connell@warmmail.com	Cape Coral	Florida	3088564950198402970	fd9890425a32fa7e47c388d9fc9312ad	Diners Club / Carte Blanche	26.7223183878201986	-81.9886412384524874
15461	2020-03-13 04:55:12	2020-03-13	Bernice Grady	bernice.grady@geemail.com	Louisville	Kentucky	4913606957234842	a678c35ee6878ddb7a93489babe72371	Mastercard	38.0699622274279577	-85.6837471529446617
15462	2020-03-13 04:56:44	2020-03-13	Mrs. Clare Becker	mrs.clare.becker@geemail.com	San Antonio	Texas	4493697487555390	020119d129b4e7c7697172940bbe3029	JCB 15 digit	29.4474997514463972	-98.4338819455657159
15463	2020-03-13 04:58:33	2020-03-13	Burl Gusikowski I	burl.gusikowski.i@warmmail.com	San Diego	California	51821245700410879	bc4bf7c743ab0562a813ed2674c8ce21	Mastercard	32.7958049760732777	-117.155394821278762
15464	2020-03-13 05:15:27	2020-03-13	Aracely Reynolds	aracely.reynolds@geemail.com	Stockton	California	869947375746526707	dbe021d22f8ff0cd13b7ebf24f2c5d47	Mastercard	38.0721575317636152	-121.317402135403086
15465	2020-03-13 05:22:13	2020-03-13	Ms. Fumiko Heaney	ms.fumiko.heaney@woohoo.com	Oakland	California	3158224361405093044	39ccc8035478a2843fb85faa8642ecd8	VISA 13 digit	37.8051017834080127	-122.279369303943184
15466	2020-03-13 05:25:28	2020-03-13	Dennie Smith-Stokes	dennie.smith.stokes@geemail.com	New York	New York	869997520431131557	bf71c3a083905dc387bda29ee5bce486	Diners Club / Carte Blanche	40.6270311837308071	-73.9762740007031709
15467	2020-03-13 05:36:20	2020-03-13	Mr. Gregory Kreiger	mr.gregory.kreiger@geemail.com	Atlanta	Georgia	4899985764874398	bd20f675663f843e37e7e7bf42273560	JCB 16 digit	33.674516349499676	-84.4823169026568621
15468	2020-03-13 05:44:49	2020-03-13	Doc Champlin-McClure	doc.champlin.mcclure@warmmail.com	Salt Lake City	Utah	3474727418120191	413176b479f9f455076965e6db6b539a	JCB 16 digit	40.8514816785376524	-111.93427689656987
15469	2020-03-13 05:47:38	2020-03-13	Kent Murray	kent.murray@warmmail.com	Billings	Montana	3158827707759594725	95baeca50c0a98d453626c06fc8b285f	Maestro	45.8456969594806409	-108.560271482418841
15470	2020-03-13 05:57:13	2020-03-13	Kerri Hermiston	kerri.hermiston@geemail.com	Rockford	Illinois	869968525805517450	6016895b05cf8b71a760ebeb133fe836	JCB 15 digit	42.3168932403914653	-89.117087506205209
15471	2020-03-13 05:58:29	2020-03-13	Miss Melody Waelchi DDS	miss.melody.waelchi.dds@geemail.com	New Orleans	Louisiana	3528376025883630959	fccef375947ab03eb80996b37047a6d6	JCB 16 digit	30.0017169130049659	-89.9002380644232062
15472	2020-03-13 06:13:23	2020-03-13	Brant Ankunding-D'Amore	brant.ankunding.d'amore@geemail.com	Gilbert	Arizona	869979880747529494	7e044a60757ca2fc40f40b4c7aed6871	American Express	33.3744316949389841	-111.666406590598072
15473	2020-03-13 06:20:06	2020-03-13	Alissa Homenick	alissa.homenick@woohoo.com	San Francisco	California	6011946875234870907	df701c87344db21ba6b1abf6fda4d80c	Voyager	37.7772321709083343	-122.410124471407855
15474	2020-03-13 06:27:26	2020-03-13	Miss Trudy Cassin PhD	miss.trudy.cassin.phd@geemail.com	New York	New York	180014410649330193	003df510206ae9fdb98bc573b4c6b15d	Discover	40.7514374069627365	-73.9454128894850555
15475	2020-03-13 06:31:32	2020-03-13	Lester Sporer	lester.sporer@warmmail.com	Berkeley	California	3052504053608401	d674468f0b5749ee4ab6a5e754264117	Mastercard	37.8714352956239466	-122.260817935586985
15476	2020-03-13 06:31:37	2020-03-13	Demario Larson	demario.larson@woohoo.com	Philadelphia	Pennsylvania	6011250504841247602	aa144c7eb49a2ef12dc552d94c27d264	Discover	39.9327009884133943	-75.1395076308298968
15477	2020-03-13 06:33:41	2020-03-13	Miss Megan Bernier	miss.megan.bernier@geemail.com	Los Angeles	California	4807277197657645	aa03e2e8452e9fa2258c63eeb330fb62	Voyager	34.1191012920677608	-118.45824551265612
15478	2020-03-13 06:34:45	2020-03-13	Gaylen Aufderhar PhD	gaylen.aufderhar.phd@geemail.com	Baltimore	Maryland	3158358263719994479	41f873f90c7de1bb670aa1c325fb5e23	VISA 13 digit	39.3568684332538368	-76.5822494509648521
15479	2020-03-13 06:45:10	2020-03-13	Lupe Fay	lupe.fay@geemail.com	Stockton	California	3744067553588408	6cc913670a7f8eb9d6f60ed1e11f65eb	VISA 16 digit	38.0298743518732536	-121.342490491652114
15480	2020-03-13 06:53:42	2020-03-13	Kenny Stoltenberg	kenny.stoltenberg@geemail.com	Colorado Springs	Colorado	502013551588984	eadab8e70d37112902abc1127493aa46	VISA 16 digit	38.8818996706560256	-104.689501447618753
15481	2020-03-13 07:04:13	2020-03-13	Ms. Laurine Corkery DDS	ms.laurine.corkery.dds@geemail.com	Chicago	Illinois	4063119500158714	6280e5294c5699ce28afd3320f2590c8	JCB 15 digit	41.785292504525188	-87.6126436952065575
15482	2020-03-13 07:10:41	2020-03-13	Neola Cummerata	neola.cummerata@geemail.com	Berkeley	California	869916826610548885	49e1c66a47f0d83e86a477ad6bc19553	American Express	37.8662271581716681	-122.248457670965408
15483	2020-03-13 07:21:03	2020-03-13	Mrs. Gloria Torp DDS	mrs.gloria.torp.dds@geemail.com	Nashville	Tennessee	210068516351588409	a379c3677f4c35242a3513fb8504e0e1	JCB 16 digit	36.1278461986809916	-86.7548637451510842
15484	2020-03-13 07:58:24	2020-03-13	Arlie Cummings V	arlie.cummings.v@geemail.com	Woodbridge	New Jersey	4548269379437551	110d00603707dd4d5938059c65c9dff4	JCB 15 digit	40.5183896489597828	-74.3804505639567992
15485	2020-03-13 07:59:02	2020-03-13	Almond Daniel Sr.	almond.daniel.sr.@geemail.com	New York	New York	4117989033241732	d5f11e6633afc718c3aaf7605895a58b	Maestro	40.5931692943666107	-73.9986688339047163
15486	2020-03-13 08:07:59	2020-03-13	Stanton Aufderhar DDS	stanton.aufderhar.dds@woohoo.com	San Francisco	California	3158880839065716728	9a685bf79219da250858ac6492c6f738	American Express	37.7439892740138916	-122.420825308868331
15487	2020-03-13 08:23:13	2020-03-13	Matthew Reichel	matthew.reichel@warmmail.com	Oakland	California	4839397971639064	129135deac0b5a349938eaa7892f31dc	Mastercard	37.7804032521779405	-122.27953689309112
15488	2020-03-13 08:27:55	2020-03-13	Roberta Lockman	roberta.lockman@geemail.com	San Antonio	Texas	4860477157712398	598e9407548a353f5a85bdea70dae99d	Maestro	29.5253300421010714	-98.5657447718851216
15489	2020-03-13 08:38:56	2020-03-13	Reuben Strosin V	reuben.strosin.v@warmmail.com	Sioux Falls	South Dakota	6011711736184989688	1dba4e8bbb6087a7a6c082b1ec3a68a7	VISA 13 digit	43.6019629108339544	-96.8240283654704683
15490	2020-03-13 08:38:59	2020-03-13	Cuba Franecki	cuba.franecki@warmmail.com	Newport News	Virginia	53519823629634626	9e450cc310e4de052fb2fd1b6e7957b4	Mastercard	37.1389339512575418	-76.5275736478883886
15491	2020-03-13 08:46:53	2020-03-13	Deryl Wilderman DVM	deryl.wilderman.dvm@geemail.com	Pasadena	Texas	52622406475355548	cc2210038fbc709274d3ce8802dde34b	Diners Club / Carte Blanche	29.7263591713145381	-95.1709262651804835
15492	2020-03-13 09:07:44	2020-03-13	Lavar Skiles	lavar.skiles@warmmail.com	Tulsa	Oklahoma	3096032441511821678	bb098171de0f7f42eadfa69a018f749b	Voyager	36.1962333759196042	-95.8696627416603206
15493	2020-03-13 09:24:19	2020-03-13	Zandra Wiza	zandra.wiza@geemail.com	Vista	California	210011107875558090	9bcfc79b2f779a3257a4c94ad70c623c	Maestro	33.1020949586275961	-117.255804388231041
15494	2020-03-13 09:31:53	2020-03-13	Kendrick Lesch	kendrick.lesch@woohoo.com	Bakersfield	California	6011877121069165409	c4115daebb8b7256be5ef5f524fc292c	JCB 16 digit	35.2442763833504173	-118.949217072342705
15495	2020-03-13 09:41:10	2020-03-13	Micheal Hauck	micheal.hauck@geemail.com	Houston	Texas	676282953942800	b5b6ecfcf6de2d637a3c2c744743551b	JCB 16 digit	29.7044151794243589	-95.3109138636864799
15496	2020-03-13 10:00:26	2020-03-13	Elwin Gerlach	elwin.gerlach@woohoo.com	Temecula	California	210043054580602122	b7dcbc0390c2c961d20388948495789e	VISA 16 digit	33.5004032203596083	-117.054459290784592
15497	2020-03-13 10:03:45	2020-03-13	Rayne Hickle	rayne.hickle@geemail.com	Cape Coral	Florida	639060596662480	8723bf01fb81eff9a47b253b8e6831a2	JCB 15 digit	26.6347147663559767	-82.039891883365442
15498	2020-03-13 10:06:46	2020-03-13	Shane Lebsack PhD	shane.lebsack.phd@geemail.com	San Jose	California	3096978199720225091	bf3ce98a99ee2613dc80a5da9e665092	VISA 13 digit	37.3775899260126039	-121.815239648822327
15499	2020-03-13 10:55:14	2020-03-13	Dennie Harris	dennie.harris@geemail.com	Colorado Springs	Colorado	4983308935433	1dd335b089375f5d506689f5dcfa00ec	JCB 15 digit	38.9265706705909196	-104.783823239399865
15500	2020-03-13 10:57:12	2020-03-13	Dr. Miguelangel Schuppe I	dr.miguelangel.schuppe.i@warmmail.com	Arlington	Texas	52380528502939812	41bd72f41cd29f04743ae89d35d03257	Diners Club / Carte Blanche	32.781894371497259	-97.1202190658103746
15501	2020-03-13 11:07:31	2020-03-13	Minervia Bednar	minervia.bednar@warmmail.com	New York	New York	4510457883003415	45ad37147f978c5760b8c938c54c0394	JCB 15 digit	40.6256589060872813	-73.9977225984808058
15502	2020-03-13 11:19:27	2020-03-13	Ms. Danika Fahey	ms.danika.fahey@warmmail.com	Reno	Nevada	502045710060166	7357122fdeb61ce9283f59fff9733a0e	VISA 13 digit	39.5973752374373404	-119.896549995213377
15503	2020-03-13 11:37:13	2020-03-13	Dr. Harvy Will DVM	dr.harvy.will.dvm@woohoo.com	Boise	Idaho	4392589970977730	d988beb4d7135964ef56f4dd64471545	JCB 15 digit	43.7000206842225083	-116.231152605191625
15504	2020-03-13 11:38:41	2020-03-13	Burt Wiegand	burt.wiegand@geemail.com	New York	New York	3528890410227387267	b28f62e848d99c3272b1a7e847492bf9	Mastercard	40.6205555003359891	-73.9084840716224107
15505	2020-03-13 11:44:33	2020-03-13	Regis Willms-Wiza	regis.willms.wiza@geemail.com	San Francisco	California	3041028689356194	41b743325902616972c3a23815db0cb5	VISA 13 digit	37.7628600760520996	-122.371994777524108
15506	2020-03-13 11:51:50	2020-03-13	Lanette Hartmann	lanette.hartmann@geemail.com	Albuquerque	New Mexico	53440268546095960	ae53d128a9f3d0f7fb922c9757462d3d	Voyager	35.0119228847458999	-106.583226743021612
15507	2020-03-13 11:57:30	2020-03-13	Trystan Gislason DVM	trystan.gislason.dvm@geemail.com	San Jose	California	180005615940634637	899b6bf6b29c6690ecbedcc0afd1c84e	American Express	37.257975671189655	-121.885457499719777
15508	2020-03-13 11:58:15	2020-03-13	Samie Hills II	samie.hills.ii@geemail.com	Virginia Beach	Virginia	4952826940079078	f32eaa49f31394c3c19ed29314e02ea5	Voyager	36.6944052705727515	-75.9683050882209017
15509	2020-03-13 12:00:48	2020-03-13	Cathleen McKenzie DVM	cathleen.mckenzie.dvm@woohoo.com	Denton	Texas	869989153462811671	6a2958a5a274fd3b3fe6fdc034531e9b	JCB 15 digit	33.1824504148013872	-97.1281476965300783
15510	2020-03-13 12:10:05	2020-03-13	Atticus Harris-McKenzie	atticus.harris.mckenzie@warmmail.com	Houston	Texas	639004468581386	7adb54b6e84583566a221cda753d9fdb	Discover	29.7210983692280948	-95.2928868243485709
15511	2020-03-13 12:33:35	2020-03-13	Dejon Rippin	dejon.rippin@geemail.com	Huntsville	Alabama	4000235672946	7e0856a0cf78d166ec3ba74302226225	VISA 16 digit	34.632519991533826	-86.6666914399266233
15512	2020-03-13 12:36:49	2020-03-13	Ms. Jailyn Becker PhD	ms.jailyn.becker.phd@geemail.com	Peoria	Illinois	4006451992389	98999afe53e08f7345d0a833bb446324	JCB 16 digit	40.8258856572080404	-89.6932097341284162
15513	2020-03-13 12:47:55	2020-03-13	Sebastian Parker	sebastian.parker@geemail.com	Los Angeles	California	180035799198497022	0c03a681325775254a4ae4a12d450df7	VISA 16 digit	34.0982430790416871	-118.313631573598087
15514	2020-03-13 12:48:16	2020-03-13	Joeseph Gulgowski	joeseph.gulgowski@warmmail.com	Salt Lake City	Utah	501864539513529	352d9bfa5d36e9d289ebcc2fb5e59fdd	Discover	40.8602725399337672	-111.961297139892352
15515	2020-03-13 13:03:32	2020-03-13	Nallely Kohler	nallely.kohler@geemail.com	San Francisco	California	4503262679320	32c8bd8cfb5ac76eed439b5fe5cbdced	VISA 16 digit	37.784780675408939	-122.418497465634104
15516	2020-03-13 13:24:35	2020-03-13	Joette Glover	joette.glover@geemail.com	Oklahoma City	Oklahoma	6011027163949021344	7c0f7960c93c263cf4ae4ee536bfa8c3	JCB 16 digit	35.3919241938184967	-97.4906741745665641
15517	2020-03-13 13:34:29	2020-03-13	Ms. Anissa Jacobi PhD	ms.anissa.jacobi.phd@geemail.com	Montgomery	Alabama	3706736009444566	d682c12aa7f9458b69384e36e2600077	JCB 16 digit	32.3463097043734038	-86.2733151343338136
15518	2020-03-13 13:34:59	2020-03-13	Glover Swaniawski	glover.swaniawski@geemail.com	San Francisco	California	180023144778646470	63eb4613cb5512760e0afc19392cedea	Discover	37.7722360578749345	-122.414319318587502
15519	2020-03-13 13:54:28	2020-03-13	Arra Torp	arra.torp@geemail.com	Garden Grove	California	869921674212334590	6a4e3b7164a234d524b03bd471d6b65b	JCB 15 digit	33.7792532900173157	-118.021295459756629
15520	2020-03-13 13:59:38	2020-03-13	Ms. May Yundt	ms.may.yundt@geemail.com	Denver	Colorado	869918628631483086	31b9e84a8f4ae2e761eb107abd45f044	Diners Club / Carte Blanche	39.7859042740013393	-104.791462116247416
15521	2020-03-13 14:24:49	2020-03-13	Mr. Kenya Breitenberg II	mr.kenya.breitenberg.ii@woohoo.com	Allen	Texas	3757938244570365	119a51174232456cc173fec994b209a6	VISA 16 digit	33.0176763648193301	-96.7195819202292739
15522	2020-03-13 14:37:27	2020-03-13	Nikolai Gorczany	nikolai.gorczany@geemail.com	Berkeley	California	3158534848894078200	1bdd496b993e6e86f3a0830d6fd65b0f	JCB 16 digit	37.8583312588333598	-122.292177803540753
15523	2020-03-13 14:44:21	2020-03-13	Kordell Barrows Jr.	kordell.barrows.jr.@geemail.com	Simi Valley	California	676181637851486	20457f61c88ed58b8c109c97506a422d	JCB 15 digit	34.3185711852513222	-118.806849902881311
15524	2020-03-13 15:02:10	2020-03-13	Bailey Botsford	bailey.botsford@geemail.com	Mobile	Alabama	51037987028200421	d1084d9fac37a327a7adb05216aca3a8	American Express	30.6834234875734886	-88.0207535911023626
15525	2020-03-13 15:18:07	2020-03-13	Dr. Andria Hintz	dr.andria.hintz@geemail.com	Phoenix	Arizona	3462758472299666	24885fe9927752ac00d0c6a29079ed25	JCB 15 digit	33.623845326148718	-112.066238760522012
15526	2020-03-13 15:20:24	2020-03-13	Mr. Trae Schneider PhD	mr.trae.schneider.phd@warmmail.com	Salem	Oregon	4629819701696811	e5f3c4d8ed67b39d484fc9c702234825	JCB 15 digit	44.8789547663450179	-122.971766143726938
15527	2020-03-13 15:56:38	2020-03-13	Shelbie Moore DDS	shelbie.moore.dds@geemail.com	San Francisco	California	3466200893412640	f237a4252deada49a7a3449ed1fd0716	VISA 16 digit	37.787130092226981	-122.405975405355008
15528	2020-03-13 16:04:43	2020-03-13	Vester Becker	vester.becker@geemail.com	San Francisco	California	3112865981748711798	4b3653d4e97cda6d1fd70b373f0bed5c	VISA 16 digit	37.7908221189723577	-122.449189765276614
15529	2020-03-13 16:21:04	2020-03-13	Lukas Orn	lukas.orn@woohoo.com	Jacksonville	Florida	210004457811837648	253ecc58124d6941a51344f9f27dbc65	VISA 13 digit	30.3746864884212613	-81.6856662467666013
15530	2020-03-13 16:36:20	2020-03-13	Dominga Watsica-Daugherty	dominga.watsica.daugherty@geemail.com	Houston	Texas	180051300168843243	4c7f0d2942a4f539e9726b5015388cb8	Maestro	29.7877985688470304	-95.4395722431611233
15531	2020-03-13 17:05:14	2020-03-13	Darnell Bartoletti III	darnell.bartoletti.iii@geemail.com	Austin	Texas	4560290768064619	5926fd7e4e8df22fa867f8dca3482eaa	American Express	30.3949419757477912	-97.7930199291795503
15532	2020-03-13 17:18:49	2020-03-13	Marlie Ruecker	marlie.ruecker@geemail.com	Hialeah	Florida	53269145055082613	9076616467708ff290bdae92c6f82db5	VISA 16 digit	25.9143067751057465	-80.3239260320454775
15533	2020-03-13 17:25:01	2020-03-13	Arnav Smitham	arnav.smitham@geemail.com	Minneapolis	Minnesota	6011279338920400502	6255cdf968e60ca30255c20771e1ffae	VISA 16 digit	45.0003369288139012	-93.2976198096100262
15534	2020-03-13 17:35:56	2020-03-13	Karli Schultz	karli.schultz@geemail.com	Irvine	California	180095868510832260	561af6d383c6f542c0a411ed9c50e54c	JCB 15 digit	33.6566815376762349	-117.770767151425773
15535	2020-03-13 17:51:37	2020-03-13	Anton Lueilwitz	anton.lueilwitz@geemail.com	Oakland	California	3096565641165987395	bf724b801543e4e78c39b7e66c8854f3	JCB 16 digit	37.7924653744576844	-122.26239483495246
15536	2020-03-13 18:03:58	2020-03-13	Jobe Schuppe	jobe.schuppe@geemail.com	New York	New York	3056489133700376	ed047e0db615f485581bdf032538ec7b	American Express	40.6797691493518627	-73.9095599205128764
15537	2020-03-13 18:29:01	2020-03-13	Miss Unique Reynolds DDS	miss.unique.reynolds.dds@geemail.com	San Francisco	California	3528295304999170772	cc5667042d13bdceb3c89c4c7f16a50e	JCB 15 digit	37.7794947091995397	-122.428370412295905
15538	2020-03-13 18:30:31	2020-03-13	Kenji Metz	kenji.metz@warmmail.com	Kansas City	Missouri	3088758468226658006	3742cf7d9d981191791ca0c8fd8dfc06	VISA 16 digit	39.1825328765273113	-94.57912898736447
15539	2020-03-13 19:10:49	2020-03-13	Lum Feest	lum.feest@geemail.com	San Diego	California	630484863401778	295d82adbf6b0b93fbc3f1e7a07a910c	Maestro	32.7803454598479007	-117.110581251224502
15540	2020-03-13 19:13:22	2020-03-13	Ryleigh Lehner-Goyette	ryleigh.lehner.goyette@geemail.com	Saint Paul	Minnesota	4064659933379121	30c35415c851d29cec53b633fd6764bc	Discover	45.008706731948628	-93.06203537017889
15541	2020-03-13 19:13:29	2020-03-13	Isreal Fay	isreal.fay@warmmail.com	Omaha	Nebraska	3421355590869999	fbc95fff9caf44e34ebddea4df93c080	JCB 15 digit	41.3364063752029125	-96.1393215456161698
15542	2020-03-13 19:17:03	2020-03-13	Hadassah Jast	hadassah.jast@warmmail.com	San Francisco	California	3052060828895260	98fa09dedcefbf251bc16f39abb35b67	Maestro	37.7499077242033678	-122.472617303404931
15543	2020-03-13 19:24:17	2020-03-13	Mrs. Aniyah Lubowitz DVM	mrs.aniyah.lubowitz.dvm@geemail.com	New York	New York	54090333683605725	c4242480936bf32139ba32ca42b4a5b3	Maestro	40.735754262072966	-74.0125960782997225
15544	2020-03-13 19:28:53	2020-03-13	Ms. Shayla Gulgowski	ms.shayla.gulgowski@geemail.com	Fullerton	California	54838566520730258	5cdd7763478e93f35490c764d89490a0	Voyager	33.9526850952923311	-117.883049857497213
15545	2020-03-13 19:32:44	2020-03-13	Gertie Bins	gertie.bins@woohoo.com	San Francisco	California	3096669735444040557	05673dd84f2d0953212fd756d1694de0	Diners Club / Carte Blanche	37.7624215031765331	-122.408836585294594
15546	2020-03-13 19:37:36	2020-03-13	Trace Witting PhD	trace.witting.phd@woohoo.com	Provo	Utah	3735942475448108	79ffb4a1c1c61f92a52406b44e67af95	JCB 16 digit	40.1668029816143246	-111.699810116705677
15547	2020-03-13 19:39:50	2020-03-13	Mr. Lawton Goldner	mr.lawton.goldner@warmmail.com	Oakland	California	3482430385026182	1fd93d938b4593896fb69de01b3735a5	American Express	37.7719995491425493	-122.250587137633218
15548	2020-03-13 19:55:30	2020-03-13	Mat Leannon	mat.leannon@woohoo.com	Simi Valley	California	3059571330899452	e422daf7419c8255ce87fc49d9bb3f93	JCB 16 digit	34.3601067894376797	-118.840921706439929
15549	2020-03-13 19:59:09	2020-03-13	Brendan Ryan-Gorczany	brendan.ryan.gorczany@woohoo.com	Detroit	Michigan	3528073135468144312	241e33dc5b556da5c33a42ea27ad5b12	JCB 16 digit	42.4362368390820919	-83.1412331937465723
15550	2020-03-13 20:19:29	2020-03-13	Lucian Deckow	lucian.deckow@geemail.com	San Francisco	California	3158576517653827052	5a0f17da2231a7f5b9b746d80abdb762	Mastercard	37.7556950148608621	-122.410640852960455
15551	2020-03-13 20:21:00	2020-03-13	Luann Maggio	luann.maggio@geemail.com	Davenport	Iowa	869990066612852410	d49e7e5ee9f73702d435e4079d3bacca	JCB 15 digit	41.5983853751126631	-90.5529428362343509
15552	2020-03-13 20:23:45	2020-03-13	Ira Jacobson	ira.jacobson@woohoo.com	San Francisco	California	210016864569641427	4a8a79d70fe1029c19c2f21789beb686	JCB 15 digit	37.7395716963334991	-122.418335069781747
15553	2020-03-13 20:28:28	2020-03-13	Maud Lakin DDS	maud.lakin.dds@woohoo.com	Peoria	Arizona	3096484486069387872	29b5882e05d91e296682f9db29acb080	VISA 16 digit	33.8686891292024441	-112.389435833638544
15554	2020-03-13 20:32:36	2020-03-13	Zavion Franecki	zavion.franecki@geemail.com	Los Angeles	California	501873383561492	f84be42db524b8a1f678f4c0a0a4620e	JCB 16 digit	34.0472097614180242	-118.40695247971378
15555	2020-03-13 20:38:10	2020-03-13	Latasha Robel PhD	latasha.robel.phd@geemail.com	San Francisco	California	52755518437479031	d97c51c9c6aff9c215262453e0d1a3bc	Diners Club / Carte Blanche	37.7820218294915833	-122.416807535715762
15556	2020-03-13 20:54:08	2020-03-13	Celeste Schaden	celeste.schaden@geemail.com	Columbus	Ohio	4892764203363348	cceafea97abd34f0116cd243c3808959	Mastercard	39.9874465511225168	-82.9072385769106575
15557	2020-03-13 21:00:58	2020-03-13	Socorro Beatty MD	socorro.beatty.md@geemail.com	Charlotte	North Carolina	3528797741752138657	ebfc91db01a2e0a32215accd1d0689b8	Diners Club / Carte Blanche	35.2267300152473126	-80.7896218276992499
15558	2020-03-13 21:13:01	2020-03-13	Rachelle Block	rachelle.block@geemail.com	Elk Grove	California	54531619501293141	f213e7cd21ef058c923622f3d528fd67	Maestro	38.3483500521913143	-121.372691737525173
15559	2020-03-13 21:16:59	2020-03-13	Ezequiel Runolfsdottir Jr.	ezequiel.runolfsdottir.jr.@geemail.com	Plano	Texas	503823003899848	78dfdd45fc89ffc21cd3b4f3d06195c7	Diners Club / Carte Blanche	32.9850386294156337	-96.755861830263953
15560	2020-03-13 21:22:10	2020-03-13	Lindsay Schuster-Towne	lindsay.schuster.towne@woohoo.com	Albuquerque	New Mexico	4133344764088	0e196a2381c02929e8adc071914c005f	VISA 16 digit	35.0551897225569959	-106.725786175492786
15561	2020-03-13 21:25:25	2020-03-13	Oral Trantow	oral.trantow@woohoo.com	Waco	Texas	4680402153714154	e2329e3202df7aa46637d321516706f6	Mastercard	31.4912483315192162	-97.1195616787895659
15562	2020-03-13 21:59:00	2020-03-13	Ammon Ankunding	ammon.ankunding@warmmail.com	Chattanooga	Tennessee	3528516214379677150	3753db1a8db9473088ce3c46d166d615	Diners Club / Carte Blanche	35.0839253152571615	-85.2072890138082215
15563	2020-03-13 22:03:35	2020-03-13	Mr. Kirt Cummings PhD	mr.kirt.cummings.phd@geemail.com	Los Angeles	California	3411288371702703	166a4817848d231de786784e7745dd86	Maestro	34.0188583987630864	-118.398253380273644
15564	2020-03-13 22:05:44	2020-03-13	Elvera Hane	elvera.hane@woohoo.com	Los Angeles	California	869967296818157608	d510edd79e1f5dda619e3c8e74a2a0e7	American Express	34.0642586133308711	-118.393350388528035
15565	2020-03-13 22:16:12	2020-03-13	Gail Kemmer	gail.kemmer@warmmail.com	San Francisco	California	4096754697323886	cd29f888b3a49cb0c5655e875fb6f280	JCB 16 digit	37.7606418067187377	-122.417822194787092
15566	2020-03-13 22:28:40	2020-03-13	Alisha Breitenberg DVM	alisha.breitenberg.dvm@woohoo.com	Berkeley	California	630461429658141	ab51a8524949c16a59785ba28c3f19b8	JCB 15 digit	37.8704662381340285	-122.270066324848841
15567	2020-03-13 22:38:59	2020-03-13	Mr. Tyrese Kutch PhD	mr.tyrese.kutch.phd@warmmail.com	Arlington	Texas	3006700303339203	4d57654428919231856b91c8c191a150	VISA 16 digit	32.7577218811277291	-97.1958486862506703
15568	2020-03-13 22:47:56	2020-03-13	Dozier Walsh I	dozier.walsh.i@geemail.com	El Paso	Texas	3528128424783808099	0903a8fb6fd9b8f1679a5e8958fa50af	JCB 15 digit	31.8433974612798565	-106.327065726181502
15569	2020-03-13 22:50:37	2020-03-13	Tamia Adams	tamia.adams@geemail.com	Houston	Texas	3096198879634032824	e5a7c4a93952088d4c062765dc8d9ef6	Mastercard	29.7450824091754846	-95.3170391742154948
15570	2020-03-13 23:07:42	2020-03-13	Janene Oberbrunner	janene.oberbrunner@geemail.com	Berkeley	California	210036636486132219	1252f54ade0bd6cbaedd5fc53fa63f38	American Express	37.8883798226523609	-122.264884001021173
15571	2020-03-13 23:09:27	2020-03-13	Tobe Bartell	tobe.bartell@geemail.com	Winston–Salem	North Carolina	060461156654065	2f1eb3a4a8707952c2e0cf14f4d289f7	VISA 13 digit	36.0769991662584246	-80.1648580019958246
15572	2020-03-13 23:16:18	2020-03-13	Jefferson Nikolaus-Rogahn	jefferson.nikolaus.rogahn@geemail.com	Berkeley	California	180051958490103683	ef0a73dd26382b50d9e78a0e7a0c37c8	Mastercard	37.8920622758798871	-122.289522522581279
15573	2020-03-13 23:35:11	2020-03-13	Echo Sawayn DVM	echo.sawayn.dvm@woohoo.com	Seattle	Washington	210083381670307234	c6bd1fee9fa5bf1d4741652e8d84048c	JCB 16 digit	47.7162971550524233	-122.406662871494518
15574	2020-03-13 23:40:53	2020-03-13	Deonta Kiehn V	deonta.kiehn.v@warmmail.com	Los Angeles	California	3088575621404651695	9d0aa95839e2469b09c9d3e73b4ea70c	Voyager	34.0868074055626948	-118.454521517687652
15575	2020-03-13 23:49:03	2020-03-13	Bliss Crona	bliss.crona@geemail.com	Chicago	Illinois	3528238950182286161	3e1e9b40d1109e0e2177ec2879a4649d	Maestro	41.9116974650718319	-87.7780661003693865
15576	2020-03-13 23:57:48	2020-03-13	Cydney Pouros	cydney.pouros@warmmail.com	Davie	Florida	4531215877228298	5c910de3107d4fe2d80497df8e231cca	JCB 16 digit	26.0981572964027535	-80.3316022778768115
15577	2020-03-14 00:11:08	2020-03-14	Desirae Reynolds	desirae.reynolds@geemail.com	Chicago	Illinois	210026153676013797	6f43b3084e8e0e96f672c11c8e0624e2	American Express	41.8818256851587449	-87.5894320448890227
15578	2020-03-14 00:13:46	2020-03-14	Dr. Araceli Schmidt	dr.araceli.schmidt@warmmail.com	Portland	Oregon	3056701176948492	a5f3d79b06a591a558ac4a3e8a7c7f35	Mastercard	45.5166216324903061	-122.614450299600151
15579	2020-03-14 00:29:15	2020-03-14	Donat Donnelly	donat.donnelly@geemail.com	Pueblo	Colorado	3474755982239022	f07f08083221c446b0e4f254994b026e	American Express	38.35725872246325	-104.593353193612032
15580	2020-03-14 00:29:54	2020-03-14	Dr. Rylee Schinner	dr.rylee.schinner@geemail.com	Fontana	California	869957156466338219	9e3af3a7e95cbd874985510368e43b53	Diners Club / Carte Blanche	34.1933236393295275	-117.52860501215757
15581	2020-03-14 00:31:39	2020-03-14	Taina Emmerich-Windler	taina.emmerich.windler@geemail.com	San Francisco	California	3528835202992716616	ed6282d0c2387b34fcffabf473ad3078	VISA 16 digit	37.7570648630647199	-122.429339727681082
15582	2020-03-14 00:42:41	2020-03-14	Mr. Eliezer Botsford DDS	mr.eliezer.botsford.dds@geemail.com	San Francisco	California	51376211509371679	bad77394bf3ee6e4759855c8f051eb6f	VISA 16 digit	37.7314915438217469	-122.444430361574831
15583	2020-03-14 00:47:26	2020-03-14	Charlie Lueilwitz	charlie.lueilwitz@geemail.com	Oakland	California	4296320451710995	8f356883b697023c2b83b21a2c8af954	JCB 16 digit	37.8322819653264233	-122.249094031552289
15584	2020-03-14 01:06:05	2020-03-14	Moises Windler	moises.windler@geemail.com	New Haven	Connecticut	4993179774092	6764c64551c3ec17f5323c6e17e7abdf	Discover	41.4061477332834187	-72.8515690865926473
15585	2020-03-14 01:07:59	2020-03-14	Mr. Orion Corkery III	mr.orion.corkery.iii@geemail.com	Scottsdale	Arizona	4667368798953480	ef28d59bb781438e51cb24f4ed8fb9c7	VISA 16 digit	33.6336767356034372	-111.787374873036882
15586	2020-03-14 01:12:07	2020-03-14	Walker Howell	walker.howell@geemail.com	Raleigh	North Carolina	869909453749460715	fb3694e5815bc16a9269e54e75941d51	Diners Club / Carte Blanche	35.865623015225303	-78.6751695149980463
15587	2020-03-14 01:32:17	2020-03-14	Denisha Hoppe	denisha.hoppe@warmmail.com	Clarksville	Tennessee	4348598059239	6d09a77af0b493c58b3c96643c3878cc	Maestro	36.5372379950840056	-87.2643329604014752
15588	2020-03-14 01:40:16	2020-03-14	Elvina Nicolas DVM	elvina.nicolas.dvm@geemail.com	New York	New York	869911174313459562	8aeb8b077aa1f3e87fc1dff128bf5445	JCB 16 digit	40.7298085677195303	-74.0150577749021323
15589	2020-03-14 01:48:40	2020-03-14	Curt Ledner-Flatley	curt.ledner.flatley@geemail.com	San Antonio	Texas	4089169772412679	512b918f2b27e85cd03907c51c986073	American Express	29.4468611221365641	-98.5738873978447145
15590	2020-03-14 01:52:52	2020-03-14	Kunta Littel	kunta.littel@geemail.com	Berkeley	California	3088925607214224259	4c6dc9484a5b2aec1e4df4e354d013c0	Maestro	37.9161087435591568	-122.288918223760362
15591	2020-03-14 01:53:03	2020-03-14	Gidget Rutherford	gidget.rutherford@geemail.com	Torrance	California	4219206944890	4c6ff697f1e80b32c2f14f1243f2c97f	VISA 16 digit	33.8622515300195701	-118.290253493900963
15592	2020-03-14 01:56:22	2020-03-14	Evander Rippin	evander.rippin@geemail.com	San Francisco	California	630422762107401	19d07cc238d73e1159872fcc42bf32c7	VISA 16 digit	37.765501318778341	-122.421856432432449
15593	2020-03-14 02:01:37	2020-03-14	Beverly Goodwin-Rice	beverly.goodwin.rice@geemail.com	New York	New York	6011715007081161946	a8e0104c871e3f30f218b415e0c84602	JCB 16 digit	40.6544090027678777	-73.983747468412659
15594	2020-03-14 02:02:10	2020-03-14	Karan Yost-Reynolds	karan.yost.reynolds@geemail.com	Oakland	California	180091878407581213	0e775b4ac5d6c9b37c3d43d783d57baa	Discover	37.7624018418647793	-122.245423328642261
15595	2020-03-14 02:06:26	2020-03-14	Ms. Isis Lakin	ms.isis.lakin@geemail.com	Boston	Massachusetts	4744415697608025	60e896fd52265f49b9e8ff81d063400e	American Express	42.4294062148947262	-71.0355326804284033
15596	2020-03-14 02:16:46	2020-03-14	Gavyn Gislason	gavyn.gislason@geemail.com	Winston–Salem	North Carolina	3088774412879623263	9202019251dfa9167e5b5caf6319d89f	JCB 16 digit	36.1010303187880623	-80.1620075224563493
15597	2020-03-14 02:41:54	2020-03-14	Mr. Adron Deckow V	mr.adron.deckow.v@geemail.com	Indianapolis	Indiana	4269162176054694	0c083ebf77f83606af28f3d240a0e5dd	JCB 16 digit	39.8764408065944878	-86.0575993753705148
15598	2020-03-14 02:47:02	2020-03-14	Ms. Elena Lesch	ms.elena.lesch@warmmail.com	New York	New York	55956114755836817	ef15438ecce4ece0ff1e48138287ab0e	Mastercard	40.7520268400888881	-73.8460869463522016
15599	2020-03-14 02:51:53	2020-03-14	Edmund Fahey	edmund.fahey@woohoo.com	Oakland	California	4529227684753578	e564825b2a8e5d3827ae001462d92d28	VISA 13 digit	37.7981231144581571	-122.262122242330335
15600	2020-03-14 02:53:49	2020-03-14	Estell Gutmann	estell.gutmann@geemail.com	Irving	Texas	4938495990698648	e1f0f7fecb0e00442f4d854a76567189	Diners Club / Carte Blanche	32.9454727150917037	-97.0455092873703649
15601	2020-03-14 03:05:06	2020-03-14	Eben Kris	eben.kris@geemail.com	San Francisco	California	3088391490084698471	fd33a30b5f906201632e25fdc06282f5	JCB 15 digit	37.7932843276233257	-122.476051482137748
15602	2020-03-14 03:09:15	2020-03-14	Roberta Sporer	roberta.sporer@geemail.com	Orange	California	4827767288408037	ccb2130fad75564de55bf1217eaca18f	Diners Club / Carte Blanche	33.8762228063195963	-117.799048100329188
15603	2020-03-14 03:14:50	2020-03-14	Miss Lila Muller DVM	miss.lila.muller.dvm@geemail.com	San Diego	California	4430882988781002	83be4d0b4568293b118f47e714c9a610	JCB 16 digit	32.8994268601827358	-117.171351068643858
15604	2020-03-14 03:18:19	2020-03-14	Bode Hermann II	bode.hermann.ii@geemail.com	Los Angeles	California	4793013256474200	ee26132f4f6d93c3a952fe69334388ba	JCB 16 digit	34.0469984251406004	-118.44304483230151
15605	2020-03-14 03:21:28	2020-03-14	Kamora Mann DVM	kamora.mann.dvm@geemail.com	Columbus	Ohio	869909506925302207	989923e49fb18fceaeeefe2ceeb49268	Voyager	39.9328485983934272	-83.0655258129585548
15606	2020-03-14 03:24:39	2020-03-14	Priscila Nader	priscila.nader@geemail.com	Portland	Oregon	6011258762348158944	fa711836095c017fb41f18c223f31bf5	Diners Club / Carte Blanche	45.5738344473186885	-122.681532173510647
15607	2020-03-14 03:32:04	2020-03-14	Merlene Waters	merlene.waters@geemail.com	Waco	Texas	3337186138337665826	1efa1b7fbc093e79e6a73e64ee90a564	VISA 16 digit	31.6143223330587126	-97.1192599057816039
15608	2020-03-14 04:02:02	2020-03-14	Kya Cremin	kya.cremin@geemail.com	Palm Bay	Florida	4153135716871149	a9f15bcb49c530f4cdfcfe5b80558750	Discover	27.9883082038112008	-80.5758214220240632
15609	2020-03-14 04:03:39	2020-03-14	Roll Corkery PhD	roll.corkery.phd@geemail.com	New York	New York	3055372477211989	e3adbe421382354dbd1d0a662cf841ec	Voyager	40.7087664627227923	-73.9284796780336677
15610	2020-03-14 04:09:41	2020-03-14	Arvin Donnelly	arvin.donnelly@geemail.com	Boston	Massachusetts	51061047658591984	8bf00061be31cffe23f5e1532bf16d09	Diners Club / Carte Blanche	42.4013878648337013	-71.0017095326397651
15611	2020-03-14 04:26:43	2020-03-14	Gina Bogan	gina.bogan@warmmail.com	Winston–Salem	North Carolina	3528764545617511837	3ce703aacd830d7bf1a0a7246c01a8ac	VISA 13 digit	36.1708797530502082	-80.1999065419789332
15612	2020-03-14 04:42:26	2020-03-14	Maurice Kessler	maurice.kessler@geemail.com	El Paso	Texas	210078972193953871	62972e24ce74037ea18083adabef48fd	JCB 16 digit	31.7646139283027509	-106.421079598411922
15613	2020-03-14 04:43:10	2020-03-14	Ollie Witting	ollie.witting@geemail.com	Worcester	Massachusetts	4106869803654319	eba46591abb5392afc5ae2d900ddbafd	Discover	42.2141562805678703	-71.8176927087150574
15614	2020-03-14 04:51:57	2020-03-14	London Reilly DDS	london.reilly.dds@geemail.com	Abilene	Texas	3468407971948464	929b56b7d4e7ff9dbad3cf4f24271a0b	American Express	32.529502059992403	-99.7163333348412095
15615	2020-03-14 04:52:35	2020-03-14	Mr. Bird Muller V	mr.bird.muller.v@woohoo.com	Los Angeles	California	869956097799849368	d3646af7299e9f1808f6d9a13b390691	JCB 16 digit	33.9255814193148169	-118.350192691478128
15616	2020-03-14 04:56:16	2020-03-14	Sherita Becker	sherita.becker@geemail.com	Moreno Valley	California	676281262075518	c29eb6fab8f2248b8b05097f38fef87b	Diners Club / Carte Blanche	33.9760981837280056	-117.196023226526378
15617	2020-03-14 05:11:24	2020-03-14	Saniyah Mann	saniyah.mann@geemail.com	Tampa	Florida	4869104895187425	d96603bc29603a723913a84476fb000a	Diners Club / Carte Blanche	28.033845147921145	-82.4938024237032863
15618	2020-03-14 05:15:38	2020-03-14	Abril Kulas DVM	abril.kulas.dvm@geemail.com	Indianapolis	Indiana	3754754214549948	59213e63f36089c53ea53c0ca37d9706	American Express	39.7574023806963126	-86.2423792829938236
15619	2020-03-14 05:17:06	2020-03-14	Jarrod Ritchie MD	jarrod.ritchie.md@geemail.com	San Francisco	California	3088585743779585221	fb82b51b888b4c062037a3e08e3d9489	Voyager	37.8117448359390735	-122.413310618145999
15620	2020-03-14 05:23:15	2020-03-14	Katina Klocko	katina.klocko@geemail.com	Richmond	Virginia	3337793839930340445	a698e9e9a616d18b2437d72b2ddee512	Diners Club / Carte Blanche	37.566473646623642	-77.4637439169213167
15621	2020-03-14 05:27:14	2020-03-14	Lucille McKenzie	lucille.mckenzie@woohoo.com	Daly City	California	4480204023729095	57fe3deafb7c0beb7a6606dc0a485c41	American Express	37.7237293886873815	-122.371852667406202
15622	2020-03-14 05:41:50	2020-03-14	Dr. Del Rath	dr.del.rath@woohoo.com	Norman	Oklahoma	54376156604351896	2c95a022d9ef8dacaae6eca00aea6cb1	JCB 16 digit	35.1721968141891068	-97.3999322340611258
15623	2020-03-14 06:07:33	2020-03-14	Latrice Ratke	latrice.ratke@geemail.com	Rochester	New York	3337595258138693630	99a0109bfe41b35ed0bbf0ab4b03299b	JCB 15 digit	43.1416267333529859	-77.5936646227032014
15624	2020-03-14 06:31:13	2020-03-14	Joyce Gutkowski	joyce.gutkowski@geemail.com	San Francisco	California	3528211311823923988	dcaceb2cd149b746255b2d10e2d811ed	JCB 16 digit	37.7580034395695989	-122.443898070235107
15625	2020-03-14 06:43:48	2020-03-14	Mr. Tilman Boyle	mr.tilman.boyle@geemail.com	Oakland	California	3757004854537044	9dd78d5b1c0c13dd7569454114e9eabe	VISA 16 digit	37.8338290986541637	-122.274263047739936
15626	2020-03-14 06:57:28	2020-03-14	Violeta Schultz	violeta.schultz@geemail.com	Philadelphia	Pennsylvania	210099352826848530	7734291b7e82e217e502fd85270d9115	VISA 16 digit	39.9634816331747942	-75.2255900912351905
15627	2020-03-14 07:13:46	2020-03-14	Loula Kub	loula.kub@geemail.com	Detroit	Michigan	54684835966864664	fa9ed3826bf3796842710680e1f8c500	Voyager	42.4194396417979149	-83.0787988065395524
15628	2020-03-14 07:16:35	2020-03-14	Itzel Tromp MD	itzel.tromp.md@geemail.com	Aurora	Illinois	4725694404976999	0bfb4d1fa8496f0b0769224a3a08e1a9	VISA 16 digit	41.6651090234275898	-88.2179668670915049
15629	2020-03-14 07:17:21	2020-03-14	Leigh Runolfsson	leigh.runolfsson@geemail.com	Greensboro	North Carolina	210050315189472542	a2c4163b73e28c13d9046e3cc83d0a99	Mastercard	36.0732650495715461	-79.9040826874300762
15630	2020-03-14 07:26:14	2020-03-14	Elenora Kerluke	elenora.kerluke@geemail.com	Oakland	California	6011358208394376302	06b12840600796b9d9ecebe0c8129e0a	Voyager	37.799844044618446	-122.266873379814371
15631	2020-03-14 07:36:02	2020-03-14	Mr. Deon Fisher III	mr.deon.fisher.iii@warmmail.com	Overland Park	Kansas	210035134918230299	e85be9571e23d4376cc723f986245ea2	VISA 16 digit	38.8803762922398803	-94.5967715298798026
15632	2020-03-14 07:36:58	2020-03-14	Phoebe Hammes	phoebe.hammes@geemail.com	Pembroke Pines	Florida	53400416389508726	6c5b21fb0f8d5398837d3ada342d3c5a	JCB 16 digit	26.104179193548859	-80.3826674973495301
15633	2020-03-14 07:40:52	2020-03-14	Darlene Dooley	darlene.dooley@geemail.com	Oakland	California	3096958168335429665	f6f473c1ba67fd58f1686cbe2dbe5616	Diners Club / Carte Blanche	37.7840926851435128	-122.268937090522925
15634	2020-03-14 07:43:30	2020-03-14	Herb Barrows	herb.barrows@warmmail.com	Overland Park	Kansas	3158619906079877016	db18d6597289496e36900ca1d0695aa9	VISA 13 digit	38.961299284581095	-94.6028471328824736
15635	2020-03-14 08:06:42	2020-03-14	Ron Schroeder-Deckow	ron.schroeder.deckow@warmmail.com	Worcester	Massachusetts	589392260012544	8fb93fc8c40037fb8e8d24db5e216aed	JCB 16 digit	42.3526592808943221	-71.863165033959973
15636	2020-03-14 08:12:43	2020-03-14	Sable Jacobi	sable.jacobi@geemail.com	Elizabeth	New Jersey	675977389016617	141eca859952347f5b3f5faf66153352	American Express	40.6405896519903109	-74.1996381915584209
15637	2020-03-14 08:20:37	2020-03-14	Shane Walter MD	shane.walter.md@geemail.com	San Francisco	California	3472363021547679	618d11d481c7eefd09ca783e2b68c6f4	Discover	37.753684189565675	-122.440972450743814
15638	2020-03-14 08:22:49	2020-03-14	Miss Lavelle Muller PhD	miss.lavelle.muller.phd@woohoo.com	Buffalo	New York	55579466809067907	6314c87dd1b91b317ed8aac3f9e73da4	VISA 13 digit	42.9385533209610699	-78.8899730373106962
15639	2020-03-14 08:24:37	2020-03-14	Pernell Keebler	pernell.keebler@geemail.com	Fort Lauderdale	Florida	3027549290174316	a7c81df6f93d6ece27bad7dd214111ef	JCB 16 digit	26.1140984531480846	-80.1959415921762542
15640	2020-03-14 08:31:11	2020-03-14	Lavonda Abbott	lavonda.abbott@geemail.com	Austin	Texas	55205611792624857	c5bb2be0e8db3baa46e06fb29c69bc36	JCB 15 digit	30.3762940061405295	-97.8126162395119678
15641	2020-03-14 08:46:14	2020-03-14	Lana Kuhlman	lana.kuhlman@woohoo.com	Tucson	Arizona	3337703177177195688	1e59bfba46469633cc109b5599a05d95	JCB 15 digit	32.179894011518364	-110.81889977946355
15642	2020-03-14 08:51:00	2020-03-14	Elayne Fay	elayne.fay@geemail.com	Tampa	Florida	4337583006099	e63372328e9287a6446f83d1cb0ae169	JCB 16 digit	27.8908642046734663	-82.4565218950368433
15643	2020-03-14 09:03:45	2020-03-14	Gasper O'Connell	gasper.o'connell@geemail.com	New York	New York	210095130719503139	1c6a15562acaa77534bebea8d26bf7b5	American Express	40.746749744726344	-74.0142441003479092
15644	2020-03-14 09:07:13	2020-03-14	Fount Murray III	fount.murray.iii@woohoo.com	Abilene	Texas	210062462990183185	5f0521a540e678647db76bea00cf6f75	Voyager	32.4109038249198349	-99.7823711342126103
15645	2020-03-14 09:31:23	2020-03-14	Dr. Edie Kerluke	dr.edie.kerluke@geemail.com	San Francisco	California	3041640830600906	7d79c0c74beab25d7724939a6d5112c5	VISA 16 digit	37.7664832835582658	-122.426190580302034
15646	2020-03-14 09:45:54	2020-03-14	Lorrayne Zemlak	lorrayne.zemlak@geemail.com	Cary	North Carolina	4730328888958503	2025d482465a4e1ab318852cd3be2c4f	Voyager	35.8087031322639433	-78.9094859184782962
15647	2020-03-14 09:58:46	2020-03-14	Mr. Alpheus Kertzmann II	mr.alpheus.kertzmann.ii@geemail.com	Joliet	Illinois	3112239657057265563	a185f0b5b9b29426001bc9808707ef32	JCB 15 digit	41.4635899664226883	-88.0850849895376626
15648	2020-03-14 10:10:36	2020-03-14	Gaines Rutherford	gaines.rutherford@geemail.com	Columbus	Ohio	676121534777335	d41c298675353f6aba4413e4c63d63b0	JCB 16 digit	40.0236787397459111	-82.9613213745646192
15649	2020-03-14 10:19:18	2020-03-14	Rufus Heidenreich	rufus.heidenreich@geemail.com	Atlanta	Georgia	501823450659455	b423ecc05117098abbfc5a71cbafb9c4	JCB 16 digit	33.8566781905755434	-84.4288607155017559
15650	2020-03-14 10:24:14	2020-03-14	Jazlynn Jaskolski-Morissette	jazlynn.jaskolski.morissette@geemail.com	Memphis	Tennessee	4103423022223309	667ef1971f0b0204b224b0168425836a	VISA 16 digit	35.196705196152628	-90.0307298135735152
15651	2020-03-14 10:27:54	2020-03-14	Gaither Corwin	gaither.corwin@geemail.com	New York	New York	4360781211675	88dbab98f7f5c4b42dd6e465ed7d9729	VISA 16 digit	40.6037178794611222	-74.0313540445536376
15652	2020-03-14 10:44:14	2020-03-14	Mrs. Philomena Grant DDS	mrs.philomena.grant.dds@geemail.com	Houston	Texas	54952126561436156	82a868acffddea126fa37bbf54a10906	JCB 15 digit	29.8117219532918192	-95.3394238789115178
15653	2020-03-14 10:50:07	2020-03-14	Donny Emard-Halvorson	donny.emard.halvorson@woohoo.com	Berkeley	California	869917227270591027	620175fbee25bdb856063107aa24cdb2	VISA 16 digit	37.8485509655137946	-122.256566907260307
15654	2020-03-14 11:14:15	2020-03-14	Mrs. Neola Cummings PhD	mrs.neola.cummings.phd@geemail.com	Corpus Christi	Texas	3112804372523049956	6cfb49c9d2c845c565b53b39a94df455	Maestro	27.8072898636508725	-97.1444642314981621
15655	2020-03-14 11:23:01	2020-03-14	Noel Moore	noel.moore@geemail.com	Phoenix	Arizona	503802289065118	8b0399859302f35807f6c77ef292acac	JCB 16 digit	33.565460973785072	-112.083914476067207
15656	2020-03-14 11:29:36	2020-03-14	Mr. Attilio Carter III	mr.attilio.carter.iii@geemail.com	Houston	Texas	3337290183550406972	742174e084b8102dfe5ae2da90cf1bfd	Diners Club / Carte Blanche	29.7098315461616949	-95.4582614302184425
15657	2020-03-14 12:12:29	2020-03-14	Felipe Waters	felipe.waters@geemail.com	Las Vegas	Nevada	869957054766343767	4f922803d3a0dddff22c7b3047769aa4	JCB 16 digit	36.1466737919587615	-115.239067176144943
15658	2020-03-14 12:15:26	2020-03-14	Von Grady	von.grady@geemail.com	Hartford	Connecticut	3096269121369417720	1d6aeabc96209fef53e99d480e928bd8	Mastercard	41.8429812840200981	-72.6785020767137411
15659	2020-03-14 12:25:57	2020-03-14	Nell Rohan	nell.rohan@geemail.com	Baltimore	Maryland	4451519976182	4682149ae8377fef5aff631c6da4a1fa	Mastercard	39.3107721450272933	-76.7082364558260963
15660	2020-03-14 12:33:27	2020-03-14	Derwin Wilkinson-Dickinson	derwin.wilkinson.dickinson@geemail.com	Aurora	Colorado	3158823742942285406	1246c2cc2cdab7f7cfc5ea9bbdaecfe3	JCB 15 digit	39.7190662451665872	-104.590402739786356
15661	2020-03-14 12:41:37	2020-03-14	Ami Armstrong	ami.armstrong@geemail.com	Houston	Texas	210094892870419394	ee7fead4de4af43f9a1aa996a26db8de	Diners Club / Carte Blanche	29.7649142006956033	-95.4051948146909439
15662	2020-03-14 12:42:30	2020-03-14	Amelia Ernser	amelia.ernser@geemail.com	Berkeley	California	210035689262339541	67506ba18909de6a251ea45fcb12b278	VISA 16 digit	37.860000425772256	-122.285632419597391
15663	2020-03-14 12:48:16	2020-03-14	Amara Rippin	amara.rippin@woohoo.com	Berkeley	California	4795734983088447	66c98a826d1a524c8e4f7c2fde8de66d	Discover	37.8523200287216426	-122.250542446100468
15664	2020-03-14 13:23:47	2020-03-14	Johnathan Kuphal	johnathan.kuphal@warmmail.com	Houston	Texas	869918517766343969	5994dc114c3b28969711b8175d66e02e	VISA 16 digit	29.8112755534317344	-95.3005136278938494
15665	2020-03-14 13:29:30	2020-03-14	Catina Gibson-Morissette	catina.gibson.morissette@geemail.com	San Francisco	California	869960499465171131	323385d3082bee15713d90d05e9e2880	Diners Club / Carte Blanche	37.7663346736769867	-122.41345854793849
15666	2020-03-14 13:29:51	2020-03-14	Westley Bogisich	westley.bogisich@geemail.com	Billings	Montana	54263395343914129	649ab429ecfa009551f65f381c164303	JCB 15 digit	45.8772295080348869	-108.569169966799763
15667	2020-03-14 13:31:19	2020-03-14	Mrs. Tricia Price DVM	mrs.tricia.price.dvm@geemail.com	Richmond	Virginia	54745418465495962	01fe8b9e66a9c4a061fea62dbc77450d	VISA 16 digit	37.592485885530337	-77.4166188478227753
15668	2020-03-14 13:43:23	2020-03-14	Carri Kemmer	carri.kemmer@warmmail.com	Killeen	Texas	3427383308118917	79dff3aac42d3c479d768b83310bfc20	VISA 16 digit	31.1594178926430629	-97.7639941021502068
15669	2020-03-14 14:13:03	2020-03-14	Miss Dayana McCullough	miss.dayana.mccullough@geemail.com	Minneapolis	Minnesota	4428537332023055	e01dbc879a40e3965dede7f1378a8cc0	Diners Club / Carte Blanche	45.062888047713038	-93.2700876371275598
15670	2020-03-14 14:17:07	2020-03-14	Dania Reinger DDS	dania.reinger.dds@geemail.com	Kenosha	Wisconsin	3727183272104632	c547f147a83879904e393f480a84101c	JCB 15 digit	42.5865353509623574	-87.7947805791854847
15671	2020-03-14 14:29:20	2020-03-14	Tom Ferry II	tom.ferry.ii@geemail.com	Olathe	Kansas	4400694952989	7973152632b134bf65ce5b13519cb390	JCB 16 digit	38.822019799624762	-94.8784168543927393
15672	2020-03-14 14:42:58	2020-03-14	Miss Risa Rolfson PhD	miss.risa.rolfson.phd@geemail.com	Los Angeles	California	4166799010177	79fb7c128374ad1891cb84943ca60fa3	Voyager	34.0195049361191693	-118.421581645495436
15673	2020-03-14 14:57:59	2020-03-14	Ms. Deborrah Jakubowski	ms.deborrah.jakubowski@geemail.com	Raleigh	North Carolina	6011748355852468763	61121d9888837af20fedc65020242b1d	JCB 16 digit	35.8855384410493059	-78.7331558107335212
15674	2020-03-14 14:58:50	2020-03-14	Mr. Trystan Ledner V	mr.trystan.ledner.v@geemail.com	Oklahoma City	Oklahoma	3779548696462138	8d2040935e37d334a8281f0d586115ce	JCB 16 digit	35.4184860642444335	-97.5970991164341513
15675	2020-03-14 14:59:36	2020-03-14	Skylar Gottlieb	skylar.gottlieb@woohoo.com	Phoenix	Arizona	869927096494633081	b455c5f960bda405623b930fe7904278	Diners Club / Carte Blanche	33.492263464669513	-112.024274150321645
15676	2020-03-14 15:31:15	2020-03-14	Dr. Darleen Borer DVM	dr.darleen.borer.dvm@geemail.com	Madison	Wisconsin	3112053518420832104	ba99cf48ad3210ea142eb6bb3bd956a6	JCB 16 digit	43.1764254697106793	-89.4902325565345649
15677	2020-03-14 15:38:02	2020-03-14	Sloane Jakubowski-Turner	sloane.jakubowski.turner@geemail.com	San Diego	California	6011356083523399836	c6bde14cc105e7432e43687c106e179f	VISA 16 digit	32.7311691894728725	-117.161951139094313
15678	2020-03-14 15:38:26	2020-03-14	Mr. Orvin Heller PhD	mr.orvin.heller.phd@geemail.com	Oakland	California	180063176500398179	4815fc367f2e3bba4065e76f6e8de5e0	VISA 16 digit	37.7784600509283308	-122.245612141924525
15679	2020-03-14 15:38:46	2020-03-14	Eldon Pfannerstill	eldon.pfannerstill@warmmail.com	Elk Grove	California	3782658340481478	1276eda2021b223c19d24368ab731a28	JCB 15 digit	38.356564977141467	-121.460680080940946
15680	2020-03-14 15:42:14	2020-03-14	Elfreda Greenfelder-Kiehn	elfreda.greenfelder.kiehn@woohoo.com	Mesa	Arizona	4734634877233196	a651bcbc66d2e8e1abc8c91589e3305f	Maestro	33.3304250642336868	-111.664671555382753
15681	2020-03-14 15:43:18	2020-03-14	Kalel Harber	kalel.harber@warmmail.com	Los Angeles	California	3528819974151523104	3c8dc8f7741797ec7f1f02f683a76934	VISA 13 digit	33.973890936780343	-118.463222695374114
15682	2020-03-14 15:49:08	2020-03-14	Mr. Rice Reynolds	mr.rice.reynolds@warmmail.com	North Las Vegas	Nevada	210073690035129949	7f2cf8b37046938b63c5ae86797eb8dc	VISA 16 digit	36.1991787204675362	-115.089780925422545
15683	2020-03-14 15:50:12	2020-03-14	Lavon Gibson-O'Hara	lavon.gibson.o'hara@woohoo.com	San Francisco	California	4103489370301195	1eaf0dc353e27af70ea993c032c53934	JCB 16 digit	37.7725102657587968	-122.444155666689184
15684	2020-03-14 16:00:21	2020-03-14	Dr. Devon Hills	dr.devon.hills@warmmail.com	Anaheim	California	3158877084839589391	75ebb817c2a9f98db8df4891c9d43f3d	Diners Club / Carte Blanche	33.8506090686488861	-117.677856918864322
15685	2020-03-14 16:02:17	2020-03-14	Jovanni Connelly DVM	jovanni.connelly.dvm@warmmail.com	Green Bay	Wisconsin	6011231166612785816	752bec1b397d8c52c7817b268f3c9b01	VISA 13 digit	44.56593544735275	-87.952054828434072
15686	2020-03-14 16:07:04	2020-03-14	Leoma Nader	leoma.nader@geemail.com	San Francisco	California	869950295276724791	796c51aeaae2e7e5f646aba62b08fb90	VISA 13 digit	37.8030455551986151	-122.431664930165695
15687	2020-03-14 16:17:48	2020-03-14	Dr. Erastus Carroll V	dr.erastus.carroll.v@geemail.com	Chicago	Illinois	4391833037636	166f5dc5b52d544835b250b53bec27d6	VISA 13 digit	41.7440059777650987	-87.7436568896781637
15688	2020-03-14 16:26:30	2020-03-14	Letitia Abernathy-Dooley	letitia.abernathy.dooley@geemail.com	Oakland	California	060467397677633	815bbfea98506fa9f91376211143275f	Discover	37.8067186264475765	-122.304109005982909
15689	2020-03-14 16:39:30	2020-03-14	Waldo Mosciski-Rath	waldo.mosciski.rath@geemail.com	Pasadena	California	676387650864629	e86509274f0c9c49ba7483042ca07f19	Discover	34.2003056910209366	-118.070313855614884
15690	2020-03-14 16:44:32	2020-03-14	Mr. Damarion Franecki	mr.damarion.franecki@geemail.com	Lubbock	Texas	53948120111856838	07ddb2b805967979f1558679df6afd7d	VISA 16 digit	33.5221062908455778	-101.871258085631581
15691	2020-03-14 16:45:16	2020-03-14	Dr. Giuseppe Carter Sr.	dr.giuseppe.carter.sr.@geemail.com	Thornton	Colorado	6011937536564834456	a2601c6c2446f96129fd9c251e9fa54f	Diners Club / Carte Blanche	39.9858669307414445	-104.922846231718736
15692	2020-03-14 17:12:43	2020-03-14	Mr. Zeb Gerlach IV	mr.zeb.gerlach.iv@geemail.com	Des Moines	Iowa	869977528902076874	84b3c49dd13fa779674a82b3f542d09d	VISA 16 digit	41.4885893503878265	-93.682202795012671
15693	2020-03-14 17:32:33	2020-03-14	Lemon Carroll	lemon.carroll@warmmail.com	Philadelphia	Pennsylvania	3337876890993827471	a2450cb19e4b495a4bdcb0bfbbf65302	Discover	39.9982466921169291	-75.1563643466580658
15694	2020-03-14 17:35:12	2020-03-14	Dr. Junie Franecki MD	dr.junie.franecki.md@geemail.com	Charlotte	North Carolina	4540159875611	6c6d1f28274a663f976c0f8faf8e68bd	JCB 15 digit	35.1785687213085581	-80.791381394997245
15695	2020-03-14 17:51:42	2020-03-14	Dr. Farah Zemlak MD	dr.farah.zemlak.md@geemail.com	Oakland	California	4722012122967161	f106c737c50c68675b6d4458ba2e4fae	JCB 16 digit	37.7771855178477622	-122.267238082864438
15696	2020-03-14 18:04:19	2020-03-14	Ms. Lavinia Hermann DDS	ms.lavinia.hermann.dds@geemail.com	Minneapolis	Minnesota	6011940607672253742	52b84c54fa30a9dbd9d78af755fd66c2	Diners Club / Carte Blanche	44.8791816355280559	-93.2095004479207034
15697	2020-03-14 18:05:04	2020-03-14	Benito Tremblay	benito.tremblay@geemail.com	Fresno	California	6011628611236875478	2afe0861cfc11d987315f4302d234a4d	Mastercard	36.8284700777254983	-119.88254032676258
15698	2020-03-14 18:10:33	2020-03-14	Amirah Emard	amirah.emard@warmmail.com	San Francisco	California	3528244729728037516	51c44483a3474d211a571ef57ce75dc0	Discover	37.7749688623589037	-122.447911545942731
15699	2020-03-14 18:17:07	2020-03-14	Mrs. Keira Hamill	mrs.keira.hamill@warmmail.com	Phoenix	Arizona	6011861115260131606	b13d8174806c2b8b9ea58a8897dfa761	Discover	33.5613412979457522	-112.16225942963959
15700	2020-03-14 18:17:38	2020-03-14	Stoney Jast	stoney.jast@woohoo.com	San Diego	California	210047852982860024	cb3a23fb4913d2167c1eae27ede0385f	VISA 16 digit	32.8923554817281669	-117.136499822875493
15701	2020-03-14 18:21:44	2020-03-14	Fount Tromp	fount.tromp@woohoo.com	Oakland	California	4562130760468582	5d005242edafbb315609860aa62e21fb	VISA 16 digit	37.7891136022914722	-122.300153757561887
15702	2020-03-14 18:22:04	2020-03-14	Mitzi Christiansen	mitzi.christiansen@geemail.com	New York	New York	4405565227437	8271f4d75308f23001a32a4252624e3a	VISA 16 digit	40.6157944143973282	-73.8866324989952119
15703	2020-03-14 18:35:02	2020-03-14	Jay Thiel	jay.thiel@geemail.com	San Diego	California	3112091759748643799	2b0b69bf54c3c3e8bf221283bb58d895	Mastercard	32.7197635322410605	-117.18318912944757
15704	2020-03-14 18:38:36	2020-03-14	Dr. Mylee Jacobi PhD	dr.mylee.jacobi.phd@geemail.com	Jersey City	New Jersey	3003886077944006	7939e26f58b42ec9fc6a2fd4cc971e20	JCB 16 digit	40.6892152448125159	-74.1394711073909036
15705	2020-03-14 18:39:05	2020-03-14	Jeraldine Osinski	jeraldine.osinski@warmmail.com	Baltimore	Maryland	630442523300624	a203d777f03ec314e9547371c0f25cfe	VISA 13 digit	39.2965120720211374	-76.6661811916176248
15706	2020-03-14 18:41:43	2020-03-14	Mr. Ali Hintz	mr.ali.hintz@geemail.com	Philadelphia	Pennsylvania	3528687572653408847	3b00dbd91076f35008966a274d4b7fe6	VISA 16 digit	40.0179420985706145	-75.1217731304831915
15707	2020-03-14 18:42:19	2020-03-14	Yoshiko Satterfield	yoshiko.satterfield@geemail.com	Pittsburgh	Pennsylvania	4940999333708	6b2c01ff8f590a5cbf38c61c21a50957	VISA 16 digit	40.3878918653309356	-80.0383843459826068
15708	2020-03-14 18:46:29	2020-03-14	Horton Smith	horton.smith@geemail.com	Houston	Texas	180027163826393022	a2ab60d863b650231125ea860d5d5c80	Mastercard	29.7561130371954299	-95.4876060904018544
15709	2020-03-14 18:49:08	2020-03-14	Red Torphy	red.torphy@geemail.com	El Paso	Texas	869922483431282641	38e364b9fa105d498d39c50a86ea9f96	VISA 16 digit	31.8384522980373355	-106.371212374417112
15710	2020-03-14 19:12:30	2020-03-14	Daryn Becker	daryn.becker@geemail.com	Lubbock	Texas	4809113350759878	5739ce849add6442a299ac506ecfff7e	VISA 13 digit	33.5148361993528923	-101.846398450937869
15711	2020-03-14 19:17:49	2020-03-14	Rosaria Johnson	rosaria.johnson@geemail.com	Atlanta	Georgia	589365978711318	8806cdd0dd2ab151a8468dbdedb8e8cd	American Express	33.7939640180949112	-84.3967887066349505
15712	2020-03-14 19:38:51	2020-03-14	Mr. Kaleb Cummings Sr.	mr.kaleb.cummings.sr.@geemail.com	Dayton	Ohio	4207503056658291	70673b27e9c1e47e5c333322de4a8988	JCB 16 digit	39.7516144885007279	-84.1494643741477262
15713	2020-03-14 20:00:06	2020-03-14	Raleigh Gleason Jr.	raleigh.gleason.jr.@geemail.com	Springfield	Missouri	3088041819461596193	64d0de9d45808f007f59e19b694a8f26	Voyager	37.1736860479887596	-93.2127350922964553
15714	2020-03-14 20:19:13	2020-03-14	Cristin Parisian	cristin.parisian@geemail.com	Bellevue	Washington	4350683021251722	ea4c38da3475bb9db33792715b21d96f	JCB 16 digit	47.6733211919847903	-122.068352367222303
15715	2020-03-14 20:30:48	2020-03-14	Ludwig Armstrong DDS	ludwig.armstrong.dds@warmmail.com	San Francisco	California	3714115562006585	e75fa96d3afc813932dfc8f5811817cb	Mastercard	37.7561396431711032	-122.395015838875466
15716	2020-03-14 20:37:32	2020-03-14	Gaven Hyatt-Murazik	gaven.hyatt.murazik@woohoo.com	New York	New York	3337152106430202540	7f6a768fc3ebd2a415759cef88ed08eb	Maestro	40.569058366328477	-73.9174473746575416
15717	2020-03-14 20:41:28	2020-03-14	Makaila Yost	makaila.yost@geemail.com	Pearland	Texas	4200377412663965	25059126c2ee1520bf3c612615f3289f	JCB 15 digit	29.5637125192947714	-95.351422959784415
15718	2020-03-14 20:47:09	2020-03-14	Dr. Othel Towne III	dr.othel.towne.iii@geemail.com	Indianapolis	Indiana	3528699794538719703	32317199fe9aae2bff94305694923249	JCB 15 digit	39.7876244290739294	-86.2387682401776345
15719	2020-03-14 21:01:16	2020-03-14	Mrs. Veola Daniel MD	mrs.veola.daniel.md@geemail.com	Santa Ana	California	6011711714912372923	64da6b41506a3e040ed1e0d43dfcb9cf	Discover	33.7054589761991039	-117.935153654210268
15720	2020-03-14 21:10:28	2020-03-14	Margurite O'Keefe	margurite.o'keefe@geemail.com	San Francisco	California	869938038831144452	58ac316f184cb6ef9d17134ec5817623	Voyager	37.801627443483298	-122.425675412297011
15721	2020-03-14 21:11:36	2020-03-14	Verona Leuschke	verona.leuschke@geemail.com	Reno	Nevada	3407410748293846	2ca9813f5bd397fd5f9c8b47bf5b0181	JCB 16 digit	39.4988198410332245	-119.835005955926704
15722	2020-03-14 21:23:55	2020-03-14	Theodora Smith	theodora.smith@geemail.com	Los Angeles	California	4449989235485	f2d9c811b1012bcd499f937038cbf539	Maestro	34.0607587925955642	-118.462385346693168
15723	2020-03-14 21:29:09	2020-03-14	Mrs. Ava Daugherty MD	mrs.ava.daugherty.md@woohoo.com	Lincoln	Nebraska	3112032180456844267	94b9f3910e987e709c32f638a81a6aaf	JCB 15 digit	40.7676554403286389	-96.5843429444052362
15724	2020-03-14 21:29:38	2020-03-14	Corine Gorczany	corine.gorczany@geemail.com	Long Beach	California	3758663207976313	43fdfe42779084f6a0a6bce2a13c870b	Voyager	33.7235086677882805	-118.104882872632885
15725	2020-03-14 21:30:03	2020-03-14	Collier Ritchie	collier.ritchie@warmmail.com	New Orleans	Louisiana	3096175687098895991	f0ee5bdbf9e399328e3406e085074f76	VISA 16 digit	30.1036770655788466	-89.9617548691835225
15726	2020-03-14 21:47:08	2020-03-14	Stoney Schneider	stoney.schneider@geemail.com	New York	New York	869946753618423305	3e7c1def227e74ace1b02c1f6449c8bf	Mastercard	40.62101052442938	-73.9255612608406665
15727	2020-03-14 21:50:47	2020-03-14	Dr. Arlyn Pollich I	dr.arlyn.pollich.i@geemail.com	Houston	Texas	4464966914481	3357938d000b1612e9c766d83638cafe	VISA 16 digit	29.7724707466162748	-95.4562853002470035
15728	2020-03-14 22:08:10	2020-03-14	Clarnce Schimmel	clarnce.schimmel@geemail.com	New York	New York	4465940527764273	eee42fdc8dc9fdc3fc04f4985e8d417c	JCB 16 digit	40.6292947498373707	-74.0366343256913098
15729	2020-03-14 22:43:36	2020-03-14	Edison Kautzer	edison.kautzer@geemail.com	Chicago	Illinois	502090835431173	0aaa900d3bb489b97cc4ec558d431c8f	JCB 16 digit	41.8581832240637439	-87.7548829386971789
15730	2020-03-14 22:56:10	2020-03-14	Lamar Denesik	lamar.denesik@geemail.com	Los Angeles	California	180010769661720548	c5aa43d150ce256b1dc27e439ea3d9a3	VISA 13 digit	34.0919949590560023	-118.371567305595789
15731	2020-03-14 23:05:43	2020-03-14	Irvin Bahringer	irvin.bahringer@geemail.com	Berkeley	California	4458057750748243	47673f800d9423138441719ee5054422	VISA 16 digit	37.8920980366822278	-122.26889197424768
15732	2020-03-14 23:19:47	2020-03-14	Davion Senger	davion.senger@geemail.com	Oakland	California	3029844229264827	efa66341e8a24194ae010db2c2ac27e1	VISA 13 digit	37.8138226494242105	-122.277345193396457
15733	2020-03-14 23:36:36	2020-03-14	Mrs. Elena West PhD	mrs.elena.west.phd@geemail.com	Norfolk	Virginia	210013587093325257	8e773a59d77ea5ebdaba232a88aacf3d	VISA 16 digit	36.8429471568223121	-76.2483879618816189
15734	2020-03-15 00:03:34	2020-03-15	Darrius Beatty	darrius.beatty@geemail.com	Oakland	California	4476344099223825	d05a1bf0d8d24fb77a569d556f9cffcf	Diners Club / Carte Blanche	37.8055126620961772	-122.27621744277954
15735	2020-03-15 00:07:11	2020-03-15	Harrold Barton	harrold.barton@geemail.com	Santa Rosa	California	51924430245116852	53845dee5761ef7b101aa382576229b5	JCB 15 digit	38.4244444084942387	-122.621953643231095
15736	2020-03-15 00:18:19	2020-03-15	Ignacio Mueller-Robel	ignacio.mueller.robel@warmmail.com	New York	New York	501891879128717	4d9772ed8d9d31458dbb302c2d04369c	JCB 16 digit	40.7633795574065303	-74.0344971070893081
15737	2020-03-15 00:20:50	2020-03-15	Quint Ullrich-Schimmel	quint.ullrich.schimmel@geemail.com	Irving	Texas	4398050109930946	4b2b8081b6a20d080695200637db4356	Diners Club / Carte Blanche	32.9044206551693392	-97.0111563594359865
15738	2020-03-15 00:27:14	2020-03-15	Aisha Sanford PhD	aisha.sanford.phd@warmmail.com	Beaumont	Texas	180032433636138419	d2dde3045fcde9006d29035e19339a80	Maestro	30.0297578251060102	-94.1862549687989059
15739	2020-03-15 00:30:56	2020-03-15	Leta Schulist-Dietrich	leta.schulist.dietrich@geemail.com	Virginia Beach	Virginia	3012227587596088	4b4a8244ebecd12931e6dc3b7400e5ed	VISA 16 digit	36.6866672914195817	-76.0299219967469497
15740	2020-03-15 00:58:51	2020-03-15	Elida Mohr	elida.mohr@geemail.com	New York	New York	6011433919525639413	4912fd0ea3fb1821982480965c5f4c6c	JCB 15 digit	40.6056231116633839	-73.9367380223598332
15741	2020-03-15 01:28:34	2020-03-15	Britney Olson	britney.olson@geemail.com	Oxnard	California	3096664292624852380	ffb8bea7f072225d852787d633dfa96b	Mastercard	34.2844443444583575	-119.300925762988996
15742	2020-03-15 02:18:40	2020-03-15	Mrs. Kanisha Padberg MD	mrs.kanisha.padberg.md@warmmail.com	San Bernardino	California	4626766725382634	bcf5ec3c26ee01683da5691ab052cc8c	Diners Club / Carte Blanche	34.1813730139549818	-117.226259200765185
15743	2020-03-15 02:38:56	2020-03-15	Jordan Reilly	jordan.reilly@geemail.com	Irvine	California	53693067918077984	586bc3f897904232a1be2f9bf98c12f5	American Express	33.6386256800513763	-117.813058812963959
15744	2020-03-15 03:03:48	2020-03-15	Parker Lowe	parker.lowe@geemail.com	Boston	Massachusetts	3739124943084304	df78f68a30567414ca0cc7767da25f8e	JCB 16 digit	42.4052618994545227	-70.9433360831297932
15745	2020-03-15 03:13:29	2020-03-15	Manerva Rogahn	manerva.rogahn@geemail.com	Houston	Texas	6011734655065142071	30601b718ec6be5fd8874a5512f1494b	VISA 16 digit	29.7615098497442894	-95.375236058283221
15746	2020-03-15 03:18:57	2020-03-15	Lorri Lubowitz	lorri.lubowitz@geemail.com	Newport News	Virginia	4751311447666	a229c5c5b664d8f8890ccf8c98f899d7	VISA 13 digit	37.1219669962663232	-76.4780261173639531
15747	2020-03-15 03:29:05	2020-03-15	Victory Stracke-Becker	victory.stracke.becker@geemail.com	Corpus Christi	Texas	3711972686439800	32c86e7ac57cfabf30a48080cade2c3b	Diners Club / Carte Blanche	27.7017970704410246	-97.2675577690653483
15748	2020-03-15 03:37:16	2020-03-15	Ms. Sada Fadel	ms.sada.fadel@warmmail.com	West Covina	California	676169081269016	c62c6cc359d689e556fe308602d79f1c	Mastercard	34.0669834999475611	-118.00247392631843
15749	2020-03-15 03:39:13	2020-03-15	Sena Herman	sena.herman@geemail.com	Columbus	Ohio	503828130240345	b2e2d1c84b3070e456a932676293ff3d	VISA 16 digit	39.9073923337783683	-83.007363316114251
15750	2020-03-15 03:47:14	2020-03-15	Holli Conroy	holli.conroy@geemail.com	Omaha	Nebraska	3485058052982499	87428af3fe251a2f0ea872af4e24ec6b	JCB 16 digit	41.1697524818737079	-96.1171887716393911
15751	2020-03-15 03:49:19	2020-03-15	Isaias Dibbert Jr.	isaias.dibbert.jr.@geemail.com	San Francisco	California	4736294065038556	a234495a1772c634dab8d28a4e0ad89f	VISA 16 digit	37.7572474977960724	-122.451657436072196
15752	2020-03-15 04:04:36	2020-03-15	Dr. Cal Armstrong	dr.cal.armstrong@geemail.com	San Francisco	California	53922467896483852	6cd0af7005b5f3383222dbb7992ca50d	Discover	37.7824282880532181	-122.43094534471642
15753	2020-03-15 04:19:54	2020-03-15	Mr. Malcom Rowe	mr.malcom.rowe@geemail.com	New York	New York	53057128752782020	45ae1394e2dbae5a6d838f31309b8db1	Diners Club / Carte Blanche	40.6400269099269025	-73.865149026307094
15754	2020-03-15 04:20:32	2020-03-15	Mr. Dyllan Mueller DDS	mr.dyllan.mueller.dds@geemail.com	San Antonio	Texas	3029670235449023	6fde7603dbe21bf98895dbb7984bdfae	VISA 16 digit	29.5522904193099585	-98.6085065401460952
15755	2020-03-15 05:11:09	2020-03-15	Izayah Strosin V	izayah.strosin.v@geemail.com	Kansas City	Missouri	3112818056581667684	cde87c880a137cc6a024aa394900d397	Discover	39.2088332711555125	-94.5740176831595676
15756	2020-03-15 05:17:01	2020-03-15	Mrs. Aaliyah Keeling	mrs.aaliyah.keeling@geemail.com	Louisville	Kentucky	060479692356656	0031b6025c16d61ec746d8cf141543f0	JCB 16 digit	38.0793021270442722	-85.5740661013010993
15757	2020-03-15 05:20:08	2020-03-15	Hennie Welch	hennie.welch@warmmail.com	Garland	Texas	4447686711813490	554d54743302164d9c151847402bcaba	American Express	32.9294837767958626	-96.5332412881936932
15758	2020-03-15 05:22:39	2020-03-15	Ricki Walter	ricki.walter@woohoo.com	New York	New York	6011494863321031936	95a3af08d03dcd52649b759e6acb1c08	Voyager	40.6940503337178399	-74.0030407711759182
15759	2020-03-15 05:29:50	2020-03-15	Dr. Ilo Mohr PhD	dr.ilo.mohr.phd@warmmail.com	Oakland	California	3112922019135601867	b727371f3a6b1ae211dab586f9db8903	Mastercard	37.7881905712509791	-122.307071631772089
15760	2020-03-15 05:38:28	2020-03-15	Mr. Ferrell Stoltenberg III	mr.ferrell.stoltenberg.iii@geemail.com	Fayetteville	North Carolina	3528052467118469533	9bcd4e259163b2d6f1b70a9a61555b77	JCB 15 digit	35.1259179390288878	-79.0711858372334433
15761	2020-03-15 05:38:49	2020-03-15	Adolph Swift	adolph.swift@geemail.com	Tucson	Arizona	52767298788733809	5f476aa6c531bd33bfdc282843db419a	VISA 13 digit	32.1605567512143438	-110.930928730754545
15762	2020-03-15 05:40:17	2020-03-15	Hardin O'Keefe DDS	hardin.o'keefe.dds@geemail.com	Phoenix	Arizona	3469653364578801	aca1767160ca47be6ab977d376204743	American Express	33.6210280999474236	-112.082038205761847
15763	2020-03-15 05:48:55	2020-03-15	Dr. Fate McDermott	dr.fate.mcdermott@geemail.com	Indianapolis	Indiana	4213385626300865	8c1a7ae7d5a2837c8964c045fe700118	JCB 16 digit	39.8315713800962996	-86.0502033591471616
15764	2020-03-15 06:14:22	2020-03-15	Roddy Kihn	roddy.kihn@geemail.com	San Francisco	California	6011519749608497455	88412fda0af801425a47473af7948279	Voyager	37.7661372279352037	-122.418935383197336
15765	2020-03-15 06:14:55	2020-03-15	Dr. Nathanael Kemmer PhD	dr.nathanael.kemmer.phd@geemail.com	Centennial	Colorado	3018181899814768	70eb081b1c8bf7e9e912064c56559915	Diners Club / Carte Blanche	39.6236911425873686	-104.886722429085893
15766	2020-03-15 06:18:25	2020-03-15	Mrs. Maybelle Flatley PhD	mrs.maybelle.flatley.phd@geemail.com	Philadelphia	Pennsylvania	6011640949327759704	b40f4445d161d73203b7218905bb301c	JCB 16 digit	40.0193076722282939	-75.0474403435729442
15767	2020-03-15 06:22:28	2020-03-15	Miss Clementine Reynolds DVM	miss.clementine.reynolds.dvm@geemail.com	San Francisco	California	869960574644565773	8c0098693e0e2d546ac8e1c19a0cca42	VISA 16 digit	37.7824477676553485	-122.388734588607647
15768	2020-03-15 06:57:42	2020-03-15	Sharon Johnson	sharon.johnson@geemail.com	Aurora	Illinois	4656615728579592	b44553a3c51918963cfbca810a8829ba	Voyager	41.6755771492365739	-88.2948880018595617
15769	2020-03-15 07:28:37	2020-03-15	Eileen Pouros	eileen.pouros@geemail.com	Berkeley	California	4668116077748082	6fadb3797327fd32fd0451ee5dec28c0	JCB 15 digit	37.8637349699260355	-122.280487318622747
15770	2020-03-15 07:41:26	2020-03-15	Susie Dibbert	susie.dibbert@geemail.com	Bakersfield	California	4473844369757868	ebca7ff12bb9770c05259932a51dd3c3	VISA 13 digit	35.2269768981903795	-118.932819071439283
15771	2020-03-15 08:00:41	2020-03-15	Alden Klein	alden.klein@geemail.com	West Palm Beach	Florida	3528750848565958711	6b400ad38f7480b4dc60e24683eb87a5	Maestro	26.7553168344158685	-80.1837210727226051
15772	2020-03-15 08:02:48	2020-03-15	Joyce Bergnaum DVM	joyce.bergnaum.dvm@geemail.com	Tallahassee	Florida	52939198950338143	ca22ce2aa5827db6b328e85fc6d7fa5e	Discover	30.5109772661257566	-84.1896173129804453
15773	2020-03-15 08:07:49	2020-03-15	Susie Ullrich	susie.ullrich@warmmail.com	St. Petersburg	Florida	52344292803450442	4d5ba0fd7e4990ec8a8db2e451a2eacb	JCB 16 digit	27.6956251938715567	-82.6222238300260159
15774	2020-03-15 08:12:13	2020-03-15	Orlando Raynor	orlando.raynor@geemail.com	Los Angeles	California	630413153829331	ba7db810657984f37869bbaee8bc2091	JCB 16 digit	33.9925160439085161	-118.370539675885055
15775	2020-03-15 08:15:08	2020-03-15	Dr. Genesis Mosciski DDS	dr.genesis.mosciski.dds@geemail.com	Sterling Heights	Michigan	675916172961209	31146b1151921d07fbb21c78e757a262	VISA 13 digit	42.5314996844705249	-82.9603745700486002
15776	2020-03-15 08:29:20	2020-03-15	Alva Roob	alva.roob@geemail.com	Denton	Texas	3024701162939630	5c730e227cde923a3333971115d11fd0	American Express	33.2563521082311837	-97.1506833531554861
15777	2020-03-15 08:29:27	2020-03-15	Dr. Guillermo Gibson IV	dr.guillermo.gibson.iv@geemail.com	Worcester	Massachusetts	3337073266094298980	5e34f6994af4a83a2c9f29e98aa64350	American Express	42.2662594005633139	-71.8182939515702401
15778	2020-03-15 08:33:04	2020-03-15	Gianni Bosco	gianni.bosco@warmmail.com	Athens	Georgia	502088046091638	1e7a3488e1424f2117254526c0f90bd1	JCB 16 digit	34.0084556610047812	-83.4451959729775723
15779	2020-03-15 08:33:39	2020-03-15	Leslie Stroman	leslie.stroman@geemail.com	Spokane	Washington	3158682888702903959	93cc9259f30a5c5163f8bc114902a5af	JCB 16 digit	47.6745907041016963	-117.448347835698357
15780	2020-03-15 08:43:42	2020-03-15	Gearldine Reilly	gearldine.reilly@geemail.com	San Francisco	California	3495471302159867	ac4921083e38f988fed5a50f4057f2e3	Mastercard	37.7737642130770581	-122.419530278068478
15781	2020-03-15 08:43:56	2020-03-15	Bryant Barton	bryant.barton@geemail.com	Oakland	California	54853950112655117	f1ad89af0250e794a16ab709b32f0d64	Voyager	37.8283270244221086	-122.27045450346138
15782	2020-03-15 08:46:15	2020-03-15	Hardie Walker	hardie.walker@geemail.com	Gilbert	Arizona	3047208736327802	751ea73513d9246683cb519f965c8738	VISA 13 digit	33.3418065309405307	-111.787315468084444
15783	2020-03-15 08:58:14	2020-03-15	Dr. Bud Johns I	dr.bud.johns.i@geemail.com	Tucson	Arizona	3337842983780857727	530589ca9ecbe98072dc6b1268829eb7	JCB 16 digit	32.1631138633511995	-110.928818763442706
15784	2020-03-15 09:14:53	2020-03-15	Bradley Franecki	bradley.franecki@geemail.com	Portland	Oregon	4836584742354	a14627f0f232e417a8bf7e5b5fe91db7	Mastercard	45.5386408728901273	-122.659493551915517
15785	2020-03-15 09:15:31	2020-03-15	Kraig Jones	kraig.jones@warmmail.com	Worcester	Massachusetts	561242519748539	1b8a06f1a14213454a177af9d0d8eba7	VISA 16 digit	42.2713821991048775	-71.849227228692925
15786	2020-03-15 09:35:48	2020-03-15	Mariel Hilll DDS	mariel.hilll.dds@geemail.com	New York	New York	869967496721979227	1483fc45803fa9ab9a51ec6576ff364a	JCB 15 digit	40.646718944678085	-73.931279310573629
15787	2020-03-15 09:42:16	2020-03-15	Ebbie Thompson	ebbie.thompson@woohoo.com	El Paso	Texas	561210977222610	5ecf5d75c562047568f75bace19cb11c	Maestro	31.8297170772511535	-106.479138687437413
15788	2020-03-15 09:51:53	2020-03-15	Dr. Haven Mohr DDS	dr.haven.mohr.dds@geemail.com	Jacksonville	Florida	4228754873103541	5a541057782e17b766b37a3c2698c649	VISA 16 digit	30.4013467149395495	-81.6119282317891788
15789	2020-03-15 10:02:30	2020-03-15	Dante Eichmann	dante.eichmann@warmmail.com	Irvine	California	3794649863274149	157de2f2ad7ee4c8c4011a3fece3eae1	American Express	33.6190902279704815	-117.852354669432344
15790	2020-03-15 10:07:44	2020-03-15	Mr. Jared Sawayn V	mr.jared.sawayn.v@geemail.com	Anaheim	California	4072095321030788	8260b5ce0c9664db6c7dd87474a6503c	VISA 16 digit	33.8900889730378978	-117.767356458094341
15791	2020-03-15 10:16:08	2020-03-15	Malaki Windler Jr.	malaki.windler.jr.@warmmail.com	San Francisco	California	869915518233281850	c6e8444454490b8249df13f8d6a242d5	JCB 16 digit	37.7485687610425913	-122.412877643936881
15792	2020-03-15 10:18:49	2020-03-15	Denita Gerhold	denita.gerhold@geemail.com	New York	New York	3471553053711620	ef34244fb1d96124fa32fc0f1b5e6f8c	JCB 16 digit	40.6874749245345555	-73.9614263768669247
15793	2020-03-15 10:34:47	2020-03-15	Rene Durgan	rene.durgan@warmmail.com	San Francisco	California	3409891379169355	b508ffa676afbea4005e8635cd11b116	Mastercard	37.7760250959679595	-122.423364353565347
15794	2020-03-15 11:03:58	2020-03-15	Shamika Grant DVM	shamika.grant.dvm@warmmail.com	Oakland	California	3796028104554627	1a344cf47a342e0a1b3a16b9486e893f	Discover	37.7934900156995752	-122.240622293031592
15795	2020-03-15 11:11:11	2020-03-15	Mikeal Dickinson	mikeal.dickinson@geemail.com	San Francisco	California	3466090548723461	84a163756452159b747dcbdb627e95ef	Maestro	37.7862143066604403	-122.440079577790641
15796	2020-03-15 11:18:50	2020-03-15	Miss Fannie Kulas DDS	miss.fannie.kulas.dds@geemail.com	Cape Coral	Florida	4763197003942175	d70febdbb4407d555df801242af59426	VISA 16 digit	26.6719084654439236	-81.9826746755350371
15797	2020-03-15 11:29:37	2020-03-15	Juana Brekke-Homenick	juana.brekke.homenick@geemail.com	San Francisco	California	180024895435208009	c9118ec744b8f18bdfa18d940526a142	VISA 16 digit	37.7494175482703511	-122.409026181150438
15798	2020-03-15 11:33:24	2020-03-15	Jayleen Lesch PhD	jayleen.lesch.phd@geemail.com	San Francisco	California	6011386122169661572	b2797f6f19ac198bfb2b0d7455ee4eed	Discover	37.7743473806438814	-122.445960352811241
15799	2020-03-15 11:45:10	2020-03-15	Gilmer Davis	gilmer.davis@woohoo.com	Tulsa	Oklahoma	4772240021552565	6b2639dd90a58daefb02851a9c425257	VISA 16 digit	36.1762165524899899	-95.9689924651246429
15800	2020-03-15 11:46:33	2020-03-15	Jana Kuphal	jana.kuphal@geemail.com	Oakland	California	3096717023098886712	0322419a4b37d8b722b0ea8353b86f20	Diners Club / Carte Blanche	37.816946471248869	-122.267662279273694
15801	2020-03-15 12:57:26	2020-03-15	Trenten Larkin	trenten.larkin@geemail.com	Greensboro	North Carolina	3088707969976611857	dddd1e053e7740b67ad87717c0fa6c3e	VISA 16 digit	36.1944593062739841	-79.8526344906054391
15802	2020-03-15 13:11:44	2020-03-15	Miss Rosemarie Bergnaum	miss.rosemarie.bergnaum@warmmail.com	San Francisco	California	4888458152308281	39fd8c0d9f0dd0807e603d1e113598a6	VISA 16 digit	37.7894265419128104	-122.414845259435779
15803	2020-03-15 13:16:07	2020-03-15	Ms. Gina Aufderhar	ms.gina.aufderhar@geemail.com	San Francisco	California	3158185205629260946	b5603ace0a63b939344eaba32d92d99b	JCB 15 digit	37.8012577437731778	-122.417828408696195
15804	2020-03-15 13:20:06	2020-03-15	Pamelia Kub PhD	pamelia.kub.phd@warmmail.com	Honolulu	Hawaii	52691402700042346	583e1716ed6b5fc16b93cce371f58be4	JCB 15 digit	21.3911539113830784	-157.863990691930439
15805	2020-03-15 13:20:42	2020-03-15	Mr. Brett Lang	mr.brett.lang@woohoo.com	Austin	Texas	180012186660167902	d83e94bda8ae146e8c0011db7a058c84	Mastercard	30.3140427366957041	-97.6620458045281481
15806	2020-03-15 13:26:15	2020-03-15	Marques O'Keefe	marques.o'keefe@woohoo.com	Houston	Texas	3006080270792217	172b5b70c9e7da14718a6b2aeec4dbec	Discover	29.750777258452402	-95.4156977789025831
15807	2020-03-15 13:31:06	2020-03-15	Mr. Baron Kemmer	mr.baron.kemmer@warmmail.com	Tulsa	Oklahoma	3467537956959572	f9131bb6c1fc1901c93e93155a566298	Mastercard	36.0737813077770113	-95.8629122365221349
15808	2020-03-15 13:34:45	2020-03-15	Elmore Bradtke Sr.	elmore.bradtke.sr.@geemail.com	Mesa	Arizona	676357483105342	afa31840e1c1ebdd9f4313d058c16fb8	Discover	33.4113324557576306	-111.692771039053426
15809	2020-03-15 13:37:16	2020-03-15	Jacques Fritsch	jacques.fritsch@geemail.com	Atlanta	Georgia	869952192201393727	af3366691aec883f7135df05dc166617	JCB 16 digit	33.700890373326466	-84.3729163276076406
15810	2020-03-15 13:38:37	2020-03-15	Gerri Bosco	gerri.bosco@geemail.com	Boise	Idaho	55332438154682042	30c26d48872e4c6b87b360c18163936f	Mastercard	43.5956360009636725	-116.309274895555163
15811	2020-03-15 13:41:38	2020-03-15	Leland Walker Jr.	leland.walker.jr.@geemail.com	Laredo	Texas	3096291522302587762	95e74a50fcee692d809375a73e9e58d8	JCB 16 digit	27.655416753487291	-99.5873433411128843
15812	2020-03-15 13:54:21	2020-03-15	Deirdre Bartell	deirdre.bartell@geemail.com	San Antonio	Texas	4223737819993179	d184d2ccbfa7c7d4f8feb227a5196687	Voyager	29.5274257539376634	-98.4290782645180826
15813	2020-03-15 14:03:25	2020-03-15	Cayden Hamill-Pfeffer	cayden.hamill.pfeffer@geemail.com	Phoenix	Arizona	4762574841777321	5db7cbc6c6ea0ae541c2aaaaedb5d02c	VISA 16 digit	33.6551288126435182	-112.163782291992021
15814	2020-03-15 14:04:32	2020-03-15	Aidyn Gorczany	aidyn.gorczany@geemail.com	Colorado Springs	Colorado	060404513389330	65941c88f8e635468e32d5e41b3f941a	Voyager	38.8481403140399593	-104.728574132189905
15815	2020-03-15 14:06:24	2020-03-15	Camisha Lueilwitz-Watsica	camisha.lueilwitz.watsica@warmmail.com	San Francisco	California	4343516657215050	4810390bc634d53667c0bdfb0732dd25	JCB 15 digit	37.7819360047800075	-122.431677383788909
15816	2020-03-15 14:40:34	2020-03-15	Dr. Lance Strosin DVM	dr.lance.strosin.dvm@woohoo.com	Oakland	California	869936795356532864	4b7937467fd90e0283c9641d2f662e9e	JCB 16 digit	37.8447710149183365	-122.289033349474053
15817	2020-03-15 14:43:34	2020-03-15	Mariam Schroeder	mariam.schroeder@warmmail.com	San Francisco	California	3158517523503585611	0885f191c3524a562ef4ea449c2275d9	Maestro	37.7593679761788934	-122.4129688826837
15818	2020-03-15 15:02:32	2020-03-15	Myer Konopelski-Ruecker	myer.konopelski.ruecker@geemail.com	San Francisco	California	3158382695850137915	5ee25d179cd5d18098600b6a704f3684	JCB 15 digit	37.7796258690217428	-122.404749853861105
15819	2020-03-15 15:08:49	2020-03-15	Dr. Michaela Spinka DDS	dr.michaela.spinka.dds@geemail.com	Virginia Beach	Virginia	4201564619595129	50715b015bb772e0ad9a6d260d8949ba	Maestro	36.8161337962560395	-76.089269500192998
15820	2020-03-15 15:43:03	2020-03-15	Hobert Schumm	hobert.schumm@geemail.com	Chesapeake	Virginia	6011182822784501709	bd7832c3985821a4ae562436ae26f80f	Mastercard	36.6042369148466733	-76.3962525833707247
15821	2020-03-15 16:08:25	2020-03-15	Guilford O'Keefe	guilford.o'keefe@geemail.com	Houston	Texas	4107792075925986	59dcdb00f105dc84e79c2b8b192b3e89	American Express	29.8497319595035151	-95.3006468443680603
15822	2020-03-15 16:28:07	2020-03-15	Alverda Skiles	alverda.skiles@warmmail.com	Palm Bay	Florida	3049842159622337	5147e60a7e5ee53355361da5fbbed872	Voyager	28.0152749080065639	-80.7290979072753316
15823	2020-03-15 16:37:00	2020-03-15	Mallorie Powlowski	mallorie.powlowski@geemail.com	Pittsburgh	Pennsylvania	869925470525912719	aa9c59938442aad42ef3adcb9b472166	VISA 13 digit	40.4960037224415643	-79.9025144220501176
15824	2020-03-15 16:52:43	2020-03-15	Orilla Vandervort	orilla.vandervort@geemail.com	Hialeah	Florida	6011532099169104972	b05ce0681501d6c732930fafa28f7ad9	JCB 16 digit	25.8793432242680339	-80.309495994811499
15825	2020-03-15 16:56:58	2020-03-15	Donavon Marvin	donavon.marvin@woohoo.com	Round Rock	Texas	3088384877229887952	ebeb4cb4644b4c41199929ee147ba407	VISA 13 digit	30.4745747759144763	-97.7062935557998742
15826	2020-03-15 17:07:50	2020-03-15	Caitlin Jast-Boyle	caitlin.jast.boyle@geemail.com	San Francisco	California	210005050585887045	cabd33d5c63861cbfc3417a0ce3c1285	Discover	37.7715645102901547	-122.433868458865589
15827	2020-03-15 17:07:58	2020-03-15	Davion Bahringer	davion.bahringer@geemail.com	San Francisco	California	51834436577551649	8a8ccb7e8d73a742a2ed73feec6f9019	Diners Club / Carte Blanche	37.7871445714281649	-122.449372945330623
15828	2020-03-15 17:14:07	2020-03-15	Asher Metz-Bogisich	asher.metz.bogisich@woohoo.com	Sunnyvale	California	3112289487802101072	c8b4489b1b3b44ad9195db64dae69dbf	VISA 13 digit	37.4616000244386527	-121.934934375734258
15829	2020-03-15 17:15:26	2020-03-15	Mr. Stephan Kozey	mr.stephan.kozey@woohoo.com	San Francisco	California	869945520988070250	9095a81b93c340c855fdffedb8816009	Diners Club / Carte Blanche	37.7712491940054775	-122.446698231476319
15830	2020-03-15 17:53:55	2020-03-15	Agness Wuckert DDS	agness.wuckert.dds@geemail.com	San Angelo	Texas	869976759622896447	37b96754e8e39ddb57fb1561f56a7aa1	Voyager	31.3695053569193902	-100.50275508501754
15831	2020-03-15 18:12:57	2020-03-15	Felice Hauck	felice.hauck@woohoo.com	Scottsdale	Arizona	3059319457236045	a515fa70c777e88b7c7faafafc722e10	JCB 16 digit	33.733208575624225	-111.843558505406975
15832	2020-03-15 18:29:43	2020-03-15	Reggie Kreiger	reggie.kreiger@woohoo.com	Chicago	Illinois	6011694606942608535	1fd042823a2d5c890fc2b78e600adf29	JCB 15 digit	41.7407511259265291	-87.7598678273178621
15833	2020-03-15 19:03:21	2020-03-15	Annemarie Pagac	annemarie.pagac@warmmail.com	San Diego	California	3096638565892144645	4e2250a88ca9f1bcca97c45470a58260	American Express	32.8037214890655164	-117.096308844294398
15834	2020-03-15 19:18:42	2020-03-15	Landin Walter	landin.walter@geemail.com	Charlotte	North Carolina	4348520049225	83360117802f3cff80f9317f276e491c	American Express	35.227420498130094	-80.8447124636210503
15835	2020-03-15 19:22:05	2020-03-15	Dr. Jay Rosenbaum MD	dr.jay.rosenbaum.md@geemail.com	New York	New York	869971344029616824	3ea1d37c1c6cd71ead1e574ba3be068d	American Express	40.6083657875880562	-74.026193210565296
15836	2020-03-15 19:27:26	2020-03-15	Elva Aufderhar	elva.aufderhar@warmmail.com	Los Angeles	California	4801879680617915	d0adf933873b9cc45161dd0b64ca2761	JCB 16 digit	33.9852893547952135	-118.353182144602016
15837	2020-03-15 19:35:56	2020-03-15	Jaslene Emard	jaslene.emard@geemail.com	Augusta	Georgia	3088276026965568340	33d904ff7fba6ff3bb54c5fa8a4b6a2c	VISA 16 digit	33.3887182582840296	-82.117352846387405
15838	2020-03-15 19:39:27	2020-03-15	Manley Morissette	manley.morissette@geemail.com	Portland	Oregon	6011007560780509937	25e9239524ca8f631562a4948a1308c8	VISA 16 digit	45.4638541438039354	-122.71557583543472
15839	2020-03-15 19:50:56	2020-03-15	Dr. Chuck Greenfelder	dr.chuck.greenfelder@woohoo.com	Portland	Oregon	639085844709346	85301f2c5b1b4ad0377afe08196bfbe4	American Express	45.4877563314400604	-122.582327361311769
15840	2020-03-15 20:08:53	2020-03-15	Sarai Ortiz	sarai.ortiz@woohoo.com	Hillsboro	Oregon	3088450509741123728	a848ac2aa3980439c84a381b0f6597dc	Voyager	45.5682048855088624	-122.883945709063482
15841	2020-03-15 20:09:06	2020-03-15	Donn Kutch	donn.kutch@geemail.com	College Station	Texas	4005368538805793	05f7172ab31849903c30d0481651746f	JCB 16 digit	30.5079251740638178	-96.2019911066010707
15842	2020-03-15 20:11:15	2020-03-15	Aniya Spencer	aniya.spencer@geemail.com	San Diego	California	6011477802850101026	1fa0f89336b187ab4a641a6a2ae0eb66	VISA 13 digit	32.8002336163140811	-117.145871550440788
15843	2020-03-15 20:25:19	2020-03-15	Clotilde Waelchi	clotilde.waelchi@geemail.com	Santa Rosa	California	6011502141614324247	d37477c7ead02e047688e6b14d70589d	VISA 16 digit	38.3965034613974439	-122.799181864714626
15844	2020-03-15 20:27:25	2020-03-15	Frederica Tremblay-Torphy	frederica.tremblay.torphy@geemail.com	Omaha	Nebraska	6011040551775843760	715ed4b7903bbd12334c0b0cf3d467fd	JCB 15 digit	41.3155897438205812	-95.9986921115428231
15845	2020-03-15 20:34:22	2020-03-15	Ana Gusikowski DVM	ana.gusikowski.dvm@warmmail.com	Philadelphia	Pennsylvania	3034919344005274	631e898b9879e9c292a7cb78add4c193	Voyager	39.9850781619507814	-75.2060009383495895
15846	2020-03-15 20:46:21	2020-03-15	Dr. Khalil Lakin Sr.	dr.khalil.lakin.sr.@geemail.com	Davenport	Iowa	4817768654976740	3b61b3d1d03871b81f6d6360bdea7c72	JCB 16 digit	41.5455502490311872	-90.6318381069190764
15847	2020-03-15 21:29:30	2020-03-15	Demarion Stamm	demarion.stamm@warmmail.com	Oakland	California	869911564875126114	6272cd6e4490b77d981e481e712f8cb7	Voyager	37.795764948432172	-122.276558016378615
15848	2020-03-15 21:44:00	2020-03-15	Elisabeth Lesch	elisabeth.lesch@geemail.com	North Las Vegas	Nevada	3005206152534440	6cbbcd60cf3171613e4147cd22f0219f	Maestro	36.2569864434812175	-115.103721574203675
15849	2020-03-15 22:30:56	2020-03-15	Macey Kub-Carroll	macey.kub.carroll@geemail.com	Temecula	California	4676153229662069	0a790da7bda7acc17f293a5cd27e149a	Mastercard	33.4718873492576137	-117.045460911906133
15850	2020-03-15 22:44:47	2020-03-15	Mackenzie Kuhic	mackenzie.kuhic@geemail.com	Frisco	Texas	4183421808019	46b6afab1b8c7fb882e5212cc7653ef8	JCB 16 digit	33.1184978328641506	-96.7297664327755484
15851	2020-03-15 22:59:24	2020-03-15	Sister Jaskolski-Gleichner	sister.jaskolski.gleichner@geemail.com	Oakland	California	3158037185920967664	df14b30a33338bc8921a48a7217000da	JCB 16 digit	37.7988763158287568	-122.260298224623014
15852	2020-03-15 23:42:19	2020-03-15	Mr. Randolf Hermann IV	mr.randolf.hermann.iv@geemail.com	Saint Paul	Minnesota	3032088764122183	c036c69eb058b57a78a8d3fa031559a6	VISA 16 digit	44.9636822990082194	-93.1973057519908963
15853	2020-03-15 23:45:54	2020-03-15	Cecily Murazik	cecily.murazik@geemail.com	Austin	Texas	3096139680748947630	62eda1a8a1947f4fde9dd2c0b2d0e812	JCB 15 digit	30.3792049430437388	-97.7556703624554046
15854	2020-03-15 23:57:20	2020-03-15	Selene Breitenberg	selene.breitenberg@woohoo.com	San Francisco	California	52636600379598211	c6b37ee53e014f88d3c5df91b685c35d	Voyager	37.8033407376133468	-122.448688770727699
15855	2020-03-16 00:24:50	2020-03-16	Orvil Kuhn	orvil.kuhn@warmmail.com	Lexington	Kentucky	3056950705024388	e3f347d55ad2da2878f4b4e055b53c8d	VISA 13 digit	38.0512036929715407	-84.4065990636490255
15856	2020-03-16 00:30:02	2020-03-16	Berniece Prosacco PhD	berniece.prosacco.phd@geemail.com	San Francisco	California	869917306319516482	8a0b1acffaba34fae6dd7cfc3ab561a9	VISA 13 digit	37.776868427209024	-122.45476157496924
15857	2020-03-16 00:32:32	2020-03-16	Esperanza Murphy	esperanza.murphy@geemail.com	Pittsburgh	Pennsylvania	4460072789182450	a4104ed3eb672327cbf6e1ed8e8458ae	VISA 13 digit	40.3531742197416676	-79.9698617775164564
15858	2020-03-16 00:38:34	2020-03-16	Inell Mann	inell.mann@geemail.com	Portland	Oregon	4628267922837	573a360767c2f387b49431e49c95810e	JCB 16 digit	45.589316917246208	-122.707125655841082
15859	2020-03-16 00:40:26	2020-03-16	Celestia Bradtke	celestia.bradtke@geemail.com	Clarksville	Tennessee	4947273003022	f4f83db0a7caa894ca920b06ed3b7eb8	VISA 13 digit	36.479813339154795	-87.2899453833185248
15860	2020-03-16 01:01:18	2020-03-16	Rudolfo Dibbert	rudolfo.dibbert@woohoo.com	Fort Worth	Texas	55434054785988026	187693e99f82d500cdd92a9ce6e41070	Diners Club / Carte Blanche	32.853689052496108	-97.428777558245514
15861	2020-03-16 01:06:47	2020-03-16	Lenore Schaden DVM	lenore.schaden.dvm@geemail.com	Los Angeles	California	3337785492497442954	7e1258c5d0ccb5e174fe3bcee757aa26	VISA 16 digit	33.9196246227115381	-118.331534248310319
15862	2020-03-16 01:15:28	2020-03-16	Tonya Toy-Rippin	tonya.toy.rippin@warmmail.com	San Francisco	California	3528223454627549264	9cdc8fd64b07c64fef601e9c30d3e4aa	Maestro	37.7411259606670271	-122.40788771784915
15863	2020-03-16 01:28:24	2020-03-16	Frieda Parisian-Runte	frieda.parisian.runte@geemail.com	Chesapeake	Virginia	4430288562354242	493fdd48c530725e79552c6f7266ec5c	Discover	36.7242779015801872	-76.366968338082728
15864	2020-03-16 01:41:31	2020-03-16	Brittnee Purdy	brittnee.purdy@geemail.com	San Francisco	California	3478486435622996	c10411aaa1c526ed6f8997913d529167	Discover	37.7834880801828419	-122.450751069758354
15865	2020-03-16 01:48:46	2020-03-16	Ms. Amalie Johnson DVM	ms.amalie.johnson.dvm@geemail.com	Charlotte	North Carolina	4224811953782927	3ea738073598952eccc8db467d3d8f71	VISA 16 digit	35.2438642873216423	-80.8745325697064459
15866	2020-03-16 02:03:22	2020-03-16	Lilyan Schultz-Jacobs	lilyan.schultz.jacobs@geemail.com	San Francisco	California	3112192573692167426	abb272d05c157eaa9ed261d8c1ab253a	Diners Club / Carte Blanche	37.7734616250254049	-122.426238520563928
15867	2020-03-16 02:16:55	2020-03-16	Zed Walter-Hoeger	zed.walter.hoeger@geemail.com	Hialeah	Florida	180005259082954873	f12572b97feb909c228602536a996efb	Discover	25.8476513268869397	-80.2608200841020789
15868	2020-03-16 02:17:00	2020-03-16	Jerald Hintz	jerald.hintz@geemail.com	Reno	Nevada	3528488855034728038	3a53e2ba438e5389bb1d9c548865bccd	Discover	39.587928952563928	-119.769092886957907
15869	2020-03-16 02:23:01	2020-03-16	Irven Hilll	irven.hilll@geemail.com	Oakland	California	4643897625819455	1139ad097dd12349689ba96bbea832a1	American Express	37.8019192052231503	-122.276780088883243
15870	2020-03-16 02:24:02	2020-03-16	Joselin Halvorson DDS	joselin.halvorson.dds@woohoo.com	Berkeley	California	55017972463036138	5acfd380fd96cc56f52fe9ffe0683ed9	Voyager	37.8528756501789587	-122.297761268897219
15871	2020-03-16 02:24:33	2020-03-16	Bobbi Franecki	bobbi.franecki@geemail.com	Houston	Texas	4937363493142	133c85e28ee5c56d71da5ef8fb6fe4ee	JCB 16 digit	29.7450196463692933	-95.4135994399447043
15872	2020-03-16 02:27:57	2020-03-16	Algernon Gerlach	algernon.gerlach@geemail.com	Tallahassee	Florida	3158678236882118707	e22a3fb8c20cca44058886b1f3fe4dae	VISA 16 digit	30.3576409794878224	-84.2652773156777073
15873	2020-03-16 02:47:21	2020-03-16	Lorena Ziemann PhD	lorena.ziemann.phd@geemail.com	Oakland	California	3018405481584970	371c224b7424cd47f23e8773770862a1	JCB 16 digit	37.7866719833557951	-122.281682539734206
15874	2020-03-16 02:58:15	2020-03-16	Samir Reinger	samir.reinger@geemail.com	Cedar Rapids	Iowa	3158465881347573546	e4a75fd832ef80770de0a2d66c222304	American Express	41.9680924031957971	-91.6536399964775939
15875	2020-03-16 03:13:40	2020-03-16	Dr. Azariah Ferry	dr.azariah.ferry@geemail.com	Greensboro	North Carolina	4728093801648805	791fd9897d18ef5eed447f89c397563c	Discover	36.0889908874522902	-79.858887023383744
15876	2020-03-16 03:27:43	2020-03-16	Eryn Franecki	eryn.franecki@woohoo.com	Mesquite	Texas	3044425292258238	ba1c9ca1fec0e1f29867e3572b9e989c	Voyager	32.6762619229774955	-96.5794444879714433
15877	2020-03-16 03:55:09	2020-03-16	Mareli Murphy	mareli.murphy@woohoo.com	New York	New York	4276114515907	a18d6433695e1c9fb575c04f0db4a75c	JCB 16 digit	40.7021257567442944	-73.9408761305164575
15878	2020-03-16 03:57:17	2020-03-16	Donta Altenwerth	donta.altenwerth@geemail.com	Costa Mesa	California	55840560069746623	8c788038387ba0c125efbab8accdef98	VISA 16 digit	33.6490303087528773	-117.889196439678969
15879	2020-03-16 04:06:23	2020-03-16	Wardell Bergnaum	wardell.bergnaum@geemail.com	Los Angeles	California	4771894110548883	f5c66657c4166775cb64a21069e4dda7	Discover	34.0344132677517806	-118.464418705598632
15880	2020-03-16 04:09:26	2020-03-16	Anissa Welch	anissa.welch@geemail.com	Oakland	California	54199862157637855	4e7bdc47d1bb86b4cd32579b8d2dde77	VISA 16 digit	37.8302937948375444	-122.263360573671761
15881	2020-03-16 04:27:39	2020-03-16	Mrs. Suzann Kemmer DDS	mrs.suzann.kemmer.dds@warmmail.com	Nashville	Tennessee	4131115892317775	af86cc55b2901426b1f491b3b7557ce7	VISA 16 digit	36.2358849827788774	-86.7872711738943963
15882	2020-03-16 04:36:18	2020-03-16	Elvira Kassulke	elvira.kassulke@warmmail.com	Los Angeles	California	3749522277730947	b0ca1d8a030ac115d88505d3c0b1c706	JCB 15 digit	33.9448578526597444	-118.459523877547298
15883	2020-03-16 04:40:12	2020-03-16	Karlene Little	karlene.little@woohoo.com	Oakland	California	4058198568765104	57dbe6955fa81e66e09c1a4231f77575	Diners Club / Carte Blanche	37.7965709567549766	-122.239507655050204
15884	2020-03-16 04:53:44	2020-03-16	Alize Upton	alize.upton@geemail.com	Philadelphia	Pennsylvania	6011018101404805083	3d33927adc3266e1b6f97cb9a510eb82	JCB 15 digit	40.0993709710385673	-75.1379224236488454
15885	2020-03-16 05:05:38	2020-03-16	Danae Borer	danae.borer@geemail.com	Modesto	California	6011288384263601560	40526e3cb4d868ca560c94a022473ba5	VISA 16 digit	37.5429531246423736	-120.957979044618085
15886	2020-03-16 05:12:11	2020-03-16	Christopher Morar	christopher.morar@geemail.com	Boston	Massachusetts	3455842682635833	701123057fb8f4c31d9af9c5bbd0665b	Diners Club / Carte Blanche	42.4084673292171246	-71.0873725993510419
15887	2020-03-16 05:14:40	2020-03-16	Willie DuBuque-Wolf	willie.dubuque.wolf@geemail.com	New York	New York	3088452569044743042	b2f07494180241ed8058da0a14243f27	VISA 13 digit	40.6066905194185637	-73.9273724904645206
15888	2020-03-16 05:24:16	2020-03-16	Dr. Cornell Kerluke V	dr.cornell.kerluke.v@geemail.com	New Haven	Connecticut	3001018537151905	6c3beeb566074d35dfdf2671465debb2	JCB 16 digit	41.3135707805857066	-72.8268820082303137
15889	2020-03-16 05:39:21	2020-03-16	Kaaren O'Reilly	kaaren.o'reilly@geemail.com	Houston	Texas	180019882165538885	b94b70f40feb5192f36b1256800e8e70	VISA 16 digit	29.7763469215095036	-95.425937504835062
15890	2020-03-16 05:42:39	2020-03-16	Mr. Bronson Jakubowski Jr.	mr.bronson.jakubowski.jr.@woohoo.com	Chicago	Illinois	3751116012454726	25c961c4b489e1abf6ed4bd0405de27c	Discover	41.7641527125447993	-87.6993879189744518
15891	2020-03-16 05:45:00	2020-03-16	Mr. Amerigo West	mr.amerigo.west@geemail.com	Oakland	California	52138518460335538	92a8cbc1d239e3fb58617c4adf4ef19d	VISA 16 digit	37.8067227759965476	-122.257999651375613
15892	2020-03-16 05:51:36	2020-03-16	Moesha Jakubowski-Ondricka	moesha.jakubowski.ondricka@geemail.com	Tulsa	Oklahoma	4994462682929799	d5c2fb7fabe7f3e88de2aa7f8a7d9f6f	Discover	36.0710694051250798	-95.9871909338470459
15893	2020-03-16 05:57:36	2020-03-16	Killian Hegmann	killian.hegmann@warmmail.com	New York	New York	4746775168568	7df4865e7c5b7ce9f84e545956e8cd37	Voyager	40.6138126269672028	-73.9517238622892563
15894	2020-03-16 05:57:48	2020-03-16	Mrs. Aurelia Bailey	mrs.aurelia.bailey@geemail.com	Chula Vista	California	4401036604150135	487e72aebfd462aa22008a6bcd27b7a2	JCB 16 digit	32.5476604324996472	-116.986696941335495
15895	2020-03-16 06:32:41	2020-03-16	Mr. Orla Lemke	mr.orla.lemke@geemail.com	Indianapolis	Indiana	3112204471845357729	482911d4065bd5343a98972fa4de77b5	Mastercard	39.8552727945156349	-86.0899954928286348
15896	2020-03-16 06:36:13	2020-03-16	Jade Rice	jade.rice@geemail.com	Milwaukee	Wisconsin	869949684700438330	d3b476cd97673eefe7e4f2a563ec661d	American Express	42.9956460401967178	-87.977223273330182
15897	2020-03-16 07:00:37	2020-03-16	Aarav Abernathy-Cassin	aarav.abernathy.cassin@warmmail.com	Wichita	Kansas	180090209329091340	784f283899f8848573feeddfdf3c2f61	Discover	37.7463419427506608	-97.3270923579778469
15898	2020-03-16 07:02:27	2020-03-16	Kole Nienow	kole.nienow@geemail.com	Dallas	Texas	4146915310708163	0bc2b18c5916616af842142df52426b1	VISA 16 digit	32.7792897479414975	-96.6748284790161989
15899	2020-03-16 07:12:28	2020-03-16	Dr. Trevon Vandervort	dr.trevon.vandervort@geemail.com	Carrollton	Texas	3337680095105558883	8030f8d9f5baeb08e6387137fc99e7cd	VISA 16 digit	32.9041328771892907	-96.8136747308868877
15900	2020-03-16 07:17:39	2020-03-16	Dr. Jennette Rosenbaum	dr.jennette.rosenbaum@geemail.com	New York	New York	4964524134324	7c1ba12bc9343d1bb748d230b1799914	Discover	40.6198498453237136	-74.0204433932796064
15901	2020-03-16 07:38:00	2020-03-16	Enriqueta Breitenberg	enriqueta.breitenberg@warmmail.com	Columbus	Ohio	3778881821804168	eac223f4d546ac3e4f43a70983b932d8	Mastercard	39.9832300894472752	-83.0103530683789472
15902	2020-03-16 08:08:08	2020-03-16	Denzel Stamm	denzel.stamm@geemail.com	Hialeah	Florida	4241065271072250	38b87919ed3a727f5a00f156f0661ed6	JCB 15 digit	25.9151210031449821	-80.2667958306051759
15903	2020-03-16 08:11:28	2020-03-16	Mr. General Ernser	mr.general.ernser@woohoo.com	Santa Ana	California	4780101846035	5532668483c2797c9ebd6ac74f54bab4	Mastercard	33.8293425189901171	-117.818255471337579
15904	2020-03-16 08:13:48	2020-03-16	Urijah Walker	urijah.walker@warmmail.com	San Francisco	California	3096086461312196752	ec192d597cbb91ed64ecbbed3cf90926	Discover	37.7925067596596662	-122.463354815142139
15905	2020-03-16 08:32:39	2020-03-16	Dominga Wilderman	dominga.wilderman@geemail.com	Berkeley	California	869983727827136076	b283008ff796c146ed9d8215bc9ff31c	Diners Club / Carte Blanche	37.8932954864558766	-122.272804948120339
15906	2020-03-16 08:37:13	2020-03-16	Mrs. Shea Wisozk	mrs.shea.wisozk@geemail.com	Washington	District of Columbia	3028762907230830	315a8a674f0269a3d7e9fd76b6470608	Maestro	38.8347767883710588	-77.0910355007488306
15907	2020-03-16 08:38:25	2020-03-16	Enrique Deckow	enrique.deckow@geemail.com	San Francisco	California	6011680345953257678	a2401cd7616720805899b8d3e399c9f9	Discover	37.8124400452609066	-122.462544027883979
15908	2020-03-16 09:00:07	2020-03-16	Hilario Gutmann	hilario.gutmann@warmmail.com	Rochester	Minnesota	4037681420962692	a9d992592e8d1a1b6a5d191d08ee258a	Mastercard	43.9386080768793832	-92.379496372689303
15909	2020-03-16 09:17:02	2020-03-16	Mr. Trae Wiza III	mr.trae.wiza.iii@geemail.com	Palmdale	California	3088534844499924732	0aadb37637b577f548f62f24c161daa6	JCB 16 digit	34.6774317134954018	-118.050474983453384
15910	2020-03-16 09:39:49	2020-03-16	Lavera Pfeffer	lavera.pfeffer@woohoo.com	San Francisco	California	3528209580649642279	7862357a345b2011102ceac3b720bcf9	VISA 16 digit	37.7785452222523404	-122.470654947642544
15911	2020-03-16 09:40:09	2020-03-16	Joella Gutkowski DDS	joella.gutkowski.dds@woohoo.com	Portland	Oregon	503892594373190	ec6a356b05e9bafe37ca0f0085ad8a92	VISA 13 digit	45.564427859418096	-122.589729959564295
15912	2020-03-16 09:49:39	2020-03-16	Kala Corwin-Rempel	kala.corwin.rempel@geemail.com	Roseville	California	3011432415617830	7f43321ab5506341429c499fb65cbfaa	JCB 15 digit	38.7082233269754781	-121.396532845798504
15913	2020-03-16 09:52:23	2020-03-16	Lucien Bins	lucien.bins@geemail.com	San Francisco	California	3770471919052892	b0fadd10fd7756c2cc0171a161998101	Maestro	37.7565338866885725	-122.44657118919865
15914	2020-03-16 09:54:24	2020-03-16	Merri Walter	merri.walter@geemail.com	New York	New York	3041280651650647	bb8d65abfc6d74682630b2eb4007e948	Mastercard	40.678526447921989	-74.0078793899051846
15915	2020-03-16 10:16:39	2020-03-16	Milda Gutkowski	milda.gutkowski@geemail.com	Syracuse	New York	4008654351115411	dfc170233f521610edc5127f5e8f0ed9	American Express	43.1095100079979687	-76.2283853561397677
15916	2020-03-16 10:27:48	2020-03-16	Carmen Lakin-Schuppe	carmen.lakin.schuppe@geemail.com	Louisville	Kentucky	3096766233806712668	36069376714d178640475c3630931e04	JCB 15 digit	38.1554368372444017	-85.7016433009948599
15917	2020-03-16 10:30:35	2020-03-16	Lovey Larson-Weber	lovey.larson.weber@geemail.com	El Cajon	California	4711221990668	2de994c60a5f52b93e20d3bc44bacde1	Voyager	32.8049766291405973	-116.873859397293629
15918	2020-03-16 10:37:43	2020-03-16	Dr. Kolten Schiller	dr.kolten.schiller@geemail.com	San Jose	California	503893211162164	70a20a365e451ba03e74f120767bd42b	American Express	37.2698459099333732	-121.872884626010062
15919	2020-03-16 10:39:53	2020-03-16	Dr. Fernand Willms DDS	dr.fernand.willms.dds@geemail.com	New York	New York	3158917210447173987	ebcefb07d8c17938201436be91132380	VISA 13 digit	40.602843286072833	-73.900739256794381
15920	2020-03-16 10:41:40	2020-03-16	Graciela Kutch	graciela.kutch@geemail.com	Amarillo	Texas	55338793384117688	135ba4a847d8f936b5ab348286684318	Voyager	35.1747427760321614	-101.745535008502017
15921	2020-03-16 11:03:53	2020-03-16	Mr. Mervin Denesik	mr.mervin.denesik@geemail.com	Oakland	California	4773978128715432	f11c061282510bd39417c0723781cc01	JCB 15 digit	37.7951495238650637	-122.294297535505493
15922	2020-03-16 11:07:41	2020-03-16	Chynna Rau	chynna.rau@warmmail.com	Columbus	Ohio	869947258265971654	b7da9f2a2c48bf249c617c9a623af6f3	Maestro	39.9069444283887762	-83.0736231704477319
15923	2020-03-16 11:56:13	2020-03-16	Calvin DuBuque-Collins	calvin.dubuque.collins@warmmail.com	Wilmington	North Carolina	4469240877396	555225af4397e89ca3ab7ca104dcf00f	Mastercard	34.187014198145647	-77.9479939487755331
15924	2020-03-16 12:05:45	2020-03-16	Krystin Mitchell-Denesik	krystin.mitchell.denesik@woohoo.com	Louisville	Kentucky	6011077873755449319	f6565b0d817f137f6baa95c479a53c4b	Maestro	38.2580001543644812	-85.6589057566668828
15925	2020-03-16 12:07:03	2020-03-16	Juliet Nikolaus	juliet.nikolaus@woohoo.com	Mobile	Alabama	869940277262209006	bd4c0a20d9ea77ad576756978c66f6d6	Mastercard	30.6953113382324574	-88.1162940165631454
15926	2020-03-16 12:34:53	2020-03-16	Rice Bailey Sr.	rice.bailey.sr.@geemail.com	San Francisco	California	4815970274206	2cc06e5d7123f90630e5c3484361cbdc	Discover	37.7860454736881124	-122.420393009776191
15927	2020-03-16 12:46:33	2020-03-16	Domenico Nitzsche	domenico.nitzsche@geemail.com	New York	New York	4741220542142508	f93cc7a52d04024a5326dc691cd783d4	VISA 16 digit	40.6881521933935559	-73.936528822117296
15928	2020-03-16 13:12:40	2020-03-16	Fredy Schmidt	fredy.schmidt@geemail.com	Chandler	Arizona	869946893099333225	1f0974e4563909a4dab348fcd905463f	VISA 16 digit	33.186954059414191	-111.756068472087009
15929	2020-03-16 13:45:36	2020-03-16	Mandi Mohr-Ritchie	mandi.mohr.ritchie@warmmail.com	San Francisco	California	4482758112106	1846902becd6e450628e19f5a1c4948b	VISA 16 digit	37.7705579045426347	-122.436854036406288
15930	2020-03-16 14:06:43	2020-03-16	Dr. Dakotah Stiedemann	dr.dakotah.stiedemann@warmmail.com	Killeen	Texas	4811307475723	d0d15912413944cabee372df9dc8ee7d	Voyager	31.1284099511567511	-97.6844713323917233
15931	2020-03-16 14:37:45	2020-03-16	Georgina Ruecker	georgina.ruecker@woohoo.com	Houston	Texas	4843573269076	44dbe82b3c6584a8f8be05ba2e6ff960	VISA 13 digit	29.8267699292007826	-95.4443027165733326
15932	2020-03-16 14:52:51	2020-03-16	Luther Welch	luther.welch@geemail.com	Minneapolis	Minnesota	3054856869629072	ed6583d9be341c2f32cb58e9fa193bf9	Diners Club / Carte Blanche	45.0271709504622919	-93.2346368305191362
15933	2020-03-16 15:03:07	2020-03-16	Mr. Marlo Beatty IV	mr.marlo.beatty.iv@geemail.com	Austin	Texas	52040323214434399	d61de17eb000c2f7e89bb8960a1e3f57	VISA 13 digit	30.3787675866052496	-97.6649157041922251
15934	2020-03-16 15:30:04	2020-03-16	Dr. Abdul Dickens PhD	dr.abdul.dickens.phd@geemail.com	Everett	Washington	3034775892458806	1e5c72f0aa1088c59f473bf74400c7c3	Mastercard	47.9643914767898636	-122.169897382719071
15935	2020-03-16 15:36:57	2020-03-16	Dr. Stephan Ortiz	dr.stephan.ortiz@geemail.com	Santa Ana	California	869902088057316344	09a49344f22504f06ede3fc43305a7c2	Maestro	33.7553874894149573	-117.859814872631802
15936	2020-03-16 15:40:14	2020-03-16	Arden Kovacek	arden.kovacek@geemail.com	Toledo	Ohio	561244793419589	1c07bd4db3e94d2f8ba2d476eed4b147	Maestro	41.6077393975745835	-83.6589833360497011
15937	2020-03-16 15:42:19	2020-03-16	Antwan Sanford	antwan.sanford@geemail.com	Tucson	Arizona	3422742317957216	da957432e933fe36b6239eded3ec683f	Mastercard	32.2043547240592574	-110.784501670835908
15938	2020-03-16 15:43:35	2020-03-16	Ms. Karma Blanda PhD	ms.karma.blanda.phd@geemail.com	Tucson	Arizona	4743070972192954	fb3f6df5054b8fdd40d8c2f8c1a90d62	JCB 16 digit	32.053857912034168	-110.875500420270853
15939	2020-03-16 15:44:54	2020-03-16	Nile Torp	nile.torp@warmmail.com	Elgin	Illinois	4667437877224	a5ff6631be3349b6ee3b96158a022eb7	VISA 16 digit	42.0654551098871963	-88.3649229895144828
15940	2020-03-16 15:49:00	2020-03-16	Zenas Mills	zenas.mills@warmmail.com	New York	New York	6011967792693468996	d3c062803b5f4d2572a95bbacf4014a5	Discover	40.7576365157254017	-73.9664563616167783
15941	2020-03-16 16:04:53	2020-03-16	Miss Lilie Huel PhD	miss.lilie.huel.phd@geemail.com	San Francisco	California	3337973156609377752	4aafe6b9693c74714eaedefc41e0dc0e	VISA 16 digit	37.777394730261264	-122.429649444752357
15942	2020-03-16 16:08:06	2020-03-16	Kayli Swaniawski	kayli.swaniawski@geemail.com	Philadelphia	Pennsylvania	3096934524329971865	d6171be3c9069f67d9df8d790f4ced95	American Express	40.029216840905697	-75.0659052754186149
15943	2020-03-16 16:14:56	2020-03-16	Grady Fahey-Denesik	grady.fahey.denesik@geemail.com	Tampa	Florida	55871810964151144	3857d40f08ba85b8e2abaf1f2f7ddbae	American Express	27.8830300006665261	-82.4840653921689722
15944	2020-03-16 16:24:21	2020-03-16	Tobias Zemlak-Ledner	tobias.zemlak.ledner@woohoo.com	Saint Paul	Minnesota	6011352355243341130	79584ea03123f56edbc2714a51d4e203	Diners Club / Carte Blanche	44.9556248499486628	-93.0602091207899207
15945	2020-03-16 16:55:28	2020-03-16	Ms. Demetria Herzog	ms.demetria.herzog@woohoo.com	Springfield	Missouri	3020752672849797	1e6b17d03c02c64b2d0defef772b7fb0	JCB 15 digit	37.283279365367072	-93.2348034861788193
15946	2020-03-16 16:59:31	2020-03-16	Elba Bednar MD	elba.bednar.md@geemail.com	San Bernardino	California	4960609845132089	9a473d229e10e6e4a2a2d20c2f8c5520	Discover	34.1021102356988877	-117.383340389352668
15947	2020-03-16 17:35:50	2020-03-16	Herman Turcotte-Cummings	herman.turcotte.cummings@geemail.com	San Diego	California	3773470305823863	8739dc4a7fb7ed7728b91fc3021e0e62	VISA 16 digit	32.8230334370929739	-117.189517758078878
15948	2020-03-16 17:40:03	2020-03-16	Roddy Collins	roddy.collins@geemail.com	Berkeley	California	4644213192589878	11b4472f39fcca3780fc1313bfa1765c	Mastercard	37.8927987247734777	-122.278466695276805
15949	2020-03-16 17:55:14	2020-03-16	Justice Kozey	justice.kozey@geemail.com	Honolulu	Hawaii	4214993046275911	7edeb8fbcd525d8f51ab78befed564fc	VISA 16 digit	21.4007324181713159	-157.86626851849482
15950	2020-03-16 18:03:57	2020-03-16	Mr. Damond Goyette Jr.	mr.damond.goyette.jr.@warmmail.com	San Francisco	California	4455597904384240	24bec7182fa41ebfe37337fa2cd22901	Mastercard	37.731186372310269	-122.470271901161496
15951	2020-03-16 18:14:09	2020-03-16	Wyman Lang	wyman.lang@geemail.com	Vacaville	California	180045838082517152	6ce94dc2041394bb8819cade2ca10b50	JCB 16 digit	38.4210304855495721	-122.03424683752209
15952	2020-03-16 18:22:32	2020-03-16	Orvin Witting	orvin.witting@warmmail.com	Chicago	Illinois	4537228408549	262ed3caceff3bd0c753dd4cc96de6ee	Discover	41.8379287336789076	-87.7316048476409094
15953	2020-03-16 18:22:53	2020-03-16	Kelis Murray MD	kelis.murray.md@geemail.com	Houston	Texas	4227896496657485	a81e48903b0647f271d3d4b9c35e9513	Voyager	29.8827617535911507	-95.4720457348987424
15954	2020-03-16 19:41:19	2020-03-16	Camila Hamill	camila.hamill@geemail.com	Sunnyvale	California	55005226968654083	3bd0ca1e2a018d6ee04890e47d51ca6d	Discover	37.350246838758892	-121.963860278503233
15955	2020-03-16 19:42:12	2020-03-16	Arnold Botsford	arnold.botsford@woohoo.com	Corona	California	869962519575787217	7c03adee3eab4cf4d8304093bc97cd8d	JCB 16 digit	33.9238389945942913	-117.617028771128503
15956	2020-03-16 20:12:22	2020-03-16	Dr. Oral Abshire	dr.oral.abshire@woohoo.com	San Francisco	California	4288379813285559	b2bd5dc1b30b8b88cb4ccc452238a2ec	Discover	37.8049079263168366	-122.45253627363887
15957	2020-03-16 20:22:32	2020-03-16	Della Hilpert	della.hilpert@warmmail.com	New York	New York	639055028680225	479a2622f664b1a10189c011ca708283	JCB 16 digit	40.6711779937837292	-73.8969984289154382
15958	2020-03-16 20:43:28	2020-03-16	Shanice Schulist	shanice.schulist@geemail.com	Springfield	Missouri	4316598265965	1f42edf9f767906969c505de35f10688	JCB 16 digit	37.1456786082785584	-93.2071533249981741
15959	2020-03-16 21:09:41	2020-03-16	Luisa Lockman	luisa.lockman@geemail.com	Fort Lauderdale	Florida	3158030767799748924	f40cb2466bfa0cec5f46c289486316ba	Mastercard	26.0517507358443012	-80.1191737520795328
15960	2020-03-16 21:13:44	2020-03-16	Rahn Ward	rahn.ward@geemail.com	San Antonio	Texas	3337420995302447324	1979d96a11709db8fb233e5557f42d19	VISA 13 digit	29.423696698581427	-98.5802203027367483
15961	2020-03-16 21:19:07	2020-03-16	Caddie Hilll	caddie.hilll@warmmail.com	San Francisco	California	4219440670285	07d0fb723d410fd0ff792a8ff64bfa80	American Express	37.7734688534729983	-122.448892988210815
15962	2020-03-16 21:22:57	2020-03-16	Mateo Miller III	mateo.miller.iii@geemail.com	Dayton	Ohio	3528317223475681801	969a6d6cff422bc19ea4d9bfa6bf9cbf	VISA 13 digit	39.8769218350551995	-84.1417892287209668
15963	2020-03-16 21:39:25	2020-03-16	Ms. Dorla Donnelly	ms.dorla.donnelly@geemail.com	Baltimore	Maryland	4824776787793271	a99516ffbb9cb45062f20d2989135ef3	Mastercard	39.3539647304452913	-76.5786552941910941
15964	2020-03-16 21:44:25	2020-03-16	Mr. Gifford Nienow V	mr.gifford.nienow.v@woohoo.com	Henderson	Nevada	210015274376470815	5cac46735c7885cf1a50d20db9808a09	VISA 16 digit	36.1013948405094496	-115.074155862086272
15965	2020-03-16 21:51:39	2020-03-16	Shiela Larkin	shiela.larkin@woohoo.com	Bakersfield	California	869957184538173562	7ab0a76f6bbe61c3b53e1f334fcd5ff4	JCB 15 digit	35.2507718471519595	-119.065583668210721
15966	2020-03-16 22:29:28	2020-03-16	Deedee Sporer DDS	deedee.sporer.dds@geemail.com	San Diego	California	180059231613416230	bc220953b0fce27d1dd6c4a617b48915	VISA 13 digit	32.7284749896332627	-117.129966711616149
15967	2020-03-16 22:36:07	2020-03-16	Leanne Altenwerth	leanne.altenwerth@geemail.com	Vancouver	Washington	4157475035592323	3cd4b4952fe78050161fec9bc1bcbf04	VISA 16 digit	45.5689774293988989	-122.513844862679761
15968	2020-03-16 22:40:42	2020-03-16	Avah Morissette	avah.morissette@warmmail.com	San Francisco	California	4373278634229943	b106bb442ec0cbcb5eb3defbbf27d132	Mastercard	37.7562262604186216	-122.425258953057408
15969	2020-03-16 22:47:35	2020-03-16	Omarion Legros II	omarion.legros.ii@geemail.com	Oakland	California	4701346325221	4bd39c6e9ee8e914945c3405a6f02e49	Voyager	37.7849985359189162	-122.296662825488156
15970	2020-03-16 23:08:03	2020-03-16	Willaim Casper	willaim.casper@geemail.com	Cape Coral	Florida	869992196703469200	24890164dd669fbcb4c9e30c8c30d4fc	JCB 16 digit	26.6176031901471326	-82.0961201768439253
15971	2020-03-17 00:08:14	2020-03-17	Nels Price	nels.price@geemail.com	Houston	Texas	4182331211780985	16b29a0c46019e3230df08f4512157f9	VISA 16 digit	29.7019803985100239	-95.3474139039885245
15972	2020-03-17 00:14:22	2020-03-17	Fleeta Mayer MD	fleeta.mayer.md@geemail.com	Fort Worth	Texas	3528869979167840334	6c3ff642c5a2e8995f18377b57aa4772	JCB 16 digit	32.7282485794797537	-97.4194556282188699
15973	2020-03-17 00:22:58	2020-03-17	Ceylon Lubowitz-Beier	ceylon.lubowitz.beier@geemail.com	Corpus Christi	Texas	4130109905375020	d8caf4e3a181107acb206a6b788e5c22	VISA 13 digit	27.6850209749240435	-97.255576730362705
15974	2020-03-17 00:23:50	2020-03-17	Ms. Winona Fahey	ms.winona.fahey@geemail.com	Springfield	Massachusetts	3454150062539901	163e4418c07b487b3d57bfdc740b5651	Diners Club / Carte Blanche	42.0710188931990388	-72.5938224384654376
15975	2020-03-17 00:24:29	2020-03-17	Mrs. Gretta Mills DDS	mrs.gretta.mills.dds@geemail.com	Davie	Florida	4118821770377	4e4e7dcab8b2790fe375a66dd837cc41	VISA 16 digit	26.1190841516744356	-80.3294877617992427
15976	2020-03-17 00:31:53	2020-03-17	Dr. Alvaro Gorczany III	dr.alvaro.gorczany.iii@woohoo.com	San Francisco	California	4828753122436540	f6112e6a99deffd56b5e87aa98fae527	VISA 16 digit	37.7609050897564344	-122.459208138432317
15977	2020-03-17 00:35:21	2020-03-17	Dr. Kathrine Baumbach	dr.kathrine.baumbach@geemail.com	Lubbock	Texas	4305776938688931	c2832fc58ff2e8d85d635f90366f6bb7	Mastercard	33.6276403107721364	-101.807273637867354
15978	2020-03-17 00:44:36	2020-03-17	Britny Effertz	britny.effertz@woohoo.com	San Francisco	California	869963993511707887	5746b35256d0837164fd88c633ac31d3	JCB 15 digit	37.7670758905571873	-122.431144743457594
15979	2020-03-17 00:54:57	2020-03-17	Lalla Pouros	lalla.pouros@geemail.com	Denver	Colorado	060477238657397	ac49b7bb3e548439219f3bc328a2295f	American Express	39.7242442120850043	-104.889186427440876
15980	2020-03-17 00:56:05	2020-03-17	Ardelle Padberg PhD	ardelle.padberg.phd@geemail.com	Pasadena	California	3088056934748309542	2dc77ae60ed51bf154dcd5dcd8c303de	JCB 16 digit	34.2538055029086763	-118.117880596481641
15981	2020-03-17 01:01:47	2020-03-17	Joshuah Dickens	joshuah.dickens@geemail.com	San Francisco	California	3528604838654507311	c4de39ea8b334524af011bbad84e65aa	JCB 15 digit	37.7878668649840108	-122.464039691683595
15982	2020-03-17 01:09:55	2020-03-17	Belva Eichmann	belva.eichmann@warmmail.com	Philadelphia	Pennsylvania	6011458665128977904	7c8e8eb6a10e983b3243ec90361175a9	American Express	39.9464335710234906	-75.1730493230644612
15983	2020-03-17 01:11:01	2020-03-17	Vara Pagac	vara.pagac@geemail.com	Richardson	Texas	6011689305313289044	a6f257a90e76ba97b1b6ab355f7e59fe	VISA 16 digit	33.0391470984790416	-96.6637189642753469
15984	2020-03-17 02:06:58	2020-03-17	Mr. Bailey Kutch Sr.	mr.bailey.kutch.sr.@geemail.com	Concord	California	210098859563011289	8101933bc1741736cdf34c6f0d5975b7	Maestro	38.0670524740058909	-122.02382538576461
15985	2020-03-17 02:20:13	2020-03-17	Jermaine Flatley MD	jermaine.flatley.md@geemail.com	Berkeley	California	4129890312662901	bb3862b0de022bdf755db0820e7fe0f0	VISA 13 digit	37.8778997249536644	-122.278918400533499
15986	2020-03-17 02:33:36	2020-03-17	Bayard Mertz-Heathcote	bayard.mertz.heathcote@geemail.com	San Francisco	California	3112143644861379249	5e504d31d895ffce97ab3d58d9267c3d	JCB 16 digit	37.7931429998892128	-122.45339576458683
15987	2020-03-17 02:48:01	2020-03-17	Lizzie Wunsch	lizzie.wunsch@geemail.com	San Francisco	California	676242466899657	6db3ea5a59965599006a13604802b740	Discover	37.8111630720568286	-122.451457728592615
15988	2020-03-17 03:00:15	2020-03-17	Caren Weimann PhD	caren.weimann.phd@warmmail.com	Miami	Florida	4574348264808501	5961d1deb90709fec1f30be95030da21	VISA 16 digit	25.873492520083488	-80.1547628002580268
15989	2020-03-17 03:30:26	2020-03-17	Harden Lowe-Olson	harden.lowe.olson@geemail.com	Newark	New Jersey	3337647085598539666	a6dcf83ba6c599116ce4de358dfbb91b	JCB 16 digit	40.7400064600080256	-74.1508752466853736
15990	2020-03-17 03:37:49	2020-03-17	Shaina Kertzmann	shaina.kertzmann@geemail.com	Louisville	Kentucky	6011279335927068100	41912570e5b0b21bfe59035ec79e6aaf	Diners Club / Carte Blanche	38.1703255702178907	-85.6076094818372297
15991	2020-03-17 03:57:46	2020-03-17	Ms. Alyvia Frami DVM	ms.alyvia.frami.dvm@geemail.com	San Francisco	California	4945063999796549	98789df3440579639d3ab4eb12fe3bfb	JCB 16 digit	37.7468337061100314	-122.439029034285824
15992	2020-03-17 04:06:04	2020-03-17	Collin Swift II	collin.swift.ii@woohoo.com	Glendale	California	676150493670710	68130b5f5c82365f276dd6b765258b87	JCB 15 digit	34.1172204020187237	-118.303372137797254
15993	2020-03-17 04:07:15	2020-03-17	Vesta Fisher	vesta.fisher@warmmail.com	Berkeley	California	869975782529950092	fd563e858bbd41df0cc5fd50655ed29e	Voyager	37.8989334524349886	-122.25393634084098
15994	2020-03-17 04:14:06	2020-03-17	Jeannette Stiedemann	jeannette.stiedemann@geemail.com	Philadelphia	Pennsylvania	3112155417904938684	f6f7f2f7a3e92799536b904e902e31cd	Discover	40.0006472879979782	-75.1334986276824139
15995	2020-03-17 04:33:00	2020-03-17	Chiquita Goodwin MD	chiquita.goodwin.md@geemail.com	Chicago	Illinois	3722176280752934	e828ea8ffb007fefc12c1ae414ba76d7	VISA 13 digit	41.8770782494287985	-87.6104170226987407
15996	2020-03-17 04:52:17	2020-03-17	Averi Wiegand	averi.wiegand@geemail.com	New York	New York	210041591742728248	90b3aff6cf8247935353a91f08124963	VISA 16 digit	40.5694493452776186	-73.9955313070107223
15997	2020-03-17 04:52:57	2020-03-17	Rossie Schneider II	rossie.schneider.ii@geemail.com	New York	New York	180061752364410607	3cc429205be4e7bad86ea072c3b5a3fe	VISA 16 digit	40.6846425986140972	-73.9755738041724982
15998	2020-03-17 05:19:54	2020-03-17	Dr. Khari Schaefer	dr.khari.schaefer@geemail.com	Garland	Texas	3492566803970192	61bb4330755274c68d44ac8c1428f0f7	JCB 16 digit	32.8179570918671786	-96.6583315477866734
15999	2020-03-17 05:21:01	2020-03-17	Dr. Judd Kreiger	dr.judd.kreiger@warmmail.com	Denver	Colorado	4750864432018	e1a4c270da8105ce2785fdda36e7a803	JCB 16 digit	39.8123331087227896	-104.802508548438922
16000	2020-03-17 05:23:01	2020-03-17	Shelly Kling	shelly.kling@warmmail.com	Austin	Texas	3427042980992433	346f79a6a320496a1c87f4e931661a62	VISA 16 digit	30.2077531799335013	-97.6815732559427659
16001	2020-03-17 05:34:23	2020-03-17	Dedric Greenholt	dedric.greenholt@geemail.com	Houston	Texas	561234639371003	e02040295a1128f68206ece7f542f83e	American Express	29.7372014702375971	-95.3854832967292481
16002	2020-03-17 05:50:21	2020-03-17	Edmund Toy Sr.	edmund.toy.sr.@geemail.com	New York	New York	4608443655882080	31229ad71a5314ee5bd998765a1a97d0	American Express	40.7527077404539995	-73.9745825806062669
16003	2020-03-17 05:58:09	2020-03-17	Dr. Dionte Greenholt DDS	dr.dionte.greenholt.dds@geemail.com	Clarksville	Tennessee	3053877642830051	2f6bfc9db8e5a60d502684ff5b88a02d	JCB 15 digit	36.5715255097147107	-87.3334113608531766
16004	2020-03-17 06:03:30	2020-03-17	Doug Mohr	doug.mohr@geemail.com	Mesa	Arizona	3492421699378961	b9fbbf13e50e2633b60469e46a803fb8	Voyager	33.3503832046553441	-111.798649231519178
16005	2020-03-17 06:08:25	2020-03-17	Delois Orn-Berge	delois.orn.berge@geemail.com	Los Angeles	California	4872149618931240	3c898394e52f77b035a94f06198feae1	VISA 16 digit	34.1037424080871006	-118.508495503430439
16006	2020-03-17 06:09:10	2020-03-17	Dr. Nataly Ward PhD	dr.nataly.ward.phd@geemail.com	Vallejo	California	3054681853238924	0b7ecc12ff63e483d822e89eb2aa6a87	American Express	38.150096489870549	-122.235348982164638
16007	2020-03-17 06:16:38	2020-03-17	Rush Hoeger DDS	rush.hoeger.dds@geemail.com	San Francisco	California	3031747018920954	3d57d42e7dfbf97f59c28636c0fb4980	VISA 13 digit	37.7770608298231423	-122.429018242965299
16008	2020-03-17 06:22:38	2020-03-17	Arno Kunde III	arno.kunde.iii@warmmail.com	Vancouver	Washington	4971071838926	a6ec2b046387bf743ada080faf6e55e7	VISA 13 digit	45.6758683838952351	-122.670628152840578
16009	2020-03-17 06:25:37	2020-03-17	Mr. Art Yundt	mr.art.yundt@woohoo.com	Wilmington	North Carolina	4196457089396077	ea91c6a9194312441cd4857bc5b527dd	Voyager	34.1628574479658198	-77.8484069648657027
16010	2020-03-17 06:26:37	2020-03-17	Lovell Cummerata	lovell.cummerata@geemail.com	New York	New York	3528941012052296826	ef4dc383a976fd9a305aec8e96290dc9	VISA 16 digit	40.6025065327286683	-73.8817917612276887
16011	2020-03-17 06:59:15	2020-03-17	Gustaf Quigley	gustaf.quigley@warmmail.com	Philadelphia	Pennsylvania	502024526920293	8c0a239734a477e67f2fb118b014ac05	JCB 16 digit	40.0663344895426192	-75.2283604598037954
16012	2020-03-17 07:04:24	2020-03-17	Ronda Johns DDS	ronda.johns.dds@woohoo.com	Glendale	California	4469526723126585	220b9686e1ff99723366f9ce472465cc	JCB 16 digit	34.1231628180235589	-118.171186070692912
16013	2020-03-17 07:29:27	2020-03-17	Celestino Waelchi-Kub	celestino.waelchi.kub@woohoo.com	Lewisville	Texas	53317602372268194	08ec28b2659e3952deadaee78faa8c0a	JCB 16 digit	33.0778421852257054	-97.0512022811949322
16014	2020-03-17 07:39:31	2020-03-17	Mr. Virgie Borer	mr.virgie.borer@geemail.com	Salinas	California	3756547314622799	1533a01ac5004bb8467852e74f515104	JCB 15 digit	36.705027320957555	-121.587992904958128
16015	2020-03-17 07:41:47	2020-03-17	Chaz Brekke	chaz.brekke@geemail.com	Greensboro	North Carolina	060457468575899	20a58392f4183c192dfed18a757d8682	VISA 16 digit	36.1901038306415117	-79.7870395866669639
16016	2020-03-17 08:02:32	2020-03-17	Keshawn Wuckert	keshawn.wuckert@geemail.com	San Jose	California	6011722130293312577	971c0d1d5d2e9ff12ea6e6f8abb4606a	VISA 16 digit	37.2259422217782614	-121.731430095502731
16017	2020-03-17 08:05:02	2020-03-17	Mrs. Nya O'Kon	mrs.nya.o'kon@geemail.com	New York	New York	3035597795472661	7bdd385f2f122cdca9702a3dcf27f31a	Mastercard	40.7232507802303871	-73.9694762132491945
16018	2020-03-17 08:05:05	2020-03-17	Watson Walker III	watson.walker.iii@geemail.com	San Francisco	California	3096888623690661075	6cd88d97c8e93db219a6e677f95b37dc	JCB 15 digit	37.7570506492906901	-122.445361575583462
16019	2020-03-17 08:26:54	2020-03-17	Katlyn Thompson	katlyn.thompson@warmmail.com	Louisville	Kentucky	210009852663063258	56bd9258b0231312210a3503cd14d2c0	American Express	38.1762233400620516	-85.7412122951425602
16020	2020-03-17 08:27:11	2020-03-17	Mrs. Mima Kuhlman DDS	mrs.mima.kuhlman.dds@geemail.com	Columbus	Ohio	4220403113669	e098437dd3052c1f36835440cf7b36ee	JCB 16 digit	40.0299007965296525	-82.9041930244073342
16021	2020-03-17 08:31:55	2020-03-17	Josue Krajcik	josue.krajcik@geemail.com	Pittsburgh	Pennsylvania	589338587801960	19d746095fe1016fb1530467d15bb78b	VISA 16 digit	40.5032024078492086	-79.8840973442591746
16022	2020-03-17 08:34:26	2020-03-17	Daryl Beahan	daryl.beahan@geemail.com	Baltimore	Maryland	4139338934084482	a7e1727e62c840bff9f4314135f9acbb	Maestro	39.2018943581264452	-76.57262866422721
16023	2020-03-17 08:36:07	2020-03-17	Carl Hodkiewicz	carl.hodkiewicz@geemail.com	San Francisco	California	4874957547637821	83773aa1eb8f2bdb5135e104d3f7b32b	Maestro	37.783704278330859	-122.419475906573254
16024	2020-03-17 08:58:34	2020-03-17	Bruce Muller-Waters	bruce.muller.waters@warmmail.com	Nashville	Tennessee	3467004650999776	46c876ccde7fab7314c77418ee15a9db	JCB 15 digit	36.2332536082372059	-86.7903597940131988
16025	2020-03-17 09:23:57	2020-03-17	Trever Sauer	trever.sauer@geemail.com	San Francisco	California	3057432475247159	0a8054304d19ee457c3408738e9ff7dd	VISA 13 digit	37.7643655101468241	-122.483387653704739
16026	2020-03-17 10:04:52	2020-03-17	Darell Gleichner	darell.gleichner@geemail.com	New York	New York	4464784989777477	8b5beec90c3661488587661994ae92e9	Diners Club / Carte Blanche	40.7500276863798518	-73.956243147550893
16027	2020-03-17 10:30:55	2020-03-17	Kalene Bogan	kalene.bogan@geemail.com	Arvada	Colorado	869913899598569374	8393604bce0b828c7e37d1e9381e6943	Discover	39.9029767732776719	-105.115031974201273
16028	2020-03-17 10:32:05	2020-03-17	Dayami Bradtke	dayami.bradtke@geemail.com	San Francisco	California	3528638831135769196	6362b33c1af9851afc7985f7f0d01792	JCB 15 digit	37.7489428322125846	-122.409290511835067
16029	2020-03-17 11:05:43	2020-03-17	Dr. Tad Muller MD	dr.tad.muller.md@woohoo.com	San Francisco	California	869935836499681043	aa974ffd55e0b6416255203ee5ea9655	VISA 13 digit	37.7434168318740291	-122.456554349973402
16030	2020-03-17 11:08:18	2020-03-17	Kaycee Gusikowski	kaycee.gusikowski@woohoo.com	Macon	Georgia	6011565336407930879	cbc5bb7dca71b3e006b6cceb3ed0725c	Discover	32.7725593865394558	-83.6765959242552526
16031	2020-03-17 11:14:49	2020-03-17	Mrs. Leonore Murphy	mrs.leonore.murphy@woohoo.com	Houston	Texas	561230421206340	0b5679aa98daab2726f35b59b56ff3a0	American Express	29.6980727943670004	-95.4505999774221294
16032	2020-03-17 11:50:11	2020-03-17	Mrs. Nanci Howell MD	mrs.nanci.howell.md@woohoo.com	Cleveland	Ohio	3032879554146030	e086f789c1922573f40a37076f05aa8d	VISA 13 digit	41.3929933862145987	-81.7542778829816683
16033	2020-03-17 12:01:46	2020-03-17	Gaither Boehm	gaither.boehm@woohoo.com	Pueblo	Colorado	503831802797063	f4036a01848258e94e66f8b2cbabd9e2	American Express	38.2513914624206706	-104.661703290078052
16034	2020-03-17 12:12:19	2020-03-17	Mrs. Nita Abshire MD	mrs.nita.abshire.md@geemail.com	San Francisco	California	3035850634242187	600e47494fb13bcfad726a13faeca0c9	VISA 13 digit	37.7896904942786449	-122.405953165235502
16035	2020-03-17 12:24:03	2020-03-17	Cleve Huels	cleve.huels@geemail.com	El Cajon	California	4100161154214	1d13441ad5f98f35a2542a37687e8b49	VISA 13 digit	32.847992974427342	-117.055067514227332
16036	2020-03-17 12:34:13	2020-03-17	Devan Gibson	devan.gibson@geemail.com	Los Angeles	California	4833719413450246	a1174eac35b0427cea6a8fcaddc4da85	JCB 16 digit	33.9932526624627371	-118.344507299223167
16037	2020-03-17 12:38:36	2020-03-17	Adrienne Corkery	adrienne.corkery@warmmail.com	Knoxville	Tennessee	4817837220760	9ea7bc37595970669211564f9cc6f93a	VISA 13 digit	36.0677764625351855	-83.8699411634106156
16038	2020-03-17 12:41:35	2020-03-17	Dr. Verlie Harber	dr.verlie.harber@geemail.com	St. Petersburg	Florida	3751909527410179	c6eaa9e755bf85467b48d4da048c6018	VISA 13 digit	27.7044651564564575	-82.6957949356999222
16039	2020-03-17 12:44:02	2020-03-17	Josiah Gerhold-Bauch	josiah.gerhold.bauch@woohoo.com	San Francisco	California	869987868953520398	f6ca902490528fcd21d080e2ccd46a34	JCB 15 digit	37.7919431815645126	-122.410492097832872
16040	2020-03-17 12:47:28	2020-03-17	Fred Lehner	fred.lehner@woohoo.com	Modesto	California	180039848806362015	2854f5c00b281beb355176ede1bd660b	Mastercard	37.6792055991943968	-121.038123250214383
16041	2020-03-17 12:51:51	2020-03-17	Ms. Dagny Effertz	ms.dagny.effertz@geemail.com	Springfield	Illinois	3528253049225158899	f37bbc74aa6f7ec10bc6246528386148	JCB 16 digit	39.8367153337843689	-89.6649607227653291
16042	2020-03-17 12:52:44	2020-03-17	Cohen Harber	cohen.harber@geemail.com	San Francisco	California	3158769197295428945	ecb8174f6007848f1de037451ea497b9	VISA 13 digit	37.7957887739816272	-122.455983645130601
16043	2020-03-17 13:35:56	2020-03-17	Uriah Langworth-Tremblay	uriah.langworth.tremblay@geemail.com	San Francisco	California	3052054686907747	e89f57d30e8bb1497fb1f2d80573785b	American Express	37.7358354188756167	-122.415503940100137
16044	2020-03-17 13:39:30	2020-03-17	Dr. Henery Larson IV	dr.henery.larson.iv@geemail.com	Sparks	Nevada	676148886302644	6b8d7d5b74a0a8027bfebc8913df6b16	Diners Club / Carte Blanche	39.6415475761756326	-119.670940149328118
16045	2020-03-17 13:39:40	2020-03-17	Miss Sherron Lakin PhD	miss.sherron.lakin.phd@geemail.com	Los Angeles	California	3785785966551784	197ff06a0ba14c7a384114dcfcd60c8d	Discover	33.9803061623923455	-118.460821600490434
16046	2020-03-17 14:11:32	2020-03-17	Kristine Hamill	kristine.hamill@geemail.com	Chicago	Illinois	869929433873237721	52e596395d9b71617b081b34333a9eb9	Voyager	41.7551721665844369	-87.6947520481918019
16047	2020-03-17 14:13:09	2020-03-17	Clare Zemlak DDS	clare.zemlak.dds@warmmail.com	New Haven	Connecticut	3088816848280944493	ff2ff32d107992316f05368ab29c2732	VISA 16 digit	41.259828387665749	-73.0118715449701909
16048	2020-03-17 14:22:32	2020-03-17	Claudie Kris	claudie.kris@woohoo.com	Louisville	Kentucky	3712091899866086	2c99f7a43c24f49be47fa842e73b2249	Maestro	38.1831244280464901	-85.6230357082165767
16049	2020-03-17 14:25:41	2020-03-17	Mr. Ayden Padberg	mr.ayden.padberg@geemail.com	San Francisco	California	3040955758072214	b1d78b1ebed2a4d9a41f2cc68dd028d6	Maestro	37.7528427019241732	-122.433981707673041
16050	2020-03-17 14:40:47	2020-03-17	Breann Schroeder	breann.schroeder@geemail.com	Virginia Beach	Virginia	4569190220378790	8cea83eea06cc14366a19114e2293868	Voyager	36.8600345859955993	-76.0358566699221683
16051	2020-03-17 14:43:26	2020-03-17	Jaclyn Murazik-Herman	jaclyn.murazik.herman@woohoo.com	New York	New York	4040421576058366	2e4e6f72181df506a43e8dfe4f4eca60	Maestro	40.6898709195423862	-73.8651891996513967
16052	2020-03-17 14:43:30	2020-03-17	Gaines Monahan	gaines.monahan@geemail.com	Oxnard	California	52980029789419978	bfed6b36a09645b782d6970e91dbcdf4	VISA 16 digit	34.2863641798451582	-119.176656030342357
16053	2020-03-17 14:45:16	2020-03-17	Phyllis Hills	phyllis.hills@warmmail.com	Los Angeles	California	3096215453180839278	ea94e03268c7a0ad82b469e0638a9340	VISA 13 digit	34.0921304127532991	-118.433955233403665
16054	2020-03-17 15:16:57	2020-03-17	Cael Borer	cael.borer@woohoo.com	Montgomery	Alabama	3020761763996748	de654acee63c120e9b91fbcec0beb1b5	Discover	32.3569958655562289	-86.2976283230505885
16055	2020-03-17 15:18:00	2020-03-17	Brinley Stamm	brinley.stamm@woohoo.com	San Francisco	California	4417157322589792	998da82211e9148f6e90831bcb02264a	VISA 13 digit	37.7675386738556256	-122.450732170885487
16056	2020-03-17 15:29:59	2020-03-17	Hayden Harber	hayden.harber@woohoo.com	Glendale	California	210038286771681286	dbb6efff683e4aeef5d3b7cd42366f18	JCB 16 digit	34.2347561601303454	-118.216809080018848
16057	2020-03-17 15:32:55	2020-03-17	Griffith Hodkiewicz	griffith.hodkiewicz@geemail.com	Santa Rosa	California	3013451961975069	7d5fc92e5e094e1f43bc6501fbc67d0d	Diners Club / Carte Blanche	38.4928110554937319	-122.769074083190787
16058	2020-03-17 16:01:50	2020-03-17	Ms. Marina Hayes	ms.marina.hayes@geemail.com	Los Angeles	California	3088601548555465427	fad8b69b3586191fefd37f415d991906	JCB 16 digit	34.0976001765444821	-118.426774245313553
16059	2020-03-17 16:09:37	2020-03-17	Elzy Jast-Blanda	elzy.jast.blanda@geemail.com	Los Angeles	California	869964013285075988	018699b0a6f7a88684577c94fbcc8f2f	Maestro	33.9322689548000653	-118.329305772529167
16060	2020-03-17 16:16:49	2020-03-17	Kylan Prosacco	kylan.prosacco@geemail.com	Boston	Massachusetts	4432029471609	2a178a76c3f7c8d22488ac92d1bbeac3	JCB 16 digit	42.3781155620869256	-70.9899546566370958
16061	2020-03-17 16:33:13	2020-03-17	Ashlee Smitham	ashlee.smitham@geemail.com	Santa Rosa	California	3029958118968528	6cb4ab682e4faead5e272f8425a3320a	JCB 16 digit	38.4756163864053846	-122.664402010875207
16062	2020-03-17 16:37:37	2020-03-17	Cheryle Turcotte	cheryle.turcotte@geemail.com	Los Angeles	California	869935594243833671	a3aaed00e5771d321a90a1b016adf60e	VISA 13 digit	34.0782422726839727	-118.365565871446577
16063	2020-03-17 16:43:23	2020-03-17	Mr. Rory Leffler II	mr.rory.leffler.ii@geemail.com	Santa Maria	California	869928176014228320	50fbfdac867851f5e63120e566c62f53	VISA 16 digit	34.9638260723154985	-120.434727974088119
16064	2020-03-17 16:58:32	2020-03-17	Ian Monahan	ian.monahan@geemail.com	Lewisville	Texas	4855436362106702	1a83c4aa1f190f1b317f520d6cc4a1f8	VISA 13 digit	33.0675612172096933	-96.9461258152529695
16065	2020-03-17 17:08:27	2020-03-17	Jayde Shanahan	jayde.shanahan@warmmail.com	Raleigh	North Carolina	3030786101731374	58bedeaed1a5033f8a5bded0b36047cd	JCB 16 digit	35.7712565118115364	-78.7170093505580013
16066	2020-03-17 17:11:21	2020-03-17	Hakeem Jenkins	hakeem.jenkins@geemail.com	Chicago	Illinois	869918251883656463	6a3a72be679996cbf7fef43421708538	Mastercard	41.8936196857433814	-87.718064469008894
16067	2020-03-17 17:14:10	2020-03-17	Andres Grant	andres.grant@geemail.com	Woodbridge	New Jersey	3047686486673162	d5da180517d5b5bf7dcbb10dfe833f9f	VISA 16 digit	40.486192991646746	-74.3556577157553278
16068	2020-03-17 17:27:44	2020-03-17	Shatara Bins-D'Amore	shatara.bins.d'amore@geemail.com	New York	New York	3112342440481449234	39f2a267b7422140214ef33f690fc70c	Maestro	40.6694221315197666	-73.9551905346464338
16069	2020-03-17 17:28:17	2020-03-17	Mr. Teddie Effertz	mr.teddie.effertz@woohoo.com	San Francisco	California	4583725685379	8bf5b1a04f161c5502debf9229ece31a	Discover	37.7677666361373241	-122.429366695785944
16070	2020-03-17 17:49:13	2020-03-17	Godfrey Greenholt	godfrey.greenholt@geemail.com	Chicago	Illinois	3797210706906012	69f749ee54ced1792adc8b7985951ac7	JCB 16 digit	41.9158742791809189	-87.609866488774486
16071	2020-03-17 17:55:40	2020-03-17	Dr. Lauren Stark MD	dr.lauren.stark.md@geemail.com	Fresno	California	3528162694693048617	b62d7e8f36ecff83ce1dea13e4272dc4	VISA 16 digit	36.8608734238766118	-119.744906761182108
16072	2020-03-17 18:02:09	2020-03-17	Sloane Jerde	sloane.jerde@woohoo.com	Fort Worth	Texas	180057175757990355	c420792a28938930f2d6fb784d96ec9c	Voyager	32.8366210412755635	-97.2975077554870325
16073	2020-03-17 18:20:02	2020-03-17	Kailyn Hagenes-Mueller	kailyn.hagenes.mueller@geemail.com	Manchester	New Hampshire	180003725640518204	7561dda357a057ae105d4be1ef3230b7	VISA 13 digit	43.0748661191273499	-71.3755100607298374
16074	2020-03-17 18:57:26	2020-03-17	Isaak Bosco	isaak.bosco@geemail.com	Jersey City	New Jersey	3158953498866248084	48ac3947818be76d01e063941ead22ac	Mastercard	40.6522738572150431	-74.0955342678774258
16075	2020-03-17 18:58:31	2020-03-17	Mr. Kimball Hyatt	mr.kimball.hyatt@geemail.com	Philadelphia	Pennsylvania	3774159823223073	207663200e8d589b37ba2af0ef59cd28	VISA 16 digit	40.0228035375900575	-75.1745486317567639
16076	2020-03-17 19:19:09	2020-03-17	Fount Stiedemann	fount.stiedemann@geemail.com	Miami	Florida	3096040563136867321	708042a544df2e35d36ed9d2b7ec8f95	VISA 16 digit	25.6987503207426542	-80.1931648260787142
16077	2020-03-17 19:24:33	2020-03-17	Brooke Robel	brooke.robel@geemail.com	Reno	Nevada	589304404775449	b157e985312af1c13d152e79a4f53345	JCB 15 digit	39.6279546120282262	-119.937736504401641
16078	2020-03-17 19:36:22	2020-03-17	Dr. Van Stehr	dr.van.stehr@warmmail.com	Chicago	Illinois	52587805189194791	34846773236d7f5195f006d8094b30cf	Diners Club / Carte Blanche	41.7623072315774877	-87.624987798140566
16079	2020-03-17 19:54:35	2020-03-17	Reanna Rippin-Pfannerstill	reanna.rippin.pfannerstill@geemail.com	Berkeley	California	3463443456124052	02562151fce278d2a51de5bd80708679	Discover	37.8634545693209432	-122.328576979404502
16080	2020-03-17 19:59:03	2020-03-17	Rudolph Lubowitz	rudolph.lubowitz@geemail.com	Atlanta	Georgia	3088330961842823548	cf695b2638c050fa1876659991cc633e	American Express	33.8067777247909476	-84.4533884665973602
16081	2020-03-17 20:01:43	2020-03-17	Clayton Lind	clayton.lind@geemail.com	San Francisco	California	4386079928658580	c1eb37b1e8bfdda133eff44227c79811	JCB 16 digit	37.7677308449728883	-122.403305225946184
16082	2020-03-17 20:03:04	2020-03-17	Wardell Brakus	wardell.brakus@woohoo.com	San Francisco	California	4881917428862048	dc1465abb4f8b90a87f11d2f1e565d9c	JCB 16 digit	37.7895873615146272	-122.404551190050128
16083	2020-03-17 20:12:36	2020-03-17	Timothy Kohler	timothy.kohler@geemail.com	New York	New York	180027607565443471	f4b2cb795839fa1c141693f95eb8d1c5	Discover	40.6928996236752738	-73.8562684043206303
16084	2020-03-17 20:21:04	2020-03-17	Justine Friesen	justine.friesen@warmmail.com	San Francisco	California	869952560718515323	237be51760458aa1dbed9cd6e73b80cb	VISA 13 digit	37.7677049973021681	-122.41206123858143
16085	2020-03-17 20:24:15	2020-03-17	Edie Crooks	edie.crooks@geemail.com	Albuquerque	New Mexico	3158615165013893589	2e46d20513185c2e0da3ab8cab22dd99	Discover	35.1537004959438022	-106.725575295144324
16086	2020-03-17 20:44:29	2020-03-17	Cameron Walsh-McClure	cameron.walsh.mcclure@geemail.com	Modesto	California	4572542346190	b153dcd7c62f1c9663c09ec54c44caf9	VISA 16 digit	37.7358601915650098	-121.039943172616887
16087	2020-03-17 20:48:19	2020-03-17	Ottie Ward-Gleason	ottie.ward.gleason@geemail.com	San Diego	California	180022419618702225	889236ab3eda9a86180e546a3a4e3389	JCB 16 digit	32.8664790897697188	-117.040083303339784
16088	2020-03-17 20:58:09	2020-03-17	Newt Gleason	newt.gleason@geemail.com	Corpus Christi	Texas	3088055554345214894	6ca365b873e09677e9f0188af7063c3f	Voyager	27.7623900692846632	-97.2149759393479656
16089	2020-03-17 21:12:04	2020-03-17	Shawnda Hickle	shawnda.hickle@geemail.com	Garland	Texas	4244100252174176	59c40410232a87b2cc60bae824608a99	Discover	32.8691101373407975	-96.5417112330600702
16090	2020-03-17 21:21:17	2020-03-17	Mr. Titus Kautzer IV	mr.titus.kautzer.iv@geemail.com	Tallahassee	Florida	3337674873898517938	d3263343668439f5cf95beb546a5a942	VISA 13 digit	30.5503910496387654	-84.2593926406014759
16091	2020-03-17 21:45:48	2020-03-17	Renard Franecki	renard.franecki@geemail.com	Austin	Texas	3528978690722468754	1075d9e971821c34264ea824c3ce324b	Mastercard	30.330783630687371	-97.6667986981809122
16092	2020-03-17 22:21:08	2020-03-17	Mr. Rand Heidenreich Jr.	mr.rand.heidenreich.jr.@geemail.com	Hartford	Connecticut	869926072579576975	63057f8559c9b971cc34f87fb452b82b	VISA 16 digit	41.8093602574445313	-72.6170207012336704
16093	2020-03-17 22:39:38	2020-03-17	Fuller Schultz-Nienow	fuller.schultz.nienow@woohoo.com	New York	New York	4574922218123603	ebac62a773f90fb8a841c9f54c3d8417	VISA 16 digit	40.6825394207835203	-73.8660716366849783
16094	2020-03-17 22:49:23	2020-03-17	Tamya Kutch	tamya.kutch@geemail.com	Jackson	Mississippi	6011309235924308968	0bb3245e7d4c918f928d886c9ead58d0	Mastercard	32.3053983482245357	-90.1367214369561509
16095	2020-03-17 22:59:16	2020-03-17	Dr. Raymundo Gaylord	dr.raymundo.gaylord@geemail.com	Oklahoma City	Oklahoma	869983920143234283	9394dcff6bc21520c44c1be8ba83f881	VISA 16 digit	35.3897892040111159	-97.4732860451459828
16096	2020-03-17 23:03:56	2020-03-17	Essex Ritchie	essex.ritchie@geemail.com	Los Angeles	California	4657610546712	94e436ab52c83ee78d5f14961506b61c	Mastercard	34.1024767037812566	-118.455567820462576
16097	2020-03-17 23:21:50	2020-03-17	Dr. Raymond Price	dr.raymond.price@woohoo.com	Phoenix	Arizona	639045883953502	5acff5f44b318351f2727ba0e61f0190	JCB 16 digit	33.5634155906669847	-112.179517092967785
16098	2020-03-17 23:36:53	2020-03-17	Miss Tamekia Yost MD	miss.tamekia.yost.md@geemail.com	San Francisco	California	869946669213664962	cb82c32bf3edde9279a4273256d3570b	Mastercard	37.7621418316401716	-122.425623177768415
16099	2020-03-17 23:43:54	2020-03-17	Madeline Bartell	madeline.bartell@geemail.com	Chicago	Illinois	4847913029253250	542b35b03e3c759fe68c3f26789cf3ed	Discover	41.7380513627383891	-87.6138077463518812
16100	2020-03-17 23:46:06	2020-03-17	Golden Lang	golden.lang@geemail.com	Tulsa	Oklahoma	3760924638318608	831981391b5b66385c1e4155ab2d3de9	American Express	36.2002233814816918	-95.9200854162640866
16101	2020-03-18 00:02:35	2020-03-18	Landen Kertzmann	landen.kertzmann@geemail.com	Davenport	Iowa	3088808740389892824	5855a34e723b1308e8deb14f7251cde2	JCB 16 digit	41.613176371137051	-90.53626977973245
16102	2020-03-18 00:05:50	2020-03-18	Jarod Hickle-Kutch	jarod.hickle.kutch@geemail.com	Los Angeles	California	4161946317934759	62d4dfe12be2c9e62a2159509d10efb8	VISA 13 digit	33.9495091654226187	-118.334785413275654
16103	2020-03-18 00:07:12	2020-03-18	Mal Kuhlman	mal.kuhlman@warmmail.com	San Francisco	California	3798370910332378	55c34cf2b647b2afda854a287c5045d4	JCB 16 digit	37.7416762672226156	-122.4189351970291
16104	2020-03-18 00:07:43	2020-03-18	Ms. Malinda Veum DDS	ms.malinda.veum.dds@geemail.com	El Paso	Texas	4131621410496462	8889bf16f2eb6ba663344abeafb02782	Diners Club / Carte Blanche	31.9022806048221916	-106.467814728615807
16105	2020-03-18 01:05:38	2020-03-18	Donovan Feeney-Cassin	donovan.feeney.cassin@geemail.com	Louisville	Kentucky	210098167063766299	a354dc2fa238adfc1f269766cf9dc1f4	Maestro	38.1830620896439967	-85.7133160116221831
16106	2020-03-18 01:08:00	2020-03-18	Neta Adams-Mraz	neta.adams.mraz@geemail.com	Alexandria	Virginia	3004851083130734	ca844b4f928a9d7b0da7b8013332e3ab	VISA 16 digit	38.9173916444297845	-77.148249326831106
16107	2020-03-18 01:11:46	2020-03-18	Aden Zboncak	aden.zboncak@geemail.com	Fort Wayne	Indiana	869907395941526755	6c1727b41e127314aad88623d90d6b98	Maestro	41.0480409049212938	-85.1103437151979705
16108	2020-03-18 01:14:17	2020-03-18	Dr. Antoinette Wolf PhD	dr.antoinette.wolf.phd@geemail.com	Rialto	California	4507718162608058	5f0b5cb9e2589677bbfa46dd8521ddaf	American Express	34.0573221214331738	-117.431865683346246
16109	2020-03-18 01:42:48	2020-03-18	Stewart Dibbert V	stewart.dibbert.v@geemail.com	Plano	Texas	3088558445170633666	1b0f96a9e30e3176551fffe39abc2df9	VISA 16 digit	32.972674527866026	-96.6986432965561704
16110	2020-03-18 01:51:01	2020-03-18	Reino Heathcote	reino.heathcote@geemail.com	San Francisco	California	060435566756421	48ac8b6f907c8dccd6eedef26598cca8	Mastercard	37.7831412252831385	-122.450404009006519
16111	2020-03-18 01:51:27	2020-03-18	Mrs. Kaylan Luettgen	mrs.kaylan.luettgen@woohoo.com	San Francisco	California	4309058173750320	ccee6824ef03ddbe94cb3d4ade3f70d6	Maestro	37.7999953511719298	-122.43710202350789
16112	2020-03-18 02:42:55	2020-03-18	Ula Volkman	ula.volkman@geemail.com	Detroit	Michigan	6011711258961101569	d0ac6f92fcb45258c42b222613dcea26	American Express	42.4491958108190488	-83.1754867097947681
16113	2020-03-18 02:43:13	2020-03-18	Linwood Larson IV	linwood.larson.iv@geemail.com	San Francisco	California	54086122990266065	1cfddfe0f85226199870d265307460bf	JCB 15 digit	37.7719180963476404	-122.445227999759851
16114	2020-03-18 02:57:52	2020-03-18	Brenna Bradtke	brenna.bradtke@geemail.com	San Francisco	California	4963352184846319	320e8f2b1e1b7d97976fd551fc93cd11	VISA 16 digit	37.76690336603437	-122.432888794350646
16115	2020-03-18 02:59:02	2020-03-18	Larry Metz	larry.metz@geemail.com	Indianapolis	Indiana	4297527799252121	9d536c16a9204f7bed50a929a19e6c07	Diners Club / Carte Blanche	39.8088874949615459	-86.0785382441446103
16116	2020-03-18 03:06:13	2020-03-18	Rigoberto Ritchie	rigoberto.ritchie@warmmail.com	San Francisco	California	676287706446496	05c7de0d58a52c7cd2744553c58ea1b9	VISA 13 digit	37.7717301057294534	-122.425927584288743
16117	2020-03-18 03:13:31	2020-03-18	Dr. Margret Schinner	dr.margret.schinner@geemail.com	Syracuse	New York	4390962504829960	05b860588b7d475e88a590de881f8360	JCB 16 digit	42.9611943099033056	-76.1639241700306542
16118	2020-03-18 03:14:32	2020-03-18	Mr. Deonta O'Kon DDS	mr.deonta.o'kon.dds@geemail.com	New York	New York	4096492413756390	6f8cffcc3db4451bbf3a0e5897e95a7a	Diners Club / Carte Blanche	40.6734120776169021	-73.8544077525742324
16119	2020-03-18 03:25:51	2020-03-18	Janene Lebsack DVM	janene.lebsack.dvm@geemail.com	Columbus	Ohio	501895125667212	34d6ba0b6ef54741e2715e73e2df0ec6	Maestro	39.9978980128232351	-83.030301918671654
16120	2020-03-18 03:31:31	2020-03-18	Miss Shaquita Hills	miss.shaquita.hills@geemail.com	Detroit	Michigan	4028126975280141	4f16d17cabaa24ba303eba419625f154	VISA 16 digit	42.4482245423756552	-83.1171581496603693
16121	2020-03-18 03:40:55	2020-03-18	Hosteen Schulist	hosteen.schulist@geemail.com	Boston	Massachusetts	869916373427108496	c5c56e468fe4133f0e32d2a1762a2724	Voyager	42.2915037951599828	-71.0732337605625446
16122	2020-03-18 03:50:03	2020-03-18	Odie Turcotte	odie.turcotte@geemail.com	Chattanooga	Tennessee	4705118762585022	8f07a8983ba9afaa33ac5e2271f5bad8	Diners Club / Carte Blanche	35.0340203307420026	-85.2573873637072808
16123	2020-03-18 04:16:25	2020-03-18	Dr. Garnett Wintheiser Sr.	dr.garnett.wintheiser.sr.@geemail.com	Berkeley	California	869976036319798412	c46d5d5876439e78590f6cbbbc8a8a42	VISA 13 digit	37.8607011784089877	-122.255105608363081
16124	2020-03-18 04:25:30	2020-03-18	Norine Satterfield	norine.satterfield@warmmail.com	Chicago	Illinois	501884285834713	4c1145937c55e0698ca2b0e1dd581401	VISA 13 digit	41.767685561331362	-87.751290881264211
16125	2020-03-18 04:32:06	2020-03-18	Vicy Kohler	vicy.kohler@geemail.com	Berkeley	California	3404339175787298	03e3c88d009be7cffbb8fcfcee4a6856	Diners Club / Carte Blanche	37.8692652696383618	-122.311512323559313
16126	2020-03-18 04:34:02	2020-03-18	Bishop Stamm	bishop.stamm@geemail.com	San Diego	California	3738347422401159	3b5b3a9e8c107a3a60c8827d230d120b	Mastercard	32.8894184670012422	-117.149808629918851
16127	2020-03-18 04:53:21	2020-03-18	Dr. Jax Emard	dr.jax.emard@warmmail.com	San Francisco	California	3088633543567862366	65ec968883834ecdc772b682a1d171af	VISA 16 digit	37.7886906803090241	-122.435589051300113
16128	2020-03-18 05:03:33	2020-03-18	Cordero Mayer-Rippin	cordero.mayer.rippin@geemail.com	Garden Grove	California	3158390322647393210	d6285d30b355cb05a0b042222606d1fe	Diners Club / Carte Blanche	33.7897695161692795	-117.952607467865562
16129	2020-03-18 05:07:51	2020-03-18	Chantelle Hauck	chantelle.hauck@geemail.com	Salem	Oregon	55605021904508533	4e8525828a62bba2953ab74d703a9dc7	VISA 16 digit	44.9092848133098315	-123.055128969081494
16130	2020-03-18 05:12:41	2020-03-18	Zina Fay	zina.fay@geemail.com	Las Vegas	Nevada	6011778870032619013	72f29dc9f09a0c04c5130ababda3fba7	JCB 15 digit	36.1676208722505734	-115.318904526412851
16131	2020-03-18 05:38:23	2020-03-18	Agness Block-Cronin	agness.block.cronin@geemail.com	San Diego	California	3445909486670911	d14049b6e0cb613f76ee7b798077323b	JCB 16 digit	32.7779002314500545	-117.202178667383279
16132	2020-03-18 05:51:27	2020-03-18	Quincy Carter-Rutherford	quincy.carter.rutherford@geemail.com	San Francisco	California	4191776750722948	cefcb9bfe8eaf5d5b217d0c70a27f6b3	VISA 13 digit	37.7723786404122208	-122.446897869821584
16133	2020-03-18 06:03:43	2020-03-18	Elna Zieme-Funk	elna.zieme.funk@geemail.com	New York	New York	4435459347414800	ea57f22d822911be708e918a84517c67	Maestro	40.5951808374132952	-73.9376952942822072
16134	2020-03-18 06:07:01	2020-03-18	Mr. Joeseph Hodkiewicz DDS	mr.joeseph.hodkiewicz.dds@woohoo.com	New York	New York	869943826052778666	785331b250b5b7ae2a1157fe1fa1b298	Maestro	40.7198089743256588	-73.8423310145631433
16135	2020-03-18 06:18:28	2020-03-18	Cathrine Lubowitz DDS	cathrine.lubowitz.dds@geemail.com	Surprise	Arizona	4240232443053	fde56e7f537c7b424793553adbc2cd64	Mastercard	33.7610395547229771	-112.368267648131393
16136	2020-03-18 06:32:47	2020-03-18	Joann Hayes	joann.hayes@warmmail.com	Omaha	Nebraska	4196431675749	c0e1f12f5d91e5d1376a0143b46db5dc	Discover	41.2136139432579327	-95.9649948738630911
16137	2020-03-18 07:33:17	2020-03-18	Rosaline Fritsch DVM	rosaline.fritsch.dvm@warmmail.com	New York	New York	3096130337983425777	b20d032315e09399c75dd2f0d0011ee5	Mastercard	40.6984327322095609	-73.954067287397379
16138	2020-03-18 07:55:38	2020-03-18	Rylee Schultz	rylee.schultz@geemail.com	Oakland	California	3337868001920163184	a1e61f4c36612f22498e023403f74f0c	VISA 16 digit	37.7499689834556804	-122.296875912144571
16139	2020-03-18 08:01:08	2020-03-18	Ottie Dach-Fahey	ottie.dach.fahey@geemail.com	Miami	Florida	6011324203214373879	9bde9cdd17cd0100cd644e46e07afbdb	VISA 16 digit	25.6988137802246968	-80.1443914796099079
16140	2020-03-18 08:28:14	2020-03-18	Rhea Hagenes	rhea.hagenes@geemail.com	Rochester	New York	3528065636279891215	32ed7382779613c058264885c3b20870	JCB 16 digit	43.1973241772945968	-77.7144207511335594
16141	2020-03-18 08:33:41	2020-03-18	Anjanette Harber	anjanette.harber@warmmail.com	Thornton	Colorado	676261712960717	3d5db91bb39ebea2cf88e055e9c797ed	Discover	39.9144396830216053	-104.883844913465168
16142	2020-03-18 08:49:05	2020-03-18	Mr. Linzy Wuckert	mr.linzy.wuckert@geemail.com	Atlanta	Georgia	4809457420689	429f3a201067bb7343e26c29705f9a08	VISA 16 digit	33.7109570503510554	-84.399351213830343
16143	2020-03-18 08:57:02	2020-03-18	Kaylene Schiller	kaylene.schiller@geemail.com	Columbus	Ohio	4073469492643795	ddd0e35df96bf7a6491d67f1e924eabb	Mastercard	39.902190770958363	-83.0679924513448071
16144	2020-03-18 09:17:53	2020-03-18	Kathern Sawayn	kathern.sawayn@geemail.com	Lewisville	Texas	869957396996253476	2f661ab43ab5a983a4d94a4acfe44d75	Mastercard	33.0350804095607202	-97.076412153107313
16145	2020-03-18 09:20:10	2020-03-18	Windell Bode	windell.bode@geemail.com	New York	New York	210066027060894569	026093c4e7dedb908163be3241706ec1	VISA 16 digit	40.6915321280937619	-73.9557483339577857
16146	2020-03-18 09:31:40	2020-03-18	Jasmyn Rodriguez	jasmyn.rodriguez@geemail.com	Baltimore	Maryland	52969671099741206	585beae7148a7df537c46cae48662db1	Diners Club / Carte Blanche	39.2047782139852643	-76.6170929440315831
16147	2020-03-18 09:34:54	2020-03-18	Kip Pouros	kip.pouros@geemail.com	Tampa	Florida	3412032618955495	32c51cf6b8cce352db149d41738cc2b0	JCB 16 digit	27.9005137050639824	-82.4049106334548327
16148	2020-03-18 09:35:40	2020-03-18	Mr. Al Botsford DDS	mr.al.botsford.dds@geemail.com	Shreveport	Louisiana	3528323945337381079	e971c1ee58a51f0d0da595b620ae2fad	JCB 16 digit	32.5511027481645385	-93.7645725942894757
16149	2020-03-18 09:37:23	2020-03-18	Chadwick Beier-Quitzon	chadwick.beier.quitzon@woohoo.com	Berkeley	California	3088299681672206858	ce00efbc4f2e06de5a3b59e86dfe0db5	JCB 16 digit	37.8889068232785746	-122.230153999897539
16150	2020-03-18 09:38:03	2020-03-18	Arely Dibbert DDS	arely.dibbert.dds@geemail.com	San Jose	California	4197012208405	2dd7b56b9667ce5586ed9bc87c87bf28	JCB 16 digit	37.2777100888833388	-121.820603088032087
16151	2020-03-18 09:40:36	2020-03-18	Susie Boyer DVM	susie.boyer.dvm@geemail.com	Edison	New Jersey	3112760602198605795	d1dd75fac0f3a56ed378e106c27fa4be	Maestro	40.5822926356885532	-74.2731803259864449
16152	2020-03-18 09:41:11	2020-03-18	Daja Steuber	daja.steuber@geemail.com	San Antonio	Texas	4624028684881	241f6607d357256af329731d5baab9fb	JCB 15 digit	29.4466307780776191	-98.4253678839955484
16153	2020-03-18 09:44:05	2020-03-18	Williard Carter-Brekke	williard.carter.brekke@geemail.com	Des Moines	Iowa	4387824698352	e926b6174de825dc1a8ed41432f17018	Voyager	41.4896461681671482	-93.5699543316893312
16154	2020-03-18 10:02:42	2020-03-18	Stewart Wolf-McCullough	stewart.wolf.mccullough@geemail.com	New York	New York	54049443788657539	6b854259c6c492b07b4d63949fadaf75	Discover	40.6172246847525216	-73.885719594255832
16155	2020-03-18 10:19:26	2020-03-18	Delmer Mueller	delmer.mueller@geemail.com	San Francisco	California	210072605897522552	3e0e69722a6347341843e22adcbc6252	JCB 15 digit	37.7905483274405825	-122.446612173824221
16156	2020-03-18 10:46:19	2020-03-18	Ova Rippin	ova.rippin@geemail.com	Huntsville	Alabama	869958592971446841	963c9b3a209d3bc4186e31b50fa051e7	VISA 16 digit	34.7142648784220214	-86.7599459101464561
16157	2020-03-18 10:51:42	2020-03-18	Grace Botsford	grace.botsford@geemail.com	Overland Park	Kansas	3769406230366202	a8028b90b4d2a70d06acd5cc125113a3	VISA 13 digit	38.8548091937191842	-94.6834852584212996
16158	2020-03-18 11:14:01	2020-03-18	Lessie Kris MD	lessie.kris.md@geemail.com	New York	New York	4051551275577021	da71f372c0ed8b203bfab4e285559213	VISA 16 digit	40.6600317153837523	-74.0094027914468171
16159	2020-03-18 11:16:06	2020-03-18	Evan Lubowitz	evan.lubowitz@geemail.com	Riverside	California	4826992390947620	80efe8044097f72a3469253ca2cc6013	JCB 16 digit	33.95617993557304	-117.487502240014067
16160	2020-03-18 11:18:37	2020-03-18	Lizette DuBuque DVM	lizette.dubuque.dvm@geemail.com	Chicago	Illinois	3112154727717325908	05e10e21ccbf06243910f0bff4abd3d5	JCB 16 digit	41.7509407858666037	-87.5966850288242114
16161	2020-03-18 11:28:28	2020-03-18	Mrs. Adeline Witting DVM	mrs.adeline.witting.dvm@geemail.com	San Francisco	California	210084866924044525	7844d708580378f68ac0b444323d4427	JCB 16 digit	37.7624605915521343	-122.37951873263394
16162	2020-03-18 11:30:18	2020-03-18	Mrs. Jeraldine Hettinger	mrs.jeraldine.hettinger@geemail.com	Little Rock	Arkansas	4459473147989003	4f317322cb9a0dc70c3972be0fbb84e6	JCB 16 digit	34.8241316942773764	-92.3226977615956201
16163	2020-03-18 11:45:08	2020-03-18	Tyrek Kiehn-Krajcik	tyrek.kiehn.krajcik@woohoo.com	Houston	Texas	4529848293461210	018b732d989a4085694c1c0664b095d9	VISA 16 digit	29.7424919072151184	-95.3835920727826618
16164	2020-03-18 11:45:34	2020-03-18	Granville Wilderman II	granville.wilderman.ii@woohoo.com	Oakland	California	4346857158535050	e26b72b45a7e24c87f3b4383fb47e09d	Mastercard	37.7999400679966939	-122.239591828256451
16165	2020-03-18 11:46:13	2020-03-18	Sarita Lesch	sarita.lesch@geemail.com	San Francisco	California	3112765586016498241	db2ce0d13f8c4675e298bcc098e05e3d	VISA 16 digit	37.7454315698329879	-122.394332149164853
16166	2020-03-18 12:18:50	2020-03-18	Mr. Kendrick Becker DVM	mr.kendrick.becker.dvm@geemail.com	Sugar Land	Texas	4498836405072	6b5304aa6ff3d2ec254a771f6d6a0ac8	Discover	29.5082143779430517	-95.5818154095213828
16167	2020-03-18 12:29:50	2020-03-18	Phylicia Ruecker	phylicia.ruecker@geemail.com	Indianapolis	Indiana	3455027435399768	82ceaf8e48eada0690a77f3b80e36f98	JCB 15 digit	39.8382003233775492	-86.0782682921472855
16168	2020-03-18 12:37:52	2020-03-18	Dr. Spring Kiehn	dr.spring.kiehn@geemail.com	Pasadena	Texas	869926515477072828	b36c0c53e4e08b7e7676910bbd044743	Maestro	29.5799460890576249	-95.0760532505758107
16169	2020-03-18 12:38:34	2020-03-18	Xander Toy	xander.toy@warmmail.com	New York	New York	4766449429183125	125bcc85b30fb0a8e93f6c1babe2a9ae	Maestro	40.5859193553905939	-73.9615464942425405
16170	2020-03-18 12:49:03	2020-03-18	Dr. Altie Kassulke MD	dr.altie.kassulke.md@woohoo.com	New York	New York	3744543186710411	d8a6656fa8ddda0f75d0d53f18695907	Diners Club / Carte Blanche	40.6248676261622421	-73.9941491784423562
16171	2020-03-18 12:53:49	2020-03-18	Rosina Swaniawski	rosina.swaniawski@geemail.com	Sacramento	California	3477915901953080	b309e9f61c008b5ecc60259251879cff	Voyager	38.6003291736621392	-121.507282273356239
16172	2020-03-18 12:57:12	2020-03-18	Quintin Reynolds II	quintin.reynolds.ii@woohoo.com	Houston	Texas	3481167093951332	8aa5fdfd53b403d746ee7fa6e985d9c1	Maestro	29.8704466142304241	-95.4800292105894499
16173	2020-03-18 13:16:23	2020-03-18	Dr. Beecher McLaughlin	dr.beecher.mclaughlin@woohoo.com	Greensboro	North Carolina	3797462636856565	2804f244298f5f0cc54abb8302f90636	Maestro	36.1387711156740821	-79.7937866852600166
16174	2020-03-18 13:19:22	2020-03-18	Alfredo Corwin-Kutch	alfredo.corwin.kutch@warmmail.com	Portland	Oregon	3112714210407479403	eaf78220c78d0e62e089b63925943158	American Express	45.4642983073256914	-122.644960299693054
16175	2020-03-18 13:20:09	2020-03-18	Broderick Gutmann	broderick.gutmann@warmmail.com	Tacoma	Washington	4767347505229193	fc1699205c3249f829f574b6ddd31674	Voyager	47.2473932603493338	-122.49161234188378
16176	2020-03-18 13:34:53	2020-03-18	Dora Maggio	dora.maggio@geemail.com	Orange	California	4932263579422939	8d1da8d5f22378627f6531c0b79fdfb0	Maestro	33.8115672310236803	-117.828951994246992
16177	2020-03-18 13:39:18	2020-03-18	Jada Dickens	jada.dickens@geemail.com	Newport News	Virginia	4668955936657	6a52db3b4b5bfad160870e9c0b804fb2	JCB 16 digit	37.0110608011379867	-76.5898611370734983
16178	2020-03-18 13:43:17	2020-03-18	Brittney Hickle	brittney.hickle@warmmail.com	San Francisco	California	4852044523250	6f4cfecac6586a13ce21cb8e358768b7	JCB 16 digit	37.7818639661904072	-122.437912396772347
16179	2020-03-18 14:00:59	2020-03-18	Maranda Lindgren	maranda.lindgren@geemail.com	New Orleans	Louisiana	6011590108411185694	1a084fa0bd7b1334a781eb76b4f59817	American Express	30.0623396159164606	-90.0334164197351754
16180	2020-03-18 14:02:42	2020-03-18	Mr. Rudolf Fadel III	mr.rudolf.fadel.iii@warmmail.com	Los Angeles	California	3096434490306554113	a7cba8ebc9bb659f0243482c0cd200f9	Mastercard	33.9951785449270147	-118.498691093827773
16181	2020-03-18 14:07:14	2020-03-18	Miss Kierra Walker PhD	miss.kierra.walker.phd@geemail.com	Charlotte	North Carolina	55472260268093613	e649255902a5b09d521f9d5cb927f3d1	Diners Club / Carte Blanche	35.2681126710280779	-80.9220739911254583
16182	2020-03-18 14:10:34	2020-03-18	Dr. Corbin Anderson	dr.corbin.anderson@warmmail.com	Albuquerque	New Mexico	3495025559924629	af718915bc51c4c285129bccdcc6ff40	VISA 16 digit	35.2002730975527314	-106.64892669125237
16183	2020-03-18 14:26:24	2020-03-18	Aline Gulgowski	aline.gulgowski@warmmail.com	Detroit	Michigan	3031606221061248	3630922353672fde1e365debdeb9a6ed	VISA 13 digit	42.3577381893452269	-83.1894732871677718
16184	2020-03-18 14:28:21	2020-03-18	Collier O'Hara	collier.o'hara@geemail.com	Pasadena	Texas	210071968447051972	639f48f4c98e5f4ac51f1efc9d22734c	Diners Club / Carte Blanche	29.6356041900686904	-95.146933491476247
16185	2020-03-18 14:30:38	2020-03-18	Dr. Clotilde Hoppe MD	dr.clotilde.hoppe.md@geemail.com	Pembroke Pines	Florida	4897748565941	c3059c9c77198f21faee393725d8d03b	Diners Club / Carte Blanche	26.0926857896652074	-80.3271135840468133
16186	2020-03-18 14:33:28	2020-03-18	Ola Hermiston Sr.	ola.hermiston.sr.@geemail.com	Oakland	California	4331183200676330	47851a1fec4ccf80ff5d5a6136127ff6	Mastercard	37.7988716036553569	-122.268691082759972
16187	2020-03-18 14:37:32	2020-03-18	Miss Elia Shanahan	miss.elia.shanahan@geemail.com	Madison	Wisconsin	3337182418465649097	79018c0bb1e78dac8a87e246ee4c1c49	VISA 16 digit	43.1808241132620765	-89.5223433840904477
16188	2020-03-18 14:40:56	2020-03-18	Kathlene Hills	kathlene.hills@warmmail.com	Tulsa	Oklahoma	6011778035669112688	41d847680db67eda65ec966583b83f64	Mastercard	36.0430572616305156	-95.8488158536098922
16189	2020-03-18 14:54:07	2020-03-18	Ms. Christian Graham DVM	ms.christian.graham.dvm@geemail.com	Naperville	Illinois	210088954255062716	253d89df16b25f9f2427a06e97bd7379	VISA 16 digit	41.7087325283706178	-88.2146159151922973
16190	2020-03-18 15:48:15	2020-03-18	Freeda Beer	freeda.beer@geemail.com	Honolulu	Hawaii	180096098431500213	6eff8c1e699173a658e08288498d2000	JCB 16 digit	21.389019491032883	-157.93274530719259
16191	2020-03-18 16:13:38	2020-03-18	Ruthann Olson-Wunsch	ruthann.olson.wunsch@geemail.com	San Angelo	Texas	210049903594974741	f0f39a3874c434e0d5f727866079e298	JCB 15 digit	31.5378548295855516	-100.425623197073122
16192	2020-03-18 16:47:46	2020-03-18	Jase Hessel	jase.hessel@woohoo.com	Thornton	Colorado	4045476016591868	90050fb4496d377a3ac2a87f621d0f66	VISA 13 digit	39.8681827666103885	-104.880015171707797
16193	2020-03-18 16:50:04	2020-03-18	Blas Robel	blas.robel@geemail.com	Denver	Colorado	4130815843193	4d2cf3f79ca9f78f2b931b5a0ede79fe	American Express	39.729138359060137	-104.7933581935022
16194	2020-03-18 17:02:08	2020-03-18	Hymen Quitzon	hymen.quitzon@warmmail.com	Miami	Florida	869953890939934170	75a7ae12db445b17d7a0a09dca16fbe5	VISA 16 digit	25.737757587120683	-80.2208544686310034
16195	2020-03-18 17:18:43	2020-03-18	Gilford Kunde	gilford.kunde@geemail.com	Fort Wayne	Indiana	4497619407412	fac162c912fdcee92bfad93db2f79ba3	VISA 16 digit	41.0175953205924486	-85.1797175751753173
16196	2020-03-18 17:28:43	2020-03-18	Nathanael Rippin	nathanael.rippin@geemail.com	Milwaukee	Wisconsin	4083976770172980	703a74f5914377a9c4392c23ce0bc566	JCB 16 digit	42.9886753247205178	-87.9597836712475925
16197	2020-03-18 17:32:37	2020-03-18	Dr. Dorathy Sanford	dr.dorathy.sanford@geemail.com	Riverside	California	869965601270509612	f7cb7617329ff277875444d6a43ce0c1	Discover	34.0302997350640553	-117.405066833269586
16198	2020-03-18 18:04:34	2020-03-18	Alver Beier	alver.beier@warmmail.com	Dallas	Texas	501803752180590	978a71400b1b5363f39220a46ae4df08	Mastercard	32.7829823193877985	-96.7768936020284798
16199	2020-03-18 18:21:55	2020-03-18	Johnnie Hammes	johnnie.hammes@geemail.com	Mobile	Alabama	4964202206899	163f1c482154ce7f647a45c23f1ed7db	Discover	30.7606845843248067	-88.1101158579018033
16200	2020-03-18 18:27:14	2020-03-18	Brenden Jacobson	brenden.jacobson@geemail.com	New York	New York	060478176611123	1c9567a42eead1bf4d985fbce5a0fcec	Mastercard	40.6230625733956714	-73.8571868852142188
16201	2020-03-18 19:07:52	2020-03-18	Donia Schneider-Glover	donia.schneider.glover@geemail.com	Beaumont	Texas	3448518586609831	0b4748b43b9c85e11467ee2391fef6f8	VISA 16 digit	30.0169259360596534	-94.1462246638510436
16202	2020-03-18 19:24:05	2020-03-18	Courtney Erdman	courtney.erdman@warmmail.com	New York	New York	3049535791165596	1ce55a139a65d2c1c8c77c772dcebfb8	JCB 16 digit	40.5857941708285352	-74.0045663408365044
16203	2020-03-18 19:32:26	2020-03-18	Dr. Bennett Schmitt	dr.bennett.schmitt@woohoo.com	New York	New York	6011549633649165244	453ea3999cf5029350d25c0d81418f96	Voyager	40.5744126590657999	-73.9431055335223704
16204	2020-03-18 19:41:25	2020-03-18	Silas Hammes	silas.hammes@geemail.com	Lafayette	Louisiana	52042125462154688	393698138df79ee6e605a1e2aac87dfa	VISA 13 digit	30.1127995517082496	-91.9559485639762073
16205	2020-03-18 19:56:50	2020-03-18	Dr. Derrell Graham	dr.derrell.graham@geemail.com	El Paso	Texas	6011104200432146695	80a3fe14a3cd587409397b68367ec2db	VISA 16 digit	31.9216817241922044	-106.487576991317795
16206	2020-03-18 20:11:01	2020-03-18	Ms. Dayle Cummerata	ms.dayle.cummerata@woohoo.com	Tampa	Florida	3528253021670200773	1c1a49140658e0d6ffc5384cce3671cc	JCB 16 digit	27.8736149903502302	-82.3865167416844457
16207	2020-03-18 20:11:10	2020-03-18	Dickie Frami	dickie.frami@woohoo.com	Seattle	Washington	4189027186752586	2f7ad1e47a72189a244fd9158a8633c7	Voyager	47.70911815291457	-122.300088730726017
16208	2020-03-18 20:18:36	2020-03-18	Angelic Dickens	angelic.dickens@woohoo.com	Victorville	California	4072509679700743	6c557cc69bbdfe21ecb52ff05694298d	Discover	34.578264359966667	-117.374822457010296
16209	2020-03-18 20:28:11	2020-03-18	Alexandro Hackett	alexandro.hackett@geemail.com	Fresno	California	55674628024272851	091496e008529c5db6128d276cd1ab83	JCB 16 digit	36.7588345460467067	-119.844863446114218
16210	2020-03-18 20:49:24	2020-03-18	Griffin Nolan DVM	griffin.nolan.dvm@woohoo.com	Tampa	Florida	53465235502304264	d0ae537506440e901e123fa1d52027e9	JCB 16 digit	27.9775619275052101	-82.5400726262692359
16211	2020-03-18 20:53:58	2020-03-18	Sonya Barrows PhD	sonya.barrows.phd@geemail.com	Los Angeles	California	6011655189886047645	b5f1221181f9761b5ab9be12597450b0	JCB 15 digit	34.0833022684656086	-118.41332586905844
16212	2020-03-18 20:58:22	2020-03-18	Edgardo Botsford	edgardo.botsford@geemail.com	Phoenix	Arizona	869950778774639769	39ce690dbb6ee9943eb6d41324fa56bb	JCB 16 digit	33.5581177645295909	-112.095631646730382
16213	2020-03-18 21:00:26	2020-03-18	Lora Hessel	lora.hessel@woohoo.com	Colorado Springs	Colorado	676175925142830	e3cd69d891a67afa131523a8a66c18a2	Voyager	38.7781435811474893	-104.805239373647424
16214	2020-03-18 21:05:14	2020-03-18	Marrion Jast	marrion.jast@geemail.com	Moreno Valley	California	869956502986637120	314e43fbfcffefbb254b8ea0f25677d3	Discover	33.8787024301003612	-117.167222812675675
16215	2020-03-18 21:21:02	2020-03-18	Phil Donnelly III	phil.donnelly.iii@geemail.com	McKinney	Texas	4073450934452607	c575829cdde88b660ca708464b05494f	Diners Club / Carte Blanche	33.1181293137501953	-96.7471456528008105
16216	2020-03-18 21:25:00	2020-03-18	Margene Hessel	margene.hessel@geemail.com	New York	New York	210089822899256805	ee67df8e9d01de2220b921d3d4ce3a24	Diners Club / Carte Blanche	40.7357021252382552	-73.8453961064934674
16217	2020-03-18 21:30:36	2020-03-18	Kiel Morissette	kiel.morissette@geemail.com	Oakland	California	3009965643488294	81aec88647bb3cccfcd1ca4769a5bffa	VISA 16 digit	37.7989628682728096	-122.283522387699605
16218	2020-03-18 21:37:48	2020-03-18	Alcide Schimmel	alcide.schimmel@geemail.com	Richmond	California	6011037043730218382	34d542d403a28de412479fd13b3e01d1	Maestro	37.9576182713221755	-122.359207012024157
16219	2020-03-18 21:47:42	2020-03-18	Doyle Jakubowski-McGlynn	doyle.jakubowski.mcglynn@geemail.com	Philadelphia	Pennsylvania	501827453962139	4fc18cb8b9df7c3f174735129d8ba73b	JCB 15 digit	40.0563835112802664	-75.0422474909007633
16220	2020-03-18 22:04:46	2020-03-18	Vicky Murphy	vicky.murphy@geemail.com	San Diego	California	3088272939929931905	1410577286224c8b2e1199767f5a46eb	JCB 15 digit	32.8919111558303214	-117.20512192727999
16221	2020-03-18 22:18:09	2020-03-18	Dr. Aryan Schuppe	dr.aryan.schuppe@geemail.com	Salinas	California	4593857044717	50be516de76314fa68c9e6248a229e73	Discover	36.7623564429346459	-121.576482806325714
16222	2020-03-18 22:19:40	2020-03-18	Amarion Stokes	amarion.stokes@geemail.com	San Francisco	California	3008703736984411	fcf5e786704e354e73c048efcb414e36	JCB 16 digit	37.7903431121053117	-122.412249105580472
16223	2020-03-18 22:30:15	2020-03-18	Oral Rohan	oral.rohan@geemail.com	San Francisco	California	3112011364696448395	52e1fd6abbf1aef20b399b6897054b45	Mastercard	37.790128968772656	-122.441824653029954
16224	2020-03-18 22:31:08	2020-03-18	Nora McKenzie	nora.mckenzie@warmmail.com	Wichita Falls	Texas	3747973916847182	5b3ca704cdd449f8f2198a8f77721cce	JCB 16 digit	33.9020010353725425	-98.5941405842468015
16225	2020-03-18 22:36:22	2020-03-18	Miss Marleigh Casper	miss.marleigh.casper@geemail.com	Philadelphia	Pennsylvania	4055416172223	e53d28a4f1c2162e2b1a7e97815386f0	JCB 16 digit	40.0390899773646112	-75.052276134900012
16226	2020-03-18 22:41:38	2020-03-18	Mechelle Schneider	mechelle.schneider@warmmail.com	San Francisco	California	3044209180697057	b3dbc86657bf4ad38ccb2c5c0bec281c	American Express	37.7359264165686241	-122.408218240350621
16227	2020-03-18 22:48:02	2020-03-18	Eugene Cronin PhD	eugene.cronin.phd@geemail.com	Orlando	Florida	3731630588176807	9a2a70acd28b249a64a7d586b586e779	VISA 16 digit	28.4118434030827132	-81.2728416993714831
16228	2020-03-18 22:58:18	2020-03-18	Erasmo Greenholt-Keebler	erasmo.greenholt.keebler@geemail.com	San Francisco	California	3088726704573677283	76bdcff1e28c3b13e5a9fb24b8dd4908	Voyager	37.7731596533936411	-122.416047606290874
16229	2020-03-18 23:13:43	2020-03-18	Alondra Leannon	alondra.leannon@geemail.com	Durham	North Carolina	3088415658037727553	1189f9eb8a7d790be8af9ec7585f931c	Discover	35.9343425251789341	-78.8264329680144868
16230	2020-03-18 23:20:12	2020-03-18	Arther Greenholt V	arther.greenholt.v@geemail.com	New York	New York	675988405911566	b7fa80b7e89c10f3c7582efb4809cd74	Diners Club / Carte Blanche	40.6737646170649683	-73.8388983041409404
16231	2020-03-18 23:31:33	2020-03-18	Caryl Heaney	caryl.heaney@warmmail.com	Baltimore	Maryland	3488310119260766	06db13565473ba93f8fa2abf0a2fbce0	Mastercard	39.2172843608073833	-76.6854343667179421
16232	2020-03-18 23:36:28	2020-03-18	Mr. Algot Gleason PhD	mr.algot.gleason.phd@woohoo.com	Birmingham	Alabama	3337442459788621898	e9b8beb79a794ab93b962505ef8188da	Diners Club / Carte Blanche	33.539234818404168	-86.7885389260724196
16233	2020-03-19 00:15:20	2020-03-19	Luther Nolan	luther.nolan@woohoo.com	El Paso	Texas	6011153527664742613	d79cc08af439b0cb485195deff20c9f9	Diners Club / Carte Blanche	31.9364812327843168	-106.523857660822571
16234	2020-03-19 00:23:16	2020-03-19	Ulises Shields	ulises.shields@geemail.com	Roseville	California	53537561759564753	f0d9764f593053dcfa6ddcf84b4c657a	Mastercard	38.8341194309815734	-121.371273396465554
16235	2020-03-19 00:30:16	2020-03-19	Rae Dicki	rae.dicki@geemail.com	Los Angeles	California	4273623237478424	389f9c692bce10f3cc12aa83d4b417b9	JCB 16 digit	34.1016476494591672	-118.375633157649261
16236	2020-03-19 01:24:53	2020-03-19	Marley Ratke	marley.ratke@warmmail.com	San Antonio	Texas	561252822915451	a16f3f3585e10906ab3b09fc45cc6591	Maestro	29.3920257105097171	-98.5362999597400346
16237	2020-03-19 01:55:49	2020-03-19	Lavenia Trantow	lavenia.trantow@warmmail.com	Portland	Oregon	4108111776132512	68f5b0064b20f90a42b1f9e2352ae5ac	Mastercard	45.5684816720783701	-122.590945568820473
16238	2020-03-19 01:58:33	2020-03-19	Ms. Diamond Sporer	ms.diamond.sporer@geemail.com	Atlanta	Georgia	4589255467724	988b76aaf1f21c282e3f7e15f004619a	VISA 16 digit	33.8182508002776672	-84.5023641124412421
16239	2020-03-19 02:02:41	2020-03-19	Zadie Rutherford	zadie.rutherford@geemail.com	North Las Vegas	Nevada	4118068762653976	3d202275936ffc25e3f129022e17ae15	American Express	36.3542390669386819	-115.127574964122473
16240	2020-03-19 02:13:23	2020-03-19	Elijah Brakus	elijah.brakus@geemail.com	Houston	Texas	3112879122063705891	6400e1e72425af8b7b5a0a4df8ad49de	Mastercard	29.8573596841733888	-95.350907110750299
16241	2020-03-19 02:43:55	2020-03-19	Hana Kovacek	hana.kovacek@geemail.com	Chicago	Illinois	6011009372149530325	f27bb627bec551d380754ea27e84b8a1	VISA 16 digit	41.8151867527816492	-87.7408652316343023
16242	2020-03-19 02:47:28	2020-03-19	Miss Alexandrea Kreiger MD	miss.alexandrea.kreiger.md@warmmail.com	Oakland	California	53198075340719925	dba9601c85e680a432f903cc36462d16	Maestro	37.8239568129049815	-122.272011662040569
16243	2020-03-19 02:52:26	2020-03-19	Marcel Baumbach II	marcel.baumbach.ii@geemail.com	El Monte	California	6011630018992638676	33304534a0e1bb4e9c5a45447db69326	Voyager	33.9966386588945966	-118.119528317571053
16244	2020-03-19 03:00:11	2020-03-19	Ethelbert King	ethelbert.king@woohoo.com	Berkeley	California	4139659236232	ec6caea60e72363989d116e563f1d248	Voyager	37.8567922667358516	-122.25628930257318
16245	2020-03-19 03:06:14	2020-03-19	Ean Brekke	ean.brekke@geemail.com	Berkeley	California	3043666980357094	14014826c50dd5318f8ab1ac9318a361	VISA 16 digit	37.8935873764289752	-122.284829154352423
16246	2020-03-19 03:06:39	2020-03-19	Mrs. Yamilex Veum	mrs.yamilex.veum@geemail.com	San Francisco	California	3088520301392849272	86035a3e984ff2071a4a784d8efd5eae	VISA 16 digit	37.7613828369315172	-122.447140443759395
16247	2020-03-19 03:20:11	2020-03-19	Ms. Viridiana Gutmann MD	ms.viridiana.gutmann.md@geemail.com	Seattle	Washington	210032195250783313	54cf0418516ddc4004b34cbec16ea5de	JCB 16 digit	47.6352314938716574	-122.432585505667703
16248	2020-03-19 03:25:58	2020-03-19	Kelley Sipes	kelley.sipes@geemail.com	Moreno Valley	California	4771731374093646	b60778d60ab0855d00aea6064f8e9cc4	JCB 15 digit	33.9892541341476146	-117.250850650944557
16249	2020-03-19 03:26:10	2020-03-19	Candice Pouros-Larson	candice.pouros.larson@geemail.com	Jacksonville	Florida	4272295651234194	c316713cec57ed4d0610da94fd63bd3b	VISA 16 digit	30.2386523749265805	-81.6931409223083449
16250	2020-03-19 03:45:50	2020-03-19	Kade Olson	kade.olson@geemail.com	Las Vegas	Nevada	4278881623022710	6e7001802c1b34a31b017bba0d60833b	Mastercard	36.159593611872566	-115.272199656648922
16251	2020-03-19 03:53:38	2020-03-19	Skyla McClure	skyla.mcclure@woohoo.com	Palm Bay	Florida	4162151340230676	2cb509a4c91daecf419a28c4c1f4f106	JCB 16 digit	28.0056143198017047	-80.6667387321427469
16252	2020-03-19 04:03:59	2020-03-19	Margery Moore	margery.moore@warmmail.com	New York	New York	4876536455991491	c088b2d4b46b5de98f4aaf7910689af3	Maestro	40.7183686754889749	-74.0080839270155906
16253	2020-03-19 04:08:07	2020-03-19	Mr. Edwin Pouros	mr.edwin.pouros@geemail.com	Fontana	California	4929037687845	c5c2b44dc13e99376ed8ab7861219432	VISA 16 digit	34.130011916548014	-117.510411780727665
16254	2020-03-19 04:28:40	2020-03-19	Pinkey McLaughlin-Klocko	pinkey.mclaughlin.klocko@geemail.com	Las Cruces	New Mexico	6011617640154561540	ef2cfb95ea99f5750ec72b54f0887edc	Voyager	32.3838743506498616	-106.742518077709519
16255	2020-03-19 04:34:10	2020-03-19	Santino Beahan	santino.beahan@geemail.com	New York	New York	3059186390636106	7f2ff0c399ae834f1a453b7a48f6521b	Mastercard	40.6942666305918266	-73.8652569035429423
16256	2020-03-19 04:36:41	2020-03-19	Birdie Robel	birdie.robel@geemail.com	Philadelphia	Pennsylvania	869939717243305236	f7526a5fff12bed6e688b6d2b19905c0	Voyager	40.063197886101527	-75.0600454581800847
16257	2020-03-19 04:43:28	2020-03-19	Artie Adams	artie.adams@geemail.com	El Monte	California	4237453077982	c679e4efbc099ab1b3c601e0c884c2e2	Maestro	34.0228174656819533	-118.103225384958463
16258	2020-03-19 04:54:31	2020-03-19	Axel Purdy	axel.purdy@woohoo.com	San Francisco	California	4040963768664	fff4117fceaa788d422df4f01407183c	VISA 16 digit	37.7966820292421488	-122.429015735972996
16259	2020-03-19 05:14:38	2020-03-19	Denine D'Amore	denine.d'amore@geemail.com	El Paso	Texas	4046313624440	069cde6b413219265ec76be7313bbf32	Voyager	31.9012672286309318	-106.387748143354443
16260	2020-03-19 05:15:31	2020-03-19	Devon Lindgren	devon.lindgren@geemail.com	New York	New York	3703511307572399	6d31ce232786e4193935623a20f49771	Maestro	40.7247875911872796	-73.9312834129098775
16261	2020-03-19 05:27:40	2020-03-19	Manson Blick	manson.blick@geemail.com	Fairfield	California	3737009409094883	a10cf4c9c7526d4b491dd1c0ba72f8e6	Diners Club / Carte Blanche	38.3446325913660289	-121.934017561423033
16262	2020-03-19 05:28:18	2020-03-19	Alexina Hilll	alexina.hilll@geemail.com	Cleveland	Ohio	501840917465623	c67059f52e216a14f21c4a999cbf1c3c	Maestro	41.4688212194330958	-81.7714464558526828
16263	2020-03-19 05:58:58	2020-03-19	Quinn Spencer	quinn.spencer@geemail.com	Los Angeles	California	3720828086673761	a0e46be42ce80f9b554164a631948369	VISA 16 digit	34.0329795932263082	-118.454769363346685
16264	2020-03-19 06:45:46	2020-03-19	Marc Keeling	marc.keeling@geemail.com	San Francisco	California	4371450295503484	43ea29ace73fe8720e2f2f6800fcaf53	American Express	37.7692776035222053	-122.416889244652836
16265	2020-03-19 07:03:04	2020-03-19	Oneta Wolf DVM	oneta.wolf.dvm@geemail.com	Las Vegas	Nevada	3737187088557329	d40b96f4321274bd426e1d17c78e376a	VISA 16 digit	36.2475572908397723	-115.209122880336267
16266	2020-03-19 07:05:37	2020-03-19	Colon Ullrich-Rodriguez	colon.ullrich.rodriguez@geemail.com	West Covina	California	4973681471136069	fa176ef4f249ce55bc9ffba9e69409cd	Voyager	34.0761020790427906	-117.949127969665071
16267	2020-03-19 07:27:51	2020-03-19	Stewart Boehm	stewart.boehm@geemail.com	Dallas	Texas	52161843426875934	f1389cce53c42b67dfa9b8596acdca58	Diners Club / Carte Blanche	32.7758372223276666	-96.7098707979973398
16268	2020-03-19 07:29:29	2020-03-19	Mr. Jayvon Schaefer Sr.	mr.jayvon.schaefer.sr.@geemail.com	Denver	Colorado	4518070809453358	3f8b7fec58ff2c8a13b366f4491cb8a2	JCB 15 digit	39.7428169036336243	-104.790649765568233
16269	2020-03-19 07:50:47	2020-03-19	Ms. Madge Zulauf	ms.madge.zulauf@geemail.com	Colorado Springs	Colorado	4119795211653	a57024865d8995970dedf5b20ac5f05d	Voyager	38.9428706701893361	-104.73511230588592
16270	2020-03-19 07:54:09	2020-03-19	Dr. Rory Doyle	dr.rory.doyle@geemail.com	Berkeley	California	4286777793436062	04b3b25f47c749ce6dc94e8f55cf218a	VISA 16 digit	37.8753810216774909	-122.264451728464493
16271	2020-03-19 08:00:26	2020-03-19	Brittaney Huel	brittaney.huel@geemail.com	El Paso	Texas	210035830170903941	9f17c3f692bd160be2ab4d26ca0c9fec	Maestro	31.868024132104221	-106.511248041734106
16272	2020-03-19 08:02:55	2020-03-19	Lovisa Block-Dickens	lovisa.block.dickens@geemail.com	San Diego	California	3337287159313956680	c04f5bef345d28d5d276cc29fbc32fbf	VISA 16 digit	32.7408656036082633	-117.074066642429685
16273	2020-03-19 08:07:00	2020-03-19	Mrs. Tiffany Hauck	mrs.tiffany.hauck@geemail.com	Lakewood	Colorado	3528677107733322098	8b7b763b7e06672e4213d26a4ecbe52a	VISA 13 digit	39.7329374343562876	-105.03727003736644
16274	2020-03-19 08:12:01	2020-03-19	Elmina Veum	elmina.veum@geemail.com	Simi Valley	California	4538213552708406	82630564e3403a575707ac603a8f458b	JCB 15 digit	34.1670683462411162	-118.77143711942621
16275	2020-03-19 08:17:13	2020-03-19	Eboni Aufderhar	eboni.aufderhar@geemail.com	San Antonio	Texas	6011689132226192762	ffe1ab86d05be5376a61d3991c378ed4	JCB 16 digit	29.3939261512901631	-98.5968687370721142
16276	2020-03-19 08:20:22	2020-03-19	Kamden Mann	kamden.mann@warmmail.com	Berkeley	California	4067612133933	5274bf182ff7b23601f43305384e032a	JCB 15 digit	37.8743234462933174	-122.248082320740536
16277	2020-03-19 08:23:59	2020-03-19	Idell Walter	idell.walter@warmmail.com	Waco	Texas	4768967122814165	59d358df3a55ad0bdf5bb25178accedb	JCB 15 digit	31.5562414739955202	-97.1199033608790501
16278	2020-03-19 08:34:22	2020-03-19	Dr. Marley Will	dr.marley.will@geemail.com	Los Angeles	California	6011022198147683359	9362414426acdfb372f9d8a51afb2c87	VISA 16 digit	34.0417206157330412	-118.486195157467563
16279	2020-03-19 08:36:06	2020-03-19	Mr. Minoru Nicolas	mr.minoru.nicolas@woohoo.com	Mesa	Arizona	3025472787534235	fe5e76291e0eb6acd2d592329e698d45	Diners Club / Carte Blanche	33.3579404872987411	-111.716281624359638
16280	2020-03-19 08:37:11	2020-03-19	Danielle Fisher	danielle.fisher@geemail.com	San Francisco	California	3096396179855525907	78fa6ae445cc748e557fb249b803c416	VISA 13 digit	37.7867012592557145	-122.442084087884751
16281	2020-03-19 08:56:01	2020-03-19	Helaine Pfannerstill	helaine.pfannerstill@geemail.com	Salinas	California	55081744092107056	69fb95b60d5a36f8aa006bf384a7d71f	JCB 16 digit	36.613323781755561	-121.704073447518795
16282	2020-03-19 09:08:26	2020-03-19	Jalisa Considine-Hudson	jalisa.considine.hudson@geemail.com	San Francisco	California	180060196938464412	b47b300edd12e5e5b257c7dbb0b2a543	VISA 16 digit	37.7558108104535322	-122.428362519710305
16283	2020-03-19 09:11:03	2020-03-19	Mrs. Odell Lindgren PhD	mrs.odell.lindgren.phd@geemail.com	Lexington	Kentucky	3420644802072497	a3eede794670ce6a89a04f084451dbcb	JCB 15 digit	38.1101627053569985	-84.4091786083199054
16284	2020-03-19 09:40:32	2020-03-19	Louisa O'Keefe	louisa.o'keefe@warmmail.com	Indianapolis	Indiana	6011000057507414688	9efeccccb6cd717c61cb288588a9226a	JCB 16 digit	39.7599030232064408	-86.2431476674709501
16285	2020-03-19 09:49:30	2020-03-19	Ms. Zina Goodwin	ms.zina.goodwin@geemail.com	Milwaukee	Wisconsin	676331938786139	196714ff3e78906da0c5e9096c3def89	American Express	43.1277893594086166	-88.0045821765072702
16286	2020-03-19 10:23:34	2020-03-19	Mrs. Dottie Mayert	mrs.dottie.mayert@geemail.com	Sparks	Nevada	210056732109611807	e1ba61f04ef709d047076ade39972a5a	JCB 16 digit	39.4992643376119474	-119.638164453100785
16287	2020-03-19 10:42:36	2020-03-19	Flo Tromp	flo.tromp@warmmail.com	Corpus Christi	Texas	4302576611275169	6441d66bd43439e62bc55696f4f3a38f	JCB 15 digit	27.8281363180309533	-97.2431882517240922
16288	2020-03-19 10:52:23	2020-03-19	Manley Reichel	manley.reichel@warmmail.com	Phoenix	Arizona	53607113489023711	6a5cd0065dff4c80cb6895245a046d79	American Express	33.4743356953308009	-112.165245838223399
16289	2020-03-19 11:07:46	2020-03-19	Tal Willms	tal.willms@geemail.com	Coral Springs	Florida	3337276781552425300	c97008d34b28c898236f1f2cabd0bc79	VISA 13 digit	26.3399710894160002	-80.3480348769698196
16290	2020-03-19 11:24:23	2020-03-19	Malia Homenick-Boehm	malia.homenick.boehm@geemail.com	Tacoma	Washington	3045520087298180	f4cdec61cf06b54fa1ffe4a408f2e745	VISA 16 digit	47.3085469835091388	-122.495795865566663
16291	2020-03-19 11:29:58	2020-03-19	Mr. Donavan Goodwin IV	mr.donavan.goodwin.iv@warmmail.com	Lubbock	Texas	4418744721190378	73ee0ef9c266e1a4398451172318c7a2	JCB 16 digit	33.4895844414405559	-101.964471311858674
16292	2020-03-19 11:34:56	2020-03-19	Payton Turcotte	payton.turcotte@geemail.com	Pompano Beach	Florida	4876824923059129	ebdc852a4030d684318abaaf4edce2b0	Discover	26.1558729364335534	-80.1638071215558767
16293	2020-03-19 11:44:40	2020-03-19	Dr. Sam Raynor	dr.sam.raynor@warmmail.com	Grand Rapids	Michigan	869995074706196574	f53e3ad223adb23614c94338b1462466	VISA 16 digit	42.9992617319606225	-85.5710660104308403
16294	2020-03-19 12:03:25	2020-03-19	Dr. Marcia Purdy PhD	dr.marcia.purdy.phd@geemail.com	Oakland	California	52334895585421944	afaca8dd62754c1b5a6c5163e50160df	VISA 16 digit	37.7842950386457304	-122.239299888225261
16295	2020-03-19 12:11:09	2020-03-19	Terrance Bruen	terrance.bruen@woohoo.com	San Francisco	California	869980091309682849	9ec6a0d3997b6970a517d3df235c3aec	Voyager	37.7949509737161051	-122.459017731732374
16296	2020-03-19 12:25:21	2020-03-19	Felipe Glover	felipe.glover@geemail.com	Dallas	Texas	6011379540449442175	713faffcaa1b67b04d81f56ac5355da4	VISA 16 digit	32.735947104803472	-96.7013962117917742
16297	2020-03-19 12:38:09	2020-03-19	Lita Nicolas	lita.nicolas@geemail.com	Philadelphia	Pennsylvania	52046461324699891	bfe9e2338b2b521fb211f28a452087a3	VISA 16 digit	40.0673803655389662	-75.1735400511316953
16298	2020-03-19 12:38:49	2020-03-19	Wendi Batz PhD	wendi.batz.phd@geemail.com	Charlotte	North Carolina	3051193213077458	6c9540587758bd3d51cabe4c64c7c6a3	JCB 15 digit	35.2448957173872728	-80.8843213816117554
16299	2020-03-19 12:45:06	2020-03-19	Mrs. Jemima Pouros	mrs.jemima.pouros@geemail.com	Norfolk	Virginia	869909334725168235	d49a042e08071e9e80b92dd0868037ca	JCB 16 digit	37.0109649430979033	-76.1616367614831802
16300	2020-03-19 13:03:23	2020-03-19	Karyme Larkin-Schneider	karyme.larkin.schneider@warmmail.com	Rochester	New York	3035806929425150	4df61e801c73092dd8128cfef8bcefc1	JCB 16 digit	43.0924152268540084	-77.6978095853474002
16301	2020-03-19 13:32:41	2020-03-19	Bedford Turcotte	bedford.turcotte@warmmail.com	San Francisco	California	4355623283081883	13ab02b0919d93842a6177bd0e59b09f	JCB 15 digit	37.793299617859077	-122.417659275775534
16302	2020-03-19 13:40:01	2020-03-19	Lester Tromp-DuBuque	lester.tromp.dubuque@woohoo.com	Berkeley	California	4534055052428355	c742d1930eae7089dbef69209964f901	JCB 15 digit	37.8625956805955255	-122.231527710473628
16303	2020-03-19 13:45:36	2020-03-19	Sherilyn Wilderman	sherilyn.wilderman@woohoo.com	Mobile	Alabama	4390016406995195	cb8dfeec9226d9020025d85f7a11cf30	American Express	30.5971877035327253	-88.0445830177653619
16304	2020-03-19 13:47:17	2020-03-19	Mr. Ozie Weber	mr.ozie.weber@geemail.com	Columbus	Ohio	3158587282059816368	835222f7d0969eaad4d658f81c714339	JCB 16 digit	40.0588013995483507	-83.019323717360578
16305	2020-03-19 13:51:08	2020-03-19	Dr. Carlton Lesch	dr.carlton.lesch@geemail.com	Saint Paul	Minnesota	3112599961295735849	d3fb87e03573d92c0a68e454f64ae157	Voyager	44.996454922429848	-93.1002343429982631
16306	2020-03-19 13:54:40	2020-03-19	Ason Jacobi-Bins	ason.jacobi.bins@geemail.com	Abilene	Texas	4340496260884324	0f31f1198cbf6ed91666b8c46ad40a77	Voyager	32.5003664009813278	-99.7788131690997631
16307	2020-03-19 14:14:39	2020-03-19	Kendal Nader	kendal.nader@warmmail.com	Worcester	Massachusetts	503833334637551	e9ab28726d1487c8d16065e0bd5357cb	Diners Club / Carte Blanche	42.3548161021135741	-71.7217759362675196
16308	2020-03-19 14:16:26	2020-03-19	Dr. Rohan Schroeder	dr.rohan.schroeder@geemail.com	Berkeley	California	869985144399693047	84f5624b9b26b9361ee0721907e12a1a	JCB 16 digit	37.8483569215421625	-122.243757235020823
16309	2020-03-19 14:18:43	2020-03-19	Robbie Hane	robbie.hane@geemail.com	San Francisco	California	4235413157247729	8f14e2fcb5ea6203a02541590f7898db	American Express	37.8415192826016309	-122.431535304512678
16310	2020-03-19 14:21:14	2020-03-19	Shantell Ledner	shantell.ledner@geemail.com	New York	New York	180011616580913812	afaf3762079de9c11650e28dd021c450	JCB 15 digit	40.7264065888933828	-73.9994383095193626
16311	2020-03-19 14:33:12	2020-03-19	Edwardo Wyman	edwardo.wyman@geemail.com	Hollywood	Florida	4419361322474	067fc2b3d1003a23b67569779602e523	JCB 16 digit	26.0439220148082811	-80.2382196187790413
16312	2020-03-19 14:52:05	2020-03-19	Baylee Beier	baylee.beier@geemail.com	Edison	New Jersey	3337940303349118050	7ea1aa624b8b384893ad30c41737a5d5	American Express	40.4063855531588203	-74.4276019113190443
16313	2020-03-19 15:04:49	2020-03-19	Daisha Braun	daisha.braun@geemail.com	Houston	Texas	6011580171651398650	a41b5c2c7b26743681af0f03c4c4e82b	Mastercard	29.8577812524590627	-95.3798253584668032
16314	2020-03-19 15:37:17	2020-03-19	Mr. Ronin Koch III	mr.ronin.koch.iii@geemail.com	Thornton	Colorado	3337530977683694358	5f41492e3566a9a170578823934cb116	VISA 16 digit	39.9582065374456405	-105.027346884568416
16315	2020-03-19 15:37:27	2020-03-19	Vashon Sipes	vashon.sipes@warmmail.com	Pasadena	California	4225401955656	9d597267303462cfc3a847cef236f97a	Maestro	34.0954439233843232	-118.224750681715463
16316	2020-03-19 16:07:24	2020-03-19	Slade Jaskolski IV	slade.jaskolski.iv@woohoo.com	Portland	Oregon	3478528427011959	ac26027e32c9dca20fbbba2520ba26a8	Diners Club / Carte Blanche	45.4443008905630563	-122.657486126339066
16317	2020-03-19 16:26:24	2020-03-19	Linwood Wuckert	linwood.wuckert@geemail.com	Baltimore	Maryland	3027877899068625	af5a1f4cbaef0ed0d60c76ec38d79b4e	American Express	39.3770925607066573	-76.565189087951552
16318	2020-03-19 16:26:47	2020-03-19	Bartley Wuckert	bartley.wuckert@geemail.com	Buffalo	New York	4508967852791	71a3b91c45412d5d9f59a29b65f63789	Mastercard	42.9471568215824675	-78.8835855012692519
16319	2020-03-19 16:30:34	2020-03-19	Brannon Glover	brannon.glover@geemail.com	Pittsburgh	Pennsylvania	3056599556407422	f362eb8e0ea4c4972ab8546288978cf6	JCB 16 digit	40.5064684700176088	-79.880335965490346
16320	2020-03-19 16:34:15	2020-03-19	Jethro Johnson	jethro.johnson@geemail.com	Tulsa	Oklahoma	210099375807108178	c5c47cb2f7b878d0eb65ba5234748d5f	VISA 13 digit	36.165368652101229	-95.8741696446623592
16321	2020-03-19 16:57:13	2020-03-19	Encarnacion Feest V	encarnacion.feest.v@woohoo.com	San Francisco	California	180023364438859319	2de0c7364d390da097b3189568e78f25	VISA 16 digit	37.8321862304023142	-122.428849873114117
16322	2020-03-19 16:59:59	2020-03-19	Odell Wolf-Hagenes	odell.wolf.hagenes@geemail.com	Louisville	Kentucky	55474754712129252	1508f33603fd4fa8e7f3bd295eb46934	VISA 16 digit	38.189597136703874	-85.6417865276407468
16323	2020-03-19 17:29:28	2020-03-19	Hernan Rowe	hernan.rowe@geemail.com	Eugene	Oregon	180030277830431860	22e6a4530cfb9bf5a67de12b80de6867	VISA 16 digit	43.9954654552701854	-123.079415549429882
16324	2020-03-19 18:02:35	2020-03-19	Clarnce Cormier	clarnce.cormier@geemail.com	Irving	Texas	4891226460774642	5f005097d00b9e5381c644bbf77369f9	Diners Club / Carte Blanche	32.8719484896816354	-97.0296898918040114
16325	2020-03-19 18:10:54	2020-03-19	Hazen Gusikowski	hazen.gusikowski@woohoo.com	Phoenix	Arizona	3112008634559821283	72186b524d6ea3ecbb59509741e98f92	American Express	33.4723051400322476	-112.048446660668034
16326	2020-03-19 18:13:49	2020-03-19	Keagan Barton	keagan.barton@geemail.com	Joliet	Illinois	4529441331614568	274f7fb2fb9d11392af955a31a8458e7	VISA 16 digit	41.5424734550386674	-88.2344405919883314
16327	2020-03-19 18:19:23	2020-03-19	Bowman Lueilwitz	bowman.lueilwitz@geemail.com	Springfield	Massachusetts	502047096949889	c35464a88545e1ff0cbbbd34026e9772	VISA 16 digit	42.1587913508266183	-72.6171852284669939
16328	2020-03-19 18:19:38	2020-03-19	Tanika Thiel	tanika.thiel@warmmail.com	San Francisco	California	6011250648218529587	930d7437aebc4842ed9967c91126a460	JCB 15 digit	37.7626421430355492	-122.429383780087065
16329	2020-03-19 18:24:47	2020-03-19	Helyn Huel	helyn.huel@geemail.com	Garland	Texas	54603037468978666	90e0079d1eb854a3a504214de4fc4df8	Diners Club / Carte Blanche	32.9261392279297098	-96.7079836978737291
16330	2020-03-19 18:26:07	2020-03-19	Zelda Bergnaum	zelda.bergnaum@woohoo.com	Oakland	California	3009501728288646	f336b4fc9ec621f736e682cad54e2cf4	Diners Club / Carte Blanche	37.8163210850484433	-122.230027754687953
16331	2020-03-19 18:31:56	2020-03-19	Matt Orn	matt.orn@geemail.com	Phoenix	Arizona	869935800278388048	5b04652b55ade2af6f7af7bf588ac63f	JCB 16 digit	33.5041216918200249	-112.14142078556344
16332	2020-03-19 18:37:44	2020-03-19	Lauren Stroman	lauren.stroman@geemail.com	Corpus Christi	Texas	3112080992985867374	ac580939cb0cba17e34f4a50f1a90aa6	Maestro	27.8343085878930978	-97.2042046777732622
16333	2020-03-19 18:57:08	2020-03-19	Mortimer Windler	mortimer.windler@warmmail.com	San Francisco	California	3096089743953418802	cb8cc965a3a624e3198776db2f5cb8d4	JCB 16 digit	37.8022686312667844	-122.450896255912184
16334	2020-03-19 19:05:14	2020-03-19	Montie Jaskolski-Predovic	montie.jaskolski.predovic@geemail.com	Los Angeles	California	3096299833648962185	24272e640fe4e539e6687742d28c8e08	American Express	34.0820568254083369	-118.414310106867177
16335	2020-03-19 19:07:15	2020-03-19	Katerina Kulas-Kris	katerina.kulas.kris@geemail.com	San Francisco	California	4016170485148673	71e8c8502375134caa98f37a99f319da	JCB 16 digit	37.7629830086881455	-122.444785959893679
16336	2020-03-19 19:08:45	2020-03-19	Amani Marvin	amani.marvin@geemail.com	Dallas	Texas	4572425736889541	e70dbe305665e7e0f2f2e884bb9cd67f	Diners Club / Carte Blanche	32.6988422828532777	-96.8421640168838138
16337	2020-03-19 19:21:47	2020-03-19	Ms. Katerina O'Reilly	ms.katerina.o'reilly@geemail.com	San Francisco	California	869935704727491009	17d6cfe0b95382d35c56cb66beba0955	Discover	37.7635073231392582	-122.455961863042305
16338	2020-03-19 19:37:48	2020-03-19	Agatha Kassulke	agatha.kassulke@warmmail.com	Chula Vista	California	3528042450549588975	acc5ff38b6eb998deebdacf037421484	VISA 13 digit	32.6945644336517844	-116.958568164217098
16339	2020-03-19 19:56:23	2020-03-19	Kalvin Murray	kalvin.murray@geemail.com	North Las Vegas	Nevada	3740574656290034	ffbcd6af1fcb7372726c7aebab9c6e25	VISA 16 digit	36.2320593674357951	-115.157455635698142
16340	2020-03-19 19:56:36	2020-03-19	Rosena Orn	rosena.orn@geemail.com	Los Angeles	California	3059648394906959	f62d2292ce0c872537f018f0f8935076	Maestro	34.0654680553689602	-118.433843341422445
16341	2020-03-19 19:57:43	2020-03-19	Jaylen Von	jaylen.von@geemail.com	Lancaster	California	676378654048707	ae61bb69ab72812031972c5d50912a9c	JCB 15 digit	34.6989261932451285	-118.102666116223844
16342	2020-03-19 20:01:21	2020-03-19	Aimee Heidenreich PhD	aimee.heidenreich.phd@geemail.com	San Francisco	California	3337368636978962436	a65558dd4041ccd671ae1c0ee84031dd	VISA 13 digit	37.7909279187571414	-122.427907313523264
16343	2020-03-19 20:06:22	2020-03-19	Dejon Kuhic	dejon.kuhic@geemail.com	Chattanooga	Tennessee	4231182176173	a8860677ba951a4c630a73b707d31c05	Maestro	35.0698191931322256	-85.1591921213377248
16344	2020-03-19 20:06:45	2020-03-19	Jeanmarie Lesch	jeanmarie.lesch@warmmail.com	Rialto	California	676355095839712	f4f4321ead5eb9a6dff06630d9d60093	American Express	34.1327894842468211	-117.374848267118637
16345	2020-03-19 20:07:14	2020-03-19	Mr. Lamonte Dietrich V	mr.lamonte.dietrich.v@geemail.com	Washington	District of Columbia	4611391799694330	6db5188323a50144cabf4ef28e985e12	Mastercard	38.9443215238660585	-76.9967263345353388
16346	2020-03-19 20:34:36	2020-03-19	Tana Hauck-Wilderman	tana.hauck.wilderman@geemail.com	Los Angeles	California	3112635655398273254	462a0c2e8e5194e23f73c52e243361b2	JCB 16 digit	34.0723127540066812	-118.434599050366501
16347	2020-03-19 20:54:43	2020-03-19	Dorinda Wilkinson	dorinda.wilkinson@geemail.com	Clearwater	Florida	4191990380067521	d18837c2e9fa145766b25d5046e648bb	Voyager	27.9679514968428755	-82.7011634813886047
16348	2020-03-19 20:58:16	2020-03-19	Ms. Nyah Kirlin DVM	ms.nyah.kirlin.dvm@woohoo.com	Fort Worth	Texas	676183186645103	265d5357538ec43268d5d23930ca7add	Mastercard	32.798266480542722	-97.2975264028932827
16349	2020-03-19 21:00:00	2020-03-19	Miss Lylah Reilly	miss.lylah.reilly@geemail.com	New York	New York	4989036882666935	03406b43f11c42e9e411735868858381	Mastercard	40.6988115409146971	-73.9548089016124521
16350	2020-03-19 21:01:35	2020-03-19	Dr. Deryl Schimmel MD	dr.deryl.schimmel.md@woohoo.com	Milwaukee	Wisconsin	3047419317175722	ac374046e27e814e06fa0e94948d56ab	Discover	43.1213327188596125	-87.9992617596972764
16351	2020-03-19 21:03:51	2020-03-19	Shonna Weber-Kerluke	shonna.weber.kerluke@geemail.com	Paterson	New Jersey	4121067298764	85c97bf61ea2bb53e7ce0b6d12c9b341	JCB 16 digit	40.9130642638031361	-74.2407420748818652
16352	2020-03-19 21:13:42	2020-03-19	Fredie Olson	fredie.olson@geemail.com	Denver	Colorado	4781057736857884	ae1895d108bc480ca896cff69ccdd32e	Discover	39.7320953661162406	-104.789597525285927
16353	2020-03-19 21:26:55	2020-03-19	Santa Huels	santa.huels@geemail.com	San Francisco	California	4346875636200907	31f3977554ccb53a7a842698ed6041b1	American Express	37.774487238489229	-122.414792545286261
16354	2020-03-19 21:35:02	2020-03-19	Mr. Durell Boyle	mr.durell.boyle@geemail.com	New York	New York	4285376710557943	912f2f6d686d149fe7b6bdbd0043b660	VISA 16 digit	40.6612472265716605	-74.0040288587462101
16355	2020-03-19 21:35:53	2020-03-19	Darrian Runte	darrian.runte@geemail.com	San Francisco	California	4525114359819	47f541e3452278f85a63f0689bb66d45	JCB 15 digit	37.7368141728785176	-122.473747167713526
16356	2020-03-19 21:51:41	2020-03-19	Pam Dickinson PhD	pam.dickinson.phd@woohoo.com	Seattle	Washington	3096198428300544017	c36c4f92cf4899e6b3fea4c736165bd3	JCB 16 digit	47.6036610091030568	-122.416441275124996
16357	2020-03-19 22:22:29	2020-03-19	Alfred Wolf-Mante	alfred.wolf.mante@geemail.com	Garden Grove	California	4956406509596964	6d1b02d73045dda9103b16b6f82c376d	VISA 16 digit	33.7254417477466149	-117.947429636122649
16358	2020-03-19 22:39:49	2020-03-19	Dr. Rod Gutmann Jr.	dr.rod.gutmann.jr.@woohoo.com	St. Louis	Missouri	6011802093531336605	e5d28892ba5f04a21eb9fa294acc9206	VISA 16 digit	38.733510962004587	-90.2954549530524844
16359	2020-03-19 22:40:48	2020-03-19	Hugo Sauer	hugo.sauer@geemail.com	Kenosha	Wisconsin	6011903128770534060	8cfa660e31d169a378c3c7bfc16f3add	JCB 16 digit	42.6093728486753989	-87.8270429090358391
16360	2020-03-19 22:46:52	2020-03-19	Dr. Alonzo Nicolas III	dr.alonzo.nicolas.iii@geemail.com	Aurora	Colorado	4719117082659487	34ba2e31c6861f5acf614829da37de52	Mastercard	39.668168859008702	-104.712862280302502
16361	2020-03-19 22:56:15	2020-03-19	Leander Mante	leander.mante@geemail.com	Anaheim	California	6011140166529350886	3cc76e89f71d0732dbb6fb8ceb3bbed3	JCB 16 digit	33.9089214657731333	-117.844066937428337
16362	2020-03-19 23:12:58	2020-03-19	Heyward Little	heyward.little@woohoo.com	Berkeley	California	3528221744486892553	cdacb848a00e2dbcaacc30aa1947ec9e	JCB 15 digit	37.8460678751385231	-122.287699109274868
16363	2020-03-19 23:20:36	2020-03-19	Mrs. Mya Kohler PhD	mrs.mya.kohler.phd@warmmail.com	Honolulu	Hawaii	55729699634398365	2f96651b669541b848c30d413217b449	Discover	21.2954481973994518	-157.904710076816741
16364	2020-03-19 23:20:50	2020-03-19	Roxie Hickle DVM	roxie.hickle.dvm@geemail.com	Seattle	Washington	4705411664712715	42043f9b273df5d2b2b89657ece465e0	VISA 13 digit	47.7024708918221307	-122.260551677776121
16365	2020-03-19 23:34:20	2020-03-19	Capitola Hamill-Mills	capitola.hamill.mills@geemail.com	San Antonio	Texas	51145245808699067	cbae08f36c284b13c2819583144947e2	Mastercard	29.3979171884316948	-98.4902613065972901
16366	2020-03-19 23:48:29	2020-03-19	Chauncey Watsica	chauncey.watsica@warmmail.com	San Antonio	Texas	3493643888759227	1477d65460af2f3598717c46edf75f51	Discover	29.4018260454829772	-98.6202992599293538
16367	2020-03-19 23:48:35	2020-03-19	Bryanna Ward-Hegmann	bryanna.ward.hegmann@geemail.com	Los Angeles	California	3096694582592507105	8bd546e219a89d4f56cd7c08ab29e0bd	JCB 15 digit	33.9530706895381158	-118.486586021025843
16368	2020-03-19 23:53:04	2020-03-19	Alijah Armstrong	alijah.armstrong@geemail.com	Fort Worth	Texas	3158094764191150752	4037e13e2d353854d388e549b3e425da	Discover	32.8488488818574709	-97.3526924318455116
16369	2020-03-20 00:06:26	2020-03-20	Namon Fisher	namon.fisher@geemail.com	Peoria	Arizona	3337244541589736775	bc64598b350fe71ffe4037f442b3c2f8	Maestro	33.8611369950033705	-112.303441845990719
16370	2020-03-20 00:16:15	2020-03-20	Mr. Fletcher Moore	mr.fletcher.moore@geemail.com	Spokane	Washington	3096694640691584159	0c887f703fb27b91145a6ef1f5d924e8	American Express	47.5870269054319692	-117.465176128260055
16371	2020-03-20 00:37:16	2020-03-20	Luke Reynolds	luke.reynolds@geemail.com	Las Vegas	Nevada	4164690590999611	082f5e9f571fcf91a581bc688787abf4	Discover	36.1539900500427933	-115.181774564899868
16372	2020-03-20 00:53:40	2020-03-20	Burr Larkin-Schaefer	burr.larkin.schaefer@warmmail.com	Chicago	Illinois	676111550268681	64c568d1f3d0ed989cb031fe6cf50734	Mastercard	41.7961475486703264	-87.7003861747246134
16373	2020-03-20 00:59:37	2020-03-20	Buster Friesen	buster.friesen@woohoo.com	Los Angeles	California	54610927784642205	332d0613b542c6dd28f49f48f81d2dee	Mastercard	34.0420238246541444	-118.359081500069422
16374	2020-03-20 01:07:53	2020-03-20	Kalel D'Amore	kalel.d'amore@geemail.com	Elizabeth	New Jersey	54571715932458732	fbf3364c44c6380f61075de467249065	VISA 13 digit	40.6042697049338415	-74.2621520571354807
16375	2020-03-20 01:37:17	2020-03-20	Sharee Graham PhD	sharee.graham.phd@woohoo.com	San Francisco	California	630407703898788	192a0309847af421bec00337c7be3617	American Express	37.7709639582170666	-122.428926213589918
16376	2020-03-20 02:05:36	2020-03-20	Remington Walker	remington.walker@warmmail.com	Philadelphia	Pennsylvania	3528728774163039895	1049778508622c785a6c41894154db05	JCB 15 digit	40.0270208358258017	-75.134574109026417
16377	2020-03-20 02:17:36	2020-03-20	Mr. Lenord Green I	mr.lenord.green.i@geemail.com	Houston	Texas	3112716191623899715	102b7ea804b85dcdf8aef25ae317330b	VISA 16 digit	29.7832321511194102	-95.3248964709244717
16378	2020-03-20 02:37:45	2020-03-20	Markus Ward	markus.ward@geemail.com	Dallas	Texas	210031136303943018	0eadb6c6fc5f6461d42f51bca1a6f779	VISA 16 digit	32.8142472113288974	-96.7245124293919645
16379	2020-03-20 02:38:30	2020-03-20	Carlie Medhurst	carlie.medhurst@geemail.com	San Francisco	California	4691284948411834	30060ec354c5effe0effdf9072f38e33	Maestro	37.7642317519148278	-122.423654812330824
16380	2020-03-20 02:42:24	2020-03-20	Melva Schroeder	melva.schroeder@geemail.com	San Francisco	California	4847777480587	d1737ea990b5e15861b4c42cd96c1e74	Maestro	37.7385858769287097	-122.418763367355652
16381	2020-03-20 02:50:04	2020-03-20	Idabelle Wunsch	idabelle.wunsch@warmmail.com	Lubbock	Texas	180067873549334472	8fbdfa28f5e318a5aa1e33cdd93166f1	Discover	33.635084720379119	-101.918521386050443
16382	2020-03-20 02:56:50	2020-03-20	Lavon Kuphal	lavon.kuphal@geemail.com	Columbus	Georgia	3088357750435235683	74aba25850cf5b6532b0a600d7486f0e	Discover	32.5102400107819562	-84.8478682240169491
16383	2020-03-20 03:07:29	2020-03-20	Dr. Donal Goyette Jr.	dr.donal.goyette.jr.@geemail.com	San Diego	California	4786377086892579	b86d5f3cf68a94bb6e0cd05934603a8b	VISA 13 digit	32.812758589216692	-117.156255235373976
16384	2020-03-20 03:21:30	2020-03-20	Kareem Kirlin	kareem.kirlin@geemail.com	New York	New York	060496674360605	fe207da90972da496636de41e56b63ea	Voyager	40.7363599287103852	-73.9756698870461378
16385	2020-03-20 03:21:33	2020-03-20	Miss Joleen Lesch	miss.joleen.lesch@woohoo.com	McKinney	Texas	3528256185155192834	d340ac95c520b67afe14ab8beeca8c37	JCB 15 digit	33.2388994549997179	-96.7179048413708813
16386	2020-03-20 03:32:50	2020-03-20	Gaylen O'Connell V	gaylen.o'connell.v@woohoo.com	Los Angeles	California	3008470929727813	49b4a9fad6803d23547fdacbcbbaa75d	VISA 16 digit	34.0388576962385301	-118.368780092661453
16387	2020-03-20 03:48:28	2020-03-20	Sherilyn Bartell	sherilyn.bartell@geemail.com	Houston	Texas	3746065128949103	4c7e533b732feb4293116431e3fe1a4f	Diners Club / Carte Blanche	29.7033635892983519	-95.3398888735115548
16388	2020-03-20 03:49:58	2020-03-20	Cristine Wuckert	cristine.wuckert@geemail.com	Cleveland	Ohio	51133602061579051	47a8652c460f0f72455663d0d33830b9	VISA 13 digit	41.3991918717827616	-81.6208805318228912
16389	2020-03-20 04:05:02	2020-03-20	Tangela Rohan MD	tangela.rohan.md@geemail.com	Sacramento	California	3112841616823907858	85192df77a9a25456e74a551f02c7d0f	VISA 16 digit	38.583123438133299	-121.513528203243752
16390	2020-03-20 04:10:16	2020-03-20	Dona Shields-Tremblay	dona.shields.tremblay@geemail.com	South Bend	Indiana	210057841573549101	51a8c15fece7811367ec801b21eeedd4	Mastercard	41.766106206798554	-86.2351901712417686
16391	2020-03-20 04:12:48	2020-03-20	Charissa Lowe-Legros	charissa.lowe.legros@woohoo.com	Rialto	California	4082067486488	67990290481f9f072a536f78ba965f86	Diners Club / Carte Blanche	34.1425270293124044	-117.452241457448523
16392	2020-03-20 04:32:36	2020-03-20	Rossie Rohan-Goldner	rossie.rohan.goldner@woohoo.com	Fort Worth	Texas	4790485934182996	1343cfb87cbc52308b357903a701760b	Maestro	32.8136597815491271	-97.4408880867816549
16393	2020-03-20 05:19:25	2020-03-20	Whitney Armstrong	whitney.armstrong@geemail.com	San Jose	California	3337067852188112613	3336929866df9fd018614167ac9ecf95	JCB 16 digit	37.3210373079225448	-121.767335802944004
16394	2020-03-20 05:46:02	2020-03-20	Angelo Kassulke	angelo.kassulke@geemail.com	San Francisco	California	180033257159426946	cbb02c0b49ba4200bbbc4773a1e116ca	Voyager	37.783118310299578	-122.422005191325908
16395	2020-03-20 06:08:25	2020-03-20	Dr. Mitzi Hahn	dr.mitzi.hahn@geemail.com	Green Bay	Wisconsin	869960239755204923	108032bea95a570fc7b815c69b4cbb52	JCB 16 digit	44.5355554618004703	-88.0325399684075336
16396	2020-03-20 07:36:56	2020-03-20	Mr. Jiles Doyle III	mr.jiles.doyle.iii@warmmail.com	Santa Ana	California	869907404590384290	8ea530d75725e9855f5f89589c280dcf	Diners Club / Carte Blanche	33.7328094405226437	-117.961743259143077
16397	2020-03-20 07:39:06	2020-03-20	Rashawn Cremin	rashawn.cremin@geemail.com	Clarksville	Tennessee	6011097091592267366	0f58e831664d59e7f5ec42617e8b3d2f	JCB 16 digit	36.5289566212460386	-87.4069922630626763
16398	2020-03-20 07:39:14	2020-03-20	Leanne Fritsch	leanne.fritsch@geemail.com	Los Angeles	California	3730364585650793	b72a16fe33b3ed61bd8e248475442d48	Discover	34.0571908885944623	-118.381716316937656
16399	2020-03-20 08:04:01	2020-03-20	Shawnda Kuhn	shawnda.kuhn@warmmail.com	Billings	Montana	675965852022386	4f6bb9994588c98071e44654f9b93fc4	Mastercard	45.8429304870069032	-108.526303856044635
16400	2020-03-20 08:07:27	2020-03-20	Jaheim Lang	jaheim.lang@woohoo.com	Huntsville	Alabama	4093171420003128	aeacd599672b7d657d2da72fcd4b7d4a	Voyager	34.6849272736590351	-86.6910753740016418
16401	2020-03-20 08:07:35	2020-03-20	Serina Pfannerstill	serina.pfannerstill@warmmail.com	Chesapeake	Virginia	869932563550750599	edec0d31f0581449a9a02e438ab525d7	Maestro	36.724464768055455	-76.2425942183781444
16402	2020-03-20 08:07:47	2020-03-20	Eddie Mann	eddie.mann@geemail.com	Salem	Oregon	3776124684653550	6d821368f8fc8dd8be6e11861fb520cc	VISA 16 digit	44.9112039767473874	-123.108791463837775
16403	2020-03-20 08:37:33	2020-03-20	Antonia Dare	antonia.dare@woohoo.com	Sterling Heights	Michigan	3158158467832596085	6d9e70820eaeda8343db4b7b3e2d4505	Mastercard	42.5621277893044052	-83.0737227935969855
16404	2020-03-20 08:40:54	2020-03-20	Bonita Christiansen-Ward	bonita.christiansen.ward@geemail.com	Detroit	Michigan	4363827029931224	6ce0e2cf6165e921b9d8deb8f62fcabb	VISA 16 digit	42.4664928087424514	-83.0234363003287399
16405	2020-03-20 08:44:28	2020-03-20	Zelma Leffler PhD	zelma.leffler.phd@geemail.com	Boise	Idaho	55496086982089773	fbdc3fd6632c92e732867a55a6c91995	JCB 16 digit	43.6859449914794453	-116.296596020991728
16406	2020-03-20 08:48:27	2020-03-20	Moira Collier	moira.collier@geemail.com	Berkeley	California	4488838119730	106fe5598e3dee252919fc6e86d85803	Discover	37.8703915243286886	-122.275390031580031
16407	2020-03-20 09:03:47	2020-03-20	Dr. Frank Swift DDS	dr.frank.swift.dds@woohoo.com	Providence	Rhode Island	869930272072560047	f1aaed9cac04bcc5544260ae21985891	VISA 16 digit	41.8878772148717147	-71.5154308576054945
16408	2020-03-20 09:34:30	2020-03-20	Miss Taya Reichel	miss.taya.reichel@geemail.com	San Francisco	California	3722479713758985	664505aeaf473faa65338eb955ef9c85	Voyager	37.7871134485577969	-122.413710990750516
16409	2020-03-20 09:45:47	2020-03-20	Dr. Jill Muller	dr.jill.muller@geemail.com	San Francisco	California	6011998341822279826	52f319bb0097d1e633797861bf93176f	American Express	37.7873640045067916	-122.413265269747598
16410	2020-03-20 09:59:15	2020-03-20	Clint Ledner	clint.ledner@geemail.com	San Francisco	California	6011771525043153363	7933b7b19fa4ee4b338f49d112fd49e4	Diners Club / Carte Blanche	37.7385257027616987	-122.429803703583673
16411	2020-03-20 10:04:48	2020-03-20	Misti Breitenberg-Adams	misti.breitenberg.adams@geemail.com	Seattle	Washington	869996398342448571	6ee7d3a85405125c6bb4597d9d4b3e5e	VISA 13 digit	47.6357153549715875	-122.377931078189604
16412	2020-03-20 10:06:10	2020-03-20	Miss Gisselle Kilback PhD	miss.gisselle.kilback.phd@warmmail.com	West Jordan	Utah	3112196166900057301	d0d53bec77659168a0ed812f4e77da0d	JCB 16 digit	40.5851643144410161	-112.014531875224037
16413	2020-03-20 10:36:31	2020-03-20	Marina Stokes-Mueller	marina.stokes.mueller@geemail.com	Los Angeles	California	4266822608986374	832c293a3e3e9543d17e2c6b7f18158e	Voyager	34.0072016557078811	-118.410549282980327
16414	2020-03-20 10:51:10	2020-03-20	Kyler Mosciski	kyler.mosciski@geemail.com	Lincoln	Nebraska	55340490190652901	72b33220446243195a470e0d3a2df6a3	JCB 16 digit	40.8457315141819421	-96.640092123269298
16415	2020-03-20 11:04:54	2020-03-20	Dr. Esau Zulauf	dr.esau.zulauf@geemail.com	Bridgeport	Connecticut	869987418877158741	e4b265e0b52dd1cded7229536df2506d	JCB 16 digit	41.1276427015826087	-73.1367862924832934
16416	2020-03-20 11:28:11	2020-03-20	Casen Hagenes-Aufderhar	casen.hagenes.aufderhar@geemail.com	San Francisco	California	3746047055639592	27e155a98ebef397804b5400891c5eb4	JCB 16 digit	37.7976644025521225	-122.446008875713147
16417	2020-03-20 11:28:26	2020-03-20	Perla Glover	perla.glover@geemail.com	Nashville	Tennessee	675969394997006	393495bdf0bb2de8766e263c98a154ed	JCB 16 digit	36.1281266099430596	-86.8657854707818444
16418	2020-03-20 11:33:52	2020-03-20	Kyler O'Conner	kyler.o'conner@geemail.com	Berkeley	California	869924075991174941	380651dee701f93f50502fb6a40fc370	VISA 16 digit	37.8672818908122508	-122.251218347253371
16419	2020-03-20 11:40:49	2020-03-20	Elroy Schiller	elroy.schiller@geemail.com	Austin	Texas	675904250063940	760badf0625f13d4bf854d6092629f35	Maestro	30.3845457268539789	-97.845290675922854
16420	2020-03-20 11:57:37	2020-03-20	Orilla Medhurst	orilla.medhurst@geemail.com	Phoenix	Arizona	210054287454268929	2e70ede3f17a93e113b22b7997bb9196	American Express	33.4978629151292182	-112.12514710230046
16421	2020-03-20 12:01:16	2020-03-20	Miss Alycia Hickle	miss.alycia.hickle@woohoo.com	Los Angeles	California	501821400069346	8c0afa7f5c41db3728f23d83b6b886e6	VISA 16 digit	34.1030910945829007	-118.320975674827764
16422	2020-03-20 12:03:21	2020-03-20	Ms. Ola Welch DDS	ms.ola.welch.dds@geemail.com	Oakland	California	869975894530620539	c7db3a157abddada08ff9eac8e825cd3	Mastercard	37.7841314311732077	-122.270730058658415
16423	2020-03-20 12:27:02	2020-03-20	Cain Kreiger	cain.kreiger@geemail.com	Austin	Texas	3337817819313933927	d141cce07e0edaabd3581e59735e8b67	Mastercard	30.3899392628703247	-97.6562262946512618
16424	2020-03-20 12:40:43	2020-03-20	Jaylen Oberbrunner	jaylen.oberbrunner@warmmail.com	Henderson	Nevada	210061314990876907	bfced28b2bfd263f9787249abb3c99f1	Diners Club / Carte Blanche	35.9962888151805842	-115.066636806788679
16425	2020-03-20 13:07:29	2020-03-20	Dayami Bogan	dayami.bogan@geemail.com	Salinas	California	869983644808688696	d598b6315f263541feb56446fbf5b076	Discover	36.7146126498699132	-121.619551788613947
16426	2020-03-20 13:28:53	2020-03-20	Ezekiel Beer	ezekiel.beer@geemail.com	Akron	Ohio	4354088277222821	cb7b2f2b224df4107c126e1eec1cd936	Discover	41.0474399542268387	-81.4809640876796095
16427	2020-03-20 13:48:16	2020-03-20	Verna Metz	verna.metz@geemail.com	Long Beach	California	51615225830671376	c598f22e630bd2ca9eea6fa6e8656c64	JCB 15 digit	33.7635979149311751	-118.169426787707209
16428	2020-03-20 14:07:45	2020-03-20	Jedidiah Bernier	jedidiah.bernier@warmmail.com	Memphis	Tennessee	3051339508331965	70504e5e4ac96946eba0f7f14ccfec49	Voyager	35.0366532088790095	-89.9722992809746387
16429	2020-03-20 14:11:02	2020-03-20	Kristi Bednar	kristi.bednar@geemail.com	Chicago	Illinois	3773043737678484	23062924cdafd6acc5c932b0c009094d	Discover	41.9263130337301675	-87.6208759564004822
16430	2020-03-20 14:27:32	2020-03-20	Shane Predovic	shane.predovic@woohoo.com	San Francisco	California	6011910687009044960	91c6b5ed35953066eff636d9ffeaf4e8	Maestro	37.7914319577690776	-122.458977893396394
16431	2020-03-20 14:37:16	2020-03-20	Neppie Kilback	neppie.kilback@geemail.com	Austin	Texas	3337210869209655707	eb85854408cf3fec21f82c02cc2f188d	Maestro	30.2925086710263045	-97.6827062151633214
16432	2020-03-20 14:38:41	2020-03-20	Lars Heller	lars.heller@geemail.com	Wichita	Kansas	3470985644107721	cd84e4a50bca7c54be7512e43d247956	Voyager	37.7806262839462619	-97.32903895887695
16433	2020-03-20 15:03:42	2020-03-20	Shena Quigley	shena.quigley@warmmail.com	Bellevue	Washington	4883456191078415	60cb7bb1238ef92ce84e0cf29c79de90	JCB 15 digit	47.600005499710889	-122.212829556787383
16434	2020-03-20 15:16:10	2020-03-20	Bernard Parisian II	bernard.parisian.ii@geemail.com	Berkeley	California	6011455045458741555	61730f9a6d24cfcc9c104c467cd06c75	American Express	37.8816368874416156	-122.289111702089855
16435	2020-03-20 15:19:20	2020-03-20	Ms. Carolann Homenick MD	ms.carolann.homenick.md@geemail.com	Sioux Falls	South Dakota	6011396505269684197	c03e5c6de213b07c57573dc4114e0852	JCB 16 digit	43.5960922580763679	-96.6735836074855115
16436	2020-03-20 15:21:08	2020-03-20	Dr. Clarke Crooks	dr.clarke.crooks@geemail.com	Billings	Montana	4422676269869	41417a719cb53a9264b44f864e2657f2	VISA 13 digit	45.7047127227988099	-108.54749240327402
16437	2020-03-20 15:21:18	2020-03-20	Lorenza Heaney	lorenza.heaney@woohoo.com	San Francisco	California	3158278234545977738	b8c7223e741798b84d15e610488c738c	Mastercard	37.7731234316921487	-122.435898462833762
16438	2020-03-20 15:29:11	2020-03-20	Mirtie O'Kon	mirtie.o'kon@geemail.com	Dallas	Texas	869934901845402675	ff7d39b15afc693364125e3f065b3eed	JCB 15 digit	32.8268286239627756	-96.8138800924140952
16439	2020-03-20 15:50:00	2020-03-20	Sena Kris	sena.kris@geemail.com	Mobile	Alabama	53743638120730097	7b413da841744ae8d301e488e88e5a00	Diners Club / Carte Blanche	30.673076597053182	-88.1660209684304874
16440	2020-03-20 15:52:19	2020-03-20	Rosalinda Macejkovic	rosalinda.macejkovic@geemail.com	Denver	Colorado	675949483645237	ef18cbf42bb67ebdae5ae091f92b1ad2	American Express	39.8113971458334461	-104.94904647327624
16441	2020-03-20 16:02:16	2020-03-20	Rillie Heaney	rillie.heaney@warmmail.com	Huntington Beach	California	676389943578081	b9619ba644868a1ec132f5f8697dabbe	JCB 16 digit	33.7807705173775616	-118.015676402173185
16442	2020-03-20 16:03:11	2020-03-20	Rondal Beahan	rondal.beahan@geemail.com	San Francisco	California	4375276022395779	89a9c457de4aba930f0e9bb00ff6931f	Mastercard	37.7665009914273497	-122.406436852565975
16443	2020-03-20 16:05:34	2020-03-20	Jonnie Hauck Sr.	jonnie.hauck.sr.@woohoo.com	Rochester	New York	3096454188562909733	585e2c2fb254633a661cb7547ad64c9e	American Express	43.1493122010003773	-77.5266740495577409
16444	2020-03-20 16:21:35	2020-03-20	Arnulfo Kozey	arnulfo.kozey@geemail.com	San Jose	California	6011255358138595784	7cfed664965d09e8745448f21f7f5e46	Mastercard	37.3252875191446378	-121.721538666145506
16445	2020-03-20 16:27:03	2020-03-20	Mr. Marshall Morar	mr.marshall.morar@geemail.com	Nashville	Tennessee	54819264504540850	fb5251042f1d6c8590f55eb8f3bd3983	JCB 16 digit	36.1939224428154489	-86.7214464671350953
16446	2020-03-20 16:44:05	2020-03-20	Manerva Wintheiser	manerva.wintheiser@geemail.com	Pasadena	Texas	4889121714858719	1997ad847b93d406549b70d21fc57fb2	VISA 16 digit	29.7158723499033606	-95.2232093643810629
16447	2020-03-20 16:46:32	2020-03-20	Alicia Bosco DVM	alicia.bosco.dvm@geemail.com	New York	New York	6011217191835189263	46c021acb6962b02de45f2a7ac6d5342	Voyager	40.6612402014192185	-73.9480646416440521
16448	2020-03-20 16:56:25	2020-03-20	Teddie Padberg	teddie.padberg@geemail.com	Davie	Florida	4431932862569913	dcb9bf0aa566513c9b35aa140195a5dd	VISA 16 digit	26.0197242860015479	-80.220261744773012
16449	2020-03-20 17:04:16	2020-03-20	Darrick Zemlak	darrick.zemlak@woohoo.com	Cleveland	Ohio	210046737156678263	be9d1f55f3b580a37851243fdd0b4ade	JCB 15 digit	41.3856163292974202	-81.6715570692211372
16450	2020-03-20 17:08:07	2020-03-20	Mr. Harland Mills MD	mr.harland.mills.md@geemail.com	San Antonio	Texas	4054054331401317	43e2771c60b902fc57180ef757997e2c	VISA 13 digit	29.4648250484444212	-98.4679289639763482
16451	2020-03-20 17:20:31	2020-03-20	Dr. Quinten Boyer III	dr.quinten.boyer.iii@geemail.com	Los Angeles	California	180035879015758606	bc84b7c5f466d879761ccc7a2e8a3021	Mastercard	34.0214771708339399	-118.347440643747518
16452	2020-03-20 17:30:35	2020-03-20	Martha Bruen	martha.bruen@geemail.com	Fargo	North Dakota	676271773931721	cb1c4d0f2b3f77fd615ebb4229ff614a	Maestro	46.8536612122550622	-96.9111320262737479
16453	2020-03-20 17:39:10	2020-03-20	Greyson Howell	greyson.howell@geemail.com	Chattanooga	Tennessee	4454379666965347	23d8acd0ffa739c3ff3e5f44e56e6f0c	VISA 13 digit	35.0500021166950475	-85.3348708818029706
16454	2020-03-20 17:39:40	2020-03-20	Denny Kub	denny.kub@geemail.com	New York	New York	3456711852945539	ee04e3337b3054591d20765df0e1d2fc	Maestro	40.607021872162818	-74.0000007957115713
16455	2020-03-20 17:42:42	2020-03-20	Olof Zulauf	olof.zulauf@warmmail.com	Anchorage	Alaska	4941241980563896	fe2ec9923a23e032ae8a3ac42fc454fe	VISA 16 digit	61.1452824529942163	-149.304898866092032
16456	2020-03-20 17:56:27	2020-03-20	Chalmers Greenholt-McKenzie	chalmers.greenholt.mckenzie@warmmail.com	Denton	Texas	4532045290204	f82f033cac05e6dd029926a0d99e224d	JCB 15 digit	33.1441190481916053	-97.1379576231479689
16457	2020-03-20 18:50:36	2020-03-20	Kailee Graham	kailee.graham@woohoo.com	Phoenix	Arizona	4193285095133298	fcd92aef1cc8b3d7dda8c934fe52a340	Voyager	33.5105421902544833	-112.141800194412852
16458	2020-03-20 19:03:01	2020-03-20	Mr. Donavon Mitchell	mr.donavon.mitchell@woohoo.com	Charlotte	North Carolina	210083011315293149	488f9acc43c1b67ed209374878e95be0	VISA 16 digit	35.2053116904824961	-80.8979170183595357
16459	2020-03-20 19:11:03	2020-03-20	Luis Schinner-Kirlin	luis.schinner.kirlin@geemail.com	Chula Vista	California	869973821564806918	643e5a471e09853375557aeb143dc39b	JCB 16 digit	32.5934545936293887	-117.02228026932552
16460	2020-03-20 19:18:33	2020-03-20	Woodie Torphy III	woodie.torphy.iii@geemail.com	Long Beach	California	3052266019298855	2746f6ecef50d287009b9afc98d9e92b	Discover	33.8147107639636815	-118.196710265909502
16461	2020-03-20 19:20:54	2020-03-20	Janet Nikolaus-Hammes	janet.nikolaus.hammes@woohoo.com	Oakland	California	4384486138146656	f20ac74051b2a331d5a9ffb024efa34f	VISA 16 digit	37.7499594257428868	-122.270650889606074
16462	2020-03-20 19:44:43	2020-03-20	Debora Huels	debora.huels@warmmail.com	Chicago	Illinois	3528266418936426066	756768a821f87a788fb43880354b367b	Diners Club / Carte Blanche	41.8926842638127539	-87.6281031935505581
16463	2020-03-20 19:57:42	2020-03-20	Tod Glover	tod.glover@geemail.com	Berkeley	California	3055024390800386	50eb22ff3813a3ed6853793db94a8289	JCB 15 digit	37.8650912321329614	-122.290175547189961
16464	2020-03-20 20:27:52	2020-03-20	Harlon Volkman	harlon.volkman@geemail.com	Clarksville	Tennessee	3096159531398529670	a207325d8b60bcdf22a508e48a751649	Diners Club / Carte Blanche	36.5537314755968765	-87.356310174609348
16465	2020-03-20 20:31:45	2020-03-20	Mr. Loran Heller	mr.loran.heller@geemail.com	San Antonio	Texas	3727986488561100	e56fedbec38d9e0ab412f99fdec4aa99	Mastercard	29.3959101386904713	-98.4572859923191288
16466	2020-03-20 20:33:53	2020-03-20	Shelvie Jaskolski	shelvie.jaskolski@geemail.com	San Francisco	California	180068775114829639	08b724e27be16de1e62752069e8e179c	JCB 15 digit	37.7738620541356553	-122.433146456902989
16467	2020-03-20 20:35:03	2020-03-20	Jean Leannon	jean.leannon@geemail.com	Glendale	California	3337481470969860470	d09d7a0ff5348c071a4582894acdfe78	American Express	34.2688204969499211	-118.269700138773032
16468	2020-03-20 20:38:31	2020-03-20	Cassie Rodriguez	cassie.rodriguez@geemail.com	Peoria	Arizona	869914858418907551	9a4bc6c320959129ed2bf358f29c2f44	Discover	33.7450691201992328	-112.297925036765648
16469	2020-03-20 21:01:19	2020-03-20	Ms. Teressa Hane	ms.teressa.hane@geemail.com	San Francisco	California	52776902233256618	390e8c12690559faf3d3cb7aab37d92f	JCB 16 digit	37.7712239575994815	-122.469478821115842
16470	2020-03-20 21:08:08	2020-03-20	Kristine Hudson DDS	kristine.hudson.dds@geemail.com	Grand Prairie	Texas	3005341872563856	2b6f0bf23eae495e4a786571a070d3b9	VISA 16 digit	32.6966415484022335	-97.0858246473468824
16471	2020-03-20 21:13:35	2020-03-20	Florrie Bogisich	florrie.bogisich@woohoo.com	Elgin	Illinois	3112317334312818744	d9e2237bdae41c6bed83fc7d739919c1	VISA 13 digit	42.1339684965372072	-88.3015952810000755
16472	2020-03-20 21:37:16	2020-03-20	Ashton Harris	ashton.harris@geemail.com	San Francisco	California	4291381776777	983c14ce6c48ab7b0d85e6a7e3466fe6	Diners Club / Carte Blanche	37.8099749721963647	-122.420182430488197
16473	2020-03-20 21:47:30	2020-03-20	Shawn Treutel	shawn.treutel@geemail.com	Seattle	Washington	4800678171380897	987668494a85048d1c13a6275477f5a0	American Express	47.6467543184217064	-122.368621413541575
16474	2020-03-20 21:48:55	2020-03-20	Jamie Hansen Sr.	jamie.hansen.sr.@geemail.com	San Francisco	California	4749846783378310	73e353ac8fb73c7d1b8153fac7a00bd0	Maestro	37.7864238905914789	-122.436524067162892
16475	2020-03-20 21:49:04	2020-03-20	Felipe Armstrong	felipe.armstrong@geemail.com	San Francisco	California	3528601354414427694	3f74c8a2a1b016a3691ebc3bed0de977	Diners Club / Carte Blanche	37.7619592079331454	-122.43699229293037
16476	2020-03-20 21:54:22	2020-03-20	Davie Buckridge	davie.buckridge@geemail.com	San Francisco	California	180043560589192212	4d835da10b0e834c10d0dc83ea5c2d75	JCB 16 digit	37.76805777763078	-122.424357610398985
16477	2020-03-20 22:04:58	2020-03-20	Mrs. Naoma Bode	mrs.naoma.bode@woohoo.com	Palm Bay	Florida	3088792639883910603	9639dc41960b800997fe0fcc822101f0	Diners Club / Carte Blanche	27.9728756402939567	-80.7170394539669189
16478	2020-03-20 22:21:13	2020-03-20	Bartholomew Zemlak	bartholomew.zemlak@woohoo.com	San Francisco	California	4138218492633170	2447829894c018b709c933ea235cf019	JCB 16 digit	37.7598421698282962	-122.400726236325667
16479	2020-03-20 22:43:33	2020-03-20	Marylin Dickinson	marylin.dickinson@woohoo.com	Chicago	Illinois	6011750661056822894	2ba63de40e26151b74759e8c9d98936b	JCB 16 digit	41.7886597440879797	-87.763852708091207
16480	2020-03-20 22:49:11	2020-03-20	Cordia Pfannerstill	cordia.pfannerstill@woohoo.com	Alexandria	Virginia	3158804429583604920	3dd37e7ff835de8f91d70885788a726e	JCB 16 digit	38.8347384241059359	-77.0640270272720613
16481	2020-03-20 22:50:52	2020-03-20	Carlie Fritsch	carlie.fritsch@woohoo.com	San Francisco	California	3042411714634026	1c30fa5eb20c611893c830e2aa525049	VISA 13 digit	37.8176057123601979	-122.406227110618133
16482	2020-03-20 23:14:33	2020-03-20	Leandra Parisian	leandra.parisian@geemail.com	San Francisco	California	6011249399366353008	3292abc730362203c52dc8b553aa98b6	Voyager	37.7580969018324382	-122.430808695067327
16483	2020-03-20 23:15:30	2020-03-20	Benedict Cruickshank-Lindgren	benedict.cruickshank.lindgren@geemail.com	Berkeley	California	4921264458321146	6232b3d42523e4e594592758764be724	JCB 15 digit	37.8369458651462338	-122.308411725315622
16484	2020-03-20 23:25:41	2020-03-20	Marlin Altenwerth DVM	marlin.altenwerth.dvm@warmmail.com	San Francisco	California	3449240374925928	e861a3544f7638871f5d49876af29955	JCB 16 digit	37.8013035228743348	-122.442884647013315
16485	2020-03-21 00:01:23	2020-03-21	Graydon Jerde-McKenzie	graydon.jerde.mckenzie@geemail.com	San Francisco	California	210033093577491877	357816855d53f07f62141199fe493ff1	JCB 16 digit	37.752130423619576	-122.423318130255339
16486	2020-03-21 00:05:25	2020-03-21	Mr. Leonidas Zemlak DDS	mr.leonidas.zemlak.dds@geemail.com	Pasadena	Texas	210050722415331758	c72659f6389d07808ccd678201ca419a	VISA 16 digit	29.5669728500176205	-95.2412474322546245
16487	2020-03-21 00:06:11	2020-03-21	Brantley Jenkins	brantley.jenkins@geemail.com	Concord	California	6011698468040513380	e3cc435fffed0b409282354fa6567bd7	VISA 13 digit	38.0524967065013939	-122.052625640964507
16488	2020-03-21 00:09:47	2020-03-21	Sarita Steuber	sarita.steuber@geemail.com	Orlando	Florida	3793058291827224	c5edd200f2ebff6f46b97de850af4f90	American Express	28.3661242296252389	-81.3123181269004931
16489	2020-03-21 00:14:41	2020-03-21	Pansy Pfannerstill	pansy.pfannerstill@woohoo.com	Mesquite	Texas	210038310968672583	a3af3574d5f668d50bb0350006232753	VISA 16 digit	32.7893053245075095	-96.6468449184402942
16490	2020-03-21 00:18:41	2020-03-21	Ms. Marti Barton MD	ms.marti.barton.md@woohoo.com	New York	New York	3761551390291142	b1467110c94ee69d990ea2d27eb8f043	Discover	40.5757932775877421	-74.0110597893025641
16491	2020-03-21 00:20:33	2020-03-21	Dr. Emmett Gusikowski V	dr.emmett.gusikowski.v@geemail.com	Arlington	Texas	3337674634242804459	8d031c94932a4e744e2c633598808859	JCB 16 digit	32.6674466093786009	-97.1660822377566262
16492	2020-03-21 00:36:57	2020-03-21	Tomie Hammes	tomie.hammes@warmmail.com	Oakland	California	3439382509623465	ff8db3eafc3d6903fc86836f9159ba7f	VISA 13 digit	37.8296081401025859	-122.277528652236526
16493	2020-03-21 00:43:40	2020-03-21	Hank Koelpin	hank.koelpin@geemail.com	Sparks	Nevada	4709707327866988	f8c432504634270f5fcd6d28619a83fb	Mastercard	39.6244377437286062	-119.735034823077171
16494	2020-03-21 00:46:55	2020-03-21	Dr. Lilyanna Grady MD	dr.lilyanna.grady.md@geemail.com	Westminster	Colorado	3112977184869117664	4f27f2338b99309df35511e933f45656	VISA 16 digit	39.9495226664774066	-105.044886173648393
16495	2020-03-21 00:47:53	2020-03-21	May Pollich	may.pollich@geemail.com	Elizabeth	New Jersey	3405986985646780	ed63a87c6f0df12a6e96704f4c763295	Maestro	40.7519245585087688	-74.1198418924529108
16496	2020-03-21 00:50:20	2020-03-21	Tyesha McCullough-Purdy	tyesha.mccullough.purdy@geemail.com	San Francisco	California	210063972705624637	d71f3b8ffa8f67ec570f28dbb89761cf	VISA 13 digit	37.7832198034220852	-122.410279026250635
16497	2020-03-21 00:55:00	2020-03-21	Amy Lesch	amy.lesch@warmmail.com	Spokane	Washington	639071062172201	7f750d406d2d924d0fa7b745113513b2	VISA 16 digit	47.6970391020882829	-117.483384119802338
16498	2020-03-21 00:58:15	2020-03-21	Journey Wehner	journey.wehner@geemail.com	Westminster	Colorado	3096422914115296362	2854e4533146f3d8e5e1c0f48e85c01f	Voyager	39.9371287057016033	-105.093540340117741
16499	2020-03-21 01:11:42	2020-03-21	Evan Larson IV	evan.larson.iv@geemail.com	Greensboro	North Carolina	4579893135738028	2a001b3fda6b3ae25eeb7cc24c108c0a	VISA 13 digit	36.002523823000864	-79.875341417824842
16500	2020-03-21 01:21:36	2020-03-21	Dr. Ballard Erdman	dr.ballard.erdman@geemail.com	Springfield	Missouri	6011519009370147857	4165b1aa685b843ec22b1b7ca7858cea	Mastercard	37.1194301779109992	-93.2603118492115328
16501	2020-03-21 01:29:23	2020-03-21	Manuel Kris	manuel.kris@geemail.com	San Francisco	California	4892332643803123	b9868a88a7761e8b1bc7493cbb64fc99	Maestro	37.7769539256949258	-122.458841457969001
16502	2020-03-21 01:32:22	2020-03-21	Wash Wisozk PhD	wash.wisozk.phd@warmmail.com	San Francisco	California	4796743411064705	c8de438f7b8a9e25973cc0ef9347151a	VISA 13 digit	37.7782218365967779	-122.431107228853847
16503	2020-03-21 01:36:44	2020-03-21	Royal Schuster	royal.schuster@geemail.com	Phoenix	Arizona	639002299340964	da241115feee58c33a30cbcb905005f3	VISA 16 digit	33.4798943882275424	-112.178434418553863
16504	2020-03-21 01:45:08	2020-03-21	Ms. Connie Stracke DDS	ms.connie.stracke.dds@geemail.com	New York	New York	4720847278275	544551224232e5420fb4b71f2c86397e	JCB 15 digit	40.6012283254172672	-73.9444739816140384
16505	2020-03-21 01:52:46	2020-03-21	Lula Hessel	lula.hessel@warmmail.com	Jacksonville	Florida	869926508024980700	55a6cad31d5bf5169e5133ce9b1a335c	VISA 16 digit	30.2964204480923698	-81.6370634369164776
16506	2020-03-21 01:54:49	2020-03-21	Jairo Aufderhar	jairo.aufderhar@geemail.com	San Francisco	California	4866171923631537	9cc13b5063c566442d29c8fa2e35149a	JCB 16 digit	37.7750578561183801	-122.410529166460847
16507	2020-03-21 01:55:46	2020-03-21	Alberta Thiel	alberta.thiel@warmmail.com	San Francisco	California	3337657930920851312	ab4dd4929b673bb151ac9a07f83fe49a	VISA 16 digit	37.7691468273154101	-122.384143928941583
16508	2020-03-21 01:57:05	2020-03-21	Tella Klein	tella.klein@geemail.com	Little Rock	Arkansas	6011567261247044012	3c08a2e7f5c5ff7ab02914522e7c823e	Voyager	34.6362724379912024	-92.2943900429051354
16509	2020-03-21 02:04:24	2020-03-21	Mittie Lehner	mittie.lehner@geemail.com	Seattle	Washington	3528767667381400240	91b250aac8642ece2e5ff188a90bce9e	VISA 16 digit	47.652550457922743	-122.391361168019102
16510	2020-03-21 02:10:28	2020-03-21	Elle Kshlerin DVM	elle.kshlerin.dvm@geemail.com	Los Angeles	California	630416705193635	c8d7411787a45116a5a0c8d76f9c536d	VISA 13 digit	34.061896876744548	-118.330006311786548
16511	2020-03-21 02:27:23	2020-03-21	Francies Bergstrom	francies.bergstrom@geemail.com	San Francisco	California	210033675329677603	279970c8be5ca677e8dff2434f719d39	Discover	37.778549981427922	-122.423602386570096
16512	2020-03-21 02:42:51	2020-03-21	Quincy Flatley IV	quincy.flatley.iv@geemail.com	Independence	Missouri	3528037952958366212	bd1f3b02a4f19d1557ffe14a7f5304f0	VISA 13 digit	39.0552920095641198	-94.3097008639298338
16513	2020-03-21 02:46:40	2020-03-21	Cesar Price	cesar.price@geemail.com	Miami Gardens	Florida	3050777779243578	5d6390edf50945984e64c17f2c3e0ab8	Diners Club / Carte Blanche	25.9958814488198584	-80.1701359530225375
16514	2020-03-21 02:48:17	2020-03-21	Myrta Kuhlman	myrta.kuhlman@geemail.com	Sandy Springs	Georgia	54561609769635342	ca030582a6d33374209dc6025c8449b0	Diners Club / Carte Blanche	33.9114583327490848	-84.2760543809820035
16515	2020-03-21 02:58:53	2020-03-21	Armin Runte MD	armin.runte.md@geemail.com	Orlando	Florida	3096489709312200625	c5c15d52183c80498d3f75abac0ae5cf	American Express	28.3303428193353106	-81.313453591611605
16516	2020-03-21 03:02:24	2020-03-21	Burr Shanahan	burr.shanahan@geemail.com	Jacksonville	Florida	4727017287523	ae69d6ece802a18a14ab3f9500aaa7b9	American Express	30.3108551119972027	-81.6038753467690299
16517	2020-03-21 03:05:26	2020-03-21	Glover Blanda	glover.blanda@geemail.com	Phoenix	Arizona	6011128063973089019	03ea6d18888099c771eec87b2d36b130	VISA 13 digit	33.6210228062167786	-112.163213336414103
16518	2020-03-21 03:11:36	2020-03-21	Grayling VonRueden	grayling.vonrueden@geemail.com	Jacksonville	Florida	4456414577645775	57251e813a8ed9d4307e5b1c694a71d3	VISA 13 digit	30.2403462750889354	-81.5814843077290845
16519	2020-03-21 03:32:09	2020-03-21	Marla Farrell-Hermiston	marla.farrell.hermiston@geemail.com	San Francisco	California	676150361714335	105bd7d12be347d4be8b62272c2f4337	Discover	37.7749306116303245	-122.435593369584808
16520	2020-03-21 03:41:22	2020-03-21	Lennon Buckridge	lennon.buckridge@warmmail.com	Simi Valley	California	869938044009489323	929b90ea9e8b3fb86d013536f7f78bdc	Diners Club / Carte Blanche	34.3601527220342291	-118.696564340418206
16521	2020-03-21 03:45:57	2020-03-21	Marylou Weimann	marylou.weimann@woohoo.com	Huntsville	Alabama	639032354389242	cd1cfea7b7ddf0c02199fa2cd05a7fa1	JCB 16 digit	34.6958571960926037	-86.7107875597216236
16522	2020-03-21 04:08:37	2020-03-21	Lyndia Schimmel MD	lyndia.schimmel.md@geemail.com	New York	New York	6011961823004521029	ca02b0d748b53a484bdbfd743fa100b3	Voyager	40.6875361863747216	-73.9758709801256629
16523	2020-03-21 04:12:12	2020-03-21	Winnie Kemmer	winnie.kemmer@woohoo.com	Huntsville	Alabama	3478587476691269	4c22bace34fdd11c464a84d2478098ca	VISA 13 digit	34.7669766985122095	-86.6821515153646516
16524	2020-03-21 04:15:29	2020-03-21	Mrs. Alma Fay MD	mrs.alma.fay.md@woohoo.com	Houston	Texas	6011696792008630528	160697423aeafc3eacd72226f3e65ee4	Maestro	29.6899587959129363	-95.4159123008620043
16525	2020-03-21 04:18:20	2020-03-21	Vertie Conn	vertie.conn@warmmail.com	San Diego	California	676186951852697	6eeca3ece489fedee28c570aaefb339f	American Express	32.7845096220795043	-117.165314604658633
16526	2020-03-21 04:18:42	2020-03-21	Roswell Rodriguez-Schulist	roswell.rodriguez.schulist@geemail.com	Denver	Colorado	55576124894162421	1c1c1bc86725d402dfd1809195bcbb40	Discover	39.7260894570086123	-104.969372019661961
16527	2020-03-21 04:19:36	2020-03-21	Nikki Fritsch	nikki.fritsch@geemail.com	Long Beach	California	3031614149104959	d890051b31a5f66f04b49a3f20cdacd2	Diners Club / Carte Blanche	33.8445687698487134	-118.135330119139695
16528	2020-03-21 04:24:13	2020-03-21	Norbert Gleason	norbert.gleason@geemail.com	Los Angeles	California	3112715039248474995	3a846a16a3b377dae28c9e5bbf55eabe	VISA 16 digit	34.110248770225418	-118.412063214973728
16529	2020-03-21 04:31:08	2020-03-21	Jade Ratke-Metz	jade.ratke.metz@woohoo.com	Round Rock	Texas	210011280962467309	573c45fd21b5bc4db946986cda43c333	VISA 13 digit	30.602179333488273	-97.6450913238190026
16530	2020-03-21 04:33:18	2020-03-21	Melodee Hilll	melodee.hilll@geemail.com	New York	New York	4978271932367274	c04f43806ca399242a5d572247f040ec	VISA 16 digit	40.7219130866453014	-73.8634325503733038
16531	2020-03-21 04:42:46	2020-03-21	Tawanda Pfannerstill DVM	tawanda.pfannerstill.dvm@geemail.com	Columbus	Ohio	51887093455881261	888be284c6b527ea5ccd9174cfe58f1d	JCB 15 digit	39.9399784782014748	-82.981663330388443
16532	2020-03-21 04:47:37	2020-03-21	Mr. Kirby Kautzer	mr.kirby.kautzer@warmmail.com	San Jose	California	3036195817516265	126e4991bd5755a2e3e160e4b74261d7	VISA 13 digit	37.2425770033903447	-121.909671598508581
16533	2020-03-21 04:53:52	2020-03-21	Joelle Orn	joelle.orn@geemail.com	New York	New York	869956464801876583	116d184b99f87aa4f69b8b287c0a3672	JCB 15 digit	40.6242076724991179	-73.8613054559927349
16534	2020-03-21 04:54:44	2020-03-21	Bernhard Grimes	bernhard.grimes@geemail.com	Burbank	California	6011355132952779066	dbdb226b4316097f550d80db1ab1a54c	Mastercard	34.2374125974647683	-118.28642967194655
16535	2020-03-21 05:04:29	2020-03-21	Erich Walter	erich.walter@geemail.com	New York	New York	869946671365923386	f21591fda84c550d782bebd90ff77211	Maestro	40.5865194740928672	-74.0216810149502038
16536	2020-03-21 05:20:44	2020-03-21	Mrs. April Hammes MD	mrs.april.hammes.md@geemail.com	Toledo	Ohio	4019831369872525	efd09aa5432e82f3b5c3aa6517fd61e7	Discover	41.7320623538162536	-83.6489107414014654
16537	2020-03-21 05:21:47	2020-03-21	Dorothea Wolf-Veum	dorothea.wolf.veum@geemail.com	Phoenix	Arizona	4427279200971	cb45f2d5408f158764943a7d7834514a	JCB 15 digit	33.5795722698260093	-112.008695697963617
16538	2020-03-21 05:54:58	2020-03-21	Dr. Ricki Murphy IV	dr.ricki.murphy.iv@geemail.com	Allentown	Pennsylvania	3038886560963609	0d9373bdb13c275e075513922aff046b	JCB 16 digit	40.6894924496080748	-75.4683415281601242
16539	2020-03-21 05:58:25	2020-03-21	Miracle Rau	miracle.rau@geemail.com	San Francisco	California	180087606549274637	fe98db66c62b0181e7f7295a11cbdab8	Discover	37.750346597331891	-122.455578658654915
16540	2020-03-21 06:05:00	2020-03-21	Tina Stracke	tina.stracke@woohoo.com	Atlanta	Georgia	3733722922455977	9ccb84b9a30c5c6f1c05dab3d8fa39fd	JCB 16 digit	33.8480107090711613	-84.4630078872244923
16541	2020-03-21 06:09:26	2020-03-21	Henriette Homenick	henriette.homenick@geemail.com	Houston	Texas	3112168406806107659	01113bb5e2f2423cb325a6d411eab473	Maestro	29.88458290184699	-95.3065368113588534
16542	2020-03-21 06:17:38	2020-03-21	Dean Bartoletti DDS	dean.bartoletti.dds@geemail.com	Newark	New Jersey	3050168985343453	8004a5f957acef4af369c6e15a5ba868	Diners Club / Carte Blanche	40.8229069336697492	-74.1938718007154847
16543	2020-03-21 06:32:34	2020-03-21	Vere Bauch-Connelly	vere.bauch.connelly@woohoo.com	New York	New York	180073895971587568	ad12071c44a80512caecbe730953b972	VISA 16 digit	40.7498064087927361	-73.9059245244961147
16544	2020-03-21 07:11:11	2020-03-21	Carlos Stroman	carlos.stroman@geemail.com	Lansing	Michigan	3006994810824084	b51aeb1b5ad02521d886f30f51084b71	Discover	42.6509037978790744	-84.5291783515486799
16545	2020-03-21 07:31:18	2020-03-21	Azariah Waelchi	azariah.waelchi@geemail.com	Gainesville	Florida	4329868779110	3c4e072d9fde50138326ab63b150308b	VISA 16 digit	29.7086484660685066	-82.3512600619685031
16546	2020-03-21 07:31:19	2020-03-21	Lester Mills V	lester.mills.v@warmmail.com	Berkeley	California	3112226082899304675	ebfeb15850b638eb4a28707866a9ebad	JCB 16 digit	37.8856617373665756	-122.272123776162061
16547	2020-03-21 08:17:58	2020-03-21	Hezekiah Bergnaum	hezekiah.bergnaum@woohoo.com	San Francisco	California	3027307493116109	163828c7f276a89517ce159691175463	VISA 16 digit	37.7718722275743488	-122.426294464938749
16548	2020-03-21 08:19:53	2020-03-21	Miss Kenia Kertzmann	miss.kenia.kertzmann@geemail.com	Jersey City	New Jersey	180054386435216930	9a80cba1716a2055e8970d87100ef375	JCB 16 digit	40.7239216461252411	-74.0008604682937374
16549	2020-03-21 08:28:01	2020-03-21	Johnna Bashirian DDS	johnna.bashirian.dds@geemail.com	Oakland	California	3337194693131892711	5c1bbfb109e7ac7bddf8fb5f290fcf05	JCB 16 digit	37.8086233104866167	-122.23682568259683
16550	2020-03-21 08:48:06	2020-03-21	Mrs. Tanika Beahan	mrs.tanika.beahan@woohoo.com	San Francisco	California	3337078748347110992	cf8d7ff7ab2bca482195a7ec823323c4	VISA 13 digit	37.8041088824538747	-122.433573524109562
16551	2020-03-21 09:28:27	2020-03-21	Sherryl Hyatt DVM	sherryl.hyatt.dvm@geemail.com	San Francisco	California	6011951024644222712	fa44dc6698498f542686bbf045a81c8a	Voyager	37.7857492211300467	-122.41649183158961
16552	2020-03-21 09:30:27	2020-03-21	Adron Rosenbaum	adron.rosenbaum@geemail.com	Denver	Colorado	4836755798984422	fcc10780552c2e27567adb3da0a14554	Voyager	39.6861902415338861	-104.782723568404464
16553	2020-03-21 09:31:12	2020-03-21	Ell Sporer	ell.sporer@geemail.com	New York	New York	4505678099281282	80cabdb2b0ddb8e57eafec7a8410a8ae	JCB 16 digit	40.7256309113223125	-74.0109703628707649
16554	2020-03-21 09:57:15	2020-03-21	Ulysses Mosciski MD	ulysses.mosciski.md@geemail.com	San Francisco	California	869947165242697502	9805c0b3e14ebc57ebb2c42540adac5a	Maestro	37.7792201798067211	-122.422063946086652
16555	2020-03-21 10:03:29	2020-03-21	Miss Cydney Fisher	miss.cydney.fisher@warmmail.com	Gresham	Oregon	4707929242291181	ee0b140d1303ab0b6e2bd776cad818ff	JCB 16 digit	45.487057817490026	-122.433630627606433
16556	2020-03-21 10:09:48	2020-03-21	Scott Ullrich	scott.ullrich@geemail.com	Garland	Texas	4285696717298476	1eff2791c74ac22cfa13df54ded68c02	JCB 16 digit	32.8591681339081347	-96.726652783124905
16557	2020-03-21 10:19:16	2020-03-21	Chanda Simonis	chanda.simonis@geemail.com	Chula Vista	California	501851691614450	09e83941716680c7c69962de914a1abe	Discover	32.5892901366341832	-116.971522786258532
16558	2020-03-21 10:45:55	2020-03-21	Lora Marvin	lora.marvin@geemail.com	Los Angeles	California	4475474379820817	00606fe337793de02257e5985d2b6fa0	JCB 16 digit	33.9852495046198371	-118.466079180640349
16559	2020-03-21 10:54:04	2020-03-21	Sanjuanita Moen	sanjuanita.moen@geemail.com	Atlanta	Georgia	3052657277253618	499040d9e2e44260d06c23b8e7405da7	Maestro	33.741486110658947	-84.3670390461616222
16560	2020-03-21 10:57:16	2020-03-21	Eleanora Torp	eleanora.torp@geemail.com	Philadelphia	Pennsylvania	503826134835086	cc075bf4fe45293a839a681f66e0365f	VISA 16 digit	39.9873520895332106	-75.1295538417428759
16561	2020-03-21 11:48:28	2020-03-21	Erin Thiel	erin.thiel@woohoo.com	Peoria	Illinois	4094412884630	c013f94dfc6bcb3e3f75da87535678de	JCB 16 digit	40.6712566973511116	-89.5225481184083947
16562	2020-03-21 11:50:56	2020-03-21	Pearle White	pearle.white@geemail.com	Laredo	Texas	4160224823634995	323437b98d204a895561d063cf983a84	Diners Club / Carte Blanche	27.4786808168698116	-99.5700894248213615
16563	2020-03-21 11:52:08	2020-03-21	Tylor Pfannerstill	tylor.pfannerstill@woohoo.com	San Francisco	California	3158889262229942976	9470282fc66868908dd0b935effb3db0	JCB 16 digit	37.755832879858751	-122.439366947935127
16564	2020-03-21 11:52:44	2020-03-21	Miss Virgie Tremblay	miss.virgie.tremblay@geemail.com	Midland	Texas	503865014358561	771789f4bc960cdd1971695995e57f77	VISA 16 digit	32.0590630387611668	-102.203811731444674
16565	2020-03-21 12:05:12	2020-03-21	Shannon Donnelly-Kuhn	shannon.donnelly.kuhn@geemail.com	Jacksonville	Florida	869950675978524757	d5a434ca3fc9f74beffb2f7758f72707	Discover	30.4330162032559528	-81.6291596091896423
16566	2020-03-21 12:13:27	2020-03-21	Harrie Hilll	harrie.hilll@geemail.com	Columbus	Ohio	6011542917703770354	352dd244a2f9a7bafc52dfa20d44920e	JCB 16 digit	39.9206520916473124	-83.0740892442178023
16567	2020-03-21 12:27:33	2020-03-21	Miss Rosey Luettgen	miss.rosey.luettgen@geemail.com	New York	New York	210049446869226462	ad70fe597b868853a32610d1e0f4e039	VISA 13 digit	40.5986779908407485	-73.9168550486106426
16568	2020-03-21 12:36:45	2020-03-21	Delphia Romaguera	delphia.romaguera@geemail.com	San Francisco	California	4617475581713640	d5f2e6d70d24a85f4fa974bac9cb2146	VISA 16 digit	37.7832131685371948	-122.461203127598324
16569	2020-03-21 12:50:15	2020-03-21	Marla Watsica	marla.watsica@geemail.com	Cincinnati	Ohio	180010872012133609	29c9f08fcab2a28cbc4f128c21810138	VISA 16 digit	39.0752100420415402	-84.4452743250682829
16570	2020-03-21 12:53:14	2020-03-21	Dr. Norbert Stanton Sr.	dr.norbert.stanton.sr.@geemail.com	New York	New York	3495979311491261	3ea1fbd7a363cff90a775ab56d96b4d7	JCB 15 digit	40.5730378173980881	-74.0366856983758481
16571	2020-03-21 12:54:56	2020-03-21	Mr. Mohamed Herzog IV	mr.mohamed.herzog.iv@geemail.com	San Francisco	California	3337973700626578940	d4babf4fdfaa80d9634160b977dd2ba5	Discover	37.7803896013639502	-122.410574989120761
16572	2020-03-21 13:05:34	2020-03-21	Dr. Porfirio Schaden	dr.porfirio.schaden@geemail.com	Philadelphia	Pennsylvania	54694846074877868	910e317f1ee9c6037f1ca7d47c6b611d	JCB 15 digit	39.9602471887093031	-75.2221672604691349
16573	2020-03-21 13:07:57	2020-03-21	Eden McCullough	eden.mccullough@geemail.com	Omaha	Nebraska	4403957408521106	bbe1cea65165ba21364ba1629b0768f9	VISA 13 digit	41.249625515021016	-96.1163244202848546
16574	2020-03-21 13:08:59	2020-03-21	Lea Haley	lea.haley@woohoo.com	Oakland	California	060481397782004	42fad52bbc4141938397308eb8a9df27	Discover	37.818672782940439	-122.291600332975918
16575	2020-03-21 13:13:20	2020-03-21	Sadie Hermiston	sadie.hermiston@geemail.com	Berkeley	California	3701489158355457	07729c122f3b8adad978abd62d967914	Voyager	37.8831086130762387	-122.262583156882457
16576	2020-03-21 13:14:53	2020-03-21	Brenton Rau	brenton.rau@warmmail.com	New York	New York	4157818881281162	11becf4035651a34841ffe5aa990b072	Voyager	40.7549312616456305	-73.8852851127169998
16577	2020-03-21 13:24:53	2020-03-21	Mrs. Joyce Renner PhD	mrs.joyce.renner.phd@geemail.com	Jacksonville	Florida	4080978942649	99a4087136021aa2b68954f59cc2e3ff	Voyager	30.3921318430505707	-81.6225663314186107
16578	2020-03-21 13:26:55	2020-03-21	Stanton Harber Sr.	stanton.harber.sr.@geemail.com	Kansas City	Missouri	3469801593774622	e98899de1f0f3ab3191378e682ef1575	Maestro	39.1512685615405474	-94.5686818221807499
16579	2020-03-21 13:37:40	2020-03-21	Ceylon Douglas	ceylon.douglas@geemail.com	Los Angeles	California	675939874281619	d2242cba4dea37f8dd2c8e2cd5265f06	Voyager	34.0951842309772957	-118.500471175787226
16580	2020-03-21 13:46:58	2020-03-21	Makayla Wyman-Rau	makayla.wyman.rau@geemail.com	Los Angeles	California	3018080031680824	ee831e30beb179b6ad2bb2fd49695fc2	VISA 16 digit	34.0640271309629057	-118.3381134024348
16581	2020-03-21 13:58:29	2020-03-21	Camden McCullough	camden.mccullough@woohoo.com	Los Angeles	California	3015245438016335	baaf12e1aba3a2fb8efd32c2ec7febfb	VISA 13 digit	34.009211510778961	-118.335373950748888
16582	2020-03-21 14:01:28	2020-03-21	Dr. Burnice Jerde	dr.burnice.jerde@geemail.com	San Francisco	California	676101903420865	9690759d2a6738843f776bffe8d665ed	Maestro	37.7475745474397115	-122.439815982206312
16583	2020-03-21 14:03:20	2020-03-21	Lennie West	lennie.west@geemail.com	Hampton	Virginia	4005895844776	0528bb2d0a3ea2fec1d0bf6dd35a988d	VISA 16 digit	37.0604937111046198	-76.3603853798568224
16584	2020-03-21 14:04:30	2020-03-21	Yesenia Littel	yesenia.littel@geemail.com	San Diego	California	3337455058854978390	9801579919ea40052f0abfdc9e297ecb	JCB 16 digit	32.7467878589008023	-117.055092654973279
16585	2020-03-21 14:07:13	2020-03-21	Sarai Wehner	sarai.wehner@geemail.com	Sterling Heights	Michigan	53916304612104439	12d7a38245e63590d01e157c81b40a16	JCB 16 digit	42.6450867266010505	-83.0721917113915111
16586	2020-03-21 14:13:30	2020-03-21	Darnell Rosenbaum	darnell.rosenbaum@geemail.com	Alexandria	Virginia	3528388472021331759	280f723f8c0da2b4b204308aca61ebb7	VISA 16 digit	38.891192529641458	-77.0061642022322985
16587	2020-03-21 14:19:42	2020-03-21	Brenton Stoltenberg	brenton.stoltenberg@geemail.com	Oceanside	California	561263536733957	331d70c80ef8deec716a84e87db56d72	Discover	33.1641651959512345	-117.307617286414654
16588	2020-03-21 14:35:21	2020-03-21	Darby Grady	darby.grady@geemail.com	Detroit	Michigan	3088646373261744404	9dc57324f2f518d24ca357e1a7103bd6	American Express	42.3724496720749926	-83.0917407116506155
16589	2020-03-21 14:44:27	2020-03-21	Junious Gorczany-Hane	junious.gorczany.hane@geemail.com	Orlando	Florida	4546669548332710	72f677e8a4123cebdecf3c0153a4a90a	Voyager	28.3858597918678051	-81.2859530490789552
16590	2020-03-21 14:54:28	2020-03-21	Anna Crooks DVM	anna.crooks.dvm@geemail.com	New York	New York	51082166417334281	1a7764572f4202810252a2f6d49883a8	JCB 16 digit	40.6903591406289493	-73.9403397702042042
16591	2020-03-21 14:57:38	2020-03-21	Dr. Cephus Fay	dr.cephus.fay@geemail.com	New York	New York	3435596311337378	5beddb7e19e4adaaa5dabb7f0219b4a2	VISA 16 digit	40.6466407714169478	-73.839457525442171
16592	2020-03-21 15:21:48	2020-03-21	Denise Bins	denise.bins@geemail.com	San Francisco	California	210027198859908486	cd3412e79c326a4f43eb11c125907443	JCB 15 digit	37.8104923450695907	-122.389829687162347
16593	2020-03-21 15:37:13	2020-03-21	Dr. Tatyana Leuschke	dr.tatyana.leuschke@warmmail.com	San Antonio	Texas	4657288311654	7db93d717d1ae44ebe79bee21a1bc297	VISA 13 digit	29.494145211118834	-98.6166713333524712
16594	2020-03-21 15:55:01	2020-03-21	Charley Huel	charley.huel@geemail.com	Portland	Oregon	060456390912907	b7946108c2631ac1c6b2cec350ba4c2f	JCB 16 digit	45.6001567251868565	-122.630160580389202
16595	2020-03-21 15:56:46	2020-03-21	Archibald Grimes	archibald.grimes@woohoo.com	Las Vegas	Nevada	4704321731835	1f13e1608c01a7e2c038a8058032202e	Mastercard	36.1609567828577028	-115.306491335548827
16596	2020-03-21 15:58:25	2020-03-21	Dr. Soloman Kovacek	dr.soloman.kovacek@geemail.com	Jacksonville	Florida	4086614198154655	dbb224d6667c22301c75f5ed1299dad8	Maestro	30.4052773916680366	-81.6305757784362953
16597	2020-03-21 16:59:31	2020-03-21	Verona Pagac-Spencer	verona.pagac.spencer@geemail.com	Oceanside	California	210064349783051984	a619ca0868ba46d6a48e36eef1e052fa	Voyager	33.1263092687707399	-117.330819924183942
16598	2020-03-21 17:15:11	2020-03-21	Mrs. Cecily Langworth	mrs.cecily.langworth@geemail.com	Los Angeles	California	4734229999630	7b5296e66dc3ceb8798b39f14ef0af83	Discover	33.9778328962489908	-118.35779373743496
16599	2020-03-21 17:24:37	2020-03-21	Mr. Stephen Harris	mr.stephen.harris@geemail.com	Augusta	Georgia	4239770807888632	be9874fd42d8346ce92500f34f4f16d4	Maestro	33.3592975278124158	-82.0911377903368447
16600	2020-03-21 17:43:50	2020-03-21	Marina Wyman	marina.wyman@warmmail.com	El Paso	Texas	3465432703790060	6c73873f6ee4e0e3ba5be9a8e67012be	VISA 16 digit	31.7774644228924075	-106.479656516619031
16601	2020-03-21 17:55:06	2020-03-21	Joann Schmeler-Howe	joann.schmeler.howe@woohoo.com	Lakeland	Florida	4989513843245330	aaddc665fb1cb876cde64ac20de07677	Discover	28.1304551764223696	-82.038199329923458
16602	2020-03-21 17:55:27	2020-03-21	Kamryn Treutel	kamryn.treutel@geemail.com	San Francisco	California	3020937924654729	0c51c93da861b5f9cac2d5e93f691920	VISA 13 digit	37.7687319077432377	-122.437542149364646
16603	2020-03-21 17:58:47	2020-03-21	Dr. Micaela Gottlieb DVM	dr.micaela.gottlieb.dvm@geemail.com	Midland	Texas	869929058225589881	a5872f2fe2596f1835e88a166844884c	American Express	32.096551291756704	-102.144209947412833
16604	2020-03-21 18:02:01	2020-03-21	Jed Hansen-Von	jed.hansen.von@woohoo.com	Macon	Georgia	4173380801634	b515211fdb156f3c7b0a81998d0cfcdf	VISA 13 digit	32.8125013564258765	-83.6760257414270114
16605	2020-03-21 18:07:27	2020-03-21	Lovie Bauch-Auer	lovie.bauch.auer@woohoo.com	Elk Grove	California	6011127969081770368	4422f0de7a596a119b4b17907414c422	Mastercard	38.514196030358228	-121.370442345868796
16606	2020-03-21 18:13:40	2020-03-21	Brianne McDermott-Herzog	brianne.mcdermott.herzog@geemail.com	New York	New York	502088983759221	e0749cd80c1e0f428d71f68008837cca	VISA 13 digit	40.7436197961904085	-73.9568752824224447
16607	2020-03-21 18:15:52	2020-03-21	Antonia Romaguera	antonia.romaguera@woohoo.com	Wichita	Kansas	53462558933797316	f464097458664663f6b2a233e04ae03e	JCB 16 digit	37.6574294457089138	-97.2673646661654061
16608	2020-03-21 18:18:09	2020-03-21	Matteo Abbott	matteo.abbott@woohoo.com	North Las Vegas	Nevada	6011836054374121553	1d9643ed93a6dafe9153ef999079e83e	Mastercard	36.3299130750045194	-115.026495076784499
16609	2020-03-21 18:20:06	2020-03-21	Lute Brekke II	lute.brekke.ii@geemail.com	New York	New York	54282147899225369	61b0c59c43f9b2eef1af914f4cbc9612	Diners Club / Carte Blanche	40.6273656677212571	-74.0302182569064229
16610	2020-03-21 18:20:37	2020-03-21	Virgie Gaylord	virgie.gaylord@woohoo.com	New York	New York	4758601991626	93988e7d54fc8f1bfb63ddeba38f09b3	VISA 13 digit	40.7063839270025483	-73.8638991250552266
16611	2020-03-21 18:21:58	2020-03-21	Dr. Ovid Kassulke	dr.ovid.kassulke@geemail.com	San Jose	California	869937623620191243	2403a0125d2d7827c5f460214a4e5cd2	American Express	37.3804865376379354	-121.796702478894588
16612	2020-03-21 18:23:18	2020-03-21	Jerilynn Ziemann	jerilynn.ziemann@warmmail.com	Chicago	Illinois	3451400540050499	ef51947b516cf06f699ad5bd01464243	VISA 16 digit	41.770262806054582	-87.7778693025030208
16613	2020-03-21 18:41:45	2020-03-21	Zella Morar	zella.morar@geemail.com	San Francisco	California	3714917868807123	8f1104943c0f42b7e796ba61ca0fce31	JCB 16 digit	37.7651417553977637	-122.451816700672353
16614	2020-03-21 18:42:46	2020-03-21	Harrell Gulgowski	harrell.gulgowski@geemail.com	Atlanta	Georgia	4937018588907949	3d89328a01568bb91ea3de4420f25cd9	JCB 15 digit	33.8299740033965577	-84.4649854230739265
16615	2020-03-21 18:45:57	2020-03-21	Clytie Goldner	clytie.goldner@geemail.com	Phoenix	Arizona	4707341133249494	2e23bab8c3171ca9e8b8d263212956ca	JCB 16 digit	33.4981723672643312	-112.016576225862281
16616	2020-03-21 18:47:02	2020-03-21	Damon Prosacco	damon.prosacco@woohoo.com	Hampton	Virginia	4197181524033355	a2d894d686b935b7fbc18e7518dd31bd	Voyager	37.0126569975651805	-76.3768616085503282
16617	2020-03-21 19:08:57	2020-03-21	Media Miller-Marquardt	media.miller.marquardt@geemail.com	San Francisco	California	3743501899118307	ca2e4aec617f6faa52398a737b76b6ef	VISA 16 digit	37.7668869782904579	-122.446082621825767
16618	2020-03-21 19:11:29	2020-03-21	Carrie O'Hara	carrie.o'hara@warmmail.com	Chicago	Illinois	501859475809394	f9399c07b227b85ca7ad27a0b058143f	Maestro	41.7440186272211378	-87.5983985458996131
16619	2020-03-21 19:17:58	2020-03-21	London Moore	london.moore@geemail.com	Baton Rouge	Louisiana	869952804119286237	1cf7851f42f6dbace95f2f70093d72a0	Diners Club / Carte Blanche	30.4618676820050922	-91.0700179511789258
16620	2020-03-21 19:27:11	2020-03-21	Wash Goldner-Berge	wash.goldner.berge@geemail.com	Frisco	Texas	3758339404060397	21c0783f8f838c4ceae42949e131b287	VISA 13 digit	33.204098105104265	-96.8263282542325499
16621	2020-03-21 19:59:05	2020-03-21	Merrill Bosco-Schumm	merrill.bosco.schumm@woohoo.com	Akron	Ohio	4663040028419400	026b944c08a9bf061c8e640f81d47d7f	American Express	41.1207202325873098	-81.4647385226409853
16622	2020-03-21 20:08:11	2020-03-21	Dr. Norman Cormier I	dr.norman.cormier.i@geemail.com	El Paso	Texas	869936660776292897	7b444c4e28e3bd28c7e3d57521a06616	Discover	31.763560334808755	-106.517273286681629
16623	2020-03-21 20:17:14	2020-03-21	Rolf Littel	rolf.littel@geemail.com	Oakland	California	3096564275050867619	8b4d40e2ca2ef5d44481c30e64c00f2d	VISA 16 digit	37.8292158976962156	-122.276258555316232
16624	2020-03-21 20:21:08	2020-03-21	Ozzie Hammes Jr.	ozzie.hammes.jr.@geemail.com	Hialeah	Florida	3158992278634161121	e1ea51198ed0c3388674ebc8c0e87061	Mastercard	25.915484973040968	-80.3168463488478181
16625	2020-03-21 20:32:16	2020-03-21	Mr. Berkley Schoen	mr.berkley.schoen@geemail.com	Thousand Oaks	California	060409903402882	10f17a024091068812e0a7481a975f8e	VISA 16 digit	34.1515498306874221	-118.777016842216995
16626	2020-03-21 20:34:08	2020-03-21	Rashad Keebler	rashad.keebler@warmmail.com	Stockton	California	210069758680440055	9dae39def14507dd9e3c6b394b7bde66	Maestro	38.0074828278005157	-121.263987214732168
16627	2020-03-21 20:39:06	2020-03-21	Almeda Schneider	almeda.schneider@geemail.com	San Francisco	California	3760292239080971	fb5d70b441f62747027ba98dcc3f1bbc	Diners Club / Carte Blanche	37.8008993416137642	-122.44405584083384
16628	2020-03-21 20:56:07	2020-03-21	Darby Howe	darby.howe@geemail.com	Atlanta	Georgia	501828044055003	aa3f62d883964c6cb33f8ee44f51def9	VISA 16 digit	33.7796833368759621	-84.3735271620608955
16629	2020-03-21 21:15:49	2020-03-21	Sadie Satterfield	sadie.satterfield@warmmail.com	San Francisco	California	3096778531325068546	6c08fe3b6a68a1e0b341178aa91a4739	JCB 15 digit	37.7463553147537141	-122.492944205741068
16630	2020-03-21 21:21:48	2020-03-21	Berneice Toy	berneice.toy@geemail.com	Independence	Missouri	4662636583036470	3a4653110ae31db574480d03175e6166	Diners Club / Carte Blanche	39.0268715690840082	-94.3230602971561183
16631	2020-03-21 21:30:23	2020-03-21	Rashaan Gleason	rashaan.gleason@warmmail.com	Killeen	Texas	869933154574252348	95f4cdd3e3bceed1119aae1a6782a39e	Diners Club / Carte Blanche	31.0294997569404529	-97.7764679242093138
16632	2020-03-21 21:59:28	2020-03-21	Jerold Reynolds	jerold.reynolds@woohoo.com	San Francisco	California	869989291300427811	0ece69511b2112b8cad647645ac6a1ea	VISA 16 digit	37.7589437725209507	-122.431168556984133
16633	2020-03-21 22:12:17	2020-03-21	Rosaria Jakubowski	rosaria.jakubowski@woohoo.com	Denver	Colorado	3337622919801148189	1ee9c99387eb01181fb2ef1f1850f8f6	Discover	39.6871326005604104	-104.90298260233962
16634	2020-03-21 22:23:10	2020-03-21	Lavonne Nolan-Wisoky	lavonne.nolan.wisoky@geemail.com	Visalia	California	6011554114216602697	cfd3a5c1bcb9b24ee35620180f3b025a	VISA 16 digit	36.2461418034464131	-119.422688339430465
16635	2020-03-21 22:23:45	2020-03-21	Canyon Renner	canyon.renner@geemail.com	New York	New York	676292765209470	fa445bf8abc8f4f4e6c150bacaacd13e	American Express	40.7102378583271047	-73.8688736021414343
16636	2020-03-21 22:27:42	2020-03-21	Dr. Young Quitzon DVM	dr.young.quitzon.dvm@geemail.com	Tyler	Texas	3112002247687730882	1b9a68fe1e0a070bd84c989e046ae568	VISA 16 digit	32.2318033302716955	-95.2670968975979804
16637	2020-03-21 22:37:13	2020-03-21	Gearldine Hills	gearldine.hills@geemail.com	Rochester	Minnesota	4402710632587	f755e65974b9c6e363c275e65113831b	Mastercard	43.9336134596630927	-92.4926325254261457
16638	2020-03-21 22:47:37	2020-03-21	Tosha Swift	tosha.swift@geemail.com	Westminster	Colorado	869991480808802742	3e1c0c6a288135157f57091871e7163e	Maestro	39.7980670196309632	-104.976242132173482
16639	2020-03-21 23:03:13	2020-03-21	Mrs. Amberly Oberbrunner DDS	mrs.amberly.oberbrunner.dds@geemail.com	Charlotte	North Carolina	4957344526350306	c0a9fc23d08e26f6ca59172cddbff8c6	JCB 15 digit	35.1344923699062335	-80.7882025650180964
16640	2020-03-21 23:03:34	2020-03-21	Colt Littel	colt.littel@geemail.com	Denver	Colorado	52563140689820705	b13b0bc78ec9a01e6976a116b4e1631f	JCB 16 digit	39.7302325418271067	-104.868010773720599
16641	2020-03-21 23:04:53	2020-03-21	Bonny King	bonny.king@woohoo.com	Los Angeles	California	4959064399817664	117fea7b74bc3550be6c207317d9cdf3	VISA 16 digit	33.9286250678222601	-118.492559624183173
16642	2020-03-21 23:05:55	2020-03-21	Otto Stamm	otto.stamm@warmmail.com	Pearland	Texas	3337801482844630989	bd9b316307656ed8ec614c75c8e20a17	Mastercard	29.6484898023579291	-95.4065034137893377
16643	2020-03-21 23:10:15	2020-03-21	Wilburn Monahan	wilburn.monahan@geemail.com	St. Louis	Missouri	3337755230647997394	51371d9a392cf156f08814f524988262	JCB 16 digit	38.6806773498810799	-90.1623378301508751
16644	2020-03-21 23:11:03	2020-03-21	Elmira Waters	elmira.waters@geemail.com	Fayetteville	North Carolina	6011767992274513218	34c06359d555d9f97ec9a1c8cb2aa5ba	Diners Club / Carte Blanche	35.1593050011686969	-79.0571938270367696
16645	2020-03-21 23:25:13	2020-03-21	Ms. Kathy Jerde	ms.kathy.jerde@geemail.com	Columbus	Ohio	6011792893441112117	be8f257788a8b84db8e069bd7bbc0726	Discover	39.901211521685866	-83.0454618228834249
16646	2020-03-21 23:40:16	2020-03-21	Brinley Hand	brinley.hand@geemail.com	Amarillo	Texas	869930780829472944	18d9b0d1a6f90cc7ba0b19435288e76d	JCB 15 digit	35.1592908592592934	-101.880461141080417
16647	2020-03-21 23:41:29	2020-03-21	Miss Talia Schaefer	miss.talia.schaefer@geemail.com	Winston–Salem	North Carolina	3034319667087480	210c40fb62ec4961c9e45d70152e2ea0	VISA 13 digit	36.0644720673792065	-80.3609814254231765
16648	2020-03-21 23:53:29	2020-03-21	Ms. Lauren Mraz DDS	ms.lauren.mraz.dds@geemail.com	Chicago	Illinois	3029001977447696	87493ef93f1408749ad2057c9d97c9c7	JCB 15 digit	41.7638232904322493	-87.5881451420981421
16649	2020-03-22 00:01:20	2020-03-22	Wilson King	wilson.king@geemail.com	Savannah	Georgia	180023685706579340	3a58aa07d86ffbe9fd7cefa29673491e	JCB 16 digit	31.9824566860310711	-81.1354518873769734
16650	2020-03-22 00:06:06	2020-03-22	Dennie Parker	dennie.parker@geemail.com	New York	New York	52985865830754003	e59cd94a36381076faf9143fced17b4a	VISA 16 digit	40.6473767682202123	-74.0336463016819124
16651	2020-03-22 00:11:12	2020-03-22	Dr. Hiram Strosin PhD	dr.hiram.strosin.phd@geemail.com	Tempe	Arizona	869992666200705108	56a65d858d96fe07ec62c5a20565a754	VISA 16 digit	33.4143321814402938	-111.929041803212087
16652	2020-03-22 00:20:52	2020-03-22	Symone Grady	symone.grady@geemail.com	Austin	Texas	869918908930992643	38138617d78520e9aafa39b754676c64	Discover	30.2789089725013802	-97.7285132891736907
16653	2020-03-22 00:28:42	2020-03-22	Cassius Brakus	cassius.brakus@geemail.com	Chicago	Illinois	3337126785483402223	47a1816bb0b84d878f76d72ad27b68bc	Discover	41.7688033939640988	-87.6248126217659546
16654	2020-03-22 00:43:08	2020-03-22	Florrie Mayer	florrie.mayer@geemail.com	Memphis	Tennessee	3158460506706635801	c40ee39c74569c433584659bf8c1b6a6	VISA 16 digit	35.005965823873133	-89.9521792439069685
16655	2020-03-22 00:47:16	2020-03-22	Miss Christa Barrows DVM	miss.christa.barrows.dvm@geemail.com	Boston	Massachusetts	4389917146844	890efec48c346195bfa6a1c791d6bf56	VISA 16 digit	42.3181545320600279	-70.9476981661234021
16656	2020-03-22 00:50:40	2020-03-22	Terance Keeling	terance.keeling@woohoo.com	Berkeley	California	4796379380857397	f533bdf95e583fffcdfe64d8ebf76cb8	Mastercard	37.8936920340665679	-122.275660292167785
16657	2020-03-22 01:03:21	2020-03-22	Mr. Therman Willms	mr.therman.willms@geemail.com	Orlando	Florida	3337783071749885004	3c2ca0e9f502f0af7e3ccd5b9137d303	JCB 16 digit	28.3742142648234967	-81.3433569876909246
16658	2020-03-22 01:21:35	2020-03-22	Noma Ankunding	noma.ankunding@geemail.com	Glendale	California	4623737872976893	1110d62b069d60e0a502e11f918c1580	VISA 16 digit	34.2529437827166134	-118.288371858828896
16659	2020-03-22 02:28:16	2020-03-22	Ari McClure	ari.mcclure@warmmail.com	Oakland	California	3007205292634076	1e083a4ec9229659167cb7b83f6859b5	VISA 13 digit	37.7716231747357227	-122.275972946689166
16660	2020-03-22 02:35:55	2020-03-22	Heaven Raynor	heaven.raynor@warmmail.com	Concord	California	869989420443076942	a4dbf14e8df03d7aa3f57b497eefe220	VISA 16 digit	37.8840230033665932	-122.101226774620258
16661	2020-03-22 02:41:26	2020-03-22	Fount Smitham-Ankunding	fount.smitham.ankunding@geemail.com	San Francisco	California	3774592157288546	4c44624aeb6ce9efeba2155e991e6671	Diners Club / Carte Blanche	37.7889629069584032	-122.444458568074509
16662	2020-03-22 02:41:41	2020-03-22	Joann Spencer	joann.spencer@geemail.com	Lewisville	Texas	4502466015061118	a61d057bd9b2218010e4c2af83fd3f52	Maestro	32.9997130939256351	-96.8998414407979709
16663	2020-03-22 02:56:29	2020-03-22	Clair Fay	clair.fay@warmmail.com	Midland	Texas	3088922393792084232	35fb6de757e1e36419b38c0d5569ea7d	JCB 16 digit	32.0204140598144349	-102.105898255923762
16664	2020-03-22 03:12:34	2020-03-22	Ike Schimmel	ike.schimmel@geemail.com	New York	New York	3017583337724015	72c1f1430120204d9468e7745133e588	Maestro	40.7088892542049265	-73.954569948361069
16665	2020-03-22 03:20:56	2020-03-22	Capitola Hyatt	capitola.hyatt@geemail.com	New York	New York	3434277192787541	0c761a86b353f496313838d8c7b5c9df	American Express	40.6573874864485134	-73.9482073823351413
16666	2020-03-22 03:31:44	2020-03-22	Lydia Will DVM	lydia.will.dvm@geemail.com	Warren	Michigan	4903045167463051	4a8d50c207a80a371a651c0987fc4a35	VISA 13 digit	42.4551580982744667	-83.1050459804013428
16667	2020-03-22 03:41:19	2020-03-22	Oakley Predovic V	oakley.predovic.v@warmmail.com	Chicago	Illinois	4655710502514104	d54f7284b7484bdc230217afcdce99f4	VISA 16 digit	41.8796826983638155	-87.704614253671096
16668	2020-03-22 03:52:34	2020-03-22	Shantell Reynolds	shantell.reynolds@woohoo.com	Dallas	Texas	503839786988517	e8a20c219c1d824694107a9e5ae18d00	Maestro	32.7310151609864093	-96.7777545173149463
16669	2020-03-22 03:52:46	2020-03-22	Adalberto Conn	adalberto.conn@geemail.com	Pittsburgh	Pennsylvania	51673945653988446	58740c8f8b6203f17df0d5a4aa542314	Maestro	40.3833261426027832	-79.8832812566481607
16670	2020-03-22 03:56:05	2020-03-22	Lizeth Hagenes-Welch	lizeth.hagenes.welch@warmmail.com	Norwalk	California	639063875377788	781bce9ec8efbe7723b5c9323beaf7d5	American Express	33.9089400289230056	-118.170197317054502
16671	2020-03-22 04:18:57	2020-03-22	Valarie Ziemann	valarie.ziemann@woohoo.com	Phoenix	Arizona	3044254091684471	ca541ccdcb7ed79b141012f1fdf1f20c	JCB 16 digit	33.6578979437638068	-112.17352079385185
16672	2020-03-22 04:34:11	2020-03-22	Mr. Gayle Kilback	mr.gayle.kilback@woohoo.com	Lincoln	Nebraska	676388719014750	3d44b56e6d7d8b2f3797a54c76b80df8	VISA 16 digit	40.7794123998396074	-96.6154774938404586
16673	2020-03-22 04:36:54	2020-03-22	Donta Simonis	donta.simonis@warmmail.com	Naperville	Illinois	869963011491824802	2b15612ef6d814e1f0ce062090ef05e1	Maestro	41.8328162128020082	-88.1570784488581154
16715	2020-03-22 13:00:19	2020-03-22	Griselda Schuppe	griselda.schuppe@geemail.com	Houston	Texas	3096663099426299822	8c02e73b4470a259b7c1260a9f13d60f	JCB 16 digit	29.7479756248261786	-95.4642637280762187
16674	2020-03-22 04:40:01	2020-03-22	Miss Brittny Kautzer	miss.brittny.kautzer@woohoo.com	San Francisco	California	3112718471093329486	df3c9f26d1aea406dd06af9658ca6f7e	VISA 16 digit	37.7532658728832757	-122.425880358152781
16675	2020-03-22 04:51:25	2020-03-22	Jaheim Gerlach	jaheim.gerlach@warmmail.com	Las Vegas	Nevada	3024242870306812	c49ebecee85610f72382e7da92f57bc8	Voyager	36.1618026041992024	-115.339521148262918
16676	2020-03-22 04:55:47	2020-03-22	Clarance Carroll	clarance.carroll@geemail.com	Tampa	Florida	6011373469690458449	14ed9462e1bd85e8359dc00f79914c3e	Voyager	27.8880830892011495	-82.4790026463780492
16677	2020-03-22 04:56:44	2020-03-22	Hortensia Reichert	hortensia.reichert@geemail.com	San Francisco	California	3096934449794524215	653e50d1610ff010e9545f4ffb046272	VISA 16 digit	37.7996496840088483	-122.450893084258666
16678	2020-03-22 04:58:38	2020-03-22	Miss Brandie Lubowitz MD	miss.brandie.lubowitz.md@woohoo.com	Oakland	California	4724530578918	e4c5fb697c09c852672add58750fad10	JCB 16 digit	37.7891385909399204	-122.290128599383976
16679	2020-03-22 05:22:41	2020-03-22	Tyron Greenholt	tyron.greenholt@geemail.com	Fort Collins	Colorado	210020028418636129	1133542c22fdd84e049ca3e28ea5c0f5	Voyager	40.5429930437978356	-105.064531213506314
16680	2020-03-22 05:28:58	2020-03-22	Bryton Bahringer-Howell	bryton.bahringer.howell@geemail.com	Paterson	New Jersey	869999935064804270	7049aae84f382c1611a62ffea68ef5f8	JCB 16 digit	40.8861703873567279	-74.1225150181885795
16681	2020-03-22 05:35:48	2020-03-22	Otto Pagac	otto.pagac@warmmail.com	Tucson	Arizona	6011570683951777955	1d2ccb2bdae23f05d4855a5cbc2f1b03	JCB 15 digit	32.1808393100317573	-110.802849995088195
16682	2020-03-22 06:00:13	2020-03-22	Kelly Keebler	kelly.keebler@geemail.com	San Francisco	California	3790338330244034	0d148f66249348d4ba7b1e5e704c48b5	VISA 16 digit	37.7781016667604135	-122.472812837804241
16683	2020-03-22 07:07:51	2020-03-22	Elick Raynor-Weber	elick.raynor.weber@geemail.com	Phoenix	Arizona	869938364131621365	99dde945205fdc78551c318941b43414	Diners Club / Carte Blanche	33.5895383945133545	-112.109467678044368
16684	2020-03-22 07:09:35	2020-03-22	Bettina Kunde	bettina.kunde@geemail.com	New Orleans	Louisiana	4938219838212838	5bc3a9f2ada0843b2ba98cf3f633e5cd	Discover	30.0177194993957883	-89.9425312264151842
16685	2020-03-22 07:21:18	2020-03-22	Monnie Schumm	monnie.schumm@woohoo.com	San Francisco	California	6011259962278390710	f16303ed9085fff581150898bb07223d	Maestro	37.7471396486112738	-122.407873817857151
16686	2020-03-22 07:35:14	2020-03-22	Quinn Brakus	quinn.brakus@geemail.com	Virginia Beach	Virginia	3776162619441691	60bdcb8156d4cfb266893fd487d44ef6	JCB 15 digit	36.8452288164943482	-76.0489390697933771
16687	2020-03-22 07:36:57	2020-03-22	Doshie Jakubowski	doshie.jakubowski@geemail.com	Louisville	Kentucky	3088860879030736462	4d758bf490f6132009aa4138ea4ae398	Mastercard	38.1470909529734357	-85.6642476167600648
16688	2020-03-22 07:45:07	2020-03-22	Ines Ruecker	ines.ruecker@geemail.com	Irvine	California	3755620697372661	d78afd8d0d42bbf975d08824ec05255a	Maestro	33.5799752788633157	-117.859975327831876
16689	2020-03-22 08:02:53	2020-03-22	Miss Sula Wiegand	miss.sula.wiegand@geemail.com	San Francisco	California	4878916781130	c189e7eff2b21bba07a2af1f89d83646	JCB 16 digit	37.7822789135285504	-122.432474713218937
16690	2020-03-22 08:11:21	2020-03-22	Dr. Everette Hackett DDS	dr.everette.hackett.dds@warmmail.com	Lexington	Kentucky	3748246280236905	b1a6ac115123d43d8f7fed0d95edf655	JCB 15 digit	37.9686667335096786	-84.3762714177269402
16691	2020-03-22 08:22:45	2020-03-22	Fitzhugh Runte	fitzhugh.runte@geemail.com	Vancouver	Washington	180044767381311465	17b2f7110706ba5f2ba89f82db13e265	JCB 16 digit	45.6567887141440067	-122.636890762678149
16692	2020-03-22 08:27:14	2020-03-22	Alaya Turner	alaya.turner@geemail.com	Baton Rouge	Louisiana	3701392044946051	658fe8414556a7bab6698fc093fc0d9d	VISA 16 digit	30.4764260178178539	-91.1329514673553405
16693	2020-03-22 08:32:51	2020-03-22	Eston Olson-Kertzmann	eston.olson.kertzmann@geemail.com	San Francisco	California	180007789045320620	c4148236bef8ec50554fb3af40132000	VISA 13 digit	37.7703191718883176	-122.398360509442796
16694	2020-03-22 08:36:33	2020-03-22	Ashli Lakin	ashli.lakin@geemail.com	New York	New York	4591600639569	14abe3e0a4b69cb3b19c42c98a0573e5	JCB 16 digit	40.6115935941450275	-73.8948911901459127
16695	2020-03-22 08:36:33	2020-03-22	Caitlin Kessler	caitlin.kessler@geemail.com	Dallas	Texas	4479748987083504	b96959b712618d72f07b4d636c1345a9	American Express	32.8685219639252892	-96.7485689994841778
16696	2020-03-22 08:36:39	2020-03-22	Celia Cremin	celia.cremin@geemail.com	Arlington	Texas	3485718002146335	e0a21c9b884117f3101f10149d9ed2cf	VISA 16 digit	32.793621088170255	-97.1634742914725109
16697	2020-03-22 08:42:10	2020-03-22	Dilan Adams	dilan.adams@geemail.com	Fort Worth	Texas	4710363012364710	e958856b74091569eceb1fbab2620c8a	VISA 16 digit	32.7219867769219022	-97.3475544680196805
16698	2020-03-22 08:51:26	2020-03-22	Wayde Gerhold	wayde.gerhold@geemail.com	New York	New York	4362374584930	3b0164f0a66845b85a37d6eef04f491a	VISA 16 digit	40.6041847254838757	-73.8786928421247779
16699	2020-03-22 09:13:34	2020-03-22	Ethelene Crooks	ethelene.crooks@geemail.com	San Francisco	California	4882403735322124	60d969e3fb4d9c5cc63d2f668e3f838f	Mastercard	37.7854076084144381	-122.464199006903428
16700	2020-03-22 09:34:20	2020-03-22	Mr. Keanu Koss	mr.keanu.koss@geemail.com	Las Vegas	Nevada	51808559078640140	34fd26875a88636966d525f52fe8fcde	JCB 16 digit	36.2178471659876422	-115.350756184358517
16701	2020-03-22 10:05:25	2020-03-22	Delphia O'Reilly-Herzog	delphia.o'reilly.herzog@woohoo.com	San Francisco	California	53110841989533868	54da293f0e95b3df14a36d6124e66611	VISA 13 digit	37.7531071009828594	-122.419666311582816
16702	2020-03-22 10:21:09	2020-03-22	Thelma Carter	thelma.carter@geemail.com	New York	New York	639022539254957	fc189e8dc106e61426339ad0a38f36c5	Discover	40.7575152781084142	-74.0088931219082298
16703	2020-03-22 10:52:34	2020-03-22	Ms. Belia DuBuque MD	ms.belia.dubuque.md@woohoo.com	Rockford	Illinois	3764113599533365	6f00843ca7fd4382e263d57c711bb091	Diners Club / Carte Blanche	42.2493576136894546	-88.9998820413652822
16704	2020-03-22 11:35:52	2020-03-22	Marge Feest	marge.feest@geemail.com	Berkeley	California	3337493535799802417	7def6538c0964f6850c3dc1bc7baab46	Discover	37.8476753404992294	-122.251261244695172
16705	2020-03-22 11:36:47	2020-03-22	Kay Koelpin	kay.koelpin@geemail.com	Bakersfield	California	6011761053645972926	a0a170c271998688f33078b25ad20fdc	Mastercard	35.3526432566985491	-118.951382149084651
16706	2020-03-22 11:40:56	2020-03-22	Lolita Koelpin	lolita.koelpin@geemail.com	Sugar Land	Texas	3528405579823543875	39508fe8632959f275ac40cc17cb9199	Voyager	29.5463100214075283	-95.5519131659071803
16707	2020-03-22 11:43:08	2020-03-22	Howard Johnston	howard.johnston@geemail.com	San Francisco	California	6011966409950764840	627705db4dedfb75ab8bc4181bb1026e	JCB 16 digit	37.7709784673354889	-122.453708912157936
16708	2020-03-22 11:47:52	2020-03-22	Evans Bergnaum	evans.bergnaum@woohoo.com	San Diego	California	4072974658915	48daa21219973defc4e718342fed6d94	Discover	32.8637202660154557	-117.2280147914216
16709	2020-03-22 11:47:59	2020-03-22	Dr. Christoper Rempel I	dr.christoper.rempel.i@geemail.com	New York	New York	3337051704431021141	782b96cc418e66c344022513fa80ead0	Mastercard	40.5687833068650221	-73.857487404289472
16710	2020-03-22 12:02:36	2020-03-22	Jason Runte	jason.runte@geemail.com	Oakland	California	210070934778096201	3f17802f7c1705755509889453dc5d62	Voyager	37.7897500951074221	-122.257143549330792
16711	2020-03-22 12:32:08	2020-03-22	Robb Beatty	robb.beatty@woohoo.com	Jersey City	New Jersey	52252664051462974	98123babcdd110d6a5e02aba1d191057	VISA 16 digit	40.806353725347293	-74.0248284346845082
16712	2020-03-22 12:38:28	2020-03-22	Gust Koss-Waelchi	gust.koss.waelchi@geemail.com	Los Angeles	California	55358044695212684	d1e550b47f49ec8cf75768ca110fc608	Maestro	34.0102033589832473	-118.477947814482448
16713	2020-03-22 12:52:18	2020-03-22	Blaine Ward	blaine.ward@warmmail.com	Anaheim	California	502072635669392	b6c470e4c44a1446bae06340c402061b	Voyager	33.8923385962676278	-117.697376066560295
16714	2020-03-22 12:59:33	2020-03-22	Monty Buckridge	monty.buckridge@warmmail.com	Dayton	Ohio	3112539973925149138	aa6364abf9e7e6fbf0fbfb9dc2f561b4	VISA 16 digit	39.8538416855294244	-84.1252092015188282
16716	2020-03-22 13:22:27	2020-03-22	Huldah Schoen	huldah.schoen@woohoo.com	Modesto	California	54528200581837076	f44aae98b7f956078a44c8c5599d67a2	JCB 15 digit	37.589796353597194	-121.030036505285651
16717	2020-03-22 13:23:23	2020-03-22	Kylene Homenick	kylene.homenick@geemail.com	Toledo	Ohio	676253568409105	e1574242e3b4cfcd73ca1924693bf05e	Maestro	41.7611564689952885	-83.5626473615277661
16718	2020-03-22 13:33:26	2020-03-22	Cooper Dare	cooper.dare@geemail.com	Pembroke Pines	Florida	55507827140096631	e4e08d964ed859ff0cdd6c0fa669c83c	JCB 16 digit	26.0541653348635904	-80.310238773552328
16719	2020-03-22 13:34:13	2020-03-22	Dr. Lurline Pfannerstill DVM	dr.lurline.pfannerstill.dvm@geemail.com	Wilmington	North Carolina	4578336328409917	4463ce9e5add12533b5c5e6f7f8494ef	VISA 13 digit	34.1374523544505237	-77.8562037941992315
16720	2020-03-22 13:51:28	2020-03-22	Mrs. Jaylen Gulgowski PhD	mrs.jaylen.gulgowski.phd@geemail.com	Eugene	Oregon	869988539799057445	ca9ddda7e76c7750717a7c7d38ab0d43	JCB 16 digit	44.1031034873526551	-123.107160340807226
16721	2020-03-22 14:05:36	2020-03-22	Woodson Cremin DVM	woodson.cremin.dvm@geemail.com	Kansas City	Missouri	3112421762691604116	e9a6d929357176797f339e145a5552c2	VISA 16 digit	39.1191359038300845	-94.5648834361452657
16722	2020-03-22 14:07:59	2020-03-22	Lucetta Boyle	lucetta.boyle@geemail.com	Houston	Texas	3528034252884772069	1ed06715581ec59c6fdc0c07bcef7b22	Discover	29.8114012546915568	-95.4167053861558401
16723	2020-03-22 14:20:44	2020-03-22	Racquel Grimes	racquel.grimes@geemail.com	Kent	Washington	3158561168592354233	f87d3cf922efc4e8d819739e67d8c2b4	American Express	47.4083543049283307	-122.172470053206013
16724	2020-03-22 14:25:21	2020-03-22	Carlo Raynor IV	carlo.raynor.iv@warmmail.com	Sandy Springs	Georgia	3050099774350328	4b31c9689ed966519822ad815ce99bf0	Mastercard	33.8968760745190067	-84.2888086778659442
16725	2020-03-22 14:27:59	2020-03-22	Araminta Wyman DVM	araminta.wyman.dvm@geemail.com	San Mateo	California	869996088463589556	0b74f1f2f41a86d9a71cc7c441766913	Voyager	37.4821015374150122	-122.366243269466224
16726	2020-03-22 15:04:20	2020-03-22	Ceylon Rodriguez DVM	ceylon.rodriguez.dvm@geemail.com	Boston	Massachusetts	210052750792256577	eb35a64f80bb29148996c2c42d519b54	JCB 16 digit	42.3780691177286215	-70.9463384084355084
16727	2020-03-22 15:20:04	2020-03-22	Allison O'Conner	allison.o'conner@geemail.com	San Francisco	California	180017058123527391	58767f35c123149510f081937413efb5	Diners Club / Carte Blanche	37.7878495456920618	-122.438234654243828
16728	2020-03-22 15:42:13	2020-03-22	Wells Kemmer	wells.kemmer@warmmail.com	Berkeley	California	3158433584173947706	d0af1f39fa8c9a185fe04cae033762af	VISA 16 digit	37.8799776872208653	-122.289424770713723
16729	2020-03-22 15:46:37	2020-03-22	Calvin Strosin	calvin.strosin@geemail.com	Billings	Montana	4124450387780	14b58bc1ef714ee413fbe3b09a122ec6	Maestro	45.8411479800231731	-108.63202886317633
16730	2020-03-22 15:58:34	2020-03-22	Cain Abshire	cain.abshire@warmmail.com	Jacksonville	Florida	3337773881473732632	6efb577fd2e0e53c19c6c65719f4dc65	Diners Club / Carte Blanche	30.3298679283406578	-81.6320439189750715
16731	2020-03-22 16:06:36	2020-03-22	Tara Christiansen DDS	tara.christiansen.dds@woohoo.com	Lansing	Michigan	4652453621309394	8a3863b109e4d7a1094ef76d0ba899e1	JCB 15 digit	42.806983503497392	-84.5108668620820964
16732	2020-03-22 16:15:56	2020-03-22	Lauri Turcotte	lauri.turcotte@geemail.com	New York	New York	869951543502075168	958f732b577d98dbe37148d67537cd0a	VISA 16 digit	40.6529536234438424	-73.9745301881235093
16733	2020-03-22 16:21:59	2020-03-22	Makaila Renner	makaila.renner@geemail.com	Tulsa	Oklahoma	3032704325780463	69788527e1238c771cd0281029329311	Diners Club / Carte Blanche	36.1817285435177354	-95.9976950040973662
16734	2020-03-22 16:23:56	2020-03-22	Pink Toy	pink.toy@geemail.com	Yonkers	New York	6011099295063490807	2b2dc3dc98b86720e8e4f41bf8f399ba	Voyager	40.9086388556953509	-73.92931350705922
16735	2020-03-22 16:27:19	2020-03-22	Rosann Fahey	rosann.fahey@geemail.com	Mesa	Arizona	210035425212904138	db06020bb34f49f35cd865fb29e6e52e	Diners Club / Carte Blanche	33.4077724958449593	-111.718067398283253
16736	2020-03-22 16:27:54	2020-03-22	Cruz Homenick	cruz.homenick@woohoo.com	Berkeley	California	6011989263312792004	39c5c45f9a5ad08336e0a7df8b2f80d0	Maestro	37.8639105121929376	-122.249943607029849
16737	2020-03-22 16:29:43	2020-03-22	Haven Kilback	haven.kilback@geemail.com	San Francisco	California	4134861614490	416eb7155c32ee58f2d7388d9919d16f	American Express	37.780076106752837	-122.452077663748142
16738	2020-03-22 16:31:36	2020-03-22	Chimere Zemlak	chimere.zemlak@geemail.com	Chicago	Illinois	4073192508319305	24714c0c1f9ecda462ce45cc5d86f1f3	VISA 16 digit	41.7913376425694665	-87.7544898047607376
16739	2020-03-22 16:32:52	2020-03-22	Dr. Michell Dooley	dr.michell.dooley@geemail.com	Houston	Texas	6011113922084099661	959cf0f51e6b84ae558f1b69a858dc1f	JCB 16 digit	29.7503323769740753	-95.4345150606721688
16740	2020-03-22 16:37:22	2020-03-22	Dr. Regina Crist	dr.regina.crist@geemail.com	Boise	Idaho	4936069974181	ff2e4826d9333f5d73e0b929992e15aa	JCB 16 digit	43.5204874095644811	-116.304130744394669
16741	2020-03-22 17:10:08	2020-03-22	Gustavus Sporer	gustavus.sporer@geemail.com	Jacksonville	Florida	3430472019865869	3534b70c44eda6936c21057c3238981d	Discover	30.2837689890112713	-81.6791144189968747
16742	2020-03-22 17:16:06	2020-03-22	Gabriel Rosenbaum-Spencer	gabriel.rosenbaum.spencer@geemail.com	Henderson	Nevada	3112811413172218582	3f0bb3cbea76f4a2c8406c321272a9fb	Mastercard	35.9325111721109636	-114.947573332923284
16743	2020-03-22 17:17:55	2020-03-22	Jorden Jenkins	jorden.jenkins@woohoo.com	Jacksonville	Florida	3048017903956254	ee228f94daf2890663ccfd03a0b4f784	VISA 16 digit	30.272027687081696	-81.61129592308626
16744	2020-03-22 17:30:37	2020-03-22	Theodora Dooley	theodora.dooley@geemail.com	New York	New York	4261003244702	73edb526f3268bfd06bbaaa579ee3833	Discover	40.6454587929639928	-73.9854392167542159
16745	2020-03-22 17:58:10	2020-03-22	Barnie Beier-Friesen	barnie.beier.friesen@warmmail.com	San Francisco	California	639018419110921	2fd468d42ed9b9d67d2f83c18618005b	Maestro	37.8000129816964119	-122.424677147182308
16746	2020-03-22 18:08:54	2020-03-22	Ramona Sawayn-Bogisich	ramona.sawayn.bogisich@geemail.com	Saint Paul	Minnesota	4999453537833695	0bfbc7af27b25553e0e009b169b2f75f	American Express	45.0440831766404202	-93.106737518336999
16747	2020-03-22 18:18:36	2020-03-22	Mauricio Homenick-Kerluke	mauricio.homenick.kerluke@geemail.com	Providence	Rhode Island	3158430875089473321	2bc6ac8d3bb081ef90bfd7ea1dd078c5	Mastercard	41.7432713461894522	-71.3278235159266814
16748	2020-03-22 18:24:50	2020-03-22	Donia Dickens	donia.dickens@geemail.com	San Francisco	California	4176937939792447	89b1a1b4842496f6fc8136a8b30c7326	JCB 15 digit	37.7845556056415717	-122.435187881017939
16749	2020-03-22 18:26:44	2020-03-22	Terance Goodwin	terance.goodwin@geemail.com	Las Vegas	Nevada	4413599381701418	9170c3183cb2e29c0dd0cf05abb4fb5c	Mastercard	36.1533737045813339	-115.301923805635795
16750	2020-03-22 18:30:46	2020-03-22	Mrs. Kelsie Nitzsche	mrs.kelsie.nitzsche@geemail.com	Sandy Springs	Georgia	3528781309043516038	42bbc9951c7cb7332503b77639475b29	Diners Club / Carte Blanche	33.8666884009316576	-84.4397669107269593
16751	2020-03-22 18:35:43	2020-03-22	Basil Pagac-Swaniawski	basil.pagac.swaniawski@woohoo.com	New York	New York	4889840927319223	752819a6c4d836aedb3dca722e8699f1	VISA 16 digit	40.6150421123709506	-73.9951794747158829
16752	2020-03-22 18:36:18	2020-03-22	Kalyn Hermann	kalyn.hermann@woohoo.com	Virginia Beach	Virginia	3088686963274640846	977429c5504c13e3320681f3558965c8	Voyager	36.6995650867652188	-76.1046554440304561
16753	2020-03-22 18:38:03	2020-03-22	Dr. Quincy Schulist	dr.quincy.schulist@geemail.com	San Francisco	California	4330490369451889	3d4776c12f30ab98070f251c3373b88b	Maestro	37.7302085388884123	-122.47852998526804
16754	2020-03-22 18:41:09	2020-03-22	Mrs. Jesse Robel DDS	mrs.jesse.robel.dds@geemail.com	Worcester	Massachusetts	3716155163148319	4a58d87234ccfb6d8ff5d7ddc5ef17e8	JCB 16 digit	42.2387985783796793	-71.7795608707956916
16755	2020-03-22 18:42:20	2020-03-22	Codie Pfannerstill	codie.pfannerstill@geemail.com	Cedar Rapids	Iowa	210047791038235510	8f8e0c3867b3da5d9405ba4b576362c4	JCB 16 digit	41.9253261037245366	-91.7457704590700587
16756	2020-03-22 18:46:17	2020-03-22	Alvia Baumbach	alvia.baumbach@geemail.com	San Francisco	California	3745651776680206	2505dcd7d2e8884e535930f0d94bfb6b	Maestro	37.7817997616690562	-122.417160153336297
16757	2020-03-22 19:14:55	2020-03-22	Teddy Hoppe	teddy.hoppe@geemail.com	Phoenix	Arizona	4975344297218912	cbaa85701d54cfe60f1109f326f77182	VISA 13 digit	33.5158819222755753	-112.162137662519143
16758	2020-03-22 19:36:32	2020-03-22	Rianna Deckow DVM	rianna.deckow.dvm@geemail.com	Roseville	California	3337997752339256746	bf3ac56ae69fe8f49142d227f489d56b	JCB 16 digit	38.770494785258542	-121.293267112480109
16759	2020-03-22 19:39:50	2020-03-22	Ms. Ofelia Bahringer	ms.ofelia.bahringer@warmmail.com	Berkeley	California	4739796989013	e00b982b8bb386e504c820832d915b66	Maestro	37.8863985795204741	-122.234638224324954
16760	2020-03-22 19:52:47	2020-03-22	Grant Trantow	grant.trantow@geemail.com	Oakland	California	3337657964049646550	295224b1be9067f60fdeb6c5f73e9ad9	VISA 13 digit	37.7449557327050726	-122.286695277032564
16761	2020-03-22 20:06:16	2020-03-22	Beverly Dicki	beverly.dicki@geemail.com	Oakland	California	3008156540766112	ddc26eabb57f8c57c32476e7f0125d0f	Diners Club / Carte Blanche	37.815647553453104	-122.263801271202055
16762	2020-03-22 20:07:08	2020-03-22	Semaj Nolan	semaj.nolan@geemail.com	San Francisco	California	6011222615270392191	09cce00fe619977a3c2f444a7db85ac9	American Express	37.7747186762492575	-122.415291381829604
16763	2020-03-22 20:23:45	2020-03-22	Marianne Miller	marianne.miller@geemail.com	North Charleston	South Carolina	53154759175905442	1a2c5237cb4b20d41eacc874ec745054	Discover	32.919892399355021	-80.0854705673735623
16764	2020-03-22 20:27:58	2020-03-22	Mr. Ivan Kuhic Sr.	mr.ivan.kuhic.sr.@geemail.com	Cincinnati	Ohio	869924651971671914	a03f4528763f8c0f2cc3e3f3705c3b8f	Discover	39.0493416797134998	-84.4162581463616277
16765	2020-03-22 20:44:38	2020-03-22	Corinna Bode	corinna.bode@geemail.com	San Francisco	California	4212534451712	bb2b2434ef3470c206f9e1531d628c41	Diners Club / Carte Blanche	37.7422799165773597	-122.456095328199567
16766	2020-03-22 20:45:47	2020-03-22	Braeden Denesik IV	braeden.denesik.iv@warmmail.com	Irving	Texas	4085255567217	0d4aabb975fc8e462d61966e52cdb45d	Voyager	32.770868051652613	-96.9374974510911898
16767	2020-03-22 20:47:18	2020-03-22	Arnie Yost	arnie.yost@geemail.com	Tallahassee	Florida	3096958339642894459	a83dd483c1cb7b47bb77f2f268e9c0c4	VISA 16 digit	30.418427435078101	-84.1944995221231096
16768	2020-03-22 20:55:46	2020-03-22	Shafter Tremblay	shafter.tremblay@warmmail.com	Kansas City	Missouri	869966987082157883	3192e161325c0fa788682f52c371fb7f	JCB 16 digit	39.0743713890969815	-94.4986071633864242
16769	2020-03-22 21:03:45	2020-03-22	Austyn McLaughlin	austyn.mclaughlin@geemail.com	San Francisco	California	676245587682001	7603fc93a3451680fb3f6223d7d842fe	American Express	37.8222967903197471	-122.427339007264749
16770	2020-03-22 21:15:41	2020-03-22	Almeta Kertzmann	almeta.kertzmann@geemail.com	Salt Lake City	Utah	4302161080064	e02d62a3754687fd9837bd5b6a59779b	Maestro	40.7818583553802227	-111.950553841836751
16771	2020-03-22 21:23:31	2020-03-22	Amy Trantow DDS	amy.trantow.dds@geemail.com	San Francisco	California	4034923017079941	457372de6c4af8bf193b183404f10469	American Express	37.7849901918925326	-122.437143690346076
16772	2020-03-22 21:38:21	2020-03-22	Verda Windler	verda.windler@geemail.com	Columbus	Georgia	6011105031156146473	fbe952d3410889118028489a045ede1f	Mastercard	32.5949620930988289	-84.7992321500718589
16773	2020-03-22 21:39:13	2020-03-22	Kenton Rath	kenton.rath@geemail.com	Tucson	Arizona	639035480505706	7cdef141e3af4b74600020c40a2494b2	VISA 16 digit	32.1364474447485051	-110.943193789594247
16774	2020-03-22 21:48:31	2020-03-22	Mrs. Jaylee Hayes	mrs.jaylee.hayes@geemail.com	El Paso	Texas	869991201618413458	b8b641f7c8f137172d9486d5034dbca9	Voyager	31.9280114193741262	-106.498312005398802
16775	2020-03-22 21:59:32	2020-03-22	Ms. Alysia Pouros DDS	ms.alysia.pouros.dds@geemail.com	San Diego	California	3088548051190814881	0a71ba5fbe852b72d8bfde17ec6a20ae	JCB 16 digit	32.8491065733201779	-117.070794474743309
16776	2020-03-22 22:00:23	2020-03-22	Urijah Hegmann IV	urijah.hegmann.iv@warmmail.com	New York	New York	3701646598915485	2aae5fd1160fd01245cc3e56dd42f47a	JCB 16 digit	40.6244630827326318	-73.8824730666249962
16777	2020-03-22 22:47:10	2020-03-22	Malik Will	malik.will@woohoo.com	New Orleans	Louisiana	4967027711783641	c97d106cedae0a4f5e6c226df10eb040	Discover	29.985455608648806	-89.8973903353121102
16778	2020-03-22 22:50:31	2020-03-22	Michell Armstrong	michell.armstrong@geemail.com	Jacksonville	Florida	3112280560884596796	45bfa45c7b9bcb1a4732ca23194c5cc8	VISA 16 digit	30.3596460183203227	-81.6121322341341653
16779	2020-03-22 23:06:43	2020-03-22	Belton Hane	belton.hane@geemail.com	Los Angeles	California	6011754490139313556	a5189b001ad2ad5724cba1d020ffa298	JCB 15 digit	33.9197247861750384	-118.35899834283552
16780	2020-03-22 23:13:58	2020-03-22	Darien O'Connell	darien.o'connell@geemail.com	St. Petersburg	Florida	180013716069013403	f78b008817db08198322554cbb610d14	Maestro	27.8256559295933705	-82.6858009839788082
16781	2020-03-22 23:14:06	2020-03-22	Aloysius Turcotte Jr.	aloysius.turcotte.jr.@woohoo.com	New York	New York	4304067795852	be8a334099b481f20a718c4a66edb234	Diners Club / Carte Blanche	40.6659077143520094	-73.8627261915605544
16782	2020-03-22 23:21:53	2020-03-22	Loretto Renner	loretto.renner@geemail.com	Pembroke Pines	Florida	3436894625850726	6524bafa69fc1cf3437d5b1b6219840e	JCB 16 digit	26.1114321674257539	-80.3710011446286074
16783	2020-03-22 23:32:10	2020-03-22	Wilhelmine Bartoletti PhD	wilhelmine.bartoletti.phd@woohoo.com	Fort Worth	Texas	4169834237684179	c8d25f420a86bcf5c307a6313221a95c	VISA 13 digit	32.8382080541979562	-97.3800060552366062
16784	2020-03-22 23:41:00	2020-03-22	Clell Abbott	clell.abbott@geemail.com	Norfolk	Virginia	4936841362440	0dd20fe8a2a274fae9947d15bd5434d4	VISA 16 digit	36.8822888008337486	-76.205866945395627
16785	2020-03-22 23:42:02	2020-03-22	Max Ullrich III	max.ullrich.iii@geemail.com	Dallas	Texas	4650024931457454	a65c5a25f1a6d903a8d031e0fa60e28d	JCB 16 digit	32.8874572597716011	-96.7510455489121313
16786	2020-03-22 23:48:44	2020-03-22	Amalie Schulist	amalie.schulist@woohoo.com	New York	New York	210093659650716120	9ff004b1f7b6b6ce8fd8d436f8777643	Maestro	40.7365583618394993	-73.9688767139229952
16787	2020-03-22 23:58:08	2020-03-22	Gordon Zboncak	gordon.zboncak@warmmail.com	Aurora	Colorado	54426532752445104	691a2b8b910e9f6a5e93f542ceca313d	Voyager	39.725602609815077	-104.737491431657972
16788	2020-03-23 00:10:53	2020-03-23	Gavyn Medhurst-Morissette	gavyn.medhurst.morissette@geemail.com	Las Vegas	Nevada	6011458883534887902	64fdf05f449e621cc9c2a446cfec232a	VISA 16 digit	36.2954907613907025	-115.236427909249812
16789	2020-03-23 00:15:45	2020-03-23	Noreen Robel	noreen.robel@geemail.com	Boston	Massachusetts	4867849783609979	770278a9af2baddfc7253682ff75d7be	Voyager	42.3001974675972008	-70.9687471864231014
16790	2020-03-23 00:17:30	2020-03-23	Miss Lacey Bode	miss.lacey.bode@geemail.com	Oakland	California	675925822660483	b66e9d4185208c10dd37ff762e739042	Voyager	37.8050124020975815	-122.282550560975807
16791	2020-03-23 01:13:19	2020-03-23	Mrs. Parlee Hackett	mrs.parlee.hackett@geemail.com	Westminster	Colorado	4980693726146	5091396f0293bba07cb639a4eee92e06	JCB 16 digit	39.8016648993201514	-105.047947067828488
16792	2020-03-23 01:15:05	2020-03-23	Ludie Runolfsdottir	ludie.runolfsdottir@geemail.com	San Francisco	California	6011911573448417307	ba22dbf4ce951fafb02611b2cdff5311	VISA 16 digit	37.7790131693502644	-122.446451801269959
16793	2020-03-23 01:17:33	2020-03-23	Fredy Stracke-Hickle	fredy.stracke.hickle@geemail.com	Murrieta	California	4517831778058770	5ec70b8ac3d281edc4f9dfd80bba4ceb	Discover	33.6205417870640773	-117.167595278927678
16794	2020-03-23 01:33:07	2020-03-23	Brigette Marquardt	brigette.marquardt@geemail.com	San Francisco	California	3042578438322961	397ec759fa605e8fa3c0ad79e0da5d40	VISA 16 digit	37.7868904656365245	-122.430649277719908
16795	2020-03-23 01:35:31	2020-03-23	Jevon Nicolas-Jast	jevon.nicolas.jast@geemail.com	Henderson	Nevada	4301303983318621	345c762ac613a9d2985174e6b35a5102	Voyager	35.9507296547226645	-115.104478803758326
16796	2020-03-23 01:47:10	2020-03-23	Dr. Larue Cassin DDS	dr.larue.cassin.dds@geemail.com	Charlotte	North Carolina	3787792082825322	c5a504739cf0fe4553fcc1947506ab1d	Maestro	35.2159367030274097	-80.7985095476675781
16797	2020-03-23 01:49:41	2020-03-23	Ceil Parisian	ceil.parisian@geemail.com	Chicago	Illinois	639092972109463	bf8afe805854501f920ca6c4c2f921fa	VISA 13 digit	41.8689326263800297	-87.6460855213489367
16798	2020-03-23 02:02:33	2020-03-23	Matthew Nicolas	matthew.nicolas@geemail.com	Laredo	Texas	869959570820994707	eebd25ed401b0a3df76b21a8a45ed55e	Discover	27.552511526103693	-99.4860481614254439
16799	2020-03-23 02:33:25	2020-03-23	Blain Windler	blain.windler@geemail.com	Rockford	Illinois	3112992398357341880	e3fb5baf34c3b29352f0d16d20fdf848	VISA 13 digit	42.3418057237762966	-89.0175814854264189
16800	2020-03-23 02:42:44	2020-03-23	Priscila Renner	priscila.renner@geemail.com	New York	New York	4215106135783609	3b7e73a8500e3e561ce175e9d2f00b3a	VISA 16 digit	40.7173824617862721	-73.9907219630096051
16801	2020-03-23 02:45:22	2020-03-23	Dr. Fisher Padberg	dr.fisher.padberg@warmmail.com	Sioux Falls	South Dakota	6011744902089633240	8f06f3396e0ec3c0dc5ad0add12087e3	Diners Club / Carte Blanche	43.4419893543787268	-96.760337403293704
16802	2020-03-23 03:04:21	2020-03-23	Courtney Welch DVM	courtney.welch.dvm@geemail.com	Ventura	California	3026381604848307	5348e616b4f934db9fe6329a15f2a54d	JCB 15 digit	34.220560186698286	-119.171321351696548
16803	2020-03-23 03:08:06	2020-03-23	Theresa Lesch	theresa.lesch@geemail.com	San Francisco	California	4081584568091	c8530c4fe8c2c8039c0cd1c23bdb6581	VISA 16 digit	37.8021801023335726	-122.445462064226547
16804	2020-03-23 03:11:08	2020-03-23	Darleen Pollich-Towne	darleen.pollich.towne@warmmail.com	Jacksonville	Florida	502074076575716	3ef71b4ca7dc6d1b4ef89f2d57a68cc8	Diners Club / Carte Blanche	30.386920780973135	-81.6997903301924566
16805	2020-03-23 03:14:49	2020-03-23	Mr. Ananias Wyman	mr.ananias.wyman@geemail.com	Fresno	California	3042375801978903	3479747c1da94c3d34e9f685e70bbc55	VISA 13 digit	36.8626444487705811	-119.708492168096456
16806	2020-03-23 03:21:25	2020-03-23	Mr. Emmett Labadie PhD	mr.emmett.labadie.phd@warmmail.com	Santa Clarita	California	3492081940880585	4d9d18dd1d7239db18088057b0b885c5	American Express	34.5026761727612481	-118.566566378679866
16807	2020-03-23 03:24:53	2020-03-23	Coleen Douglas	coleen.douglas@woohoo.com	Jacksonville	Florida	4125905646936	3cf8182ccbdf1f1d1c4567d45e67b447	VISA 16 digit	30.254470660775528	-81.6663845259308943
16808	2020-03-23 03:37:11	2020-03-23	Ms. Marry Prosacco	ms.marry.prosacco@geemail.com	Pearland	Texas	502083268506272	23738058d430ac872aa35c54c1e6c06d	JCB 16 digit	29.4756383161332458	-95.243291474445158
16809	2020-03-23 03:40:57	2020-03-23	Owen Beier-Ortiz	owen.beier.ortiz@geemail.com	Fayetteville	North Carolina	3337954685299780803	5e5c6966c0392fea488918b87dbed7d3	Mastercard	35.0498249830000077	-79.0448137244340074
16810	2020-03-23 04:23:08	2020-03-23	Alzina Romaguera	alzina.romaguera@geemail.com	Berkeley	California	6011284038301762727	76ac40283b7900870df0609cf4146f5b	Diners Club / Carte Blanche	37.8752109611005494	-122.288692306861037
16811	2020-03-23 04:31:35	2020-03-23	Wiley Larson III	wiley.larson.iii@geemail.com	New York	New York	3096656680249036522	86c497ac38aac89bddd92d8c4a258287	JCB 16 digit	40.6653032272346309	-73.9959077223565345
16812	2020-03-23 04:55:41	2020-03-23	Mr. Ryan Gerlach	mr.ryan.gerlach@geemail.com	Pearland	Texas	3004863820034996	75cd268799ef9688532930b4da5cc19b	American Express	29.5962809452593341	-95.4014427108544822
16813	2020-03-23 05:21:56	2020-03-23	Hoover Effertz MD	hoover.effertz.md@geemail.com	San Francisco	California	4378509024584611	6bb64ec83d8e73949aead2eff172e023	Mastercard	37.7831159755735442	-122.43489978123884
16814	2020-03-23 05:29:10	2020-03-23	Miss Alyssa Hills MD	miss.alyssa.hills.md@geemail.com	Garland	Texas	869930511684236862	ddf156164ae5021e517a43baf81b71b8	VISA 16 digit	32.9706115346170918	-96.5513399107076253
16815	2020-03-23 05:50:14	2020-03-23	Payton Romaguera-Waelchi	payton.romaguera.waelchi@woohoo.com	San Francisco	California	676370763553677	6f9a4aa35b19c959141ecf771647fb5c	Maestro	37.7644640790550525	-122.426896429206082
16816	2020-03-23 05:57:58	2020-03-23	Ms. Sierra Osinski DVM	ms.sierra.osinski.dvm@geemail.com	Fort Worth	Texas	4450866253724	c17812cf934b5b2f2224f179370bb297	VISA 16 digit	32.8460998831372706	-97.4066144979380084
16817	2020-03-23 05:58:35	2020-03-23	Mrs. Adda Langosh PhD	mrs.adda.langosh.phd@geemail.com	Fort Worth	Texas	4532676436241	df17443dbeb9d831119ea5598716b32f	JCB 15 digit	32.754136742703615	-97.2793141276396796
16818	2020-03-23 06:00:16	2020-03-23	Marques O'Kon	marques.o'kon@geemail.com	San Diego	California	3447815455599130	c2d4bc32fb3c7379abd7f6fb838dd441	Maestro	32.813921100047601	-117.12445467909798
16819	2020-03-23 06:07:23	2020-03-23	Aubrie Reichel DVM	aubrie.reichel.dvm@geemail.com	Mobile	Alabama	55041396085327321	1ffb2986f09fb21284817b842ed2d6e8	Mastercard	30.7577508520908651	-88.1484640317641208
16820	2020-03-23 06:43:01	2020-03-23	Kelsey Ziemann	kelsey.ziemann@geemail.com	San Francisco	California	4942375922115354	20e25c19fd524c6ab66d96c591967b63	VISA 16 digit	37.7645970822418775	-122.436971244064424
16821	2020-03-23 07:05:27	2020-03-23	Dr. Jahir Kuphal DDS	dr.jahir.kuphal.dds@geemail.com	Los Angeles	California	51489290065194414	8becbb112146a9251efeb24112aafc0f	VISA 16 digit	33.9928303117264008	-118.387603347654633
16822	2020-03-23 07:29:14	2020-03-23	Floyd Schmeler	floyd.schmeler@geemail.com	San Francisco	California	4832074661254119	80ca39c51ec0244e13280c7bd86f3266	American Express	37.783901833150388	-122.446456483667234
16823	2020-03-23 07:43:46	2020-03-23	Docia Frami	docia.frami@geemail.com	Los Angeles	California	53414812561815737	ba72e7c86fca3503d977f430a005741e	VISA 16 digit	33.9383110347069774	-118.398654281300679
16824	2020-03-23 07:44:59	2020-03-23	Jethro Luettgen	jethro.luettgen@warmmail.com	St. Petersburg	Florida	4802566071567085	e46ef72ad08e4222646404290872a8bf	VISA 13 digit	27.665306466294453	-82.6263051889263096
16825	2020-03-23 08:04:07	2020-03-23	Laurence Shanahan	laurence.shanahan@woohoo.com	San Francisco	California	3158355750936519934	ca0eb9a5d05262cdb34ecb751fd69ab1	JCB 16 digit	37.8041999831911824	-122.460578032252215
16826	2020-03-23 08:09:48	2020-03-23	Taurus Ebert	taurus.ebert@warmmail.com	Minneapolis	Minnesota	6011210529121373462	b9e1478847736e4c18b37cd4f17bdc4d	JCB 16 digit	45.0597500718750013	-93.18241341195926
16827	2020-03-23 08:12:06	2020-03-23	Justen Quitzon PhD	justen.quitzon.phd@warmmail.com	Los Angeles	California	4336643305914592	64f141c8c6cca33db51d902fc73ffae4	JCB 16 digit	33.9326921894546558	-118.453962801628933
16828	2020-03-23 08:28:03	2020-03-23	Dorman Fahey-Ratke	dorman.fahey.ratke@geemail.com	College Station	Texas	4439376964757491	eb44b13f15b65b5bf9be08b6f63c5809	Voyager	30.5595751998525103	-96.2583566185399917
16829	2020-03-23 08:36:21	2020-03-23	Dr. Dayna Bauch DVM	dr.dayna.bauch.dvm@geemail.com	San Francisco	California	589341020623553	0597cb94afbc1fa769a399f1604d9b49	VISA 16 digit	37.7969359851576385	-122.437873587668733
16830	2020-03-23 08:48:25	2020-03-23	Wendel Schuster I	wendel.schuster.i@geemail.com	Charlotte	North Carolina	3528846756688718241	97f1bfaec2874485099f20c5ef2baca4	American Express	35.2429716961711605	-80.7364587102495221
16831	2020-03-23 09:29:25	2020-03-23	Mrs. Velda Kuhn	mrs.velda.kuhn@geemail.com	Las Vegas	Nevada	3050889794700340	03a6f387dc3d4ede96e48c5170ed2435	JCB 16 digit	36.3034103620432305	-115.256217932116613
16832	2020-03-23 09:38:06	2020-03-23	Carlo Greenholt	carlo.greenholt@geemail.com	New York	New York	210093494733475217	a46fa1a7448eff9c7174ddcecb483a10	JCB 15 digit	40.7161435666717608	-74.0288661653071642
16833	2020-03-23 09:56:44	2020-03-23	Dr. Erla Mueller PhD	dr.erla.mueller.phd@warmmail.com	Atlanta	Georgia	3096584544266091272	f3e6416ebe3c2e8071f4eea018215bf6	Voyager	33.7091742811068897	-84.3648169236302437
16834	2020-03-23 09:58:16	2020-03-23	Jonell Lesch	jonell.lesch@geemail.com	Toledo	Ohio	210064366443409899	468409a6f25432155536cb07aa308dee	Discover	41.7190700189381829	-83.538037146754192
16835	2020-03-23 10:02:43	2020-03-23	Sabra Harber	sabra.harber@warmmail.com	El Paso	Texas	53447058650914202	e2126cb1424a3285c2b923fd3e3b93ee	JCB 16 digit	31.8707927748855226	-106.368763432230807
16836	2020-03-23 10:04:24	2020-03-23	Ms. Suellen Stroman DDS	ms.suellen.stroman.dds@geemail.com	Gilbert	Arizona	3337439237108226290	35cae1a6d8d595a0ec638a8b2d16e863	JCB 16 digit	33.2661606615289998	-111.729369968515257
16837	2020-03-23 10:06:21	2020-03-23	Alfonso McClure-Welch	alfonso.mcclure.welch@woohoo.com	Downey	California	869904354312167288	1d65fba902b0711e502c1c7d63ed6908	Mastercard	33.8443466114129876	-118.144434126291046
16838	2020-03-23 10:23:26	2020-03-23	Simmie Hills	simmie.hills@geemail.com	St. Louis	Missouri	210022829998579813	cb81e8835b6f7a4ab3a72f09b83b9605	VISA 16 digit	38.573403010719268	-90.2685404303487502
16839	2020-03-23 10:57:29	2020-03-23	Dr. Shyheim Beer	dr.shyheim.beer@geemail.com	Huntsville	Alabama	6011298329802394274	e844a7745045eeb8bd4c8b5be6ba06f4	JCB 16 digit	34.6646353899277742	-86.583743812005963
16840	2020-03-23 11:02:00	2020-03-23	Ward Ondricka	ward.ondricka@geemail.com	Buffalo	New York	4952658017264857	819970047b0d7a0b48a476724b07fae2	JCB 16 digit	42.9328169536963102	-78.8524920340560413
16841	2020-03-23 11:06:39	2020-03-23	Ms. Cristina Beatty PhD	ms.cristina.beatty.phd@woohoo.com	Oakland	California	3158682134294955838	1d98d9540aaa24c8c433f79a87ce4e12	Mastercard	37.84075999400293	-122.283900329109542
16842	2020-03-23 11:36:25	2020-03-23	Mikeal Crist	mikeal.crist@geemail.com	Mesquite	Texas	4572349021368	b44da562c39d770e3c72ea7e8de20a58	VISA 16 digit	32.8277132603149866	-96.544651586023349
16843	2020-03-23 11:46:40	2020-03-23	Gage Torp-Witting	gage.torp.witting@geemail.com	San Francisco	California	180084744654851387	47ec76c3d9475849ce6e7857ed74bfe1	JCB 15 digit	37.7493958895028214	-122.452632167035546
16844	2020-03-23 11:55:23	2020-03-23	Ms. Althea Runolfsdottir PhD	ms.althea.runolfsdottir.phd@geemail.com	San Francisco	California	3112584490232612439	daa3a493e181c2d463a9c8132b8fde75	Voyager	37.7812808998109659	-122.424896249080106
16845	2020-03-23 12:26:37	2020-03-23	Hampton Weimann DVM	hampton.weimann.dvm@woohoo.com	New York	New York	180040399122540063	d2a864daf991b9111a156f5a6eb42378	JCB 16 digit	40.7582551955934633	-73.8683719782054453
16846	2020-03-23 12:35:48	2020-03-23	Otto Reichert	otto.reichert@warmmail.com	Moreno Valley	California	3337419875044310621	5786e701b9439ac6987db09a04fa2841	VISA 16 digit	34.0077915710389576	-117.210839059573402
16847	2020-03-23 12:40:11	2020-03-23	Trudi Bergstrom PhD	trudi.bergstrom.phd@woohoo.com	Carrollton	Texas	3056778470113064	bcc903fadf44bfe1a4847d58c4ecb9f0	Voyager	32.9935071824971544	-96.9525606904972364
16848	2020-03-23 12:52:41	2020-03-23	Tinnie Schultz	tinnie.schultz@woohoo.com	Lexington	Kentucky	54700063910030759	40e19981977644c654ed09d604e8bf14	VISA 16 digit	38.0267739561263483	-84.4487017291963014
16849	2020-03-23 12:58:52	2020-03-23	Deb Mraz	deb.mraz@woohoo.com	New York	New York	4424798955516	c31fed3c39f317f7052c67ba16a4f36a	JCB 16 digit	40.6559950245302133	-74.0233912591252476
16850	2020-03-23 13:03:17	2020-03-23	Carolina Feil	carolina.feil@woohoo.com	New York	New York	180029734389397168	8a28a6a48fcd0c2d1becffb4c525f1da	VISA 16 digit	40.7352586575541622	-73.9492670867022071
16851	2020-03-23 13:07:23	2020-03-23	Anitra Hoppe	anitra.hoppe@warmmail.com	San Francisco	California	4475086724940007	8327cd626f68620e5d1ff29a04465689	American Express	37.7909765538895499	-122.425722415678052
16852	2020-03-23 13:23:36	2020-03-23	Rosendo Reichel	rosendo.reichel@woohoo.com	New York	New York	3528948950051370774	24332f807c7deca5cf95c7a959fd7717	VISA 13 digit	40.7138308350685989	-73.9386605149030629
16853	2020-03-23 13:24:44	2020-03-23	Elie Koelpin	elie.koelpin@warmmail.com	San Francisco	California	869900474444238015	b7133771cfa312ed2114b75a874633ca	American Express	37.7825859249870533	-122.444079961177607
16854	2020-03-23 13:32:54	2020-03-23	Dr. Tallie Beahan	dr.tallie.beahan@warmmail.com	Fremont	California	3096798770147949378	9f1689d8fbd37b78a516d9137f3faed8	Voyager	37.4365168593060247	-121.964821036624528
16855	2020-03-23 13:34:55	2020-03-23	Dr. Yehuda Fisher MD	dr.yehuda.fisher.md@woohoo.com	New York	New York	6011114680696734674	73afce9d64811c1d72f11e824bc8416a	Diners Club / Carte Blanche	40.6680222949236594	-73.9169605589833054
16856	2020-03-23 13:36:40	2020-03-23	Dr. Christ VonRueden	dr.christ.vonrueden@geemail.com	San Francisco	California	6011595752486637264	a4f0cd89c7a989a6cb1ca370b5719888	JCB 16 digit	37.7878784260347089	-122.450568253532069
16857	2020-03-23 13:52:48	2020-03-23	Bristol Mertz	bristol.mertz@woohoo.com	New York	New York	4847471584239	730b86a82341e2c7653cdfb7d535df9e	VISA 13 digit	40.6962722280751876	-73.8773653607245535
16858	2020-03-23 13:56:21	2020-03-23	Ms. Miriah Cronin DDS	ms.miriah.cronin.dds@geemail.com	Berkeley	California	3088919378860562388	c411e2ab0dd8bf61964a6de5add7fdfc	American Express	37.8646678076645244	-122.25263422205937
16859	2020-03-23 14:43:20	2020-03-23	Preston Tromp	preston.tromp@geemail.com	San Francisco	California	4032774198211346	41027580a11dff31fa0dc70074ae1f09	JCB 16 digit	37.7690071045964473	-122.397113996189674
16860	2020-03-23 15:30:56	2020-03-23	Ever Turcotte DVM	ever.turcotte.dvm@woohoo.com	Huntington Beach	California	55510183812748603	74d1bcd88e09191a624f43aea6ca9452	JCB 16 digit	33.6583345781587084	-118.008166185778748
16861	2020-03-23 15:52:21	2020-03-23	Dr. Chester Zulauf Jr.	dr.chester.zulauf.jr.@warmmail.com	Chicago	Illinois	869964572836300567	9553c0ee5a41949e34cff233182e3a76	JCB 16 digit	41.8482283881235873	-87.6194650534570201
16862	2020-03-23 15:55:14	2020-03-23	Roy Macejkovic	roy.macejkovic@warmmail.com	Tulsa	Oklahoma	4900512992935	225119110c710edb518f39324e9d65b2	VISA 13 digit	36.193500532153621	-95.8742297043979192
16863	2020-03-23 16:02:04	2020-03-23	Easton Buckridge	easton.buckridge@woohoo.com	Jacksonville	Florida	3429365932183084	0cf2671ec3ecef3ec0c6c73a120c5404	JCB 16 digit	30.2623981107544147	-81.6035457069598209
16864	2020-03-23 16:08:46	2020-03-23	Dr. Areli Hansen MD	dr.areli.hansen.md@geemail.com	San Francisco	California	503890280182727	05814bf43acc1b2b5419b91f2971c98a	Mastercard	37.780662800613193	-122.434068611072931
16865	2020-03-23 16:36:07	2020-03-23	Aldona Mosciski-Crooks	aldona.mosciski.crooks@warmmail.com	San Diego	California	4701586804887818	82ea1e5cfa37d62e354a8ee5cb74d250	Discover	32.9119290606185828	-117.105145922433593
16866	2020-03-23 16:37:57	2020-03-23	Arah O'Connell	arah.o'connell@geemail.com	Phoenix	Arizona	3096341296005863602	d77dd6e737aa5fae260a363f80aaecea	JCB 16 digit	33.5243848148666359	-112.160113766223574
16867	2020-03-23 16:55:03	2020-03-23	Nora Barrows	nora.barrows@geemail.com	Portland	Oregon	869947607138629578	2254a6cedfc8cd2913e4a63a1b74dfdb	Discover	45.4416724659856399	-122.641215678118172
16868	2020-03-23 17:19:53	2020-03-23	Lurana Bauch	lurana.bauch@geemail.com	North Las Vegas	Nevada	55962801261232208	93429a273abbf6afbd7e6853d6dbd6fa	Diners Club / Carte Blanche	36.3417130830854163	-115.17461627477185
16869	2020-03-23 17:20:49	2020-03-23	Fernand Bernier	fernand.bernier@warmmail.com	Arlington	Texas	3418615940483683	5d043ec4e4c87be7b454ff1ac949dc62	VISA 16 digit	32.61221368510909	-97.0763406171023888
16870	2020-03-23 17:36:32	2020-03-23	Dr. Goldia Kirlin	dr.goldia.kirlin@woohoo.com	Los Angeles	California	3528093433660535593	c8f0f589630089472ae5e21daec9c218	VISA 16 digit	34.0831247200123926	-118.386919834417469
16871	2020-03-23 18:12:48	2020-03-23	Brylee Berge PhD	brylee.berge.phd@geemail.com	Plano	Texas	3088752231614244193	23299cd8f63d6d62be0786c5f95d4db7	Discover	32.9816631367981472	-96.7895169518604916
16872	2020-03-23 18:12:55	2020-03-23	Demi Nicolas	demi.nicolas@woohoo.com	Cedar Rapids	Iowa	3011527505524372	89c5e71f44f437306b6888bafdde55b3	Voyager	41.9797577960491139	-91.7550549651097498
16873	2020-03-23 18:32:52	2020-03-23	Skylar Bruen	skylar.bruen@geemail.com	Las Vegas	Nevada	3096020871779039783	a7325c0c7511ac9e280c4df614127304	VISA 16 digit	36.2396245101101684	-115.315543706270304
16874	2020-03-23 18:41:34	2020-03-23	Mr. Hollie Bins	mr.hollie.bins@geemail.com	Tuscaloosa	Alabama	4401798573911603	466bd41175aaf832be4296fd3f1464a1	JCB 15 digit	33.2116276019308714	-87.438398808436844
16875	2020-03-23 18:54:54	2020-03-23	Linus Reynolds	linus.reynolds@geemail.com	Louisville	Kentucky	4151648144500033	7634472404b20aa1465a961b24f10db3	Mastercard	38.1882165061678691	-85.6336096840050089
16876	2020-03-23 19:12:17	2020-03-23	Mrs. Anaya Stark	mrs.anaya.stark@geemail.com	North Las Vegas	Nevada	3337364651800763971	d48e49ba55e92ed5f7fb2d06c8825ecb	VISA 16 digit	36.3775646922334985	-115.135068978018694
16877	2020-03-23 19:33:45	2020-03-23	Keaton Bosco	keaton.bosco@geemail.com	Las Vegas	Nevada	3750800598166371	96455b440d5f12c08012e779948c81b7	American Express	36.1721411849938335	-115.340616354786221
16878	2020-03-23 19:44:13	2020-03-23	Dr. Gerhard Hermann	dr.gerhard.hermann@geemail.com	Wichita	Kansas	3096606437859765671	ca96f50266361df4214aa1e06925230d	Discover	37.7736520367551591	-97.3682901579622211
16879	2020-03-23 19:50:05	2020-03-23	Karla Heller	karla.heller@geemail.com	New York	New York	869986841364981955	def478c13fb4d41f19128cf58ff5d12a	Discover	40.6770931577533474	-73.9811293541815047
16880	2020-03-23 19:50:54	2020-03-23	Dr. Arlan Crona III	dr.arlan.crona.iii@geemail.com	Miramar	Florida	4695417990974822	37e77cbcccfb1fd0be31e38a32abcd4a	JCB 16 digit	25.885507167361677	-80.3170145767267911
16881	2020-03-23 20:32:23	2020-03-23	Clay Moen	clay.moen@geemail.com	San Francisco	California	4229956903285	186eedb3aaf0a1eee4c8fa63d5a69412	VISA 16 digit	37.7870456337575931	-122.431709130199295
16882	2020-03-23 20:52:29	2020-03-23	Cody Macejkovic	cody.macejkovic@geemail.com	Kenosha	Wisconsin	4508472060229	51411c237bea19bc984d5cb2402c3e56	VISA 16 digit	42.675277784311028	-87.9372607531718984
16883	2020-03-23 21:01:03	2020-03-23	Sade Klein	sade.klein@geemail.com	San Francisco	California	6011549031892193452	38387de2afdba5b09707b67f80b940e0	VISA 13 digit	37.7506764148445697	-122.437552938604426
16884	2020-03-23 21:14:09	2020-03-23	Kaitlin Nikolaus	kaitlin.nikolaus@geemail.com	Spokane	Washington	3032863604300722	c7a34002f4f37fab4f4e499620685bde	JCB 16 digit	47.5726670329697399	-117.474456514920291
16885	2020-03-23 21:35:58	2020-03-23	Yuridia Lindgren PhD	yuridia.lindgren.phd@geemail.com	Indianapolis	Indiana	589336068563760	e64bb4b8598dd026dea82316a53b2361	VISA 16 digit	39.7896290981683833	-86.1397369998708342
16886	2020-03-23 21:53:49	2020-03-23	Elden Keebler-Bartell	elden.keebler.bartell@geemail.com	New York	New York	4903539410248483	a7010f5a3c927a8a683621fb43377d6a	VISA 16 digit	40.7134101331457501	-73.9070911863714457
16887	2020-03-23 22:07:14	2020-03-23	Fayette Wyman IV	fayette.wyman.iv@warmmail.com	San Francisco	California	4300919626688103	03906a301d2ce9d431014103632f0166	Discover	37.7903452362120191	-122.443567764164726
16888	2020-03-23 22:47:42	2020-03-23	Arlin Mitchell	arlin.mitchell@geemail.com	Las Vegas	Nevada	4918269032549	98282c259fa616427451cede85cc4073	VISA 16 digit	36.2842420568324613	-115.246109946698311
16889	2020-03-23 22:52:24	2020-03-23	Terra Daniel	terra.daniel@geemail.com	Antioch	California	869902004898188792	7a73c8ba8e6f9908d349fba54f74da05	JCB 16 digit	37.9738864539921295	-121.710320375504722
16890	2020-03-23 22:53:00	2020-03-23	Ricardo Friesen	ricardo.friesen@geemail.com	Arvada	Colorado	4252346380956	88e8134f35d590c77a79e616029401a6	VISA 13 digit	39.7876038041140916	-105.161330265549196
16891	2020-03-23 22:55:54	2020-03-23	Emmalee Volkman	emmalee.volkman@geemail.com	San Francisco	California	3528858705759790139	a587244e277b7695d1389fd6125334e4	Mastercard	37.7689407238831691	-122.414926788157899
16892	2020-03-23 22:57:11	2020-03-23	Dr. Kadyn Kautzer	dr.kadyn.kautzer@woohoo.com	Beaumont	Texas	6011789269093254132	627001898ef07e43cb42e9e3dd24874c	JCB 15 digit	29.9968077381677922	-94.1044979830991508
16893	2020-03-23 23:02:39	2020-03-23	Maxim Bailey	maxim.bailey@woohoo.com	Rancho Cucamonga	California	6011531445640734070	fd52d22aa34d26d225bd5d39f32f1c2c	VISA 16 digit	34.0553521569810798	-117.522528334288666
16894	2020-03-23 23:07:02	2020-03-23	Jakayla Larkin	jakayla.larkin@geemail.com	New York	New York	589374655354830	0ce589497803c1d7fd918dffae0135eb	VISA 16 digit	40.7274096043538307	-73.8937043595489058
16895	2020-03-23 23:09:08	2020-03-23	Rosalee Marks	rosalee.marks@geemail.com	Oakland	California	52757759050878517	f683667358ba391da82fdeaeb213a1fc	VISA 16 digit	37.8010670171375835	-122.270137631650968
16896	2020-03-23 23:13:24	2020-03-23	Clyda Conroy-Jast	clyda.conroy.jast@geemail.com	Manchester	New Hampshire	3015672199523128	9aa42e82bf9749301dd6ddd7c23c3017	Discover	42.8946468901425604	-71.4184770751170817
16897	2020-03-23 23:31:20	2020-03-23	Marcus Kozey-Hegmann	marcus.kozey.hegmann@warmmail.com	Cedar Rapids	Iowa	869933087799070493	9ba0a16a6b646557c24381701d2ef07f	JCB 16 digit	41.9709031353779096	-91.7760722667977262
16898	2020-03-23 23:37:25	2020-03-23	Mr. Aidyn Effertz III	mr.aidyn.effertz.iii@warmmail.com	Phoenix	Arizona	869925145057641718	c59d1cd4af9a8ec5f6a372701ad61e7f	JCB 15 digit	33.5885263243623129	-112.010387459576506
16899	2020-03-23 23:44:37	2020-03-23	Mikal Jacobson PhD	mikal.jacobson.phd@geemail.com	West Valley City	Utah	53458998356089617	86575d722bdad2ac313db50c57d71ef1	VISA 13 digit	40.717315183555705	-111.975667045333608
16900	2020-03-23 23:58:49	2020-03-23	Jere Lang	jere.lang@warmmail.com	Alexandria	Virginia	4545320048236651	51b9a256caebbec6bde334287002f9f0	VISA 13 digit	38.9053802966721349	-77.056507255088917
16901	2020-03-24 00:00:11	2020-03-24	Werner Mohr DVM	werner.mohr.dvm@geemail.com	Newport News	Virginia	4429082399651786	9fdb77b15421b4f71732959795e16225	Voyager	37.0516210603423417	-76.5373876684140413
16902	2020-03-24 00:46:26	2020-03-24	Jacques Ziemann	jacques.ziemann@geemail.com	Chicago	Illinois	4719902092835437	42bc45f67b4220b574391831441f0ff2	Mastercard	41.8696760278962543	-87.6740049792017686
16903	2020-03-24 00:48:03	2020-03-24	Dr. Lu Fisher	dr.lu.fisher@geemail.com	Atlanta	Georgia	3096695719103053265	40dd51b1bfb2d61ef7aa9c07f47aed10	Voyager	33.7598227150082622	-84.4666797583036129
16904	2020-03-24 00:50:08	2020-03-24	Lionel Upton	lionel.upton@geemail.com	Hialeah	Florida	4175165906389	ecf8dede971000623c198814b3f51dc5	Maestro	25.8851986196801072	-80.2885940018013002
16905	2020-03-24 00:52:07	2020-03-24	Kolten Reinger	kolten.reinger@geemail.com	New York	New York	3003205425512862	c0751f3ac726930e899fa41564a719a1	Voyager	40.6909021015968193	-73.9079983128596041
16906	2020-03-24 00:58:12	2020-03-24	Rihanna Cummings-Brekke	rihanna.cummings.brekke@geemail.com	El Paso	Texas	3700420134838093	9e915f29877e9c6070546afb108cd3f1	American Express	31.8545468102503584	-106.437229721385989
16907	2020-03-24 01:07:16	2020-03-24	John Sipes	john.sipes@geemail.com	Concord	California	3112277879608372655	c1cb3e661ec2d360932a90ab4f64875b	Maestro	37.9364907578963795	-122.092204870300733
16908	2020-03-24 01:16:27	2020-03-24	Terance Kshlerin	terance.kshlerin@woohoo.com	Nashville	Tennessee	4499196639263528	09165d7c3a497b56a6bab4ef01672550	JCB 15 digit	36.1542249533005062	-86.7651368955057052
16909	2020-03-24 01:21:26	2020-03-24	Arvo Kunze Sr.	arvo.kunze.sr.@geemail.com	San Francisco	California	3479851816394060	5401d170a97180bff18dc49a2a5cf8b1	VISA 13 digit	37.7648749422246297	-122.446986951008597
16910	2020-03-24 01:34:03	2020-03-24	Sherlyn Lakin-Beer	sherlyn.lakin.beer@woohoo.com	San Francisco	California	210072392303045904	17347f2eda4653d198cfc14ea32a4597	Mastercard	37.75728403508122	-122.444701314475353
16911	2020-03-24 01:43:44	2020-03-24	Wayland Goodwin	wayland.goodwin@geemail.com	New York	New York	869911867214487786	9df99333d8df65bc2903c1b419e87900	VISA 16 digit	40.6942847816962754	-73.8690062263410567
16912	2020-03-24 01:48:51	2020-03-24	Catharine Schultz	catharine.schultz@woohoo.com	Charlotte	North Carolina	3096288138988355666	f1210a38be436484a0cb1af4663a876c	VISA 16 digit	35.1153358560308817	-80.7937542250789704
16913	2020-03-24 02:16:57	2020-03-24	Maryjane VonRueden	maryjane.vonrueden@geemail.com	San Francisco	California	55381930117086766	027db8f8fa14de9c9614cb89cc598612	Maestro	37.7543391358139857	-122.43829968823286
16914	2020-03-24 02:21:22	2020-03-24	Mrs. Betha Leannon	mrs.betha.leannon@geemail.com	Oakland	California	3793519922946196	4226cc9291f91e17911366024feb6b77	American Express	37.8344885199450758	-122.310593595054968
16915	2020-03-24 02:22:15	2020-03-24	Liam Rempel	liam.rempel@geemail.com	Arvada	Colorado	4749332010810	5097646bd13c86649b31a35e73be6a81	JCB 16 digit	39.8942353844352056	-105.159317305215822
16916	2020-03-24 02:30:48	2020-03-24	Aja Metz-Considine	aja.metz.considine@geemail.com	New York	New York	3056784273683253	f7bbe96a54afc882eed0e7976b2f4044	JCB 16 digit	40.6336929581817259	-73.9955642285186741
16917	2020-03-24 02:31:46	2020-03-24	Roena Dare DDS	roena.dare.dds@geemail.com	Philadelphia	Pennsylvania	3000867047406113	63556365c4f7c6f3ad5b1113ead0f462	JCB 16 digit	40.0902156060986243	-75.0620513651885091
16918	2020-03-24 02:52:04	2020-03-24	Glendon Ziemann	glendon.ziemann@woohoo.com	Rancho Cucamonga	California	6011035250623461720	93fba4c1600cba3988ca5c3c0f3d276c	VISA 13 digit	34.1056193967342409	-117.55473349206224
16919	2020-03-24 02:58:48	2020-03-24	Samiyah Harris	samiyah.harris@geemail.com	Glendale	Arizona	3337276162784467222	d6470588da29663b58d3dee7554114fd	Diners Club / Carte Blanche	33.5898805415950719	-112.106193645650137
16920	2020-03-24 03:13:11	2020-03-24	Tommie Bauch Sr.	tommie.bauch.sr.@woohoo.com	Fort Worth	Texas	4960047144693123	caa7cca3621c5faf81e308f66845597e	Voyager	32.8618543820977251	-97.3920330660704536
16921	2020-03-24 03:23:35	2020-03-24	Tamiko Carter	tamiko.carter@geemail.com	Eugene	Oregon	3776961655512582	06d3f93457155ab6de000265742447dc	VISA 16 digit	44.0493397774368489	-123.169719645519564
16922	2020-03-24 03:30:49	2020-03-24	Marietta Roob	marietta.roob@woohoo.com	Atlanta	Georgia	3026021222152225	e9b3c67eded04035677c887c8554b305	JCB 15 digit	33.7086384788896893	-84.3766575995877446
16923	2020-03-24 03:32:19	2020-03-24	Alby King	alby.king@geemail.com	Dallas	Texas	180006342756486551	e3667482618a9e071e0d9d1b6e20e88f	Voyager	32.8718095066297806	-96.8540344875268602
16924	2020-03-24 04:00:14	2020-03-24	Mozella Bernier	mozella.bernier@woohoo.com	Denver	Colorado	3045650769769701	aedca179d989bd7ebc367fccd3ad53b4	Diners Club / Carte Blanche	39.7383250634238081	-104.888909135271234
16925	2020-03-24 04:06:53	2020-03-24	Karyn Miller DDS	karyn.miller.dds@woohoo.com	Huntington Beach	California	060486251351176	ebefead54d5c97719dd0edb35b602007	Diners Club / Carte Blanche	33.5946891690179754	-118.102433983900767
16926	2020-03-24 04:22:17	2020-03-24	Mimi Mann MD	mimi.mann.md@geemail.com	Oakland	California	3112531199387189549	2c8b0a161a9d528b42454f74611712d8	JCB 16 digit	37.8050472569181366	-122.248293287145316
16927	2020-03-24 04:22:30	2020-03-24	Bradford Hirthe	bradford.hirthe@warmmail.com	Fort Worth	Texas	4032527037158965	c578c3549518cdd39bcabca84a9baae2	Mastercard	32.8775897168610243	-97.3056004895649806
16928	2020-03-24 04:37:13	2020-03-24	Tylor Oberbrunner	tylor.oberbrunner@geemail.com	Anaheim	California	503859351183401	2ffb6a091b76595542358f5d5b7b8e6f	JCB 16 digit	33.9356270098425412	-117.755125445427737
16929	2020-03-24 04:54:58	2020-03-24	Dr. Ocie Tromp PhD	dr.ocie.tromp.phd@geemail.com	New York	New York	52854733612600950	f897fbe3b46486539e8e457404751e1f	Mastercard	40.5668182709012157	-73.9078031581722144
16930	2020-03-24 05:07:38	2020-03-24	Lenord McLaughlin	lenord.mclaughlin@geemail.com	Rialto	California	55297316212868055	a9e2be13b846b21d782b51fee1e884b5	JCB 15 digit	34.1483460622590087	-117.388428148403023
16931	2020-03-24 05:23:04	2020-03-24	Scottie Hansen	scottie.hansen@geemail.com	Virginia Beach	Virginia	3337009427870776016	bbb4aa51a374200d7c7817de66d178b5	Diners Club / Carte Blanche	36.8220268885791313	-76.0289018420640303
16932	2020-03-24 05:24:17	2020-03-24	Tamatha Greenfelder PhD	tamatha.greenfelder.phd@geemail.com	Worcester	Massachusetts	3029818201010523	72196116ce3afaa6cadfaa5c464bc196	Discover	42.2762092514596901	-71.8813026621259752
16933	2020-03-24 05:27:44	2020-03-24	Kiara Adams	kiara.adams@geemail.com	Los Angeles	California	3032834066245119	f4ed473e52d6203dd16b3f00b76b3f71	JCB 16 digit	33.9919353685207639	-118.497331936191017
16934	2020-03-24 05:40:41	2020-03-24	Dionte Marks	dionte.marks@geemail.com	McAllen	Texas	869923947319443565	612f8f7b83b8771af9073adfeefc12d5	American Express	26.2956739560075086	-98.2236843789309262
16935	2020-03-24 05:53:32	2020-03-24	Cornelius Langosh	cornelius.langosh@geemail.com	Coral Springs	Florida	6011033971964574167	45ed99e33417d77e8157c59f21457593	Maestro	26.339377749764175	-80.2805285287212484
16936	2020-03-24 06:37:34	2020-03-24	Mr. Santino Kovacek	mr.santino.kovacek@geemail.com	Springfield	Missouri	3088690014494366475	84415ef376d3b918a8b07b87f829691f	Mastercard	37.1568535715535333	-93.2957748478103497
16937	2020-03-24 06:52:52	2020-03-24	Torrey Ward V	torrey.ward.v@geemail.com	Murfreesboro	Tennessee	869978539288328499	e06766aabe7a58fac8f0ff9ec4e26650	JCB 15 digit	35.8743636242233279	-86.4381243226435032
16938	2020-03-24 06:54:40	2020-03-24	Roger Cremin	roger.cremin@geemail.com	San Francisco	California	4692893520554115	9dc7adbf062d0281899a3c80be156dfc	JCB 16 digit	37.7631989160982755	-122.421812807328436
16939	2020-03-24 07:46:05	2020-03-24	Mont Crist	mont.crist@geemail.com	Chicago	Illinois	55404004279789931	9e9645ee3656bf2dba727848e27086da	Mastercard	41.8265693585690101	-87.7657220818597779
16940	2020-03-24 07:46:37	2020-03-24	Dr. Marcell Fadel MD	dr.marcell.fadel.md@woohoo.com	Atlanta	Georgia	3337879259679568832	95274c2450e40bc20a358f90cc3b1135	JCB 16 digit	33.7394471552033011	-84.4469112230975298
16941	2020-03-24 08:19:03	2020-03-24	Dr. Kwame Goldner	dr.kwame.goldner@geemail.com	New York	New York	3416836519558737	e48bbb009f554fe76b9ceb6d4598c190	JCB 16 digit	40.6320122431721558	-74.0176213914889871
16942	2020-03-24 08:40:16	2020-03-24	Giselle Yundt	giselle.yundt@geemail.com	Montgomery	Alabama	4154201587404	b3f2800a1c50823206b6fbf8d6ae4086	VISA 16 digit	32.3267572937466241	-86.1751967674273942
16943	2020-03-24 08:41:05	2020-03-24	Sylvanus Rempel	sylvanus.rempel@geemail.com	Roseville	California	51259755674793994	158f919dd0d6d9c89cbba7eef9cd8f1a	Discover	38.8567923754043889	-121.332606509396427
16944	2020-03-24 08:48:43	2020-03-24	Alina Braun PhD	alina.braun.phd@geemail.com	San Francisco	California	54054982580599011	2cb0c08e834571eebb21bcb97094c754	Maestro	37.8104857728668691	-122.422181639309045
16945	2020-03-24 08:51:49	2020-03-24	Tallie Kshlerin	tallie.kshlerin@warmmail.com	Long Beach	California	3043409240449918	11666ae0f2743ade8e8720f6891d25fb	VISA 16 digit	33.8632361297782509	-118.252577313843361
16946	2020-03-24 09:03:03	2020-03-24	Sullivan Carter DVM	sullivan.carter.dvm@geemail.com	San Francisco	California	3426536149191986	636bf93a4dbadaf25e3c275c1d933d17	VISA 16 digit	37.7571871813469926	-122.435954410320477
16947	2020-03-24 09:04:46	2020-03-24	Georgiann Mayer-Lehner	georgiann.mayer.lehner@geemail.com	San Antonio	Texas	869956392515577405	0f14a589180336d2657786d843656a9c	Diners Club / Carte Blanche	29.4694896508544701	-98.6176008720252639
16948	2020-03-24 09:06:51	2020-03-24	Ms. Scarlet Douglas	ms.scarlet.douglas@geemail.com	Los Angeles	California	3158911140945459537	55b4205103f3746b37d061c44b5c0ae6	Maestro	33.943546557552736	-118.429372189798571
16949	2020-03-24 09:10:05	2020-03-24	Lillie Steuber	lillie.steuber@geemail.com	Jacksonville	Florida	4630498753581259	d6974c9f87f79fb9eb873dfa8f767265	JCB 15 digit	30.3909559723507599	-81.7473383518945553
16950	2020-03-24 09:10:38	2020-03-24	Nichole Bartell-Shields	nichole.bartell.shields@geemail.com	Baton Rouge	Louisiana	3004167648534942	16fd31b324e75e7306b8c1fd1d15b573	Diners Club / Carte Blanche	30.4431683107025925	-91.1114635529104646
16951	2020-03-24 09:18:16	2020-03-24	Mr. Loney Reinger Sr.	mr.loney.reinger.sr.@woohoo.com	San Bernardino	California	4665600889480375	eda8510f4c3bcc6fa46866e6a0f7b112	Diners Club / Carte Blanche	34.090456736347079	-117.274626732269667
16952	2020-03-24 09:28:39	2020-03-24	Webster Purdy V	webster.purdy.v@woohoo.com	Los Angeles	California	4247704426403812	e6c3bcf88222fb5adafed8c94e73cec7	American Express	34.104879620983823	-118.390625350036842
16953	2020-03-24 09:36:57	2020-03-24	Anjanette Lindgren DVM	anjanette.lindgren.dvm@geemail.com	Visalia	California	3453425945204258	c3cf7cd770005c811a67bfe75ec7b85d	Diners Club / Carte Blanche	36.3880688825111847	-119.373862908606981
16954	2020-03-24 09:39:58	2020-03-24	Zadie Harber	zadie.harber@warmmail.com	Houston	Texas	52036313984401070	bba256baf6c50da835d3c02bec58dec5	JCB 16 digit	29.719490900596977	-95.4538181020893148
16955	2020-03-24 09:49:39	2020-03-24	Kenyon Hirthe	kenyon.hirthe@geemail.com	Berkeley	California	4085258757344	2fed582aa068141775e7a06f75cbc919	American Express	37.8721616109333397	-122.254542917503443
16956	2020-03-24 10:01:37	2020-03-24	Mr. Hiram Cassin V	mr.hiram.cassin.v@geemail.com	Los Angeles	California	52860210985382815	7dd22537c76c8775cdfd5531979dd16f	Mastercard	34.0568150956049536	-118.32950361091568
16957	2020-03-24 10:01:46	2020-03-24	Audrina Huel	audrina.huel@geemail.com	San Francisco	California	180004248995349082	93ff2a8b748e7e0c8c5f811bde024b52	Voyager	37.790360106361689	-122.45129148248941
16958	2020-03-24 10:02:02	2020-03-24	Aidyn Mayert	aidyn.mayert@geemail.com	Denver	Colorado	210089755657541317	d78b554f5806045fc88e7307ac859d2d	JCB 16 digit	39.8243518835917101	-104.852370852955062
16959	2020-03-24 10:09:23	2020-03-24	Ms. Elvera Rodriguez DVM	ms.elvera.rodriguez.dvm@geemail.com	San Francisco	California	3158794546780672228	2db164754349486d4c98b46dd9bb0970	JCB 16 digit	37.7306594956668064	-122.41770244286127
16960	2020-03-24 10:21:00	2020-03-24	Frederica Kuphal	frederica.kuphal@geemail.com	Memphis	Tennessee	3096522618701663732	265cb08533987c2ba6edc7e2ef5cf30a	Voyager	35.1499483872737741	-89.8850203364878979
16961	2020-03-24 10:36:53	2020-03-24	Juliana Jerde DVM	juliana.jerde.dvm@geemail.com	Grand Prairie	Texas	4305257181233	8973516ca82dc5b010d33d1b0856a0b7	VISA 13 digit	32.6612189468979821	-97.0122574550438657
16962	2020-03-24 10:42:12	2020-03-24	Ms. Cathleen O'Conner DDS	ms.cathleen.o'conner.dds@warmmail.com	Killeen	Texas	4897074703785411	c2a5bcba4c53cdc0b5822797c685916d	VISA 16 digit	30.9879279712446021	-97.7199109927453122
16963	2020-03-24 10:48:46	2020-03-24	Porter Boehm-Harber	porter.boehm.harber@warmmail.com	Laredo	Texas	869965703182757162	cb248b4205b00ac8fde45ad4eae7cfa4	Voyager	27.5402460362944765	-99.5385560015223945
16964	2020-03-24 11:02:34	2020-03-24	Henriette Quitzon	henriette.quitzon@warmmail.com	San Francisco	California	3528258770975588515	972acf622a1e93bef26034e2530c4e23	Voyager	37.7708083342253929	-122.404125359609552
16965	2020-03-24 11:05:37	2020-03-24	Ancel Ritchie	ancel.ritchie@geemail.com	Greensboro	North Carolina	4795148521245411	61cab1267ebadc61960f342da694a043	JCB 15 digit	36.1679564252145624	-79.8366710370387835
16966	2020-03-24 11:23:57	2020-03-24	Washington Langosh	washington.langosh@geemail.com	Los Angeles	California	869928670915571952	24161b2daf6a1d2f2bfc3edbf8f914de	Discover	34.0940694455388922	-118.488113308324657
16967	2020-03-24 11:26:16	2020-03-24	Ocie Hessel	ocie.hessel@woohoo.com	San Francisco	California	3112171842635373226	c85f28cecb06e6cf3a4ca3e454460cb3	VISA 16 digit	37.7592759727390543	-122.454582299113341
16968	2020-03-24 11:50:21	2020-03-24	Jeffie Haag	jeffie.haag@geemail.com	Virginia Beach	Virginia	4975152104303276	0fd5af22b5ba04c5bd88c6517b669bbe	Voyager	36.7221552457846698	-75.9809354734744886
16969	2020-03-24 11:52:19	2020-03-24	Thekla Runolfsson DVM	thekla.runolfsson.dvm@geemail.com	San Francisco	California	3158787074895937708	ffc395c8ce4fa9b0538bbbda864cdc39	JCB 15 digit	37.7653258169086712	-122.385520437925337
16970	2020-03-24 12:00:25	2020-03-24	Miss Lexi Bogan DVM	miss.lexi.bogan.dvm@woohoo.com	New York	New York	180016200941295188	7dfff93818bd86398a5ea0e858d04cbb	Mastercard	40.7298983926642677	-73.9792570187140228
16971	2020-03-24 12:17:15	2020-03-24	Desean Witting Jr.	desean.witting.jr.@woohoo.com	Shreveport	Louisiana	869937351185005406	8ed3b08968080855803a346041ce0063	Mastercard	32.3842733415547812	-93.7059518021743685
16972	2020-03-24 12:27:06	2020-03-24	Mrs. Jocelynn Monahan PhD	mrs.jocelynn.monahan.phd@geemail.com	San Francisco	California	55462235863126580	f64cf623b233dbd48d4f70ba59598928	American Express	37.7478366890865118	-122.491534226495702
16973	2020-03-24 12:34:20	2020-03-24	Ellyn Leffler DVM	ellyn.leffler.dvm@woohoo.com	Tallahassee	Florida	6011772647028232001	8c0880c78b4a23b89cbc41ad4b4e9a5c	VISA 16 digit	30.3649004577215784	-84.1829876066200455
16974	2020-03-24 12:52:16	2020-03-24	Gene Huels	gene.huels@geemail.com	Dallas	Texas	4031172216652990	04986ae3983b22a683b79686d3ddc949	JCB 16 digit	32.8209056109461983	-96.7292772964537022
16975	2020-03-24 13:10:45	2020-03-24	Kennedi Schumm	kennedi.schumm@geemail.com	Denver	Colorado	4252434299793170	d62e140611c04b3c53e65b1f3861d9cc	American Express	39.842573449486494	-104.978852049472181
16976	2020-03-24 13:23:41	2020-03-24	Dr. Judah Osinski Sr.	dr.judah.osinski.sr.@geemail.com	Detroit	Michigan	3006495927714390	6d8209a628a4d36a8e50d889e8129b6a	VISA 16 digit	42.476284398736432	-83.0083787584796511
16977	2020-03-24 13:31:35	2020-03-24	Julius VonRueden-Cronin	julius.vonrueden.cronin@woohoo.com	Garden Grove	California	4937278955276	9e714f87256e5a66b42a5985821ec2cf	Discover	33.7669782706826922	-117.919534283366048
16978	2020-03-24 13:34:54	2020-03-24	Milan Schultz	milan.schultz@warmmail.com	Shreveport	Louisiana	4451204959766	765bc24e74e9e32664e125f4045ec82b	Discover	32.4506902300991129	-93.7316217253196982
16979	2020-03-24 13:47:47	2020-03-24	Miss Catalina Lindgren DDS	miss.catalina.lindgren.dds@warmmail.com	San Francisco	California	180083058634633596	1c21c89d75f14ec1d62c494fb4108d7b	VISA 16 digit	37.7878970472149831	-122.44143281529098
16980	2020-03-24 13:56:48	2020-03-24	Contina Osinski	contina.osinski@geemail.com	Austin	Texas	210040446417983324	d07b88e7f8b6517b33c6ed4b99edfefc	Mastercard	30.2803646654017271	-97.753457202320547
16981	2020-03-24 14:00:14	2020-03-24	Ramsey Stracke	ramsey.stracke@geemail.com	San Francisco	California	869924498148646597	6192cd5297dc3c9316abbf0b6f7d0b12	JCB 16 digit	37.7773968726459444	-122.411880273992523
16982	2020-03-24 14:18:39	2020-03-24	Venessa Adams PhD	venessa.adams.phd@geemail.com	Santa Ana	California	3528566739486947988	9d00150638cc2465f962ce5709c2fd9a	Diners Club / Carte Blanche	33.7919403443217305	-117.822356987783678
16983	2020-03-24 14:32:13	2020-03-24	Lindsey Thiel	lindsey.thiel@geemail.com	Long Beach	California	210065229394797085	f146869e2a3889d3d17ab037d6d2b9e1	VISA 13 digit	33.8108957954037876	-118.172805569942298
16984	2020-03-24 14:40:55	2020-03-24	Verla Littel PhD	verla.littel.phd@geemail.com	Oakland	California	4072309767051376	66e9336563c2a37cbd0bdd888761a9a4	Maestro	37.7962863221360621	-122.265656501376213
16985	2020-03-24 14:45:59	2020-03-24	Daryn Hermiston	daryn.hermiston@woohoo.com	San Francisco	California	3528135059557834466	2319af97e6a72b2cdd4f1b9cbe3522c7	Mastercard	37.7600462864869186	-122.435328374284978
16986	2020-03-24 14:59:29	2020-03-24	Selina Schinner-Hintz	selina.schinner.hintz@woohoo.com	Chicago	Illinois	869929733813169144	150446b3cf65dd3f3dfddc9017f66b1e	Diners Club / Carte Blanche	41.8126742013566215	-87.7051744326978877
16987	2020-03-24 15:23:12	2020-03-24	Meadow Williamson	meadow.williamson@geemail.com	Los Angeles	California	4750094850246567	0b9916d7db8d16ebf38377289384c6bd	American Express	34.0155518879979795	-118.484200238249443
16988	2020-03-24 15:29:16	2020-03-24	Rod McGlynn-Rice	rod.mcglynn.rice@geemail.com	San Jose	California	3039773467715945	792cb02281251183fc497881bf1975c4	Voyager	37.3147433220230056	-121.750911653669178
16989	2020-03-24 16:05:36	2020-03-24	Stevie Leffler DVM	stevie.leffler.dvm@woohoo.com	Detroit	Michigan	3488676531916502	cf9759cecad42f5bdbce07f757699154	VISA 16 digit	42.4084220449365716	-83.0428033406034132
16990	2020-03-24 16:05:59	2020-03-24	Mr. Hasan Sporer III	mr.hasan.sporer.iii@woohoo.com	Austin	Texas	869947253846739746	86186a0f95290ab47e9066c8da4b71a9	Discover	30.358618477698041	-97.8426949124556131
16991	2020-03-24 16:14:54	2020-03-24	Seth Dickens-Murray	seth.dickens.murray@woohoo.com	New York	New York	4499647421044690	5de9bf20fc65d1a9f3a17d46a64de432	Discover	40.6322803778331689	-74.0118899575330289
16992	2020-03-24 16:18:19	2020-03-24	Alyce Hilll	alyce.hilll@woohoo.com	Santa Rosa	California	3096244410830400062	022d2c11e9728c5e54181810ef53c9a3	Voyager	38.525666309998563	-122.713328475855675
16993	2020-03-24 16:24:43	2020-03-24	Jeanne Schumm	jeanne.schumm@geemail.com	San Jose	California	3480233422235044	a0298f1918005cd8d039b608064648fa	VISA 13 digit	37.3583104831453454	-121.737457815393427
16994	2020-03-24 16:28:23	2020-03-24	Mr. Harl Hills Jr.	mr.harl.hills.jr.@geemail.com	Fort Collins	Colorado	53913445390207457	8af8e91547ea9a5c6ba10b78c77bfb78	JCB 16 digit	40.5626724109210102	-105.122099973024064
16995	2020-03-24 16:32:51	2020-03-24	Concetta Reynolds MD	concetta.reynolds.md@geemail.com	New York	New York	3746766231717127	d52631aefc59117ab157320afe217f45	Maestro	40.6381419418137497	-73.9281349848851477
16996	2020-03-24 16:34:53	2020-03-24	Laddie Mante	laddie.mante@geemail.com	San Francisco	California	210044973796355150	bd6d4d5959b8dbaef4104357f32de7d2	Voyager	37.7565151670845935	-122.440517262971795
16997	2020-03-24 16:40:15	2020-03-24	Williams Kassulke	williams.kassulke@geemail.com	Waco	Texas	3058984581120257	7e01f8b20d680f6d86f79e47be7b3458	Maestro	31.5756104018747799	-97.2378876243848396
16998	2020-03-24 16:48:09	2020-03-24	Caddie Hegmann-Reilly	caddie.hegmann.reilly@warmmail.com	Hartford	Connecticut	3096665460793067044	23eda203e44206c2335f6e54be2f8b76	VISA 16 digit	41.8120934134364148	-72.5889366810567651
16999	2020-03-24 16:50:21	2020-03-24	Dr. Stella Bechtelar PhD	dr.stella.bechtelar.phd@warmmail.com	San Francisco	California	3489394332541359	69bc197c1d066abb2e86a869698bca3e	VISA 16 digit	37.7549709709477952	-122.442539522585491
17000	2020-03-24 16:54:46	2020-03-24	Huy Yundt	huy.yundt@woohoo.com	Plano	Texas	502041422159636	cbca476256ecf4629170772763301a16	Diners Club / Carte Blanche	32.96273354651332	-96.6634573516618474
17001	2020-03-24 17:00:31	2020-03-24	Jetta Moore-Wuckert	jetta.moore.wuckert@warmmail.com	San Antonio	Texas	3088096558687840134	491455faadfe334008dc48c1462a0ab4	VISA 16 digit	29.4555488620024164	-98.5354413909207949
17002	2020-03-24 17:26:59	2020-03-24	Roswell Ullrich-Wunsch	roswell.ullrich.wunsch@geemail.com	San Francisco	California	6011020997179529204	efc43604a9d8cbcf94cf369cab8e92ea	VISA 16 digit	37.7799485766200647	-122.443310827476822
17003	2020-03-24 17:32:45	2020-03-24	Vida Jenkins PhD	vida.jenkins.phd@warmmail.com	Newark	New Jersey	561296738112174	dccb0a57bf80e225bb0fa25d5f79d06e	VISA 16 digit	40.6543277272868906	-74.1809572198636857
17004	2020-03-24 17:45:30	2020-03-24	Shirleyann Kuhlman	shirleyann.kuhlman@geemail.com	Toledo	Ohio	639081088304811	7900622872e54d8bc9cf79973f003319	VISA 16 digit	41.6558483167257165	-83.5477391913864835
17005	2020-03-24 17:59:42	2020-03-24	Sammie Shields	sammie.shields@geemail.com	Rockford	Illinois	53828342434040933	2111f5843a2e10b5afa22668889f8622	Mastercard	42.2012886172637351	-89.102893388532479
17006	2020-03-24 18:06:11	2020-03-24	Mr. Vashon Beer	mr.vashon.beer@geemail.com	Boston	Massachusetts	3713365588018079	1e15c9ffb0708b2c7d3b585669c0dad5	Discover	42.3484725631009766	-70.9459005624007517
17007	2020-03-24 18:23:04	2020-03-24	Ms. Nylah Haley DDS	ms.nylah.haley.dds@geemail.com	New York	New York	4630182961379	23c4abf45ec4dca7ab25e4e1f19d0821	JCB 16 digit	40.5969587057586736	-73.9798752882413595
17008	2020-03-24 18:47:27	2020-03-24	Mr. Khari Ankunding	mr.khari.ankunding@warmmail.com	Houston	Texas	3015779179207687	c75468c42dfa472318ec56ab2a9b6d2d	Discover	29.8120509945865706	-95.4337358003497087
17009	2020-03-24 18:56:38	2020-03-24	Kegan Parisian	kegan.parisian@woohoo.com	New York	New York	6011741040971569512	d9a293c5df8fea698da0cad1bdb31a20	Maestro	40.661382315842431	-73.9069706237770561
17010	2020-03-24 19:06:19	2020-03-24	Dr. Orrie McGlynn	dr.orrie.mcglynn@geemail.com	Oakland	California	52055955564621133	4a8d1c80689f292b7b31fec6feab0f26	VISA 13 digit	37.8113406285592646	-122.268112534589505
17011	2020-03-24 19:13:01	2020-03-24	Candyce Willms	candyce.willms@warmmail.com	Atlanta	Georgia	180049043243505099	8961b5b63da3e314a9171bcf6d230c7a	VISA 16 digit	33.7187508252259391	-84.3319010014690491
17012	2020-03-24 20:17:41	2020-03-24	Elfie Gutmann	elfie.gutmann@geemail.com	Washington	District of Columbia	4902630086665	115198c5af55730389d501b03556e924	VISA 16 digit	38.9044481631632877	-77.1158636405810682
17013	2020-03-24 20:20:46	2020-03-24	Vernell Mertz	vernell.mertz@geemail.com	Chicago	Illinois	869988377150602503	8db5a40c52712e383466cc40857a817d	Voyager	41.7996600983966147	-87.7644605316251472
17014	2020-03-24 20:38:09	2020-03-24	Baxter Streich	baxter.streich@geemail.com	Rancho Cucamonga	California	3337260367546014281	84d7529d06d6d2082a8b80b3abbefbc2	JCB 16 digit	34.1074856724116984	-117.613216798660162
17015	2020-03-24 20:42:54	2020-03-24	Rinda Cremin-Volkman	rinda.cremin.volkman@geemail.com	San Francisco	California	502024962974721	efb3667ea15414e369f68fead88c7c82	JCB 16 digit	37.7783129735887826	-122.441427385571544
17016	2020-03-24 20:45:06	2020-03-24	Martine Dickinson	martine.dickinson@woohoo.com	Las Vegas	Nevada	3051074625861525	ad23193495f8460c9fa8856cff815277	JCB 16 digit	36.2200898814581294	-115.319326175304496
17017	2020-03-24 20:45:13	2020-03-24	Mr. Abelardo Lakin	mr.abelardo.lakin@warmmail.com	Buffalo	New York	4418298247283	df74e43d6d5e01c9bab2c97c0280420f	American Express	42.8790294091403439	-78.9454271028216965
17018	2020-03-24 21:08:03	2020-03-24	Mrs. Kassie McCullough MD	mrs.kassie.mccullough.md@woohoo.com	Atlanta	Georgia	502035411517275	be1f2f1e680157e037e0d0ec915a9b46	Discover	33.7888445096831802	-84.344618535698217
17019	2020-03-24 21:32:01	2020-03-24	Miss Luverne Shanahan	miss.luverne.shanahan@geemail.com	New York	New York	54344363933370030	11255a962a50821caf41ca33d4e6f076	Diners Club / Carte Blanche	40.7086925137545919	-73.9763002746634157
17020	2020-03-24 21:42:25	2020-03-24	Miss Kylah Luettgen DVM	miss.kylah.luettgen.dvm@geemail.com	Honolulu	Hawaii	4371657775146200	4de76f6d27bdc43f4b4a96f911d884c3	Mastercard	21.2840785817459235	-157.844131831985351
17021	2020-03-24 22:08:28	2020-03-24	Odalys Bogisich	odalys.bogisich@geemail.com	Los Angeles	California	4999264773157701	1900711fc367bf303f4e1b2fa9f63066	Maestro	34.0710462391242359	-118.428824151260031
17022	2020-03-24 22:08:56	2020-03-24	Dr. Uriah Zboncak	dr.uriah.zboncak@warmmail.com	Atlanta	Georgia	180011211360847784	79f79031aebde47c974961fad5185569	American Express	33.7806963821683084	-84.3666231111668168
17023	2020-03-24 22:14:33	2020-03-24	Silvio Bauch	silvio.bauch@geemail.com	Green Bay	Wisconsin	4948752666009932	9c95469be0704edf639201af3afbfd31	VISA 13 digit	44.5841640324395101	-87.9281733564388048
17024	2020-03-24 22:15:31	2020-03-24	Ica Torphy	ica.torphy@geemail.com	Naperville	Illinois	3011008808084992	3ec44a92741663ff7490b0b23828b4e5	JCB 16 digit	41.6776686133731147	-88.2066356244851022
17025	2020-03-24 22:17:30	2020-03-24	Rico Howell	rico.howell@geemail.com	San Antonio	Texas	4194144361524541	904a5e7fa947cfdfd32c302e0c2f46b3	VISA 16 digit	29.4323449813365947	-98.6194889760412252
17026	2020-03-24 22:30:47	2020-03-24	Kaylie Pfeffer	kaylie.pfeffer@geemail.com	San Bernardino	California	54254154855443758	ac7a65446656f740bdbdb63372dabe16	JCB 16 digit	34.1546265704356102	-117.218965749513728
17027	2020-03-24 22:31:16	2020-03-24	Jarod Hermann	jarod.hermann@warmmail.com	New York	New York	6011689584141248766	8f355a80ef20e5ebd0fa3389dd9d4610	Voyager	40.7028558814655952	-73.9819311390526622
17028	2020-03-24 22:47:58	2020-03-24	Elle Wilderman	elle.wilderman@geemail.com	Oceanside	California	561255408065526	be9712153500323429538c9054a67743	VISA 13 digit	33.1278810956869236	-117.28411510648094
17029	2020-03-24 22:49:36	2020-03-24	Denver Schimmel	denver.schimmel@geemail.com	Newark	New Jersey	4028978755537	82963afa3430666c92cfcebd3d22b850	JCB 15 digit	40.7708276803519638	-74.1778891091443597
17030	2020-03-24 22:59:27	2020-03-24	Cierra Kovacek	cierra.kovacek@geemail.com	Detroit	Michigan	3019781146450362	784738c2a9f0593d4cdc2a0a95a6f278	Maestro	42.361928436338907	-83.0432989557392887
17031	2020-03-24 23:16:47	2020-03-24	Cathy Ritchie	cathy.ritchie@geemail.com	Laredo	Texas	210065577633616817	0ec4f07d85967d7e7824ec3a34d122f5	VISA 16 digit	27.5633478280805058	-99.4066004432279584
17032	2020-03-24 23:30:13	2020-03-24	Adalberto Nolan	adalberto.nolan@geemail.com	Aurora	Illinois	3036162174752644	875a155c11530ed1cc78b90c52532b3f	VISA 16 digit	41.6692699663564596	-88.3162498919222401
17033	2020-03-24 23:36:05	2020-03-24	Dr. Idell Schowalter	dr.idell.schowalter@geemail.com	Laredo	Texas	52770518251021191	81c3f64aa4cc207eb283c6d9953d2501	Mastercard	27.5302460797779283	-99.453164123977345
17034	2020-03-24 23:56:56	2020-03-24	Antonio Bashirian	antonio.bashirian@warmmail.com	Charlotte	North Carolina	180096556664591639	461c13286b8ad78a41021e513c869e8b	VISA 16 digit	35.2717164858963343	-80.9049752197638128
17035	2020-03-25 00:03:21	2020-03-25	Adrian Altenwerth	adrian.altenwerth@geemail.com	San Francisco	California	4565141401333	b720592fa5d6b97a7a1a27dbbf32c737	JCB 15 digit	37.7592080332549003	-122.437726889006029
17036	2020-03-25 00:06:50	2020-03-25	Tennille Aufderhar	tennille.aufderhar@geemail.com	Berkeley	California	3030478484441355	060afb2acd9f23d3257ef0638ff19b76	Maestro	37.8254505196418691	-122.275599651599308
17037	2020-03-25 00:50:47	2020-03-25	Mr. Belton Reilly	mr.belton.reilly@geemail.com	San Francisco	California	3406905056647427	a5d61fc1ddd65a71da7cc55ed4497f8a	Diners Club / Carte Blanche	37.7399131972650466	-122.414831717401114
17038	2020-03-25 00:56:27	2020-03-25	Terry O'Reilly	terry.o'reilly@geemail.com	Aurora	Colorado	676245535352558	3f92ab40b448794998fd5582245352bc	JCB 15 digit	39.7266092667933606	-104.640335966751721
17039	2020-03-25 00:59:01	2020-03-25	Ms. Violet Jenkins	ms.violet.jenkins@geemail.com	Pasadena	Texas	6011628756442113477	a167ab38d8d4b3885c2cd6438f6f25d6	VISA 16 digit	29.6665745472408844	-95.1566018822085056
17040	2020-03-25 01:15:37	2020-03-25	Ms. Sheila Bogisich	ms.sheila.bogisich@geemail.com	Elizabeth	New Jersey	3749582627119472	1bec0d94a506c04eb825f1666198031d	JCB 16 digit	40.7347919523377016	-74.2592647977117508
17041	2020-03-25 01:22:34	2020-03-25	Taft Pfannerstill	taft.pfannerstill@warmmail.com	San Francisco	California	3337279088309829280	0aa9f9e8972b01ddfcaa5ef59580a3f4	Mastercard	37.7624624207278927	-122.418259651222755
17042	2020-03-25 01:36:47	2020-03-25	Lindsay Muller	lindsay.muller@woohoo.com	San Diego	California	4008972357477472	c0149e2618cb9af83f9de4703f361cde	JCB 16 digit	32.8283591937340802	-117.222103269062941
17043	2020-03-25 01:37:27	2020-03-25	Euphemia Erdman	euphemia.erdman@geemail.com	Springfield	Missouri	4961588547972662	aaf98936393b02f21dd59e6f4763acab	JCB 15 digit	37.2657196360833964	-93.2118537807662051
17044	2020-03-25 01:47:06	2020-03-25	Tonya Morar	tonya.morar@warmmail.com	Baton Rouge	Louisiana	4840383294745454	5ca8e1bdfefc1e1e38d7bcc75fd4b70b	Mastercard	30.3594250275500102	-91.093372392944616
17045	2020-03-25 01:51:41	2020-03-25	Queenie Grant PhD	queenie.grant.phd@geemail.com	Overland Park	Kansas	6011000784269322912	bf0859ea96bd8e19de0ea55b6a9c95bd	JCB 16 digit	38.9066272131036968	-94.6394495973404588
17046	2020-03-25 01:51:45	2020-03-25	Lonnie Reinger	lonnie.reinger@geemail.com	San Francisco	California	4954443866847377	84b55499c65aecc34625fd4c0cc087be	Voyager	37.7950997461311218	-122.463051534406432
17047	2020-03-25 02:42:26	2020-03-25	Hermann Ruecker Jr.	hermann.ruecker.jr.@geemail.com	Peoria	Arizona	3015645397729267	433b85996d71e0f2a94408d8d75de7f3	JCB 16 digit	33.7883315538324425	-112.242252038318668
17048	2020-03-25 02:50:21	2020-03-25	Nelly McGlynn-Brown	nelly.mcglynn.brown@geemail.com	Elizabeth	New Jersey	51728108073297436	bae664af3652170be5123e4d28040059	VISA 13 digit	40.6968091640282452	-74.2611337051670972
17049	2020-03-25 02:57:59	2020-03-25	Robyn Beahan	robyn.beahan@geemail.com	Fort Worth	Texas	4592532508104	bce850c03bfcc09cac2223e927462f10	American Express	32.8762389256674794	-97.3186224587082904
17050	2020-03-25 03:09:22	2020-03-25	Trent Considine	trent.considine@geemail.com	San Francisco	California	676243209035195	752028bb39127682f81ede1c9cf80583	JCB 16 digit	37.755533483431698	-122.418031963443326
17051	2020-03-25 03:23:10	2020-03-25	Demetra Bernier	demetra.bernier@geemail.com	Baltimore	Maryland	3096890135056768929	a5f3b974f8f7acaa90b18d5be2c2b469	JCB 16 digit	39.3815344293601797	-76.5902295519616416
17052	2020-03-25 03:31:07	2020-03-25	Steven Kovacek DVM	steven.kovacek.dvm@geemail.com	Dayton	Ohio	210054094238816928	40bc325e1d8c4608a13736ae189d7bac	JCB 15 digit	39.7440168421972544	-84.1575610070679403
17053	2020-03-25 03:34:26	2020-03-25	Garett Schmidt	garett.schmidt@warmmail.com	League City	Texas	6011031053612614901	23d5e97be7c1c16b716e8a90a8ac592b	Discover	29.4589149551860991	-95.0691814270786892
17054	2020-03-25 03:34:28	2020-03-25	Yancy Legros II	yancy.legros.ii@geemail.com	Hartford	Connecticut	3096466614670995856	a1f8cf7adda247bd21a637f3319fea89	VISA 16 digit	41.7824489679668147	-72.7425679426066552
17055	2020-03-25 03:35:28	2020-03-25	Miss Karlene White	miss.karlene.white@geemail.com	Philadelphia	Pennsylvania	51128721243641337	e92bdbf69b53c3367248a60c50330e70	JCB 16 digit	40.0128714635461549	-75.0685045619860318
17056	2020-03-25 03:40:35	2020-03-25	Gerry Wolff	gerry.wolff@woohoo.com	San Francisco	California	869980736856971421	f3e924123fe6bfbddcb1b26596b830c0	Discover	37.786077223221163	-122.422128187572241
17057	2020-03-25 03:55:26	2020-03-25	Jana Weissnat DDS	jana.weissnat.dds@geemail.com	San Francisco	California	589379161392463	89425140fe55a717d9fd223ca2971db5	Mastercard	37.8012451696144822	-122.417196343104919
17058	2020-03-25 04:02:08	2020-03-25	Franklyn Daniel	franklyn.daniel@geemail.com	Portland	Oregon	3337372836280080000	46f6171f6a31a72f850de002ff6a0f62	Voyager	45.5770559712667023	-122.682009554142141
17059	2020-03-25 04:56:52	2020-03-25	Doris Jenkins	doris.jenkins@geemail.com	Jacksonville	Florida	4081987240531756	cad4e6ee0244777d9e6b3f2cba712ac8	VISA 16 digit	30.3090027150284484	-81.6821406150314999
17060	2020-03-25 04:58:42	2020-03-25	Dr. Evans Mitchell	dr.evans.mitchell@woohoo.com	Oakland	California	52503212278028363	983bd0171f1f191604bef15287093a54	JCB 16 digit	37.8007197406905249	-122.280615906591237
17061	2020-03-25 05:05:22	2020-03-25	Brice Veum I	brice.veum.i@woohoo.com	San Francisco	California	3433682211393943	91172e1ec6102a0fd9b8cbaf256e56ad	American Express	37.8030681292085262	-122.456019359211794
17062	2020-03-25 05:05:42	2020-03-25	Miss Eunice Doyle	miss.eunice.doyle@geemail.com	San Francisco	California	3112331321935549865	dd6237d5fb5ac28ac6df360222f42680	JCB 15 digit	37.7670861287151354	-122.438691961014683
17063	2020-03-25 05:07:59	2020-03-25	Dr. Kerwin Kshlerin	dr.kerwin.kshlerin@geemail.com	San Francisco	California	4518055351551899	35fedb345b3220f22beb80e96bb20398	Mastercard	37.782342342001364	-122.412233547185224
17064	2020-03-25 06:02:09	2020-03-25	Noemi Barton MD	noemi.barton.md@geemail.com	Fresno	California	6011253719465122363	8ab6cdb53545ca18d36b47725a2a1fc7	Diners Club / Carte Blanche	36.8692519212480647	-119.814773976860195
17065	2020-03-25 06:10:21	2020-03-25	Ferdinand Auer	ferdinand.auer@geemail.com	Charleston	South Carolina	3425105942339720	58915d59318f1e02d219eb81163654d5	VISA 13 digit	32.7900232204698057	-79.9735577827002828
17066	2020-03-25 06:21:52	2020-03-25	Mrs. Fannie Emard	mrs.fannie.emard@warmmail.com	Miami	Florida	6011144275996107152	e0f3764c226e6c6e47461950d3445746	VISA 16 digit	25.8618456350777315	-80.1877721429210197
17067	2020-03-25 06:22:50	2020-03-25	Allen Hand	allen.hand@geemail.com	Orange	California	869933988031553792	dba0f2a6b7b2987c9a646f4459f3a72d	VISA 16 digit	33.7316875252295247	-117.824682842112338
17068	2020-03-25 06:29:25	2020-03-25	Amil Batz	amil.batz@warmmail.com	Lewisville	Texas	3528586251432697507	99f0e15fa449df9569aa0252339f80fa	Diners Club / Carte Blanche	32.9835772396050402	-96.9784381701640825
17069	2020-03-25 06:30:02	2020-03-25	Jasper Botsford	jasper.botsford@geemail.com	Columbus	Ohio	6011151522682246640	05bce644851ea3559cb2dd570afd5614	JCB 15 digit	40.0059853855565208	-82.912850440642984
17070	2020-03-25 06:30:59	2020-03-25	Clayton Turner	clayton.turner@warmmail.com	Louisville	Kentucky	3112470328186012544	49f218e473efb725349aa25d2f325d13	Maestro	38.1420729945782568	-85.6835815597862052
17071	2020-03-25 06:38:09	2020-03-25	Cali Wiza	cali.wiza@geemail.com	Macon	Georgia	3472744666375940	f218318d6ba2e5f18a52158204a6fa80	Diners Club / Carte Blanche	32.8772802536852637	-83.6023126146949807
17072	2020-03-25 06:58:05	2020-03-25	Shelvia Blick	shelvia.blick@geemail.com	Aurora	Colorado	3112170220808120073	7d9c401c4d24a6d08845e31db71fe259	Diners Club / Carte Blanche	39.7288470476046243	-104.73521620455459
17073	2020-03-25 07:32:53	2020-03-25	Dario Feest	dario.feest@geemail.com	Indianapolis	Indiana	869927337785154373	4c3a6a766e91c11acbeee224fc6bf10d	Mastercard	39.8123203919276563	-86.2446706210929932
17074	2020-03-25 07:43:26	2020-03-25	Jamison Murazik-Ruecker	jamison.murazik.ruecker@geemail.com	Oakland	California	639012959718110	aa43ffcc94be07995bdb999dbc159df6	JCB 15 digit	37.7633799799926422	-122.244287095178962
17075	2020-03-25 07:50:12	2020-03-25	Andre Bashirian	andre.bashirian@warmmail.com	Denver	Colorado	4349781588370978	9fc88c4b1b37dfd9642ed71c8bf378ac	VISA 13 digit	39.7994605988316223	-104.951659068769217
17076	2020-03-25 08:00:48	2020-03-25	Drake Bruen Sr.	drake.bruen.sr.@geemail.com	League City	Texas	4039717782139459	90c6ebaed6a7a4c4c76e64f7b66c5553	VISA 13 digit	29.4689973737973752	-95.1121399627517832
17077	2020-03-25 08:06:15	2020-03-25	Janice Rohan-Parisian	janice.rohan.parisian@woohoo.com	Waco	Texas	4013513078678	f37b3ccc404a7bd6ee1751a457774cce	Maestro	31.6197265813801422	-97.2852827155161748
17078	2020-03-25 08:21:55	2020-03-25	Jermain Turcotte	jermain.turcotte@geemail.com	Lubbock	Texas	3096928859172062836	11f131f500b5b9803fc57fef1380b8bb	JCB 15 digit	33.5767554471775895	-101.825656472976135
17079	2020-03-25 08:32:48	2020-03-25	Milton Schamberger	milton.schamberger@geemail.com	Berkeley	California	3477713852687520	f0a4be624c60b79a3b33af209535160a	VISA 13 digit	37.8638667860202034	-122.281779519466099
17080	2020-03-25 09:15:35	2020-03-25	Grafton Auer	grafton.auer@geemail.com	San Francisco	California	4286781313545097	27f23baa36f0c0a8cdfaebd29cf87e15	JCB 15 digit	37.7419230160300785	-122.415428585807391
17081	2020-03-25 09:53:11	2020-03-25	Adan Jaskolski Sr.	adan.jaskolski.sr.@geemail.com	Atlanta	Georgia	3044524834724614	669b9b19bef1acaf2f35ee68c9acb166	Maestro	33.7225419354900708	-84.4320530957121491
17082	2020-03-25 10:49:52	2020-03-25	Dr. Khiry Howe II	dr.khiry.howe.ii@woohoo.com	Temecula	California	869912874931162782	bb2fa08f689e9d0f9694bd07236d8797	JCB 16 digit	33.5624765477277336	-117.190284962645535
17083	2020-03-25 11:00:29	2020-03-25	Ms. Marnie McCullough MD	ms.marnie.mccullough.md@geemail.com	San Francisco	California	3730052696308779	27891f2935493155497522a7b8d07bdf	JCB 16 digit	37.7649825378653006	-122.433169957794235
17084	2020-03-25 11:02:29	2020-03-25	Ms. Almeda Okuneva DVM	ms.almeda.okuneva.dvm@woohoo.com	Tulsa	Oklahoma	3030821399786143	7919d499707ab3855f32cb130351a813	Discover	36.1595386759746802	-95.8610372058071221
17085	2020-03-25 11:08:00	2020-03-25	Miss Mckenzie Fadel PhD	miss.mckenzie.fadel.phd@warmmail.com	Frisco	Texas	3528867987500719976	07a2a2e5d1e4a4e63dcab1d00decc95d	VISA 16 digit	33.2117447497785108	-96.7713140951212409
17086	2020-03-25 11:25:03	2020-03-25	Talan Gibson	talan.gibson@geemail.com	Tampa	Florida	3337311614680494152	eea06d0c90fdbea984e2d511428a0477	Voyager	27.9103144701685757	-82.4826230268206331
17087	2020-03-25 11:28:04	2020-03-25	Mrs. Madlyn Russel	mrs.madlyn.russel@geemail.com	Cambridge	Massachusetts	4212406549858	119f59debe0915d2ffbd67293f3f99f9	Diners Club / Carte Blanche	42.3484770585074983	-71.1680420029059064
17088	2020-03-25 11:37:24	2020-03-25	Alois Bartell	alois.bartell@geemail.com	Lubbock	Texas	6011102247504650916	86220ea5da168a94384caecd76c30512	VISA 13 digit	33.6029570254538257	-101.837351662144812
17089	2020-03-25 11:42:56	2020-03-25	Chase Brown	chase.brown@geemail.com	San Francisco	California	3028008692466357	46481decf3eaf952585f00a4faba52f7	Voyager	37.7430817766669477	-122.430149235759671
17090	2020-03-25 12:19:10	2020-03-25	Dr. Axel Nitzsche PhD	dr.axel.nitzsche.phd@geemail.com	Columbus	Ohio	3112780310858787780	7a188dc5ff645cd3242c693d6c9e8277	VISA 13 digit	39.8934740553654734	-83.0461035044632894
17091	2020-03-25 12:30:04	2020-03-25	Chrissie Carter	chrissie.carter@geemail.com	Lubbock	Texas	676349085998331	bba49213af3dc3d8a2a50fbde3bc9167	VISA 16 digit	33.5743967718951453	-101.985151718548323
17092	2020-03-25 13:28:51	2020-03-25	Prentice Rutherford	prentice.rutherford@geemail.com	Los Angeles	California	3735952725325626	557a30d2a4877d1ccee9870b89fabe8b	American Express	34.1158058678131511	-118.343125047627083
17093	2020-03-25 13:32:16	2020-03-25	Cristina Dooley-Bashirian	cristina.dooley.bashirian@geemail.com	Buffalo	New York	3112093477531146106	27e65a957786ad77a3f751a529387417	Maestro	42.7957870257738975	-78.9183478224024242
17094	2020-03-25 13:40:26	2020-03-25	Alger Pouros MD	alger.pouros.md@warmmail.com	Chattanooga	Tennessee	589337030206546	529873b168781583e666154eab7c1337	JCB 16 digit	34.985140697363768	-85.2712626937605478
17095	2020-03-25 13:43:40	2020-03-25	Harmon Casper	harmon.casper@warmmail.com	Honolulu	Hawaii	502014734831333	e140de4d53ca5ebfdc31e8c0fcb50ccb	Mastercard	21.413514264089244	-157.860410082593944
17096	2020-03-25 13:48:37	2020-03-25	Mansfield Wilderman	mansfield.wilderman@geemail.com	Knoxville	Tennessee	4589884814006280	a475c499a69f2858bd6da68c16c1a6dd	JCB 16 digit	35.908081157930944	-83.8994005215570269
17097	2020-03-25 13:59:02	2020-03-25	Dino Anderson-Brakus	dino.anderson.brakus@geemail.com	New York	New York	3465400122098316	a39358a25f224bcbf88eb6cb3b4f30ea	JCB 16 digit	40.6277161417286834	-74.000010695996508
17098	2020-03-25 14:11:13	2020-03-25	Cordia Skiles	cordia.skiles@geemail.com	San Francisco	California	53410692507141008	8263b24c806af661f8db9ccb19b8f636	JCB 15 digit	37.7734036053438658	-122.423999300479025
17099	2020-03-25 14:12:49	2020-03-25	Hildur Pacocha DVM	hildur.pacocha.dvm@warmmail.com	San Diego	California	4155624248587057	972ae15e155eb1a94ea2425b472886a0	Discover	32.8720724745720645	-117.141840684218337
17100	2020-03-25 14:15:56	2020-03-25	Jarred Will	jarred.will@geemail.com	Detroit	Michigan	3461786781899802	f50d4055ba195806df044aa3ba025503	Diners Club / Carte Blanche	42.3231176317129325	-83.1310422998506482
17101	2020-03-25 14:36:08	2020-03-25	Dezzie Romaguera	dezzie.romaguera@geemail.com	Oakland	California	3469641703303502	f1e14e8a96675f7031301c29b0084bc7	Voyager	37.784015625499741	-122.267866467001355
17102	2020-03-25 14:38:48	2020-03-25	Asia Howell	asia.howell@geemail.com	Houston	Texas	3452316809329607	0a816408261329cb393c103054c93f26	American Express	29.7108881774436675	-95.2914162310320876
17103	2020-03-25 14:39:31	2020-03-25	Dax Wisozk	dax.wisozk@woohoo.com	Chicago	Illinois	4062093641033	223bbe45ac559836bb108e7e4b911354	Mastercard	41.8855840916581457	-87.7270289606910154
17104	2020-03-25 15:07:02	2020-03-25	Dr. Olivine Walter	dr.olivine.walter@warmmail.com	Seattle	Washington	3528005508003933675	bfd8e6d1ef65db1f0a1999f012b652e4	JCB 15 digit	47.6098679382279499	-122.286569956915073
17105	2020-03-25 15:18:19	2020-03-25	Scottie Leffler	scottie.leffler@geemail.com	Stockton	California	630402039118654	14a71cbc21b625cc38eca049ea6e07cc	JCB 15 digit	37.8777206279534866	-121.324790761768071
17106	2020-03-25 15:33:29	2020-03-25	Adolphus Auer	adolphus.auer@geemail.com	Westminster	Colorado	3337618020625797545	5d1f229b0b1ae83b41efa71f810d8af5	Maestro	39.8783775074712921	-105.120510539892692
17107	2020-03-25 16:14:41	2020-03-25	Mrs. Vannie Boyer	mrs.vannie.boyer@geemail.com	Augusta	Georgia	4033595231307893	b0facbd2b9125e71c2653e5598f4821a	Discover	33.3019988272078322	-82.0492935771416967
17108	2020-03-25 16:17:12	2020-03-25	Corliss Hilpert-Robel	corliss.hilpert.robel@geemail.com	Berkeley	California	4923603492516	fcea4d096e787ccc74a3d5266929e9ef	Discover	37.8870305463687629	-122.290524433718602
17109	2020-03-25 16:21:00	2020-03-25	Clide Littel V	clide.littel.v@geemail.com	Anaheim	California	4798638460347597	9c58f02e53aa252cbf73977f5d9fdcca	JCB 16 digit	33.8044862217567825	-117.799909309737757
17110	2020-03-25 16:34:31	2020-03-25	Toney Monahan	toney.monahan@geemail.com	Philadelphia	Pennsylvania	3055106382625903	a9a81780d4b5615b60dc30a4013e0857	American Express	39.9430467775981839	-75.1776591646850108
17111	2020-03-25 16:52:44	2020-03-25	Carrol Rodriguez	carrol.rodriguez@geemail.com	Baltimore	Maryland	3112218927721353771	3f2dceae4f85c620720f5326af3ade79	Discover	39.3531396137550473	-76.5671021416336259
17112	2020-03-25 16:56:31	2020-03-25	Lindsay Lockman MD	lindsay.lockman.md@geemail.com	Pompano Beach	Florida	869933483123260472	e7dbde6b5e2e2e6424506bcedcbff2f2	JCB 16 digit	26.2142957882754501	-80.1426188380770412
17113	2020-03-25 16:56:59	2020-03-25	Christiana Wehner	christiana.wehner@geemail.com	Omaha	Nebraska	3719237478597989	4385b048aa415904458e3e7d28ceba8c	JCB 16 digit	41.2071667494863263	-96.1172452598460012
17114	2020-03-25 17:14:01	2020-03-25	Chaya Jerde	chaya.jerde@geemail.com	San Francisco	California	3158668063363973794	12a17066bcade87b03bd2942a33bcc05	Maestro	37.745945195252304	-122.433230381853392
17115	2020-03-25 17:54:51	2020-03-25	Freeman Fahey PhD	freeman.fahey.phd@woohoo.com	Gainesville	Florida	52921451970228418	a337941fe4af67c26a77fe8ad0ae60c8	VISA 13 digit	29.61087175116986	-82.2733555943578523
17116	2020-03-25 18:25:55	2020-03-25	Dr. Everett Kertzmann III	dr.everett.kertzmann.iii@geemail.com	Houston	Texas	3402841378044825	7f57264e7c51cad70672567af24d6df3	JCB 16 digit	29.8094076065890476	-95.3764882562231264
17117	2020-03-25 18:38:27	2020-03-25	Mr. Earnest O'Conner	mr.earnest.o'conner@geemail.com	McKinney	Texas	869998829356678404	a0b4b77de60a01909c6569b0b6fb6636	Diners Club / Carte Blanche	33.2549503029454527	-96.7202581171710136
17118	2020-03-25 18:48:57	2020-03-25	Dorthea Schiller	dorthea.schiller@geemail.com	West Jordan	Utah	639063090837533	0f68071e6f10676dec4d66d862ddefd0	JCB 16 digit	40.5265887307725876	-111.927640587146584
17119	2020-03-25 18:52:00	2020-03-25	Ossie Altenwerth	ossie.altenwerth@warmmail.com	San Francisco	California	4940624415051077	61981c0eb3d547cddf0ad6f6138714bf	Mastercard	37.7803882480976085	-122.407486220454572
17120	2020-03-25 18:59:45	2020-03-25	Lorenza Goldner	lorenza.goldner@woohoo.com	Louisville	Kentucky	53316769642722440	30955943e6685e00c57795fcc76e840f	American Express	38.2168354486949724	-85.6444056796446489
17121	2020-03-25 19:04:57	2020-03-25	Pink Schowalter DVM	pink.schowalter.dvm@geemail.com	New York	New York	4437038904343491	a34c44b38785353e202b718bc1a41dc7	Voyager	40.6614887262452385	-73.9292428914353223
17122	2020-03-25 19:24:02	2020-03-25	Adelynn Prosacco	adelynn.prosacco@geemail.com	Lancaster	California	3033265874199942	cdd97c0c8f434e2bf5d541e81d95b043	Discover	34.677823658498383	-118.261763242582973
17123	2020-03-25 19:37:19	2020-03-25	Tilman Jones	tilman.jones@woohoo.com	Sacramento	California	3096355370131189233	54c29e870dbc5c7bf92b1c6dc8fd817f	VISA 16 digit	38.4859760219030065	-121.460168009089671
17124	2020-03-25 19:48:58	2020-03-25	Krystina Feest MD	krystina.feest.md@woohoo.com	Anaheim	California	675919615640620	9268ee0fac214f3b6d1abff1e624c341	Maestro	33.9381462258119129	-117.783205848534024
17125	2020-03-25 19:58:12	2020-03-25	Codi Hoeger	codi.hoeger@warmmail.com	Jacksonville	Florida	4173711648423	b4995939567a6c0e637f187d727bcc95	Voyager	30.2887579600844532	-81.6916205178558954
17126	2020-03-25 20:39:35	2020-03-25	Jeanna Torphy	jeanna.torphy@geemail.com	New York	New York	630472903580800	9894ee76cfbeeb9c5cbebd5d761985a4	Discover	40.6080662171579903	-74.0136375422485173
17127	2020-03-25 20:39:58	2020-03-25	Carlotta Fritsch	carlotta.fritsch@geemail.com	New York	New York	3337691850748438415	fb04962c26cc4870f656aec7cefdead1	Mastercard	40.7536632703840738	-74.0150226788956616
17128	2020-03-25 21:24:21	2020-03-25	Analia Sanford	analia.sanford@geemail.com	Cleveland	Ohio	3088140318722612154	988ed5676451eedbd7c99e0c7251789d	American Express	41.3913872409462869	-81.7508363615028628
17129	2020-03-25 21:37:49	2020-03-25	Dr. Melonie Graham PhD	dr.melonie.graham.phd@geemail.com	Woodbridge	New Jersey	3528109801360042346	516714f8df6c910b32fc4275873fc9ab	JCB 15 digit	40.5351821425992966	-74.2000448910377912
17130	2020-03-25 21:38:36	2020-03-25	Edmon Jones	edmon.jones@geemail.com	Cleveland	Ohio	51670030098266709	36e879ed4d59c4ae800181684d920ce6	American Express	41.545377443855628	-81.6737743279669388
17131	2020-03-25 21:54:24	2020-03-25	Ray Block-Orn	ray.block.orn@warmmail.com	New York	New York	4709546179983	83d5569bd3a48fd9f85767fd0c8376e3	VISA 13 digit	40.6903599769566213	-73.8975188510388108
17132	2020-03-25 21:55:08	2020-03-25	Tyrell Pagac	tyrell.pagac@geemail.com	Vancouver	Washington	55015589283358419	5727e48198514b8b799d3dd276ea9ac0	Voyager	45.5940045435052355	-122.573319556942948
17133	2020-03-25 22:06:09	2020-03-25	Deward Von	deward.von@geemail.com	San Francisco	California	4170437870201892	5e737a528eb48bae7beda3bcd2308d01	VISA 13 digit	37.7580794976626919	-122.41496085458185
17134	2020-03-25 23:04:47	2020-03-25	Dr. Jazmin Skiles DVM	dr.jazmin.skiles.dvm@geemail.com	Philadelphia	Pennsylvania	869906485490582928	f50c4d10855220bfaa8c16f042897df6	JCB 16 digit	39.9169589355546961	-75.0814345571577633
17135	2020-03-25 23:16:49	2020-03-25	Landon Miller	landon.miller@geemail.com	Fort Worth	Texas	869907665294183341	671535c1f1aee936cd3b3fb53a2f6b95	Discover	32.782325630407783	-97.3280681359868538
17136	2020-03-25 23:29:01	2020-03-25	Doretta Schmitt	doretta.schmitt@geemail.com	Louisville	Kentucky	3528286189041497674	48aac07bcfd0297be94aadfaa59d9a16	Mastercard	38.084546906258538	-85.5713910599775716
17137	2020-03-25 23:40:32	2020-03-25	Larue Heidenreich-Boehm	larue.heidenreich.boehm@woohoo.com	Charlotte	North Carolina	3489927773504293	d90c286eb1acd278fea0d66c2ed26bd8	JCB 16 digit	35.2562162120148557	-80.8531622146666109
17138	2020-03-25 23:40:44	2020-03-25	Mr. Kaye Blick Sr.	mr.kaye.blick.sr.@warmmail.com	San Francisco	California	6011025822356646644	49b89082c86282844e771516313c8261	VISA 16 digit	37.7626016771354642	-122.419023954405816
17139	2020-03-25 23:40:51	2020-03-25	Winfred Rolfson	winfred.rolfson@geemail.com	San Francisco	California	869977650725128102	529f5cb64ee05c75ca522a204a43d481	Diners Club / Carte Blanche	37.7714337385344905	-122.417286320517462
17140	2020-03-25 23:53:49	2020-03-25	Greene Corwin	greene.corwin@warmmail.com	New York	New York	6011029597045839018	ff40243f6ebcc73e5068a71ac5259ea6	American Express	40.6453109551444669	-74.035986887327212
17141	2020-03-25 23:57:30	2020-03-25	Viridiana Bayer	viridiana.bayer@geemail.com	Oakland	California	676334144435129	d478b989b4208397bf47d826cfa92638	VISA 16 digit	37.8417985176081402	-122.254034705418789
17142	2020-03-26 00:05:59	2020-03-26	Melonie Goldner	melonie.goldner@geemail.com	Las Vegas	Nevada	3001326519616005	7fff2520b237495a4bea03d8926f035b	Discover	36.3240668644763502	-115.340655349355558
17143	2020-03-26 00:11:47	2020-03-26	Hughes Toy-Streich	hughes.toy.streich@geemail.com	Pearland	Texas	210041276600814898	5f613f819e891349fa73182ea17ab1db	VISA 13 digit	29.4713135477893076	-95.3382223608758324
17144	2020-03-26 00:17:14	2020-03-26	Bettie Yundt	bettie.yundt@geemail.com	Greensboro	North Carolina	4566929554756490	b9f9c5472ddb40fdc5dbfeaa518865fe	VISA 16 digit	36.1368362836655237	-79.8350347682815027
17145	2020-03-26 00:27:19	2020-03-26	Lonna Wuckert	lonna.wuckert@geemail.com	San Francisco	California	4208355885978872	4d0e739aa5122b36f55721547465fcc4	VISA 16 digit	37.7551098792789261	-122.422831357971518
17146	2020-03-26 00:47:39	2020-03-26	Luetta Hermiston	luetta.hermiston@geemail.com	Las Cruces	New Mexico	210019567854404982	5a08ea8aac10683d821a4f2428a64a5c	JCB 16 digit	32.4224846292320663	-106.727056226518741
17147	2020-03-26 00:55:02	2020-03-26	Miss Margueritte Parker MD	miss.margueritte.parker.md@geemail.com	Los Angeles	California	869923714343133186	42b4531ba31fde874ef72b5f7084f2c3	Diners Club / Carte Blanche	34.086856707824019	-118.402833129092301
17148	2020-03-26 00:58:34	2020-03-26	Dr. Lauren Windler	dr.lauren.windler@warmmail.com	Columbia	South Carolina	54142863339389447	4332086ff1a9be283be58e76bc8a8c73	VISA 16 digit	33.9513869735211102	-80.7994311162289165
17149	2020-03-26 01:02:29	2020-03-26	Eliezer Marks	eliezer.marks@geemail.com	Boise	Idaho	4132535923973586	598e5ec5859652ac1cb810a9a9ad5750	Diners Club / Carte Blanche	43.6097870611257861	-116.146704079649226
17150	2020-03-26 01:06:32	2020-03-26	Dr. Karina Bogisich	dr.karina.bogisich@warmmail.com	Berkeley	California	869975531949752160	6f2476952f5399c0e2660c3f1b47ff62	American Express	37.8668221803420337	-122.248317105749919
17151	2020-03-26 01:15:08	2020-03-26	Mr. Taft Gleason	mr.taft.gleason@geemail.com	New York	New York	6011653259304064969	7d4eee35d79361143dbe8cb265b118d8	American Express	40.6020417683515689	-73.9072044557321846
17152	2020-03-26 01:32:28	2020-03-26	Jeffery Jenkins	jeffery.jenkins@geemail.com	Killeen	Texas	4577915416991	dd8b729d0cd9ddc0757e0673ce4f8b49	VISA 13 digit	31.1268927216295168	-97.8082604603543899
17153	2020-03-26 01:38:18	2020-03-26	Miss Angelia Barton PhD	miss.angelia.barton.phd@woohoo.com	Carlsbad	California	6011769601173991940	d2b351e16d250e45bc593deff37dad6f	JCB 15 digit	33.1182830389995146	-117.33907265856601
17154	2020-03-26 01:59:05	2020-03-26	Ardath Schuster	ardath.schuster@woohoo.com	Indianapolis	Indiana	210069394408938863	ebcc9f346957ba927421e614394e3f56	Diners Club / Carte Blanche	39.7752084353480484	-86.1215531003862651
17155	2020-03-26 02:09:31	2020-03-26	Mr. Jonah Swift DDS	mr.jonah.swift.dds@geemail.com	Glendale	Arizona	3337061351824617743	3c2ca59e78d75689600183a4470f05fb	JCB 15 digit	33.4980977846071113	-112.124232734858609
17156	2020-03-26 02:18:12	2020-03-26	Miss Aurora Rath MD	miss.aurora.rath.md@woohoo.com	San Antonio	Texas	53784401713671842	f25214a371dc2473c75dd3b5b6e3ecea	Maestro	29.5431369294483233	-98.4939021543435729
17157	2020-03-26 02:34:39	2020-03-26	Duke Bradtke	duke.bradtke@geemail.com	Greeley	Colorado	53133078253643494	052c6f23aafb90f9648075822ca58447	JCB 15 digit	40.4588633394867188	-104.731138900604847
17158	2020-03-26 02:52:16	2020-03-26	Meghann Kunze-Hintz	meghann.kunze.hintz@geemail.com	Fresno	California	3088670506786768940	ad336157fc533738ed2411812949af0e	VISA 16 digit	36.7938507554925991	-119.865473191730317
17159	2020-03-26 02:53:08	2020-03-26	Mr. Johnathan Kovacek	mr.johnathan.kovacek@woohoo.com	Fremont	California	6011491945411020516	7b61cfaf50378e97dc4e42187c944bf8	JCB 16 digit	37.4199431271925604	-121.876642575439803
17160	2020-03-26 03:02:04	2020-03-26	Madyson Jones	madyson.jones@woohoo.com	Madison	Wisconsin	869944376255557656	34cef44a38d46936c49182900fd9eb4f	VISA 13 digit	43.0355191571146278	-89.485188567999387
17161	2020-03-26 03:18:54	2020-03-26	Jeremie Wisoky	jeremie.wisoky@geemail.com	Columbus	Ohio	561225020490717	d011888bf6158e206801c0963a843853	Voyager	40.0104887238282672	-82.8982745767340106
17162	2020-03-26 03:27:15	2020-03-26	Xander Streich	xander.streich@geemail.com	Odessa	Texas	6011670563191631361	c699042fc6016a7f02f7093312a13e72	JCB 16 digit	31.9817375370312504	-102.324739136329285
17163	2020-03-26 03:34:28	2020-03-26	Maralyn Hoppe	maralyn.hoppe@warmmail.com	Los Angeles	California	3096356978375112502	a84f325416372dca7a208cf293e0488e	VISA 13 digit	33.9830561580467929	-118.392063711163772
17164	2020-03-26 03:40:22	2020-03-26	Ms. Kaleena Lueilwitz DDS	ms.kaleena.lueilwitz.dds@warmmail.com	Hollywood	Florida	3011114280599943	51d06e4907a1634650904bdb95319e6f	Discover	26.0015568141303959	-80.2597007488649297
17165	2020-03-26 03:47:32	2020-03-26	Kurtis Wehner	kurtis.wehner@geemail.com	Pompano Beach	Florida	869979319282799444	72d5ad36abe34c5a3a84c8032cd96ef0	Maestro	26.2162964964084324	-80.0571041256502269
17166	2020-03-26 03:59:26	2020-03-26	Dr. Erle Spinka	dr.erle.spinka@geemail.com	Oceanside	California	869907288265491369	bcae0ca3c32f68b63ad5a10075168f85	Diners Club / Carte Blanche	33.2952802883349364	-117.235067559321223
17167	2020-03-26 04:08:21	2020-03-26	Natasha Ledner	natasha.ledner@warmmail.com	San Francisco	California	3710211711877200	d1620c7ce6e91de9a05fda92aa171efb	American Express	37.7685732374309566	-122.41496074164094
17168	2020-03-26 04:10:48	2020-03-26	Mr. Maurice Pouros V	mr.maurice.pouros.v@geemail.com	Oakland	California	3112319059964623526	94539c46655eb8c1a74b092cded87b0a	JCB 16 digit	37.8236621184583939	-122.277838779070095
17169	2020-03-26 04:11:56	2020-03-26	Tillman Kshlerin	tillman.kshlerin@warmmail.com	Portland	Oregon	4584756758436357	59b55317e5706cfba04c6fba56972234	Diners Club / Carte Blanche	45.4825119248479623	-122.602426280779767
17170	2020-03-26 04:27:24	2020-03-26	Rollin Lakin	rollin.lakin@geemail.com	New York	New York	4333847894891	471caa140c43fbb9339d553a78e9b010	JCB 16 digit	40.6097507339194408	-73.8879346828337731
17171	2020-03-26 04:30:46	2020-03-26	Dr. Amarion Turcotte	dr.amarion.turcotte@geemail.com	Colorado Springs	Colorado	3337655255619262379	1f675a73e395614d4ba94c42ae86d525	Diners Club / Carte Blanche	38.8676361414186644	-104.733909844157097
17172	2020-03-26 04:47:12	2020-03-26	Carmine O'Kon-Shields	carmine.o'kon.shields@geemail.com	San Francisco	California	869995074015004006	64a0bf9bacf08e81b909a3fff58af140	VISA 16 digit	37.7630611061176751	-122.472454343624662
17173	2020-03-26 04:56:13	2020-03-26	Wendy Boehm	wendy.boehm@geemail.com	San Francisco	California	3021700017109020	5e2ecfa87fa1f4d601db32747d7decc4	VISA 13 digit	37.7567431600974928	-122.432778406920789
17174	2020-03-26 05:23:57	2020-03-26	Brianda Schiller	brianda.schiller@geemail.com	San Francisco	California	180048012019105559	4bfa943c4aac9e95061d438a470a6372	JCB 16 digit	37.811838140976576	-122.415000978660842
17175	2020-03-26 05:53:37	2020-03-26	Kip Murazik	kip.murazik@geemail.com	Houston	Texas	55653907794394797	68ac28854020b598456febe7cf6c3650	JCB 15 digit	29.7474176600188009	-95.4331326811589378
17176	2020-03-26 05:54:37	2020-03-26	Taina Buckridge-Reichel	taina.buckridge.reichel@geemail.com	Wichita	Kansas	4969006347435	b3220b5bff2657e733f8d8a0bab21af3	JCB 16 digit	37.7525346556089829	-97.2693040276613061
17177	2020-03-26 06:26:00	2020-03-26	Dickie Graham	dickie.graham@geemail.com	Las Cruces	New Mexico	3034694635217959	acf867ea9d24c4015faf53ade9db2ebe	Maestro	32.299234799764676	-106.870558777277168
17178	2020-03-26 06:52:27	2020-03-26	Montgomery Anderson	montgomery.anderson@warmmail.com	Miramar	Florida	675928652791055	c4954397fcefa44ae6443a43419d907a	Diners Club / Carte Blanche	26.0044259841535244	-80.2586880606591819
17179	2020-03-26 06:55:25	2020-03-26	Bryton Moore-Bogan	bryton.moore.bogan@geemail.com	Augusta	Georgia	3757574102736176	afb1df187a50df9e6285c1206fd69a21	American Express	33.418023626387118	-82.0510756885927179
17180	2020-03-26 07:08:46	2020-03-26	Leonor Eichmann	leonor.eichmann@geemail.com	Oakland	California	4354997043113	14bff54e913033093c97df74b0832bc6	VISA 13 digit	37.8185580597196278	-122.249661471951214
17181	2020-03-26 07:16:30	2020-03-26	Zadie Ullrich DVM	zadie.ullrich.dvm@warmmail.com	North Charleston	South Carolina	3528524203898156457	502bc7f4e2af85e16ff27d9f374b1304	Diners Club / Carte Blanche	32.8206458965942289	-80.0138659860566293
17182	2020-03-26 07:18:15	2020-03-26	Loy Ferry	loy.ferry@warmmail.com	Lafayette	Louisiana	4584674710457	5578743b04577f07720d27b8279f56a3	JCB 15 digit	30.2656810737192643	-92.0622196324486168
17183	2020-03-26 07:33:13	2020-03-26	Ms. Latesha Moore	ms.latesha.moore@geemail.com	Orange	California	3019130282036538	f93b351b0f494bbae76384f7c094a368	VISA 13 digit	33.7485235568955559	-117.91748602801114
17184	2020-03-26 07:43:26	2020-03-26	Deacon Ratke	deacon.ratke@geemail.com	Round Rock	Texas	6011601146939693192	78aa48817ba3f7c65ebe9954a5dd01ab	Discover	30.4649159562446208	-97.604278664275995
17185	2020-03-26 07:45:31	2020-03-26	Loni Bashirian-Stamm	loni.bashirian.stamm@geemail.com	Atlanta	Georgia	6011721195984891628	958393228daa6abfaa30cdefd007e1fc	VISA 16 digit	33.7399231826230874	-84.3462310453921589
17186	2020-03-26 07:49:39	2020-03-26	Kellan Lind-Lowe	kellan.lind.lowe@geemail.com	New York	New York	3055523690805789	3182df0cd24e2faca3f467cad2f0c2b3	Maestro	40.6536625778991692	-73.8522279796551828
17187	2020-03-26 08:31:22	2020-03-26	Miss Dayna Bashirian MD	miss.dayna.bashirian.md@geemail.com	Phoenix	Arizona	3026064956571046	78f877a2df0147739f82623e80e0a8d8	JCB 15 digit	33.5741372416194537	-112.074535830684383
17188	2020-03-26 08:49:13	2020-03-26	Christin Mraz	christin.mraz@warmmail.com	San Diego	California	676127518788859	e1dbad889a6ac60bde51f0565ddd8aab	VISA 16 digit	32.7281078138455754	-117.108652782896542
17189	2020-03-26 09:34:56	2020-03-26	Luther Kertzmann	luther.kertzmann@geemail.com	Baton Rouge	Louisiana	52919247360370313	b3ec106b3fc59d79f5a28c0b7f3637f7	Voyager	30.3778825964990986	-91.1518882744587984
17190	2020-03-26 09:36:39	2020-03-26	Donia Okuneva	donia.okuneva@geemail.com	Springfield	Missouri	4076012412666483	261697563fb3536043c029a67db50c7a	Voyager	37.2438137699577965	-93.3781457958567955
17191	2020-03-26 09:39:49	2020-03-26	Dion Graham-Okuneva	dion.graham.okuneva@woohoo.com	Boston	Massachusetts	4198278962010520	4b17349d2bbbcca8a3a66faea1459c5b	JCB 16 digit	42.2700026282742627	-70.977457748441779
17192	2020-03-26 09:55:21	2020-03-26	Georgia Becker	georgia.becker@woohoo.com	Berkeley	California	3112250391012580742	4b95ff2a8b48f30c865381449a040987	Maestro	37.8725807724125545	-122.269147588646291
17193	2020-03-26 10:04:48	2020-03-26	Needham Lubowitz	needham.lubowitz@woohoo.com	Centennial	Colorado	210046426941108303	06583b1eb7c7f6d25fa8beaf86ec3204	Mastercard	39.6617294413544244	-104.881455038244283
17194	2020-03-26 10:21:43	2020-03-26	Deion Harvey	deion.harvey@geemail.com	Berkeley	California	3337986502485039773	a1821a0487b778d1465a3a4cdf059e24	Voyager	37.8574944938116857	-122.266587779598439
17195	2020-03-26 10:29:34	2020-03-26	Ms. Tai Stamm	ms.tai.stamm@geemail.com	Cambridge	Massachusetts	4500059324813667	0c9d37edf87430623c4cb4cc48de53a9	JCB 16 digit	42.3677696141172149	-71.0944143616676314
17196	2020-03-26 10:30:22	2020-03-26	Adison Jacobson	adison.jacobson@woohoo.com	San Antonio	Texas	3088969701414489486	7bd3bec7c364ee5277be72c50befeeb6	JCB 16 digit	29.5341532567121092	-98.5095456989783713
17197	2020-03-26 10:37:07	2020-03-26	Maida Lindgren	maida.lindgren@geemail.com	San Francisco	California	869907295865613243	a51962bf72566dd42af17e913c8ddda9	American Express	37.7593035411515459	-122.411110776007746
17198	2020-03-26 10:57:54	2020-03-26	Fannye Yost	fannye.yost@woohoo.com	Tacoma	Washington	3047830424850314	e77fba4121afc76ca243c504c2f0b546	Discover	47.2638879911627612	-122.544584373966984
17199	2020-03-26 11:03:14	2020-03-26	Minna Nienow	minna.nienow@geemail.com	Berkeley	California	869920201348641275	a94436bcb31114ac69e05ba63a875295	Maestro	37.8563042255409101	-122.266521270928436
17200	2020-03-26 11:08:03	2020-03-26	Tamia Halvorson	tamia.halvorson@geemail.com	San Diego	California	6011301654396632754	3ab00e634b70d3e34905b85a61d5fdb1	JCB 15 digit	32.770506615151838	-117.04628536378965
17201	2020-03-26 11:16:53	2020-03-26	Miss Aniyah Larkin MD	miss.aniyah.larkin.md@woohoo.com	Portland	Oregon	869942162761034923	bac95cb28450438213fd5c0f3990e322	Mastercard	45.5807233214266603	-122.62440432505683
17202	2020-03-26 11:28:06	2020-03-26	Wyatt Abshire	wyatt.abshire@geemail.com	San Francisco	California	4997422801537	3a733bd37cba5d07eee11d1550120909	VISA 13 digit	37.7791674570883345	-122.39825830250436
17203	2020-03-26 11:48:26	2020-03-26	Denita O'Hara	denita.o'hara@geemail.com	Pittsburgh	Pennsylvania	3492662414218673	4f444f9d5ebcace75ba9df25ce20f8ff	VISA 16 digit	40.4023674718990904	-80.0305581458084276
17204	2020-03-26 12:01:15	2020-03-26	Shanon Moen	shanon.moen@geemail.com	Naperville	Illinois	869993879872270652	7921d697be36ef0b62e297f5a56e57a1	Discover	41.670621675989409	-88.1188592771887897
17205	2020-03-26 12:21:03	2020-03-26	Daquan Lueilwitz	daquan.lueilwitz@geemail.com	New York	New York	4541755451750561	192d1e190295c084513089fd1b8fc085	Voyager	40.75082612659223	-73.8426753809571181
17206	2020-03-26 12:23:48	2020-03-26	Albertine Douglas PhD	albertine.douglas.phd@geemail.com	Baltimore	Maryland	55600336823970340	791f443ba9e0a76e24bf6519e2fe91d3	Mastercard	39.2600732374004977	-76.6799405380636472
17207	2020-03-26 12:25:39	2020-03-26	Cato Funk MD	cato.funk.md@woohoo.com	Ontario	California	3112803828604218399	ca9dfd1b37fb5651c75357fae8b97cff	JCB 15 digit	34.0430941550206398	-117.693589149518687
17208	2020-03-26 12:31:11	2020-03-26	Schuyler Aufderhar	schuyler.aufderhar@woohoo.com	Charlotte	North Carolina	3088249594788178310	73b8cd253acf1579ce622c977b3fb280	American Express	35.2833025585182014	-80.8717403198536573
17209	2020-03-26 12:33:49	2020-03-26	Ilma Wisoky MD	ilma.wisoky.md@geemail.com	San Francisco	California	3528825615104093198	2393e9249fd13e3c9f78745724c01ec3	JCB 16 digit	37.7895024748536557	-122.468073611660657
17210	2020-03-26 12:34:04	2020-03-26	Milan Johns DDS	milan.johns.dds@geemail.com	Atlanta	Georgia	6011460708604788431	70f8afd9ff3308f3fbe6edc8134d2e51	VISA 16 digit	33.8502895808588704	-84.4437641424171659
17211	2020-03-26 12:47:46	2020-03-26	Sydni Bogisich	sydni.bogisich@geemail.com	Jersey City	New Jersey	4036617054171847	481cb44225fc83dff111091d9ea8e154	JCB 16 digit	40.6288813807476288	-73.9801314171358939
17212	2020-03-26 12:49:41	2020-03-26	Horton Larson-Kemmer	horton.larson.kemmer@geemail.com	Wichita	Kansas	4390205474102301	e731b738d6e1c8d998168d38cdc96326	VISA 16 digit	37.6156923014082025	-97.4334076123513313
17213	2020-03-26 13:09:09	2020-03-26	Cheryll Davis	cheryll.davis@geemail.com	Coral Springs	Florida	4590220387265234	ef3b509436244e8c697bea2d66be0dab	VISA 16 digit	26.3504434464097024	-80.1766674852587187
17214	2020-03-26 13:10:58	2020-03-26	Dale Hoppe	dale.hoppe@geemail.com	Riverside	California	4607949776225	4da116b81643a814ce140426dde64940	Discover	33.9293176392506766	-117.430221696148436
17215	2020-03-26 13:16:13	2020-03-26	Adam Armstrong	adam.armstrong@warmmail.com	Portland	Oregon	869929724320884184	a265420d51c745f66cae183c6a41fa21	Discover	45.4388383766058794	-122.557361915335065
17216	2020-03-26 13:29:00	2020-03-26	Levi Hansen	levi.hansen@geemail.com	Austin	Texas	4080987361773	cfd18e5f33a0a50772c5866063e3b149	Maestro	30.3788717960134136	-97.6851973949238754
17217	2020-03-26 14:11:16	2020-03-26	Joellen Schmitt	joellen.schmitt@woohoo.com	San Francisco	California	4896398071770	50b90c00ac30774743c13983c2083fb6	JCB 15 digit	37.7742026386670062	-122.487826287488971
17218	2020-03-26 14:28:33	2020-03-26	Miss Dotty Will DVM	miss.dotty.will.dvm@geemail.com	Detroit	Michigan	3528809502607633847	01e568656fbefc864564d6f11a8c49b9	American Express	42.3791528057698201	-83.1771007773585609
17219	2020-03-26 14:34:59	2020-03-26	Darcie Kuhlman	darcie.kuhlman@geemail.com	Jacksonville	Florida	869934512738268394	236eaf05779c339409d7a18f556e3358	American Express	30.3693166540987782	-81.581093196159614
17220	2020-03-26 14:58:37	2020-03-26	Arland Cormier	arland.cormier@geemail.com	Birmingham	Alabama	3032141250319142	e9ae56092e11c755bb640883aa624fb1	JCB 16 digit	33.4913274661894889	-86.8064502978939601
17221	2020-03-26 15:02:47	2020-03-26	Antoinette Greenholt MD	antoinette.greenholt.md@geemail.com	San Diego	California	4449275778818796	79efbba81dd9f44e156fe00d111d46b3	VISA 16 digit	32.8584343762669704	-117.155158697525039
17222	2020-03-26 15:06:51	2020-03-26	Rudolf Reilly V	rudolf.reilly.v@geemail.com	Albuquerque	New Mexico	180043498858866929	ac4fd496f53bd8360010e7932069dd6b	American Express	35.1382995127834405	-106.692045553315069
17223	2020-03-26 15:22:00	2020-03-26	Miss Stephany Bins	miss.stephany.bins@geemail.com	Portland	Oregon	6011510960256724335	ebd431d85b9117b73e49b53005aa083d	Voyager	45.5292380207572123	-122.60582833089866
17224	2020-03-26 15:26:10	2020-03-26	Leilani Zieme-Blick	leilani.zieme.blick@geemail.com	New York	New York	4552916972770506	079bde898281ef89d6bc0af8e19729a7	JCB 16 digit	40.5637716952469205	-73.8402264388173819
17225	2020-03-26 15:37:47	2020-03-26	Tex Dicki	tex.dicki@geemail.com	Oakland	California	4557842636141865	024e2aa01b015f547c5c3a3b38acd9cd	American Express	37.8107662121714512	-122.2846743308112
17226	2020-03-26 15:40:20	2020-03-26	Brielle Reichert	brielle.reichert@geemail.com	Des Moines	Iowa	3528217156933026782	13e54d8d32bb39a5c7ca90661fa5750f	JCB 15 digit	41.6067931933537167	-93.5870776498269379
17227	2020-03-26 16:03:41	2020-03-26	Reinhold Hyatt	reinhold.hyatt@geemail.com	Palmdale	California	3088891504772352848	214e119f59d761a648dbe9e4435594d0	JCB 15 digit	34.6396911346670251	-118.008933844044435
17228	2020-03-26 16:19:53	2020-03-26	Elia Jenkins	elia.jenkins@geemail.com	Charlotte	North Carolina	6011270601072124710	3bf69ec41e6873161a3b5aec2994202f	Discover	35.2480822768315676	-80.9202772562336179
17229	2020-03-26 16:20:47	2020-03-26	Shara Kirlin	shara.kirlin@geemail.com	Elizabeth	New Jersey	3528897492581126351	4e2a37f12f74dcca74b9fffdf3dc4223	JCB 16 digit	40.6715137377508	-74.1699988260809278
17230	2020-03-26 16:37:28	2020-03-26	Erling Klein	erling.klein@geemail.com	Simi Valley	California	52147609491724052	3f934040af89cb7812965e9f353d4d8d	JCB 16 digit	34.2839647159218757	-118.764829010110361
17231	2020-03-26 16:39:39	2020-03-26	Ole Bechtelar DDS	ole.bechtelar.dds@geemail.com	Seattle	Washington	4352232934959860	0459cff3544baf1e668373a6f9461c79	VISA 13 digit	47.5507848692517712	-122.344928066145258
17232	2020-03-26 16:45:05	2020-03-26	Ms. Flavia Wisozk MD	ms.flavia.wisozk.md@warmmail.com	Indianapolis	Indiana	6011890454829625096	745bb762dd3d89bfd483c51a368a1adf	JCB 16 digit	39.7114084013279509	-86.2249819827467121
17233	2020-03-26 16:51:14	2020-03-26	Vic Towne	vic.towne@geemail.com	Berkeley	California	4341634509065854	6954fdc71ff1b66a94d57f91ac8cdcac	Maestro	37.8364554221804852	-122.247233361231864
17234	2020-03-26 16:52:18	2020-03-26	Lim Collier	lim.collier@geemail.com	Houston	Texas	3337385369829986920	f5e3ced8d81c91d66c51b72926051d33	Mastercard	29.7207246063821025	-95.4045330341454587
17235	2020-03-26 16:59:26	2020-03-26	Royce Barton	royce.barton@geemail.com	San Francisco	California	3088433273413881624	d6f9482334dfce3604d86ea484cc20ee	VISA 13 digit	37.7761208501598276	-122.453888723294554
17236	2020-03-26 17:01:10	2020-03-26	Dr. Dondre Becker	dr.dondre.becker@woohoo.com	San Francisco	California	3158531658608556992	2c3243d7a79c826650bffa36ccfe7524	VISA 16 digit	37.8020249522125766	-122.452780372106105
17237	2020-03-26 17:13:29	2020-03-26	Kunta Gleichner	kunta.gleichner@geemail.com	South Bend	Indiana	3528787064921710161	08e09f4e223089152951f89b33646d58	Maestro	41.7415970201283741	-86.3122681373786236
17238	2020-03-26 17:20:46	2020-03-26	Mrs. Desirae Farrell PhD	mrs.desirae.farrell.phd@geemail.com	Atlanta	Georgia	4917048170703640	91faa203ad56a6037b2e0b5d90831fd8	JCB 16 digit	33.7378812083784538	-84.4665202589750379
17239	2020-03-26 17:31:58	2020-03-26	Jaron Daugherty	jaron.daugherty@warmmail.com	San Francisco	California	4623432833070792	3c76b34f3cd2487012f015f76c403f69	JCB 15 digit	37.7589078778881344	-122.413709739158975
17240	2020-03-26 17:36:36	2020-03-26	Karley Ullrich	karley.ullrich@warmmail.com	Bellevue	Washington	4881055129603922	e5d30f6d2a89e26642517912ce1efffb	VISA 13 digit	47.5908712335579125	-122.16789865089207
17241	2020-03-26 17:53:51	2020-03-26	Alcide Pfannerstill	alcide.pfannerstill@geemail.com	Long Beach	California	3337680522517210886	dfb29022be9c1da737b1cca79601463a	JCB 16 digit	33.8369357982005923	-118.176197861057886
17242	2020-03-26 17:59:07	2020-03-26	Peggie Murazik	peggie.murazik@geemail.com	Atlanta	Georgia	3528396880887222260	95142feab6f87132c19b4e17045f5de4	JCB 16 digit	33.8223328744336982	-84.3980430627286466
17243	2020-03-26 18:09:16	2020-03-26	Cyntha Lindgren	cyntha.lindgren@woohoo.com	Evansville	Indiana	4008054029107728	b2bf8cf9f08e66077f2eb23bf669a81a	Maestro	38.0552813067238773	-87.4482946677997717
17244	2020-03-26 18:18:01	2020-03-26	Devyn Wintheiser	devyn.wintheiser@geemail.com	Richmond	California	4317121432783	f6a63787caa6ae954fd427a73ae6eecb	Maestro	38.0071934780526917	-122.426222999751943
17245	2020-03-26 18:43:35	2020-03-26	Ms. Parlee Eichmann PhD	ms.parlee.eichmann.phd@warmmail.com	Berkeley	California	869949125061125488	98f70d1ad462a6443f054798fe8cd4b5	JCB 16 digit	37.8516452556137821	-122.277193908533917
17246	2020-03-26 18:56:12	2020-03-26	Miss Oralia Stehr MD	miss.oralia.stehr.md@woohoo.com	Beaumont	Texas	4492368508874514	df49841885df2bb26c482f5f8180ebc1	VISA 16 digit	30.0243688656087961	-94.0595129168380168
17247	2020-03-26 18:59:56	2020-03-26	Giovani Hansen	giovani.hansen@geemail.com	Berkeley	California	4651182051361309	7f1c9abffc8bf529f1c5b0b245f126b1	Voyager	37.8648196498677834	-122.268822779369287
17248	2020-03-26 19:03:25	2020-03-26	Bernadette Kuphal	bernadette.kuphal@geemail.com	New York	New York	869974416045506895	ba40a2fe8f959210db0f82764fe196e4	JCB 15 digit	40.611451032128187	-73.9124597135826917
17249	2020-03-26 19:11:14	2020-03-26	Helene Kemmer	helene.kemmer@geemail.com	New York	New York	4353244811084901	ab8b8433d58582b1604d88f60aa9fb3b	Voyager	40.6810944397225995	-73.9438234715152447
17250	2020-03-26 19:14:59	2020-03-26	Delvin Parisian	delvin.parisian@woohoo.com	Hayward	California	869994430790741827	43047a4d79de05e32a4188ee95b6d8b0	VISA 16 digit	37.7074065859884016	-122.171089793348315
17251	2020-03-26 19:25:41	2020-03-26	Gillie Gutmann	gillie.gutmann@geemail.com	Houston	Texas	869944298810269884	7c80017798708c8de76a20014be325b5	Maestro	29.7095327263310551	-95.3840145323906086
17252	2020-03-26 19:26:32	2020-03-26	Dr. Payton Kuhlman DDS	dr.payton.kuhlman.dds@woohoo.com	Honolulu	Hawaii	4748865802964380	40310698302771eea2e8829bf513194d	JCB 16 digit	21.2988511445216844	-157.819992440726992
17253	2020-03-26 19:35:49	2020-03-26	Emelia Bartell	emelia.bartell@geemail.com	Mesa	Arizona	3740146264956080	a4182939a07ceead357397e0e7bcaa8d	Discover	33.4110734131798139	-111.812532141420618
17254	2020-03-26 19:45:12	2020-03-26	Dr. Margarette Mueller	dr.margarette.mueller@geemail.com	New York	New York	4651975359390023	fd428a8a0bc2e95b041168cdfabdab29	Mastercard	40.7296898562684646	-73.8817054831784219
17255	2020-03-26 20:07:48	2020-03-26	Lawanda Erdman DDS	lawanda.erdman.dds@woohoo.com	San Francisco	California	4124344001852	f4de763b90e682205d823818b69885a1	JCB 16 digit	37.7857634525444155	-122.476412763825238
17256	2020-03-26 20:08:30	2020-03-26	Kay Kohler	kay.kohler@geemail.com	New York	New York	675996459847065	b9ea6843b0c16bbe435e8fa33aa0f0ba	VISA 16 digit	40.667107912594453	-73.9994415779493693
17257	2020-03-26 20:22:08	2020-03-26	Dr. Kassandra Champlin PhD	dr.kassandra.champlin.phd@warmmail.com	Durham	North Carolina	6011274201212348976	3f52b7c162cae04f76fc430d0750da35	VISA 16 digit	35.9920652019571463	-78.966089110625532
17258	2020-03-26 20:24:02	2020-03-26	Merrie Carroll	merrie.carroll@geemail.com	Chicago	Illinois	3096639772649737908	49b8b9ad32d32101d21f589344e6992d	JCB 15 digit	41.8860897755086441	-87.6680831864506018
17259	2020-03-26 20:30:24	2020-03-26	Cheyenne Yundt	cheyenne.yundt@geemail.com	San Francisco	California	6011222319607204670	10aa7aaaca3938ebc32382656578d4f9	Maestro	37.7821065510943299	-122.405637176921815
17260	2020-03-26 20:31:55	2020-03-26	Ulysses Hammes	ulysses.hammes@geemail.com	Tallahassee	Florida	4393639017519919	c18cd2bc139509c48309251d75f39952	Mastercard	30.4345739438220875	-84.2412750587347858
17261	2020-03-26 20:33:14	2020-03-26	Louie Krajcik	louie.krajcik@geemail.com	Laredo	Texas	4498412686184041	ea3513c17b94396b81c2b18fb237b019	VISA 16 digit	27.4974966887567192	-99.4334008855752671
17262	2020-03-26 21:14:09	2020-03-26	Darcy McLaughlin	darcy.mclaughlin@geemail.com	Houston	Texas	3007024032521786	5e59f9b26e67da4544ca998da73220ee	Diners Club / Carte Blanche	29.7768428937610246	-95.4343789225459176
17263	2020-03-26 21:15:59	2020-03-26	Miss Joellen Ruecker DVM	miss.joellen.ruecker.dvm@geemail.com	Seattle	Washington	180072076052762179	a14bfd835adee97648297705953f8f5d	Maestro	47.5402244542185244	-122.321612850429119
17264	2020-03-26 21:17:36	2020-03-26	Ms. Madelene Nader	ms.madelene.nader@geemail.com	Jacksonville	Florida	3088400470818655053	f31299e6b77360675c29c4028387bbe6	VISA 13 digit	30.3394633180048316	-81.6937433088276634
17265	2020-03-26 21:29:06	2020-03-26	Osbaldo Dicki-Bogan	osbaldo.dicki.bogan@geemail.com	Dallas	Texas	4073360008090672	2b41016ec89bd9654e46b1af2886cb69	JCB 16 digit	32.7984405906677239	-96.8439068780708965
17266	2020-03-26 21:52:50	2020-03-26	Regan Luettgen	regan.luettgen@geemail.com	New York	New York	3088665546815924301	793dc2a794906556fcde748251b42cc3	VISA 16 digit	40.7231245091408454	-73.8630461698759291
17267	2020-03-26 21:53:20	2020-03-26	Raleigh Weissnat	raleigh.weissnat@geemail.com	New York	New York	210085635848080942	9f27c7c90fd4a21610b00898d2dfdedb	JCB 16 digit	40.7521191709432742	-73.9799815036717803
17268	2020-03-26 22:01:14	2020-03-26	Lucas Grant II	lucas.grant.ii@geemail.com	New York	New York	3021353287690707	1df4fcda184bcccdab177423d8cea694	VISA 13 digit	40.7399998135156949	-73.9658980330348044
17269	2020-03-26 22:10:36	2020-03-26	Annemarie Schmidt DDS	annemarie.schmidt.dds@warmmail.com	New York	New York	630436927229785	09aee1e9d39c53ffd406db05ad0e3a8d	American Express	40.6119742652624822	-73.9955957189563662
17270	2020-03-26 22:27:53	2020-03-26	Ms. Kaci Hartmann MD	ms.kaci.hartmann.md@geemail.com	Chicago	Illinois	6011334273427904487	673789d146752f72cb2938e288801ea6	Maestro	41.749958095776293	-87.6888883260108543
17271	2020-03-26 22:30:16	2020-03-26	Liam Sauer	liam.sauer@woohoo.com	San Bernardino	California	4058829713573262	01599a5755a1f1e6f70482075bf4947b	Voyager	34.0545694121424063	-117.341854816886041
17272	2020-03-26 22:32:00	2020-03-26	Wilbert Green	wilbert.green@geemail.com	Fort Wayne	Indiana	3088204188836231958	c7ccf0595a2f81371aab39c87623182d	VISA 16 digit	41.0897325766988075	-85.11880232344717
17273	2020-03-26 23:04:28	2020-03-26	Jetta Barrows	jetta.barrows@geemail.com	Tallahassee	Florida	3158602424611416953	3994b5b2ab57f9729ba18e612fca9a59	Maestro	30.5475616023898127	-84.2891079322449883
17274	2020-03-26 23:07:09	2020-03-26	Burney Rohan	burney.rohan@geemail.com	San Francisco	California	3112269128474163222	d352fca7a2451334d24dc49f512a522f	Diners Club / Carte Blanche	37.7682919904497965	-122.39329314183118
17275	2020-03-26 23:26:02	2020-03-26	Jamie Schaefer	jamie.schaefer@geemail.com	Lowell	Massachusetts	3088872269147570960	d68af335baaf5f1fcc7a38272d823beb	VISA 16 digit	42.5720972580239234	-71.3562108414120928
17276	2020-03-26 23:35:47	2020-03-26	Zana Kling-Schimmel	zana.kling.schimmel@geemail.com	Birmingham	Alabama	4342988340406472	7cfd9f3f85081e5d084bb01d038a6a6a	Diners Club / Carte Blanche	33.4757562285546229	-86.8364408575240532
17277	2020-03-26 23:36:19	2020-03-26	Ms. Loris Baumbach DDS	ms.loris.baumbach.dds@warmmail.com	San Francisco	California	869942654400251926	302aa4021ff70bf2a599820356af403a	Mastercard	37.7556965378637059	-122.438757390709569
17278	2020-03-26 23:59:52	2020-03-26	Dr. Cortney Marquardt	dr.cortney.marquardt@geemail.com	Abilene	Texas	869920842005262036	34701172a4e8217464cb42f9bad63dce	JCB 15 digit	32.5512440893873602	-99.8134422221168904
17279	2020-03-27 00:01:29	2020-03-27	Dr. Howard Nienow PhD	dr.howard.nienow.phd@geemail.com	San Antonio	Texas	6011369002315279985	1fb5ccffe6dcb462457b002546cbd2de	Discover	29.5058091509692382	-98.505944881059591
17280	2020-03-27 00:01:33	2020-03-27	Edris Heaney PhD	edris.heaney.phd@woohoo.com	San Francisco	California	53226125028421793	f34dd2a036f4a8271f7d86be90e1ef35	Maestro	37.7591776491009483	-122.416582357927169
17281	2020-03-27 00:04:09	2020-03-27	Damon Marvin	damon.marvin@warmmail.com	Woodbridge	New Jersey	3337099137442338770	ded452769cef4218696524474bf4753e	JCB 16 digit	40.5545118831254499	-74.2252803863350294
17282	2020-03-27 00:09:13	2020-03-27	Aydin Brown	aydin.brown@woohoo.com	Houston	Texas	561214580919653	1a943040a76cb1973a9d5691a1e8a970	Diners Club / Carte Blanche	29.7156801066439584	-95.3485294262427914
17283	2020-03-27 00:09:32	2020-03-27	Kaleb Thompson	kaleb.thompson@geemail.com	Virginia Beach	Virginia	3020946999434859	f11ed622063da9459dbaad24ba4ba815	Voyager	36.7503612437471787	-75.97407673519551
17284	2020-03-27 00:13:40	2020-03-27	Marybelle Kerluke	marybelle.kerluke@warmmail.com	San Francisco	California	3722541493516667	66ce361983f0b104f3d511d71461a0c0	Mastercard	37.7424947492690279	-122.466402247741087
17285	2020-03-27 00:17:28	2020-03-27	Bernadette Runte	bernadette.runte@woohoo.com	Albuquerque	New Mexico	4483548887472797	a76a5ecebe2ce45acecc023b26fac089	Discover	35.1167919855698969	-106.66260632533357
17286	2020-03-27 00:20:10	2020-03-27	Mr. Waino Wuckert DDS	mr.waino.wuckert.dds@geemail.com	Denver	Colorado	4484943028709349	6fd09ad28962b0bbc92328dc9eda392f	Maestro	39.8370508594490573	-104.847387235682831
17287	2020-03-27 00:32:39	2020-03-27	Miss Tracie O'Kon	miss.tracie.o'kon@geemail.com	Grand Rapids	Michigan	4693875241129	b2e021ae5607f1d05d547b6802d89fa9	VISA 13 digit	43.0600559516146788	-85.6008686568722226
17288	2020-03-27 00:33:48	2020-03-27	Bernie Paucek	bernie.paucek@geemail.com	New York	New York	3451894111210633	96545057380d3a55c5a115a948fb8360	VISA 16 digit	40.6854799972604937	-73.8604476457823012
17289	2020-03-27 00:43:39	2020-03-27	Shaun Dach	shaun.dach@warmmail.com	New York	New York	4193934589660502	9a913819dbbe568cd48636d6c5a940e6	Maestro	40.7359159910809225	-74.0302734570939123
17290	2020-03-27 00:51:45	2020-03-27	Shaquille Huels	shaquille.huels@geemail.com	San Antonio	Texas	3448831685047278	425cd6c7d1dc6c27aa2aa34c162ee3c8	JCB 15 digit	29.5494419071428496	-98.4526070393923618
17291	2020-03-27 01:12:04	2020-03-27	Lexie Jacobi	lexie.jacobi@woohoo.com	Norfolk	Virginia	3007860541355079	b71d582d8b15d8130ab80abb7638028a	Diners Club / Carte Blanche	36.9622360423691561	-76.190826675855007
17292	2020-03-27 01:21:48	2020-03-27	Ms. Jayme Gleason	ms.jayme.gleason@geemail.com	Austin	Texas	3096203809279198336	0955c9bfc16a0f3821b70102a14fbf4b	VISA 16 digit	30.2647921177219601	-97.8303741098154376
17293	2020-03-27 01:25:24	2020-03-27	Henderson White-Gleason	henderson.white.gleason@geemail.com	Phoenix	Arizona	869936225640925476	33f1506723d719144e5a977bf4b2ab9e	VISA 16 digit	33.6313637351550199	-112.093905180871872
17294	2020-03-27 01:27:40	2020-03-27	Roel Nader-Crona	roel.nader.crona@geemail.com	Ontario	California	869976148054362260	de36af7751aa6aab36942febf0a3b3f2	VISA 16 digit	34.122943295133858	-117.573724356583142
17295	2020-03-27 01:39:27	2020-03-27	Drema Schoen	drema.schoen@geemail.com	Oakland	California	869994214713837981	73b6f195925e05537ca0efe253b0ef00	Diners Club / Carte Blanche	37.8092350932996268	-122.284596070998305
17296	2020-03-27 01:44:56	2020-03-27	Ashton Schamberger PhD	ashton.schamberger.phd@geemail.com	Raleigh	North Carolina	4735721976442700	fc378cbf0da8b45454fb23e7e22c8995	JCB 16 digit	35.808954188287629	-78.6646896232321922
17297	2020-03-27 01:47:07	2020-03-27	Ms. Delma Farrell	ms.delma.farrell@geemail.com	San Antonio	Texas	3528387835067571341	e3e8df7bdb3d1317ee65d3289683becf	JCB 16 digit	29.5285317802406837	-98.447067745013527
17298	2020-03-27 01:49:26	2020-03-27	Winifred Reynolds	winifred.reynolds@woohoo.com	San Francisco	California	4380210407851554	0fb3eca5190ea9caa7c7120869296336	VISA 13 digit	37.7790954366616347	-122.428923104788794
17299	2020-03-27 01:51:31	2020-03-27	Venus Hermiston DVM	venus.hermiston.dvm@geemail.com	Fresno	California	3031217907124928	7fad9ce22e4a74f79746db79f30dd556	VISA 16 digit	36.7320231181908383	-119.828691435476401
17300	2020-03-27 01:52:54	2020-03-27	Miss Goldie Moore DVM	miss.goldie.moore.dvm@geemail.com	Oklahoma City	Oklahoma	53254403899565526	b8cb91d8fcec90242928c36fe6850390	JCB 16 digit	35.5070397219996892	-97.5589829365618471
17301	2020-03-27 02:14:53	2020-03-27	Zachery Hayes PhD	zachery.hayes.phd@geemail.com	Warren	Michigan	3088324645960285329	c529d2c2fe9c6cb70587ab038cab572e	Maestro	42.4206855231426658	-83.0702107934747005
17302	2020-03-27 02:38:45	2020-03-27	Jenny Shields	jenny.shields@geemail.com	San Francisco	California	3088527470982993312	b2075ba6d7de99afe0d136edb38eb4cd	VISA 13 digit	37.772832434062579	-122.415873208250346
17303	2020-03-27 02:40:00	2020-03-27	Buna Deckow	buna.deckow@geemail.com	Buffalo	New York	3714227718069738	fcb8b4612b5f4b325726d13096c62759	Mastercard	42.9084767832607028	-78.9297733875390151
17304	2020-03-27 02:56:12	2020-03-27	Chanelle Abshire	chanelle.abshire@warmmail.com	New York	New York	503853763562302	4df76d55f4c4696522e6869ea81bacdc	VISA 16 digit	40.6334386779218875	-73.9618918795034261
17305	2020-03-27 03:08:00	2020-03-27	Kaci Wolff	kaci.wolff@geemail.com	Kansas City	Missouri	4651920885407792	981f7da63cb02830dd93f0d408efeb8c	JCB 16 digit	39.1099711314611156	-94.5994655648935634
17306	2020-03-27 03:12:28	2020-03-27	Marlee Heaney	marlee.heaney@woohoo.com	Oakland	California	180096064533748399	24a02aa7e204d9afd4d37a4d9a163ac3	Discover	37.8332209704461206	-122.265339521105659
17307	2020-03-27 03:33:53	2020-03-27	Lorenzo Ledner	lorenzo.ledner@geemail.com	Wilmington	North Carolina	3702816507050265	1740334e8dee5fb17919413e9ea4665a	VISA 16 digit	34.2342593804288668	-77.9794404602136524
17308	2020-03-27 03:36:54	2020-03-27	Woodson Bradtke-Kihn	woodson.bradtke.kihn@woohoo.com	El Paso	Texas	52356569499106650	e4c97b036abf15cccca2c7d70206a4e5	American Express	31.7852068024981769	-106.348328868763531
17309	2020-03-27 04:03:05	2020-03-27	Soledad Streich-Ortiz	soledad.streich.ortiz@geemail.com	New York	New York	869975211776949789	5f4018be6ecd6d4fe0f1dcd00c190c99	Diners Club / Carte Blanche	40.644920986447481	-73.8758987883932861
17310	2020-03-27 04:14:32	2020-03-27	Walt Tromp	walt.tromp@geemail.com	Lexington	Kentucky	4371894449835187	12775fcf7148098fa4c2d5a7254711c8	VISA 16 digit	38.0519161775585246	-84.4264277057155965
17311	2020-03-27 04:16:04	2020-03-27	Charline Price	charline.price@woohoo.com	San Antonio	Texas	4544120416342854	7d46a9e374a396c9d4d158826dc7de18	VISA 16 digit	29.4019073359739025	-98.4376482062343428
17312	2020-03-27 04:22:17	2020-03-27	Alida Schamberger-Koepp	alida.schamberger.koepp@geemail.com	Memphis	Tennessee	4955255150422	127fab0ade12e9f1db8afbe473ceb9d1	Voyager	35.130444413476809	-90.0672351010866521
17313	2020-03-27 04:31:39	2020-03-27	Miss Geneva Abshire DVM	miss.geneva.abshire.dvm@warmmail.com	Antioch	California	3096049912184008604	0fba1e7b9eed07a135a555c58fbf3fe6	JCB 16 digit	38.0416224484130794	-121.728935588960354
17314	2020-03-27 04:37:13	2020-03-27	Kenyatta Powlowski	kenyatta.powlowski@geemail.com	Boise	Idaho	3158822383545375087	1f927631bf1855d556e1d3645de9768c	Diners Club / Carte Blanche	43.5782259404797117	-116.261579727214581
17315	2020-03-27 04:40:04	2020-03-27	Zeb Buckridge	zeb.buckridge@warmmail.com	Berkeley	California	3112316856785992219	363df096a6f8239827be9952fd8b39c9	JCB 16 digit	37.8550687941815127	-122.237432894932638
17316	2020-03-27 04:52:35	2020-03-27	Trevin Hane IV	trevin.hane.iv@geemail.com	Miami	Florida	3707852226130273	8c5a584ee4106f76b489e30932632a32	JCB 16 digit	25.6992209821145998	-80.1776377190709155
17317	2020-03-27 04:52:38	2020-03-27	Anaya Erdman	anaya.erdman@geemail.com	San Francisco	California	3015286651116055	cdd4926e0cd63559a3c3e9f4f4847216	American Express	37.7898881322956157	-122.429807739255452
17318	2020-03-27 04:54:32	2020-03-27	Ferne Nicolas	ferne.nicolas@geemail.com	Philadelphia	Pennsylvania	589398478132784	b4ecc0ebde2e1e3273cb60a8a635111e	American Express	40.0002399653620984	-75.2002731817674004
17319	2020-03-27 04:55:00	2020-03-27	Ammie Gulgowski	ammie.gulgowski@geemail.com	Davie	Florida	3012813791221231	52ea5c666d4c5003d9dacc292079bbbe	JCB 16 digit	26.0013288130316873	-80.2393621206656036
17320	2020-03-27 05:08:57	2020-03-27	Miss Valinda Wiza	miss.valinda.wiza@geemail.com	Little Rock	Arkansas	4820522976142	9e51013fd4760d0bfd009b858bc59cf7	VISA 16 digit	34.8161090474385801	-92.3460094909522695
17321	2020-03-27 05:21:32	2020-03-27	Miss Edythe Larson	miss.edythe.larson@warmmail.com	San Francisco	California	3761800685705732	652512ae3b1a3fbac39687d6296950ba	JCB 16 digit	37.7970169468792179	-122.434724585672328
17322	2020-03-27 05:22:10	2020-03-27	Yusuf Wolff	yusuf.wolff@geemail.com	Thornton	Colorado	4392843787306561	8108c7e1a4154470873220821e761690	JCB 16 digit	39.9092479152936548	-104.917990913630661
17323	2020-03-27 05:27:19	2020-03-27	Dr. Mariano Swaniawski	dr.mariano.swaniawski@warmmail.com	Phoenix	Arizona	675981772043907	61eb10b59491245525179e6947e64339	Diners Club / Carte Blanche	33.6254471354119531	-112.116159263665239
17324	2020-03-27 05:31:27	2020-03-27	Carlisle Konopelski	carlisle.konopelski@geemail.com	San Jose	California	676251906611788	6ad33426d61ff2f40e66c6fe7284eaa0	Diners Club / Carte Blanche	37.3288473305579274	-121.739406902458143
17325	2020-03-27 05:40:10	2020-03-27	Rose Koelpin	rose.koelpin@geemail.com	Fort Wayne	Indiana	869938384302988161	85170493a795b8bd03621c303ea200c9	JCB 15 digit	41.1623770844906574	-85.1199799580253682
17326	2020-03-27 05:55:23	2020-03-27	Gianna Lehner	gianna.lehner@geemail.com	Grand Rapids	Michigan	4576847291784831	82041060fce415f75ed474b0ee260878	VISA 16 digit	43.0421471492189909	-85.6603858797945179
17327	2020-03-27 06:06:15	2020-03-27	Dr. Zavion Jacobson	dr.zavion.jacobson@geemail.com	Lowell	Massachusetts	869908643780425491	baef2aee1171d2da9f95ff541bd08661	Diners Club / Carte Blanche	42.5925794395022095	-71.26413040844389
17328	2020-03-27 06:16:26	2020-03-27	Alexandria Ledner	alexandria.ledner@geemail.com	San Francisco	California	3005056937207386	b965f84f73025092d3068095751d53e8	JCB 16 digit	37.7949248673273814	-122.438274308418642
17329	2020-03-27 06:25:17	2020-03-27	Nelia Jast	nelia.jast@geemail.com	San Francisco	California	3088029422207742167	c75efcbcd328f2c83de0c1ec9e81275b	JCB 16 digit	37.7936416920579461	-122.405497771153705
17330	2020-03-27 06:26:57	2020-03-27	Dr. Tyreke Turcotte I	dr.tyreke.turcotte.i@geemail.com	Baltimore	Maryland	3112665044993083488	c1a9a635baacb791c88bb261558c9358	Discover	39.25039979419671	-76.5633299720026628
17331	2020-03-27 06:35:47	2020-03-27	Tula Block MD	tula.block.md@geemail.com	Sioux Falls	South Dakota	869911792740539944	06d4fa034177307058796819bc291dd7	JCB 16 digit	43.4878877234730865	-96.6864035339262387
17332	2020-03-27 06:46:52	2020-03-27	Anna Champlin	anna.champlin@geemail.com	Portland	Oregon	3528208675870825675	a6414772551bac76856026b399eb1130	Maestro	45.5346148992776847	-122.701436322322124
17333	2020-03-27 06:55:45	2020-03-27	Ms. Arielle Altenwerth DDS	ms.arielle.altenwerth.dds@woohoo.com	Dallas	Texas	52185512343860814	a56e2c262927908a3b83c3bc881dd9b6	JCB 16 digit	32.8365379540521687	-96.7315760119315229
17334	2020-03-27 06:58:11	2020-03-27	Miss Kerry Greenholt MD	miss.kerry.greenholt.md@geemail.com	Everett	Washington	210053330590714322	88c7ef052242932e298b26d6ca8dd321	Maestro	48.0169174795862332	-122.139434980706866
17335	2020-03-27 07:07:50	2020-03-27	Miss Delaney Kuvalis PhD	miss.delaney.kuvalis.phd@geemail.com	Kenosha	Wisconsin	210092169046579811	e6197f2139f789cc21abd7834d225b46	JCB 16 digit	42.6148560440938908	-87.8898645189352408
17336	2020-03-27 07:12:50	2020-03-27	Dr. Eliseo Bogan V	dr.eliseo.bogan.v@woohoo.com	San Diego	California	6011803974200064132	52c63ea5249e14df274107aec611a09d	JCB 16 digit	32.8569273812297737	-117.065997521663093
17337	2020-03-27 07:23:45	2020-03-27	Adrienne Rutherford	adrienne.rutherford@geemail.com	El Paso	Texas	3158426903506236489	9b4994921e2c81245af130eeb63f0c0e	Maestro	31.8147114910945312	-106.46462708092109
17338	2020-03-27 07:25:18	2020-03-27	Dr. Encarnacion Hagenes	dr.encarnacion.hagenes@geemail.com	Oakland	California	3777872165015066	de909216a5d612f7af1023a329fdf9fe	JCB 16 digit	37.8398859369874643	-122.265494730328442
17339	2020-03-27 07:47:05	2020-03-27	Audry Johnston-Hagenes	audry.johnston.hagenes@geemail.com	New York	New York	210061795523664499	681ec065bb9e9aa3792ba8fdc6e26973	VISA 16 digit	40.6016909396965033	-73.9254613947484671
17340	2020-03-27 07:47:52	2020-03-27	Milagros Senger-Kshlerin	milagros.senger.kshlerin@warmmail.com	Phoenix	Arizona	869991223342381207	a557b9abc1e368566e96445878fd9332	VISA 13 digit	33.5374744658291348	-112.144061766511214
17341	2020-03-27 07:50:55	2020-03-27	Prentiss Dibbert V	prentiss.dibbert.v@geemail.com	New York	New York	3112711076161691365	50ee728eb4336e4385c18dc94bd347be	VISA 13 digit	40.6210624669902032	-73.8670030909020454
17342	2020-03-27 07:57:24	2020-03-27	Dr. Salina Bednar	dr.salina.bednar@geemail.com	Long Beach	California	3528980388172198213	c569f65d462178d5ab8f77b808163f92	VISA 13 digit	33.7938877810079603	-118.20637904439792
17343	2020-03-27 08:02:43	2020-03-27	Mr. Conley Okuneva	mr.conley.okuneva@geemail.com	Philadelphia	Pennsylvania	4171319794750148	c4a18026991edee5296c4229311e2875	JCB 16 digit	39.92012473102249	-75.1040366470713252
17344	2020-03-27 08:05:22	2020-03-27	Katelynn Rau	katelynn.rau@geemail.com	Aurora	Colorado	3482991333610260	efe48bcc9737050d007c58fd1203d268	VISA 16 digit	39.644298497738319	-104.618128356582304
17345	2020-03-27 08:14:05	2020-03-27	Verdie Bruen-Heaney	verdie.bruen.heaney@geemail.com	Anaheim	California	3337639689637903211	1af1c5b2780e9e1cb8e47fae4c44258b	VISA 13 digit	33.8923563148193026	-117.692593866840369
17346	2020-03-27 08:29:08	2020-03-27	Jaylyn Mayer	jaylyn.mayer@geemail.com	Lincoln	Nebraska	3455288754306145	590e9ef2c710a6a46bd8cd63e5994b2c	Diners Club / Carte Blanche	40.833199023550371	-96.7217038395974811
17347	2020-03-27 08:39:57	2020-03-27	Natalya Harber	natalya.harber@geemail.com	Olathe	Kansas	6011404886073628541	0632e3977131fa93c00eac5c381f516d	VISA 16 digit	38.7843723844394148	-94.7725384379439078
17348	2020-03-27 08:58:52	2020-03-27	Treyton Bednar	treyton.bednar@geemail.com	Phoenix	Arizona	210090360582999826	9ad32c4d25ce9153216e47faff44de38	JCB 15 digit	33.5845421177268051	-112.153020102244255
17349	2020-03-27 09:02:46	2020-03-27	Golden Willms	golden.willms@woohoo.com	New York	New York	3017809043350013	e5b4e944fe1b8dd327eee80fd913f01d	American Express	40.5852899218667318	-73.8967692758318009
17350	2020-03-27 09:06:21	2020-03-27	Carrol Nicolas	carrol.nicolas@geemail.com	Plano	Texas	4902902426507816	bdba46794a7238b806cf2d742af0ee20	Maestro	33.0490985590584572	-96.8336664113398626
17351	2020-03-27 09:13:04	2020-03-27	Dr. Kellan Sanford DVM	dr.kellan.sanford.dvm@woohoo.com	San Francisco	California	3023908345508999	c844bafa2f670bed9fc925b58bcd7018	Diners Club / Carte Blanche	37.7733201284745448	-122.46963923772347
17352	2020-03-27 09:26:52	2020-03-27	Buel Frami	buel.frami@geemail.com	San Francisco	California	3088498028707998068	22186ca3b5303908c003d24319b291bd	Maestro	37.7743639773400943	-122.435432988931424
17353	2020-03-27 09:35:20	2020-03-27	Evia Funk	evia.funk@geemail.com	San Francisco	California	3743947674334033	60a7dbf6a15f4ff671dac00150bcc2e9	Discover	37.7537063045083627	-122.444062339555401
17354	2020-03-27 10:11:12	2020-03-27	Marta Schulist	marta.schulist@geemail.com	Houston	Texas	55665033615247704	e4e18d96dcf90055144b816d139baba1	JCB 16 digit	29.7865996221624307	-95.2995291383020628
17355	2020-03-27 10:12:19	2020-03-27	Luanne Smitham-Little	luanne.smitham.little@geemail.com	Jacksonville	Florida	210060663167409608	13729d3177ccf3012d2fc912f3328763	VISA 16 digit	30.2893679396301501	-81.6040462838564196
17356	2020-03-27 10:27:41	2020-03-27	Patrice Rempel	patrice.rempel@geemail.com	Topeka	Kansas	180098385208365997	c1f83e2539a26aed39c4a6dc8b94050b	Maestro	39.0794046192828546	-95.6242277638230576
17357	2020-03-27 10:35:08	2020-03-27	Stacy Romaguera PhD	stacy.romaguera.phd@geemail.com	Boston	Massachusetts	3158492164764613666	4d7ab19297a968d774ed32c1d54f266d	VISA 16 digit	42.3636637296695255	-71.0216823013916638
17358	2020-03-27 10:39:50	2020-03-27	Dorsey Keeling-Hilll	dorsey.keeling.hilll@geemail.com	Houston	Texas	3012103471459917	b94c1228446dcbc1ff0605709661223d	VISA 16 digit	29.8720810797609388	-95.4350121994517764
17359	2020-03-27 10:49:44	2020-03-27	Shanice Schroeder	shanice.schroeder@geemail.com	Peoria	Illinois	4831681099899	cd3543c90bc8117db628ccd657b0a1a9	Maestro	40.7674927450120421	-89.6738343242906097
17360	2020-03-27 10:51:34	2020-03-27	Infant Jenkins	infant.jenkins@geemail.com	Washington	District of Columbia	3016110308755637	e5eaf3b0d153a60ddc6039cf2876fa3b	JCB 16 digit	38.8236148135535402	-77.0091726403895791
17361	2020-03-27 11:16:10	2020-03-27	Kaaren Gutkowski	kaaren.gutkowski@geemail.com	Joliet	Illinois	3337618942039839565	c652e9c2d99aaecbcfe8ae62d0933bff	American Express	41.4450983891122036	-88.1717198977816849
17362	2020-03-27 11:24:48	2020-03-27	Lavern Boehm	lavern.boehm@geemail.com	Oakland	California	3403763100155266	fa5974b40cb1c7cb3acc2f549fff4b48	JCB 15 digit	37.7773800942826128	-122.25738833401752
17363	2020-03-27 11:32:15	2020-03-27	Mr. Marquis Nolan I	mr.marquis.nolan.i@geemail.com	Meridian	Idaho	3088868828754585284	03c353c8a13facd4c044617bce53181a	Diners Club / Carte Blanche	43.6272007990170252	-116.402091199293352
17364	2020-03-27 11:59:35	2020-03-27	Dr. Matilde Hagenes DVM	dr.matilde.hagenes.dvm@geemail.com	San Francisco	California	6011790205247604860	e15f5e38e589ebe94bc5e8099874fbaf	Diners Club / Carte Blanche	37.7353895443418565	-122.403553679711095
17365	2020-03-27 11:59:36	2020-03-27	Miss Patti Fahey	miss.patti.fahey@warmmail.com	Oakland	California	3033562810271789	7e797b2b2230f90cee6d9c46bdf75c71	Maestro	37.8384434725760812	-122.288726425670475
17366	2020-03-27 12:03:24	2020-03-27	Dorcas Heidenreich	dorcas.heidenreich@geemail.com	Phoenix	Arizona	676170806458983	e23fcf31fe6186a3fc13e3cc126c4aba	JCB 16 digit	33.6663522964276396	-112.014477266410751
17367	2020-03-27 12:10:29	2020-03-27	Harvy McDermott	harvy.mcdermott@geemail.com	Springfield	Massachusetts	210001134740056474	8d7863d01df7570d4e17a6e6ba9ee936	JCB 16 digit	42.1627032333258498	-72.614030854087332
17368	2020-03-27 12:15:28	2020-03-27	Kinsley Feest	kinsley.feest@geemail.com	San Francisco	California	53892718712950615	8e94f30e5dd16aabb217f7b1e8b27e40	JCB 15 digit	37.7808188832541134	-122.429347417034236
17369	2020-03-27 12:30:51	2020-03-27	Bernadette Friesen	bernadette.friesen@geemail.com	San Francisco	California	52960215692583059	66ae2f8d7e893b3b0e66a83072bb2e5a	JCB 15 digit	37.7903044392122993	-122.445831853287856
17370	2020-03-27 12:31:08	2020-03-27	Ica Mills	ica.mills@geemail.com	New York	New York	4441329304650336	67168c9ba59544107d367c88a4702e54	JCB 15 digit	40.675584116833285	-73.8746927920624614
17371	2020-03-27 13:19:23	2020-03-27	Bertie Gaylord-Walter	bertie.gaylord.walter@geemail.com	Anchorage	Alaska	502065377566511	7752212b8b197768f0b9e17da546a0ce	JCB 15 digit	61.124718577063831	-149.263593645685546
17372	2020-03-27 13:34:35	2020-03-27	Dr. Dondre Huel	dr.dondre.huel@warmmail.com	Oakland	California	639070216990252	8f01c54fe1264a67700d9ecb24b9e068	VISA 16 digit	37.7829380948745097	-122.273766514141528
17373	2020-03-27 14:04:58	2020-03-27	Fernanda Corwin	fernanda.corwin@geemail.com	San Antonio	Texas	4569112739704613	7c06168d8785dcf3aa50f024fa5e6076	Discover	29.3952916326072078	-98.5278151336893444
17374	2020-03-27 14:19:39	2020-03-27	Eliza Graham	eliza.graham@geemail.com	Grand Rapids	Michigan	869979735142577789	252b4ff3b59f86e3434deac33fb654a7	Diners Club / Carte Blanche	42.8922649911407348	-85.5752386037394501
17375	2020-03-27 14:27:47	2020-03-27	Fremont Nicolas	fremont.nicolas@geemail.com	San Francisco	California	3496630843990937	62f4ae609860622d527f0988f80369a2	VISA 13 digit	37.7554721697125686	-122.419930076322203
17376	2020-03-27 14:39:45	2020-03-27	Orah Tillman DVM	orah.tillman.dvm@geemail.com	Murrieta	California	869970298708788166	4ad16bfb1d8aeadb1238f07cd9d5a21c	Discover	33.6718196665499363	-117.234385999375576
17377	2020-03-27 14:50:00	2020-03-27	Mr. Devin Nienow V	mr.devin.nienow.v@geemail.com	Berkeley	California	3737920547726386	9d23db3197c046e623d4a55384a79f7f	VISA 16 digit	37.8819491551841523	-122.270040031513531
17378	2020-03-27 14:51:41	2020-03-27	Evander Deckow	evander.deckow@woohoo.com	Phoenix	Arizona	6011375710773815767	266394fd661ccd809ddf065d5d0a2e8f	Discover	33.5981155915118777	-112.174880241362757
17379	2020-03-27 14:52:46	2020-03-27	Dionte Dooley Jr.	dionte.dooley.jr.@geemail.com	Pearland	Texas	3158011580497232114	4a2e59bc7d415708d9bf5db8b0a7f16c	VISA 16 digit	29.5194778631247594	-95.2410580838885181
17380	2020-03-27 14:54:14	2020-03-27	Americo Wehner	americo.wehner@geemail.com	Baltimore	Maryland	3043379477235712	c1d360d4a09c06ab05c7ac822d61627f	Diners Club / Carte Blanche	39.2720931969117331	-76.5716923814285622
17381	2020-03-27 15:07:24	2020-03-27	Dr. Kaye Torp	dr.kaye.torp@geemail.com	Tyler	Texas	869965880883698729	a41b222926b90f0d066956c8efbfa9c9	VISA 16 digit	32.2848074387341768	-95.3028055824447335
17382	2020-03-27 15:07:48	2020-03-27	Jeb Windler	jeb.windler@woohoo.com	Winston–Salem	North Carolina	3112416211039282760	facd9ea4c121074c8267331bb0ae3ba1	Maestro	36.0322591370668235	-80.2180740247145252
17383	2020-03-27 15:08:57	2020-03-27	Nick Fadel	nick.fadel@woohoo.com	Columbus	Ohio	54816685644057715	b85c273f5368bcfbaab86c17aa58b83f	VISA 16 digit	39.9073452387981078	-83.033895529969783
17384	2020-03-27 15:09:35	2020-03-27	Mr. Delbert Abshire	mr.delbert.abshire@geemail.com	Ann Arbor	Michigan	869999734448869574	1c36ae6f2fa9569f289c5b9458981dec	VISA 16 digit	42.3277288745682654	-83.7613187397472672
17385	2020-03-27 15:20:51	2020-03-27	Mr. Nathanial Ward V	mr.nathanial.ward.v@woohoo.com	Arlington	Texas	51514771187665315	aee7c0613178224af7a104596cc79e5e	VISA 16 digit	32.6029893445566259	-97.127490359547366
17386	2020-03-27 15:33:50	2020-03-27	Buren Batz	buren.batz@geemail.com	Laredo	Texas	869918156795109032	e37a68ec4e176e86c831727c6cd49f56	JCB 16 digit	27.5130236985344467	-99.3915093546275017
17387	2020-03-27 15:53:05	2020-03-27	Norine Brakus	norine.brakus@geemail.com	Phoenix	Arizona	210012966852361250	e871d0dd2af583d803f73fcdb0dd49fb	Discover	33.6294555616963677	-112.056169355094809
17388	2020-03-27 16:06:35	2020-03-27	Minna Schoen DDS	minna.schoen.dds@geemail.com	Fontana	California	502088152788662	b7d23add6f3daa5e16a19ab62d873d5b	JCB 15 digit	34.0090826278701428	-117.417537964349251
17389	2020-03-27 16:11:39	2020-03-27	Branden Zulauf	branden.zulauf@woohoo.com	Nashville	Tennessee	639088126090039	61d14fba08b4a34020154fc176402c0b	Mastercard	36.215336920100448	-86.7628606149367982
17390	2020-03-27 16:22:46	2020-03-27	Blanchie Crooks	blanchie.crooks@geemail.com	Stamford	Connecticut	6011327820460313957	f6f5bdf300c1d56d5a8089b2aa5e2bf0	Mastercard	41.1425909129321568	-73.6432839983645948
17391	2020-03-27 16:25:15	2020-03-27	Nira Mosciski	nira.mosciski@geemail.com	Naperville	Illinois	210036158329178309	af10f09c48e8332be10aea0246c3d55c	JCB 15 digit	41.8251195553604518	-88.0973152648545863
17392	2020-03-27 16:54:31	2020-03-27	Dr. Mario Kiehn	dr.mario.kiehn@geemail.com	San Francisco	California	3408496048985628	ff9f366b6000d3c8350ea90e215401f2	American Express	37.7424734727247326	-122.441803139518754
17393	2020-03-27 17:12:29	2020-03-27	Mrs. Yasmeen Langworth	mrs.yasmeen.langworth@geemail.com	Los Angeles	California	3038294495521818	e12b1bc93968b711705bd532731fc95f	Maestro	34.06950415627621	-118.450077401054273
17394	2020-03-27 17:18:49	2020-03-27	Dereon Keeling	dereon.keeling@warmmail.com	Bakersfield	California	676286817793663	950acb6bd4df862227fbcd1e80f09da9	VISA 16 digit	35.2665511906322067	-118.949718295111509
17395	2020-03-27 17:56:34	2020-03-27	Evans Connelly	evans.connelly@warmmail.com	Charleston	South Carolina	3044872480581691	a16505908c08526e4dc34d3921f36797	Mastercard	32.831935222586246	-79.9993686251491312
17396	2020-03-27 18:05:40	2020-03-27	Georgia Streich	georgia.streich@geemail.com	New York	New York	3337654119521468329	b4d95c7a4dacb056590512cc9635d3ae	JCB 16 digit	40.7156740166004738	-74.0013219122670591
17397	2020-03-27 18:19:33	2020-03-27	Vonetta Schuppe	vonetta.schuppe@geemail.com	San Francisco	California	3056927692579913	3cd14361010c17446a83ab9868700895	JCB 16 digit	37.7772660391757142	-122.440196010030405
17398	2020-03-27 18:21:29	2020-03-27	Aubra Dietrich	aubra.dietrich@geemail.com	Chattanooga	Tennessee	52958324660835824	1a64ea11e6ff8c3464f99ee2604bfa66	Discover	34.9749198313187861	-85.3074000053867678
17399	2020-03-27 18:39:20	2020-03-27	Mrs. Eveline Fadel	mrs.eveline.fadel@woohoo.com	Berkeley	California	3055146708323320	6b4e9b337a67ed472d7c30d3bc45c7c0	American Express	37.8683186385436059	-122.266923897196705
17400	2020-03-27 18:41:49	2020-03-27	Olin Jacobs I	olin.jacobs.i@geemail.com	St. Louis	Missouri	180065389702621912	2316bd7552834f08374a80059804587e	JCB 16 digit	38.6935483163844793	-90.2961003981068728
17401	2020-03-27 18:54:47	2020-03-27	Dr. Jeremy Fisher PhD	dr.jeremy.fisher.phd@geemail.com	Charleston	South Carolina	4025210568802546	742b4e6b4f10c4bc0708456860c6ebdf	JCB 16 digit	32.9074497986115517	-80.008093801248819
17402	2020-03-27 18:58:25	2020-03-27	Dr. Ples Weimann	dr.ples.weimann@warmmail.com	Oakland	California	55663056037516887	1e2f7bf41e1f6bb40690dad83324e01f	JCB 15 digit	37.7998482305126942	-122.270157919539272
17403	2020-03-27 19:01:08	2020-03-27	Marilla Kemmer	marilla.kemmer@geemail.com	San Francisco	California	4774166687855	3b72a91ce1b9ad1bcd41da73bbb7e454	Voyager	37.7895420350994655	-122.409344731039809
17404	2020-03-27 19:18:31	2020-03-27	Alexandre Treutel	alexandre.treutel@geemail.com	Allen	Texas	4517425555281372	3a8c37384e26674c5b5d7ed79eb46f2b	JCB 15 digit	33.0420756438773111	-96.7387678847596106
17405	2020-03-27 19:35:06	2020-03-27	Mr. Reinhold Heathcote	mr.reinhold.heathcote@geemail.com	Seattle	Washington	180049235182000344	8316b796ea5d18a812f638b72cdaf25e	VISA 16 digit	47.6150372533984481	-122.261177077276258
17406	2020-03-27 19:56:31	2020-03-27	Nelle Bins	nelle.bins@geemail.com	Hialeah	Florida	6011106599980982981	724cd9979c1444d342fcab814d634049	Maestro	25.9385187893152249	-80.2780621321774959
17407	2020-03-27 20:00:34	2020-03-27	John DuBuque	john.dubuque@geemail.com	Roseville	California	3528408622786000611	9f2d0c91aa93779d2db4b6892d8667fb	JCB 15 digit	38.7078667752034917	-121.276117092579227
17408	2020-03-27 20:10:21	2020-03-27	Arizona Brekke	arizona.brekke@geemail.com	Nashville	Tennessee	4380094928104	2f344d854c53d1595c6993766d2d4305	Maestro	36.1367851272813922	-86.6997056562360342
17409	2020-03-27 20:15:36	2020-03-27	Shamar Graham DVM	shamar.graham.dvm@geemail.com	Henderson	Nevada	4215206657563809	32d6242536ee5f50c5dd92be6e04f4e3	VISA 13 digit	36.0478646706722685	-114.942194271103304
17410	2020-03-27 20:30:51	2020-03-27	Beatrix VonRueden	beatrix.vonrueden@geemail.com	Los Angeles	California	869944791242649756	5c78d6b01762b032daea5b86997695c1	Discover	34.0973939258005458	-118.4203092812553
17411	2020-03-27 20:46:31	2020-03-27	Mrs. Lorenza Beier	mrs.lorenza.beier@geemail.com	Omaha	Nebraska	6011486990120314807	8dd14aacd4d58bedc7156ce6a4052bc0	VISA 16 digit	41.2180443062126685	-95.9695481106754471
17412	2020-03-27 20:53:25	2020-03-27	Rhett Leannon Sr.	rhett.leannon.sr.@geemail.com	Mobile	Alabama	3059618565237120	5c13233065d7a593761bc0a8989186d8	JCB 16 digit	30.6518056499414122	-88.141667530373482
17413	2020-03-27 20:57:36	2020-03-27	Ms. Loretto Ortiz MD	ms.loretto.ortiz.md@geemail.com	Chicago	Illinois	4839492378972729	d4f959cbeeb7cfd54f0425624772a4e3	Diners Club / Carte Blanche	41.8433263244409162	-87.6480821067962808
17414	2020-03-27 21:01:09	2020-03-27	Mr. Storm Flatley	mr.storm.flatley@geemail.com	Austin	Texas	3796093803905199	c851661304e9f41325a8d26d81dd0eae	Maestro	30.3780506084334085	-97.8195045548729638
17415	2020-03-27 21:02:41	2020-03-27	Mrs. Sheryll Langworth	mrs.sheryll.langworth@geemail.com	San Francisco	California	4920059932235	0900f2c40f5556e866951818777d156c	JCB 16 digit	37.8280609316923986	-122.447593018668414
17416	2020-03-27 21:15:19	2020-03-27	Dr. Alvie Kuhn	dr.alvie.kuhn@geemail.com	Miramar	Florida	630407456707624	03b75032047332d483ae19f6ea3de5e2	Maestro	25.9712148242145773	-80.3118858103167383
17417	2020-03-27 21:18:28	2020-03-27	Renard Cassin	renard.cassin@geemail.com	San Mateo	California	3056698691593946	9512e5d1e94191ef2131102eb510d58e	JCB 16 digit	37.6579335308980205	-122.392249967795237
17418	2020-03-27 21:44:47	2020-03-27	Heriberto Walsh	heriberto.walsh@woohoo.com	Los Angeles	California	869955627706503640	c6087dfe7a533213daef08ca9c551788	JCB 15 digit	34.0405003503296513	-118.4648618777275
17419	2020-03-27 21:57:20	2020-03-27	Sharee Gutkowski DVM	sharee.gutkowski.dvm@geemail.com	Irving	Texas	3096173247507156543	3dbb28aa4ae46b8b21ba3f44dc8210c5	JCB 15 digit	32.7594972963396458	-96.930519371135162
17420	2020-03-27 22:54:37	2020-03-27	Michial Grady	michial.grady@geemail.com	Philadelphia	Pennsylvania	4987127890836	315534072475e84a3dae56fcb29e05f9	VISA 16 digit	39.9802009876310791	-75.1371749306462817
17421	2020-03-27 23:06:00	2020-03-27	Yulissa Muller	yulissa.muller@geemail.com	Nashville	Tennessee	3005455028717891	f873e9c3c2bf4b70b452036e6c86f186	JCB 16 digit	36.1974464775186036	-86.6858469162974501
17422	2020-03-27 23:11:45	2020-03-27	Dwyane Borer DDS	dwyane.borer.dds@warmmail.com	Springfield	Missouri	3528368821838124845	6482c778d8665a0dc544042c3b1d3570	Maestro	37.2253847146134831	-93.3030778526153455
17423	2020-03-27 23:15:05	2020-03-27	Luciana Abbott MD	luciana.abbott.md@geemail.com	Oakland	California	3055690972970696	3aaa29e0ffc869854a0f9f9f952ed70a	VISA 13 digit	37.7997044883911855	-122.31163691330292
17424	2020-03-27 23:28:35	2020-03-27	Kasey Bernhard	kasey.bernhard@geemail.com	San Francisco	California	503889490201517	a293d74fb68ab716b64ba7a5e7fd9a59	VISA 16 digit	37.7822944302831374	-122.4660631511411
17425	2020-03-27 23:37:22	2020-03-27	Latanya Mills	latanya.mills@geemail.com	San Francisco	California	3497798577936142	a9a8b9f4e0ce4237e99f08882716c89c	VISA 13 digit	37.7808734870983685	-122.464516059965504
17426	2020-03-27 23:38:31	2020-03-27	Dr. Davey Hessel DVM	dr.davey.hessel.dvm@warmmail.com	Las Vegas	Nevada	3757389091877935	cc3f568f3b1e42cf8d795fd87621a475	Voyager	36.1753637294385584	-115.299295730863136
17427	2020-03-27 23:40:08	2020-03-27	Clement Conn	clement.conn@geemail.com	Garland	Texas	869911130468709698	467cf7fb58ecc422f327d4f83b0126de	Discover	32.8153979664437472	-96.6088022497177121
17428	2020-03-27 23:40:49	2020-03-27	Hermon Parker	hermon.parker@woohoo.com	Virginia Beach	Virginia	869919170826975997	baa4782c0842803e92bb50d00db6395c	JCB 16 digit	36.7399956735037279	-76.0790115777075329
17429	2020-03-28 00:03:29	2020-03-28	Letitia Goyette	letitia.goyette@geemail.com	Glendale	Arizona	4665060230674400	9576542b6bacb0e0600bf9698ec9e1fc	JCB 16 digit	33.4446033929701869	-112.152719919781759
17430	2020-03-28 00:14:23	2020-03-28	Mya Dooley	mya.dooley@geemail.com	San Francisco	California	3033255958654409	4d6c00a1c4a1be4d3d9af0ec806a2011	American Express	37.7520103043692217	-122.44075815910152
17431	2020-03-28 00:20:18	2020-03-28	Theadore Predovic	theadore.predovic@geemail.com	Aurora	Illinois	3446630744056250	f7c1859833abbb40be65f912886a49e7	Maestro	41.7417580738887182	-88.3358055975217269
17432	2020-03-28 00:38:56	2020-03-28	Elian McDermott	elian.mcdermott@woohoo.com	Jacksonville	Florida	210041554887018601	425fe27c31589ea4d63e440d090dc4c1	JCB 16 digit	30.2434520339645445	-81.581007501583926
17433	2020-03-28 00:41:52	2020-03-28	Kristoffer Effertz	kristoffer.effertz@geemail.com	San Antonio	Texas	4595654960632334	b6bcc8b02831f1e989d94a2eff92eeeb	Voyager	29.4958000513330099	-98.6114788016140409
17434	2020-03-28 00:57:23	2020-03-28	Dr. Russell Christiansen I	dr.russell.christiansen.i@warmmail.com	New York	New York	51095461000143016	f0943351fca18e0dc1ab596ea8847a34	American Express	40.5654707052968462	-73.9881762732647275
17435	2020-03-28 01:01:08	2020-03-28	Sanford Lowe	sanford.lowe@geemail.com	Los Angeles	California	630447265020496	0bdb29c1a41cffad0a14922c67d4fa13	Discover	34.0320476870849689	-118.4955182850819
17436	2020-03-28 01:03:44	2020-03-28	Tai Collier PhD	tai.collier.phd@woohoo.com	Elk Grove	California	6011528244589349643	dd6dcb4870d69401a4fd34b1ee3135cb	Voyager	38.4729450146950782	-121.439357777722179
17437	2020-03-28 01:21:02	2020-03-28	Greg Weber	greg.weber@geemail.com	Nashville	Tennessee	3112752413828150230	18986627d15a27deb311a692e3a5b691	Discover	36.2142458464607557	-86.7554656266607367
17438	2020-03-28 01:22:34	2020-03-28	Dr. Nicolette Feeney MD	dr.nicolette.feeney.md@geemail.com	Santa Ana	California	4726685948168	6ac4f105d5e8768e5ef1d03d5a2079be	Maestro	33.782125679320842	-117.94476495072432
17439	2020-03-28 01:23:27	2020-03-28	Jamarcus Rogahn-Kilback	jamarcus.rogahn.kilback@geemail.com	Louisville	Kentucky	53811142585481038	ff7d54d49d9b67551d154426a3cf29f3	Mastercard	38.1508171024169727	-85.6218837968144584
17440	2020-03-28 01:29:46	2020-03-28	Colter Nader	colter.nader@geemail.com	Columbus	Georgia	3088939504864827735	e41bf55ebd3769ee5b10419d7daabc96	VISA 16 digit	32.5701057011771908	-84.8469254961866852
17441	2020-03-28 01:54:30	2020-03-28	Hiroshi Littel	hiroshi.littel@geemail.com	Dallas	Texas	4297464799866926	4cededf6712abcaa3f9a42df91f694a9	JCB 15 digit	32.8084715875603266	-96.8185663498900766
17442	2020-03-28 01:56:24	2020-03-28	Mr. Dominic Davis DVM	mr.dominic.davis.dvm@geemail.com	Austin	Texas	675940091601605	b15cc810b5e3a8417a748e9d2299e4ee	Diners Club / Carte Blanche	30.359708907328173	-97.7890733064856477
17443	2020-03-28 01:59:11	2020-03-28	Rollie Koelpin-Adams	rollie.koelpin.adams@geemail.com	Sacramento	California	3711010073840742	4763f6baed019730b61778d1d24ed90a	Discover	38.6568868700679431	-121.515929324297602
17444	2020-03-28 02:01:46	2020-03-28	Crysta Little	crysta.little@geemail.com	Kansas City	Missouri	3112703859397924506	c845c117987fcbe3de0cb9bfe9bb0d70	Maestro	39.0476889319088372	-94.6206901350282124
17445	2020-03-28 02:05:37	2020-03-28	Delmer Boyer	delmer.boyer@geemail.com	Fort Worth	Texas	4489473370859018	b1ce1cfe3c5dcbf9cad72e1b0ea9d0d7	Diners Club / Carte Blanche	32.8507236782051635	-97.4039921809740292
17446	2020-03-28 02:37:01	2020-03-28	Mekhi Quitzon	mekhi.quitzon@geemail.com	Greensboro	North Carolina	3088459676863397785	430192c55147c07f89f59290998caf13	Diners Club / Carte Blanche	36.1102391410268879	-79.7291731351036503
17447	2020-03-28 02:44:31	2020-03-28	Brooklyn Lemke	brooklyn.lemke@woohoo.com	San Francisco	California	3028360233370386	387219b4fff78654c3ed8ea74c8726a5	Voyager	37.7858276326421745	-122.445789783504196
17448	2020-03-28 03:01:08	2020-03-28	Dakota Glover	dakota.glover@geemail.com	Salinas	California	4496656822001780	c9bff27f9407d4cb79d801591c5743dc	JCB 16 digit	36.7066454323239597	-121.670520051539697
17449	2020-03-28 03:01:49	2020-03-28	Lenna Ondricka PhD	lenna.ondricka.phd@geemail.com	San Francisco	California	4276423355743361	d3166a305d28238a176a44443f06d63d	VISA 13 digit	37.7860746232694851	-122.449985240318924
17450	2020-03-28 03:05:55	2020-03-28	Lulie Tromp	lulie.tromp@woohoo.com	Vallejo	California	4445137372345	54a6258f686a63d7f11a72b202ed6df8	JCB 16 digit	38.1053851793143892	-122.29953194636478
17451	2020-03-28 03:07:16	2020-03-28	Renaldo Stroman-Lubowitz	renaldo.stroman.lubowitz@geemail.com	Long Beach	California	3490502676399807	b5830a294c46125cdc2d110458adb8a4	Discover	33.8806100122451781	-118.236087421250716
17452	2020-03-28 03:19:10	2020-03-28	Madison Champlin DDS	madison.champlin.dds@warmmail.com	Tampa	Florida	3744012659350816	5d6f09c22af47c0e8c47607b6fb7d6d4	American Express	27.9450435487668933	-82.5486587676431895
17453	2020-03-28 03:20:25	2020-03-28	Madonna Renner	madonna.renner@geemail.com	San Francisco	California	3158469540377836381	bf0663a88a2e843c8543f94f35392168	VISA 16 digit	37.7729261218706611	-122.419226992153284
17454	2020-03-28 03:29:47	2020-03-28	Kalen Gorczany	kalen.gorczany@geemail.com	Vancouver	Washington	3058862041201919	57918be17da6111250eb5b370b866512	Diners Club / Carte Blanche	45.5417204525392521	-122.610899633780861
17455	2020-03-28 03:33:26	2020-03-28	Barbara Olson	barbara.olson@warmmail.com	Rancho Cucamonga	California	869931818196202517	2ffc0c59a8ba8ab480c6ba647b494fdb	VISA 16 digit	34.1703937506761406	-117.505298475363105
17456	2020-03-28 03:34:05	2020-03-28	Dr. Diego Schulist DVM	dr.diego.schulist.dvm@geemail.com	Phoenix	Arizona	3774636118506270	4b6fe9fbbd9a0ebf7c4dadaebf3d707b	Discover	33.5713256423294553	-112.102300491596026
17457	2020-03-28 03:34:11	2020-03-28	Baron Bogisich	baron.bogisich@woohoo.com	Oakland	California	3337168815387304438	ff0e0e4a323c2920239bd967d08d688e	Voyager	37.8325810348092517	-122.262246519659669
17458	2020-03-28 03:39:50	2020-03-28	Judi Cormier	judi.cormier@geemail.com	Philadelphia	Pennsylvania	4507382963221973	ae7f667669ad5adc8b7f09447843ad2a	JCB 16 digit	40.1072158439509536	-75.0679245670225583
17459	2020-03-28 04:16:04	2020-03-28	Romie Douglas	romie.douglas@woohoo.com	Chicago	Illinois	3019326652050923	dc5827b41ee1ea704ddab3dcb56eda03	JCB 15 digit	41.8567761981695909	-87.7712708252511931
17460	2020-03-28 04:16:25	2020-03-28	Dr. Eino Schneider	dr.eino.schneider@geemail.com	San Francisco	California	676377318011655	b096d6dd22bdd052a8a91081df16dde3	VISA 16 digit	37.7697857996598998	-122.430895689210075
17461	2020-03-28 04:36:00	2020-03-28	Ms. Lonnie Baumbach MD	ms.lonnie.baumbach.md@geemail.com	Sacramento	California	4872693432965827	2898e695aab59e6af5eee423cfab32ef	Voyager	38.5866883295387026	-121.43688772868029
17462	2020-03-28 04:48:16	2020-03-28	Maria Smitham PhD	maria.smitham.phd@geemail.com	Chesapeake	Virginia	676394431066144	1c37af446c5e2b6a5d189c0adb1ee566	VISA 16 digit	36.7380531057488184	-76.2974720955669881
17463	2020-03-28 04:58:45	2020-03-28	Sharde Harris-Ernser	sharde.harris.ernser@warmmail.com	Ontario	California	4085870080065661	790cad95ccc281ea828e5dcd1019001f	Discover	34.1167581793531767	-117.537451095470047
17464	2020-03-28 05:15:48	2020-03-28	Assunta Kris	assunta.kris@woohoo.com	Los Angeles	California	4019860240536520	a8b195c3e35752f6a22a6febc4a92996	Diners Club / Carte Blanche	33.9813833098258797	-118.313603932270027
17465	2020-03-28 05:17:40	2020-03-28	Dr. Konnor West Jr.	dr.konnor.west.jr.@geemail.com	Pasadena	California	4792358086087891	9b136d8af347181c3b6deef446af53e6	Voyager	34.0712323957908936	-118.079659485612439
17466	2020-03-28 05:38:23	2020-03-28	Mr. Cash Hammes	mr.cash.hammes@woohoo.com	Columbus	Ohio	3337982681891372418	70196e6a640c548ee49406a249c58065	JCB 16 digit	40.0545880554288587	-82.9555479369360995
17467	2020-03-28 05:50:17	2020-03-28	Falon Zieme	falon.zieme@geemail.com	New York	New York	3437431102279530	58a9ef1c5c5583b1ec8cc4887fe4367f	Maestro	40.7606312654204643	-74.0197846042353689
17468	2020-03-28 05:57:01	2020-03-28	Alex Klocko	alex.klocko@geemail.com	Olathe	Kansas	6011459186055313947	8928455bae845f9d18b9e3357207027e	JCB 15 digit	38.7959966881323624	-94.7783918006979036
17469	2020-03-28 05:59:11	2020-03-28	Davis Murray DDS	davis.murray.dds@geemail.com	Fairfield	California	4005170751662	67f721ec9a11d9998c3c1821678e906f	JCB 16 digit	38.3148192537605823	-122.053189594485232
17470	2020-03-28 06:15:44	2020-03-28	Louanna Steuber DVM	louanna.steuber.dvm@geemail.com	Oakland	California	4154769232500	b79d48dc8099abeffa18c0a126ade280	JCB 16 digit	37.8478375728355445	-122.282993196394742
17471	2020-03-28 06:19:58	2020-03-28	Khari Grady DVM	khari.grady.dvm@warmmail.com	El Paso	Texas	6011645824077472607	8fbe6ef8130385ca9b7a8cd464b04098	VISA 16 digit	31.7990202439311922	-106.357329209705824
17472	2020-03-28 06:32:51	2020-03-28	Jaylan Howe-Lind	jaylan.howe.lind@warmmail.com	San Francisco	California	180097708801021983	234886cd1bb3a15d240393249e9e5dab	Mastercard	37.78816703012847	-122.450243910274708
17473	2020-03-28 06:34:00	2020-03-28	Lesly Frami	lesly.frami@woohoo.com	Rochester	New York	3760354513256824	63454d5782e154b2e5a70ace0b726186	VISA 16 digit	43.2428188175871924	-77.5500264068838163
17474	2020-03-28 06:38:36	2020-03-28	Wilbert Tillman	wilbert.tillman@woohoo.com	Chicago	Illinois	869909000870693646	dd0f71352b68559fc7c8af41dd5293d3	Diners Club / Carte Blanche	41.7638746603228199	-87.6458077499207064
17475	2020-03-28 06:39:37	2020-03-28	Wright Feest	wright.feest@warmmail.com	Fresno	California	51969793558193693	f543931760540d3319aef58fc42d0d08	JCB 15 digit	36.8189077865205689	-119.740173010166373
17476	2020-03-28 07:16:06	2020-03-28	Drew Schumm	drew.schumm@geemail.com	Santa Clarita	California	51194042449835725	f6a6a8b46315f0344833b5fcd3c50a3e	JCB 15 digit	34.3601945790201384	-118.422663874422014
17477	2020-03-28 07:31:24	2020-03-28	Robby Nitzsche-Lind	robby.nitzsche.lind@geemail.com	Boston	Massachusetts	060480325214361	4da4ce99ac3f7963187f149dc2d1c65d	VISA 16 digit	42.3857371704820522	-71.0263591097153721
17478	2020-03-28 07:55:09	2020-03-28	Shawn Orn	shawn.orn@warmmail.com	San Francisco	California	3528128365381379423	9a3044d753afb62e540704014675dfec	Mastercard	37.7831760767435583	-122.434270941202342
17479	2020-03-28 08:11:04	2020-03-28	Yandel Schmeler-Dooley	yandel.schmeler.dooley@geemail.com	Miami	Florida	869912608900171683	2bb780de4c0c05f8ac61e469c338d424	JCB 16 digit	25.8311493532869996	-80.1585731029383908
17480	2020-03-28 08:14:34	2020-03-28	Kadin Walsh	kadin.walsh@geemail.com	San Francisco	California	4406557911137	5ac3276e96f5850bd445a0cd70f6fb98	Mastercard	37.7891485184374218	-122.422623000119899
17481	2020-03-28 08:26:57	2020-03-28	Tod Friesen	tod.friesen@geemail.com	Pittsburgh	Pennsylvania	3449816535253183	88f95c60a562285f086cee56d5fbc14c	VISA 13 digit	40.4916258589319895	-79.8857951518319567
17482	2020-03-28 08:32:42	2020-03-28	Vertie Greenholt	vertie.greenholt@geemail.com	Elk Grove	California	4992280661542546	6feeee14c4a6ff5365031691e38643e0	JCB 15 digit	38.3709539886381492	-121.411542687416087
17483	2020-03-28 08:33:03	2020-03-28	Ms. Tonda Doyle MD	ms.tonda.doyle.md@geemail.com	Atlanta	Georgia	869919327203315896	5ed000628e407ee7f5b12f43ac994a59	JCB 16 digit	33.7240474736593683	-84.4037972681734772
17484	2020-03-28 08:35:26	2020-03-28	Girtha Cartwright	girtha.cartwright@warmmail.com	Allentown	Pennsylvania	4265217967352873	637388a6b08ddb2b09bc0d122f287b36	JCB 16 digit	40.5593911297865262	-75.5195609602626376
17485	2020-03-28 08:40:50	2020-03-28	Francesco Mills	francesco.mills@woohoo.com	Dallas	Texas	4157772782007	65179f3e3a9e33ab4cea3a79daf4d21f	Diners Club / Carte Blanche	32.8061117533866309	-96.6714227195791835
17486	2020-03-28 08:44:40	2020-03-28	Mrs. Angeline Keebler DDS	mrs.angeline.keebler.dds@geemail.com	Lubbock	Texas	4687518559830	450985316f87cf839524a890e3af0171	JCB 15 digit	33.6026070468168712	-101.953740659533821
17487	2020-03-28 08:45:28	2020-03-28	Mitzi Hayes DVM	mitzi.hayes.dvm@warmmail.com	New York	New York	3011017907619681	36a1fc7d75af95ae8b642c997b6f748b	Voyager	40.5872110310234149	-73.9598894920095802
17488	2020-03-28 09:03:40	2020-03-28	Mr. Lonzo Kris V	mr.lonzo.kris.v@geemail.com	Philadelphia	Pennsylvania	3712571413024080	fc991abd0e975744b142f85e6aeca68a	JCB 15 digit	39.9384233328472789	-75.1266348898310241
17489	2020-03-28 09:04:33	2020-03-28	Jack Daniel	jack.daniel@geemail.com	Louisville	Kentucky	3059292486646585	d9d6cf75738d4f00af0c6aa935fa6a05	Maestro	38.0823929745607046	-85.7071730991430627
17490	2020-03-28 09:05:55	2020-03-28	Leonard Shields	leonard.shields@geemail.com	Charlotte	North Carolina	210081093652333391	36bde48b3b09eb9a4fefb6b47ae8af33	Diners Club / Carte Blanche	35.1406017443884124	-80.8228532869312914
17491	2020-03-28 09:07:11	2020-03-28	Dr. George Wilderman I	dr.george.wilderman.i@geemail.com	San Francisco	California	589348104284368	fc642b6e4c037c384ee0696f956d5ee4	Diners Club / Carte Blanche	37.7750549566146603	-122.406759045907222
17492	2020-03-28 09:36:08	2020-03-28	Thorwald Mayer-Green	thorwald.mayer.green@woohoo.com	Stockton	California	4162304476656	e979c1b97af868ebe0ee1824c00ff874	JCB 16 digit	37.9024199550237526	-121.306326170274247
17493	2020-03-28 09:40:14	2020-03-28	Karon Harris-Bailey	karon.harris.bailey@warmmail.com	Savannah	Georgia	210063902118272161	3f87af1623138c3bb4dbf52c456af98a	JCB 16 digit	32.063816885845732	-81.2502952080838412
17494	2020-03-28 09:44:17	2020-03-28	Tye Gleason	tye.gleason@geemail.com	New York	New York	4725875723282	a4ea438b342503474992d70cb5617c0f	Mastercard	40.7051734529659157	-73.9701977298025071
17495	2020-03-28 10:26:36	2020-03-28	Tollie Kub I	tollie.kub.i@geemail.com	San Francisco	California	3158845000450494777	aee082df263959892d0840f787af3979	Discover	37.8150968859124106	-122.452220857193169
17496	2020-03-28 10:27:32	2020-03-28	Dr. Claribel Klocko MD	dr.claribel.klocko.md@geemail.com	Phoenix	Arizona	3771760537004395	95f1d0e00e762c263e807485972a10c2	VISA 13 digit	33.476061712710937	-112.048095495293296
17497	2020-03-28 10:33:02	2020-03-28	Ms. Latricia Weimann DDS	ms.latricia.weimann.dds@geemail.com	Virginia Beach	Virginia	4478379415379503	e1e1f9cf071a2d986c81535f061b70d4	American Express	36.816955670593309	-75.9406973417520561
17498	2020-03-28 10:46:48	2020-03-28	Mrs. Ozella Boyle DVM	mrs.ozella.boyle.dvm@geemail.com	San Francisco	California	4002747851367650	6cba6f437d6a3861b1e25e079529833f	Maestro	37.7454068699068941	-122.453247928927837
17499	2020-03-28 10:59:42	2020-03-28	Lindell Schultz	lindell.schultz@woohoo.com	Houston	Texas	676314862471001	61045ee401db48cadda6fde764b510a4	Mastercard	29.7363010931372642	-95.478641858698424
17500	2020-03-28 11:08:47	2020-03-28	Emilee Treutel	emilee.treutel@woohoo.com	San Francisco	California	630426512155875	121651fb636ddff8b8e8b1f4e57b128f	VISA 13 digit	37.7958413875516825	-122.413955401977589
17501	2020-03-28 11:37:03	2020-03-28	Lucian Collins	lucian.collins@warmmail.com	San Francisco	California	676187968807781	9af1d5d317075a145ee69ccc38ff2dd4	Discover	37.7467275550319883	-122.438440380141415
17502	2020-03-28 11:37:39	2020-03-28	Renaldo Reichel	renaldo.reichel@warmmail.com	San Francisco	California	3496358215243921	828c53d8ac25e1987f13fcb27ede58e9	VISA 16 digit	37.7305860627594214	-122.428948639769786
17503	2020-03-28 11:38:44	2020-03-28	Marian Wiza	marian.wiza@geemail.com	Madison	Wisconsin	3013884335600494	d9a138a100e01fde26a8e40aacaf1173	American Express	43.1169583748534322	-89.5107828345034306
17504	2020-03-28 11:40:35	2020-03-28	Isabelle Gutmann	isabelle.gutmann@geemail.com	Palm Bay	Florida	180072959299024802	102b4a1cde9dfbd1080100ba320dcbdf	Voyager	28.0737224577780822	-80.7223793641500151
17505	2020-03-28 12:11:33	2020-03-28	Leann Friesen	leann.friesen@warmmail.com	New York	New York	4758423862074505	ee2f52a351f7b2198aee14bf73c12fb4	VISA 13 digit	40.6170142231732569	-73.9385548951931213
17506	2020-03-28 12:29:06	2020-03-28	Fed Heidenreich MD	fed.heidenreich.md@geemail.com	Berkeley	California	3096414437562513600	4b50ddce6b0aa8638d2f4a60ec4e2d23	JCB 16 digit	37.8506658733513603	-122.298533165815712
17507	2020-03-28 12:59:06	2020-03-28	Benito Baumbach	benito.baumbach@woohoo.com	Saint Paul	Minnesota	3001975499715045	2ccd8c13b096cd2dd1ec5c37fad9c245	Maestro	45.0408461261946726	-93.0588442018054423
17508	2020-03-28 13:03:26	2020-03-28	Korbin Stiedemann	korbin.stiedemann@geemail.com	Salt Lake City	Utah	503800648054484	bff148a7437fbc94272f41cf40d80940	VISA 13 digit	40.6915054163575149	-111.915603604534638
17509	2020-03-28 13:04:38	2020-03-28	Lu Lesch	lu.lesch@geemail.com	Vancouver	Washington	3088916337414984004	5a14eba90320b3fef91d5eb9327f656a	VISA 16 digit	45.5740067442484218	-122.626134073181817
17510	2020-03-28 13:09:56	2020-03-28	Allan Cole	allan.cole@geemail.com	Hampton	Virginia	3528203062947022088	43a6f54d1b98cf1128ab17852b0deadc	Voyager	37.0665754946898716	-76.3844092616908199
17511	2020-03-28 13:22:37	2020-03-28	Roma Rempel	roma.rempel@woohoo.com	Columbus	Ohio	4827269574923	c067b5fb7fecfe563ed7c26afa5056bc	Voyager	40.0625025678005073	-83.0590622305173554
17512	2020-03-28 13:25:48	2020-03-28	Kendra Kautzer-Reichert	kendra.kautzer.reichert@geemail.com	San Francisco	California	3753437514839174	fd74ad0262f9054b5726a19640502b09	JCB 15 digit	37.7823338785101654	-122.425379071264217
17513	2020-03-28 13:25:55	2020-03-28	Lavon Robel	lavon.robel@warmmail.com	Jersey City	New Jersey	3752986342491302	a22312cb4c0de66935c1c01e61edad56	JCB 16 digit	40.7459702782738944	-74.1227888056032356
17514	2020-03-28 13:28:49	2020-03-28	Mercer McDermott V	mercer.mcdermott.v@geemail.com	San Antonio	Texas	869938006631058271	d88477e47e3be4dea43efc3e40c14cc1	Maestro	29.4677024486545491	-98.4837864841170614
17515	2020-03-28 13:43:31	2020-03-28	Josiephine Jacobs	josiephine.jacobs@woohoo.com	San Francisco	California	502020689117941	8c7c7b4e8f7877782ac5180f0b786208	Diners Club / Carte Blanche	37.770212320573556	-122.428323127821471
17516	2020-03-28 13:50:17	2020-03-28	Cailyn Nicolas DVM	cailyn.nicolas.dvm@warmmail.com	San Diego	California	6011569064260253157	7fc62f683562c548aafecc932eb6e454	JCB 16 digit	32.9030684203907882	-117.10700179132634
17517	2020-03-28 13:52:55	2020-03-28	Miss Elvina Jaskolski DVM	miss.elvina.jaskolski.dvm@geemail.com	Jacksonville	Florida	869994370275612467	2da3ad30306fcdd3b6dbb3d2342de4f2	Maestro	30.2863436390232295	-81.6770661240056199
17518	2020-03-28 14:04:33	2020-03-28	Archibald Kulas Sr.	archibald.kulas.sr.@geemail.com	Los Angeles	California	3158076321640550793	5f69b2bca12eadaef9d44c379fd737a3	JCB 16 digit	34.0944571983400735	-118.392592204314838
17519	2020-03-28 14:10:35	2020-03-28	Karter Conroy I	karter.conroy.i@geemail.com	Rockford	Illinois	210028028539835453	a0f13322b04f66755ef6111a6bd64c21	VISA 13 digit	42.1741774175792941	-89.0738045008204864
17520	2020-03-28 14:18:52	2020-03-28	Gustavus Rohan	gustavus.rohan@geemail.com	Oakland	California	3528863952909473603	8397f0b17414cbc074d8223354a78f69	VISA 16 digit	37.7836445186140537	-122.266688066726047
17521	2020-03-28 14:32:39	2020-03-28	Dr. Racquel Daniel	dr.racquel.daniel@geemail.com	Berkeley	California	6011759395673066616	00a0b998eb84ac108da6c4c8e1fbbcda	American Express	37.8382246890600413	-122.297821301826318
17522	2020-03-28 14:37:57	2020-03-28	Janette Denesik	janette.denesik@warmmail.com	Hampton	Virginia	3704068838100355	05e7ff7910b229970b8db8a079f8cd90	VISA 13 digit	36.9733503317944709	-76.2314347149901153
17523	2020-03-28 14:46:48	2020-03-28	Carmen Hessel	carmen.hessel@geemail.com	Jacksonville	Florida	3088446246687245960	d238ea545746bb1a60d8a199c3f12284	Discover	30.4343702308885753	-81.6216830991752573
17524	2020-03-28 15:19:08	2020-03-28	Edw Daugherty-Sawayn	edw.daugherty.sawayn@geemail.com	Detroit	Michigan	3158685686849447162	36e46d3097c1f16503878f0c54bccfe9	VISA 13 digit	42.2942336512655075	-83.017497670615839
17525	2020-03-28 15:59:03	2020-03-28	Mattie Toy	mattie.toy@geemail.com	Madison	Wisconsin	3747721600237321	02a759f9c41a8e312bcc5bc10f4a2b45	JCB 16 digit	43.1328606020633174	-89.3664818758495159
17526	2020-03-28 15:59:22	2020-03-28	Carma Kshlerin	carma.kshlerin@geemail.com	Oakland	California	561256144890037	68ba52af0e30e9c15c837618c3143fe2	JCB 15 digit	37.8506746542070616	-122.298489884726663
17527	2020-03-28 16:01:15	2020-03-28	Mrs. Tawana Batz	mrs.tawana.batz@geemail.com	Milwaukee	Wisconsin	3038172071601362	f6591aee8eb1cc2c410f37c189dfd7af	JCB 15 digit	43.1129542040258613	-88.0490156593833149
17528	2020-03-28 16:20:23	2020-03-28	Daniele O'Keefe	daniele.o'keefe@geemail.com	Fort Collins	Colorado	3054141677349712	a79cb000d1b175fe2865c132ae11ae46	JCB 16 digit	40.5379146763280076	-105.119999229111897
17529	2020-03-28 16:33:30	2020-03-28	Miss Ashlyn Raynor	miss.ashlyn.raynor@warmmail.com	Orange	California	3727277960413352	6a1730afedbe36c45b0faece23f956ce	JCB 16 digit	33.825514236873012	-117.958161935500058
17530	2020-03-28 16:43:03	2020-03-28	Narcissus Douglas DDS	narcissus.douglas.dds@geemail.com	Jersey City	New Jersey	3528746386664325596	d09fbd849f958ed7cd30543d14846772	VISA 16 digit	40.7918531032685152	-74.108226766153436
17531	2020-03-28 17:12:35	2020-03-28	Creed Hand-McClure	creed.hand.mcclure@woohoo.com	Phoenix	Arizona	3014333651930357	1bb13a1b52de394aff7031f0c0453451	Diners Club / Carte Blanche	33.474934647877518	-112.168155410971877
17532	2020-03-28 17:26:13	2020-03-28	Ovila Bogisich	ovila.bogisich@geemail.com	Washington	District of Columbia	3411764780944227	fd71f7c14c60dbccde4a66cd6fec2df4	JCB 16 digit	38.9032081735119206	-77.0030582190237993
17533	2020-03-28 17:44:34	2020-03-28	Johnnie Price	johnnie.price@geemail.com	Las Vegas	Nevada	869908051347635695	20250e5db520b268dc1dc827ed75a1f9	JCB 16 digit	36.1676500312153237	-115.355570989868042
17534	2020-03-28 17:58:23	2020-03-28	Mrs. Norene Larson	mrs.norene.larson@geemail.com	Manchester	New Hampshire	4088409634544579	db5df06f0dc4ff35e4caecc34510c3f4	JCB 16 digit	42.959268835287169	-71.3979663094863355
17535	2020-03-28 17:59:10	2020-03-28	Fayette O'Keefe	fayette.o'keefe@geemail.com	Stockton	California	3771984463692557	d020b58adc03112adf0191025ed5c45c	JCB 16 digit	38.0648089853312825	-121.265447420588885
17536	2020-03-28 18:17:19	2020-03-28	Milo Crist PhD	milo.crist.phd@geemail.com	San Francisco	California	180042903636634383	8f7ac910973664627b4ef1dab3802d79	Maestro	37.7711383909146221	-122.448153807077929
17537	2020-03-28 18:22:30	2020-03-28	Manly Kub	manly.kub@geemail.com	Houston	Texas	53709157900057227	769fb038bcd6bf88fede417bc07130f8	VISA 13 digit	29.7038091493848704	-95.3025356923710518
17538	2020-03-28 18:25:03	2020-03-28	Carole Spinka	carole.spinka@geemail.com	Boulder	Colorado	210032887469777231	61af7e320b088223d7af6e4eb77fa86a	JCB 15 digit	40.0817717722132798	-105.27709304445014
17539	2020-03-28 18:38:00	2020-03-28	Dr. Mikeal Abshire	dr.mikeal.abshire@geemail.com	Tulsa	Oklahoma	589346984776206	52b706bd88c7b59efe26ebefd9aea50d	JCB 16 digit	36.0420963361762432	-95.905622700085118
17540	2020-03-28 19:10:15	2020-03-28	Lyndia O'Kon	lyndia.o'kon@geemail.com	San Francisco	California	4639734974390232	50343f6a75e7bef1cca78b3da591569d	JCB 16 digit	37.7781222704539843	-122.434778454645297
17541	2020-03-28 19:23:35	2020-03-28	Birtie McKenzie	birtie.mckenzie@geemail.com	Chicago	Illinois	4909763722443954	d174441ad0eb68ed76758b0967faf814	JCB 16 digit	41.925424921403085	-87.7159037830337809
17542	2020-03-28 19:29:12	2020-03-28	Dr. Rosalind Kub DDS	dr.rosalind.kub.dds@geemail.com	Austin	Texas	6011999219447106203	a75a424c1f82440d5b65b193e3584a23	JCB 16 digit	30.2447386404160383	-97.8433445837121525
17543	2020-03-28 19:32:41	2020-03-28	Dr. Mateo Dooley	dr.mateo.dooley@geemail.com	San Diego	California	3042882270332884	1a433dc4c4e1b34f95619df2dedfef1f	Voyager	32.8801848982993548	-117.134610032374042
17544	2020-03-28 19:39:13	2020-03-28	Severo Erdman	severo.erdman@warmmail.com	San Francisco	California	869921810929224910	c540467a46660ab79a5cc3c44d0cb073	VISA 16 digit	37.7706657191508555	-122.406661132324615
17545	2020-03-28 19:52:59	2020-03-28	Mr. Marques Mueller IV	mr.marques.mueller.iv@geemail.com	McKinney	Texas	210075294825712002	6cab511f0168879b362594c1610be377	Voyager	33.2364137166775819	-96.5887616776227986
17546	2020-03-28 19:58:12	2020-03-28	Dr. Clayton D'Amore MD	dr.clayton.d'amore.md@geemail.com	Washington	District of Columbia	869959897716700470	d9b04c3ef47c443d3744949d8f57ff28	VISA 13 digit	39.0022849846895809	-77.1043829347684948
17547	2020-03-28 20:04:33	2020-03-28	Tamera Graham	tamera.graham@geemail.com	Houston	Texas	3000049053470677	b4cdafc4ccd5b50849d7d4f848e9cbc1	VISA 16 digit	29.7227002660356447	-95.4450467772796713
17548	2020-03-28 20:10:00	2020-03-28	Ms. Lovina Crooks DVM	ms.lovina.crooks.dvm@geemail.com	Oakland	California	54123657505052752	593ecde574248afb233d2d91c6c53391	VISA 13 digit	37.83179986735162	-122.261453555749426
17549	2020-03-28 20:24:00	2020-03-28	Antwan Greenholt V	antwan.greenholt.v@geemail.com	Greensboro	North Carolina	3013273918267808	07afa68f801b786dd8989e661ece8d0f	VISA 16 digit	36.1427367380470059	-79.8565149970799695
17550	2020-03-28 20:36:43	2020-03-28	Harmony Fritsch	harmony.fritsch@geemail.com	Milwaukee	Wisconsin	6011996539048805603	f16918f2665393060d3dc21cbb495f24	JCB 16 digit	43.0907910082109282	-88.0207172508452089
17551	2020-03-28 20:49:21	2020-03-28	Buffy Koch	buffy.koch@geemail.com	Boston	Massachusetts	869976714889821406	f74c1e6a83bdb10e163d5218f7a4b036	JCB 16 digit	42.394959150597451	-70.9967632564201949
17552	2020-03-28 21:36:18	2020-03-28	Dr. Hortensia Nader DDS	dr.hortensia.nader.dds@geemail.com	New York	New York	180071779392458322	d1d4e6193fb9542ecc0dd091780345be	VISA 16 digit	40.7432030795365563	-74.009066900134826
17553	2020-03-28 21:37:03	2020-03-28	Cordia Ullrich	cordia.ullrich@geemail.com	New York	New York	3001670546731976	92f52ab39b176e0fafa91a625e01e3c2	VISA 13 digit	40.5726722910292423	-73.8393299401633385
17554	2020-03-28 21:45:39	2020-03-28	Glen VonRueden	glen.vonrueden@geemail.com	Memphis	Tennessee	3016229237086417	01a6e0cf2e2772c0f347754415ad8dde	VISA 16 digit	35.0284306968629409	-89.9898442977830797
17555	2020-03-28 22:04:30	2020-03-28	Baby Lang	baby.lang@geemail.com	New York	New York	4009465128743	51d2ad34ded0208c36ff337a7add8b67	JCB 16 digit	40.5692348838541648	-73.9318147282011751
17556	2020-03-28 22:09:50	2020-03-28	Alexia Lubowitz	alexia.lubowitz@geemail.com	San Antonio	Texas	4931826874907456	4e782a31c7a6463385f78d2f2ed002c6	JCB 15 digit	29.3912065427821148	-98.6106435385368769
17557	2020-03-28 22:14:10	2020-03-28	Savannah Goldner	savannah.goldner@woohoo.com	Tallahassee	Florida	4184929019818317	4bdf47f0ba1a80f7af90da53f303cff1	VISA 16 digit	30.4342507735848429	-84.3355756323799426
17558	2020-03-28 22:25:58	2020-03-28	Lady Muller MD	lady.muller.md@warmmail.com	Oklahoma City	Oklahoma	3112052758260187240	047ef2976fe8df2b858a431fa1172688	Voyager	35.5103952402625254	-97.6081074610713841
17559	2020-03-28 22:47:56	2020-03-28	Silvia Kirlin-Cruickshank	silvia.kirlin.cruickshank@geemail.com	Des Moines	Iowa	589397302479130	7ba8c8a8066a05d1179ad6971d4c855a	VISA 16 digit	41.5368540859524202	-93.653334696409118
17560	2020-03-28 22:50:51	2020-03-28	Lonna Sporer	lonna.sporer@geemail.com	Mobile	Alabama	54825741844380255	dc6418122adf14db2770fd117d84587d	VISA 13 digit	30.616489700425042	-88.1492332367364355
17561	2020-03-28 22:56:39	2020-03-28	Arthur Medhurst	arthur.medhurst@geemail.com	Salinas	California	869972133205192679	41ffd796bf5426b61055ea500ecbfe12	Voyager	36.6778419267151463	-121.544759386562561
17562	2020-03-28 23:15:58	2020-03-28	Shalon Pagac	shalon.pagac@geemail.com	Houston	Texas	4361846587686832	2464e60127a11e513ca0022fa8bab803	JCB 16 digit	29.7625117147419616	-95.4904386282447746
17563	2020-03-28 23:27:34	2020-03-28	Erby Turner-Hand	erby.turner.hand@geemail.com	San Francisco	California	3337067661359193363	eba69adf5f7e15052c62c5c753637e87	JCB 16 digit	37.7539011239345612	-122.422956066763859
17564	2020-03-28 23:47:32	2020-03-28	Gilbert Morissette	gilbert.morissette@warmmail.com	Anaheim	California	6011172094234188006	87c30000c34b555f2f9f14d40fe7edd5	VISA 16 digit	33.8033519757278285	-117.765669596868008
17565	2020-03-29 00:14:45	2020-03-29	Dr. Joy Kutch DDS	dr.joy.kutch.dds@warmmail.com	Scottsdale	Arizona	53660214763633102	31f78c0ae27c5c1c1b474fd58dbc1fef	Discover	33.5911809578660865	-111.876787355631961
17566	2020-03-29 00:17:04	2020-03-29	Orrie Dooley	orrie.dooley@woohoo.com	Mesa	Arizona	4639501973285600	fec991dd66ca21cc1e64caab69741942	American Express	33.46562419851832	-111.76516865458116
17567	2020-03-29 00:30:52	2020-03-29	Jazlynn Fadel DVM	jazlynn.fadel.dvm@warmmail.com	Hayward	California	3158101974041251160	20299fb8337ede6a86903b374445a2aa	American Express	37.5942597835779182	-122.121196302098781
17568	2020-03-29 00:34:01	2020-03-29	Mrs. Tanika Hilll MD	mrs.tanika.hilll.md@woohoo.com	San Antonio	Texas	6011013469392376762	781c3893a7ccf881e17d29fb44bb8947	American Express	29.3897293366096903	-98.522284553788964
17569	2020-03-29 00:50:51	2020-03-29	Randolf Mueller-Kshlerin	randolf.mueller.kshlerin@geemail.com	San Francisco	California	6011464454299029544	d49c7a6af3e000b505a0aade2b949a31	JCB 16 digit	37.8038481796733166	-122.428067119176148
17570	2020-03-29 01:11:23	2020-03-29	Joeseph Keebler	joeseph.keebler@woohoo.com	San Francisco	California	4256923685027421	6627347f8dcb4c3f69f8e2ca7f327ac9	Maestro	37.7512016736061611	-122.455870332646484
17571	2020-03-29 01:14:28	2020-03-29	Daisie Langosh	daisie.langosh@geemail.com	Norman	Oklahoma	51484711928626453	446fcee95302253ccf42c4c3ad42f26d	VISA 16 digit	35.3120147970080396	-97.4194715411655494
17572	2020-03-29 01:51:58	2020-03-29	Rowan Ziemann	rowan.ziemann@geemail.com	Columbus	Georgia	4384207999767285	7fa72c21df077ccf3942a2f2c8b5f49d	Maestro	32.5191219931978708	-84.8343251248054173
17573	2020-03-29 02:05:02	2020-03-29	Miss Nikki Greenfelder	miss.nikki.greenfelder@geemail.com	San Francisco	California	502011219643605	4d1a1c2b2733e567b81b48e61ee223d6	JCB 16 digit	37.7874920092315918	-122.459347908092852
17574	2020-03-29 02:09:04	2020-03-29	Casen Schimmel	casen.schimmel@geemail.com	San Francisco	California	180019909741777669	b99958a9943c4093f3321320a94f6c57	JCB 15 digit	37.7427255126709298	-122.439478066458975
17575	2020-03-29 02:20:05	2020-03-29	Mr. Bill Von IV	mr.bill.von.iv@geemail.com	San Antonio	Texas	3049129426945992	a4beadcf1d5146816bfa6b861c5f72e4	Voyager	29.4207468037564297	-98.4989489716779332
17576	2020-03-29 02:22:53	2020-03-29	Juelz Kihn III	juelz.kihn.iii@geemail.com	Baton Rouge	Louisiana	53982731389119654	ccc66881b2979acc6009b9e77420316f	JCB 16 digit	30.3494321327403185	-91.0367475179131986
17577	2020-03-29 02:24:03	2020-03-29	Dovie Ratke	dovie.ratke@geemail.com	Des Moines	Iowa	3446385976748989	175c1669031fa2fe8d2aa0c529f0a148	Maestro	41.5848240574099108	-93.5222611848775358
17578	2020-03-29 02:31:36	2020-03-29	Dr. Jacquelin Murphy PhD	dr.jacquelin.murphy.phd@geemail.com	Oakland	California	3096055555376295595	e91a7c9d562094b7506c165c29fdbd44	VISA 13 digit	37.7984443797562477	-122.285656372369601
17579	2020-03-29 02:32:28	2020-03-29	Mr. Ron Kihn II	mr.ron.kihn.ii@warmmail.com	Houston	Texas	53139537395987873	0c64d383bd181a1adb3fcadb77ede890	Voyager	29.8427831671278909	-95.3651180713918052
17580	2020-03-29 02:41:41	2020-03-29	Jaimee Rutherford	jaimee.rutherford@warmmail.com	Hayward	California	3730819774381302	d6f4504e2065b05081b57fabc109b3e5	American Express	37.5869631692755988	-122.116563150778049
17581	2020-03-29 02:58:02	2020-03-29	Rohan Boyer I	rohan.boyer.i@geemail.com	Kansas City	Missouri	3096769528512780280	aa5ba57bb92b69cbea84c75fb0d19f39	Diners Club / Carte Blanche	39.0754169306553933	-94.4968190406207071
17582	2020-03-29 03:00:53	2020-03-29	Roberto Kessler	roberto.kessler@geemail.com	San Francisco	California	51381936277476259	4e2e22bdbd37dde704d9b3fafc324af9	JCB 16 digit	37.7848349688809009	-122.45731662058148
17583	2020-03-29 03:01:05	2020-03-29	Charley Will	charley.will@geemail.com	Philadelphia	Pennsylvania	180042697471084627	0e79a28a6cb752dd49a1ecd8c775eca6	VISA 16 digit	40.0389005473308259	-75.0593858017951305
17584	2020-03-29 03:08:22	2020-03-29	Anjanette Robel	anjanette.robel@geemail.com	Los Angeles	California	3470453466108111	884184af600e54818c9b5332ef6db6ad	Maestro	34.0612541028629963	-118.414253329810862
17585	2020-03-29 03:17:47	2020-03-29	Mrs. Rillie Kuhlman DVM	mrs.rillie.kuhlman.dvm@warmmail.com	New York	New York	55642851721823987	0784f425504afc912bb476e6fd03a994	JCB 16 digit	40.6345161442402727	-74.0135219280037973
17586	2020-03-29 03:19:05	2020-03-29	Mr. Erie O'Conner	mr.erie.o'conner@geemail.com	Houston	Texas	6011506565637097461	3a8ba912f5a084c6a9359f195b29aa05	JCB 15 digit	29.7634951868638389	-95.4270073278822082
17587	2020-03-29 03:23:34	2020-03-29	Dr. Tracy Mohr DDS	dr.tracy.mohr.dds@warmmail.com	Long Beach	California	630466576667316	239dfd59dddf4f457a563944eaab0a6a	JCB 16 digit	33.8800871908951535	-118.178204571099201
17588	2020-03-29 03:37:55	2020-03-29	Shaun Witting	shaun.witting@woohoo.com	New York	New York	6011772841177798355	cb896bf4bd294affad169a0ac209e7a9	JCB 15 digit	40.6654986930768914	-73.9745260287437532
17589	2020-03-29 03:39:47	2020-03-29	Miss Cathern Bruen	miss.cathern.bruen@geemail.com	Amarillo	Texas	3732587320596545	24f603f07388ae1d190d11bd8f958985	American Express	35.1653811746440823	-101.899431168646373
17590	2020-03-29 03:43:10	2020-03-29	Dr. Hans Emard MD	dr.hans.emard.md@geemail.com	New York	New York	180023085442772244	42eaf965c412eacfc6e2c921784979a8	JCB 16 digit	40.7388738224972045	-73.9703402962896917
17591	2020-03-29 04:01:33	2020-03-29	Arland Cummerata	arland.cummerata@geemail.com	Phoenix	Arizona	676178107615375	2079e3aa075708528b14dcd1c728652a	VISA 16 digit	33.573211587306858	-112.013992373591662
17592	2020-03-29 04:12:36	2020-03-29	Dr. Oral Haag	dr.oral.haag@woohoo.com	San Francisco	California	589335365703459	cd430a546e6555cecbc1694eb9435543	JCB 15 digit	37.7420398512715778	-122.440034670066254
17593	2020-03-29 04:35:55	2020-03-29	Dr. Harden Rowe	dr.harden.rowe@geemail.com	Davie	Florida	4200808773645670	21fd121fdc7fcf6a7c1819c2c558a9db	JCB 15 digit	25.9838144053503868	-80.2819309831969434
17594	2020-03-29 04:41:09	2020-03-29	Mr. Thorwald Weimann III	mr.thorwald.weimann.iii@geemail.com	San Francisco	California	3765956873272657	6cd9e5af8b74d23d44de8d7798edbc2d	VISA 16 digit	37.7771903804634448	-122.402475168360695
17595	2020-03-29 04:44:46	2020-03-29	Dr. Chalmer Kuvalis	dr.chalmer.kuvalis@woohoo.com	New York	New York	51462734249072393	19d5dac4d0b044d7b33f9b2110b473fa	Diners Club / Carte Blanche	40.6762050815615765	-74.0022289353784117
17596	2020-03-29 05:08:43	2020-03-29	Domenick Cormier-Borer	domenick.cormier.borer@woohoo.com	Alexandria	Virginia	52884283785740286	e7b84b9b6c4773e582a28324500fafbf	Maestro	38.8156894965212729	-77.1034219239823528
17597	2020-03-29 05:12:40	2020-03-29	Carla Johnson	carla.johnson@geemail.com	San Francisco	California	6011985852833074787	7a67cac76201c0d20ebf5b207664e112	Diners Club / Carte Blanche	37.7736938303850707	-122.429171112428804
17598	2020-03-29 05:17:53	2020-03-29	Dr. Zetta Goyette DDS	dr.zetta.goyette.dds@geemail.com	San Antonio	Texas	3708284980643821	d1f341a48f26408d121e3f6a8cf2015a	JCB 16 digit	29.4869043785683829	-98.4284889639191221
17599	2020-03-29 05:18:34	2020-03-29	Brycen Fadel	brycen.fadel@geemail.com	McKinney	Texas	3088086754404113085	e4f487fc9eeef1235dc04acfd403a27d	Voyager	33.2719928492922392	-96.5825113061647897
17600	2020-03-29 05:27:24	2020-03-29	Dr. Shawanda Pagac MD	dr.shawanda.pagac.md@geemail.com	Chattanooga	Tennessee	6011224558230039916	e3a6dd001d530317dd5b48b0454e832e	Maestro	35.0109014000594669	-85.277145802165947
17601	2020-03-29 05:44:14	2020-03-29	Vicy Wolf	vicy.wolf@geemail.com	Greensboro	North Carolina	180001540692731221	106a0824b03dec68b2f246262ba0d03c	Diners Club / Carte Blanche	36.0570832640048167	-79.7612195155099073
17602	2020-03-29 05:47:36	2020-03-29	Sherie Medhurst PhD	sherie.medhurst.phd@geemail.com	Oklahoma City	Oklahoma	4799147458992256	8d67f29268e01c24387b73d5adb4ca43	Mastercard	35.3881460997186608	-97.5823619865708025
17603	2020-03-29 05:51:38	2020-03-29	Dr. Jabez Hamill II	dr.jabez.hamill.ii@geemail.com	New York	New York	4736452436149	d157aaf783d2854bf5747f341ea3411b	Voyager	40.7163614155482492	-73.9640188153263125
17604	2020-03-29 05:51:49	2020-03-29	Ms. Darlene Hilll	ms.darlene.hilll@woohoo.com	San Francisco	California	4812902886683825	77540b009cb845144ebed2f1736f21c6	Diners Club / Carte Blanche	37.7722861719481244	-122.472696537122943
17605	2020-03-29 05:55:38	2020-03-29	Dolphus Bradtke-Hane	dolphus.bradtke.hane@geemail.com	Frisco	Texas	3716566189962790	ee33dc152f67b4f6d2825387b85f288d	Maestro	33.2389796729195837	-96.8806327236559213
17606	2020-03-29 06:09:11	2020-03-29	Sarrah Stroman	sarrah.stroman@geemail.com	Richmond	Virginia	3767273783245189	d442fa806866ec141d37774b2a57ec92	VISA 16 digit	37.4404674631297567	-77.3860889281835398
17607	2020-03-29 06:09:28	2020-03-29	Dottie Hettinger	dottie.hettinger@geemail.com	Garland	Texas	869900104919316646	65018ce367e63ea5cdaa7f3092d3bad3	Mastercard	33.0075352788671808	-96.5999601671632462
17608	2020-03-29 06:31:46	2020-03-29	Jami Reichel-Morissette	jami.reichel.morissette@woohoo.com	New York	New York	210007504890679024	92afc08cec8b143857f0ef5f6d59d750	VISA 16 digit	40.5992166233472531	-74.0131700912386208
17609	2020-03-29 06:42:14	2020-03-29	Abb Swaniawski PhD	abb.swaniawski.phd@geemail.com	San Francisco	California	3056543287248416	f1dfbbe63bf621407f3f6458001f5d53	JCB 16 digit	37.7728814758522731	-122.449254617132951
17610	2020-03-29 06:44:19	2020-03-29	Gibson Kub MD	gibson.kub.md@woohoo.com	Houston	Texas	4681335749206062	20f92c38b9fd063853569120dc760f5f	JCB 15 digit	29.8117285294536494	-95.417915465963631
17611	2020-03-29 06:51:40	2020-03-29	Sasha Cormier	sasha.cormier@geemail.com	Moreno Valley	California	54628865627492224	dec1f07b22fb3f5f3ef462e600349453	JCB 16 digit	33.9207338542204297	-117.226727695341026
17612	2020-03-29 07:06:58	2020-03-29	Leonor Schowalter	leonor.schowalter@woohoo.com	Davie	Florida	4118029423830288	c3d3962750ae867898215572219d9f08	VISA 13 digit	26.094385966778173	-80.2971419528499268
17613	2020-03-29 07:19:54	2020-03-29	Maurice Ferry	maurice.ferry@warmmail.com	Philadelphia	Pennsylvania	6011072912621998052	3f71e38c71e8ed8c5bf3bf2cf2bfdb1f	Diners Club / Carte Blanche	40.0500443121843048	-75.035537929683187
17614	2020-03-29 07:45:39	2020-03-29	Rosalee Haley	rosalee.haley@geemail.com	San Francisco	California	6011633089324028719	1e798d23134192a791bd809e5557e873	Mastercard	37.7318430706563177	-122.428806431121728
17615	2020-03-29 08:07:37	2020-03-29	Dr. Yurem Fisher PhD	dr.yurem.fisher.phd@geemail.com	San Francisco	California	4026338046805374	12f738144083c5581a8faac954e1ab2f	Maestro	37.7662137314836457	-122.447673053656032
17616	2020-03-29 08:10:00	2020-03-29	Tera Bahringer	tera.bahringer@geemail.com	Providence	Rhode Island	3158116959792220210	f40158a42c64110e0a4910d0dcd9b86d	JCB 16 digit	41.9003799668367947	-71.3874140335630614
17617	2020-03-29 08:34:19	2020-03-29	Ms. Pennie Kohler	ms.pennie.kohler@warmmail.com	Irvine	California	6011816837169332953	2d83b24653aa92f10fd8ff1a9b8bd91c	JCB 16 digit	33.6706747089061906	-117.795532749827203
17618	2020-03-29 08:36:58	2020-03-29	Miss Vernell Halvorson	miss.vernell.halvorson@geemail.com	Hampton	Virginia	4009250296791223	762d125b29a5e05244e681bcdd930406	Mastercard	37.018540583319961	-76.2982490694247133
17619	2020-03-29 08:38:07	2020-03-29	Clyde Kilback	clyde.kilback@woohoo.com	Tulsa	Oklahoma	3054105729802416	ee667ca4d771a28cecc7309a2f993a5e	Mastercard	36.1435274632085068	-95.8729093125045324
17620	2020-03-29 08:52:33	2020-03-29	Latonia Gleichner-Wintheiser	latonia.gleichner.wintheiser@woohoo.com	Rochester	New York	869946043720359096	07d36ce080c0d8bdc117c909fa4ddc1a	Diners Club / Carte Blanche	43.1185157264560459	-77.570854239701859
17621	2020-03-29 08:53:00	2020-03-29	Dr. Elizbeth Wilderman	dr.elizbeth.wilderman@geemail.com	Fort Worth	Texas	6011173461081243953	f021963984df76d786d6824c45837249	Diners Club / Carte Blanche	32.8000267777647849	-97.2562082421321463
17622	2020-03-29 08:59:04	2020-03-29	Jade Smith	jade.smith@geemail.com	New York	New York	869995200449627696	86d5aa8df7f36eb40aa872729a5bc2dc	JCB 15 digit	40.6551006338316938	-73.9746848889056565
17623	2020-03-29 09:06:20	2020-03-29	Mr. Shellie Harvey DVM	mr.shellie.harvey.dvm@geemail.com	New York	New York	869901268682377280	1b793c47b9806f5ecf52a398bffcc45c	Maestro	40.687089578317476	-74.0329674904130428
17624	2020-03-29 09:08:06	2020-03-29	Miss Erna Schaefer DDS	miss.erna.schaefer.dds@geemail.com	Evansville	Indiana	52829658394952604	de9f7abc948a79b0d9c9d338f7d931dd	Voyager	37.9545748246505852	-87.5765384789954879
17625	2020-03-29 09:34:16	2020-03-29	Lulla Smitham DVM	lulla.smitham.dvm@geemail.com	Saint Paul	Minnesota	6011826151318307009	83a5003484f6d66d284775a7a6caac04	VISA 13 digit	45.0408694236014071	-93.0592732794381732
17626	2020-03-29 10:44:25	2020-03-29	Aleena Bogan	aleena.bogan@geemail.com	Mesquite	Texas	4666639978061	798feb27569d3d11963b4c012257dc97	VISA 13 digit	32.7938144517406869	-96.58950792990737
17627	2020-03-29 11:06:59	2020-03-29	Breonna Armstrong	breonna.armstrong@woohoo.com	Thousand Oaks	California	869950366804148405	629f1ade12888adac04315227e212b66	Voyager	34.2559559014897772	-118.940642436678331
17628	2020-03-29 11:08:19	2020-03-29	Loring Nicolas-Bradtke	loring.nicolas.bradtke@geemail.com	New York	New York	676121643090414	03d2f7e42c40d3ec1ac9df3612691ce4	Diners Club / Carte Blanche	40.7304799310155232	-73.8567661557707851
17629	2020-03-29 11:47:20	2020-03-29	Lorne Beer	lorne.beer@geemail.com	Downey	California	180080722498852468	f82252d4497e9df4fa6625aa54b18b5d	VISA 16 digit	34.0358333216764066	-118.12551832395755
17630	2020-03-29 11:58:42	2020-03-29	Manson Kertzmann Sr.	manson.kertzmann.sr.@warmmail.com	West Covina	California	4920307312966	fd6f2d3d021346982f8b57f72bc9864f	JCB 15 digit	33.9748014789182733	-117.951809243911498
17631	2020-03-29 12:29:19	2020-03-29	Cindi Feil	cindi.feil@geemail.com	Berkeley	California	869977152652159788	1891ed36acb9a89a332738e7d0db9144	Mastercard	37.8909394289834296	-122.319625711434952
17632	2020-03-29 12:43:25	2020-03-29	Stevie Kirlin	stevie.kirlin@woohoo.com	San Francisco	California	3112264700242354567	024186448a8b18cad9b05ce90815c601	Diners Club / Carte Blanche	37.7829738919447138	-122.391513731222688
17633	2020-03-29 12:47:06	2020-03-29	Hal Bednar	hal.bednar@warmmail.com	Buffalo	New York	3528204805442514333	9d276eabda8323381644881c62fe9d60	VISA 16 digit	42.8127187866438135	-78.9260781969342418
17634	2020-03-29 12:52:43	2020-03-29	Dr. Elden DuBuque	dr.elden.dubuque@geemail.com	Jurupa Valley	California	4931510461070858	3caf59bd4e9170fb26cac14b4f8e916e	VISA 13 digit	33.9196945168007176	-117.466811755115543
17635	2020-03-29 12:59:06	2020-03-29	Catharine Abbott	catharine.abbott@warmmail.com	New York	New York	3792054785422201	7459145ab6fb07148cd644893dbbd43f	JCB 16 digit	40.687018457543104	-73.9976570421725484
17636	2020-03-29 13:03:55	2020-03-29	Irma Kassulke	irma.kassulke@geemail.com	Tampa	Florida	180039635967289529	96fa7c65257d85b4e9d4dbdbeb2202f2	JCB 16 digit	27.9600249586276703	-82.392407228632635
17637	2020-03-29 13:10:02	2020-03-29	Kristen Kreiger	kristen.kreiger@geemail.com	Lakewood	New Jersey	3096512689536490049	9d1742a92b39e8f65f448a2eb202a3b8	Voyager	40.0686674631018178	-74.1096206961475303
17638	2020-03-29 13:15:45	2020-03-29	Aliza Kirlin MD	aliza.kirlin.md@warmmail.com	Centennial	Colorado	676179263884094	430895dc4a8d1d361bc1ab3e5a9de9fe	Maestro	39.5658199254464407	-104.883959886141497
17639	2020-03-29 13:19:35	2020-03-29	Archibald Harvey	archibald.harvey@geemail.com	New York	New York	3337309223726913953	387e87c43069d3265a3cd9762b41d480	VISA 13 digit	40.7535592466350636	-73.9126331819582703
17640	2020-03-29 13:35:39	2020-03-29	Nicolas Labadie	nicolas.labadie@geemail.com	Lansing	Michigan	3096261429300739435	879f3d2ce704a3ca1ac8ba6af1558031	Discover	42.6684019699070589	-84.4955416297662936
17641	2020-03-29 13:39:32	2020-03-29	Mr. Nile Wiza PhD	mr.nile.wiza.phd@geemail.com	San Francisco	California	060402189948264	74e41a428528c1a9254228b9dc22623a	Maestro	37.7916967249794382	-122.459405811154639
17642	2020-03-29 13:45:30	2020-03-29	Lacy Brakus	lacy.brakus@geemail.com	Houston	Texas	6011026337255980605	6b77e1ca2996b4bf2253d0c3b437ef60	VISA 13 digit	29.6966593465380377	-95.4896172696273737
17643	2020-03-29 13:49:25	2020-03-29	Irvine Ebert	irvine.ebert@geemail.com	Raleigh	North Carolina	53985325721353274	5fce5d5defea39273e506cad09ffd575	VISA 16 digit	35.8955541153106807	-78.66583890509159
17644	2020-03-29 13:53:07	2020-03-29	Staci Fisher	staci.fisher@geemail.com	Norwalk	California	869945022691683032	4c3bcfa2899552d7b688c2eb34304a6d	Diners Club / Carte Blanche	33.9258321391999758	-118.178344817509881
17645	2020-03-29 14:11:49	2020-03-29	Siobhan Shanahan-Lehner	siobhan.shanahan.lehner@geemail.com	Lincoln	Nebraska	3033839457446308	18ec3f8e63289053bb012fe87370db9b	VISA 13 digit	40.8351526816859831	-96.695957061850649
17646	2020-03-29 14:12:55	2020-03-29	Walter Durgan	walter.durgan@geemail.com	El Paso	Texas	3158892443161533263	0f887d7433a141084093d94cace39e8c	Maestro	31.9298264951273829	-106.486917027410129
17647	2020-03-29 14:34:12	2020-03-29	Deward Hegmann	deward.hegmann@geemail.com	Brownsville	Texas	3051712777787655	7857f54adb2f55de1909c7184fd92b5f	American Express	25.9914066669143722	-97.3778038622532023
17648	2020-03-29 15:07:25	2020-03-29	Justus Hilll	justus.hilll@geemail.com	Pasadena	Texas	53211409464724598	341cf46e5c8016eddac46d67591f55a9	Mastercard	29.5790768026713273	-95.1468645884603177
17649	2020-03-29 15:14:09	2020-03-29	Sage Weber	sage.weber@woohoo.com	San Francisco	California	3158904968307690573	f241d1eb30aed7f4bbcc078202148f42	JCB 16 digit	37.7745296089770477	-122.399018815566095
17650	2020-03-29 15:27:57	2020-03-29	Dr. Hosteen Pfeffer	dr.hosteen.pfeffer@geemail.com	Chicago	Illinois	3528219092162326122	3596343982bb1a8fb0bfbca2834072b4	JCB 16 digit	41.8659739063423117	-87.6504239453498286
17651	2020-03-29 15:32:36	2020-03-29	Damond Blanda	damond.blanda@geemail.com	Philadelphia	Pennsylvania	3784772683413952	0f2b53cda9a089c999405be48c18b006	VISA 13 digit	40.0521707296330476	-75.1263551218334698
17652	2020-03-29 15:36:55	2020-03-29	Magdalena Schamberger	magdalena.schamberger@warmmail.com	Phoenix	Arizona	6011194516070462164	14f196124508499c6250b12fd90f54ab	JCB 15 digit	33.4761056824985914	-112.167864249639592
17653	2020-03-29 15:38:30	2020-03-29	Jaxen Deckow	jaxen.deckow@geemail.com	Los Angeles	California	3476213970649198	3a5c8cef85f3877f1f0bc87f91837ac4	Maestro	34.0164591875258822	-118.414671671436352
17654	2020-03-29 15:50:41	2020-03-29	Ivah Witting	ivah.witting@warmmail.com	Kansas City	Missouri	4467722213957488	5a187a6ac222cfba445a7615d1fd7738	Voyager	39.133903907595581	-94.5469517336916141
17655	2020-03-29 16:11:12	2020-03-29	Cathey Oberbrunner MD	cathey.oberbrunner.md@warmmail.com	Charlotte	North Carolina	52490798851140505	13c11db37f474cd54e9c31f5709ccb4d	JCB 16 digit	35.2148376777555754	-80.9090206837225736
17656	2020-03-29 16:16:33	2020-03-29	Darrien Flatley	darrien.flatley@warmmail.com	Port St. Lucie	Florida	3158050702788431138	3f4ebb19c0783c5905b5e00f6f87cbcf	JCB 16 digit	27.2258917790040371	-80.4869229264177335
17657	2020-03-29 16:27:25	2020-03-29	Mr. Myrtle Howell V	mr.myrtle.howell.v@warmmail.com	New York	New York	3040156388242299	b3a8c4e693ed411f25be072dd1f21abe	JCB 16 digit	40.6467948818802824	-73.9417588924884797
17658	2020-03-29 16:34:18	2020-03-29	Dr. Amina Anderson	dr.amina.anderson@geemail.com	Detroit	Michigan	869991589541741924	858472e0b274b2135e1295601ae648f7	VISA 16 digit	42.3058308970108641	-83.176690328319367
17659	2020-03-29 16:36:43	2020-03-29	Freddy Doyle	freddy.doyle@geemail.com	Milwaukee	Wisconsin	4620147347866906	beaa0393115b153609e07b4a912cb27f	Voyager	43.0853117128454102	-87.9591436168745133
17660	2020-03-29 16:38:35	2020-03-29	Virgil Becker	virgil.becker@geemail.com	Virginia Beach	Virginia	51173720544491982	de922c8d536f3c25232043f269154c10	Maestro	36.8128103859443243	-76.0983612262781719
17661	2020-03-29 16:40:44	2020-03-29	Mr. Laron Bernhard Sr.	mr.laron.bernhard.sr.@geemail.com	San Francisco	California	6011171069977290939	eecc9b22edda3bb94746b1e170665ca0	JCB 16 digit	37.7938209429425456	-122.43515153411937
17662	2020-03-29 17:14:06	2020-03-29	Ken O'Kon-Harber	ken.o'kon.harber@geemail.com	Fayetteville	North Carolina	3088261687799326374	12f2c54523d3f0eb121087583569d18f	Diners Club / Carte Blanche	35.158783986677598	-79.0597596386112258
17663	2020-03-29 17:21:06	2020-03-29	Lucinda Pouros-Kreiger	lucinda.pouros.kreiger@geemail.com	San Francisco	California	3766536651490165	3e29be5b5a560a5dc8ac7309820fc404	VISA 13 digit	37.7923375534761377	-122.425670061193031
17664	2020-03-29 17:44:27	2020-03-29	Tristan Wunsch-Prosacco	tristan.wunsch.prosacco@geemail.com	Los Angeles	California	180065692987101470	90bfcbc4740a1b8f73c5fffa41591614	VISA 16 digit	34.1058247254095974	-118.415079587557528
17665	2020-03-29 17:53:54	2020-03-29	Acey Mante	acey.mante@geemail.com	New York	New York	3337099488973814659	27e695b97de57cd731c8dd3844c75b01	American Express	40.7082979988530269	-73.926491260937226
17666	2020-03-29 17:54:08	2020-03-29	Candido Brown II	candido.brown.ii@warmmail.com	Chattanooga	Tennessee	3088506295608815028	6824bd6350728eb719c0fb6310d81e45	Diners Club / Carte Blanche	35.134719112593686	-85.2520858466453859
17667	2020-03-29 18:02:04	2020-03-29	Domingo Lynch	domingo.lynch@geemail.com	Los Angeles	California	4735156673667590	b6d97e4ef83542fa480a517fc3c29c42	VISA 16 digit	33.951480562738702	-118.46381602608524
17668	2020-03-29 18:08:28	2020-03-29	Suzy Cormier	suzy.cormier@geemail.com	San Francisco	California	210055695552056575	c682d027c9621cdca515268259f1e51f	American Express	37.7631424846358073	-122.399725569381914
17669	2020-03-29 18:28:37	2020-03-29	Reno Bechtelar	reno.bechtelar@geemail.com	Atlanta	Georgia	6011563750406188663	dbe90ce6a40e71226946a4d016fd6ce5	Voyager	33.8113603013843331	-84.4679000133693307
17670	2020-03-29 18:32:19	2020-03-29	Katharine Rempel	katharine.rempel@geemail.com	San Jose	California	869987391329651144	1de1ed91e3720262fd77ff3e58d8f27a	JCB 16 digit	37.3426316428285077	-121.896442747743421
17671	2020-03-29 18:50:38	2020-03-29	Alek Erdman	alek.erdman@geemail.com	Los Angeles	California	3112147265288847539	62a06a66e843fbb1aa50205400c953e0	Diners Club / Carte Blanche	34.1072472435288105	-118.505988610441975
17672	2020-03-29 18:51:50	2020-03-29	Brisa Kub	brisa.kub@warmmail.com	Madison	Wisconsin	6011408754427376801	ce30d9d1e30c7c35ee7ea9f02a0ab3f4	VISA 13 digit	43.1702659265112132	-89.344149566523356
17673	2020-03-29 18:53:08	2020-03-29	Jewell Bayer	jewell.bayer@warmmail.com	Rockford	Illinois	180032414081405818	3c234aaa8c1077aef72e9cb431cf1173	Voyager	42.2675140539661029	-89.1589072088528383
17674	2020-03-29 19:00:03	2020-03-29	Mr. Male Schimmel	mr.male.schimmel@woohoo.com	New York	New York	3043774464503009	30f3abf5cae2e998b6489f5f21b006c6	JCB 16 digit	40.5815461059324463	-73.8969658183295195
17675	2020-03-29 19:09:00	2020-03-29	Randell Feeney	randell.feeney@geemail.com	San Francisco	California	51768843583563353	96b42185f51c8f31bb248d2623eec090	Maestro	37.7687839842020736	-122.426012840950392
17676	2020-03-29 19:18:22	2020-03-29	Ford Nolan	ford.nolan@geemail.com	Seattle	Washington	3793332320129682	dbac9503111d8356b6b0288ed7080426	VISA 13 digit	47.5679589399527742	-122.348644507109739
17677	2020-03-29 19:34:45	2020-03-29	Brandan Leannon	brandan.leannon@warmmail.com	Fresno	California	4480083993893309	bf5502c5147d7affd08afe4c35d44fdd	Maestro	36.6996183889791396	-119.788007105990872
17678	2020-03-29 19:36:41	2020-03-29	Arletta Kling	arletta.kling@warmmail.com	Fort Worth	Texas	3337492267543705099	81ba69238431f4ae0efcd87f0f53603d	JCB 16 digit	32.761996484320612	-97.3651360738843721
17679	2020-03-29 19:57:43	2020-03-29	Tylor Wilkinson DDS	tylor.wilkinson.dds@geemail.com	Berkeley	California	3528671434550989866	272295abcf93ff8d59d49c756165000d	JCB 16 digit	37.8484255282187192	-122.301298555770956
17680	2020-03-29 20:05:06	2020-03-29	Joseph Rippin-Will	joseph.rippin.will@warmmail.com	New York	New York	180070474704164310	aad0bb667aa905b7e49726613bd2fb15	Mastercard	40.7239262459091833	-73.8572984219424455
17681	2020-03-29 20:15:20	2020-03-29	Mrs. Dayna Prosacco	mrs.dayna.prosacco@geemail.com	New Haven	Connecticut	3460747792413141	daeb78e9c6335dc2ed48931cb7c5c451	Voyager	41.2158825171172651	-72.9022702157031688
17682	2020-03-29 20:30:26	2020-03-29	Maebelle Mante	maebelle.mante@geemail.com	San Francisco	California	3028447662577910	5f69f57412fc7827b935215e05bf9f46	JCB 16 digit	37.7839202012056887	-122.434433562891925
17683	2020-03-29 20:31:15	2020-03-29	Luana Ledner	luana.ledner@geemail.com	Toledo	Ohio	4339380020168611	e210c20f04102886bfab81054e4859cc	VISA 16 digit	41.7302259431857578	-83.535212353463848
17684	2020-03-29 20:36:15	2020-03-29	Jamaal Fadel	jamaal.fadel@geemail.com	El Paso	Texas	3781101057270025	e272bc5bc89d0c7c5fcc6d1cf8f3d43e	VISA 16 digit	31.9251687536310413	-106.392585024422047
17685	2020-03-29 20:39:33	2020-03-29	Jarrad Gottlieb-Monahan	jarrad.gottlieb.monahan@geemail.com	San Francisco	California	3057916127010411	d8d58744c0777ce4f7bb82af7f357b1b	Discover	37.7659570302066001	-122.454820037313056
17686	2020-03-29 20:46:31	2020-03-29	Mr. Zack Jaskolski	mr.zack.jaskolski@geemail.com	New York	New York	180076964448317467	959af98b5a4b09526d2393055f670822	Maestro	40.7135652706250539	-73.9183584798023077
17687	2020-03-29 20:50:45	2020-03-29	Mr. Lionel Baumbach DDS	mr.lionel.baumbach.dds@geemail.com	Little Rock	Arkansas	3051804186250464	029f5169df6b48d9cc40f7e06adb7fbc	Voyager	34.63028691125065	-92.4134024766612754
17688	2020-03-29 20:59:28	2020-03-29	Linus Mills	linus.mills@geemail.com	San Francisco	California	6011341138527990663	d0dd9c13411d5e21f06581b2aa767d6f	American Express	37.7648889206992564	-122.431757353044603
17689	2020-03-29 21:01:51	2020-03-29	Veva O'Hara	veva.o'hara@warmmail.com	Frisco	Texas	3434817442682578	5a4f487f7b541fc54d295cf25a9e4e8c	Discover	33.1467635984528783	-96.817321935177219
17690	2020-03-29 21:02:06	2020-03-29	Ms. Rhoda Schultz	ms.rhoda.schultz@geemail.com	Glendale	Arizona	52165325760358483	6e974b544b55fac27e6be29847a7a0b0	Discover	33.4785762950073931	-112.235807940855238
17691	2020-03-29 21:10:13	2020-03-29	Taylor Johnson-Shanahan	taylor.johnson.shanahan@geemail.com	San Francisco	California	3050178254338936	959ff434d7fc9652ad654c6bab1d6b73	JCB 16 digit	37.7834928887329013	-122.446515895969
17692	2020-03-29 21:14:00	2020-03-29	Deion Flatley	deion.flatley@woohoo.com	Charlotte	North Carolina	3402774926565928	e338580ab5a2318b36cb05bdf91221b1	VISA 16 digit	35.1493402723941912	-80.7919772020950973
17693	2020-03-29 21:17:32	2020-03-29	Arkie Medhurst	arkie.medhurst@geemail.com	Richardson	Texas	3088659026935833201	f9f8445d20383a493116c0cc89890e8c	Discover	33.028720745234935	-96.7543831617798702
17694	2020-03-29 21:19:27	2020-03-29	Joel Kemmer	joel.kemmer@woohoo.com	Long Beach	California	060441194320812	f0a1d248d25b59d5e021de24b839d343	VISA 16 digit	33.8999330000773043	-118.059190367457646
17695	2020-03-29 21:22:22	2020-03-29	Katharine Nikolaus	katharine.nikolaus@geemail.com	San Francisco	California	675979048042125	af98af8a42043e2d8f512edce4a5b056	VISA 16 digit	37.7875569927923323	-122.402775509220561
17696	2020-03-29 21:38:59	2020-03-29	Brianda Cormier	brianda.cormier@geemail.com	Raleigh	North Carolina	3042107091208331	c719215daec012d17ba9aea1c02e0edb	JCB 16 digit	35.9143010493502004	-78.5768423266179923
17697	2020-03-29 21:44:43	2020-03-29	Mr. Boston Robel DDS	mr.boston.robel.dds@woohoo.com	Temecula	California	180090192875579449	8e57c6517f457c59db481546ac1acc31	JCB 16 digit	33.5100456077739608	-117.081784456428878
17698	2020-03-29 21:49:10	2020-03-29	Ashly Douglas	ashly.douglas@warmmail.com	San Angelo	Texas	3528046559973237093	79f9cdb178fd04314894ef073b411c32	VISA 16 digit	31.5231236921776059	-100.422582948638137
17699	2020-03-29 21:52:05	2020-03-29	Pattie Harvey	pattie.harvey@woohoo.com	Aurora	Colorado	3096153476175246757	df0cab85807c464b7715dcc5228e1f56	JCB 16 digit	39.6180533940549964	-104.648937564168875
17700	2020-03-29 22:14:37	2020-03-29	Mr. Diamond Stiedemann	mr.diamond.stiedemann@warmmail.com	Oakland	California	676397764404840	218626ea05df516806b4f5c38182c703	Mastercard	37.7757775244043827	-122.253268271934473
17701	2020-03-29 22:21:44	2020-03-29	Algot Vandervort	algot.vandervort@geemail.com	New York	New York	3056207901213723	6bfb088c262a6c5c7d3ab27e034bc088	Diners Club / Carte Blanche	40.7524161443803479	-73.847371081624928
17702	2020-03-29 22:22:54	2020-03-29	Fitzgerald Stark-Kling	fitzgerald.stark.kling@geemail.com	San Francisco	California	4163364332797	bb1fd8e70e4deaf06a5435200141fabc	JCB 16 digit	37.7618255772287839	-122.407476463585169
17703	2020-03-29 22:59:26	2020-03-29	Bert Schultz-Swaniawski	bert.schultz.swaniawski@geemail.com	Waterbury	Connecticut	3528011090693708578	a282e9e15979f7835482a025ff3cbc32	Mastercard	41.612234472533693	-73.0572304200760954
17704	2020-03-29 23:09:24	2020-03-29	Cheyenne Wiza	cheyenne.wiza@woohoo.com	Greeley	Colorado	869909357300801417	67103760752c03991c25a8b44bf19f2f	VISA 16 digit	40.4694005228180487	-104.758606902773309
17705	2020-03-29 23:12:53	2020-03-29	Odell Okuneva	odell.okuneva@warmmail.com	Fort Lauderdale	Florida	53400021909332241	b422ff3047517ab5e6135240c05ce67a	JCB 15 digit	26.1801150699600598	-80.0899922908570545
17706	2020-03-29 23:15:02	2020-03-29	Mr. Kingston Rempel	mr.kingston.rempel@geemail.com	Riverside	California	180074897750693269	d75f845b73371f3a2b00d23094549bd2	Discover	33.8546109207388	-117.319896980418633
17707	2020-03-30 00:29:06	2020-03-30	Mariah Satterfield	mariah.satterfield@geemail.com	Fresno	California	180062688901451242	4135287dca1bdac79f7149f042110730	JCB 16 digit	36.8621341585986286	-119.743757134453958
17708	2020-03-30 00:59:24	2020-03-30	Mira Blanda	mira.blanda@geemail.com	San Francisco	California	3031953968615616	49e82d4fea7901da36880dbe26df0127	JCB 16 digit	37.787787081501186	-122.434825012254436
17709	2020-03-30 01:27:59	2020-03-30	Faron Metz	faron.metz@woohoo.com	High Point	North Carolina	210015781625489800	b33f7fb1f61b930165f19e150971a12b	American Express	36.0564151761680876	-80.0423802411854268
17710	2020-03-30 01:35:05	2020-03-30	Mrs. Nedra Larkin MD	mrs.nedra.larkin.md@geemail.com	Los Angeles	California	3158692155928028138	e51a14f37ffee9ba7175365f0b13be4f	JCB 16 digit	33.9443114131089274	-118.406027881427846
17711	2020-03-30 01:37:06	2020-03-30	Dr. Lenon Osinski	dr.lenon.osinski@geemail.com	Centennial	Colorado	3112046950932424403	6bdbf86d4ddbf6fc872d64617527c1bd	Maestro	39.4910750274587414	-104.895461557934439
17712	2020-03-30 01:47:51	2020-03-30	Kaitlynn Orn	kaitlynn.orn@warmmail.com	Kansas City	Missouri	3013772935561291	630812f749b4f43710eb8709f8d09a5d	Mastercard	39.0547417260542531	-94.4816082611437906
17713	2020-03-30 02:04:30	2020-03-30	Glendora Koepp	glendora.koepp@geemail.com	Lakewood	Colorado	180015560678047099	7bfcdec989b77bfe724c1e9dfc00f409	VISA 16 digit	39.756880275154117	-105.116242267566165
17714	2020-03-30 02:10:12	2020-03-30	Jamarcus O'Kon	jamarcus.o'kon@woohoo.com	Aurora	Illinois	3112703511968501227	93c52e51433090e994737c81f01ac7ed	VISA 16 digit	41.8471650840006788	-88.3146722670573752
17715	2020-03-30 02:56:07	2020-03-30	Henrietta Stark	henrietta.stark@warmmail.com	Cleveland	Ohio	4838484569410453	3de853dbd7ae1756dbd75575dc75359c	Mastercard	41.4090563029833092	-81.6987465687800238
17716	2020-03-30 03:06:26	2020-03-30	Lelia Ernser	lelia.ernser@geemail.com	San Francisco	California	060458031379926	ebef38444dee019d95541652acce974a	JCB 16 digit	37.7600779929142618	-122.437180824368312
17717	2020-03-30 03:37:53	2020-03-30	Ms. Verlie Bogisich DVM	ms.verlie.bogisich.dvm@geemail.com	Aurora	Illinois	4405378138458261	e9e39eb6a440616f2738db1be2bd049e	Discover	41.7085122003909206	-88.3767686319000916
17718	2020-03-30 03:38:59	2020-03-30	German Trantow IV	german.trantow.iv@geemail.com	Charlotte	North Carolina	51715423582214839	de39585b3531ca3ae1488fe18621dece	VISA 16 digit	35.1266469924032663	-80.9042915645465257
17719	2020-03-30 04:00:35	2020-03-30	Amani Nienow	amani.nienow@warmmail.com	Pembroke Pines	Florida	3035223113845864	40b3570da79e9b7f6faae78808a9f05b	Voyager	26.0376779468301685	-80.4031171517349748
17720	2020-03-30 04:03:00	2020-03-30	Jeramie Bauch	jeramie.bauch@woohoo.com	West Jordan	Utah	4197031043041019	374cd71050631338d017d2512e9a75db	Voyager	40.6115168585233448	-111.942928349933766
17721	2020-03-30 04:03:49	2020-03-30	Everette Satterfield	everette.satterfield@geemail.com	Arlington	Texas	3721923651189456	b3edddafa53f5e8792551993e85fcd6a	VISA 16 digit	32.6674116165161124	-97.1144891124710483
17722	2020-03-30 04:15:06	2020-03-30	Miss Eloisa Kuphal MD	miss.eloisa.kuphal.md@warmmail.com	Austin	Texas	676333348142531	b549a9ea3ac2fc0a28f11084afffa603	JCB 16 digit	30.3252878340553487	-97.720420313138149
17723	2020-03-30 04:37:08	2020-03-30	Val Olson	val.olson@woohoo.com	San Francisco	California	3487468846160476	008178ff2b6d16f06ae3c5e93142d50d	Diners Club / Carte Blanche	37.7469549131616233	-122.409298229818376
17724	2020-03-30 04:38:03	2020-03-30	Mr. Durward Schmidt Jr.	mr.durward.schmidt.jr.@woohoo.com	Santa Clarita	California	210037401561726974	5c2ba5c2ae06ff2549fc9d8c58023314	VISA 16 digit	34.3213616666123258	-118.495383343483127
17725	2020-03-30 04:48:14	2020-03-30	Dr. Angelo Rempel	dr.angelo.rempel@geemail.com	Los Angeles	California	4720153618407692	19eea2f986a241088a3827a691db9802	JCB 16 digit	34.1185983239073281	-118.323325442102913
17726	2020-03-30 04:51:25	2020-03-30	Loyal Schmeler	loyal.schmeler@woohoo.com	Allentown	Pennsylvania	4694003390044	e0fdeee63f2839c6753c92cfeacf4fd4	JCB 16 digit	40.5637872657984531	-75.4201193136643582
17727	2020-03-30 05:07:06	2020-03-30	Deann Funk-Gleichner	deann.funk.gleichner@geemail.com	San Francisco	California	3112640122923715807	9dc18f514d9e6cc035681d2a349d8e7c	Discover	37.7582023560487201	-122.433565826341408
17728	2020-03-30 05:30:30	2020-03-30	Daron Smitham	daron.smitham@geemail.com	Dallas	Texas	210083851851472379	8de9a30bd04cbb825623f11f5b46c0f0	Diners Club / Carte Blanche	32.7139373172346524	-96.8561512997336678
17729	2020-03-30 05:44:26	2020-03-30	Cyrus Kerluke	cyrus.kerluke@geemail.com	Philadelphia	Pennsylvania	3112625392457256671	037c7cd8efc9a79fb593273696cea45f	American Express	39.9958751089364313	-75.220074889566007
17730	2020-03-30 05:50:23	2020-03-30	Jeanie Stoltenberg-Kerluke	jeanie.stoltenberg.kerluke@geemail.com	Raleigh	North Carolina	4965670216543069	08730a438c17d85f6b0b8e15d6f2ad45	Maestro	35.8067353375390169	-78.5432006028883194
17731	2020-03-30 06:15:57	2020-03-30	Jeremy Kshlerin	jeremy.kshlerin@woohoo.com	San Francisco	California	3528732717591573138	345e3112939fd7ad1f5131da67d712ea	Diners Club / Carte Blanche	37.7855358736683797	-122.415757008836934
17732	2020-03-30 06:43:47	2020-03-30	Trisha Blanda	trisha.blanda@woohoo.com	New York	New York	869943607663780345	c10e7225897ec5596a65b98da0649734	Mastercard	40.5938352185059301	-74.0079432852461849
17733	2020-03-30 06:51:44	2020-03-30	Cheyanne Ondricka	cheyanne.ondricka@geemail.com	Oklahoma City	Oklahoma	3725808830785959	e57d9d7e17faff809a9c8bb67e26d810	JCB 16 digit	35.5562994236968493	-97.541497767799342
17734	2020-03-30 07:05:59	2020-03-30	Wing Mitchell-Rath	wing.mitchell.rath@woohoo.com	Mobile	Alabama	3528308625505256332	dc81508f1a546071646c0ac61b842238	JCB 16 digit	30.7164239071417597	-88.1102974571891195
17735	2020-03-30 07:10:07	2020-03-30	Luster Schmitt	luster.schmitt@geemail.com	Cincinnati	Ohio	52549121526331634	52bdaa4ea737c2757ee40fc70253ffb7	Voyager	39.0761104034025237	-84.4535232905104749
17736	2020-03-30 07:26:30	2020-03-30	Imelda Kihn	imelda.kihn@geemail.com	Dallas	Texas	4619143388889	5558991647b92f60efa978bb502fb30c	JCB 16 digit	32.8266537382539383	-96.8234890247192226
17737	2020-03-30 07:31:32	2020-03-30	Trisha Kihn	trisha.kihn@warmmail.com	New York	New York	3088956385167735769	4cab27b6826572d0d719a15c83d49a22	VISA 16 digit	40.6543320005983091	-74.0236556590896129
17738	2020-03-30 08:14:51	2020-03-30	Everette Schumm-Jaskolski	everette.schumm.jaskolski@woohoo.com	Raleigh	North Carolina	4966480670227160	09b8d06b61b09e81aaa075abfa4e338b	JCB 16 digit	35.786479745958367	-78.7302934441652127
17739	2020-03-30 08:19:33	2020-03-30	Frederica Klein-Eichmann	frederica.klein.eichmann@geemail.com	Chicago	Illinois	4418187683012612	ca6881de24f967ab8b744dc6c51c650d	Mastercard	41.7465097432792192	-87.6053015495680256
17740	2020-03-30 08:22:47	2020-03-30	Latrell Hessel-Von	latrell.hessel.von@geemail.com	San Francisco	California	4977546965962	a72a5f751d959e86433ae12141e78b02	JCB 16 digit	37.795490163136634	-122.447244686419623
17741	2020-03-30 08:26:47	2020-03-30	Ms. Michaele Kirlin MD	ms.michaele.kirlin.md@geemail.com	Tallahassee	Florida	52396136586906350	a13b6656aedf87663613105cf971c565	Diners Club / Carte Blanche	30.5370885402917871	-84.2566538092229536
17742	2020-03-30 08:30:15	2020-03-30	Dollie Blanda	dollie.blanda@warmmail.com	San Diego	California	6011753789091828381	a109d4f67033158b65d2c180e5676609	Diners Club / Carte Blanche	32.8105018911019002	-117.062605239814147
17743	2020-03-30 08:30:52	2020-03-30	Maximilian Watsica-Kautzer	maximilian.watsica.kautzer@geemail.com	San Jose	California	3337245844415988662	0f587f310521b90218a1e059b930deb8	VISA 13 digit	37.3022391494650378	-121.756336492089176
17744	2020-03-30 08:31:26	2020-03-30	Orrie Okuneva	orrie.okuneva@geemail.com	Des Moines	Iowa	639086407242766	532b2a38ee978d9cf1424b735a5cb6bb	Voyager	41.597888640568037	-93.6793051117610247
17745	2020-03-30 09:01:42	2020-03-30	Dr. Clement Friesen DDS	dr.clement.friesen.dds@geemail.com	Bridgeport	Connecticut	676301209688785	ed2d29b646cbf145500a28eaa47a4081	Discover	41.1008469049051399	-73.1212332438577022
17746	2020-03-30 09:47:27	2020-03-30	Laurance Crist-Bradtke	laurance.crist.bradtke@geemail.com	Boston	Massachusetts	210098747067807221	81cccd49bc4c9480fc7d0c52e039fc40	Diners Club / Carte Blanche	42.3826237709894755	-70.9662319265723198
17747	2020-03-30 10:22:21	2020-03-30	Thornton Ledner Sr.	thornton.ledner.sr.@geemail.com	Fresno	California	503811179152845	6cda970d572cf04afea9a0957c14a1ad	JCB 15 digit	36.8527502459812908	-119.785943153883892
17748	2020-03-30 10:33:51	2020-03-30	Danita Effertz	danita.effertz@woohoo.com	Baltimore	Maryland	4343303951336001	7823f64e980366a0f385619fbb1d8105	VISA 16 digit	39.293404066003859	-76.5587923543080677
17749	2020-03-30 10:43:16	2020-03-30	Lilla Larson	lilla.larson@woohoo.com	Ventura	California	869935966697238658	1452e60988a1c35e7a8bb2f04331674e	JCB 15 digit	34.3220743876110745	-119.175199138755715
17750	2020-03-30 11:15:40	2020-03-30	Kayleigh Kuhic	kayleigh.kuhic@woohoo.com	Anaheim	California	3088194073845652562	1e05d83d0738892c630cacbdde4a6606	Voyager	33.7688176974952228	-117.683418505007765
17751	2020-03-30 11:46:41	2020-03-30	Cael Robel	cael.robel@warmmail.com	Alexandria	Virginia	3096919439822990859	729efd4898be80ae0b8e2b602c659fc7	American Express	38.7400515725951635	-77.0665623971246276
17752	2020-03-30 12:13:13	2020-03-30	Mr. Messiah Crist IV	mr.messiah.crist.iv@geemail.com	Los Angeles	California	3096371578031341254	e836e73089db71c319273b88794eed33	VISA 16 digit	34.0743223538488138	-118.337815256322912
17753	2020-03-30 12:39:54	2020-03-30	Lois Murray	lois.murray@geemail.com	Cincinnati	Ohio	4428833548515053	ae19b457444abc0c0474a9f8a742ce3b	Voyager	39.0724379908524426	-84.5011537587076305
17754	2020-03-30 12:47:27	2020-03-30	Tim Lindgren	tim.lindgren@geemail.com	San Francisco	California	3528264846486883496	bffe01bd846cd936b8251b9a80f433ed	JCB 16 digit	37.7533034122498208	-122.399535360306515
17755	2020-03-30 12:52:20	2020-03-30	Dr. Angus Torp MD	dr.angus.torp.md@warmmail.com	Elizabeth	New Jersey	3025813030883764	9a997b15cc6c11880e144948473d7cd7	JCB 15 digit	40.6144018289759785	-74.1711733007747682
17756	2020-03-30 13:06:50	2020-03-30	Posey Hirthe-Goldner	posey.hirthe.goldner@geemail.com	Santa Clara	California	55966783365033508	33e516af283edf0585b611c1b7297b0c	JCB 16 digit	37.3331084097553045	-122.042674426687512
17757	2020-03-30 13:13:19	2020-03-30	Dawn Weber	dawn.weber@warmmail.com	Hampton	Virginia	3039643650231614	ddcf59d594b7e3b1e129232b070ac38b	Mastercard	37.0967275784835238	-76.2261885397233101
17758	2020-03-30 13:21:09	2020-03-30	Frankie Prohaska	frankie.prohaska@woohoo.com	Visalia	California	4365992981069161	187a297b094cd92aba0924a3475e6674	JCB 16 digit	36.407797470404951	-119.400772649341832
17759	2020-03-30 13:23:14	2020-03-30	Letty Ratke-Wilderman	letty.ratke.wilderman@geemail.com	San Diego	California	869929648960075029	aac350987cd7c8315a3fdc42401b9e5f	Mastercard	32.7896744179606472	-117.131859097527339
17760	2020-03-30 13:24:49	2020-03-30	Dr. Hayward Nitzsche	dr.hayward.nitzsche@woohoo.com	Fresno	California	3158059411074957555	4491c586cc6f0d17ff496b267f5d7ead	VISA 13 digit	36.6988792993467285	-119.85968628578037
17761	2020-03-30 13:37:33	2020-03-30	Miss Yareli Beier	miss.yareli.beier@warmmail.com	Salt Lake City	Utah	210020569079116471	eb0d595271182ef03c2e03789192e211	JCB 15 digit	40.6922507068287587	-111.845139219792557
17762	2020-03-30 13:48:07	2020-03-30	Dr. Wes Goodwin II	dr.wes.goodwin.ii@geemail.com	Bridgeport	Connecticut	4039951626181860	9986e5fe2ec16af72e96d48e664ffe8c	JCB 16 digit	41.1968526852015344	-73.1167237440489259
17763	2020-03-30 13:53:33	2020-03-30	Aric Wisoky	aric.wisoky@geemail.com	Raleigh	North Carolina	3158328888454864136	96216ea38cff53989662f99f5102c80a	VISA 16 digit	35.7467889516282824	-78.5854615318525589
17764	2020-03-30 14:03:04	2020-03-30	Dr. Yoel Streich DDS	dr.yoel.streich.dds@warmmail.com	San Francisco	California	502079477949881	a7689e275dc0d89ecb7705aa4845fae0	JCB 16 digit	37.7917016505502232	-122.446585487912017
17765	2020-03-30 14:06:33	2020-03-30	Easton Schiller	easton.schiller@woohoo.com	Austin	Texas	060490197587703	5720e26e8c5dcc3fa417454f92db2322	VISA 16 digit	30.2500050975136432	-97.7006381261866608
17766	2020-03-30 14:28:15	2020-03-30	Ms. Tamera Bergnaum	ms.tamera.bergnaum@geemail.com	San Francisco	California	869934468882763518	7910577458f133e220f6408d6543985c	JCB 16 digit	37.7509852995768398	-122.444522731739397
17767	2020-03-30 14:28:59	2020-03-30	Bentley Koch	bentley.koch@woohoo.com	San Francisco	California	4489621206404793	9b1812e4f0b84f40ea77b4ff33d554dd	JCB 16 digit	37.7658880875687757	-122.403584731923146
17768	2020-03-30 14:32:15	2020-03-30	Pat Abernathy	pat.abernathy@warmmail.com	Sacramento	California	6011894939550805723	9935c586e145284972c144914b71d53a	JCB 16 digit	38.5550074233472344	-121.501160933101914
17769	2020-03-30 14:35:19	2020-03-30	Chana Walsh	chana.walsh@warmmail.com	Chicago	Illinois	3780302710704183	3ed614e5074b25d3331a39f70b38578b	VISA 16 digit	41.9163722915876704	-87.7680366054207042
17770	2020-03-30 14:47:18	2020-03-30	Martin Ratke	martin.ratke@woohoo.com	Baton Rouge	Louisiana	4339167998845043	7f5ab6ebbc299b435c407055e432585c	Diners Club / Carte Blanche	30.3969458178363752	-91.1762515635803368
17771	2020-03-30 15:12:37	2020-03-30	Medora Satterfield	medora.satterfield@geemail.com	San Bernardino	California	869961279558238008	528fce7ddb5026108ba827d9d3dff624	Voyager	34.1497298091448798	-117.226135293698306
17772	2020-03-30 15:25:56	2020-03-30	Kash Balistreri-Emard	kash.balistreri.emard@geemail.com	Knoxville	Tennessee	4813264167581163	fbfafd6b236445d21d2535186e7a6ae8	JCB 16 digit	35.873762623785808	-84.0321897064551706
17773	2020-03-30 15:27:01	2020-03-30	Pasquale Zulauf-Wiegand	pasquale.zulauf.wiegand@geemail.com	Thousand Oaks	California	54285134748448555	52e9306b1cbeeb7a0a8822f84a0d9796	Voyager	34.1653896430313608	-118.883901985167341
17774	2020-03-30 15:29:15	2020-03-30	Chandra Considine	chandra.considine@geemail.com	Houston	Texas	4348821723544680	e72d5e2c9c1b74e77050ac4b02e1472f	VISA 16 digit	29.8142395545341081	-95.4330564518008373
17775	2020-03-30 16:16:13	2020-03-30	Nya Fadel	nya.fadel@warmmail.com	New York	New York	3337629066616609279	ca18dd03481b716de666795975fe6d22	JCB 16 digit	40.6605696440432212	-73.9135766099102796
17776	2020-03-30 16:17:37	2020-03-30	Rayne Kuvalis	rayne.kuvalis@warmmail.com	Lubbock	Texas	3040289304344632	e69c512c3017436677f7b6e1471a67b6	JCB 16 digit	33.5361128375440884	-101.931354495269062
17777	2020-03-30 16:28:44	2020-03-30	Regenia Stokes	regenia.stokes@geemail.com	San Francisco	California	4295760578525084	1e40bc0ecdfec73071ddb95f1a88d674	JCB 16 digit	37.7766346557098629	-122.42677265617904
17778	2020-03-30 16:59:23	2020-03-30	Anner Rutherford	anner.rutherford@geemail.com	San Francisco	California	3491745676301518	109b1fe0659238ddcc195d6bf182dc6e	VISA 16 digit	37.7910675505696787	-122.41440527631211
17779	2020-03-30 17:14:04	2020-03-30	Lance Spencer	lance.spencer@geemail.com	Carlsbad	California	869957812651521064	45e77e86dcc704ebcc7c198490ff6428	VISA 16 digit	33.1897594926353534	-117.249376986061407
17780	2020-03-30 17:23:48	2020-03-30	Mr. Cal Leffler	mr.cal.leffler@geemail.com	Denver	Colorado	589357268290327	40534e7a63141dc1c5d688718cb17f3b	Mastercard	39.6811642369307549	-104.836970862631134
17781	2020-03-30 17:26:27	2020-03-30	Kaylynn Bechtelar	kaylynn.bechtelar@geemail.com	San Francisco	California	3781420975695919	2a4d65f44321630b232adb503d012a48	VISA 13 digit	37.8298376442862008	-122.42582731481734
17782	2020-03-30 17:28:39	2020-03-30	Lora Morar	lora.morar@woohoo.com	Phoenix	Arizona	3088153044351041986	f4742a0cf35a14a6b15c2b3ef79c5315	Maestro	33.5294241520043457	-112.080862887196616
17783	2020-03-30 17:30:13	2020-03-30	Miss Joni Bruen	miss.joni.bruen@woohoo.com	New York	New York	55311956263268457	7fda586c4b5afa472c53f231928339bc	Maestro	40.69361049875058	-73.8711726380407754
17784	2020-03-30 18:08:13	2020-03-30	Dr. Boyce Upton	dr.boyce.upton@geemail.com	San Francisco	California	4304420830622299	d2d5a44457281112d67f765681d5a796	Diners Club / Carte Blanche	37.7714050325906143	-122.420365411214917
17785	2020-03-30 18:24:49	2020-03-30	Oral Hilll DDS	oral.hilll.dds@geemail.com	Ontario	California	869916858306337547	066426f0adbf23a3da60728c6ef8b942	Discover	34.0976764944061657	-117.53148912341409
17786	2020-03-30 18:29:05	2020-03-30	Dr. Bailee Bins	dr.bailee.bins@woohoo.com	Oakland	California	4663140990901664	8f27b17054adf01df7416cc1e71ba1e9	Voyager	37.7890575009490775	-122.259137001910588
17787	2020-03-30 18:33:51	2020-03-30	Mr. Jonathon Carroll	mr.jonathon.carroll@geemail.com	Detroit	Michigan	3762947285925712	ef1d1f309da7bf704c3f6786f851e5d1	Diners Club / Carte Blanche	42.4119771539159132	-83.1355687241654806
17788	2020-03-30 18:39:48	2020-03-30	Pallie Feest	pallie.feest@geemail.com	San Francisco	California	6011677719794635307	03a897a405539731deccd779c6bbb3ef	JCB 16 digit	37.7663831934802303	-122.393695684717329
17789	2020-03-30 18:57:24	2020-03-30	Wardell Dach-Runolfsdottir	wardell.dach.runolfsdottir@woohoo.com	San Mateo	California	869934344458014349	fa75dfa135fdee71b4d683532ce6cf73	JCB 16 digit	37.532399615726618	-122.239964624572906
17790	2020-03-30 19:19:14	2020-03-30	Henery O'Hara	henery.o'hara@geemail.com	San Francisco	California	51315011203317737	9826b7aeb303eafed24d9da0d3149ad9	American Express	37.8185364727247659	-122.437468950678678
17791	2020-03-30 19:34:30	2020-03-30	Sofia Deckow	sofia.deckow@warmmail.com	Washington	District of Columbia	3475047601829469	ed218216ae83c5531e02c9035036b246	Maestro	38.9014717276006934	-76.9392117434859273
17792	2020-03-30 19:41:02	2020-03-30	Octavie Spinka	octavie.spinka@geemail.com	Albuquerque	New Mexico	4787563870635	d05691829aa20ea3a1ac5b795a289cac	VISA 16 digit	35.0762482238136286	-106.731400711329286
17793	2020-03-30 19:53:11	2020-03-30	Dr. Asa Ondricka III	dr.asa.ondricka.iii@geemail.com	Los Angeles	California	4068105318163017	7c37955db5f422d7d56b6905d1df0a6f	JCB 16 digit	34.073355244319508	-118.457789974984891
17794	2020-03-30 20:35:10	2020-03-30	Nathanael Thompson	nathanael.thompson@geemail.com	Wichita	Kansas	6011055030596472614	c67bfe2c4b8f3ce5553e3e142fd9609f	VISA 13 digit	37.7065621112816061	-97.2546132254615401
17795	2020-03-30 20:51:34	2020-03-30	Jaylon Shanahan	jaylon.shanahan@geemail.com	Philadelphia	Pennsylvania	3096666676770629634	15e189be99b8624f1cd85c06430b9ba2	Maestro	40.0899167930200662	-75.090099268536278
17796	2020-03-30 21:00:24	2020-03-30	Mechelle Bernhard	mechelle.bernhard@geemail.com	Miramar	Florida	4716490777290477	97782334dd82f0e7b37b0557427570d2	JCB 15 digit	25.9168506528697904	-80.3817477091208161
17797	2020-03-30 21:01:37	2020-03-30	Louie Crooks-Mayer	louie.crooks.mayer@woohoo.com	San Antonio	Texas	3418677517270802	a82d5956431cd9b22252eb7f90cf2b9c	Diners Club / Carte Blanche	29.4546073850315082	-98.5697477626450365
17798	2020-03-30 21:09:26	2020-03-30	Stone Hackett	stone.hackett@geemail.com	San Francisco	California	4552378579250269	7958802003fc08448a74ba503915fd1f	Diners Club / Carte Blanche	37.7862921659111421	-122.413309120455608
17799	2020-03-30 21:22:25	2020-03-30	Frederick Renner	frederick.renner@geemail.com	Tacoma	Washington	6011237592016173677	fe30e16545166ba0716f0815e4a630e8	JCB 16 digit	47.1893355403214727	-122.507595752435918
17800	2020-03-30 21:25:18	2020-03-30	Lovell Satterfield	lovell.satterfield@geemail.com	Philadelphia	Pennsylvania	55355625117343009	76936d2468e9a567f2786b8555b5d49a	Voyager	40.0934485419612372	-75.1381523836769247
17801	2020-03-30 21:28:06	2020-03-30	Jaqueline Mueller-Okuneva	jaqueline.mueller.okuneva@geemail.com	San Francisco	California	3724577116191593	9a2c5a2741d25bd6f6b8c06e3fb43d20	Voyager	37.7677504227382457	-122.425287242977546
17802	2020-03-30 21:46:46	2020-03-30	Dakotah Boehm	dakotah.boehm@warmmail.com	San Bernardino	California	3733089531825929	1d7c214fa1443edc2d35a9d99d3b262b	Discover	34.1500379964508056	-117.390651327908415
17803	2020-03-30 21:49:29	2020-03-30	Dylan Effertz PhD	dylan.effertz.phd@warmmail.com	Centennial	Colorado	869970059402479530	690f6c501132664b7c2b6f18d4906ba5	VISA 16 digit	39.6290337222669322	-104.805059039069718
17804	2020-03-30 22:06:35	2020-03-30	Vada Marquardt	vada.marquardt@woohoo.com	Wichita	Kansas	869954586124610224	f41ddfc277dff8c31087be4049ae386a	Mastercard	37.7479483556810749	-97.4452416294455475
17805	2020-03-30 22:17:44	2020-03-30	Haywood Bins	haywood.bins@geemail.com	San Francisco	California	4427535076787936	032c01116ed063b7e21cbf7adc96b7ad	American Express	37.7732862039344326	-122.440370895251661
17806	2020-03-30 22:29:09	2020-03-30	Barry Howe	barry.howe@geemail.com	Garden Grove	California	4239586903720	2e3919532b812571c63e65d535d20a3f	Voyager	33.7107088358897684	-117.917774250499903
17807	2020-03-30 22:37:15	2020-03-30	Jamey Kutch	jamey.kutch@warmmail.com	San Francisco	California	180079382445196403	22fb3e1adfe9f46ad108fb0516f630c3	VISA 16 digit	37.7833621022723634	-122.468177176354033
17808	2020-03-30 22:39:04	2020-03-30	Buelah Cummerata-Hessel	buelah.cummerata.hessel@geemail.com	Tempe	Arizona	3417433229632520	afbc228cb15b7f51e5a3e2c7e0e5f3bc	JCB 15 digit	33.4366083164621131	-111.87652126858309
17809	2020-03-30 22:43:59	2020-03-30	Mr. Teagan Quigley	mr.teagan.quigley@geemail.com	Los Angeles	California	3528490711503967407	266f1d9d7d5fa23543adb48b3410977b	Voyager	34.0292438302054947	-118.394155734171335
17810	2020-03-30 22:46:51	2020-03-30	Kanesha Hudson	kanesha.hudson@woohoo.com	Arlington	Texas	53711273971149417	289c08266cb587c6f0ed38342a632584	VISA 16 digit	32.7373718946024752	-97.164721156752492
17811	2020-03-30 23:08:09	2020-03-30	Celine Goodwin	celine.goodwin@geemail.com	Escondido	California	3765433613896427	22180f16892248e458c9fcfdac796ca7	Mastercard	33.1296909030288447	-117.089134524973105
17812	2020-03-30 23:10:03	2020-03-30	Douglass Hickle	douglass.hickle@geemail.com	Berkeley	California	3043789645578696	77348584b70a8735aff8bdc247c4444d	VISA 16 digit	37.8677523764013344	-122.30224064381008
17813	2020-03-30 23:13:25	2020-03-30	Sanders Dooley-Lemke	sanders.dooley.lemke@geemail.com	Fremont	California	180099932876792678	56101f29e90c3682f0c311789193a535	American Express	37.4523359833918548	-121.971855675427989
17814	2020-03-30 23:20:26	2020-03-30	Jolie Abshire	jolie.abshire@geemail.com	San Francisco	California	869920039189646932	c66943524bfcd69228c60e2ca571e314	JCB 15 digit	37.7345755719199687	-122.463067748552774
17815	2020-03-30 23:25:05	2020-03-30	Ray Heller-Ritchie	ray.heller.ritchie@woohoo.com	Chicago	Illinois	6011147496364804603	8ff43fea9f2c1d888ca96fbf42d94b62	Maestro	41.9276159650016567	-87.6193985983293402
17816	2020-03-30 23:27:22	2020-03-30	Hassan Huels-Walker	hassan.huels.walker@warmmail.com	San Francisco	California	210094482134550273	5f5a9df3e8d6600b205dbb0cb88fce5d	Mastercard	37.7854937556028219	-122.454770111007463
17817	2020-03-30 23:37:33	2020-03-30	Mr. Dereck Dach	mr.dereck.dach@geemail.com	Tyler	Texas	55571086090294008	c3083b0a74fa777cd4ba71a3da789900	American Express	32.2533289103351564	-95.4051384552024189
17818	2020-03-30 23:41:40	2020-03-30	Dr. Cassie Block	dr.cassie.block@geemail.com	Los Angeles	California	6011252207769143997	01bfadb9896ef270e8c5dc895edc7941	Discover	34.0523595803748762	-118.311287973121921
17819	2020-03-30 23:45:49	2020-03-30	Citlali McLaughlin	citlali.mclaughlin@woohoo.com	Raleigh	North Carolina	869992076482145553	14eeba879e21992877c89a18c00c2526	VISA 16 digit	35.7526097866374997	-78.6780981183454458
17820	2020-03-30 23:47:07	2020-03-30	Letta Funk	letta.funk@woohoo.com	Los Angeles	California	4826381060358435	cdecd3e6c56060eb50a0665bf4e7fb66	JCB 16 digit	33.9520593798119563	-118.409764637564493
17821	2020-03-30 23:50:22	2020-03-30	Mr. Chin Zboncak	mr.chin.zboncak@geemail.com	Arlington	Texas	589391482708798	97f2bf77df62b56db3207b5359d3494b	VISA 16 digit	32.6309943124435833	-97.0527640433542444
17822	2020-03-30 23:50:45	2020-03-30	Kendal Keebler-Bogan	kendal.keebler.bogan@geemail.com	Denton	Texas	180042450974026715	aea1f4477d98633d3df9ca7620ce4c42	JCB 15 digit	33.1598047819718715	-97.1130607092414095
17823	2020-03-30 23:52:48	2020-03-30	Dameon Williamson I	dameon.williamson.i@geemail.com	San Jose	California	4564803338834	4a9166e6f5855ad05be36c89734989e7	VISA 13 digit	37.3826496363904326	-121.76189818906002
17824	2020-03-30 23:53:42	2020-03-30	Katarina O'Reilly	katarina.o'reilly@geemail.com	West Valley City	Utah	4218500984987518	2146a2b1b3a7fcb863e779be53db93d3	VISA 16 digit	40.6267644196506552	-111.988538109998402
17825	2020-03-31 00:12:20	2020-03-31	Mahlon Hegmann	mahlon.hegmann@warmmail.com	Columbus	Ohio	4392912313208797	64a02364639f6e5ebb9425f51b207392	VISA 16 digit	39.9916127813559044	-82.8895592606395581
17826	2020-03-31 00:19:23	2020-03-31	Dr. Tom Christiansen MD	dr.tom.christiansen.md@woohoo.com	Portland	Oregon	210024798544101158	61e65dd8e262c7d4a7860fd8aac9b715	Maestro	45.5906526165902619	-122.681749594444412
17827	2020-03-31 00:24:28	2020-03-31	Adele Smith	adele.smith@geemail.com	Westminster	Colorado	6011671307262104851	7dbc0c51defef1c7a3bf345b9247440e	VISA 16 digit	39.92011593853384	-105.106796215302879
17828	2020-03-31 00:40:56	2020-03-31	Jalynn Bogan	jalynn.bogan@geemail.com	Fullerton	California	3158643918308223862	f3865826844f116abbc163100046e73f	JCB 16 digit	33.797501451724024	-118.004022426085541
17829	2020-03-31 01:26:02	2020-03-31	Mr. Norris Lubowitz Jr.	mr.norris.lubowitz.jr.@geemail.com	San Francisco	California	4026715332099	8aa36962ac0f4448bcbf72fadd3992f4	American Express	37.7937172637887286	-122.446713239031737
17830	2020-03-31 01:33:22	2020-03-31	Dyan Haag PhD	dyan.haag.phd@woohoo.com	Philadelphia	Pennsylvania	4682747404973811	6d375a747900d03e4d06dccff19b65de	JCB 16 digit	40.076210140479354	-75.1170759331800042
17831	2020-03-31 01:35:29	2020-03-31	Claudius Lind	claudius.lind@geemail.com	Omaha	Nebraska	3436621449293886	339346556754a598eb14890b326be56d	JCB 16 digit	41.346190444208311	-96.1140984509721505
17832	2020-03-31 01:38:12	2020-03-31	Miss Khalilah Bahringer	miss.khalilah.bahringer@geemail.com	Elgin	Illinois	3088824636437775690	094daf591c9c16b7d0504271228c74a0	VISA 16 digit	42.0579697903994472	-88.362545432970677
17833	2020-03-31 01:50:45	2020-03-31	Cassius Goodwin	cassius.goodwin@warmmail.com	San Bernardino	California	3158366547441807318	1a1bd0bbd046ba4d086530f0dd46627c	Maestro	34.0493637912239819	-117.217668598356099
17834	2020-03-31 01:59:16	2020-03-31	Jerry Wyman	jerry.wyman@geemail.com	Pittsburgh	Pennsylvania	210057752000367324	954986d08eaad0a4fed2cf5b4dc76ce7	American Express	40.3824935201976416	-80.0267425651833406
17835	2020-03-31 02:06:07	2020-03-31	Frank Beahan Jr.	frank.beahan.jr.@geemail.com	Long Beach	California	6011321184049559358	75db2b2c4a4d9dca67e67d474cc408c6	JCB 16 digit	33.8725980644401119	-118.062163655941561
17836	2020-03-31 02:11:46	2020-03-31	Jacky Jaskolski-Marks	jacky.jaskolski.marks@geemail.com	San Antonio	Texas	3337531401658325889	dfc24fba79995ad6700fd118d8cbe724	VISA 16 digit	29.4658024552814659	-98.483072425827757
17837	2020-03-31 02:24:00	2020-03-31	Vivien Tremblay	vivien.tremblay@geemail.com	Austin	Texas	6011688462580890771	aa0f3a193299d3c80fe66177ffb8ac6f	Maestro	30.3686230024449522	-97.721050701314212
17838	2020-03-31 02:29:38	2020-03-31	Maximiliano Padberg	maximiliano.padberg@warmmail.com	Huntsville	Alabama	3112204965377672959	1c2829fe0e8770d4303c938734822987	Diners Club / Carte Blanche	34.6750819449089462	-86.6949140382949253
17839	2020-03-31 02:32:09	2020-03-31	Orilla Block	orilla.block@geemail.com	Shreveport	Louisiana	4829830186516406	ddf002406c1957f386321c4786d16c77	Diners Club / Carte Blanche	32.5134267159044796	-93.8589312419041875
17840	2020-03-31 02:49:42	2020-03-31	Squire Bartell	squire.bartell@geemail.com	Lubbock	Texas	4513253504188272	34c4a479688a7e6bd41c807e6b694be9	VISA 16 digit	33.6012137276627172	-101.974061924862497
17841	2020-03-31 02:52:21	2020-03-31	Ursula Bogisich	ursula.bogisich@woohoo.com	Virginia Beach	Virginia	4502398366856640	d7d3b5e3b3fe2812a65fe647fe271938	Diners Club / Carte Blanche	36.6806271596997959	-76.0190903226051518
17842	2020-03-31 03:18:19	2020-03-31	Douglas Breitenberg	douglas.breitenberg@geemail.com	Durham	North Carolina	869993844216029735	6fdcffa06b13cc99828b1fa021bfee9d	VISA 16 digit	36.014607451321929	-78.9517472935278022
17843	2020-03-31 03:38:31	2020-03-31	Roselyn West	roselyn.west@geemail.com	New York	New York	3158490243235070144	23e11a89db1391694786ace53164baac	Mastercard	40.7109759277421972	-73.9218813414581035
17844	2020-03-31 03:55:19	2020-03-31	Jaxson Fahey	jaxson.fahey@warmmail.com	Los Angeles	California	4957705551536052	0c8d9c63eda14044cc11b527381aed7a	VISA 16 digit	34.048835693798587	-118.391407551569117
17845	2020-03-31 03:55:29	2020-03-31	Dr. Gustave Spencer	dr.gustave.spencer@geemail.com	Fort Worth	Texas	869906564059810738	a67643cb05ee9d52a8860e12e1c9719b	Mastercard	32.7033285807408376	-97.4008057253256396
17846	2020-03-31 03:59:25	2020-03-31	Holland Runolfsdottir PhD	holland.runolfsdottir.phd@geemail.com	San Francisco	California	3158232848469442182	cb91e9927aa939360e7c1c4491efd4bf	JCB 16 digit	37.7829483811874951	-122.398956890217022
17847	2020-03-31 04:01:54	2020-03-31	Dejuan Hyatt	dejuan.hyatt@geemail.com	Irvine	California	6011164206827190591	52eec6e928b20f3aa515868579da2b2f	Mastercard	33.7502026903923635	-117.81830076035223
17848	2020-03-31 04:21:12	2020-03-31	Tyrus Howe	tyrus.howe@geemail.com	Midland	Texas	060406665952617	630ea79915cc19d2561202ce98c69582	JCB 16 digit	32.0892335897501582	-102.157289042579009
17849	2020-03-31 04:28:05	2020-03-31	Remington Bayer	remington.bayer@geemail.com	Chicago	Illinois	4551247321302	a8f10d90c3ccd29ac29bac2793bc0eb8	JCB 16 digit	41.8820299580529323	-87.6910506766319173
17850	2020-03-31 04:59:00	2020-03-31	Guy Schultz	guy.schultz@geemail.com	San Antonio	Texas	4718339888919334	154c39b87a951eed62826e47de261b2b	VISA 13 digit	29.5445834187861536	-98.5016932745765814
17851	2020-03-31 04:59:58	2020-03-31	Arnav Beer-Rau	arnav.beer.rau@woohoo.com	Philadelphia	Pennsylvania	6011306038829024638	5b2a56efc09543969c853df807e9c1f8	VISA 16 digit	40.081492106193302	-75.1441029786963099
17852	2020-03-31 05:03:53	2020-03-31	Nancie Sipes	nancie.sipes@geemail.com	Houston	Texas	4934547166141581	c657aeee38d0ce8dd61792fe309c0633	Mastercard	29.7620620340652771	-95.3808990326259334
17853	2020-03-31 05:09:13	2020-03-31	Metta Kulas	metta.kulas@geemail.com	Corpus Christi	Texas	4692493003259	c704d2e843103e26c865ffc91b98332a	VISA 16 digit	27.6744580162625766	-97.1511178816031702
17854	2020-03-31 05:26:44	2020-03-31	Jaime Hodkiewicz	jaime.hodkiewicz@geemail.com	Lakewood	Colorado	6011019656135636429	8434be3a8b465e46472efe2100980a9d	American Express	39.6978142698701504	-105.203353798577936
17855	2020-03-31 05:58:26	2020-03-31	Ms. Martha Schowalter	ms.martha.schowalter@geemail.com	Henderson	Nevada	210059089023047346	0f55d9c41e615d43cad4697eedcc5298	Diners Club / Carte Blanche	36.0594122665401571	-114.981086059442546
17856	2020-03-31 06:06:13	2020-03-31	Dr. Rhett Beer II	dr.rhett.beer.ii@geemail.com	High Point	North Carolina	3112241165376149621	d6ccfedc282423284fbf8b510787f61c	JCB 16 digit	36.0152979082055396	-79.9265322267282698
17857	2020-03-31 06:17:14	2020-03-31	Jim Senger-Weber	jim.senger.weber@woohoo.com	New York	New York	4062826857534	cf71116a02b0928eaccc40855196bbbc	JCB 16 digit	40.6045219803452468	-73.8815863402921735
17858	2020-03-31 06:19:04	2020-03-31	Linus O'Keefe	linus.o'keefe@warmmail.com	San Antonio	Texas	3158023897295075925	fb0c044cd8f8326730ab90f690dbc276	VISA 16 digit	29.5402901673294593	-98.4728466658689001
17859	2020-03-31 06:21:45	2020-03-31	Daisey Heathcote	daisey.heathcote@geemail.com	Providence	Rhode Island	4384434063618414	feb8986c714b9adc5ff5c79522b822c7	Discover	41.805652867010231	-71.3552542962983267
17860	2020-03-31 06:25:09	2020-03-31	Marcelino Bernhard-Jacobi	marcelino.bernhard.jacobi@geemail.com	Phoenix	Arizona	4401684986619191	53587a03f18c7c00b397990c80877915	Mastercard	33.5507065937787345	-112.108996104581664
17861	2020-03-31 06:43:05	2020-03-31	Norma Willms	norma.willms@geemail.com	San Francisco	California	210028611363315997	34ea6228c441abcb75175f5cbb6df0d2	JCB 15 digit	37.7560103854229183	-122.455216998266593
17862	2020-03-31 06:44:40	2020-03-31	Ilda McLaughlin	ilda.mclaughlin@geemail.com	Des Moines	Iowa	869972761391842879	042d9e4b026c069ff4df8ba62689426c	JCB 15 digit	41.4888755226716412	-93.6069670687474371
17863	2020-03-31 06:59:25	2020-03-31	Heriberto Fadel	heriberto.fadel@warmmail.com	Orlando	Florida	869997969163422728	a9139d986763e96830436befbde3526f	Mastercard	28.3772260988861298	-81.33047105166726
17864	2020-03-31 07:12:21	2020-03-31	Judyth Watsica-Spinka	judyth.watsica.spinka@woohoo.com	Los Angeles	California	3096513498164061331	455c266d3cab23cf1a46fa1c6d72fdd6	VISA 16 digit	34.0077564875926797	-118.420444870972261
17865	2020-03-31 07:29:07	2020-03-31	Dr. Delina Jacobi	dr.delina.jacobi@warmmail.com	Columbus	Ohio	3158174398943127017	34c2d0d96bd0dc7dcfbcdda493723421	Discover	40.0234895705290157	-83.0544525323204823
17866	2020-03-31 07:41:38	2020-03-31	Kai Price	kai.price@woohoo.com	Pittsburgh	Pennsylvania	54100336583358061	a91d80030668e9e2496409ce512b2950	American Express	40.3452730929434296	-80.0715016550555845
17867	2020-03-31 07:50:40	2020-03-31	Dr. Colon Hamill DDS	dr.colon.hamill.dds@geemail.com	Chicago	Illinois	4920681533119792	962ae83268debf46546a6b980de4e6b6	JCB 16 digit	41.8529243948239866	-87.6361325121048793
17868	2020-03-31 08:04:53	2020-03-31	Ms. Marge McKenzie	ms.marge.mckenzie@geemail.com	Austin	Texas	6011603776126334735	6138a09857d7a9060e38f88cad26d98e	Maestro	30.2490693179085852	-97.781083242060248
17869	2020-03-31 08:23:22	2020-03-31	Abdul Mosciski	abdul.mosciski@geemail.com	Corona	California	561290131605496	a6d2d4e0dc40a1dcbfaf3c17ec1c17f9	VISA 13 digit	33.8502166386116343	-117.523384475449106
17870	2020-03-31 08:26:34	2020-03-31	Saint Breitenberg MD	saint.breitenberg.md@woohoo.com	Tyler	Texas	6011011625733998281	f27248a77c6febb9bdef531e4a7cae95	VISA 16 digit	32.2712290522225231	-95.2938833127371936
17871	2020-03-31 08:29:03	2020-03-31	Concepcion Schmitt	concepcion.schmitt@geemail.com	New York	New York	4628663900130	f37c2d95302d4bed42950ee2f1836462	VISA 16 digit	40.7087106873504823	-73.9110719815257937
17872	2020-03-31 08:46:59	2020-03-31	Jennie Lind	jennie.lind@warmmail.com	New York	New York	3430911865785820	ff24525bb98a57e1c1ab5840733b932b	VISA 16 digit	40.6975077819768316	-73.968725238264355
17873	2020-03-31 08:53:31	2020-03-31	Alyson White	alyson.white@warmmail.com	Berkeley	California	3493243831746064	e0b1d5dc59b58e94cd3e1498b36bd966	VISA 16 digit	37.8512130393725741	-122.284497168144895
17874	2020-03-31 09:02:07	2020-03-31	Roberta Ward	roberta.ward@geemail.com	San Francisco	California	54457083543370062	2c06b2617445be5ba94f7a838cd960b6	American Express	37.7776297645420982	-122.439928223386048
17875	2020-03-31 09:04:43	2020-03-31	Kelton Marquardt	kelton.marquardt@geemail.com	San Francisco	California	52394593741230005	74eee92c950fdf1038f2c2299c81ca42	American Express	37.803788961468598	-122.434780726655035
17876	2020-03-31 09:36:11	2020-03-31	Jamarion O'Reilly	jamarion.o'reilly@geemail.com	San Francisco	California	3112347839673267244	16744fc91228a9ce3845d15e5efcb4d6	JCB 15 digit	37.7802458335429989	-122.42116473703588
17877	2020-03-31 09:41:38	2020-03-31	Luciano Hoeger	luciano.hoeger@geemail.com	San Antonio	Texas	4303970847177860	0607a3539471849994ba323d00b19312	Voyager	29.4777312478587028	-98.4653535056695262
17878	2020-03-31 10:06:08	2020-03-31	Tommie Hansen	tommie.hansen@woohoo.com	Abilene	Texas	3024090544978270	0b5f3cecc9503179aa88cf71118d12aa	American Express	32.4798987926524134	-99.7216526417475251
17879	2020-03-31 10:09:18	2020-03-31	Abel Ebert	abel.ebert@geemail.com	Chicago	Illinois	4336892588284	915cf39b407e7cf9b769f2c61638eb18	Voyager	41.7677607273519058	-87.703860191025953
17880	2020-03-31 10:13:16	2020-03-31	Almedia McKenzie DDS	almedia.mckenzie.dds@warmmail.com	Baton Rouge	Louisiana	3024482630586762	6140a7ae6fbf9cb0ff916c279800747f	JCB 16 digit	30.366051552512495	-91.2179206707157135
17881	2020-03-31 10:26:51	2020-03-31	Dr. Courtland Champlin DVM	dr.courtland.champlin.dvm@woohoo.com	San Diego	California	3042640245065801	e0d36e058eb68063fb4dd3fe4be4d9dc	JCB 15 digit	32.8468471274778224	-117.172550192838543
17882	2020-03-31 10:36:15	2020-03-31	Dr. Dayna Nikolaus	dr.dayna.nikolaus@woohoo.com	Bakersfield	California	869943049132523941	73ed774934aec262113313aa7f874988	VISA 13 digit	35.2220666851092119	-119.025122419399395
17883	2020-03-31 10:39:40	2020-03-31	Torrence Jacobson PhD	torrence.jacobson.phd@warmmail.com	Berkeley	California	3753196702767890	3a4debf8a649ac8923ee738c06d5f299	VISA 16 digit	37.8937549108762397	-122.250708699006609
17884	2020-03-31 10:44:41	2020-03-31	Soren Shields	soren.shields@geemail.com	Riverside	California	502084547422992	8657267a7a613d909c3073530d608a1a	Diners Club / Carte Blanche	33.8429427979927482	-117.444205873829119
17885	2020-03-31 10:47:29	2020-03-31	Krystle Vandervort	krystle.vandervort@geemail.com	Hialeah	Florida	3158900067935294587	a7541367d8a8f5c32da7104310275a81	JCB 16 digit	25.7722940982297075	-80.278741718772423
17886	2020-03-31 10:51:51	2020-03-31	Kelsi McKenzie	kelsi.mckenzie@geemail.com	San Francisco	California	3026671565166859	1cb4c3bdd7200b2e7244869c7d861997	VISA 13 digit	37.7745269088392632	-122.420043817020101
17887	2020-03-31 11:31:27	2020-03-31	Roll Olson	roll.olson@woohoo.com	New York	New York	55482271971734839	9b10ca60a453f7d93bc1b236b7fde28e	Discover	40.580519859701397	-73.8557897545292974
17888	2020-03-31 11:33:54	2020-03-31	Enola Mayer	enola.mayer@geemail.com	Augusta	Georgia	3337738027525894665	a441c3ba458b8ba66ce7f8fffcd7868c	VISA 16 digit	33.3997629643622744	-81.9874187386423472
17889	2020-03-31 11:50:31	2020-03-31	Mr. Alfonzo Hauck	mr.alfonzo.hauck@geemail.com	Norfolk	Virginia	3158470002191874350	78d3797717d29426498dfdc0e83da661	VISA 13 digit	36.8901164867002507	-76.2936715910214929
17890	2020-03-31 11:56:39	2020-03-31	Mildred Hegmann	mildred.hegmann@geemail.com	Boise	Idaho	3528579591330036335	a909f3e9604c38c2bbd37f0637cfc84d	Maestro	43.6596259413424903	-116.242071325584135
17891	2020-03-31 12:39:01	2020-03-31	Kisha Koepp-Koepp	kisha.koepp.koepp@woohoo.com	Los Angeles	California	869987709151279082	318e54d909dc5af64b99fd1be0704a17	VISA 16 digit	33.9835786945052405	-118.324104605707518
17892	2020-03-31 12:42:59	2020-03-31	Miriah Lowe	miriah.lowe@geemail.com	New York	New York	4025915786322420	306987e7b0b5f8f15a6a174ae421e55b	JCB 15 digit	40.7361415745448312	-74.0121746273606931
17893	2020-03-31 12:45:46	2020-03-31	Dr. Dax Kihn Jr.	dr.dax.kihn.jr.@warmmail.com	Garden Grove	California	869917439242201276	bf40d84ac1af93272ae162f96ae14e25	VISA 13 digit	33.8308888742525085	-117.908337258130302
17894	2020-03-31 12:51:00	2020-03-31	Shepherd Morissette DVM	shepherd.morissette.dvm@warmmail.com	Salinas	California	639029338623589	c18b4ba90a2a42c36e1ee597fbe28b9e	Maestro	36.7523249764692039	-121.569505673990406
17895	2020-03-31 13:03:01	2020-03-31	Scott Funk	scott.funk@geemail.com	Hampton	Virginia	3770255550071117	4d63b4f9cab94dff43735aeb87a8e6f4	JCB 16 digit	37.0112994679268468	-76.3332971929669384
17896	2020-03-31 13:05:22	2020-03-31	Tyra Kilback	tyra.kilback@warmmail.com	New York	New York	6011336702921496663	85f29a0c0dcf1efce60f2b2653ce92b6	Discover	40.6763652792889587	-73.8785614278994416
17897	2020-03-31 13:07:32	2020-03-31	Bush Wolf	bush.wolf@warmmail.com	Savannah	Georgia	3158637829688756447	93a4a1d140c0bf6b4f2705d347d1d02b	JCB 16 digit	31.9880966546107075	-81.1255525960739732
17898	2020-03-31 13:18:42	2020-03-31	Verlyn Rogahn	verlyn.rogahn@geemail.com	Chicago	Illinois	6011796134507546963	b157d37a908153ec77af90b0f5d58c66	VISA 16 digit	41.8157371150631505	-87.7360130842804864
17899	2020-03-31 13:21:15	2020-03-31	Lugenia Runte	lugenia.runte@geemail.com	Oakland	California	869901638624476988	25c8057c3188bb3f2491b9a497136816	JCB 16 digit	37.8041863149249409	-122.280020362471461
17900	2020-03-31 13:30:13	2020-03-31	Dr. Jammie Flatley MD	dr.jammie.flatley.md@geemail.com	New York	New York	3158164434213083945	759866396ffae5caa102ff68352008b3	VISA 16 digit	40.7460113245286024	-73.9507381382759661
17901	2020-03-31 13:53:01	2020-03-31	Shena Fahey	shena.fahey@geemail.com	Oakland	California	4821594607208344	30bd7cb185df15bd2334d486a8b2017c	Voyager	37.7840909951632042	-122.265112327424603
17902	2020-03-31 14:13:17	2020-03-31	Ula Rice	ula.rice@geemail.com	Portland	Oregon	3096086306447765494	0e36d762d13a54a264792349f0d7e978	Diners Club / Carte Blanche	45.5392209722548742	-122.644421358592808
17903	2020-03-31 14:34:46	2020-03-31	Dorcas Rempel	dorcas.rempel@woohoo.com	New York	New York	3006766080988355	16264a4edc3c07fa881f6a4f83925ebc	JCB 16 digit	40.5707279682848565	-73.9983510020550312
17904	2020-03-31 14:43:10	2020-03-31	Alton Stokes	alton.stokes@warmmail.com	Amarillo	Texas	51678670029752194	d1a111a571d9c496e2f902224e5885eb	VISA 16 digit	35.2476279266808206	-101.834740606355297
17905	2020-03-31 14:48:48	2020-03-31	Luda Hartmann	luda.hartmann@geemail.com	Henderson	Nevada	3158583120219651438	6709ae1a5258a78517af7eb8d14b6d51	JCB 16 digit	35.9794657860815548	-114.972706784556436
17906	2020-03-31 15:11:30	2020-03-31	Mont Ernser III	mont.ernser.iii@geemail.com	San Francisco	California	6011116202716815637	c71bcd0a06911e8416a96a762dc1d910	JCB 16 digit	37.7686838644338323	-122.406984825795689
17907	2020-03-31 15:14:06	2020-03-31	Justine Schaden DVM	justine.schaden.dvm@geemail.com	New York	New York	52933601949615162	99650e9a7674a7be3a5bac4907560a98	Mastercard	40.6144514205623395	-73.9634327227145434
17908	2020-03-31 15:27:37	2020-03-31	Ammon Weimann	ammon.weimann@woohoo.com	Tampa	Florida	3028769709487278	d4145cd7f29f54e4b513a009aa868999	Discover	28.0683741387095296	-82.5655196375425788
17909	2020-03-31 15:30:19	2020-03-31	Ms. Josefina Veum	ms.josefina.veum@woohoo.com	New Haven	Connecticut	4163844552030	bd9d645b5da3ead9dd90ff57f30cc47e	Voyager	41.2256012328892965	-72.8540074470918597
17910	2020-03-31 15:36:12	2020-03-31	Miss Aretha Schuster DDS	miss.aretha.schuster.dds@geemail.com	Chicago	Illinois	6011367343234788884	2bd6786092b5f0856a200fda3b5bb5ef	Discover	41.9192143302246976	-87.630465826674552
17911	2020-03-31 15:36:18	2020-03-31	Carrol Batz	carrol.batz@geemail.com	San Jose	California	589343901945857	fcd4ecc9f48e93957493e32aab0a5567	JCB 16 digit	37.3824375675812348	-121.797072137355428
17912	2020-03-31 15:41:02	2020-03-31	Madelynn Jaskolski-Smith	madelynn.jaskolski.smith@woohoo.com	Philadelphia	Pennsylvania	53488852453560091	5dae79ca10f8c419887428bca3b92242	VISA 16 digit	40.0504837948322319	-75.1372266366977328
17913	2020-03-31 15:45:33	2020-03-31	Adin Simonis MD	adin.simonis.md@woohoo.com	Wilmington	North Carolina	4139427259863362	3199fa68cc7741a4e387f0c1fcbc4cae	JCB 16 digit	34.2583170913446722	-77.8044800994910304
17914	2020-03-31 15:49:18	2020-03-31	Isamar Rolfson-Jacobson	isamar.rolfson.jacobson@geemail.com	San Francisco	California	4064407658990304	3815f93faeae9f7df5155c4b9d2fe87c	JCB 16 digit	37.8082144417486461	-122.44597679676464
17915	2020-03-31 15:53:58	2020-03-31	Latesha Romaguera	latesha.romaguera@geemail.com	Tucson	Arizona	4605121551291126	aa4f8e280aad199b78a556342b7eacf6	VISA 16 digit	32.0973219363991191	-110.843751896288609
17916	2020-03-31 16:18:15	2020-03-31	Cassidy Lockman	cassidy.lockman@geemail.com	Mobile	Alabama	4936517026184855	0f33df2213577d94f1acdc16bdc33225	JCB 16 digit	30.594941900541631	-88.1403454555336339
17917	2020-03-31 16:22:30	2020-03-31	Mr. Odin Bednar	mr.odin.bednar@geemail.com	Anchorage	Alaska	501855544468493	37362108a2e72e272381cef8c5db646b	Voyager	61.1608262879524389	-149.346689727309354
17918	2020-03-31 16:36:26	2020-03-31	Charmaine Jacobi	charmaine.jacobi@woohoo.com	New York	New York	4782223172118	7c29fd435fa1c2ae62e35f05471500d8	Voyager	40.7555575405005328	-73.851755881345639
17919	2020-03-31 16:44:25	2020-03-31	Emmy Heller	emmy.heller@geemail.com	Fort Worth	Texas	4419999463455897	00c1a0a47cae1b0a561d88e609f3de77	Discover	32.7685519004762185	-97.3193151227019655
17920	2020-03-31 16:46:03	2020-03-31	Yuliana Fritsch	yuliana.fritsch@geemail.com	Oakland	California	4115428824390905	8b0478dbc985f907f460ad57937f0728	Mastercard	37.8004445286559232	-122.274689561162731
17921	2020-03-31 16:55:40	2020-03-31	Gino Klocko	gino.klocko@geemail.com	Kenosha	Wisconsin	3158606021948188945	939a2517b72361c12ada11d5beb9a7ac	VISA 13 digit	42.5460813211582618	-87.8726616726949885
17922	2020-03-31 17:10:04	2020-03-31	Grove Jacobs	grove.jacobs@warmmail.com	Boston	Massachusetts	3112911157003720881	580b8730bb8186e8a148bdc196919ad9	American Express	42.3481230702418827	-71.0131997891653413
17923	2020-03-31 17:29:49	2020-03-31	Hennie Koss	hennie.koss@woohoo.com	Eugene	Oregon	869924064715342646	871b01cc8e8a29dece18926ceb55475f	Diners Club / Carte Blanche	43.9872498195812085	-123.082214443663887
17924	2020-03-31 17:36:16	2020-03-31	Moesha Blick	moesha.blick@warmmail.com	Sugar Land	Texas	3112169241566228604	41f7ba8e0a33b6a783f139930c7f69ec	JCB 16 digit	29.6964448978245237	-95.6722348661169377
17925	2020-03-31 18:10:37	2020-03-31	Michelina Jones	michelina.jones@geemail.com	New York	New York	54145986986468540	bde0107abb030b16a501dfab8ec7ab62	Mastercard	40.6024652879442982	-74.0379895852308749
17926	2020-03-31 18:10:38	2020-03-31	Mariann Powlowski DDS	mariann.powlowski.dds@warmmail.com	Charlotte	North Carolina	503823909865992	69fcf55d31611897c9a282e76d161505	Mastercard	35.1118433455724244	-80.8190818650126488
17927	2020-03-31 18:11:01	2020-03-31	Mrs. Joann Cummerata DVM	mrs.joann.cummerata.dvm@geemail.com	Lewisville	Texas	3775546106165600	3f3bddf1df7585907543b44a355f511d	VISA 13 digit	33.0140684848170736	-97.0199408533547114
17928	2020-03-31 18:20:06	2020-03-31	Hartley Jones-Marvin	hartley.jones.marvin@geemail.com	Spokane	Washington	4771698517474084	98f489b6a87d4c0162f30b9ad4e15cf7	Discover	47.5995892365701465	-117.431183273987102
17929	2020-03-31 18:22:48	2020-03-31	Miss Regenia Moore PhD	miss.regenia.moore.phd@geemail.com	San Francisco	California	869914882320161560	3d0e7cd5dfa8b8e5c4e791a2d38cf30d	Discover	37.7988423569916492	-122.420696510193096
17930	2020-03-31 18:26:56	2020-03-31	Ms. Rinda Runte DVM	ms.rinda.runte.dvm@woohoo.com	San Antonio	Texas	3112810070032309059	16ba95dce2b7645a1360ab61769b7f42	VISA 16 digit	29.5576837844751772	-98.4421768620911877
17931	2020-03-31 18:29:57	2020-03-31	Lorelei Bogisich	lorelei.bogisich@geemail.com	New York	New York	4292659844289	e35f4e618dd4ca87c30bd08d51ef867d	Diners Club / Carte Blanche	40.6970676588118039	-73.9204245311569395
17932	2020-03-31 18:50:23	2020-03-31	Dr. Erik Luettgen	dr.erik.luettgen@warmmail.com	San Francisco	California	3337016773145224386	4c72fc14ef4ff8e11242a65be14692c7	Maestro	37.7872445952828073	-122.429162151873001
17933	2020-03-31 19:02:16	2020-03-31	Gisselle Marquardt	gisselle.marquardt@geemail.com	Austin	Texas	3096152263447878950	84b3ac9ea253a8d78e2770cf8335fc8b	Discover	30.3104635909326348	-97.7537635649327257
17934	2020-03-31 19:03:34	2020-03-31	Payten Kiehn	payten.kiehn@geemail.com	Greensboro	North Carolina	4965661183497637	14a40b4b6e41907040a40e839f517f32	JCB 16 digit	36.1370911829289057	-79.7644930132646124
17935	2020-03-31 19:04:16	2020-03-31	Lenord Yundt	lenord.yundt@woohoo.com	Rochester	New York	180060600712423684	0f1f05a54e9cce630df226ce23abb4db	Mastercard	43.2590488781198843	-77.5906798129674087
17936	2020-03-31 19:11:04	2020-03-31	Gale Maggio-Sipes	gale.maggio.sipes@geemail.com	Dallas	Texas	6011381095022155195	b6ae8f93308f934db4ca0a740ae63c23	JCB 15 digit	32.7903158111304052	-96.8336652512624738
17937	2020-03-31 19:26:36	2020-03-31	Lark Keebler	lark.keebler@geemail.com	Phoenix	Arizona	3337512398429543134	bed9b4744f080d7476dea0a5a2c44b6d	JCB 15 digit	33.4869814616095312	-112.021009358756629
17938	2020-03-31 19:35:39	2020-03-31	Oney Reichert MD	oney.reichert.md@geemail.com	Berkeley	California	4662253310814	268e1c58c9c089e54dba4a1230d8862e	Voyager	37.8955941342723932	-122.293809152233052
17939	2020-03-31 19:37:45	2020-03-31	Vallie Larson DVM	vallie.larson.dvm@geemail.com	Jacksonville	Florida	3718557899812845	607aa50c1b4562c79f98ba5e576d3017	VISA 16 digit	30.4315312326006584	-81.6241294080935518
17940	2020-03-31 19:46:32	2020-03-31	Dr. Boston Sporer MD	dr.boston.sporer.md@warmmail.com	Ann Arbor	Michigan	3005921098451547	091cc9fcecf5b270400c52cb48834882	Voyager	42.2722736961267884	-83.8046611399032173
17941	2020-03-31 19:55:44	2020-03-31	Teri Klein DVM	teri.klein.dvm@woohoo.com	Naperville	Illinois	6011231910504707697	18dfecc1f2d2ec3a0fa7e4b3441cc5ee	VISA 13 digit	41.6738627228334551	-88.1672341037895535
17942	2020-03-31 20:02:14	2020-03-31	Nicolette Fay	nicolette.fay@geemail.com	Charlotte	North Carolina	503806869769452	65c08f098533c333ba850e5caed42963	JCB 15 digit	35.1925139337100106	-80.8550779272746354
17943	2020-03-31 20:27:11	2020-03-31	Marchello Sanford-Beahan	marchello.sanford.beahan@geemail.com	San Francisco	California	3096577226980555647	52ba58ab1dc1b9072a0dc5b884077e90	Discover	37.7766469987574496	-122.461958194452791
17944	2020-03-31 20:40:14	2020-03-31	Miss Taryn Kshlerin DDS	miss.taryn.kshlerin.dds@geemail.com	Washington	District of Columbia	6011978328613898272	4494591f5d4ba75d376ad78abc9a6081	VISA 13 digit	38.9890434250500064	-76.9766048579689084
17945	2020-03-31 21:08:28	2020-03-31	Alwina Stokes	alwina.stokes@geemail.com	Oakland	California	6011181292581649443	078bc4a9e0790affa7a254a178d1cbce	VISA 16 digit	37.8065397680867221	-122.276109132435437
17946	2020-03-31 21:10:33	2020-03-31	Ms. Norma Fadel	ms.norma.fadel@geemail.com	San Francisco	California	3796429326801202	015571dcceb1f1ff09d4a0b09c439284	VISA 16 digit	37.8003722202052046	-122.458588807658316
17947	2020-03-31 21:22:27	2020-03-31	Dena Littel-Hodkiewicz	dena.littel.hodkiewicz@geemail.com	Austin	Texas	3036640334620587	d35723861f01d5404032656e4ec35fb8	JCB 16 digit	30.3843912306833985	-97.6653489955939449
17948	2020-03-31 22:06:04	2020-03-31	Angel Gislason	angel.gislason@warmmail.com	Port St. Lucie	Florida	3479907857649802	7bef39e30612c455c6f297b685bb3952	Maestro	27.1906574787706141	-80.4037969769530037
17949	2020-03-31 22:12:55	2020-03-31	Dewey Kulas	dewey.kulas@geemail.com	Saint Paul	Minnesota	3055933820450929	bfb23e8ecf977370742182e6719579f6	Discover	44.9865487184781614	-93.0537032380033367
17950	2020-03-31 22:13:35	2020-03-31	Dr. Lee Grady	dr.lee.grady@geemail.com	Chicago	Illinois	4649013671650	f8d82de7f101bed217006d1d55b7573b	VISA 13 digit	41.8412330298986319	-87.6688728142093794
17951	2020-03-31 22:43:31	2020-03-31	Willam Dibbert	willam.dibbert@geemail.com	Jurupa Valley	California	180056668835238400	b213bac04031f7597703da2cf5c9465f	Voyager	33.9228245860826263	-117.53061512811334
17952	2020-03-31 23:26:54	2020-03-31	Kala Cassin	kala.cassin@geemail.com	Oakland	California	51321038065678932	e25931df4ef774d5f377a3481799d339	JCB 15 digit	37.8345534970280539	-122.291670091565905
17953	2020-03-31 23:36:58	2020-03-31	Pam Kessler	pam.kessler@woohoo.com	San Francisco	California	501833550765821	ba849a108a595cfccbc9732dc61189ad	American Express	37.7749050455694757	-122.452532368174985
17954	2020-03-31 23:41:42	2020-03-31	Darcie Beahan-Heidenreich	darcie.beahan.heidenreich@geemail.com	San Francisco	California	4829584982870513	e25d3ac823735d43a6225f24d42b33e7	American Express	37.7640351340655016	-122.417081360441671
17955	2020-04-01 00:21:58	2020-04-01	Aracely O'Reilly-Klein	aracely.o'reilly.klein@warmmail.com	Tallahassee	Florida	4738414126435124	8816e1391da88e7608e63c3a114c21dc	Maestro	30.5266175155550243	-84.3375083941981245
17956	2020-04-01 00:32:05	2020-04-01	Nestor Klein	nestor.klein@warmmail.com	San Francisco	California	6011759508144833501	33a6a80d9ad69dc068ac565e1fb965ee	VISA 16 digit	37.7858676896599732	-122.41342198416497
17957	2020-04-01 00:35:50	2020-04-01	Cher Kris PhD	cher.kris.phd@warmmail.com	Reno	Nevada	3010793644114126	026d0b9e7126374c3c468a6ddf5a8a63	Voyager	39.6030699434302775	-119.797242809382837
17958	2020-04-01 00:43:04	2020-04-01	Denzell Aufderhar-Schaefer	denzell.aufderhar.schaefer@woohoo.com	Oxnard	California	4845132842331944	339c056f765f94d09fb6d5fa1efb0b15	JCB 16 digit	34.1942050099793846	-119.170945615684985
17959	2020-04-01 00:56:30	2020-04-01	Miss Carra Hane	miss.carra.hane@woohoo.com	West Valley City	Utah	4126825835161	79f3558df8d5e03343213ab9a05e5ff7	American Express	40.7693300656266473	-111.959561474596327
17960	2020-04-01 00:58:55	2020-04-01	Madlyn Witting	madlyn.witting@geemail.com	San Francisco	California	3035190282625510	4cbf9a0ef6bd7b0267086a3f227eea26	Mastercard	37.7570233178663131	-122.427077480105908
17961	2020-04-01 01:08:47	2020-04-01	Brad Hayes	brad.hayes@woohoo.com	Hartford	Connecticut	51143911631942824	518222b1e7769389605747554723af37	JCB 16 digit	41.8284382705591611	-72.6114551281448541
17962	2020-04-01 01:27:55	2020-04-01	Joell Harvey	joell.harvey@geemail.com	Tampa	Florida	54580026595800239	557ba6f123bb14d5968dbca1d7b8a5bc	Voyager	27.9963660920154283	-82.490412877381587
17963	2020-04-01 01:29:25	2020-04-01	Ms. Beatriz Predovic	ms.beatriz.predovic@geemail.com	Eugene	Oregon	4038311791414227	d9efd913cecaf5bc53d7031df6471dd7	American Express	44.1231355101529488	-123.024334978823376
17964	2020-04-01 01:41:44	2020-04-01	Shelby Quitzon	shelby.quitzon@geemail.com	Inglewood	California	52144239309760909	c030849e57cab33c8e2d9f7a9c3424ce	VISA 16 digit	33.9902546903364353	-118.349764577535169
17965	2020-04-01 01:53:41	2020-04-01	Shea Metz	shea.metz@woohoo.com	Fort Worth	Texas	6011323369776548959	1aa6ddc93d0686fae560eaa0be6cfc92	American Express	32.7109010281562789	-97.2664430616244715
17966	2020-04-01 01:56:19	2020-04-01	Alford Krajcik	alford.krajcik@woohoo.com	Jacksonville	Florida	676328213655674	5a129ecd374bcc7de7ff838f3c1b9834	Maestro	30.2460333068907268	-81.6641893311481937
17967	2020-04-01 01:56:36	2020-04-01	Miss Hortensia Klein	miss.hortensia.klein@geemail.com	San Diego	California	55806778986563200	576346813688485390b1647b130cf9e1	Mastercard	32.8327167724791948	-117.110290442118426
17968	2020-04-01 02:03:21	2020-04-01	Franco Hudson	franco.hudson@geemail.com	Houston	Texas	4591728470505497	6110cd39dbd5a475a4c39eb65ab2c822	American Express	29.8310889188744142	-95.4415147855892769
17969	2020-04-01 02:03:52	2020-04-01	Mr. Solomon Wyman IV	mr.solomon.wyman.iv@warmmail.com	Dallas	Texas	630436859344339	74f2707637b740d9825f67292dcccdd7	JCB 15 digit	32.7762296606592827	-96.8414693624209519
17970	2020-04-01 02:28:05	2020-04-01	Mirtie Tillman	mirtie.tillman@geemail.com	New York	New York	180071413006065824	a9c49ad2e0a60e66b56390cb20665709	JCB 16 digit	40.676966809364032	-74.0076769130665753
17971	2020-04-01 02:28:08	2020-04-01	Mr. Elonzo Dooley	mr.elonzo.dooley@woohoo.com	Newark	New Jersey	676283809916147	68708c523d89f9162a2bd3dcdb23adda	Maestro	40.8052084946919251	-74.2311889564361422
17972	2020-04-01 02:46:11	2020-04-01	Pearla Paucek MD	pearla.paucek.md@warmmail.com	New York	New York	3088011331010497051	d5db09a5b83cfb6911803e7cafc4f365	Discover	40.7028368252553037	-73.9230937694095047
17973	2020-04-01 03:00:18	2020-04-01	Tyson Russel	tyson.russel@geemail.com	Wichita	Kansas	210030385578669094	84bbbba4ec515f00eb3bcce1a04e523d	Discover	37.7720442806247618	-97.4160095113065125
17974	2020-04-01 03:09:57	2020-04-01	Ms. Serina Hintz DVM	ms.serina.hintz.dvm@geemail.com	New York	New York	869929960057900476	dd7c790d39f0a3beedd2fb6fa5c33dd1	Voyager	40.5935595263484856	-74.0237342120043849
17975	2020-04-01 03:14:27	2020-04-01	Anice Erdman	anice.erdman@geemail.com	Norwalk	California	3712522143685377	d5d0ff4796f305fa0c6058f5fd5d4a50	VISA 16 digit	33.8290459724258668	-118.081003423783926
17976	2020-04-01 03:43:01	2020-04-01	Polk Grant	polk.grant@geemail.com	Los Angeles	California	55865670103670398	e217f042b8ce1f854760de3703def1ca	American Express	33.9749290203075844	-118.488592969951398
17977	2020-04-01 03:48:41	2020-04-01	Coleman Torphy DVM	coleman.torphy.dvm@geemail.com	New York	New York	676269006952621	122442b46365eeb6c3d868c8a20b9bf6	Mastercard	40.6368617868740074	-73.883195346210897
17978	2020-04-01 04:07:16	2020-04-01	Vere Schuster	vere.schuster@geemail.com	Nashville	Tennessee	51298915236949160	6a463478cbc47c500d372ec677e28159	American Express	36.1823060613714134	-86.7341583391092712
17979	2020-04-01 04:17:21	2020-04-01	Dr. Ernest Witting DDS	dr.ernest.witting.dds@geemail.com	Gilbert	Arizona	3096726966719108263	6205e60fcb531169e66356f517407b20	American Express	33.2676291490320111	-111.752507532680781
17980	2020-04-01 04:26:02	2020-04-01	Mr. Denton Fritsch Sr.	mr.denton.fritsch.sr.@geemail.com	Memphis	Tennessee	639065796027301	8b11550b18ec3c46208c4ad2d1edfa24	VISA 16 digit	35.0417941107016091	-90.0161770534027426
17981	2020-04-01 04:29:08	2020-04-01	Shelbie Bogisich-Corkery	shelbie.bogisich.corkery@woohoo.com	Fontana	California	3337201304152160670	9a2230d94ddac83dea71a83b67d7258b	Diners Club / Carte Blanche	34.0317303385734604	-117.422313124620914
17982	2020-04-01 04:35:24	2020-04-01	Duke Crooks-Halvorson	duke.crooks.halvorson@geemail.com	Chicago	Illinois	3463912309760098	378daa15acc6138f0d35cbdf4103f4b0	Maestro	41.7733939892448518	-87.6230683173082667
17983	2020-04-01 04:40:43	2020-04-01	Dr. Jordon O'Keefe	dr.jordon.o'keefe@warmmail.com	San Francisco	California	589339845183399	6f7c8a9a4fd394c729f846cda692f955	Voyager	37.7440363471612343	-122.393132452634944
17984	2020-04-01 04:53:27	2020-04-01	Glenwood Shields	glenwood.shields@warmmail.com	Norfolk	Virginia	4915278460844	e08046181982f1b09f12c0ecbb732ea5	Mastercard	36.9473990885559473	-76.2716384447649176
17985	2020-04-01 05:08:50	2020-04-01	Demetra Monahan	demetra.monahan@geemail.com	Ventura	California	4136870604927015	0247bbbc34346079f32281a3a4153358	Mastercard	34.1836390362281364	-119.291330998680365
17986	2020-04-01 05:12:01	2020-04-01	Mr. Maury Konopelski	mr.maury.konopelski@geemail.com	Fontana	California	4624329301384250	dea783fc14be0a36e0447772956ce05f	VISA 16 digit	34.1356329931095246	-117.366834929240497
17987	2020-04-01 05:43:33	2020-04-01	Rozanne Fahey-Dicki	rozanne.fahey.dicki@geemail.com	Miami	Florida	501817238193506	f0b0933025031bad89a33f745b591fb2	Mastercard	25.7012530573315949	-80.250874313885717
17988	2020-04-01 05:53:09	2020-04-01	Jasper Marquardt	jasper.marquardt@geemail.com	New York	New York	55326486653563609	cfaf5f5fa0ac50ebb1c1a5736fa29f10	Mastercard	40.7326002089530235	-74.0029300248146029
17989	2020-04-01 06:09:07	2020-04-01	Dr. Cam Corkery Sr.	dr.cam.corkery.sr.@geemail.com	Oakland	California	6011173397170138995	8ea88b1b650c006685e248ce56c9bae4	VISA 16 digit	37.8125268973990316	-122.280146431131712
17990	2020-04-01 06:16:11	2020-04-01	Shanice Sawayn-Schimmel	shanice.sawayn.schimmel@geemail.com	New York	New York	4681352904356483	2bd49629582cc2db076ab57b732f146b	VISA 16 digit	40.670307659799235	-74.0288644320227149
17991	2020-04-01 06:22:17	2020-04-01	Adelbert Leffler-Considine	adelbert.leffler.considine@geemail.com	Edison	New Jersey	3096134446115110920	67e7dec8ebbe64b588eb4e78331845f3	Discover	40.4934444629084282	-74.4053087226167378
17992	2020-04-01 06:53:18	2020-04-01	Starling Ledner	starling.ledner@warmmail.com	San Antonio	Texas	210084258955238277	a29144d1d58950de68f35b916eed4386	Diners Club / Carte Blanche	29.5260527838557962	-98.5618786002811049
17993	2020-04-01 06:59:11	2020-04-01	Johnna Feest	johnna.feest@woohoo.com	San Francisco	California	4946667173539233	9e4567eb6881553901d2b6b9790db23c	JCB 16 digit	37.7543948109009548	-122.423293913788058
17994	2020-04-01 07:03:13	2020-04-01	Charley Stracke IV	charley.stracke.iv@woohoo.com	College Station	Texas	180006601289388844	258e31d49243b261363db6a94bc7f7dd	VISA 16 digit	30.5355605046775196	-96.2758231600593888
17995	2020-04-01 07:09:02	2020-04-01	Orson Waters	orson.waters@woohoo.com	San Francisco	California	3088718915444752416	ac1c9cc43ed2a16c6a9a23e1a7903d21	Diners Club / Carte Blanche	37.7884607453088961	-122.413077814936472
17996	2020-04-01 07:20:18	2020-04-01	Len Bashirian MD	len.bashirian.md@woohoo.com	Las Vegas	Nevada	4850608909766	7620ea42508031f8114b46f8035b6e0b	VISA 13 digit	36.3239308448608966	-115.255172246063495
17997	2020-04-01 07:26:49	2020-04-01	Nell Ruecker DDS	nell.ruecker.dds@woohoo.com	Killeen	Texas	3055059699875556	82039046e8bbc6728d277ce4ba43c062	Discover	31.0070564547318952	-97.6743066102433914
17998	2020-04-01 07:42:34	2020-04-01	Mr. Eugenio Rice	mr.eugenio.rice@geemail.com	San Diego	California	4683833792789818	7645bc5c8ef182ab0785ed54e94e7ce7	Discover	32.9094568829119183	-117.1221522765141
17999	2020-04-01 07:45:22	2020-04-01	Kalie Schowalter	kalie.schowalter@geemail.com	Stamford	Connecticut	55167026223037817	0c133596d2a3ce30ca9f862baaf907a0	Diners Club / Carte Blanche	41.0602749014157808	-73.4467248294539843
18000	2020-04-01 07:56:03	2020-04-01	Kadence Homenick DVM	kadence.homenick.dvm@geemail.com	New York	New York	869934832403934694	030992c45481a5ddd1644cd1a76b045f	JCB 16 digit	40.6951859077196545	-73.9195999716304186
18001	2020-04-01 08:09:38	2020-04-01	Elliot Ledner	elliot.ledner@geemail.com	San Jose	California	676370658185213	76462aee51a0e7965125812b9f0bf72d	VISA 13 digit	37.2638914838720154	-121.76079070365391
18002	2020-04-01 08:09:46	2020-04-01	Mrs. Marcy Miller	mrs.marcy.miller@geemail.com	Cincinnati	Ohio	210018037033217292	cdac32b3c56392db0c12290b6f682878	Maestro	39.1567791945066332	-84.4440933445274737
18003	2020-04-01 08:13:17	2020-04-01	Pearlene Schiller	pearlene.schiller@geemail.com	Los Angeles	California	3485104803878170	8fedfb3614117ea59bc307e78c1833ab	Mastercard	33.9617247190657991	-118.415026835863657
18004	2020-04-01 08:23:19	2020-04-01	Clarinda Raynor-Purdy	clarinda.raynor.purdy@geemail.com	Los Angeles	California	3020122811693615	dc148d815bf9d24e77381f19741ac52d	VISA 16 digit	34.063072991078343	-118.349732850817219
18005	2020-04-01 08:27:43	2020-04-01	Mose Lind	mose.lind@woohoo.com	Oakland	California	180050894762059629	9ad861747ab8aa50509c84ecf0cfa7a9	Mastercard	37.7912819695785629	-122.275930317101199
18006	2020-04-01 08:33:10	2020-04-01	Laurel Gerhold-Batz	laurel.gerhold.batz@geemail.com	Norfolk	Virginia	53070397593150423	8136545b47d9eef027f207752399ce63	VISA 16 digit	36.9955799845065911	-76.2326136664956806
18007	2020-04-01 08:49:36	2020-04-01	Mr. Darnell Koch	mr.darnell.koch@geemail.com	Fontana	California	4442476393607229	4b8143e7aa8bd5f0ff0199b89c0a25ed	JCB 16 digit	34.0303033810723576	-117.532539719091361
18008	2020-04-01 08:53:38	2020-04-01	Luster Eichmann	luster.eichmann@woohoo.com	Los Angeles	California	6011296253311908709	a111d49e01cd093388751589fc227954	Maestro	34.1096770131360714	-118.353441652002928
18009	2020-04-01 09:02:15	2020-04-01	Colon Roberts	colon.roberts@geemail.com	Fargo	North Dakota	3047584649478431	b90a17aa6c6e4f14a5c39bccdfc2d8fe	JCB 16 digit	46.8644602789308919	-96.820769829625263
18010	2020-04-01 09:17:54	2020-04-01	Harding Ankunding	harding.ankunding@geemail.com	Los Angeles	California	180044127386479066	595272c9c56a26da0c5a2b52f05cd680	VISA 16 digit	34.0046383809629802	-118.418134296638144
18011	2020-04-01 09:22:30	2020-04-01	Nelia Schmidt	nelia.schmidt@woohoo.com	Chicago	Illinois	3088692323412629718	f59ee170720291786a464c112629feda	VISA 16 digit	41.8890961177483234	-87.5894401845086321
18012	2020-04-01 09:25:11	2020-04-01	Rayan Cummings	rayan.cummings@woohoo.com	Nashville	Tennessee	6011925372954196551	2214660cb699b5054cd92bc2c0e1e456	JCB 16 digit	36.1370101239189481	-86.7741589502803947
18013	2020-04-01 09:36:01	2020-04-01	Trenton Gislason-Mayer	trenton.gislason.mayer@geemail.com	San Diego	California	3337868940761493442	51890f4bdbc85c7c5fc438c84362e2b3	Maestro	32.8634446458958109	-117.130983094442641
18014	2020-04-01 09:41:15	2020-04-01	Lorna Kihn	lorna.kihn@geemail.com	Jackson	Mississippi	630407441264194	51a9e59bbf1327d43c809d59a9c28bcc	Discover	32.2433057759135977	-90.1290192414514735
18015	2020-04-01 09:55:42	2020-04-01	Albertus Ortiz	albertus.ortiz@geemail.com	San Francisco	California	210003700408186635	0a8a0f51c34584ea79f423f23a1bc9cb	Voyager	37.7795019946139945	-122.440259971843645
18016	2020-04-01 09:59:19	2020-04-01	Almeda Weimann	almeda.weimann@geemail.com	Huntington Beach	California	3046841116808768	26a25632b42483c8c5f5edb02baea9e1	Voyager	33.731431484831873	-118.034691443446278
18017	2020-04-01 10:40:49	2020-04-01	Irena Goyette	irena.goyette@geemail.com	New York	New York	210067084536188513	367d07d1b63277103cdcfe298f0c45fa	JCB 15 digit	40.7244922864474361	-73.9634753080911906
18018	2020-04-01 10:51:33	2020-04-01	River Leannon	river.leannon@geemail.com	Seattle	Washington	180099721324875411	ec3f6af9e4010dcba6636cdb968265c3	VISA 16 digit	47.7173387082684783	-122.276011392838882
18019	2020-04-01 10:52:25	2020-04-01	Dr. Gisselle Fay DVM	dr.gisselle.fay.dvm@geemail.com	Los Angeles	California	180075805592126231	4207ecd4527e331be0ef0818323dd838	VISA 13 digit	33.9346455286122861	-118.419669928121564
18020	2020-04-01 10:52:55	2020-04-01	Rhea Crona	rhea.crona@geemail.com	San Diego	California	4706595867294569	a56cca472ba2d7e9a92c1d8c6c67ce45	VISA 13 digit	32.8236289027214028	-117.135966166239243
18021	2020-04-01 10:57:03	2020-04-01	Dewey Casper	dewey.casper@geemail.com	San Francisco	California	501822860591266	ddd37e639d9524d4cd1345dde4f3ae75	Mastercard	37.7768229386280083	-122.382365056900198
18022	2020-04-01 10:59:28	2020-04-01	Alf Paucek	alf.paucek@geemail.com	Frisco	Texas	210071526131611566	42f649f15b1e7377a9f7f9ec04a2a9e2	JCB 15 digit	33.1242480350188941	-96.8844130454327797
18023	2020-04-01 11:11:41	2020-04-01	Mr. Godfrey Willms	mr.godfrey.willms@woohoo.com	Springfield	Missouri	53272713355005504	e3c533ee37cbe2fe80cef8c599f0e088	Maestro	37.2431108797162764	-93.317714319127802
18024	2020-04-01 11:14:06	2020-04-01	Pinkney Considine	pinkney.considine@geemail.com	Phoenix	Arizona	3423735908417185	f181629abeb48c13ad6a5c6b70f058bd	JCB 16 digit	33.5546425114318723	-112.102313033810262
18025	2020-04-01 11:16:50	2020-04-01	Mr. Kaiden Turner PhD	mr.kaiden.turner.phd@geemail.com	San Francisco	California	6011056568129492749	6bc03ff9a45b4db64fac14a80082879c	Voyager	37.7529866969249497	-122.425170400380168
18026	2020-04-01 11:22:16	2020-04-01	Kennith Nicolas	kennith.nicolas@geemail.com	San Antonio	Texas	4793174104265	0685ed135bc2869c6d765cf37759bfb5	VISA 13 digit	29.4854103651434194	-98.4758767518982268
18027	2020-04-01 11:34:52	2020-04-01	Pascal Kihn Jr.	pascal.kihn.jr.@warmmail.com	San Francisco	California	3096086596860466303	bc6fdb2f05b90e4d7bf0ed67a55bffe2	JCB 15 digit	37.7818294481643377	-122.412802897993288
18028	2020-04-01 12:24:20	2020-04-01	Alberto Fay	alberto.fay@geemail.com	Seattle	Washington	676363295173445	4229d40a4352b026e5390313b388cf17	VISA 16 digit	47.5820769724361625	-122.414088097579395
18029	2020-04-01 12:57:49	2020-04-01	Liz Schumm	liz.schumm@geemail.com	Buffalo	New York	3088457386732192498	3e02bf802dd58f5a30baa90d47576aca	VISA 13 digit	42.8951034151669575	-78.8923398157980387
18030	2020-04-01 13:40:51	2020-04-01	Mr. Denny Abshire I	mr.denny.abshire.i@geemail.com	San Francisco	California	3112641325021442773	f092968f176cf335841066087d366bee	Discover	37.7992034911992718	-122.457132196456968
18031	2020-04-01 13:44:03	2020-04-01	Mae Lakin	mae.lakin@geemail.com	New York	New York	869947694850676862	23ec492fe85d1c8d97ea45074dd7eab1	Maestro	40.6101159273404591	-73.9383127274818719
18032	2020-04-01 13:45:24	2020-04-01	Riya Smitham	riya.smitham@geemail.com	El Cajon	California	55044259408994200	47fcd4e2fa193f6f99768d1475ec8b0f	Voyager	32.8548002970412369	-116.990806005028645
18033	2020-04-01 13:48:59	2020-04-01	Jaxen Kemmer	jaxen.kemmer@geemail.com	Boise	Idaho	3007391623933724	cc028e87150d9e60104bd61fa8f6c84c	VISA 16 digit	43.5949369367349888	-116.215236939183256
18034	2020-04-01 14:05:45	2020-04-01	Joseline Schowalter DDS	joseline.schowalter.dds@warmmail.com	San Francisco	California	4785119083878982	57b9a50a80c8cc65f90befcfdabfa5b1	VISA 16 digit	37.7742789097019411	-122.444827662045356
18035	2020-04-01 14:27:04	2020-04-01	Medora Rosenbaum	medora.rosenbaum@woohoo.com	Wichita Falls	Texas	4523485068812	108d308fed16d49cc3562ee4613ec5f9	Voyager	33.9891337565340095	-98.4761744051627801
18036	2020-04-01 14:40:19	2020-04-01	Natalia Kozey-Schmeler	natalia.kozey.schmeler@geemail.com	New York	New York	3337541274838213236	2771f514be08a060772a62135f6c30d2	Discover	40.5640882903933502	-73.8407119690801892
18037	2020-04-01 14:40:35	2020-04-01	Marty Kozey DVM	marty.kozey.dvm@geemail.com	New York	New York	52462493359909981	383cbd73c4e6814f6a7aa0fcdc8c9147	JCB 15 digit	40.6744587525017565	-73.9051737157989237
18038	2020-04-01 14:43:34	2020-04-01	Asbury Labadie	asbury.labadie@geemail.com	San Francisco	California	210056994790465816	d501cd1a3954f855682a5029efc1e9b4	Maestro	37.7565383274716453	-122.448359051023203
18039	2020-04-01 14:56:16	2020-04-01	Maverick Wilderman	maverick.wilderman@geemail.com	San Jose	California	3048665915826616	7ef539c3b2ca6ae53e0c91e33b8fa5de	Diners Club / Carte Blanche	37.3751011153504251	-121.747065242075919
18040	2020-04-01 15:02:48	2020-04-01	Quint Gulgowski II	quint.gulgowski.ii@woohoo.com	Victorville	California	4801947618929957	84e56fdab484352d91a102c607cedbad	Maestro	34.4466730619080366	-117.337799605649337
18041	2020-04-01 15:16:05	2020-04-01	Mrs. Bella Baumbach	mrs.bella.baumbach@geemail.com	Lubbock	Texas	3033933282808202	175cda48421155a4be12f8b3632fc8ba	VISA 16 digit	33.6048906109336798	-101.821068034126242
18042	2020-04-01 15:43:45	2020-04-01	Adalynn Kub	adalynn.kub@geemail.com	Phoenix	Arizona	502073235212369	8e8f6744e0f7387dba81cc31bd9b4fdf	Diners Club / Carte Blanche	33.525704985058681	-112.063294593098021
18043	2020-04-01 15:43:46	2020-04-01	Orson Kuphal	orson.kuphal@geemail.com	Los Angeles	California	6011280770752144864	bf399c2751e34c1359de513888d2576e	Mastercard	34.0510943037789318	-118.334383704885084
18044	2020-04-01 15:56:53	2020-04-01	Pollie Funk DVM	pollie.funk.dvm@woohoo.com	New York	New York	3112069451930405801	abb5d4a14a1087698318407691c0ecbf	American Express	40.7236591499522333	-73.9971976941812812
18045	2020-04-01 15:59:40	2020-04-01	Miss Marianita Bosco DVM	miss.marianita.bosco.dvm@geemail.com	Kansas City	Kansas	4999547247065579	3cf776d3e982da0affb8ca03dd16dea9	JCB 15 digit	39.048599795475603	-94.8245416073530834
18046	2020-04-01 16:00:13	2020-04-01	Mr. Billy Auer	mr.billy.auer@geemail.com	Fort Wayne	Indiana	4285719362144	9066f8ba1764e02deb1a148b005be250	Mastercard	41.165454525059836	-85.1478260935504068
18047	2020-04-01 16:16:28	2020-04-01	Dr. Hasan Grant DVM	dr.hasan.grant.dvm@warmmail.com	Berkeley	California	676125793370724	4dd4da1efa3aab2893c7d6e91da5ee4f	VISA 16 digit	37.8944050109477359	-122.26281329700727
18048	2020-04-01 16:19:29	2020-04-01	Argie O'Keefe-Veum	argie.o'keefe.veum@geemail.com	Charlotte	North Carolina	4811715275210	3f2a6a64e9978d67ff809dd5a579e68a	Voyager	35.1328795643776672	-80.8045969448462102
18049	2020-04-01 16:21:47	2020-04-01	Vernal Wolff Jr.	vernal.wolff.jr.@warmmail.com	San Francisco	California	6011843750489037789	e9dbb69ee8abd0c812a8ac92fc0b8013	American Express	37.7724540250154917	-122.415140307344615
18050	2020-04-01 16:38:31	2020-04-01	Burrell Rath-Bruen	burrell.rath.bruen@geemail.com	Spokane	Washington	4019185176237988	4cc09f5bd25d5e58e42cb302dc0b5ff3	VISA 16 digit	47.7440940843667789	-117.464215620271119
18051	2020-04-01 16:38:44	2020-04-01	Hale Parisian III	hale.parisian.iii@geemail.com	Daly City	California	3337073424014793198	b33ada2059d82ae0e0c2ebab304feb78	JCB 16 digit	37.7483316640756996	-122.535574995502827
18052	2020-04-01 17:13:27	2020-04-01	Presley Schulist	presley.schulist@geemail.com	Denver	Colorado	4121965467389720	3791784fc393dfc02a0647213c7a4a84	VISA 13 digit	39.7530194627638878	-104.793189350214234
18053	2020-04-01 17:26:06	2020-04-01	Ms. Concha King DVM	ms.concha.king.dvm@geemail.com	Gilbert	Arizona	180022314645676916	1cad5bee10f22396702535e066a138fd	Diners Club / Carte Blanche	33.4066147107046092	-111.761459893839799
18054	2020-04-01 17:32:48	2020-04-01	Drew Keebler	drew.keebler@geemail.com	San Diego	California	3450348617660222	ef6d4180a1587fb4a6d5f75742c9ba51	Maestro	32.8830572723478056	-117.13522002859041
18055	2020-04-01 17:48:44	2020-04-01	Chelsy West-Cartwright	chelsy.west.cartwright@geemail.com	Houston	Texas	4151225922073010	372f7157522efdd59a7291fe3d84c396	Voyager	29.6887697469986982	-95.4665167103070758
18056	2020-04-01 18:03:35	2020-04-01	Dayna Robel	dayna.robel@geemail.com	Garland	Texas	4354811594887	3bc885179c6b1345fdecafa4a1cd19d5	VISA 13 digit	33.0075574266493277	-96.6587817518666412
18057	2020-04-01 18:27:45	2020-04-01	Ethen Yost V	ethen.yost.v@geemail.com	Oakland	California	3004621682313464	3dc3ad69a4269e8d7024010ace66d7d3	Diners Club / Carte Blanche	37.7796261619787046	-122.274235931645563
18058	2020-04-01 18:28:54	2020-04-01	Kem Kirlin	kem.kirlin@warmmail.com	Houston	Texas	869956536070394966	6901977fea0bc5e38ccfd1ab5993e6d7	JCB 16 digit	29.7412466378495104	-95.4566742954790612
18059	2020-04-01 18:43:32	2020-04-01	Marlo Strosin DVM	marlo.strosin.dvm@geemail.com	Plano	Texas	53116546260065399	867b4ee8404a95b9e77448acc2da9157	VISA 13 digit	32.9578595634169886	-96.7146795339133547
18060	2020-04-01 19:03:24	2020-04-01	Fredy Kreiger	fredy.kreiger@warmmail.com	San Francisco	California	3450809624311349	d21df3772bc018ad660f6cc182c56d33	American Express	37.771649524059832	-122.408897261657629
18061	2020-04-01 19:03:44	2020-04-01	Carleton Gleason	carleton.gleason@geemail.com	Los Angeles	California	3337839934393348880	b6bcd5930d150bde2b8c105e37083645	Voyager	33.9401428256981035	-118.389068146049226
18062	2020-04-01 19:24:09	2020-04-01	Zavion Torp	zavion.torp@woohoo.com	Virginia Beach	Virginia	869987613696599097	cafa4a30ae80dfe44eecbdba465be9dd	Discover	36.8373837650008511	-76.0644728438135189
18063	2020-04-01 19:36:50	2020-04-01	Norman Goldner	norman.goldner@geemail.com	San Francisco	California	4012335210378	3267f5d250ff74f93a8216ee047cd362	Diners Club / Carte Blanche	37.7528772901755119	-122.448302752339941
18064	2020-04-01 19:47:11	2020-04-01	Jaidyn Purdy	jaidyn.purdy@geemail.com	Vancouver	Washington	6011082249686003884	fa278bd3e60f4eed5cbb4b3167be7c61	Discover	45.6792486170843262	-122.559579080209872
18065	2020-04-01 19:57:00	2020-04-01	Scotty Ledner	scotty.ledner@geemail.com	Glendale	Arizona	4075106730379	2c83708002ab5ccb0caf8be664dd92f8	American Express	33.6312603789608886	-112.164584327468276
18066	2020-04-01 20:04:34	2020-04-01	Landan Windler	landan.windler@geemail.com	Los Angeles	California	630433521833641	6190b8df51ca50a6122e63cd1f561268	Diners Club / Carte Blanche	33.9447502790350413	-118.423592819598682
18067	2020-04-01 20:18:07	2020-04-01	Hoover Murazik-Hartmann	hoover.murazik.hartmann@geemail.com	Hampton	Virginia	3337149623783521348	e39384a7b434907a4681c3c47d5dd137	VISA 13 digit	36.9853775332234846	-76.2098300309017276
18068	2020-04-01 20:26:35	2020-04-01	Mr. Alfonzo Anderson	mr.alfonzo.anderson@geemail.com	Oklahoma City	Oklahoma	4967567999198	8e327b8ac1b70a5896829d99963994c7	American Express	35.5026991299729815	-97.4516966373089701
18069	2020-04-01 20:35:16	2020-04-01	Virgle Koch	virgle.koch@geemail.com	Torrance	California	3096870838466457009	58ce2d3a02b71b895f7a631ffba79e01	Diners Club / Carte Blanche	33.7625544283911623	-118.36047776221632
18070	2020-04-01 20:40:40	2020-04-01	Ms. Zina Farrell	ms.zina.farrell@geemail.com	Omaha	Nebraska	54389921082719624	be4c26da0ba9552cf5c0850185be22d9	VISA 16 digit	41.2304272263921803	-96.0310592945315022
18071	2020-04-01 20:44:01	2020-04-01	Lynn Romaguera Sr.	lynn.romaguera.sr.@geemail.com	Louisville	Kentucky	6011981370540825502	123c089054ed64b823fef44eaa5a40ed	JCB 15 digit	38.096175004532185	-85.7097501255642698
18072	2020-04-01 21:02:43	2020-04-01	Roxie Hintz	roxie.hintz@geemail.com	Los Angeles	California	4942396212563327	902efede4a160124b3c69fcbf8e59ed6	Mastercard	33.9381376549467433	-118.405389288439594
18073	2020-04-01 21:36:23	2020-04-01	Rowena Nader	rowena.nader@geemail.com	Berkeley	California	3088719162359539533	abd2a2785a44046ef7182175f1194589	American Express	37.87643365394554	-122.286655291408607
18074	2020-04-01 21:41:05	2020-04-01	Fount Lind-Kunde	fount.lind.kunde@geemail.com	Shreveport	Louisiana	3442718431944815	ad606accdfdef090697248b1f3925cff	VISA 13 digit	32.5620556347310597	-93.8417351348072231
18075	2020-04-01 21:46:08	2020-04-01	Abigayle Cormier	abigayle.cormier@geemail.com	Chicago	Illinois	3747772898946123	e74e5c5f9dbf3ce4a8f1e24c55453950	Maestro	41.7608948979362893	-87.6993204520113778
18076	2020-04-01 22:30:29	2020-04-01	Kenzie Kertzmann	kenzie.kertzmann@geemail.com	Mesa	Arizona	54564739280209074	11ee17c5ad973eb7e21116e08f875d6e	Discover	33.3690425957698338	-111.699337148422003
18077	2020-04-01 22:40:23	2020-04-01	Madeline Swaniawski	madeline.swaniawski@woohoo.com	New York	New York	4942275973589210	548530651fa654bf1f717a7c7e22cd47	VISA 13 digit	40.7577861830815635	-73.8975214549235915
18078	2020-04-01 22:41:41	2020-04-01	Dillion Cummerata	dillion.cummerata@geemail.com	Portland	Oregon	676140292451354	ea371df7fedb9728abc7ec7a9c7083c7	Voyager	45.5065778934285063	-122.716852301778275
18079	2020-04-01 22:44:24	2020-04-01	Chante Fisher	chante.fisher@geemail.com	Murfreesboro	Tennessee	3528993944960711750	23f23155f0cf533de0f3ecee9d4e2ab8	JCB 15 digit	35.7604083769142633	-86.3295609252843974
18080	2020-04-01 22:49:30	2020-04-01	Santiago Leuschke	santiago.leuschke@woohoo.com	San Francisco	California	3158010254315436767	7da7b5f7b740e54d0b24b98dc89b6a75	Diners Club / Carte Blanche	37.760883521880146	-122.421592052491121
18081	2020-04-01 23:22:38	2020-04-01	Elgin Yundt Jr.	elgin.yundt.jr.@geemail.com	Corpus Christi	Texas	3026716939363177	a75334b93ce054acb2b48f09895c6dca	JCB 16 digit	27.6938850600209108	-97.1725696769371581
18082	2020-04-01 23:37:07	2020-04-01	Darrin Heaney	darrin.heaney@geemail.com	San Francisco	California	3096219573292808030	dd308dc43bd4cb49a093fe5fb0031199	VISA 16 digit	37.783775692592215	-122.430633308547101
18083	2020-04-01 23:41:21	2020-04-01	Mrs. Ivette Hyatt	mrs.ivette.hyatt@warmmail.com	Charlotte	North Carolina	54309552777478452	8df797894741e464ed712d491c6fb3c1	JCB 16 digit	35.2135273401413116	-80.8642527494058072
18084	2020-04-01 23:45:27	2020-04-01	Frederick Luettgen	frederick.luettgen@warmmail.com	Oklahoma City	Oklahoma	4474759642602062	2dc2009b7edad32a941447d1388f7598	Voyager	35.5298750976942515	-97.4800383370265422
18085	2020-04-01 23:49:23	2020-04-01	Silas Marks	silas.marks@geemail.com	Denver	Colorado	4212188837949251	e4aa9769c82664e640b231f4c7a41daa	Maestro	39.82058352628313	-104.950102462923525
18086	2020-04-02 00:12:13	2020-04-02	Rowan Hagenes DDS	rowan.hagenes.dds@geemail.com	Chicago	Illinois	6011839484786223340	e2b1c5cdc3007ba09073eaa2ba17c2bb	VISA 13 digit	41.886570209667461	-87.6870025083918136
18087	2020-04-02 00:19:15	2020-04-02	Devontae Robel	devontae.robel@geemail.com	Boston	Massachusetts	6011179907613657734	446f4dba0c98538e8dd33ed68cdb19e5	JCB 15 digit	42.3485163466241232	-71.0134857883628428
18088	2020-04-02 00:24:06	2020-04-02	Salena Keebler-Altenwerth	salena.keebler.altenwerth@woohoo.com	Columbus	Ohio	3158959151162960704	e97e62ead2b1d5cfa42c411fc87055ae	Voyager	40.0119682828940455	-83.0008671810153942
18089	2020-04-02 00:29:37	2020-04-02	Mr. Samie Lebsack III	mr.samie.lebsack.iii@warmmail.com	San Francisco	California	869912392039778409	2f479bac7fac05c02fdd8260ff5f0ac4	Mastercard	37.7884840325205147	-122.400028110831698
18090	2020-04-02 00:46:28	2020-04-02	Mr. Olaf Yost DDS	mr.olaf.yost.dds@geemail.com	Corpus Christi	Texas	561237448232035	f11e85038726ebe8bea76d61f47e0cbc	Maestro	27.7893241086445748	-97.2618864123538174
18091	2020-04-02 00:48:07	2020-04-02	Dr. Baldwin Kautzer	dr.baldwin.kautzer@geemail.com	Jersey City	New Jersey	3454494303716955	c373560a0e4533a0d00923bf6dc9860d	VISA 16 digit	40.7712080944269886	-74.0995280587535348
18092	2020-04-02 01:11:06	2020-04-02	Carmine Crona	carmine.crona@geemail.com	Springfield	Missouri	3096153358071789504	a37099e67407fe1b609bdbe82f91a3b3	VISA 16 digit	37.2245070915862968	-93.2901103550858863
18093	2020-04-02 01:21:25	2020-04-02	Dr. Adrian Murphy	dr.adrian.murphy@geemail.com	Los Angeles	California	4250572990589	106a2393d7be2fe6baf874678eabfccb	Maestro	34.097247399236629	-118.415620342920718
18094	2020-04-02 01:23:54	2020-04-02	Dr. Leslie Blanda	dr.leslie.blanda@woohoo.com	San Francisco	California	869958351377132608	285d888f8f6c73a256efb3e7b4b30686	JCB 16 digit	37.7606958463009121	-122.413258528650374
18095	2020-04-02 01:39:57	2020-04-02	Aryanna Windler PhD	aryanna.windler.phd@geemail.com	Springfield	Illinois	6011676054273029918	d8823d9e74178b6f81384d531398bf61	VISA 16 digit	39.8311798270013213	-89.7391289209019334
18096	2020-04-02 01:51:13	2020-04-02	Clarice Lynch-Padberg	clarice.lynch.padberg@geemail.com	Chicago	Illinois	3158486979230246165	60545fc7ed33080d5f3d063ac907cbdc	Mastercard	41.7787295612808336	-87.5958694888774261
18097	2020-04-02 02:04:54	2020-04-02	Karis Balistreri DVM	karis.balistreri.dvm@geemail.com	Pueblo	Colorado	51100354672245099	858842e8b0393844c0400561434a1243	VISA 13 digit	38.3234706018563358	-104.547253641705225
18098	2020-04-02 02:39:08	2020-04-02	Will Kirlin PhD	will.kirlin.phd@geemail.com	Hollywood	Florida	180086616651715310	faaefab70910a7d33f68da17fc6fc13e	VISA 13 digit	26.0465766891315553	-80.1087077053081202
18099	2020-04-02 02:45:50	2020-04-02	Earlie Abbott-Farrell	earlie.abbott.farrell@geemail.com	New York	New York	501894716498459	4ff1e243278d5d146151f4b4c534874c	VISA 13 digit	40.7158046713788053	-73.8838611278578554
18100	2020-04-02 02:48:02	2020-04-02	Russ Breitenberg	russ.breitenberg@warmmail.com	Mobile	Alabama	4483264982883	225c0c824134dcd38ed170bfd48c2a75	Maestro	30.7421245481461263	-88.1179450137212825
18101	2020-04-02 02:56:04	2020-04-02	Willia Connelly-Braun	willia.connelly.braun@geemail.com	San Antonio	Texas	6011497992920588652	ad8ce583acaa4002b9c7ea3a13ab1efc	Voyager	29.3953732632171381	-98.5767100103501122
18102	2020-04-02 02:57:45	2020-04-02	Ebenezer Kris	ebenezer.kris@warmmail.com	Los Angeles	California	180009527546345698	c192bb07a8e53b53b40f4ad39267101a	American Express	33.923488432947174	-118.360887671633805
18103	2020-04-02 03:17:33	2020-04-02	Kalie Graham	kalie.graham@woohoo.com	New York	New York	675968870683429	9daf5e82ed036372ec43a181df8716d2	VISA 16 digit	40.6374325275644637	-73.8413100670453133
18104	2020-04-02 03:23:50	2020-04-02	Verl Witting	verl.witting@geemail.com	New Haven	Connecticut	4227888398641840	52c088f5120a4f90c820973ae67122b3	JCB 16 digit	41.2276735282495608	-72.8915277465246589
18105	2020-04-02 03:34:50	2020-04-02	Dontae Gislason	dontae.gislason@geemail.com	San Francisco	California	4636308432790292	012a1cc29e02e6f5f99b0a6bb5720cc9	VISA 16 digit	37.7733791384273943	-122.442717800670607
18106	2020-04-02 03:44:37	2020-04-02	Alysa Green	alysa.green@woohoo.com	New York	New York	180006618865509015	5156e91c13f056635cd7feb9e0e20dbd	Diners Club / Carte Blanche	40.7394840460959813	-73.854865104927498
18107	2020-04-02 03:50:47	2020-04-02	Nella Kassulke MD	nella.kassulke.md@geemail.com	New York	New York	3404417480018953	58abbbd9604a39e499f016811e67c0d6	Diners Club / Carte Blanche	40.6893016550447797	-73.9245730468433351
18108	2020-04-02 04:36:24	2020-04-02	Amerigo Okuneva	amerigo.okuneva@warmmail.com	Atlanta	Georgia	503806047475311	0185ffaccad05588cea2c0c738180f94	JCB 16 digit	33.7731802654262623	-84.4036142328333199
18109	2020-04-02 05:10:25	2020-04-02	Dr. Erin Bergnaum I	dr.erin.bergnaum.i@geemail.com	Houston	Texas	3158171586195986238	d14f0f459076af242acc963fddbcb9de	Diners Club / Carte Blanche	29.8122348498165621	-95.4864541765317369
18110	2020-04-02 05:20:00	2020-04-02	Kayden Langworth	kayden.langworth@geemail.com	Chicago	Illinois	4005092835536	98a2a9c56aa9d4cfbf8fa3c2eaf3dccf	JCB 15 digit	41.8216974519494968	-87.5982024824276522
18111	2020-04-02 05:32:13	2020-04-02	Gracie Windler	gracie.windler@geemail.com	Philadelphia	Pennsylvania	3112978156552133603	d46d1e8f899da8feb6fc76496f03ac4c	Maestro	39.9367410276509816	-75.1440609308324809
18112	2020-04-02 05:33:53	2020-04-02	Mrs. Isabelle Stanton DDS	mrs.isabelle.stanton.dds@geemail.com	Winston–Salem	North Carolina	3112848204934416342	78b5026ca9d86cf9c104e9c4b4300625	Discover	36.1666206481631818	-80.1725419886540607
18113	2020-04-02 05:37:35	2020-04-02	Alston Kris	alston.kris@geemail.com	Buffalo	New York	3158168258351459435	e56bc61b3e00e227d12dede9c6d2848b	JCB 16 digit	42.8681740640383211	-78.9371859775789062
18114	2020-04-02 05:39:17	2020-04-02	Pranav Lindgren IV	pranav.lindgren.iv@geemail.com	Oakland	California	180066491755917707	85c9eae1be8649b3265052f38f4a9099	VISA 13 digit	37.7512991950262133	-122.285054610909413
18115	2020-04-02 05:56:19	2020-04-02	Mr. Juelz Corwin DDS	mr.juelz.corwin.dds@warmmail.com	Tucson	Arizona	3337506911283942719	0811df59d8706044b15c073f7a7dd13f	Diners Club / Carte Blanche	32.0572993097402161	-110.872835755184667
18116	2020-04-02 05:59:29	2020-04-02	Mr. Tobie Watsica DDS	mr.tobie.watsica.dds@geemail.com	San Antonio	Texas	3468198651462047	812e09bbbfb2acd60b9bf2f2fc205a82	Discover	29.3754510562472042	-98.4856094079859474
18117	2020-04-02 06:03:48	2020-04-02	Suzie Leuschke	suzie.leuschke@geemail.com	Bellevue	Washington	4320333782562969	1b1e9b27c3dbae05628e9d95d1e23c49	Maestro	47.6334804907623734	-122.144983646791417
18118	2020-04-02 06:08:17	2020-04-02	Ferne Stanton	ferne.stanton@geemail.com	Oakland	California	6011595417105902123	ebad43afc5cdb85bc10569ebeb9688da	Diners Club / Carte Blanche	37.8004413198521902	-122.270622196756577
18119	2020-04-02 06:13:13	2020-04-02	Neola Lebsack	neola.lebsack@geemail.com	San Francisco	California	51751785238936980	85cf73fe1ea5331266dfcbf83ede9be5	Discover	37.7730188147045425	-122.434840874554084
18120	2020-04-02 06:18:09	2020-04-02	Jordan Feeney V	jordan.feeney.v@geemail.com	New York	New York	4653017492643014	3ad474f083e81240fdeb74bd3aef52a5	VISA 13 digit	40.7082038636542833	-73.8918224727164983
18121	2020-04-02 06:27:40	2020-04-02	Tomie Wilkinson DDS	tomie.wilkinson.dds@geemail.com	Philadelphia	Pennsylvania	869933760219573532	6a1506ab197fdfe4bf762950da6c2c45	Voyager	39.9595847307197758	-75.1459293410081415
18122	2020-04-02 06:34:35	2020-04-02	Desmond O'Connell	desmond.o'connell@warmmail.com	San Francisco	California	6011522531280297964	503c49c430b0d41d5d76ef3685b7c381	VISA 16 digit	37.7776741369122604	-122.471806142814273
18123	2020-04-02 06:59:36	2020-04-02	Teddy Sipes	teddy.sipes@woohoo.com	Los Angeles	California	3439339565726004	cef35eb37a73ee81b6c4f4f6ae7790dc	American Express	34.0769015795882737	-118.487114255641771
18124	2020-04-02 07:01:07	2020-04-02	Andre Corkery III	andre.corkery.iii@geemail.com	New York	New York	6011124087586117754	7c65a1dab046f11ccf4eb9f991d24ff6	Maestro	40.5810184363499289	-73.8460370424564871
18125	2020-04-02 07:19:02	2020-04-02	Gladys Heaney DDS	gladys.heaney.dds@woohoo.com	Elk Grove	California	3096562335305675795	53f736aa07cf2ed965fdd42e02d9ae0d	JCB 16 digit	38.4238260172124981	-121.41143207320944
18126	2020-04-02 07:36:02	2020-04-02	Dario Wolf	dario.wolf@geemail.com	Plano	Texas	6011679692459986331	5654d96c5ec1333ac2caaff2b184c40c	JCB 16 digit	33.1108459635257759	-96.8363306848049206
18127	2020-04-02 07:46:50	2020-04-02	Zandra White	zandra.white@geemail.com	Santa Clara	California	4807122685585017	a82fdfa5f864866fb636ac0486da68b0	Maestro	37.4509121496979205	-122.044062828970695
18128	2020-04-02 08:08:42	2020-04-02	Mr. Dan Aufderhar V	mr.dan.aufderhar.v@geemail.com	Oakland	California	3428766396513966	ee97ec9856c6f275f35c7f3b91b9bb24	Voyager	37.8114043335515433	-122.298287604930067
18129	2020-04-02 08:19:10	2020-04-02	Robert Kub IV	robert.kub.iv@geemail.com	Rancho Cucamonga	California	4108621155570033	8a12ee25e2ae60cf1f857fffd9b38d96	Mastercard	34.0635614227496077	-117.503098427644744
18130	2020-04-02 08:21:56	2020-04-02	Abb Rohan	abb.rohan@geemail.com	Tucson	Arizona	4631670934480	11d1ae1fc29a19acf95692657153589e	Discover	32.0909772961441462	-110.92728748840689
18131	2020-04-02 08:30:10	2020-04-02	Johan Reilly	johan.reilly@geemail.com	Meridian	Idaho	561244716425804	12c7eed1bae7a167c087ff5c4fb63647	JCB 15 digit	43.6289319092415226	-116.405929867125678
18132	2020-04-02 08:40:19	2020-04-02	Keila Kihn-Hills	keila.kihn.hills@warmmail.com	Los Angeles	California	3528876723738312477	8c1a5640dc197af0668019f7c00450c0	Diners Club / Carte Blanche	33.9315393086388681	-118.452361505524436
18133	2020-04-02 08:42:02	2020-04-02	Lita Lehner	lita.lehner@geemail.com	San Francisco	California	869991889100719026	6f29cf3f2f4b6211543b4f81ec588f0b	VISA 16 digit	37.7860351255997315	-122.44040264526754
18134	2020-04-02 08:50:10	2020-04-02	Cleola Huel	cleola.huel@geemail.com	Houston	Texas	3112757260659267251	771dc7ab4f2f05848ab15eb816309c91	Voyager	29.6938478698100887	-95.3322736882619637
18135	2020-04-02 08:56:25	2020-04-02	Ms. Audriana Robel DVM	ms.audriana.robel.dvm@geemail.com	Portland	Oregon	4318997211061	0bef8e0f963d80045573b94ca006c894	Discover	45.451229602832349	-122.594088571518668
18136	2020-04-02 09:08:15	2020-04-02	Mykel O'Reilly-Hettinger	mykel.o'reilly.hettinger@geemail.com	Norfolk	Virginia	4825137886974	e71d5684f26b6a6813e8ac2ae84ee2ac	VISA 16 digit	36.9960334859807034	-76.1800713333770716
18137	2020-04-02 09:17:33	2020-04-02	Arland Lindgren-Grady	arland.lindgren.grady@geemail.com	Richmond	Virginia	55267373456847234	7ff595fd5760f05334ee15ada8e38f6f	Discover	37.6152723589200519	-77.5027757640220187
18138	2020-04-02 09:18:35	2020-04-02	Donn Macejkovic	donn.macejkovic@warmmail.com	Houston	Texas	869985874721480701	718ead5be7a9b6d6e9ff36f2ffeb441d	VISA 16 digit	29.6939471063748002	-95.3829007020700743
18139	2020-04-02 09:21:47	2020-04-02	Virgel Hegmann	virgel.hegmann@warmmail.com	Charleston	South Carolina	589357772990701	41ec5c3acccc7d22c391f9e105470557	Voyager	32.854009202913943	-80.0500167925059856
18140	2020-04-02 09:32:09	2020-04-02	May Lind	may.lind@geemail.com	Costa Mesa	California	3112130845638397795	47879c5a5304743c2a156629ec29d039	American Express	33.614481317393107	-117.972637184555836
18141	2020-04-02 09:33:01	2020-04-02	Vinnie McKenzie	vinnie.mckenzie@geemail.com	Santa Clara	California	4620732171850801	1fc074fb69c882e6b13cc9796ec1e8b0	Maestro	37.4185592397864966	-121.950891608325392
18142	2020-04-02 09:37:24	2020-04-02	Kimberlie Boyer	kimberlie.boyer@geemail.com	San Francisco	California	3528584520141260985	d60ab83203fb8fa7001f740229590826	Discover	37.7498683319714345	-122.422340521482255
18143	2020-04-02 09:55:21	2020-04-02	Otto Keebler	otto.keebler@geemail.com	Memphis	Tennessee	180053659386359227	7bceb0444eeae09cae465315fbcaef18	Maestro	35.176672546339411	-89.9861001893203678
18144	2020-04-02 10:00:32	2020-04-02	Emory Murazik	emory.murazik@geemail.com	San Francisco	California	3741670157983462	e4d487acf2378f41283e23f229129ba9	American Express	37.7940284667244413	-122.482639791958931
18145	2020-04-02 10:04:40	2020-04-02	Miss Elsa Gerhold MD	miss.elsa.gerhold.md@woohoo.com	Hampton	Virginia	4592077573419324	bc8efe2c496c949565d9f0a81b0101f1	American Express	37.0672188016138975	-76.2212034323349599
18146	2020-04-02 10:15:34	2020-04-02	Mrs. Mahala Cremin	mrs.mahala.cremin@geemail.com	Ontario	California	3769705064000971	32576619c691940abc7e50f9a1c0382d	JCB 16 digit	34.0738143900088986	-117.572347154198965
18147	2020-04-02 10:35:31	2020-04-02	Nada O'Conner	nada.o'conner@geemail.com	San Francisco	California	676279332909542	885a52062f437090893bc6e33de0f16e	VISA 13 digit	37.7556484628952731	-122.403594800995464
18148	2020-04-02 10:47:27	2020-04-02	Cliffie Hudson	cliffie.hudson@geemail.com	Buffalo	New York	3001804811330855	129a78043bfb0fee2391c89d98ad9397	VISA 16 digit	42.9210326818004262	-78.9218565584559002
18149	2020-04-02 10:49:33	2020-04-02	Shaylee Terry	shaylee.terry@woohoo.com	New York	New York	3798914040325925	ae404876e3ff1b0c6b331938b76395d0	JCB 16 digit	40.636456640459599	-74.0327447987988592
18150	2020-04-02 10:59:04	2020-04-02	Gloria Block	gloria.block@geemail.com	New York	New York	4774181940827423	0f60622f88388a9b76e3ee8688e8f2b2	JCB 16 digit	40.6891278158165477	-73.9045690185751738
18151	2020-04-02 11:06:49	2020-04-02	Kristian Monahan	kristian.monahan@geemail.com	Sugar Land	Texas	4793832613400	4b0e2b73364b605632cf46aeb9ad5d58	American Express	29.6933848703332224	-95.6158527451574827
18152	2020-04-02 11:09:48	2020-04-02	Danica Nicolas DVM	danica.nicolas.dvm@geemail.com	Los Angeles	California	4902073526017641	9e2e8a5da6c092369f8d34845dfd7f06	Maestro	34.0559509951952819	-118.380065205366535
18153	2020-04-02 11:12:39	2020-04-02	Green Smith	green.smith@geemail.com	Chicago	Illinois	3047066604964860	21f443826c68ce7b28916f6cf88e4fb8	JCB 16 digit	41.8015916291926075	-87.6929405233386916
18154	2020-04-02 11:20:39	2020-04-02	Mr. Jakob Bartoletti Sr.	mr.jakob.bartoletti.sr.@geemail.com	San Francisco	California	869998664704390398	95d6b9ccf5dfea879c5785003e497d3c	VISA 16 digit	37.7653057299429662	-122.437634253539471
18155	2020-04-02 11:20:58	2020-04-02	Braylen Beier	braylen.beier@geemail.com	Orange	California	3024928420464321	14858cba9ca83518fc306e445adbb745	American Express	33.8808284803181863	-117.764207855436212
18156	2020-04-02 11:21:20	2020-04-02	Mrs. Paralee Klein	mrs.paralee.klein@geemail.com	Norfolk	Virginia	675995929544898	6e844ee3c31910f8ec98038259256b33	VISA 13 digit	37.0019605651516486	-76.1617822148375296
18157	2020-04-02 11:29:18	2020-04-02	Aniyah Marquardt	aniyah.marquardt@geemail.com	San Francisco	California	3528741423550375917	8207556d7c3aaa675a2a84d63f707685	Maestro	37.7777986114865101	-122.383233614747112
18158	2020-04-02 11:45:22	2020-04-02	Deana McKenzie	deana.mckenzie@geemail.com	Fremont	California	4544295333212172	c16f0275aca2b2d86cc57a06eea613a5	VISA 13 digit	37.4136074861213572	-122.021227328431607
18159	2020-04-02 11:47:39	2020-04-02	Mr. Nico Boyer III	mr.nico.boyer.iii@warmmail.com	Dallas	Texas	3088095536751149997	05e7574b8d9ec67e5727d01c87216e20	American Express	32.7159973476819701	-96.7731891172435041
18160	2020-04-02 11:49:06	2020-04-02	Jaxton Will	jaxton.will@geemail.com	Hartford	Connecticut	4304160527004	47faf1499b62f49c2c68663a7f50b22a	JCB 15 digit	41.7399141911897829	-72.7498554604485719
18161	2020-04-02 11:58:12	2020-04-02	Delma Prohaska-Baumbach	delma.prohaska.baumbach@woohoo.com	Grand Prairie	Texas	6011925444075240434	7b6cf03afdc9d56c1cda071639c0ff2a	Maestro	32.7419936075393139	-97.096335338276262
18162	2020-04-02 12:00:05	2020-04-02	Geary Kessler II	geary.kessler.ii@geemail.com	Abilene	Texas	3056783159632970	689194a49fd1a8a5a6de5f54caef57a0	American Express	32.5001638095434799	-99.6524411203287599
18163	2020-04-02 12:17:09	2020-04-02	Miss Diamond Wiza DVM	miss.diamond.wiza.dvm@geemail.com	Houston	Texas	6011600976661849203	95d3a61b827087f03de06e03c5554c86	Maestro	29.8204566340506076	-95.4577695206288297
18164	2020-04-02 12:18:32	2020-04-02	Chadwick Beer-Mann	chadwick.beer.mann@geemail.com	New York	New York	4412356613452	01821d472311b9a55ae9ca95efc82402	Voyager	40.7103312582001067	-73.8622862919595065
18165	2020-04-02 12:24:53	2020-04-02	Verlyn Lind	verlyn.lind@geemail.com	Fremont	California	4392337698465558	02f2ba04262c8bd27f0cbfdbdbc1fd2a	JCB 16 digit	37.4397605140395484	-121.845597332062937
18166	2020-04-02 12:26:40	2020-04-02	Tricia Mann MD	tricia.mann.md@geemail.com	Tampa	Florida	3112507854860384914	a35339ad9f2834932e1214349d6f4102	JCB 16 digit	27.9976585909374052	-82.3845165041021943
18167	2020-04-02 12:36:23	2020-04-02	Deliah Abernathy	deliah.abernathy@geemail.com	Orange	California	3798276965576845	5358a009821b6ae550b0fa19392dd70a	JCB 15 digit	33.7777140215858793	-117.782844893085951
18168	2020-04-02 12:40:50	2020-04-02	Shameka Schoen	shameka.schoen@geemail.com	San Francisco	California	3057942827545662	e20c199bd2b2ad7c82cd5d0289e15069	JCB 16 digit	37.7669579534715893	-122.447281696848734
18169	2020-04-02 12:48:22	2020-04-02	Jeremey Leffler	jeremey.leffler@woohoo.com	New York	New York	3088296159006874611	917a3f1da21482d8a0af7a8133c25450	Discover	40.5832590909898272	-73.9236362017586828
18170	2020-04-02 13:07:37	2020-04-02	Mauro Schmitt	mauro.schmitt@geemail.com	Berkeley	California	51989306226984793	907d3d69bde9877010f3e4af0f00a20e	VISA 13 digit	37.8615281332521221	-122.278904180292145
18171	2020-04-02 13:29:14	2020-04-02	Brenton Ziemann Jr.	brenton.ziemann.jr.@woohoo.com	Alexandria	Virginia	180038956882364242	52cfb564fb16243ad0252199c54f8221	JCB 16 digit	38.8099357895668575	-76.9983673820722885
18172	2020-04-02 13:29:45	2020-04-02	Miss Kamilah Schmidt PhD	miss.kamilah.schmidt.phd@geemail.com	Milwaukee	Wisconsin	3112360902006397260	b18c839b83dc999ac12e37b7e43904d6	Voyager	43.1106221079446357	-88.05313344612793
18173	2020-04-02 13:32:00	2020-04-02	Donal Batz	donal.batz@geemail.com	Yonkers	New York	3466809416508245	b2db3417b37795a5b694ac307a486a84	VISA 16 digit	41.014128502152488	-73.8909726261511537
18174	2020-04-02 13:39:20	2020-04-02	Lambert Leannon	lambert.leannon@woohoo.com	San Antonio	Texas	3528852756162402073	23c8f6818642cc0235c8c586d8b5e64a	Voyager	29.4856977130357194	-98.6078498712111156
18175	2020-04-02 13:53:35	2020-04-02	Omari Dicki DDS	omari.dicki.dds@geemail.com	Hampton	Virginia	51786747804901151	b89c5aa4711ecd1115ea83e1f52c39d8	VISA 16 digit	37.1368532311189909	-76.2911416665282047
18176	2020-04-02 13:57:30	2020-04-02	Dr. Willaim Champlin	dr.willaim.champlin@geemail.com	San Francisco	California	3020979130276871	8fd1691f71a1ff1fbae55fb1da1dd12e	Maestro	37.7655627997251884	-122.468104344580283
18177	2020-04-02 14:22:35	2020-04-02	Darlene Schinner	darlene.schinner@woohoo.com	Long Beach	California	3528248908268276611	21347e0c646c1dca7955675a795e0755	JCB 16 digit	33.8612313242450327	-118.150505970667297
18178	2020-04-02 14:40:38	2020-04-02	Izetta Gleason	izetta.gleason@geemail.com	Fresno	California	3059615579209483	76d46f10b5f2805a8df73c111052a3fd	Maestro	36.7133201721929012	-119.875329013272747
18179	2020-04-02 14:55:45	2020-04-02	Rustin Brown	rustin.brown@geemail.com	Minneapolis	Minnesota	869961093769899007	c62aee80e7fde03af0295e494017a053	Mastercard	44.9754565815992606	-93.2557454410280968
18180	2020-04-02 15:53:18	2020-04-02	Haylie Prosacco MD	haylie.prosacco.md@geemail.com	San Francisco	California	52997862254583584	32636b0b0783291f1bf4f892d5ba01e8	VISA 16 digit	37.7987561204095641	-122.435388119813112
18181	2020-04-02 16:02:38	2020-04-02	Annika Walsh	annika.walsh@geemail.com	Columbia	South Carolina	180066886800904818	f92b15486e400722ee575b12212c782a	JCB 16 digit	34.0234425238132445	-80.8111297889165598
18182	2020-04-02 16:03:21	2020-04-02	Hadassah Rath	hadassah.rath@woohoo.com	Lowell	Massachusetts	3028278002087124	64fe009de770e8931afaf60874314906	Maestro	42.6170824831221253	-71.3036620425399406
18183	2020-04-02 16:06:27	2020-04-02	Stacey Beier-Kozey	stacey.beier.kozey@geemail.com	West Jordan	Utah	630405793187849	9bfc1e720b849bd8b7b3ad426de686e7	American Express	40.685796972855556	-111.938964736563335
18184	2020-04-02 16:21:58	2020-04-02	Leonore Treutel	leonore.treutel@geemail.com	Bakersfield	California	4069893945932248	778746d9e1ce71295991c2d597dab2c9	Mastercard	35.3389373521029952	-119.075907977604487
18185	2020-04-02 16:23:32	2020-04-02	Desirae Christiansen-Runte	desirae.christiansen.runte@geemail.com	Arlington	Texas	3411836372796338	b3a1344b75a46052f32f0262b5f4a55b	VISA 13 digit	32.7418392276640944	-97.2090998545780849
18186	2020-04-02 16:53:07	2020-04-02	Melton Mayer-Ondricka	melton.mayer.ondricka@warmmail.com	Philadelphia	Pennsylvania	6011034461634604924	b17ce33bf66beffeeb99e65cf24f163c	Maestro	39.9352720052428509	-75.0948222865250017
18187	2020-04-02 16:55:30	2020-04-02	Korbin Metz	korbin.metz@geemail.com	Springfield	Massachusetts	3026111869224112	27835c7d556f3048eae9ac91d8dbd1cc	Voyager	42.1016270471941638	-72.524853203641257
18188	2020-04-02 16:55:58	2020-04-02	Chelsi Hamill	chelsi.hamill@geemail.com	New York	New York	4595506061894363	c84ffb6a53443841c83277cf2adf77b0	Discover	40.6104652155414243	-73.8632032761711628
18189	2020-04-02 17:01:12	2020-04-02	Jamarion Crist	jamarion.crist@geemail.com	Berkeley	California	4995695107779823	474c1951cbfcf2975266936b09f539e6	VISA 16 digit	37.8333765143505403	-122.247762521951671
18190	2020-04-02 17:02:12	2020-04-02	Cheryl Muller	cheryl.muller@woohoo.com	Abilene	Texas	503823845926270	d574d8fa1602946af9c1f9296cf3e06e	Discover	32.5457346506491305	-99.8087475796178012
18191	2020-04-02 17:16:36	2020-04-02	Peyton Sanford-Miller	peyton.sanford.miller@woohoo.com	Tallahassee	Florida	3008708373797133	335e042fa5fa5e12d672f78aee0f04f8	Mastercard	30.5366369970630878	-84.3176050110734963
18192	2020-04-02 17:30:15	2020-04-02	Khiry McClure	khiry.mcclure@geemail.com	Chicago	Illinois	4116309943626024	10afedb2d30b07dd689cd658dbd0ca12	American Express	41.7826423974078196	-87.6476690333831954
18193	2020-04-02 17:35:06	2020-04-02	Ancil Brakus	ancil.brakus@warmmail.com	Chicago	Illinois	4578178823687062	6f32c15a017c03877dea94b90e9dd1d4	VISA 16 digit	41.8345748379196962	-87.659427855073659
18194	2020-04-02 17:35:46	2020-04-02	Ms. Catrina Moore	ms.catrina.moore@geemail.com	Evansville	Indiana	6011954688211826993	9d66c20f5e0f81ab1f9486dc03423f09	Mastercard	38.0480381477761966	-87.5391684092514168
18195	2020-04-02 17:49:06	2020-04-02	Dr. Shaunna Klein	dr.shaunna.klein@geemail.com	Chicago	Illinois	180039167979522523	508edaee1ff37bcdd9ddfc7f3d42ec0d	Maestro	41.8194461103364858	-87.6722778535012139
18196	2020-04-02 18:03:17	2020-04-02	Reason Mueller	reason.mueller@warmmail.com	Raleigh	North Carolina	676375398858219	47a61459c780e2840e926ea6c0f61ca4	JCB 16 digit	35.8551224441867262	-78.7372474839847598
18197	2020-04-02 18:03:43	2020-04-02	Dr. Sunny Runte	dr.sunny.runte@geemail.com	Laredo	Texas	3041455235977761	8a51fe97ec9deb4e489ba3732302591f	JCB 16 digit	27.4895162197943783	-99.3975378915209262
18198	2020-04-02 18:05:35	2020-04-02	Tiffanie Ankunding	tiffanie.ankunding@geemail.com	San Francisco	California	54125977878986768	4d972392174768323e46ad5947aa8085	Voyager	37.7355335528936351	-122.440538204571538
18199	2020-04-02 18:21:55	2020-04-02	Antoine Zulauf	antoine.zulauf@geemail.com	San Diego	California	4419040614739	a41295c2a3ba17e99742755f7bd89ec6	Mastercard	32.741700969456879	-117.21368338627741
18200	2020-04-02 18:26:52	2020-04-02	Dr. Berkley Bins	dr.berkley.bins@geemail.com	San Antonio	Texas	4758465498007	f2a4998b2f217d3b2367d8524be38dac	JCB 16 digit	29.473416497192904	-98.5219877695966488
18201	2020-04-02 18:43:08	2020-04-02	Sean Prohaska MD	sean.prohaska.md@geemail.com	Miami Gardens	Florida	4535300567356	1d602d72a50473dacc2750b6dfa3d8d4	VISA 16 digit	25.9094473240837431	-80.1715291979037232
18202	2020-04-02 18:45:17	2020-04-02	Miss Izabella Johnson MD	miss.izabella.johnson.md@warmmail.com	Oakland	California	180085381113009866	927a078c993e764eb1e4a6afe1cefea6	VISA 16 digit	37.8292289235330585	-122.28047211963333
18203	2020-04-02 18:56:57	2020-04-02	Zoie Gerhold	zoie.gerhold@geemail.com	Pittsburgh	Pennsylvania	180017026583675893	4049d29a211a1a92db80ffba34b2d259	VISA 16 digit	40.4139269657388311	-80.0434676142580912
18204	2020-04-02 19:02:41	2020-04-02	Dr. Lane Willms III	dr.lane.willms.iii@geemail.com	New York	New York	3096884815541434793	5367dd38e1c6f9f46fc8750068f9625c	Voyager	40.6285391938630482	-73.9296045203588932
18205	2020-04-02 19:02:45	2020-04-02	Herschel Macejkovic	herschel.macejkovic@geemail.com	Dallas	Texas	210006001488110786	daaabd8ebe537d80606e1636b2075b15	American Express	32.7302532549288117	-96.7723561241719779
18206	2020-04-02 19:32:29	2020-04-02	Birdie Johns	birdie.johns@geemail.com	Indianapolis	Indiana	561281038405908	65a377d1602bf3f68757b0ef0e042c3e	Voyager	39.7786881669431907	-86.1917329937886478
18207	2020-04-02 19:37:42	2020-04-02	Mr. Ab Sporer	mr.ab.sporer@woohoo.com	San Francisco	California	4552514603852106	53f67329fedb8a62ebc8e659cea52175	VISA 13 digit	37.7723470172719971	-122.432931767309043
18208	2020-04-02 20:07:18	2020-04-02	Vickie Kris-Bergstrom	vickie.kris.bergstrom@geemail.com	Paterson	New Jersey	4802042732064722	063d68611c3d1d49f8ca4fcdc0acc523	Discover	40.9088841292496781	-74.0836932134788526
18209	2020-04-02 20:23:09	2020-04-02	Cas O'Hara II	cas.o'hara.ii@geemail.com	Montgomery	Alabama	3088661574970830265	033b0fbeb064a9d71f6f9e4b7e854ee0	JCB 15 digit	32.2517476409140968	-86.2884979028873147
18210	2020-04-02 20:32:56	2020-04-02	Dr. Ignatius Bins III	dr.ignatius.bins.iii@geemail.com	Fort Wayne	Indiana	3413017103474135	1ebe5f65bd8e759ba5114f41245c3784	VISA 16 digit	41.0370388200756153	-85.2136220290079791
18211	2020-04-02 20:35:50	2020-04-02	Venessa Reynolds	venessa.reynolds@warmmail.com	Santa Clara	California	3337968078281239539	41711dcb0860b148e7c2c3bef92132d4	VISA 16 digit	37.3678458545640169	-122.009279789030174
18212	2020-04-02 20:41:47	2020-04-02	Evita Mante DDS	evita.mante.dds@geemail.com	San Jose	California	4804097983521257	c4742bb77dcd3a17ca4e3c6ca8cfac0f	JCB 16 digit	37.3493100011542438	-121.872910728374123
18213	2020-04-02 20:58:52	2020-04-02	Koda Murray	koda.murray@geemail.com	Rochester	Minnesota	3498801350100149	723d4c18e14ad42d4810b731d276ec53	VISA 16 digit	44.1046809977289271	-92.4756177405480315
18214	2020-04-02 21:01:15	2020-04-02	Jermain Schuppe	jermain.schuppe@geemail.com	San Francisco	California	4295856231192138	0ec7944523642f6cdeb6c0167a3510d0	JCB 16 digit	37.7563270078919189	-122.458131329926658
18215	2020-04-02 21:07:50	2020-04-02	Contina Schroeder	contina.schroeder@geemail.com	Peoria	Arizona	210082672887812383	f5fdf63094bbfdfc3fb391acd817ee51	JCB 16 digit	33.704404963719476	-112.261725893655793
18216	2020-04-02 22:02:49	2020-04-02	Helaine Jacobi	helaine.jacobi@geemail.com	San Francisco	California	210026178359338153	df9d645fd9d89f8e4c9c8cfce92b4021	JCB 16 digit	37.7924787827594102	-122.466052137725839
18217	2020-04-02 22:13:57	2020-04-02	Mat Johnson	mat.johnson@woohoo.com	Atlanta	Georgia	55887841278321851	bde3ded0e0d5a7d490f3114cfc2db83f	VISA 16 digit	33.6895303601209122	-84.4110647436276196
18218	2020-04-02 22:16:48	2020-04-02	Lenon O'Reilly	lenon.o'reilly@warmmail.com	Oklahoma City	Oklahoma	3337651926056763491	e4335967f4f84678ab1398adb849d92e	Maestro	35.5664205651175251	-97.5206200636353344
18219	2020-04-02 22:21:06	2020-04-02	Kit Schaefer	kit.schaefer@geemail.com	Austin	Texas	53505728157545167	a14050a84d0182235ea34bb9870e933a	JCB 15 digit	30.3790439582090812	-97.7321981931343657
18220	2020-04-02 22:36:53	2020-04-02	Annabella Pfeffer-Braun	annabella.pfeffer.braun@geemail.com	San Jose	California	3158318513811968477	ba575f92cf7afb6fea62151d631f9af6	JCB 16 digit	37.3088090616565182	-121.887324765951931
18221	2020-04-02 22:40:29	2020-04-02	Mckinley Mante	mckinley.mante@geemail.com	Orange	California	3528545932729088878	72745bd7360e1c6161b0da7f81d41ebd	JCB 16 digit	33.7481267390195256	-117.840798942801726
18222	2020-04-02 23:14:22	2020-04-02	Jonatan Reichert	jonatan.reichert@warmmail.com	San Francisco	California	869901971466132900	0451696dedf8b1a5b6112adcb71c1f7e	JCB 16 digit	37.8123694758806224	-122.428108266827394
18223	2020-04-02 23:21:22	2020-04-02	Lemuel Zulauf	lemuel.zulauf@woohoo.com	Memphis	Tennessee	503849325554191	f657c41f8dc9e41d9824c2ed2a042dbf	VISA 13 digit	35.1633688421055695	-89.9729289474688443
18224	2020-04-02 23:35:05	2020-04-02	Gaylon Abshire	gaylon.abshire@geemail.com	Hartford	Connecticut	3528025198648223371	9bf10ffffd744a877d3c555dd4ab3334	JCB 16 digit	41.7455328508295125	-72.7304682498689772
18225	2020-04-02 23:51:24	2020-04-02	Euna Considine	euna.considine@woohoo.com	Des Moines	Iowa	3528695071233194241	68a0948abf82f1d2947094bf47e62f8b	JCB 15 digit	41.617860819839315	-93.6768229208465755
18226	2020-04-02 23:58:08	2020-04-02	Elmira Sawayn	elmira.sawayn@warmmail.com	Los Angeles	California	3096182141220389201	45cb84e9814a3cf2071abb411512179f	Maestro	34.0959207501128319	-118.382484614848337
18227	2020-04-03 00:04:31	2020-04-03	Norris Walsh	norris.walsh@woohoo.com	San Francisco	California	4312714178372	634093c314f30e73554af78105c860d3	JCB 15 digit	37.8138979150459562	-122.460233534728218
18228	2020-04-03 00:24:02	2020-04-03	Gaylen Mayer	gaylen.mayer@geemail.com	Oakland	California	180030505596588402	acf6921a3aefb5df5e75cec50aa1ee73	Discover	37.8303861729462128	-122.248605017736281
18229	2020-04-03 00:42:08	2020-04-03	Mr. Lloyd Quigley V	mr.lloyd.quigley.v@geemail.com	San Francisco	California	869980096939166758	9fb3f04681d97d79cfab7e8ae70739d4	JCB 15 digit	37.8060336585655961	-122.439668033132548
18230	2020-04-03 00:43:00	2020-04-03	Olin Sipes	olin.sipes@woohoo.com	New York	New York	4096152375740564	c79e49d3bd62d128c6954f992aefbe67	JCB 15 digit	40.7563038651123648	-73.9663031986810182
18231	2020-04-03 00:58:32	2020-04-03	Dr. Lashawn Schmitt Jr.	dr.lashawn.schmitt.jr.@geemail.com	San Francisco	California	4721774810878924	1662b48de67cd1b1f980324a05a22dc5	JCB 16 digit	37.789735282961054	-122.45977667757127
18232	2020-04-03 01:07:41	2020-04-03	Santino Gottlieb	santino.gottlieb@woohoo.com	Oakland	California	4789267471167066	fec6017124edb76434f7f185f24baac3	Maestro	37.776460726291873	-122.274369798924582
18233	2020-04-03 01:21:05	2020-04-03	Dr. Greyson Hudson MD	dr.greyson.hudson.md@geemail.com	Tacoma	Washington	4221937851113643	282f955eb38b1b5d809d7fa8931f6b53	VISA 16 digit	47.3422629358366152	-122.362641365709905
18234	2020-04-03 01:26:01	2020-04-03	Zachariah Ritchie	zachariah.ritchie@geemail.com	Bellevue	Washington	51333918156048523	8997d452ee3b569e4ed94efc45643ea6	Maestro	47.5568003675617277	-122.097543255245313
18235	2020-04-03 02:10:24	2020-04-03	Dr. Mervin Kertzmann MD	dr.mervin.kertzmann.md@geemail.com	Chicago	Illinois	4333264257143	998a2aeab3592f99f96d15d3007824fc	JCB 16 digit	41.7805110000841324	-87.7208422713477063
18236	2020-04-03 02:11:56	2020-04-03	Lorne Mertz	lorne.mertz@woohoo.com	Long Beach	California	501813396825237	bf6748d33040011a167d0ba186d1e70a	JCB 16 digit	33.7954930093891903	-118.250944692145282
18237	2020-04-03 02:14:57	2020-04-03	Khiry Stracke	khiry.stracke@geemail.com	Simi Valley	California	3748093370089509	bf6e9ef1aad16a574ef1089c6d3130df	Maestro	34.2424261079408225	-118.680452183740215
18238	2020-04-03 02:33:04	2020-04-03	Dena Wisozk	dena.wisozk@warmmail.com	Rochester	New York	3016362657720643	37a94841c58da6122cfd85727c70fdca	American Express	43.176007968045397	-77.6196887335047165
18239	2020-04-03 02:33:22	2020-04-03	Mr. Roscoe Dibbert	mr.roscoe.dibbert@warmmail.com	Berkeley	California	3158756425680425464	a9bc5c458e9c3eeba7f86c7e6199ab7f	JCB 16 digit	37.8846472295258323	-122.292981709509377
18240	2020-04-03 02:40:29	2020-04-03	Georgie Huels	georgie.huels@geemail.com	Tulsa	Oklahoma	52623261273995204	87de6de179d149cc21349b4ff6da35e6	VISA 16 digit	36.0431378879953144	-95.93907725810557
18241	2020-04-03 03:23:24	2020-04-03	Dola Walter	dola.walter@geemail.com	Raleigh	North Carolina	630443217493741	057f2d8dab2a7c7d427b08ba9c492d23	American Express	35.7755243475217313	-78.7378853059310444
18242	2020-04-03 03:23:25	2020-04-03	Mr. Newell Bailey IV	mr.newell.bailey.iv@geemail.com	Vista	California	869907952508979965	ecd9b976235929aa31785197191bf0d3	American Express	33.2518827676754469	-117.304918955691534
18243	2020-04-03 03:39:49	2020-04-03	Demetri Gutmann-VonRueden	demetri.gutmann.vonrueden@geemail.com	Frisco	Texas	210048379378648804	995dd055e3815b09b36e3c763bc23aa6	JCB 15 digit	33.1751228328790546	-96.7983627509999991
18244	2020-04-03 04:06:03	2020-04-03	Ms. Tarah Beatty	ms.tarah.beatty@geemail.com	Austin	Texas	180060664427796081	d7b4ff55f34c25381a11a274af844965	VISA 16 digit	30.371761393420023	-97.710308722244207
18245	2020-04-03 04:06:26	2020-04-03	Alto Waelchi	alto.waelchi@woohoo.com	Houston	Texas	54080229358044293	5e1c28a1b24643a2859a3eec07925f57	JCB 15 digit	29.8189656355030834	-95.3140338164303529
18246	2020-04-03 04:09:39	2020-04-03	Syed Hagenes-Hessel	syed.hagenes.hessel@geemail.com	Chula Vista	California	869945190914988064	e9bd90be904dd7fbc91996f558139403	VISA 16 digit	32.721142648602644	-117.024956051097064
18247	2020-04-03 04:14:08	2020-04-03	Marget Dickinson	marget.dickinson@woohoo.com	Sacramento	California	4637413128186281	760e8a3c5c9644cfed52b8bcceae824c	VISA 13 digit	38.5032219691932198	-121.395412448212866
18248	2020-04-03 04:18:02	2020-04-03	Kinsley Greenfelder-Abshire	kinsley.greenfelder.abshire@geemail.com	Lansing	Michigan	3030493669146877	5541c62d08daad22002043957b7b95eb	JCB 15 digit	42.7847352823551788	-84.5233117272734518
18249	2020-04-03 04:25:55	2020-04-03	Zettie Toy	zettie.toy@geemail.com	San Mateo	California	4333219943911895	e3bea7af7c702afcb742e949a329d2b7	VISA 13 digit	37.6299144488640138	-122.235908060925453
18250	2020-04-03 04:37:36	2020-04-03	Kelvin Pouros-Purdy	kelvin.pouros.purdy@geemail.com	Downey	California	675916535355487	623d732a4abec23a2ad2cfdbf47f2715	Mastercard	33.972313272977992	-118.160174736624214
18251	2020-04-03 04:39:19	2020-04-03	Jaycie Klein	jaycie.klein@warmmail.com	Huntington Beach	California	676171433627875	c7a2684e051018e4592576d508e1c6be	Mastercard	33.6348417909856892	-117.934183315246543
18252	2020-04-03 05:03:03	2020-04-03	Dr. Darwin Boyle MD	dr.darwin.boyle.md@woohoo.com	San Francisco	California	3717418572278682	35a68a9de45663889c03292c35ebae86	Discover	37.8160631559987195	-122.403333121693379
18253	2020-04-03 05:08:20	2020-04-03	Hilmer Maggio DVM	hilmer.maggio.dvm@geemail.com	San Francisco	California	6011549657373735278	d489e924498e5b6a11bab7a8ec31feee	Mastercard	37.7561084764381931	-122.454314043378417
18254	2020-04-03 05:13:20	2020-04-03	Miss Amalia Koepp MD	miss.amalia.koepp.md@woohoo.com	Arvada	Colorado	3048391821915415	1ddb5a78e7ec26cdb7da7770c741cb00	JCB 16 digit	39.925606136553732	-105.066259283802665
18255	2020-04-03 05:13:29	2020-04-03	Jayvion Dickens V	jayvion.dickens.v@geemail.com	Jacksonville	Florida	4497650181755119	06fb9a5111272516fa3f414796e8250e	JCB 16 digit	30.2844229656789459	-81.5996345085170134
18256	2020-04-03 05:19:41	2020-04-03	Pierce Turner-Schamberger	pierce.turner.schamberger@geemail.com	Saint Paul	Minnesota	180062659911861704	632c39c9a85da1c535c7154d9ee31bb8	American Express	44.8620469727493827	-93.0639112691193873
18257	2020-04-03 05:42:11	2020-04-03	Royce Russel	royce.russel@geemail.com	San Diego	California	4385830659651231	c05e056bf17b2c50c3320034edfd31da	Mastercard	32.7868601783245808	-117.077949510365727
18258	2020-04-03 05:45:59	2020-04-03	Lynwood Dickens	lynwood.dickens@geemail.com	Aurora	Colorado	3088165614872915821	7eec09216a8ad56b25996c5958d8dd14	JCB 16 digit	39.7155733278133027	-104.724566967052226
18259	2020-04-03 05:52:01	2020-04-03	Lavonne Willms DVM	lavonne.willms.dvm@geemail.com	Berkeley	California	180071171065473632	faf34f113b442b50f3f092aee92f2cc8	VISA 16 digit	37.8933164498923247	-122.298897628835505
18260	2020-04-03 05:55:51	2020-04-03	Mr. Teddie Greenholt I	mr.teddie.greenholt.i@geemail.com	Los Angeles	California	3112525577862928325	3d4f60c6f6cb2d65e58385c1400eb3b9	VISA 16 digit	33.948884201315785	-118.379895730315894
18261	2020-04-03 05:58:54	2020-04-03	Maggie Thiel	maggie.thiel@woohoo.com	Sacramento	California	869994199767394676	4d3ae6d606aed935f467a81d4bd07a3a	JCB 15 digit	38.6145270653799173	-121.541658566171677
18262	2020-04-03 06:06:50	2020-04-03	Heaven Koelpin	heaven.koelpin@geemail.com	San Francisco	California	869924478271956385	8dc2e84be220b8a23072f95f04c916de	VISA 16 digit	37.7554131504032711	-122.42716112908883
18263	2020-04-03 06:13:25	2020-04-03	Newton Johns	newton.johns@geemail.com	Long Beach	California	4367945102560532	c553ef82a1d65981e5244e380801bc6c	Diners Club / Carte Blanche	33.7346638756159649	-118.055387987538424
18264	2020-04-03 06:22:07	2020-04-03	Mr. Samie Bartoletti Jr.	mr.samie.bartoletti.jr.@geemail.com	Elizabeth	New Jersey	4527375492784	8713579cc6ad8422c115f865bb340afe	VISA 16 digit	40.6870405998207687	-74.2344622370265483
18265	2020-04-03 06:34:51	2020-04-03	Lena Schuppe	lena.schuppe@geemail.com	Phoenix	Arizona	502056487075014	4a4ea5e3f656ec66a8662d2c33312de6	VISA 13 digit	33.6107249417740874	-112.009317297900481
18266	2020-04-03 06:46:01	2020-04-03	Carlota Marks-Swift	carlota.marks.swift@woohoo.com	Murfreesboro	Tennessee	3717617966550347	3be2c09ca118390ce0697c7369ec143d	Maestro	35.760161413217709	-86.4761387610193282
18267	2020-04-03 07:02:14	2020-04-03	Mr. Mahlon Goyette	mr.mahlon.goyette@geemail.com	Oakland	California	869936110861066087	d6ca49c47762e17d36acbc7e3eb2a985	Voyager	37.8077480310753344	-122.258275431678115
18268	2020-04-03 07:20:05	2020-04-03	Troy Roberts	troy.roberts@geemail.com	Stockton	California	180077676825840155	ff190ea991b9ea71e3c7918a0da789f4	JCB 16 digit	38.0009234905440394	-121.353464010040454
18269	2020-04-03 07:24:21	2020-04-03	Foster Will-Kihn	foster.will.kihn@geemail.com	Los Angeles	California	561249572837265	030fad140f134daeb46a6dad246e422d	JCB 15 digit	34.0198738057032202	-118.35572457993328
18270	2020-04-03 07:43:28	2020-04-03	Dr. Will Dooley V	dr.will.dooley.v@woohoo.com	Los Angeles	California	3497578551552739	868f4ba0e45bf6351996b48e97ff579a	JCB 16 digit	33.981080819280443	-118.355478961858154
18271	2020-04-03 08:06:07	2020-04-03	Beckham McClure	beckham.mcclure@geemail.com	New York	New York	210037655134074234	a7a596ade96c13d7f1c58aed8166f588	Discover	40.6801034414432934	-73.97810170542337
18272	2020-04-03 08:16:03	2020-04-03	Edmon Wiegand	edmon.wiegand@woohoo.com	Rancho Cucamonga	California	6011541577169684084	dfb285a234ef6cfbee4d61dcd8abddc4	Voyager	34.0719120211426159	-117.474947662745421
18273	2020-04-03 08:22:56	2020-04-03	Ronald Towne I	ronald.towne.i@geemail.com	Pittsburgh	Pennsylvania	4210936263007909	987855e837ab39286a5cb6d192995cd1	Mastercard	40.4286345582410647	-80.076047810882713
18274	2020-04-03 08:25:13	2020-04-03	Ms. Helena Rogahn	ms.helena.rogahn@woohoo.com	Lubbock	Texas	4779473658603327	b291b2e78d6b81b370da27d674a298ed	Voyager	33.5889159707859193	-101.97877458179444
18275	2020-04-03 08:29:40	2020-04-03	Kasie Gusikowski DVM	kasie.gusikowski.dvm@geemail.com	North Las Vegas	Nevada	180018006969780482	3b860e125abc7d1bc2ad16cdd5838936	Maestro	36.188092256166783	-115.103245073252921
18276	2020-04-03 08:42:10	2020-04-03	Vernita Ruecker-Bailey	vernita.ruecker.bailey@geemail.com	Irving	Texas	6011487843546891644	5855a00d86a24ac0f55d9b9acb6681cf	Voyager	32.8062305986367164	-97.0395669732987898
18277	2020-04-03 08:43:03	2020-04-03	Rod Bernier	rod.bernier@geemail.com	Virginia Beach	Virginia	4958492330179	3fb6e44e8409e31117f10a7885073646	Maestro	36.6980262212175887	-75.9381316743463231
18278	2020-04-03 08:45:32	2020-04-03	Jonna Cummerata	jonna.cummerata@geemail.com	Topeka	Kansas	3021289391958061	ad03acad35c7164268edef9412ab8cec	Discover	38.9584282987684034	-95.7941648171924101
18279	2020-04-03 08:54:39	2020-04-03	Mrs. Ruthann Kihn DVM	mrs.ruthann.kihn.dvm@woohoo.com	San Francisco	California	060484933405452	5765e0dc0eb5de8cd199cc0fcc08fd88	JCB 16 digit	37.7727947287212729	-122.449703283762801
18280	2020-04-03 08:57:05	2020-04-03	Case Nitzsche	case.nitzsche@geemail.com	Memphis	Tennessee	4274250214800682	9fad17c870d5af08b1a00487e7419cd8	VISA 13 digit	35.0490657144293181	-89.8910743985582172
18281	2020-04-03 09:23:29	2020-04-03	Albin Willms-Borer	albin.willms.borer@geemail.com	Vancouver	Washington	54447425348554627	5060ee6d8fb9d2ee356e10c6229e17ba	JCB 15 digit	45.579040778947622	-122.694185201690345
18282	2020-04-03 09:28:46	2020-04-03	Brandin Anderson	brandin.anderson@geemail.com	Norfolk	Virginia	3766618684119282	40593ae8817649fb2d3bc5787103a5c6	Voyager	36.8524353464152696	-76.2679378702309094
18283	2020-04-03 10:09:28	2020-04-03	Leontine Marvin	leontine.marvin@geemail.com	New York	New York	3096758431850073421	3a11ab1dd889c9f28a42d135c8e62eed	American Express	40.7139733053501658	-73.9698662884429012
18284	2020-04-03 10:27:56	2020-04-03	Mrs. Chloie Kassulke MD	mrs.chloie.kassulke.md@geemail.com	New York	New York	4639992137674	aae18335c0925ae34c864b6d9860c828	American Express	40.7233914582747971	-74.0062157684367179
18285	2020-04-03 10:35:18	2020-04-03	Levar Jones	levar.jones@geemail.com	West Valley City	Utah	3041965825366373	c96c5fefac3dea83c8e371edff668694	Voyager	40.722238232729957	-112.026519970943397
18286	2020-04-03 10:47:40	2020-04-03	Tyson Steuber	tyson.steuber@geemail.com	New York	New York	3031794196904392	e967927b742538a1c36e57240a132c59	Maestro	40.6357334102727492	-74.0047900513175847
18287	2020-04-03 10:49:50	2020-04-03	Marylouise Murphy	marylouise.murphy@geemail.com	Memphis	Tennessee	4933724608598592	941dd4e3c89c26a2e2b6a6908cde6930	VISA 13 digit	35.0745536109034006	-89.9433245557151793
18288	2020-04-03 11:13:11	2020-04-03	Breanne Dietrich PhD	breanne.dietrich.phd@geemail.com	Oakland	California	3439336571512402	03ca638a14e94faa838221ce3502a600	Voyager	37.8204015397441253	-122.277935710262426
18289	2020-04-03 11:26:07	2020-04-03	Layla Kihn	layla.kihn@geemail.com	San Francisco	California	4600006947331378	7107d63bd80d324d354dd3957bf7d78e	American Express	37.7620382481692261	-122.40818367414353
18290	2020-04-03 11:39:03	2020-04-03	Dr. Huey Lesch IV	dr.huey.lesch.iv@geemail.com	Renton	Washington	210078130815427499	8637733cccdbda2d4257bb8c2c4675f7	Mastercard	47.5469332944661431	-122.170981779096635
18291	2020-04-03 11:51:18	2020-04-03	Mrs. Audrina Jaskolski PhD	mrs.audrina.jaskolski.phd@geemail.com	Riverside	California	869996472796807507	ab3c4e3e282c5633a497ca0f32d73e3f	VISA 13 digit	33.9039932002726943	-117.349505028917264
18292	2020-04-03 11:55:05	2020-04-03	Birtie Ward	birtie.ward@geemail.com	Oakland	California	3029447218119430	2730c248b618d5c403f972e1d417cb72	JCB 15 digit	37.819995010675747	-122.237713849624754
18293	2020-04-03 12:06:11	2020-04-03	Memphis Wolff	memphis.wolff@woohoo.com	Jacksonville	Florida	3049305710707674	78bcd8de51abfd3b202a7295ab4ab950	VISA 16 digit	30.3316661397047334	-81.7328670861743518
18294	2020-04-03 12:14:02	2020-04-03	Hector Marquardt	hector.marquardt@geemail.com	San Francisco	California	3493658919078470	26ec0e58cff10b5aae9dfaed5452508d	VISA 16 digit	37.7329162019275444	-122.427526138065048
18295	2020-04-03 12:23:07	2020-04-03	Alfreda Hintz-Huel	alfreda.hintz.huel@geemail.com	Chula Vista	California	55483420849576505	f04b0b4c7e01b5470f04c6132d74f982	Maestro	32.5478984165701988	-117.033560584881144
18296	2020-04-03 12:27:47	2020-04-03	Takisha Douglas-Botsford	takisha.douglas.botsford@woohoo.com	Mobile	Alabama	676236923864213	5fc47d7bd96aa39e713d3fe80be8b995	Diners Club / Carte Blanche	30.6409499503314464	-88.0537406837705561
18297	2020-04-03 12:50:48	2020-04-03	Samara Witting-Dibbert	samara.witting.dibbert@geemail.com	San Diego	California	3769937634744792	63fc52ddfc7cf5ff83503bc95361e4d5	VISA 16 digit	32.8468949735231703	-117.166919462513178
18298	2020-04-03 12:54:01	2020-04-03	Dorthea Reynolds-Kautzer	dorthea.reynolds.kautzer@warmmail.com	Fontana	California	4740869378692381	8b92f08723991686dd49b64edfa91d11	VISA 13 digit	34.1132651538271503	-117.412999176028748
18299	2020-04-03 13:00:33	2020-04-03	Urban Stoltenberg	urban.stoltenberg@warmmail.com	Aurora	Illinois	869992664572142869	b079fdce2d6016be3e5b2a4dd52d171d	Maestro	41.834605879591777	-88.3005634826071457
18300	2020-04-03 13:08:27	2020-04-03	Allyssa Walter	allyssa.walter@geemail.com	Los Angeles	California	4456455784486602	1c05f42c8277777d313d094f62942f7d	VISA 13 digit	33.9479250437445899	-118.409148027374584
18301	2020-04-03 13:12:50	2020-04-03	Helga Swaniawski	helga.swaniawski@geemail.com	Boulder	Colorado	4352570205687	f3e6c94a480ffb3910f168bd2c75884d	VISA 16 digit	39.9593412942234423	-105.303764093681806
18302	2020-04-03 13:23:53	2020-04-03	Harrison Turner	harrison.turner@geemail.com	Houston	Texas	4380514893517524	46615f2ab5c2e6207164a26d9c9ca6a5	JCB 16 digit	29.7665993656575694	-95.4389904984287938
18303	2020-04-03 13:43:47	2020-04-03	Dorothea Predovic MD	dorothea.predovic.md@geemail.com	Des Moines	Iowa	869936101264894324	eaf525815d1d8660f8422e021bd2d86a	JCB 15 digit	41.6584840094879283	-93.5353822456251862
18304	2020-04-03 13:45:00	2020-04-03	Starling Nicolas	starling.nicolas@geemail.com	San Francisco	California	3498333690079395	c1d8abfb2f60f651bc8fce7e26641737	VISA 13 digit	37.7848843739048021	-122.466279871861346
18305	2020-04-03 14:09:17	2020-04-03	Linna Bahringer	linna.bahringer@geemail.com	Corpus Christi	Texas	6011603241254007298	e005a1a5d033f35c598107bfed9f0e08	Discover	27.6929332345195114	-97.2074661908965538
18306	2020-04-03 14:21:08	2020-04-03	Rhett Carroll Jr.	rhett.carroll.jr.@geemail.com	Lakewood	Colorado	4032295442897946	985c93bdf6f0c0c01bf56b82d026453d	Discover	39.6221744305394594	-105.041820102559768
18307	2020-04-03 14:43:01	2020-04-03	Mrs. Beryl Ullrich	mrs.beryl.ullrich@geemail.com	Orlando	Florida	6011669698710657571	c0f5eb5c501d1665c618713c52f88fcd	Maestro	28.3411614679064598	-81.3632660516969821
18308	2020-04-03 14:45:18	2020-04-03	Ms. Adelle Hirthe MD	ms.adelle.hirthe.md@woohoo.com	Everett	Washington	210059550691559995	75695566bfae9f06b2a5981af1074f58	JCB 16 digit	47.8673136084232524	-122.27264090977944
18309	2020-04-03 14:46:07	2020-04-03	Dr. Sarita Rowe	dr.sarita.rowe@warmmail.com	Oakland	California	869914314686258152	3650760ae7a160598c60ce5e2f24be58	VISA 16 digit	37.8073198274942044	-122.284733904174431
18310	2020-04-03 14:47:43	2020-04-03	Mrs. Anie Donnelly	mrs.anie.donnelly@geemail.com	Jacksonville	Florida	4287000362547196	f37bb370411a4bfd7b3a8878c57bcc03	American Express	30.2546306962199516	-81.5964064408637597
18311	2020-04-03 14:50:19	2020-04-03	Manuel Kub	manuel.kub@woohoo.com	Fremont	California	869996456424669363	f8caa504f32baeea1edfc60776431ba5	American Express	37.4746206311210983	-121.852442299620051
18312	2020-04-03 14:56:46	2020-04-03	Amerigo Gibson	amerigo.gibson@woohoo.com	Augusta	Georgia	4195403154901897	5772cfd4bf687c2a6555f5f2ad94c9f0	VISA 16 digit	33.3261813805643428	-82.1312987166751185
18313	2020-04-03 15:03:58	2020-04-03	Rosanne Cassin DDS	rosanne.cassin.dds@warmmail.com	San Francisco	California	3112960311103582127	e90064fd0442fa57901b1101f679131e	VISA 13 digit	37.7822493390651175	-122.43959738004672
18314	2020-04-03 15:04:00	2020-04-03	Stephanie Auer	stephanie.auer@geemail.com	Mesa	Arizona	4720858821963	2bef80e21862f48b69d98950be312bbb	Maestro	33.3359678863227344	-111.675676846539233
18315	2020-04-03 15:04:46	2020-04-03	Mr. Alcide Vandervort II	mr.alcide.vandervort.ii@geemail.com	Cincinnati	Ohio	3466857390382871	e7a47b7ca9ae828ada78cec6f00e10a8	JCB 15 digit	39.2243603870503605	-84.5531965018987535
18316	2020-04-03 15:37:09	2020-04-03	Myron Schowalter-Stamm	myron.schowalter.stamm@warmmail.com	San Francisco	California	6011399864251107593	5355c8e98a50483e5a2cd98d5355709b	Voyager	37.839182268146935	-122.418638385401806
18317	2020-04-03 15:43:01	2020-04-03	Deanna Hegmann	deanna.hegmann@geemail.com	San Diego	California	55017527745925357	0407479eee8f33fae2ed47ae22128904	Voyager	32.911553627026457	-117.09829540871084
18318	2020-04-03 15:51:00	2020-04-03	Mary White	mary.white@geemail.com	Carrollton	Texas	3055594073861202	6b875d2aeca09c2e4ae34aa5ef014873	VISA 16 digit	33.0770004209052786	-96.98226766636148
18319	2020-04-03 16:03:15	2020-04-03	Kylie Borer	kylie.borer@geemail.com	Lancaster	California	4073286946932669	391a20c2c2f0ebf661854b164692a5cc	VISA 16 digit	34.7518758987322514	-118.101224120843398
18320	2020-04-03 16:05:55	2020-04-03	Johnathon Stanton	johnathon.stanton@geemail.com	Berkeley	California	630434181166686	09506f61917fe918cc009121fe2037b3	Voyager	37.8480223615761489	-122.241673289961795
18321	2020-04-03 16:14:00	2020-04-03	Montgomery Stark	montgomery.stark@warmmail.com	Greensboro	North Carolina	4800009241035578	f5845488414ea79fad207b02c3690178	American Express	36.150055174308271	-79.8413091903999401
18322	2020-04-03 16:43:50	2020-04-03	Obie Hegmann	obie.hegmann@geemail.com	Killeen	Texas	502025434250806	b983f99cfbe650cae79f2bfd9c8fac8b	JCB 16 digit	31.0577340493675322	-97.7237903908062719
18323	2020-04-03 17:28:52	2020-04-03	Miss Elmira Hirthe MD	miss.elmira.hirthe.md@geemail.com	Fort Worth	Texas	4601991895116	95540a9118d951ac823722bb97dede2c	JCB 15 digit	32.8504105927478562	-97.3998123072840229
18324	2020-04-03 17:47:18	2020-04-03	Dr. Montrell Paucek	dr.montrell.paucek@geemail.com	Philadelphia	Pennsylvania	6011808589730417561	8042c9655268f69067f061a245adbbb7	Discover	39.9945190068759047	-75.1093677595157203
18325	2020-04-03 17:59:47	2020-04-03	Venita Boehm	venita.boehm@geemail.com	Cincinnati	Ohio	675930189502682	28e5ed29a3c75fc7002e3ad5a06c3172	VISA 16 digit	39.1130445716667907	-84.4216423208631568
18326	2020-04-03 18:22:33	2020-04-03	Jameel McCullough	jameel.mccullough@warmmail.com	Detroit	Michigan	3337468658839216561	6803120184decd89e1350b8d4ee235ff	JCB 15 digit	42.4138464908506734	-83.1771151275493139
18327	2020-04-03 18:55:37	2020-04-03	Mr. Elwood Fadel	mr.elwood.fadel@geemail.com	Philadelphia	Pennsylvania	180029397475806516	851d3063f90d15b4a9afbf70c878ebcd	Discover	40.0184564619749779	-75.1267007029049125
18328	2020-04-03 19:11:12	2020-04-03	Greg Fay Jr.	greg.fay.jr.@geemail.com	San Francisco	California	180081878520437840	2e0176fdd737cd057f6677b2ee01dec5	American Express	37.7341436914852295	-122.435756335536809
18329	2020-04-03 19:11:22	2020-04-03	Chadd Rau III	chadd.rau.iii@geemail.com	New York	New York	3036096972056669	8a4f7032cb2de48ecb75e025f398569d	VISA 13 digit	40.6184446015153071	-73.9685986007459491
18330	2020-04-03 19:19:30	2020-04-03	Prince Cartwright	prince.cartwright@geemail.com	Houston	Texas	3088613386909944508	ec328137ad0c01e83e9f822e0aaed012	VISA 16 digit	29.6989529582284391	-95.364229866677519
18331	2020-04-03 19:20:56	2020-04-03	Marylou Dickens	marylou.dickens@warmmail.com	San Francisco	California	4344072564257883	d8e06e80134180367bea2cd81dc1ee09	Mastercard	37.7822315706447114	-122.447676761367816
18332	2020-04-03 19:29:09	2020-04-03	Mordechai Walker	mordechai.walker@warmmail.com	Rialto	California	54704248525201715	0ee27b6352d94bfc37be41e7a6789e1e	JCB 16 digit	34.1708462455526032	-117.352306024971611
18333	2020-04-03 19:30:14	2020-04-03	Ron Torp-Monahan	ron.torp.monahan@woohoo.com	Philadelphia	Pennsylvania	3056207328282137	c8b901f09ba238415cfb2f6f594cd2fb	VISA 13 digit	40.0522303772583612	-75.0975709007486785
18334	2020-04-03 20:04:55	2020-04-03	Donato Blanda	donato.blanda@geemail.com	Philadelphia	Pennsylvania	3158340390809887239	1ed4089220f259ca9301bc2dfaed39b2	JCB 15 digit	39.961588461460174	-75.1685392000611898
18335	2020-04-03 20:25:23	2020-04-03	Terese Klocko	terese.klocko@geemail.com	Aurora	Colorado	3158063822660065690	82b93b8c0897bbb07c625ed33aaff1f0	JCB 16 digit	39.7330224061962269	-104.75706186300404
18336	2020-04-03 20:25:36	2020-04-03	Salvatore Kiehn IV	salvatore.kiehn.iv@geemail.com	San Francisco	California	210005605982847106	e28f6fb1ee53b0375efd156530ebfb9a	VISA 16 digit	37.7991010728081918	-122.401822088422364
18337	2020-04-03 20:30:03	2020-04-03	Len Orn	len.orn@geemail.com	San Antonio	Texas	53156838552396322	9248aecb9c1eff6ee629cbfb7ae2d009	Voyager	29.4121681367117915	-98.5904367645107129
18338	2020-04-03 20:44:12	2020-04-03	Mell Monahan	mell.monahan@geemail.com	St. Louis	Missouri	4655793613436441	51da772ad79023f27f92d0ca16a099b9	Maestro	38.6342400182660697	-90.3255232930187191
18339	2020-04-03 20:48:01	2020-04-03	Treasure Romaguera-Orn	treasure.romaguera.orn@geemail.com	Irvine	California	4620851362150357	d457a946b68ebf4fa7eafc52c604596f	JCB 16 digit	33.6671170062400407	-117.676821656293413
18340	2020-04-03 20:53:15	2020-04-03	Hakeem Gleason	hakeem.gleason@geemail.com	Mesa	Arizona	869941591053453410	f8def7b9a9565c30fa8ae31d94f6b271	JCB 16 digit	33.4807946460466823	-111.718896244780723
18341	2020-04-03 20:58:07	2020-04-03	Jahiem Kozey	jahiem.kozey@warmmail.com	South Bend	Indiana	4905421835300538	f632c80e060479fb7bbfe69d314cb8b5	JCB 16 digit	41.7321504490595316	-86.231142430758112
18342	2020-04-03 21:10:01	2020-04-03	Marcello Feil	marcello.feil@geemail.com	Philadelphia	Pennsylvania	6011486729526192536	57a14aeeff1584b1e5a70083e84aa776	VISA 16 digit	39.9988697443582097	-75.2232893465452008
18343	2020-04-03 21:26:17	2020-04-03	Lela Gutmann	lela.gutmann@geemail.com	Madison	Wisconsin	3778137730200703	c25f82c59ee65326ce69182628673310	American Express	43.0326323168791873	-89.4027603629861005
18344	2020-04-03 21:41:10	2020-04-03	Herman Lehner-Heaney	herman.lehner.heaney@geemail.com	San Francisco	California	4904857995784	d04d8d60a105693ce038b4760b6155b4	VISA 16 digit	37.7872581394964939	-122.432184562085396
18345	2020-04-03 22:27:58	2020-04-03	Boston Lindgren DDS	boston.lindgren.dds@geemail.com	New York	New York	4004147623526	e16f5feab86ce7a1b71f85402278ced1	JCB 16 digit	40.5809263187218434	-73.9030540482036713
18346	2020-04-03 22:33:38	2020-04-03	Demetra Treutel	demetra.treutel@geemail.com	San Antonio	Texas	675911741142761	9b3123d11a963e6b7e052659be3511c0	Voyager	29.5384584688186642	-98.46806548338607
18347	2020-04-03 22:35:53	2020-04-03	Esther Fadel	esther.fadel@warmmail.com	San Francisco	California	4314406349107656	6031a0192d7946f9eb91b4904bfe9964	JCB 16 digit	37.7645371951192601	-122.420599855532842
18348	2020-04-03 22:37:14	2020-04-03	Margy Emard-Nienow	margy.emard.nienow@warmmail.com	San Francisco	California	3030795130367902	c38ad1fbe5554612dcfc39fed1a09d8e	Maestro	37.7663020583915596	-122.43645347842444
18349	2020-04-03 22:49:24	2020-04-03	Ivy Lebsack-Howell	ivy.lebsack.howell@geemail.com	San Francisco	California	4692471944105622	d70b46d989b37dfa33f1241053ebf72b	VISA 16 digit	37.7637159480283131	-122.432342022977693
18350	2020-04-03 22:51:59	2020-04-03	Burt Monahan	burt.monahan@woohoo.com	Kansas City	Missouri	3528092750079743836	30c8ef39f57298949ae37bcd23e8063c	JCB 16 digit	39.1165422330446546	-94.5606188864204995
18351	2020-04-03 22:57:58	2020-04-03	Dameon Mitchell	dameon.mitchell@geemail.com	Burbank	California	3088042684244597564	50dd0e6e795c593883f301aa2e9717fc	Discover	34.1092423033364156	-118.250793881764267
18352	2020-04-03 23:13:52	2020-04-03	Hank Nikolaus-Hand	hank.nikolaus.hand@geemail.com	Chicago	Illinois	3769621002213024	6601a3bcf95b911ee1755a73146084f9	JCB 16 digit	41.8830798901919295	-87.7612708093628271
18353	2020-04-03 23:20:47	2020-04-03	Mrs. Emery Eichmann PhD	mrs.emery.eichmann.phd@geemail.com	San Francisco	California	4134770694365385	60086e471decc223e300c58d1c28bf09	American Express	37.7666976130366194	-122.417207608772557
18354	2020-04-03 23:21:02	2020-04-03	Less Hand	less.hand@woohoo.com	Jackson	Mississippi	3019077887669371	f6072c845feda853f20725b45dbcd3d5	Mastercard	32.3791886559400766	-90.121722476228328
18355	2020-04-03 23:29:45	2020-04-03	Amari Jakubowski	amari.jakubowski@geemail.com	Detroit	Michigan	55903817570215652	99a112e5d884b42e13dba36a41c5f46f	Discover	42.4552364514134837	-83.1875600786067508
18356	2020-04-03 23:30:30	2020-04-03	Mr. Pierre Kertzmann	mr.pierre.kertzmann@woohoo.com	Hartford	Connecticut	51791848494936532	b88d86e0548c791a0660284aeba2e96e	VISA 13 digit	41.7307296805564363	-72.5894642360400439
18357	2020-04-03 23:43:21	2020-04-03	Mrs. Margaretta Barton	mrs.margaretta.barton@geemail.com	Rialto	California	6011715639930107769	c0bc4a2bcea2d0187999a454c8c2abc4	JCB 15 digit	34.07384568552785	-117.390881878704946
18358	2020-04-03 23:46:35	2020-04-03	Jens Schoen-Windler	jens.schoen.windler@geemail.com	San Diego	California	52829068684927045	2cc1df23e517e536e7828acda68a65df	VISA 16 digit	32.7737081534296308	-117.064718551598489
18359	2020-04-03 23:49:28	2020-04-03	Mr. Randolf Dicki Jr.	mr.randolf.dicki.jr.@geemail.com	Chicago	Illinois	3112427663362986614	d3bcf103db71fd01950b9d7b77902a94	JCB 15 digit	41.8602803119294364	-87.6918465698167608
18360	2020-04-03 23:53:41	2020-04-03	Buster Brown	buster.brown@geemail.com	Green Bay	Wisconsin	52845438029974954	610f08bc7fbb09d93f1db5a7ec48d2f5	Discover	44.6055539897706339	-88.0035278010469
18361	2020-04-04 00:14:33	2020-04-04	Sheilah Yundt	sheilah.yundt@woohoo.com	Anaheim	California	4748573712308	53da1f70fde51b6033250bdf53c546cc	JCB 16 digit	33.8128698767460847	-117.780281191014126
18362	2020-04-04 00:19:36	2020-04-04	Wilbert Gusikowski-Ebert	wilbert.gusikowski.ebert@geemail.com	Berkeley	California	4156196571177904	9407acb3481fa8fb96f987611503e84d	Discover	37.883719414202524	-122.250581878550094
18363	2020-04-04 00:19:37	2020-04-04	Alston Leffler	alston.leffler@geemail.com	Berkeley	California	060453742133811	07c39b25135cec28eff230a1e053e9cc	Maestro	37.8967778352552429	-122.264655432421733
18364	2020-04-04 00:30:38	2020-04-04	Darian Brown	darian.brown@geemail.com	Laredo	Texas	4595607812260902	14cfe93c83b273b07fdda56bd9453ce6	JCB 16 digit	27.6315550881620524	-99.5686229736085977
18365	2020-04-04 00:33:33	2020-04-04	Elenore Schneider MD	elenore.schneider.md@woohoo.com	Baton Rouge	Louisiana	53706853530876266	ce0da95f3bf5868e059f2abb5d400ce9	Mastercard	30.4394734241746363	-91.0496629607040404
18366	2020-04-04 00:39:57	2020-04-04	Miss Roseanna Miller DDS	miss.roseanna.miller.dds@woohoo.com	Houston	Texas	639067023614083	7eafacfbc965e3735707f9a2e8c30a57	JCB 16 digit	29.7041095073413111	-95.4249938859619249
18367	2020-04-04 00:53:29	2020-04-04	Diandra Harvey	diandra.harvey@geemail.com	Las Vegas	Nevada	3528118881480531963	b39cbb631fef8788bbbf347df52a35b9	American Express	36.2246384215176107	-115.273143876038858
18368	2020-04-04 01:19:19	2020-04-04	Miss Tenisha Yost PhD	miss.tenisha.yost.phd@woohoo.com	San Jose	California	3088852934134574200	a78b7c7b3e65dbddb3e9def70992e95b	JCB 16 digit	37.292663591616602	-121.864125780177858
18369	2020-04-04 01:19:30	2020-04-04	Colter Hauck	colter.hauck@geemail.com	San Francisco	California	630423336888906	3cb36cfa7adfe271fd60d929dd63abf8	VISA 13 digit	37.7331799454565839	-122.382335939709009
18370	2020-04-04 01:28:28	2020-04-04	Mariah Jaskolski	mariah.jaskolski@geemail.com	Greensboro	North Carolina	4137489782110	e418e8d63a27092ddced785b8936d07c	JCB 15 digit	36.1590464233536295	-79.7631294122412839
18371	2020-04-04 01:29:16	2020-04-04	Jahir Kunze	jahir.kunze@geemail.com	San Antonio	Texas	4504614403020612	d0d503559a4f3044cf7d51078d7d6cab	Discover	29.5266325166519721	-98.6114312302622835
18372	2020-04-04 01:30:43	2020-04-04	Giselle Nolan	giselle.nolan@geemail.com	Scottsdale	Arizona	54768608310459336	c61dcb6a7e68f98f623662b47f5b8b4e	Diners Club / Carte Blanche	33.635523345519978	-111.921317417497178
18373	2020-04-04 02:20:07	2020-04-04	Liz Hegmann	liz.hegmann@geemail.com	Austin	Texas	3112915459345425351	5092b9d616696352ad5cb23fe1b6cf64	JCB 16 digit	30.3478025766216213	-97.84113347965814
18374	2020-04-04 02:34:11	2020-04-04	Kiefer Cronin IV	kiefer.cronin.iv@woohoo.com	Berkeley	California	55431866689818063	ccc6197a96d745bb02724e478e20eeb6	JCB 16 digit	37.8819027408379014	-122.250061590361838
18375	2020-04-04 02:37:47	2020-04-04	Sannie O'Kon	sannie.o'kon@geemail.com	Jacksonville	Florida	3722443250285323	bc19348b211b7b5a8f2960414a06b007	American Express	30.4141281725425259	-81.7579710353709856
18376	2020-04-04 03:39:29	2020-04-04	Abril Swift	abril.swift@woohoo.com	Midland	Texas	4924302309647	d1326d25ede4b785fd58f91db79fb7c1	JCB 16 digit	31.9454593786694119	-102.077595846610151
18377	2020-04-04 03:41:50	2020-04-04	Mr. Tod Wintheiser I	mr.tod.wintheiser.i@geemail.com	San Francisco	California	4244381965416787	0d9e7561a6b32e31c5b04bed27fe6a95	JCB 15 digit	37.7942702425384027	-122.4143634935036
18378	2020-04-04 03:43:35	2020-04-04	Ms. Shelbi Crooks DVM	ms.shelbi.crooks.dvm@geemail.com	Oakland	California	4931872022052191	25879c5613c5025ab13d3b296fdea57e	Maestro	37.7911376959696952	-122.272030537492512
18379	2020-04-04 03:47:20	2020-04-04	Ms. Marvel Prohaska DVM	ms.marvel.prohaska.dvm@warmmail.com	Frisco	Texas	3528884814742369031	f79dd24c5eb81223b263ce09bbd6da0e	VISA 13 digit	33.0716668998353214	-96.8930794878605752
18380	2020-04-04 03:54:13	2020-04-04	Kennard McKenzie	kennard.mckenzie@geemail.com	Chesapeake	Virginia	3755277539704476	c5922731f21d7189b31da171115ebe80	Diners Club / Carte Blanche	36.5967630274366584	-76.2338859740953865
18381	2020-04-04 04:03:31	2020-04-04	Mrs. Serena O'Keefe	mrs.serena.o'keefe@warmmail.com	New York	New York	869968429475499893	eff99ea9e2c81e6405798383794bddb9	Maestro	40.6472821805849662	-74.0271641666430895
18382	2020-04-04 04:29:26	2020-04-04	Jody Witting	jody.witting@geemail.com	El Monte	California	3422408288320426	2c64840b6754b6b86cbb2c0335106213	VISA 16 digit	33.9759212968129631	-117.950213002765921
18383	2020-04-04 04:29:26	2020-04-04	Cullen Little	cullen.little@geemail.com	Anaheim	California	53187557763949736	bbfb145b1ab4b9246cad067de63108cf	Discover	33.7838566989004576	-117.777800508236879
18384	2020-04-04 04:39:32	2020-04-04	Dr. Catalina Mante	dr.catalina.mante@woohoo.com	Oakland	California	210097145021787913	c92a8d50f6b0e10e3a1e7b5c101c2483	Mastercard	37.8115084391064755	-122.298532123530876
18385	2020-04-04 04:41:35	2020-04-04	Efren Hartmann	efren.hartmann@geemail.com	Baton Rouge	Louisiana	3112676647840011002	f2a9878134b052ecbbf6d1e7e427ab3b	VISA 16 digit	30.3427753972567622	-91.2264861336551576
18386	2020-04-04 04:54:05	2020-04-04	Coty Langosh	coty.langosh@geemail.com	Bellevue	Washington	210059369667746357	ee7b95b80ae67cad5649d94b9cca1fb3	VISA 16 digit	47.6936243821118069	-122.107594123814252
18387	2020-04-04 05:23:32	2020-04-04	Luda Douglas	luda.douglas@geemail.com	San Francisco	California	3158308959818001253	c211d8c2e68236c61d0d2e39b8126e90	Diners Club / Carte Blanche	37.7683400692364302	-122.415876389227108
18388	2020-04-04 05:26:50	2020-04-04	Lucien Mueller II	lucien.mueller.ii@geemail.com	Rochester	New York	676250885586086	0be7fd50dd087de89893141a71cdbbf4	Maestro	43.1035684694047987	-77.6666968952171572
18389	2020-04-04 05:36:08	2020-04-04	Santiago Abbott	santiago.abbott@geemail.com	Washington	District of Columbia	4748997963691492	52dd1e0cbafe1f72e683b44594fc2334	VISA 13 digit	38.9500192881826308	-77.0167834476780229
18390	2020-04-04 05:44:23	2020-04-04	Valentine Waelchi	valentine.waelchi@geemail.com	Richmond	Virginia	4730653704652	ac8619461d1b71bead262383aa4a80b9	Mastercard	37.5147392541855567	-77.461137043055146
18391	2020-04-04 06:21:54	2020-04-04	Teddie Cartwright	teddie.cartwright@woohoo.com	Winston–Salem	North Carolina	4287842578977430	0d820bfc527f088750cff7a7eaf2219e	JCB 15 digit	36.0074718447167399	-80.2652147223371912
18392	2020-04-04 06:25:58	2020-04-04	Dondre Rohan	dondre.rohan@geemail.com	San Francisco	California	869905477533218751	6faa18a0647f811cf666357797d24a67	Discover	37.7438701177982381	-122.422421172328214
18393	2020-04-04 06:36:52	2020-04-04	Josefina DuBuque	josefina.dubuque@woohoo.com	Berkeley	California	4264699877548412	6dc0eb25f0e39868f2736a36ffd89ce3	Discover	37.8959684259454193	-122.276680210606045
18394	2020-04-04 06:39:13	2020-04-04	Theodis Berge	theodis.berge@geemail.com	San Francisco	California	3112170166057457601	f4e89e940306431a646d510dc731cbc5	Voyager	37.7629962206757952	-122.442278412613973
18395	2020-04-04 06:44:40	2020-04-04	Mr. Patric Mueller	mr.patric.mueller@geemail.com	Rochester	New York	4902736709089278	6477f473028ee93a50045661b82c5720	VISA 16 digit	43.0852017304372055	-77.655976594775538
18396	2020-04-04 06:47:12	2020-04-04	Ms. Denisha Okuneva PhD	ms.denisha.okuneva.phd@geemail.com	Oakland	California	3088946701459163309	b98ef1d8cc4956fe0e06d3763a0764bb	Maestro	37.794318531980835	-122.293310290484683
18397	2020-04-04 06:49:44	2020-04-04	Caroline Morar	caroline.morar@geemail.com	Cleveland	Ohio	3112497987196282170	e8072de930434b8631ae2f97c537f826	Voyager	41.3900257910452751	-81.7607313801307214
18398	2020-04-04 06:49:55	2020-04-04	Mr. Shannon Lakin DDS	mr.shannon.lakin.dds@geemail.com	New York	New York	3023228269191924	bf8afcef6eb0dd76a306ae7ff89feec1	VISA 16 digit	40.6140107369739525	-73.9605618696089806
18399	2020-04-04 06:52:44	2020-04-04	Halsey Koepp	halsey.koepp@woohoo.com	Oakland	California	3096872081646170782	f3cbfe46747b244cef714663d5cf04b5	Diners Club / Carte Blanche	37.7922851428745759	-122.263913336920851
18400	2020-04-04 06:55:04	2020-04-04	Damarcus Goldner	damarcus.goldner@geemail.com	St. Louis	Missouri	210026759546688905	a356ea1128438d50482541133b23a1c9	JCB 16 digit	38.5868836800258634	-90.2247280224695913
18401	2020-04-04 07:23:35	2020-04-04	Dr. Stanton Cummerata	dr.stanton.cummerata@geemail.com	New York	New York	869940890287339853	0570da320bfde916a14aa2b87b23ac75	JCB 16 digit	40.5871733572557574	-73.9481419038854568
18402	2020-04-04 07:30:15	2020-04-04	Mr. Benedict Waelchi V	mr.benedict.waelchi.v@warmmail.com	Baton Rouge	Louisiana	3096823202047096661	ac4d01a615ebf0b0f7897c399e74ab69	Maestro	30.522643795723841	-91.1058594451859562
18403	2020-04-04 07:31:04	2020-04-04	Claiborne Lang	claiborne.lang@warmmail.com	Stamford	Connecticut	3337790927325705117	e885908910b9b696dcbad8e2fcc40563	Voyager	41.041681753739347	-73.4856681710612065
18404	2020-04-04 07:31:49	2020-04-04	Milo Jenkins	milo.jenkins@geemail.com	Grand Prairie	Texas	4165607595493118	dbb2f2d9f503b0c333b1406484822d6b	Mastercard	32.7185909659188283	-97.0530233821239392
18405	2020-04-04 07:32:19	2020-04-04	Collier Mertz	collier.mertz@geemail.com	San Francisco	California	3158577168835607910	4a4698b3ba24a0aceff4379d707772f3	Diners Club / Carte Blanche	37.7729965126520781	-122.419483060106899
18406	2020-04-04 07:42:04	2020-04-04	Mr. Erin Kohler PhD	mr.erin.kohler.phd@geemail.com	Seattle	Washington	4316422409586372	a409d55a091ad68e5b174a2b6bf738dd	JCB 16 digit	47.5360120155774055	-122.449462966147436
18407	2020-04-04 07:56:59	2020-04-04	Mr. Reino Nienow	mr.reino.nienow@geemail.com	Warren	Michigan	4869418342417486	d35148e2da4b9453bbd1f56217ddc309	VISA 13 digit	42.4880080319471674	-82.9615145732648784
18408	2020-04-04 07:58:00	2020-04-04	Amerigo Cremin	amerigo.cremin@geemail.com	Winston–Salem	North Carolina	3337894130418453340	e491c4624a12b439163f8b785934b8db	Voyager	36.1534234176620828	-80.3202040376272066
18409	2020-04-04 08:37:16	2020-04-04	Denisse Grimes	denisse.grimes@warmmail.com	San Francisco	California	3088484032965762188	714cd9030583e89e26024b1beafffc29	JCB 16 digit	37.7326919623806276	-122.414527090560739
18410	2020-04-04 08:42:44	2020-04-04	Gaston Howell	gaston.howell@geemail.com	Topeka	Kansas	54607011273560643	3856c753f127fa2ed5a79c755812dc43	Maestro	38.9929110318355256	-95.7837913260504621
18411	2020-04-04 08:51:58	2020-04-04	Sol Schaefer	sol.schaefer@geemail.com	Columbus	Georgia	4917691300227	1282d0996c3488db1573823b8b569783	JCB 16 digit	32.5956616864118729	-84.8259099257342513
18412	2020-04-04 09:03:51	2020-04-04	Rachel Doyle	rachel.doyle@geemail.com	Houston	Texas	4104697042509669	aa11f26cdd5cf3d234e6e19d84d4c9ee	Discover	29.8478936085090041	-95.386334407098218
18413	2020-04-04 09:17:58	2020-04-04	Kennth Ledner	kennth.ledner@woohoo.com	Wichita Falls	Texas	180015682993359288	90a69fc6a4a7f77537ca08c094ba2974	Diners Club / Carte Blanche	33.8993609248854213	-98.5544139325074724
18414	2020-04-04 09:24:45	2020-04-04	Chance Welch	chance.welch@geemail.com	Daly City	California	3003255815836587	886559dfcde170a0d7a0669acac6d054	Diners Club / Carte Blanche	37.6052021585326628	-122.414176570819691
18415	2020-04-04 09:42:28	2020-04-04	Draven Reinger-Fahey	draven.reinger.fahey@geemail.com	San Francisco	California	3058207981772109	b3a3d7a06b2d22fc32e12f8efd22ae0c	Voyager	37.7769280101005478	-122.431876851999277
18416	2020-04-04 10:10:19	2020-04-04	Jovany Considine	jovany.considine@woohoo.com	New York	New York	3007279986460783	1b5c21f65766e7cb9ea02643f87f5a66	VISA 16 digit	40.7466132253166293	-74.0131628583546757
18417	2020-04-04 10:18:59	2020-04-04	Bryn Pagac	bryn.pagac@geemail.com	Kansas City	Missouri	210012274153683484	ff9956097fad13fd0e14313d2226ee3c	JCB 16 digit	39.1402718930341322	-94.5153837388139237
18418	2020-04-04 10:22:16	2020-04-04	Normand Gulgowski DVM	normand.gulgowski.dvm@woohoo.com	Aurora	Illinois	869909549282299673	bd61926ca9ef929b86fe8481df62199f	JCB 15 digit	41.8108688056226825	-88.2141836701821518
18419	2020-04-04 10:47:02	2020-04-04	Bryon Reynolds	bryon.reynolds@woohoo.com	San Diego	California	210057757522283750	7b409808ce9d25538d3d8f1e50ac62f2	VISA 16 digit	32.8414567260604358	-117.119123576991271
18420	2020-04-04 10:54:42	2020-04-04	Lucille Bayer	lucille.bayer@woohoo.com	Orange	California	3337428126221410365	80aa3a15ef6162cbee7229b67be76e7f	JCB 15 digit	33.8623467455972005	-117.844783073813844
18421	2020-04-04 11:34:36	2020-04-04	Damarion Feil-Hagenes	damarion.feil.hagenes@geemail.com	New Orleans	Louisiana	869906959839986164	17ce50cbe0565de5b8d326d2b30363c7	Diners Club / Carte Blanche	30.0616494590897112	-89.9275987716652452
18422	2020-04-04 12:07:04	2020-04-04	Dr. Henderson Wuckert IV	dr.henderson.wuckert.iv@geemail.com	San Francisco	California	3528755502901814048	69c90e8c8ea5c23597995932a0074eff	VISA 16 digit	37.7923044649324567	-122.410651195554578
18423	2020-04-04 12:11:24	2020-04-04	Kyra Kuphal-Gislason	kyra.kuphal.gislason@geemail.com	Anchorage	Alaska	3088917128621884460	8a3a75578d35122cdc03ad47c1e41cea	Maestro	61.2251922096807562	-149.251870783849796
18424	2020-04-04 12:30:33	2020-04-04	Norman Kilback	norman.kilback@woohoo.com	San Francisco	California	3528070108360396549	f90f0b98d4bb4e8272c07fc3fffe0e69	VISA 16 digit	37.7721017076184395	-122.437285321743403
18425	2020-04-04 12:39:52	2020-04-04	Thalia Hane-Reilly	thalia.hane.reilly@geemail.com	San Francisco	California	51766056460296458	7196985ecff2c32e488ffb0804353431	American Express	37.7662383540597162	-122.426320197011549
18426	2020-04-04 12:50:15	2020-04-04	Jade Kulas-Kohler	jade.kulas.kohler@warmmail.com	San Francisco	California	4928578791802881	4db99b86beddce9e268731523dde6e0b	Mastercard	37.7879015824532232	-122.427220484711739
18427	2020-04-04 12:51:19	2020-04-04	Arnold Ledner	arnold.ledner@geemail.com	Hartford	Connecticut	4791001520259269	98648b2e3bf9951264c4471b9cdfcaf5	VISA 16 digit	41.7048297210145762	-72.6597679766718301
18428	2020-04-04 12:59:04	2020-04-04	Uriel Pouros	uriel.pouros@geemail.com	Oakland	California	210034550423580897	3367eb047552bc405e85fb840b6d2910	Maestro	37.8031767777826602	-122.241670069910043
18429	2020-04-04 13:04:46	2020-04-04	Ephraim Skiles	ephraim.skiles@warmmail.com	New York	New York	52410051705719976	3d32e50f100c55492459c94cabf4af0d	Mastercard	40.6484643704947075	-73.8969583428360437
18430	2020-04-04 13:06:07	2020-04-04	Makayla Rodriguez	makayla.rodriguez@geemail.com	Oakland	California	3700361578799047	1660aae3a09eac7f903cbdccfd4390b0	American Express	37.7650655653888236	-122.300791142247732
18431	2020-04-04 13:09:33	2020-04-04	Kane Moen	kane.moen@geemail.com	Louisville	Kentucky	4413154822337990	d151d26c40dbdcfc270cd515dfe7ae70	VISA 13 digit	38.123851370475812	-85.6192606861773982
18432	2020-04-04 13:14:22	2020-04-04	Garfield Murphy-Zemlak	garfield.murphy.zemlak@geemail.com	New York	New York	630439072462300	2ea7d24eaf178461b25119350df89913	VISA 16 digit	40.5873478824030585	-73.9741060541838351
18433	2020-04-04 13:15:54	2020-04-04	Charla Wisoky	charla.wisoky@geemail.com	Phoenix	Arizona	6011921917547379579	cd2d64a78cbabb8d45e978a616755f9e	VISA 13 digit	33.633691047451272	-112.18525104284511
18434	2020-04-04 13:33:58	2020-04-04	Jacob Mueller-Miller	jacob.mueller.miller@geemail.com	Berkeley	California	210023093090621937	98521d06219d95b551c45f97f3134678	VISA 16 digit	37.86954322062887	-122.29804069339572
18435	2020-04-04 13:35:28	2020-04-04	Jettie Schuster	jettie.schuster@geemail.com	Montgomery	Alabama	4828936731608654	6fce77f73b5ef1d8751763e54781e2f0	Mastercard	32.3267327746309334	-86.1798796517461483
18436	2020-04-04 13:42:16	2020-04-04	Vicky Rippin DVM	vicky.rippin.dvm@geemail.com	New York	New York	3112921935345598299	1c29e147d142ebb09392180f2ffb17f4	Diners Club / Carte Blanche	40.5702748714704029	-73.8635008359223519
18437	2020-04-04 13:46:41	2020-04-04	Annemarie Beatty	annemarie.beatty@geemail.com	New York	New York	4722392933132720	dd0232210f34dfaa21b3f6571d701901	Mastercard	40.6749333271980262	-73.8837779503677012
18438	2020-04-04 13:54:00	2020-04-04	Elvin Stiedemann DDS	elvin.stiedemann.dds@geemail.com	Torrance	California	53677274056609582	7ad84ebfb20271df7e88996e335d8211	Maestro	33.7351931654289388	-118.406709464884912
18439	2020-04-04 13:56:49	2020-04-04	Mrs. Vassie Larson MD	mrs.vassie.larson.md@woohoo.com	Lafayette	Louisiana	4545716529678297	b426fac775d8c71dc9b7d775abec2d3b	Diners Club / Carte Blanche	30.1610040124483412	-92.0843267420623448
18440	2020-04-04 14:20:28	2020-04-04	Otha Romaguera	otha.romaguera@geemail.com	New York	New York	3096374659114196471	705af23acadb9d18feccac676a48ec97	Discover	40.7510341198872794	-73.928654218640915
18441	2020-04-04 14:21:02	2020-04-04	Cathryn Harvey	cathryn.harvey@warmmail.com	San Francisco	California	4423487823033988	34259fede61611375135cea2ce0fc9e1	American Express	37.7551848458876904	-122.416528989018985
18442	2020-04-04 14:22:12	2020-04-04	Cecile Borer-Cronin	cecile.borer.cronin@geemail.com	New York	New York	4301489231715658	36990c77d956dd95fc7f5b1ee9892a63	VISA 13 digit	40.6375885684732339	-73.9824527161557199
18443	2020-04-04 14:26:05	2020-04-04	Bradyn Sawayn-Mosciski	bradyn.sawayn.mosciski@geemail.com	Ann Arbor	Michigan	4036059004923	7b14d74dcb14346b8e9b9fa00134e9ed	VISA 16 digit	42.2096438002366554	-83.6467089223317828
18444	2020-04-04 14:27:54	2020-04-04	Garner Aufderhar	garner.aufderhar@warmmail.com	Houston	Texas	210013908887914983	626b38e98d6d6b4ce6af3e225e434c56	VISA 13 digit	29.7139945694789276	-95.3125348248533868
18445	2020-04-04 14:43:01	2020-04-04	Caylee Luettgen-Braun	caylee.luettgen.braun@geemail.com	San Francisco	California	55770428272660714	3ab190dad373a8925aeaf2566c8e102d	VISA 16 digit	37.7614502370452669	-122.459181542019692
18446	2020-04-04 14:52:24	2020-04-04	Leonia Quigley	leonia.quigley@geemail.com	New Orleans	Louisiana	869933129777185982	06609c363fc1d3d903d9ac325b2e5340	JCB 16 digit	29.9554245684776461	-89.8442337576560703
18447	2020-04-04 14:52:30	2020-04-04	Maribeth Hoeger	maribeth.hoeger@geemail.com	Waco	Texas	3494840480284328	1af864e76c31296fba01df422b980bb1	VISA 13 digit	31.5644069997802355	-97.2819262961987477
18448	2020-04-04 15:08:11	2020-04-04	Ali Wiegand	ali.wiegand@warmmail.com	Huntington Beach	California	4502816107135	5520fd5df024f2c897f9b503742118d5	VISA 16 digit	33.6252226954832736	-118.085955351836233
18449	2020-04-04 15:12:18	2020-04-04	Mose Bins	mose.bins@geemail.com	Oklahoma City	Oklahoma	210018976717748678	84d8abfc842be5f088b22a18e84fc428	JCB 16 digit	35.4044398941475933	-97.486313497870043
18450	2020-04-04 15:13:19	2020-04-04	Woodroe Murphy	woodroe.murphy@geemail.com	Los Angeles	California	869980202967100707	8952c022553dc5f7bd40b3c5f1cb8fbc	Maestro	34.0299205636471456	-118.414681515748796
18451	2020-04-04 15:32:21	2020-04-04	Amari Wiza	amari.wiza@geemail.com	Yonkers	New York	869946550282828037	f4e23e5b2d48a5b3494c4179e457ca42	VISA 13 digit	40.848527064706758	-73.9405738325674093
18452	2020-04-04 15:33:02	2020-04-04	Ms. Frederica Bernhard	ms.frederica.bernhard@woohoo.com	Los Angeles	California	55819072201205861	942f0d66a8b26a648c9b977aa745f730	American Express	34.1039215592533296	-118.321393948420138
18453	2020-04-04 15:43:57	2020-04-04	Malissie Lockman	malissie.lockman@woohoo.com	San Antonio	Texas	4320306914860576	8b9150be8889fc1aaadcf10eeae8a8e8	VISA 16 digit	29.4669481053087878	-98.447904399160663
18454	2020-04-04 15:44:26	2020-04-04	Silvester Langosh	silvester.langosh@woohoo.com	Cambridge	Massachusetts	6011211065889506893	3d9b309d71a7e4abc60312dc6a2c93ee	Mastercard	42.2782934278007545	-71.0673928803846309
18455	2020-04-04 16:08:28	2020-04-04	Ransom Mertz	ransom.mertz@warmmail.com	Los Angeles	California	869954252191160375	3c55981ee804ee6e8e06464ec056de12	Mastercard	33.974188112547246	-118.393314639804132
18456	2020-04-04 16:25:20	2020-04-04	Donell Von I	donell.von.i@warmmail.com	Torrance	California	4565211866530	a52257d024bc0693d09983ced236e1bd	Mastercard	33.8666530765499942	-118.421444546723365
18457	2020-04-04 16:36:30	2020-04-04	Dixon Rath	dixon.rath@geemail.com	Los Angeles	California	4073594674787	6ef2cec6e2cfdcde30bcb607a836445d	Mastercard	33.9626306103408311	-118.456648102681328
18458	2020-04-04 17:05:22	2020-04-04	Deacon Pouros DDS	deacon.pouros.dds@warmmail.com	Los Angeles	California	3337213292679140893	6fb561c61dcfd3bb9ec2dc385d089f72	VISA 16 digit	34.0506072586268189	-118.429082202538098
18459	2020-04-04 17:10:29	2020-04-04	Mrs. Star Abshire	mrs.star.abshire@warmmail.com	Naperville	Illinois	3026072613806788	44635dbfa8b6aa75caa2450904b1981c	Mastercard	41.7108464456543331	-88.1508918438926372
18460	2020-04-04 17:19:43	2020-04-04	Gerrit Runolfsson IV	gerrit.runolfsson.iv@geemail.com	Coral Springs	Florida	3158328209919476988	86baa7a77850ca7092f37784d7e7f228	American Express	26.2570655630033478	-80.2049344407051734
18461	2020-04-04 17:48:04	2020-04-04	Miss Izola Lebsack DVM	miss.izola.lebsack.dvm@warmmail.com	Las Vegas	Nevada	3337094809322549057	4758803f710c16b24512cc80c9a91c96	JCB 16 digit	36.1906218266680852	-115.215150533032045
18462	2020-04-04 18:57:39	2020-04-04	Gwyn Lehner	gwyn.lehner@geemail.com	Dallas	Texas	3039248234439558	25eaab2c9bf260eff01bf3c26d486284	Voyager	32.7628569184143146	-96.7536563235763367
18463	2020-04-04 19:17:59	2020-04-04	Trystan Kiehn	trystan.kiehn@woohoo.com	Huntsville	Alabama	3786290235941196	1dc6a848253d919e2c6246a7c22bbfe1	American Express	34.6837457996103922	-86.5932057453338047
18464	2020-04-04 19:24:22	2020-04-04	Dr. Grady Gusikowski V	dr.grady.gusikowski.v@geemail.com	West Jordan	Utah	3158936662739508261	1369f82d1c509d0689701e4f23db2d9a	Diners Club / Carte Blanche	40.6786233573943434	-112.023097355672348
18465	2020-04-04 19:26:16	2020-04-04	Bena Collier DVM	bena.collier.dvm@geemail.com	Aurora	Colorado	54269205438531486	1619b0d3dbd9591044eb6daa4525fcfe	Voyager	39.6386017709150948	-104.739587279653918
18466	2020-04-04 19:42:13	2020-04-04	Dellar Waelchi	dellar.waelchi@geemail.com	Providence	Rhode Island	869929026343183366	9f6fa572b0685960e700994509cfc04f	VISA 13 digit	41.7753693140432176	-71.4756169252015638
18467	2020-04-04 19:48:35	2020-04-04	Miss Symone Dare DDS	miss.symone.dare.dds@geemail.com	Boston	Massachusetts	6011390492144517882	81ac1e3305b737be52bd92f5b96ceffa	Voyager	42.3761019248683013	-71.0093943799331839
18468	2020-04-04 19:55:58	2020-04-04	Mr. Hakeem Bergnaum III	mr.hakeem.bergnaum.iii@geemail.com	Midland	Texas	6011973449820885871	13a6b6b196e013496eeb32850b1d9c97	Discover	31.9246744310673307	-102.089870944315564
18469	2020-04-04 19:58:38	2020-04-04	Georgiann Dach	georgiann.dach@geemail.com	New York	New York	54057962133777329	77d375b3fd25ed95e5c8d89aa2cb2c60	VISA 13 digit	40.6617762706000363	-73.9148928725522012
18470	2020-04-04 20:05:49	2020-04-04	Dr. Nathalia Kuhn	dr.nathalia.kuhn@woohoo.com	Augusta	Georgia	3337503757216412475	e42a6d83185887afd37a2d69958ae438	Diners Club / Carte Blanche	33.2825503311790527	-82.0574352728962992
18471	2020-04-04 20:23:12	2020-04-04	Natalee Dare	natalee.dare@geemail.com	Savannah	Georgia	4417487116857877	fd16e1896a92c8bbf19e9ad1dd8ba1ea	Diners Club / Carte Blanche	31.9610892464965559	-81.1227712465602906
18472	2020-04-04 20:30:59	2020-04-04	Collis Walker	collis.walker@woohoo.com	Houston	Texas	3528716266879172221	41f53e67853826f127eaf05963fcd305	Diners Club / Carte Blanche	29.6985924437254667	-95.363061699505522
18473	2020-04-04 20:49:44	2020-04-04	Ms. Leontine Barton	ms.leontine.barton@geemail.com	Denver	Colorado	3337810221577411640	a51cbfd483db3bd93c73f2b345d67211	VISA 16 digit	39.6731914772704215	-104.789288995812086
18474	2020-04-04 21:24:15	2020-04-04	Simona Treutel	simona.treutel@geemail.com	Glendale	California	210035745246778913	e347b4a774be94130a05f52d9421f3a3	VISA 16 digit	34.1071825290318529	-118.200914570120347
18475	2020-04-04 21:37:28	2020-04-04	Miss Ilah Kling MD	miss.ilah.kling.md@woohoo.com	Fremont	California	210059948262318421	12c8a4c81c660be96328ea3df5971bb7	VISA 13 digit	37.4114184218160801	-121.915573456370083
18476	2020-04-04 22:07:21	2020-04-04	Dr. Kassandra Kutch MD	dr.kassandra.kutch.md@geemail.com	Irvine	California	869971732579168966	1848630e9f5da9d1a770ca70d1fbe48a	Maestro	33.6181399349138204	-117.841096211645009
18477	2020-04-04 22:16:33	2020-04-04	Eleanora Hagenes	eleanora.hagenes@warmmail.com	Phoenix	Arizona	3158405933872590875	0c3b804f84961035d9492a4973c47265	Discover	33.574439085640762	-112.025957369983573
18478	2020-04-04 22:18:38	2020-04-04	Dr. Edie Johnston	dr.edie.johnston@geemail.com	Detroit	Michigan	52264321195335253	2f8a8a98c7e2f2f90443afc644f05cbc	VISA 16 digit	42.4424195606652646	-83.1835580267596981
18479	2020-04-04 22:20:18	2020-04-04	Jeanine Collier	jeanine.collier@warmmail.com	Buffalo	New York	3485018250639523	008892ce2e806855aca3613986f7b1bc	VISA 16 digit	42.907013409463687	-78.9043345146279762
18480	2020-04-04 22:47:18	2020-04-04	Ally Toy-Collins	ally.toy.collins@geemail.com	Madison	Wisconsin	869982896389941305	2c6fcdbf70190c34a5422107f93f2d20	JCB 15 digit	43.0587505168255404	-89.3882828962408098
18481	2020-04-04 22:49:26	2020-04-04	Callum Koelpin	callum.koelpin@geemail.com	San Francisco	California	3055128542982396	8de3c8d7c10c6ef009719f3149f2fa4a	JCB 15 digit	37.7858631581287909	-122.451887461135996
18482	2020-04-04 22:50:12	2020-04-04	Demetri Bahringer	demetri.bahringer@geemail.com	Costa Mesa	California	3088995075499172715	a72bbb1bd577fcdd188f0cc9556f0ae4	JCB 15 digit	33.7243079904016128	-117.936408834099026
18483	2020-04-04 22:58:34	2020-04-04	Bula Frami-Towne	bula.frami.towne@geemail.com	Omaha	Nebraska	3337942708975206920	9acef6294251c0f7a4ec0ef281298fca	Maestro	41.313731413116308	-96.0128103536669215
18484	2020-04-04 23:01:24	2020-04-04	Foster Thompson	foster.thompson@geemail.com	Arvada	Colorado	4646556884880	1ba161ed4c361d428009071e60fca388	VISA 16 digit	39.8215291725181046	-105.23647759938352
18485	2020-04-04 23:04:20	2020-04-04	Misti Sanford	misti.sanford@geemail.com	San Francisco	California	3041359732144968	fae88ae9338760c275ac0568269265b1	VISA 16 digit	37.7611954923276159	-122.411329013941355
18486	2020-04-04 23:04:45	2020-04-04	Jep Crist V	jep.crist.v@geemail.com	Denver	Colorado	4257277599722	f57253432223aadd3b97d652aa664ce8	Discover	39.8317381492402376	-104.951864105301354
18487	2020-04-04 23:11:17	2020-04-04	Matteo Murray Sr.	matteo.murray.sr.@woohoo.com	Philadelphia	Pennsylvania	3158454120052591267	88b52e2db89cbeeb03a8fd4a3deb239c	Mastercard	40.0543545919895152	-75.1389923550553647
18488	2020-04-04 23:15:22	2020-04-04	Candy Kuphal	candy.kuphal@geemail.com	Oakland	California	4283065140628	4e872cff7984ee4a93a53be02c937582	VISA 16 digit	37.8069349008205577	-122.293413401981326
18489	2020-04-04 23:34:31	2020-04-04	Joshua Shanahan	joshua.shanahan@woohoo.com	Vista	California	210054169696575891	99c00d1d837107df39fc97a29f7e805d	VISA 16 digit	33.2204067171067052	-117.242496604990592
18490	2020-04-04 23:36:11	2020-04-04	Ethelbert Baumbach	ethelbert.baumbach@geemail.com	Oakland	California	3337487412205820425	39c416f9827c9e4133f512a4fa6352ea	Voyager	37.7865618708349231	-122.263168384565859
18491	2020-04-05 00:01:41	2020-04-05	Horace Wolf	horace.wolf@geemail.com	Jackson	Mississippi	3112688397633082473	12d5fd121316ab1d9cd65bfca3d32def	Voyager	32.277087393327804	-90.2159004865653884
18492	2020-04-05 00:06:53	2020-04-05	Ernestine Kulas	ernestine.kulas@geemail.com	Lakeland	Florida	3096753422574192113	3eaf6d6871e9e42686f3c7d26d913058	Voyager	28.0705639323517673	-81.9039974596235822
18493	2020-04-05 00:07:53	2020-04-05	Miss Debbie Abernathy MD	miss.debbie.abernathy.md@warmmail.com	Corpus Christi	Texas	3528632642764401746	933c7fc0ab9fdc912bf2c8456865bf14	American Express	27.7800224743720143	-97.1390395885162121
18494	2020-04-05 00:16:15	2020-04-05	Jaymes Lehner	jaymes.lehner@geemail.com	Baton Rouge	Louisiana	4857727303840252	0178312655b407b05551cf4cd49aaacf	JCB 16 digit	30.3711921807590883	-91.0989966846644847
18495	2020-04-05 00:16:41	2020-04-05	Mr. French Boyle	mr.french.boyle@geemail.com	Aurora	Illinois	54206376014467076	ba442f7335f37746885a07a31cba5955	VISA 13 digit	41.8516004708353435	-88.3620460769090812
18496	2020-04-05 00:36:26	2020-04-05	Justina Mraz	justina.mraz@geemail.com	Grand Rapids	Michigan	3112587526823556878	8bcfd55496cac48f212e7cc54853f884	Maestro	43.0082989225897947	-85.7443552796863031
18497	2020-04-05 00:57:38	2020-04-05	Nyasia Kemmer-Stracke	nyasia.kemmer.stracke@geemail.com	Lancaster	California	3528245198937005061	c374f8cc2e44c5b356e16120f579c7ce	Voyager	34.6116394959170393	-118.201880353081222
18498	2020-04-05 00:58:16	2020-04-05	Cameron Rempel	cameron.rempel@warmmail.com	Miami	Florida	55096818366935799	c2eb777a1fd8432c3b0a3a9169f07da8	Voyager	25.7007665402859473	-80.1963737165894344
18499	2020-04-05 00:58:33	2020-04-05	Ms. Brittni Kulas MD	ms.brittni.kulas.md@woohoo.com	Salinas	California	4122716451769321	3b049ac71450019fa395a50324711008	Maestro	36.6944722512036563	-121.696324430563308
18500	2020-04-05 01:06:44	2020-04-05	Ms. Senora McDermott PhD	ms.senora.mcdermott.phd@geemail.com	St. Louis	Missouri	3024962949560087	8097c2e469e4d0d2d9cbbfbbf8bd063e	Diners Club / Carte Blanche	38.6786574610199807	-90.1818307440731672
18501	2020-04-05 01:11:24	2020-04-05	Emma Goldner	emma.goldner@warmmail.com	Oakland	California	4678526833846947	0ba207c7880ad636f5d60ed0de11f67a	Mastercard	37.8106127628496367	-122.293593747483158
18502	2020-04-05 01:14:41	2020-04-05	Idella Towne PhD	idella.towne.phd@geemail.com	Charleston	South Carolina	503863222843458	e9dc678ac3fda391ea2aaa96bf48ea8d	VISA 16 digit	32.7204458443909871	-80.017210496325049
18503	2020-04-05 01:19:32	2020-04-05	Lisbeth Brekke	lisbeth.brekke@warmmail.com	New York	New York	3096239070430538070	ad93c9b783d3bea27d7623f68819b5d3	JCB 15 digit	40.7050104622021323	-73.9997546498093755
18504	2020-04-05 01:20:15	2020-04-05	Maybell Paucek	maybell.paucek@geemail.com	New York	New York	4497413355595773	1c7d173a88556cb885fd9fd26dae1d06	JCB 15 digit	40.6758531757853916	-74.0301991549681873
18505	2020-04-05 01:52:26	2020-04-05	Jim Bruen	jim.bruen@geemail.com	New York	New York	502003535586071	42806ced35a43d7719f4c3e3d0e7d796	Voyager	40.5813438299335516	-73.9543080789864007
18506	2020-04-05 01:59:57	2020-04-05	Hideo Ortiz II	hideo.ortiz.ii@geemail.com	Dallas	Texas	3528746070152976215	b6317d5e9edc8bccb2375eb029fe6f21	VISA 16 digit	32.6962330169782049	-96.7131963449958647
18507	2020-04-05 02:00:50	2020-04-05	Santana Kshlerin	santana.kshlerin@geemail.com	Oklahoma City	Oklahoma	4985616064678479	156b3ba266645bae0133b691ef658f03	Discover	35.5606108570847681	-97.4772176239069523
18508	2020-04-05 02:04:07	2020-04-05	Erik Daniel	erik.daniel@geemail.com	New York	New York	869921955867132235	aaeb46e8e8daba3934957ec7ee88e6d8	Maestro	40.6304686412438727	-74.0378491017397522
18509	2020-04-05 02:07:04	2020-04-05	Liana Pacocha	liana.pacocha@geemail.com	Milwaukee	Wisconsin	3739216805382337	37f4f167ca807d5351c8758fb53f9a6b	VISA 16 digit	43.02902809666395	-87.9007170472860366
18510	2020-04-05 02:15:00	2020-04-05	Samantha Lueilwitz DDS	samantha.lueilwitz.dds@woohoo.com	Savannah	Georgia	4452671701296460	e0974a6830a7f4b33c1243e0b21698c6	VISA 16 digit	31.9392241774685672	-81.0548423446867616
18511	2020-04-05 02:24:29	2020-04-05	Steven Dietrich	steven.dietrich@geemail.com	San Francisco	California	3029407219796008	9c0e40fabd6cb76fb7c5636e80e561b1	Discover	37.7674687819623784	-122.451861489496991
18512	2020-04-05 02:27:38	2020-04-05	Early Jenkins Jr.	early.jenkins.jr.@geemail.com	Houston	Texas	55099437212672469	31bc1eef188b814e2170afc943bb7d5e	VISA 16 digit	29.8708490279581405	-95.309107114050164
18513	2020-04-05 02:39:03	2020-04-05	Alberta Bechtelar DDS	alberta.bechtelar.dds@geemail.com	San Francisco	California	4536589762882	63daa478dd0516366aebd2316f6c142a	Voyager	37.739199592898828	-122.432358346807789
18514	2020-04-05 02:41:22	2020-04-05	Miss Lilyanna Abernathy PhD	miss.lilyanna.abernathy.phd@geemail.com	Cleveland	Ohio	869938842402936802	4a6cdb6e7d93a33f629d7b2ebe7a05e6	American Express	41.4829629925861951	-81.6652879025094194
18515	2020-04-05 02:52:01	2020-04-05	Anjali Klocko	anjali.klocko@geemail.com	Chesapeake	Virginia	3337648823305132204	9ab1fa133f1cdaef3fc8c9e0f2f3a0d9	Voyager	36.5831818466778884	-76.2463802193135081
18516	2020-04-05 02:59:15	2020-04-05	Louisiana Schumm PhD	louisiana.schumm.phd@geemail.com	Naperville	Illinois	6011545813920243258	a4978fb145b51d9b4e527121206bc9c0	Mastercard	41.7933968431230625	-88.0951103709526393
18517	2020-04-05 03:48:37	2020-04-05	Lora Conroy	lora.conroy@geemail.com	El Monte	California	4396465764886	27b9fe4d66b3377fe510de338922ca11	Maestro	34.1678741427328418	-117.945640137818089
18518	2020-04-05 03:50:54	2020-04-05	Darryl Jenkins	darryl.jenkins@woohoo.com	Rancho Cucamonga	California	4735410809253639	b13f159759e7ca57cc08b5aeb082b0b4	VISA 16 digit	34.2107212058261041	-117.647083734395721
18519	2020-04-05 03:55:38	2020-04-05	Mr. Phillip Bahringer III	mr.phillip.bahringer.iii@woohoo.com	San Francisco	California	54592709554068429	9d22687a701a1c7e3671dd867855bb88	Maestro	37.7950284965430683	-122.452406801239164
18520	2020-04-05 03:56:10	2020-04-05	Arba Wuckert	arba.wuckert@warmmail.com	Philadelphia	Pennsylvania	3088827877147090957	6e0bff2f21ce2ca587bf166808bc660c	Maestro	39.9996141540776904	-75.2164471066456315
18521	2020-04-05 04:00:09	2020-04-05	Arlis Moore-Price	arlis.moore.price@geemail.com	Long Beach	California	3096226664551053730	a606aaa8c773a68acf9fffef16f19aa8	VISA 16 digit	33.8746948228504507	-118.222079674123975
18522	2020-04-05 04:51:06	2020-04-05	Dr. Delwin Hagenes MD	dr.delwin.hagenes.md@geemail.com	San Francisco	California	4538418177847113	4be17411805e866a873d7f4868b3ab5c	JCB 15 digit	37.8009298629479744	-122.447053476302941
18523	2020-04-05 05:11:45	2020-04-05	Lesley Will DVM	lesley.will.dvm@geemail.com	San Francisco	California	869959112830224104	9e2961db3b483154fe23c99c215abfa4	VISA 16 digit	37.7763074779162764	-122.432499751225919
18524	2020-04-05 05:11:59	2020-04-05	Dr. Pairlee Brekke DVM	dr.pairlee.brekke.dvm@geemail.com	Fullerton	California	3744017223209984	e4175d32feb42c95caf07096d4758ec2	Maestro	33.8701010919332504	-117.877707410391423
18525	2020-04-05 05:20:41	2020-04-05	Lizabeth Willms-Moen	lizabeth.willms.moen@woohoo.com	San Francisco	California	53848207879746649	d439c166a0007bf3bb1240d6356a39e1	Discover	37.7673985724608556	-122.444049315934976
18526	2020-04-05 05:27:59	2020-04-05	Shatara Bartell	shatara.bartell@warmmail.com	San Francisco	California	4144094803885	a6711f7e5218c63f7e6972c0978435a8	VISA 16 digit	37.7760747903475718	-122.442482734879519
18527	2020-04-05 06:08:27	2020-04-05	Pearlene Barrows PhD	pearlene.barrows.phd@woohoo.com	San Francisco	California	51296495582794132	ecc4a996d5e43bb1bc7ff6023e90f63b	American Express	37.7494821910711877	-122.431641661102532
18528	2020-04-05 06:13:03	2020-04-05	Verdie Weimann	verdie.weimann@woohoo.com	Columbus	Georgia	3528406167443331332	1835c13529aac725b57f1897dde87221	Discover	32.4437917301475949	-84.8372954877257257
18529	2020-04-05 06:51:23	2020-04-05	Viney Larson	viney.larson@geemail.com	Salinas	California	3019329457567331	47cd0edf944baec21ec057f7fa10a931	Maestro	36.7644093627341064	-121.587176651664834
18530	2020-04-05 06:52:26	2020-04-05	Mr. Pasquale Hayes	mr.pasquale.hayes@woohoo.com	San Francisco	California	3112836927142172729	1d53de5e9c8bbe9357bd75bec20869eb	Discover	37.7541869020733856	-122.421812690778225
18531	2020-04-05 06:58:54	2020-04-05	Ms. Manila Olson MD	ms.manila.olson.md@geemail.com	San Francisco	California	4663081035991817	b2eb4a6cc74331caa87a759b822effcb	JCB 15 digit	37.7771992816470288	-122.447174693520125
18532	2020-04-05 06:59:34	2020-04-05	Tyquan Parker	tyquan.parker@geemail.com	Dallas	Texas	3096054638353544986	aac3cce94dfafbdeb06f3a3b67f5fef5	Mastercard	32.7792826852567529	-96.8466979412790323
18533	2020-04-05 07:02:51	2020-04-05	Darien Collins	darien.collins@geemail.com	San Francisco	California	676272500932958	6629414a016e60281b060cb16931d368	JCB 15 digit	37.7792751851575872	-122.437422266359903
18534	2020-04-05 07:03:39	2020-04-05	Mr. Jahir Bruen MD	mr.jahir.bruen.md@warmmail.com	Hialeah	Florida	501811803874681	e70102b65e394b75ba279ffe2329ea9c	VISA 13 digit	25.8177407762479056	-80.3092990463036926
18535	2020-04-05 07:06:30	2020-04-05	Dimitri Hyatt-O'Reilly	dimitri.hyatt.o'reilly@geemail.com	Minneapolis	Minnesota	4832547313183802	2f3683d898027383f28a7b71db8f311b	VISA 16 digit	44.9765093345280675	-93.1937731941502534
18536	2020-04-05 07:07:32	2020-04-05	Ms. Joann Kertzmann	ms.joann.kertzmann@geemail.com	Oklahoma City	Oklahoma	6011375871795998609	ffda1f687c90d78972395835ccaf47d6	Mastercard	35.3689858369905537	-97.4326388982020291
18537	2020-04-05 07:15:10	2020-04-05	Reece Heidenreich	reece.heidenreich@geemail.com	Fort Worth	Texas	6011767106505837342	f80ab6f32848e7c70f41ab6015486a06	Voyager	32.8732839174158897	-97.4016357309471772
18538	2020-04-05 07:27:04	2020-04-05	Rance Rohan	rance.rohan@woohoo.com	Fort Collins	Colorado	3449554776671686	0098a8570fe81d5a9458a2d2fcc9e1e3	Maestro	40.6205037809599219	-105.086773128290858
18539	2020-04-05 07:44:41	2020-04-05	Cornell Spencer	cornell.spencer@woohoo.com	Orlando	Florida	4294358407251	58f3c5f19f4e52b5c4d86ba380cfd767	American Express	28.3981091965254393	-81.3584957314156014
18540	2020-04-05 07:51:33	2020-04-05	Dr. Makena Hirthe PhD	dr.makena.hirthe.phd@geemail.com	New York	New York	675918493386140	d685e4c76b5c0d41ae1bde074e557b00	JCB 16 digit	40.6747652285955823	-73.9400470801524818
18541	2020-04-05 07:53:26	2020-04-05	Concepcion Jerde-Blanda	concepcion.jerde.blanda@geemail.com	San Francisco	California	4586298673772739	8ade1903f540ed4589af65d663b3d967	JCB 16 digit	37.7772341001204168	-122.406991854342678
18542	2020-04-05 08:04:22	2020-04-05	Lilliana Funk	lilliana.funk@geemail.com	Tulsa	Oklahoma	3055971309248257	56b18c844db37f91ee2c3e1ecb5eac4d	VISA 13 digit	36.201726279444614	-95.923893330521139
18543	2020-04-05 08:09:23	2020-04-05	Ala Nikolaus	ala.nikolaus@geemail.com	Fort Worth	Texas	52335586432088874	12c01bebd01b8ae3abc3f109168dda6b	Voyager	32.7250468488372874	-97.4139077913768574
18544	2020-04-05 08:22:15	2020-04-05	Lilianna Pacocha	lilianna.pacocha@geemail.com	Modesto	California	4194338385799598	e6a3fbd49c597ff238f101ebe4dce101	Mastercard	37.680903053237131	-120.928125511176887
18545	2020-04-05 08:22:24	2020-04-05	Nellie Legros DVM	nellie.legros.dvm@geemail.com	Austin	Texas	210034289416821600	a290ca31739456a9f156c810373afc4a	Maestro	30.3454473042055959	-97.8085743305046122
18546	2020-04-05 08:24:15	2020-04-05	Krish Little-Denesik	krish.little.denesik@geemail.com	Philadelphia	Pennsylvania	3158892164155018257	abbab09a806e4ba3a50b11a6b95882b1	Mastercard	39.9496285945601741	-75.1212920734092648
18547	2020-04-05 08:30:27	2020-04-05	Bartley Gislason	bartley.gislason@geemail.com	Bakersfield	California	503828136442598	c250eed95348b789ff799b165f5e84d2	Maestro	35.2596732577484104	-119.100471161938458
18548	2020-04-05 09:10:42	2020-04-05	Sammie McClure	sammie.mcclure@geemail.com	San Francisco	California	869948055609753114	899635e317cf7ea16b64d186ef53fe69	Voyager	37.7440930899685441	-122.463183916207811
18549	2020-04-05 09:13:09	2020-04-05	Dakota Auer	dakota.auer@woohoo.com	Chicago	Illinois	869919490030033312	a6d4f8229bd1a3f61d1bf5d3f30cb864	VISA 16 digit	41.7976261905230615	-87.7561759010452676
18550	2020-04-05 09:20:10	2020-04-05	Dionte Mraz-Leuschke	dionte.mraz.leuschke@geemail.com	Springfield	Massachusetts	4931729246401	be6644295c1955f7020bc04c79f474f4	Maestro	42.1681702499482753	-72.6214773997757703
18551	2020-04-05 09:22:48	2020-04-05	Elva Kirlin	elva.kirlin@geemail.com	Oakland	California	4335616823217	d5ae4da61c763e9e0c700d502084265a	VISA 13 digit	37.8105549724372878	-122.246077565709484
18552	2020-04-05 09:25:58	2020-04-05	Keifer Kuvalis	keifer.kuvalis@geemail.com	Philadelphia	Pennsylvania	3096122005954047041	5fbe19b211199017cc7e370198312efc	Maestro	40.0353961375501015	-75.1507018331337804
18553	2020-04-05 09:33:59	2020-04-05	Lavon Krajcik	lavon.krajcik@geemail.com	New York	New York	589384410765295	3bc30333b105f0d49e00b69a46ca7ab6	JCB 16 digit	40.686474743228402	-73.9687381678156584
18554	2020-04-05 09:37:31	2020-04-05	Tilden Jaskolski	tilden.jaskolski@geemail.com	Lowell	Massachusetts	6011390758195921797	c7958f6e9d74459d1f6958431c8b1daa	American Express	42.5437085406724407	-71.3600167230110571
18555	2020-04-05 09:41:45	2020-04-05	Miss Richelle Keeling DDS	miss.richelle.keeling.dds@geemail.com	St. Petersburg	Florida	4425180275877378	a82d5130bd7afb8d2b6dc425078490e0	JCB 16 digit	27.7869752686358993	-82.7029912176433868
18556	2020-04-05 10:07:30	2020-04-05	Hiroshi Collier	hiroshi.collier@warmmail.com	Carrollton	Texas	3158746514041641381	a8494055ef37e2e11978c0971a8cd0db	Mastercard	32.9098008089154916	-96.8004126090884256
18557	2020-04-05 10:07:39	2020-04-05	Steve Schulist	steve.schulist@geemail.com	San Francisco	California	4598893877111	e2d7004be3ab2760860f14b901c0ee35	Maestro	37.7606607846798781	-122.410209397223227
18558	2020-04-05 10:09:11	2020-04-05	Byrdie Carroll	byrdie.carroll@geemail.com	Dallas	Texas	4256475705149	582ef4f6e9cc420c1a999c2211c4b4f2	VISA 16 digit	32.7007683894403272	-96.8428810509350058
18559	2020-04-05 10:10:07	2020-04-05	Michell Yost	michell.yost@geemail.com	Oakland	California	51785083581041347	0c319cb9e2e9e1035f5be515c9034974	JCB 15 digit	37.7913195704326768	-122.277377657378693
18560	2020-04-05 10:15:43	2020-04-05	Fulton Swaniawski MD	fulton.swaniawski.md@geemail.com	New York	New York	3720035074831241	70a40888b6ad4387806cc5df37f87054	JCB 16 digit	40.762457515973594	-74.0140545757848685
18561	2020-04-05 10:33:06	2020-04-05	Mr. Sigmund Mosciski DVM	mr.sigmund.mosciski.dvm@warmmail.com	San Francisco	California	4862040639284481	77e91f0f56d93425dc97749d4363afca	Mastercard	37.7276212771528279	-122.44596038816664
18562	2020-04-05 10:43:14	2020-04-05	Dr. Addie Lindgren	dr.addie.lindgren@geemail.com	Philadelphia	Pennsylvania	3030517616120849	199d7d5e2e1d87020e71d02a39f35aeb	American Express	39.9521839951589683	-75.0961082634881194
18563	2020-04-05 10:56:36	2020-04-05	Orla Larson	orla.larson@geemail.com	Phoenix	Arizona	4411845208542911	9a4ed6c491b922880c62c8f6deeb7e2e	VISA 16 digit	33.4962024064667574	-112.140349278033156
18564	2020-04-05 10:59:27	2020-04-05	Keisha Batz-Kihn	keisha.batz.kihn@geemail.com	Philadelphia	Pennsylvania	4905267203438	2dd81df96256cf12747511c9693e5503	JCB 16 digit	40.0028485032688792	-75.1789339040305578
18565	2020-04-05 11:14:27	2020-04-05	Grayce Crist	grayce.crist@geemail.com	Seattle	Washington	180028115269324301	9b24db3c473699c0f7aca77df5cb5629	VISA 16 digit	47.5499290994759676	-122.414345107080038
18566	2020-04-05 11:33:14	2020-04-05	Shirleen Graham	shirleen.graham@geemail.com	Columbus	Ohio	210029171722351059	e648097425263b847a55ff07b1f98bca	VISA 16 digit	40.0557422114115198	-83.0282363197535318
18567	2020-04-05 11:40:08	2020-04-05	Schley Sanford PhD	schley.sanford.phd@geemail.com	Fort Wayne	Indiana	3424668545742872	82ea6150873af6d000caaf2b28da0ea0	VISA 13 digit	41.1333320094056418	-85.2339541990529739
18568	2020-04-05 11:43:46	2020-04-05	Charley Huel-Reinger	charley.huel.reinger@geemail.com	Corona	California	210013026236870416	bf8919dcaff58638ac55b70535fda1eb	JCB 15 digit	33.7699821614548554	-117.59466555446572
18569	2020-04-05 11:44:35	2020-04-05	Earl Keebler DVM	earl.keebler.dvm@geemail.com	San Francisco	California	3096749169595534057	38c99b0d268cc6e80109c0e83ac19e36	JCB 16 digit	37.764705734237964	-122.421369887999731
18570	2020-04-05 11:48:56	2020-04-05	Lisette Thompson	lisette.thompson@geemail.com	Mobile	Alabama	51447054140021997	ad3f32514437938ea6eba4ea3b6601af	JCB 15 digit	30.71140282220356	-88.0589561727967123
18571	2020-04-05 11:49:29	2020-04-05	Mrs. Delois Windler MD	mrs.delois.windler.md@geemail.com	Aurora	Illinois	180055749512623675	91a8fb75847972975af599a72e117065	VISA 13 digit	41.8174889457169954	-88.2215673546236019
18572	2020-04-05 11:51:12	2020-04-05	Mrs. Yareli Schroeder MD	mrs.yareli.schroeder.md@warmmail.com	Irvine	California	3023875651552178	5bd4e30ce9febcd89c20c4cf51357532	JCB 16 digit	33.5918210931602914	-117.806845479413113
18573	2020-04-05 12:00:59	2020-04-05	Lexie Bauch	lexie.bauch@geemail.com	Rancho Cucamonga	California	4209198376537594	0b04b77866bde0fb40ac23bc6e5b60ea	American Express	34.102296214270595	-117.469054146670544
18574	2020-04-05 12:04:16	2020-04-05	Erving Will	erving.will@geemail.com	Reno	Nevada	6011494246356963860	91b40e7770d9c8b8d77d5d8429ed868e	American Express	39.4995286054056152	-119.894797718261927
18575	2020-04-05 12:06:41	2020-04-05	Pricilla Stokes	pricilla.stokes@warmmail.com	San Francisco	California	180064308014188064	5b46f26d26058820f6373d6777456480	JCB 15 digit	37.7203128545288848	-122.404597942102939
18576	2020-04-05 12:27:37	2020-04-05	Angele Dickens	angele.dickens@warmmail.com	San Francisco	California	3088687985422002982	153484c08ed5ca0e38b5c1d5d936ac47	JCB 16 digit	37.7719431460730064	-122.408292610104624
18577	2020-04-05 12:38:15	2020-04-05	Savon Kautzer	savon.kautzer@warmmail.com	New York	New York	3158692211649650633	4d8de6bdc031032611f4040c92003e5b	Maestro	40.698157218027859	-73.8835409426957312
18578	2020-04-05 12:38:32	2020-04-05	Ignacio Mayert	ignacio.mayert@geemail.com	Gainesville	Florida	4854023803307	7b7686fdaf7e71291fdfe8dc3638545d	JCB 16 digit	29.7023499268397693	-82.4309205534275691
18579	2020-04-05 13:01:41	2020-04-05	Jordan Block	jordan.block@geemail.com	Los Angeles	California	4404771359753	7cb2e0e989283d93e9d61edaa150741a	Mastercard	34.0788355685170714	-118.509896376635126
18580	2020-04-05 13:04:19	2020-04-05	Bobbie Spinka	bobbie.spinka@geemail.com	Santa Rosa	California	4799608231855	56d0c3aa48cf1195cae001405cb4a429	Discover	38.534415755852315	-122.675665414311368
18581	2020-04-05 13:08:42	2020-04-05	Rosario Turcotte-Roob	rosario.turcotte.roob@geemail.com	Pasadena	California	180056953200506114	e7e58a3062f179dd2547a7762780ee90	Discover	34.2584948994074026	-118.175526119098436
18582	2020-04-05 13:12:43	2020-04-05	Ms. Margy Heathcote	ms.margy.heathcote@geemail.com	Savannah	Georgia	210021399847507846	205a4834bf03900864c82ee0990f1d24	VISA 13 digit	32.0132748690526938	-81.1556571935921909
18583	2020-04-05 13:48:08	2020-04-05	Mr. Brenton Parisian Sr.	mr.brenton.parisian.sr.@warmmail.com	Long Beach	California	6011397214193105374	a38346e1c84fe063d54a716bc12b6233	Discover	33.8945542346507267	-118.167619639092308
18584	2020-04-05 13:54:46	2020-04-05	Jemal Bernhard	jemal.bernhard@warmmail.com	San Francisco	California	3096050161381942951	ac84790b5845755e30a7dc42c2081fd8	VISA 13 digit	37.7966435922273547	-122.437130524371383
18585	2020-04-05 14:03:30	2020-04-05	Hart Walsh	hart.walsh@warmmail.com	San Francisco	California	3482451464164678	a39a85e4d182b496b9a2afe59420bd55	Discover	37.7635371896599992	-122.425212227965886
18586	2020-04-05 14:10:58	2020-04-05	Rowland Block	rowland.block@woohoo.com	Los Angeles	California	3088178897176826860	7809d2be88a78ad4f1344a7d45bda1f1	Maestro	34.0169621054414648	-118.455417694476608
18587	2020-04-05 14:18:34	2020-04-05	Dr. Alayna Haley PhD	dr.alayna.haley.phd@woohoo.com	New York	New York	869927682368188136	39a604450d19d39356630d46abe68cc9	VISA 13 digit	40.7051401115711755	-73.9754783766239825
18588	2020-04-05 14:54:24	2020-04-05	Paulette Murray	paulette.murray@geemail.com	Clinton	Michigan	4090009960775	45f409f9a21bbf7b11f32d51ac0a8d9d	Maestro	42.6701857065383336	-82.8646049115415622
18589	2020-04-05 15:50:34	2020-04-05	Shavon Wehner	shavon.wehner@geemail.com	San Francisco	California	210021526314801555	aa771a9737b3266d8f88379d70996a81	Voyager	37.756672191287052	-122.430695824232885
18590	2020-04-05 15:59:24	2020-04-05	Ms. Joslyn Miller	ms.joslyn.miller@geemail.com	New York	New York	210063122384525032	1740f7aa9308a216cde70bec8af1adb3	Voyager	40.5939084181319885	-73.9415473662212435
18591	2020-04-05 16:08:16	2020-04-05	Jason Boyle	jason.boyle@geemail.com	Torrance	California	3528523245090137646	84fb8b01ac6dee3f0cb34611fb235fa0	JCB 16 digit	33.7635855011548855	-118.257948758884879
18592	2020-04-05 16:18:18	2020-04-05	Gilberto Schowalter	gilberto.schowalter@geemail.com	Bridgeport	Connecticut	3528686097031624387	fa04c0bd7ec76e83a1cd0a21af960a17	American Express	41.1505873110309182	-73.1139837761309082
18593	2020-04-05 16:20:20	2020-04-05	Gennie McGlynn DVM	gennie.mcglynn.dvm@geemail.com	Salem	Oregon	869991116848970210	a2f43ff528c8c8804bae80d261232e92	Voyager	44.9328465828474606	-122.979064473572009
18594	2020-04-05 16:36:12	2020-04-05	Angel Bruen	angel.bruen@geemail.com	Atlanta	Georgia	3037678253456152	150c8edbc38f078953229aba3ce11c30	Mastercard	33.6970551505494882	-84.3337223526600752
18595	2020-04-05 16:45:38	2020-04-05	Santina Dicki	santina.dicki@geemail.com	Rialto	California	676277897958789	1f7ba96e1c81a8f3c656d832b950229c	JCB 15 digit	34.0558621325280555	-117.306813928819452
18596	2020-04-05 17:14:08	2020-04-05	Salina Zboncak	salina.zboncak@warmmail.com	New York	New York	4049782308972609	d5df8cf1bf4a633a7cdb7d31e5cddaf7	VISA 16 digit	40.6874187405444658	-73.8781544700626256
18597	2020-04-05 17:21:08	2020-04-05	Mr. Mart Treutel Sr.	mr.mart.treutel.sr.@woohoo.com	Montgomery	Alabama	4083452578328166	a0e934e6d911e47b25290847a2e716a5	VISA 13 digit	32.2984132721953117	-86.3442515518203351
18598	2020-04-05 17:53:08	2020-04-05	Alfonse Robel	alfonse.robel@geemail.com	Lakewood	New Jersey	51147913087830772	3a8da23ee95f2faddb79eaf8cd2603bd	JCB 16 digit	40.0792968347951799	-74.2473414016231885
18599	2020-04-05 17:55:29	2020-04-05	Dalia Kilback	dalia.kilback@geemail.com	Fremont	California	4898606004562608	7d66337d06de75bf0ace4cf463a2f0dc	Discover	37.581210828356447	-121.974267405130703
18600	2020-04-05 18:08:55	2020-04-05	Kiley Lind IV	kiley.lind.iv@warmmail.com	Raleigh	North Carolina	3096132952691207131	6da029c101610b417c040811f5189aeb	American Express	35.7575766523502736	-78.6001774335682484
18601	2020-04-05 18:20:21	2020-04-05	Nell Abshire	nell.abshire@warmmail.com	Charlotte	North Carolina	4048597751483347	89122aee46af3d3856cea31dda85ceee	VISA 16 digit	35.268143917738648	-80.9250085137728661
18602	2020-04-05 18:29:46	2020-04-05	Codey Bauch	codey.bauch@geemail.com	San Francisco	California	869975596919618824	7824616b22e1318c72d15cde7fabbf8e	JCB 15 digit	37.7664893685302232	-122.447166749682339
18603	2020-04-05 18:30:45	2020-04-05	Vinson Goyette-DuBuque	vinson.goyette.dubuque@warmmail.com	Oklahoma City	Oklahoma	4738632551292	642680fb0e60af70d5f86c92255fe2bb	Diners Club / Carte Blanche	35.4854201934210991	-97.4378795839276108
18604	2020-04-05 18:33:49	2020-04-05	Sydney Gaylord-White	sydney.gaylord.white@geemail.com	San Francisco	California	4816767388746	218f84621b5b28645aa933ceaf8760a0	VISA 13 digit	37.786588470876211	-122.419290252321616
18605	2020-04-05 18:40:46	2020-04-05	Helaine Waters-Schamberger	helaine.waters.schamberger@geemail.com	Peoria	Arizona	4570341813032776	366350ccbd7bb4f019d5f82fe5db63f2	JCB 16 digit	33.8555536880426118	-112.218912164486952
18606	2020-04-05 18:41:10	2020-04-05	Mannie Steuber	mannie.steuber@geemail.com	Anchorage	Alaska	3440385508958425	7e71b06b67b38582a6ccd81202ce693e	Mastercard	61.1499410400848831	-149.189969777328145
18607	2020-04-05 18:55:03	2020-04-05	Cleon Brekke II	cleon.brekke.ii@geemail.com	Springfield	Illinois	6011071138872972015	001b4b1ec47859b076ad8062197d6fad	VISA 13 digit	39.8257319081261727	-89.6272325801666767
18608	2020-04-05 18:55:03	2020-04-05	Gee Gutmann-Cummings	gee.gutmann.cummings@warmmail.com	Pasadena	Texas	3528948935416577254	7b113ba2b06267ce1c1a2ff0cdd31dde	American Express	29.6317388900894656	-95.2199538543768256
18609	2020-04-05 19:00:18	2020-04-05	Abbott Nitzsche	abbott.nitzsche@woohoo.com	Philadelphia	Pennsylvania	3711547930092850	e0f7e447c1d46a9e851b9c2f757b275a	Discover	39.9938604083336884	-75.1841298807777463
18610	2020-04-05 19:06:24	2020-04-05	Aubrie Prosacco	aubrie.prosacco@geemail.com	High Point	North Carolina	6011514688748210243	33f077d52e612fe72fe38aabbdba600d	Voyager	36.0824521200824577	-80.0790731002781513
18611	2020-04-05 19:06:25	2020-04-05	Smith Cruickshank	smith.cruickshank@geemail.com	El Paso	Texas	3059034495880296	6c6bfa53df285aa8e71e8941ef997fbd	VISA 16 digit	31.8036240913733863	-106.369156828055168
18612	2020-04-05 19:08:14	2020-04-05	Nello Morar-Fadel	nello.morar.fadel@geemail.com	Westminster	Colorado	4046332634499753	109625f115474b7fb211b701a6ae4249	Mastercard	39.8141931746926119	-104.984570615939433
18613	2020-04-05 19:14:37	2020-04-05	Mrs. Lynn Jacobson MD	mrs.lynn.jacobson.md@geemail.com	Rialto	California	4874564410185001	e671dd06f506b4e1c320058a99947d95	VISA 13 digit	34.1927689159505093	-117.444685063705961
18614	2020-04-05 19:38:00	2020-04-05	Marylin Toy	marylin.toy@woohoo.com	Arvada	Colorado	3528544000733377330	328a9c31caddf5ebda6cdc2a8abbe501	Diners Club / Carte Blanche	39.7594021549623449	-105.065241949537025
18615	2020-04-05 19:43:14	2020-04-05	Dollie Schulist	dollie.schulist@geemail.com	New York	New York	3528496553698344776	2a2a616d0f1836813fc83bced1f85708	VISA 16 digit	40.5723008755818029	-73.9452407499670983
18616	2020-04-05 19:44:45	2020-04-05	Mohammed Harris-Fadel	mohammed.harris.fadel@geemail.com	Charlotte	North Carolina	3714303020358539	9781ce77aaa513968778c504a3f81a45	Voyager	35.1356032652102428	-80.7897300758808825
18617	2020-04-05 19:44:49	2020-04-05	Shyanne Renner PhD	shyanne.renner.phd@geemail.com	Columbus	Georgia	869929208270168970	78aba11b5be5886dc798fc61f8081409	American Express	32.4691809928554989	-84.9113373344462303
18618	2020-04-05 19:45:03	2020-04-05	Alphonsine Hane	alphonsine.hane@geemail.com	Edison	New Jersey	3112848497753513401	9a0c9a81e27e2b5009027dda5eafb6a9	Maestro	40.5781772719193228	-74.2797719882387639
18619	2020-04-05 19:51:33	2020-04-05	Dr. Keyon Gleason Sr.	dr.keyon.gleason.sr.@warmmail.com	Sacramento	California	3427954854618425	0072e4f06cc44bd890da49f4cef9249b	VISA 16 digit	38.5896731224641201	-121.540543031903354
18620	2020-04-05 19:55:18	2020-04-05	Carmel McGlynn	carmel.mcglynn@geemail.com	San Antonio	Texas	502067641648208	606ea51244ef5ec38b6de0d504b69b40	Diners Club / Carte Blanche	29.5303887783620524	-98.4504580546472141
18621	2020-04-05 19:57:35	2020-04-05	Anne Kuphal-Bergstrom	anne.kuphal.bergstrom@geemail.com	Los Angeles	California	3096441205585730940	554e3318801a56d13be1f6507fb6f618	Voyager	34.0817874450568112	-118.461123115242643
18622	2020-04-05 20:11:00	2020-04-05	Nichelle Runte PhD	nichelle.runte.phd@geemail.com	San Francisco	California	3096722197984675208	d99f1b668d3a982c5170f52585845eef	Mastercard	37.8267309709324309	-122.43025277596729
18623	2020-04-05 20:17:55	2020-04-05	Dr. Jonathon Ziemann IV	dr.jonathon.ziemann.iv@geemail.com	North Las Vegas	Nevada	869985865405617923	5036c81dd1accdc5db2fd729b489d0fc	JCB 15 digit	36.2444580115068717	-115.129411952685203
18624	2020-04-05 20:28:47	2020-04-05	Doris Bauch	doris.bauch@geemail.com	San Francisco	California	3029135939667023	248a0dac590cfe5ff3e6137a3569c645	American Express	37.759795564444758	-122.427165813118449
18625	2020-04-05 20:53:21	2020-04-05	Dario Pfannerstill	dario.pfannerstill@woohoo.com	Los Angeles	California	4093828290439928	b359a065d79081e83482adb0b2efed5c	JCB 16 digit	34.0704347510222334	-118.414768337131662
18626	2020-04-05 20:57:40	2020-04-05	Alexina Blick	alexina.blick@warmmail.com	Overland Park	Kansas	3744777976953555	91321adc6040fc62b11b730b69254ab1	VISA 16 digit	38.9668242677450181	-94.6335925834294471
18627	2020-04-05 21:00:39	2020-04-05	Mrs. Isis Sawayn DVM	mrs.isis.sawayn.dvm@geemail.com	Santa Ana	California	3707275870141091	fa364c1c85de432b0cdff6696747bd91	American Express	33.6843866381432875	-117.869327741015695
18628	2020-04-05 21:03:16	2020-04-05	Patrica Conn	patrica.conn@woohoo.com	Columbia	Missouri	4317686688504772	f2daf06a9ccd7b7dae063e5188109357	JCB 16 digit	39.0050372077964838	-92.3134102798585872
18629	2020-04-05 21:16:59	2020-04-05	Xander Gulgowski V	xander.gulgowski.v@geemail.com	Grand Prairie	Texas	4340513271480734	d3623e095f40ea42f57975b3a009a27e	JCB 15 digit	32.7531777098827064	-97.0464061439841998
18630	2020-04-05 21:20:21	2020-04-05	Daijah DuBuque	daijah.dubuque@geemail.com	Denver	Colorado	3049320049959540	e305fe70030e332b161eac45b74f30af	Mastercard	39.8545082841120646	-104.824480617769439
18631	2020-04-05 21:37:55	2020-04-05	Marty Raynor	marty.raynor@warmmail.com	Houston	Texas	4544289097363081	90ae17239a8f54abe1c946463aa08b93	Voyager	29.7818931626234189	-95.4250796196531468
18632	2020-04-05 21:54:55	2020-04-05	Abbigail Schiller	abbigail.schiller@geemail.com	Madison	Wisconsin	869983194335926102	11e14788cd1b2e71a47a1cf9c21ad2cb	Mastercard	43.0817618742093487	-89.4252971607610618
18633	2020-04-05 22:11:27	2020-04-05	Sanders Lemke-Davis	sanders.lemke.davis@geemail.com	San Jose	California	6011105411763855163	2a024a52cb9a1b6362327af41cfb1152	Maestro	37.2808166149824842	-121.75443242841736
18634	2020-04-05 22:16:21	2020-04-05	Hildegarde Dach	hildegarde.dach@geemail.com	Baltimore	Maryland	53851624766119157	b79aeb14cfe130ad913f53121fe5659d	VISA 16 digit	39.3480298949405523	-76.6656412519998867
18635	2020-04-05 22:25:27	2020-04-05	Saige Considine	saige.considine@geemail.com	San Jose	California	3051100990207604	8ee3523c0f1f74a7bfe9207b68d9b580	Discover	37.3236358164630815	-121.868546665062752
18636	2020-04-05 22:32:11	2020-04-05	Silver Buckridge	silver.buckridge@geemail.com	Richardson	Texas	3528241197881133535	2dfde2978fda3846e9d67eeca724120a	VISA 13 digit	32.9991985959701211	-96.7867671746056573
18637	2020-04-05 22:38:01	2020-04-05	Salina Lebsack	salina.lebsack@warmmail.com	Wichita Falls	Texas	3755228644099369	519d5dc64418c5d3f0d1eba9f3cba1eb	VISA 16 digit	33.829903929979352	-98.4672802918512247
18638	2020-04-05 22:45:50	2020-04-05	Kourtney Bailey DVM	kourtney.bailey.dvm@geemail.com	Santa Clarita	California	6011643461783593525	af97b042a7d92d428f5096db95ee9902	Discover	34.4044552561566235	-118.59410876865573
18639	2020-04-05 22:56:17	2020-04-05	Geneva Reynolds	geneva.reynolds@geemail.com	Tyler	Texas	51650932889198492	97560ea47cc66a3ebbfb2b0ebaf724f7	JCB 16 digit	32.2724339173689501	-95.3641739873323502
18640	2020-04-05 23:00:59	2020-04-05	Fred Jacobson	fred.jacobson@geemail.com	Houston	Texas	4699110258794	9ec1e9e3e7a7aa9b45ceaa0d87a175e0	VISA 16 digit	29.7143660497464239	-95.3112167909756351
18641	2020-04-05 23:04:18	2020-04-05	Jordan Hintz	jordan.hintz@geemail.com	Corpus Christi	Texas	3055346684624747	cd0b01a57684258c8f3fbf8866c4ad02	Mastercard	27.8360675896454595	-97.1149718738455334
18642	2020-04-05 23:09:58	2020-04-05	Giovanny Stokes	giovanny.stokes@geemail.com	New York	New York	6011436543267837386	4cab8c7084aa3c96b2a2f99618f4f74b	VISA 16 digit	40.6512773214131613	-73.9505498391937408
18643	2020-04-05 23:35:51	2020-04-05	Josette Schmeler	josette.schmeler@warmmail.com	Berkeley	California	869937603090830249	77d612c6b6272e35b67123085b1d581b	Mastercard	37.8586388273150973	-122.276666142113129
18644	2020-04-05 23:46:57	2020-04-05	Miss Cindy Moen PhD	miss.cindy.moen.phd@geemail.com	Aurora	Colorado	4695718279455	0222be0fb63fab510802236bc2e2b5c0	Discover	39.7218211982510994	-104.763039394619696
18645	2020-04-05 23:51:02	2020-04-05	Dr. Nola Crona DDS	dr.nola.crona.dds@geemail.com	Cleveland	Ohio	4394247810066895	e1f2acc542bbe9d21c7204c6fc1a93e4	Maestro	41.4200773261804116	-81.5896279949933358
18646	2020-04-06 00:14:36	2020-04-06	Averi Ledner	averi.ledner@geemail.com	San Francisco	California	3096577006218577740	ea753496e95f4cbd36edac3f0cc21e01	Maestro	37.7776178923196326	-122.418618150134549
18647	2020-04-06 00:18:20	2020-04-06	Ashleigh Dietrich	ashleigh.dietrich@geemail.com	Peoria	Arizona	3710067876326205	4407da0fc18148bfadf8353f66d2ce55	American Express	33.8689391970437015	-112.277074195437137
18648	2020-04-06 01:17:03	2020-04-06	Magdalene Muller	magdalene.muller@geemail.com	Portland	Oregon	3158339424293312777	0dfbee055f6370649c340d625ef6dde7	Discover	45.4962493054457013	-122.737894925940793
18649	2020-04-06 01:30:53	2020-04-06	Judy Welch	judy.welch@geemail.com	Chattanooga	Tennessee	869908045889050586	f0dcd770650d2974313d23f54cec47af	Diners Club / Carte Blanche	35.1002842550948273	-85.1937863720409609
18650	2020-04-06 02:15:15	2020-04-06	Tim Auer	tim.auer@geemail.com	Columbus	Ohio	869912443648729653	8d499eebeeee771eae75f09e1ffc6671	Mastercard	39.9132592855066051	-83.0790303911317238
18651	2020-04-06 02:23:22	2020-04-06	Ms. Verla Roob PhD	ms.verla.roob.phd@woohoo.com	Washington	District of Columbia	869916920995207223	877c0061be22920ae953937cdabeed33	Mastercard	38.8403292177975175	-77.0143870247740381
18652	2020-04-06 02:24:31	2020-04-06	Lashanda Russel	lashanda.russel@warmmail.com	Berkeley	California	51580596524624561	66ff94e89bd5bf526fb14f9138c26d3a	VISA 16 digit	37.8883625867313896	-122.275730183365894
18653	2020-04-06 02:30:15	2020-04-06	Jeramie Pouros-Lemke	jeramie.pouros.lemke@geemail.com	New York	New York	4399622702807561	200407e21744957af8176c01e77d6d77	JCB 16 digit	40.6926174173820741	-74.0191149589966955
18654	2020-04-06 02:37:26	2020-04-06	Mahala Koepp	mahala.koepp@geemail.com	Los Angeles	California	4289841626410517	7949331c9e772e18df03138a65f35b58	Discover	34.1119120666157443	-118.384468131418515
18655	2020-04-06 02:37:46	2020-04-06	Katharina Muller	katharina.muller@warmmail.com	Los Angeles	California	3467525581554421	8ff30e3d1c7fdf281d3bcc699349924c	Discover	34.1100106558628369	-118.318811273108423
18656	2020-04-06 02:43:48	2020-04-06	Albin Stamm III	albin.stamm.iii@geemail.com	North Las Vegas	Nevada	3088998485427283483	65a37e0fa5ba5a7ed120ef2fcdf7ebf3	JCB 15 digit	36.3437357786733628	-115.189028956902774
18657	2020-04-06 02:50:55	2020-04-06	Laurence Mertz	laurence.mertz@geemail.com	Houston	Texas	869960717563740931	9c202dd472ddf2faa995a654f4b3ac6c	VISA 16 digit	29.8269293757233775	-95.4885055240724228
18658	2020-04-06 03:03:06	2020-04-06	Kasey Donnelly	kasey.donnelly@geemail.com	Pomona	California	3158160913888814902	1849bdad905db2e353948680bdf36196	Mastercard	34.0489149312991657	-117.829574086979406
18659	2020-04-06 03:08:27	2020-04-06	Ms. Shaquita Quitzon MD	ms.shaquita.quitzon.md@geemail.com	Spokane	Washington	4817579907429332	c4f5ca13c788e0c1efee5c2bbf913c6e	Maestro	47.6483286862034348	-117.366486670206484
18660	2020-04-06 03:12:01	2020-04-06	Dr. Demetric Von	dr.demetric.von@geemail.com	Berkeley	California	4227710290078022	e18d75a0763e0cba26d152cab2776b0c	Discover	37.8647374013507587	-122.304758454512907
18661	2020-04-06 03:32:52	2020-04-06	China Mueller	china.mueller@geemail.com	Chula Vista	California	6011001677947590877	f8232855e229693628a384ce00efe895	VISA 16 digit	32.6661911497589159	-117.0474221581824
18662	2020-04-06 03:37:20	2020-04-06	Miss Shenna Gerlach MD	miss.shenna.gerlach.md@geemail.com	Concord	California	52114009670776321	9543b958924e7e9ef434324d917e70fe	American Express	37.9754317579258256	-121.983342933392521
18663	2020-04-06 04:08:42	2020-04-06	Wade Bernhard DVM	wade.bernhard.dvm@geemail.com	Fremont	California	53425871569396014	40a0466216e45dd6b2877bf4c6a79565	American Express	37.4149321146942668	-121.984623929950217
18664	2020-04-06 04:26:33	2020-04-06	Dr. Ethen Friesen	dr.ethen.friesen@geemail.com	Oakland	California	676209994290378	cf5ef36070bb6469e841a49cde13cada	JCB 15 digit	37.7891549526921793	-122.276676741539376
18665	2020-04-06 04:31:36	2020-04-06	Mr. Derwin Klocko I	mr.derwin.klocko.i@geemail.com	Los Angeles	California	6011066843484314954	05f467e1a6be1a0b4536cc58cce39d22	Discover	34.0560369304712864	-118.473717577428744
18666	2020-04-06 04:38:23	2020-04-06	Ms. Terrie Heathcote DDS	ms.terrie.heathcote.dds@woohoo.com	Thornton	Colorado	210011632407677522	4329467760c96890840cb6608b218ff6	Voyager	39.8211387267202142	-105.010362149744481
18667	2020-04-06 04:40:30	2020-04-06	Darcy Robel II	darcy.robel.ii@geemail.com	New York	New York	4268695671753	7d79ab01dd40dfb44d39e3f02108469e	VISA 13 digit	40.6323041913788785	-74.0075183066900735
18668	2020-04-06 05:12:24	2020-04-06	Beatrix Osinski	beatrix.osinski@woohoo.com	Allentown	Pennsylvania	51203355770265455	7fb8084478d6d9e3b5a443b1300bf716	Discover	40.6791963603127797	-75.5293394942317065
18669	2020-04-06 05:26:53	2020-04-06	Mont Ruecker	mont.ruecker@geemail.com	New York	New York	4901903663848781	4d8db4ebff9988acbdae773e6f32b1bb	Discover	40.7588082403168102	-73.9517888198502362
18670	2020-04-06 05:30:18	2020-04-06	Rosalinda Johns	rosalinda.johns@geemail.com	Houston	Texas	3112036720092376335	f57ec1d27e820354c0b7660ccc2e8f18	JCB 16 digit	29.7688217352688298	-95.3433142128415483
18671	2020-04-06 05:31:34	2020-04-06	Mr. Elwin Kirlin	mr.elwin.kirlin@geemail.com	North Charleston	South Carolina	53813584089086607	397cd5302417b48f0948eb7ec82b2a52	JCB 15 digit	32.8600831546515195	-80.0952681940607647
18672	2020-04-06 05:54:34	2020-04-06	Wynona Hickle PhD	wynona.hickle.phd@geemail.com	Escondido	California	210041582945374872	208e446928f752fd42ad6a3a691dd60c	VISA 16 digit	33.1754276139423254	-117.142637737771494
18673	2020-04-06 05:59:06	2020-04-06	Miss Crysta Jerde	miss.crysta.jerde@woohoo.com	Boston	Massachusetts	4467873170491258	b32f1e7d5cf819ad3d1314bc876b31e8	Mastercard	42.3217857255768024	-71.034149690759179
18674	2020-04-06 05:59:15	2020-04-06	Harmony Stokes	harmony.stokes@geemail.com	Oakland	California	3337480857085917971	a08835f7c9ba80bd9ae101a23068f192	JCB 16 digit	37.8298519298994762	-122.282595318013392
18675	2020-04-06 06:16:31	2020-04-06	Nikhil Hessel	nikhil.hessel@geemail.com	Sacramento	California	630446555157976	3fd17bc43067f50cf91e0dfe45e95697	Discover	38.6269122126776736	-121.483423964843524
18676	2020-04-06 06:20:49	2020-04-06	Christen Gutmann-Welch	christen.gutmann.welch@geemail.com	Chula Vista	California	3337635655738481344	4ff7e17988ef6b9f11503b25706be700	Diners Club / Carte Blanche	32.53023435517661	-117.000600791745626
18677	2020-04-06 06:22:56	2020-04-06	Benito Deckow	benito.deckow@geemail.com	Victorville	California	4802662638318383	653cf271cdfa8e4b0ef8c74271bd13ac	Voyager	34.6058907347496643	-117.452710609665516
18678	2020-04-06 06:50:14	2020-04-06	Leontine Lemke	leontine.lemke@geemail.com	El Paso	Texas	180088388679613087	d27cdc2e18106bd11ffe95485764aa15	VISA 16 digit	31.8176919149994859	-106.343697311215109
18679	2020-04-06 06:56:32	2020-04-06	Evon Kunde	evon.kunde@warmmail.com	San Francisco	California	4591565469929928	bc21c399da3cbd490ca49b6c08575415	Maestro	37.7859156432787486	-122.388650493805159
18680	2020-04-06 06:58:38	2020-04-06	Armin Heathcote	armin.heathcote@woohoo.com	Norman	Oklahoma	4138847230570169	75b44413fde5e41f6c0532a2fad84ceb	JCB 16 digit	35.1789448777254705	-97.3526703388683501
18681	2020-04-06 06:59:36	2020-04-06	Janelle Friesen-Waelchi	janelle.friesen.waelchi@warmmail.com	San Antonio	Texas	6011183175007023095	47f9a9c3d806404621c3dda147c2137c	JCB 15 digit	29.3931190089859058	-98.6087485523264746
18682	2020-04-06 07:06:06	2020-04-06	Claiborne Pollich	claiborne.pollich@warmmail.com	Boston	Massachusetts	210090879636240440	b03c273ae4d490daaea134fd32b9af40	Discover	42.2452700301706798	-70.9957732974037583
18683	2020-04-06 07:07:44	2020-04-06	Mr. Tate Leffler II	mr.tate.leffler.ii@geemail.com	Oklahoma City	Oklahoma	6011066169894325939	341c74403d9af3d8552b753c41b6520c	Mastercard	35.5340613489881179	-97.5053888472158405
18684	2020-04-06 07:15:22	2020-04-06	Reginal Braun	reginal.braun@geemail.com	Columbus	Georgia	51603864292606324	d20910db93e45245638ddac64cd20f8d	VISA 16 digit	32.5371780561793571	-84.8813420925453244
18685	2020-04-06 07:18:50	2020-04-06	Montel Donnelly	montel.donnelly@woohoo.com	Oklahoma City	Oklahoma	3026229725852940	625e271876575aa2eb4e63d0a65b7e42	VISA 16 digit	35.3855017610270579	-97.6065292576223555
18686	2020-04-06 07:19:56	2020-04-06	Emely Zemlak-Hagenes	emely.zemlak.hagenes@geemail.com	Houston	Texas	52451639150522703	c296bea6cc0f1c0d97262ced25c85b41	JCB 16 digit	29.8615566284473992	-95.4760921070832751
18687	2020-04-06 07:21:55	2020-04-06	Polly Kovacek	polly.kovacek@geemail.com	San Francisco	California	3112067408708025783	f85b780a61482a3c8655ecf418df3336	VISA 16 digit	37.7142118048943829	-122.389348861207651
18688	2020-04-06 07:22:12	2020-04-06	Mr. Dorr Erdman I	mr.dorr.erdman.i@geemail.com	Jacksonville	Florida	4906665603625	676b97fbb8196700e53b408be0bd454e	Discover	30.2895377443224199	-81.5869848446533155
18689	2020-04-06 07:24:00	2020-04-06	Demond Heller	demond.heller@geemail.com	New York	New York	4935375918794682	680eeb0ff8e4eeaa69583ef7ba6a3cd2	Mastercard	40.7545534359514718	-74.0089756389509859
18690	2020-04-06 07:25:29	2020-04-06	Yoselin Conn	yoselin.conn@warmmail.com	Albuquerque	New Mexico	6011300622509297964	465a85ac7abf9da09de9d31c87c174e1	JCB 16 digit	35.1293747891806092	-106.733794466040663
18691	2020-04-06 07:31:50	2020-04-06	Mr. Ewing Durgan	mr.ewing.durgan@geemail.com	Washington	District of Columbia	55874587989188585	b74055f856404f00bacb0c8d603da23c	JCB 15 digit	38.8631671236161154	-77.0691802153576191
18692	2020-04-06 07:54:17	2020-04-06	Irl Braun	irl.braun@geemail.com	Tucson	Arizona	4603478897392352	c21a26a4de0630d2a4d091379e6bf7e3	VISA 13 digit	32.0573362604755943	-110.874494270909949
18693	2020-04-06 08:09:42	2020-04-06	Peter Windler	peter.windler@geemail.com	Cincinnati	Ohio	3004913684033244	30256db00839bd5f5597a39fee2e57e3	Mastercard	39.1621875491689906	-84.5834422970928159
18694	2020-04-06 08:24:22	2020-04-06	Mrs. Vela Yost	mrs.vela.yost@woohoo.com	Bridgeport	Connecticut	3044869709216901	35530785744422073264215f6f3da372	JCB 16 digit	41.2357230912126553	-73.1680611466888422
18695	2020-04-06 08:26:37	2020-04-06	Dolly Sipes	dolly.sipes@geemail.com	New York	New York	869929892767146266	ccac2cc319ac6394584fec6416ec1927	VISA 16 digit	40.7012000063657737	-73.9525739534653752
18696	2020-04-06 08:27:00	2020-04-06	Levar Prohaska	levar.prohaska@geemail.com	North Las Vegas	Nevada	55236195497448930	fdb18482a5e41b47bdbbedf803d358d4	Voyager	36.2409546230144812	-115.162858057602875
18697	2020-04-06 08:38:02	2020-04-06	Loretta Fadel-Kihn	loretta.fadel.kihn@geemail.com	Richmond	Virginia	6011589110330506458	6845fac78f46a638de9f2484f6cea5ac	Diners Club / Carte Blanche	37.5086102900780745	-77.3835164317619046
18698	2020-04-06 08:44:07	2020-04-06	Marsha Botsford	marsha.botsford@woohoo.com	Dallas	Texas	3088841483860582403	1e4c493661d334f04b768a08c038fb41	Mastercard	32.8731369767144344	-96.7885034254249064
18699	2020-04-06 08:44:11	2020-04-06	Miley Romaguera	miley.romaguera@geemail.com	San Antonio	Texas	55665197741692420	67120c7f672a622b0d10fb43b10b8914	JCB 16 digit	29.5212156385719773	-98.4268562021967028
18700	2020-04-06 08:54:40	2020-04-06	Federico Paucek	federico.paucek@geemail.com	Vancouver	Washington	54667856829307759	76b3442719201e89b9de36d78891d6bf	JCB 16 digit	45.5870962325554387	-122.682954954595118
18701	2020-04-06 09:02:12	2020-04-06	Adrien Heidenreich	adrien.heidenreich@geemail.com	Garland	Texas	3034727901543169	831fda25b58d65218bb8098761709698	Discover	32.9728059820134192	-96.7041007788080833
18702	2020-04-06 09:06:11	2020-04-06	Hollie Stracke	hollie.stracke@woohoo.com	Ventura	California	630409177030922	cd8e36c27f105a37fac3a03013ebf34c	Discover	34.327295922271162	-119.218874334460864
18703	2020-04-06 09:11:53	2020-04-06	Luciana Kshlerin	luciana.kshlerin@geemail.com	San Francisco	California	4169082650824	53d38ca39f75463491199023f518eb59	American Express	37.7700492027071135	-122.427543339031686
18704	2020-04-06 09:29:11	2020-04-06	Orren Kunze-Kohler	orren.kunze.kohler@woohoo.com	San Francisco	California	4722251428842	42f49e3f153826eec370f5dfe1ac70cc	Maestro	37.7696449070875602	-122.43802293926413
18705	2020-04-06 09:35:58	2020-04-06	Chantelle Marks	chantelle.marks@warmmail.com	Houston	Texas	3096275077593067503	8d585be820575927625cae57155479cd	Mastercard	29.8557663858480744	-95.3256823879215887
18706	2020-04-06 09:40:18	2020-04-06	Dr. Fenton Bode DDS	dr.fenton.bode.dds@geemail.com	New York	New York	4570138751513399	d60318fc72112ddba1d68020dd0b31db	JCB 16 digit	40.7066525738444156	-73.9596957478567987
18707	2020-04-06 10:14:24	2020-04-06	Breana Mohr	breana.mohr@warmmail.com	Philadelphia	Pennsylvania	4248824183284	11f248cf8594ceef31e59eaf8e5d6ea2	JCB 16 digit	39.9942186799790704	-75.1681121210467182
18708	2020-04-06 10:17:09	2020-04-06	Leota Schimmel	leota.schimmel@geemail.com	Baton Rouge	Louisiana	3434434319878410	1d3d4b00efe10cc13d2206b3b0e50677	Mastercard	30.4310096196576936	-91.0469478166304498
18709	2020-04-06 10:22:58	2020-04-06	Park Sawayn	park.sawayn@geemail.com	Detroit	Michigan	4241814900013445	288e803900e3921fbd32c86d3c5e38a0	VISA 16 digit	42.4457198430709539	-83.1811701236411949
18710	2020-04-06 10:24:34	2020-04-06	Mrs. Biddie Lowe	mrs.biddie.lowe@warmmail.com	Los Angeles	California	3096209414539047672	ab81ff4d23e178c2777752c6ad38b5d5	JCB 16 digit	34.0086905341461261	-118.329913302323959
18711	2020-04-06 10:28:13	2020-04-06	Mrs. Carri Hansen	mrs.carri.hansen@geemail.com	Corpus Christi	Texas	3528691287369920027	0e8aa05c1fcc677a6651407832d8bced	VISA 16 digit	27.7232219113904996	-97.2672896372914266
18712	2020-04-06 10:34:36	2020-04-06	Dr. Sheryl Armstrong DVM	dr.sheryl.armstrong.dvm@geemail.com	New York	New York	4602981350117456	e71544b21581b91739f51a63d0d2ee46	American Express	40.6765280227865986	-73.9417031158123166
18713	2020-04-06 11:02:30	2020-04-06	Coralie Kertzmann-Gislason	coralie.kertzmann.gislason@warmmail.com	New York	New York	676118696184029	1f2e5d2b250e382b6120877bc5427bde	JCB 16 digit	40.619804850429297	-74.0339293251175405
18714	2020-04-06 11:05:29	2020-04-06	Rickey Feil	rickey.feil@geemail.com	Oakland	California	4776709774541054	9a1fab4f420166393311a6f8af57ea57	American Express	37.8114492518957377	-122.274282482446452
18715	2020-04-06 11:08:49	2020-04-06	Albertine Koss	albertine.koss@geemail.com	Houston	Texas	6011236672363788904	284d4ab07321143465a88e099121f397	VISA 16 digit	29.6876340017732225	-95.4417679150138127
18716	2020-04-06 11:26:46	2020-04-06	Barbie O'Reilly DDS	barbie.o'reilly.dds@warmmail.com	West Valley City	Utah	3782693893297054	e609e979c8c7a1e0e9127804897cb941	American Express	40.6141040538661144	-112.023354839555168
18717	2020-04-06 11:48:30	2020-04-06	Jacoby Corkery	jacoby.corkery@geemail.com	Peoria	Arizona	3004959499480435	86ee41555c01314a41462824f57857fa	Voyager	33.6988931928098197	-112.353764745818452
18718	2020-04-06 11:57:01	2020-04-06	Maximo Gleason	maximo.gleason@warmmail.com	San Angelo	Texas	3057595399790320	7c83d494454b97503fd28b716fa76fb0	Maestro	31.3815912667814629	-100.435814000397926
18719	2020-04-06 12:23:05	2020-04-06	Walker Hirthe	walker.hirthe@woohoo.com	Corpus Christi	Texas	52165725490190074	52d26f3ae53d22597f67b46338e4a5e1	Mastercard	27.7532766291342696	-97.198147903365637
18720	2020-04-06 12:55:31	2020-04-06	Ms. Consuelo Blanda DVM	ms.consuelo.blanda.dvm@woohoo.com	Jurupa Valley	California	3464017467054125	eac2ca99939a7b62f9677b654b91bcb4	JCB 16 digit	33.9426220580864708	-117.484144485930358
18721	2020-04-06 12:56:43	2020-04-06	Loney Green	loney.green@geemail.com	Toledo	Ohio	3023839513809234	ee324f08b631e59c2381667f7f2d24fd	Diners Club / Carte Blanche	41.6449009144384377	-83.5511848224658564
18722	2020-04-06 12:59:00	2020-04-06	Dr. Jaxen Considine Jr.	dr.jaxen.considine.jr.@geemail.com	Tuscaloosa	Alabama	3337526921916646922	235222dbfad9779264566a43b0adba86	JCB 15 digit	33.1947640243507891	-87.5350037591628762
18723	2020-04-06 13:12:27	2020-04-06	Delma Block	delma.block@geemail.com	Berkeley	California	3018528783966445	3695d3866d1109832c1eff482c509c12	JCB 16 digit	37.9165710625855041	-122.262660180425513
18724	2020-04-06 13:48:32	2020-04-06	Mr. Horace Toy	mr.horace.toy@woohoo.com	Chandler	Arizona	53840431899338629	3ca438e004d5b66bf4b2b693dee0c58d	VISA 13 digit	33.2993166355039918	-111.92355935339593
18725	2020-04-06 13:51:18	2020-04-06	Kailyn Thiel	kailyn.thiel@geemail.com	New York	New York	4127744814388667	0354ba8be57781a749643837482b8d98	VISA 16 digit	40.6380870529673999	-73.8974067143060296
18726	2020-04-06 13:53:10	2020-04-06	Melba Labadie DVM	melba.labadie.dvm@geemail.com	Memphis	Tennessee	869986895613696442	16152c23b4ca332cd162c0d552f6a533	VISA 16 digit	35.1950830685973202	-90.0172945371620443
18727	2020-04-06 13:53:30	2020-04-06	Crissy Dicki	crissy.dicki@geemail.com	Miami Gardens	Florida	3096876003594964657	4690bbc808c6bf94540d95239f140a91	JCB 16 digit	25.931274968798828	-80.2087109943632015
18728	2020-04-06 13:57:18	2020-04-06	Miss Imo Jerde DVM	miss.imo.jerde.dvm@geemail.com	Orange	California	4097490694742666	d9344bd9874cc49471fffeaad01d2e53	JCB 15 digit	33.6926843248661569	-117.821275115396077
18729	2020-04-06 14:02:00	2020-04-06	Johnie Prosacco I	johnie.prosacco.i@geemail.com	San Francisco	California	3423117170964238	508905a16ace2cf8935fb1f7f57f50f9	VISA 13 digit	37.7763975473967264	-122.455932433142181
18730	2020-04-06 14:26:18	2020-04-06	Mathews Nitzsche MD	mathews.nitzsche.md@geemail.com	Simi Valley	California	4959021197325878	6970aac2526c1eb6875d47e48ad31120	Voyager	34.2702752150833589	-118.68167527668551
18731	2020-04-06 14:48:46	2020-04-06	Katharyn Howell-Macejkovic	katharyn.howell.macejkovic@geemail.com	Alexandria	Virginia	52565464365079412	668da4915bbe63cb4390511c678b568c	Diners Club / Carte Blanche	38.725780743325501	-77.1317698518265047
18732	2020-04-06 15:02:41	2020-04-06	Pierce Medhurst	pierce.medhurst@geemail.com	Los Angeles	California	869921704441647825	c0eb73699a8a6cd4735c89e3e89e7531	Mastercard	34.1105388257984075	-118.401223381375146
18733	2020-04-06 15:13:41	2020-04-06	Mrs. Lyda Medhurst	mrs.lyda.medhurst@geemail.com	Berkeley	California	4465990530664	5c5d3b8a48d964a4af44267f826df45c	Discover	37.8771532379497771	-122.269830809250251
18734	2020-04-06 15:20:35	2020-04-06	Gerardo Hirthe	gerardo.hirthe@geemail.com	Phoenix	Arizona	3004402251167650	e6ffeb3d521ddee6187101cd30e9cbdc	JCB 16 digit	33.6663425819415636	-112.057132193951318
18735	2020-04-06 15:23:00	2020-04-06	Dr. Dominic Will IV	dr.dominic.will.iv@warmmail.com	Baton Rouge	Louisiana	6011852129675610725	afce9a08de5c12cec70828c27489d9bd	VISA 16 digit	30.4930373374119412	-91.0754170053746464
18736	2020-04-06 15:27:34	2020-04-06	Docia Olson DDS	docia.olson.dds@geemail.com	Dallas	Texas	501851538252985	264659f8cf89e2ba0586ca09362108b9	VISA 16 digit	32.7819689271312242	-96.7335867145061457
18737	2020-04-06 16:01:21	2020-04-06	Mrs. Fleda Bartoletti PhD	mrs.fleda.bartoletti.phd@geemail.com	Houston	Texas	6011363223968927045	e2051075fb42b897e8da8a19a34ebc4a	Discover	29.8598504278887056	-95.3784226989854176
18738	2020-04-06 16:10:13	2020-04-06	Miss Darlyne Lowe	miss.darlyne.lowe@geemail.com	Houston	Texas	502018915738522	d98e64bbd05f6767c3adfda8d5827e22	VISA 16 digit	29.6906832921396955	-95.3201289667762808
18739	2020-04-06 16:10:26	2020-04-06	Eber Funk	eber.funk@geemail.com	Denver	Colorado	869942722765808109	b55c90fcaee5810abcad60164afe4872	Voyager	39.6642780432995394	-104.852384322021535
18740	2020-04-06 16:19:09	2020-04-06	Celestine O'Conner	celestine.o'conner@warmmail.com	Glendale	California	3528991754084795395	ecf2c8ab03ae21c7e17ecdecf41076af	Discover	34.2415337878033483	-118.335895783211299
18741	2020-04-06 16:26:46	2020-04-06	Pamella Jaskolski DVM	pamella.jaskolski.dvm@geemail.com	Waterbury	Connecticut	4136122289355975	b64271139882e68b62c27aaa18e3ba16	VISA 13 digit	41.520402611423286	-73.0325114029839568
18742	2020-04-06 16:44:58	2020-04-06	Rudolf Schneider	rudolf.schneider@woohoo.com	Boston	Massachusetts	54345196175997097	8c578509530fd24d8d49dc2b4924c5ef	JCB 15 digit	42.3793257775418439	-70.9772257631130543
18743	2020-04-06 16:52:12	2020-04-06	Jerrad Pouros	jerrad.pouros@geemail.com	San Francisco	California	4690082197288312	9533b8e33c1767758c50a020d257386d	VISA 16 digit	37.7734669494430477	-122.418955670368234
18744	2020-04-06 16:54:41	2020-04-06	Arvel Ullrich	arvel.ullrich@geemail.com	Berkeley	California	4955572321425319	37146b077ec42b7656cb459f939456cb	JCB 15 digit	37.8555848343787673	-122.275104359476657
18745	2020-04-06 17:10:26	2020-04-06	Carroll Rice	carroll.rice@geemail.com	New York	New York	3059810380427172	d464927ea0815dc09da63648e5ba6745	JCB 16 digit	40.6469668710362129	-74.0058326010487946
18746	2020-04-06 17:13:40	2020-04-06	Ewin Feeney	ewin.feeney@woohoo.com	San Francisco	California	6011904462376531454	aaa368371fe4f753c9f6142da72a4290	VISA 16 digit	37.7612699605214885	-122.419596782778484
18747	2020-04-06 17:19:54	2020-04-06	Hilah Abernathy	hilah.abernathy@woohoo.com	Dayton	Ohio	4754924776828	5d2f46d266575e877eaf9ed236d39c71	Diners Club / Carte Blanche	39.8650374707091615	-84.2848608880959489
18748	2020-04-06 17:33:42	2020-04-06	Haruko Jast	haruko.jast@geemail.com	New York	New York	3738280174488464	0da6b5a4a9b8444dc520e930434c44f4	JCB 16 digit	40.7357665014211108	-74.0232160519238533
18749	2020-04-06 17:50:55	2020-04-06	Inger DuBuque DVM	inger.dubuque.dvm@geemail.com	San Francisco	California	869900220629669247	961eecf6a459dd10bd5d29981bdd29ea	JCB 16 digit	37.8027965412809479	-122.407402470351016
18750	2020-04-06 17:53:43	2020-04-06	Dr. Nicolas Treutel	dr.nicolas.treutel@warmmail.com	Lexington	Kentucky	4596145981459	5ab919cc1bc2b41f741d2e2c965af129	Voyager	37.9644325934227567	-84.5466440523873928
18751	2020-04-06 17:56:38	2020-04-06	Davin Miller	davin.miller@woohoo.com	New York	New York	4717832723037339	5118c296e7d8a92268581794f8f1aef2	JCB 16 digit	40.6754795838370882	-73.9002382045973008
18752	2020-04-06 18:03:30	2020-04-06	Mr. Everet Marquardt	mr.everet.marquardt@warmmail.com	Topeka	Kansas	869936593538462732	fb0eb260761500a0c81275ddebe67772	Discover	39.0933257743649207	-95.6198449066549614
18753	2020-04-06 18:05:41	2020-04-06	Avis O'Conner	avis.o'conner@geemail.com	San Francisco	California	4842541414984000	8c92aff3f1323ab36a52ea16ec4cd923	Maestro	37.7836596533857474	-122.381904054284135
18754	2020-04-06 18:06:37	2020-04-06	Dirk Herman	dirk.herman@geemail.com	Tampa	Florida	3708530888152459	bb41f3f6d33365624154bfea1aecadf6	VISA 13 digit	27.8809780497219393	-82.451226536392042
18755	2020-04-06 18:08:29	2020-04-06	Roberto Waters	roberto.waters@geemail.com	Oakland	California	4742973183254714	d373c8e287501dc1e0981f43418df3a7	VISA 13 digit	37.7892969624725836	-122.286594458595275
18756	2020-04-06 18:13:54	2020-04-06	Taj Weimann-Reinger	taj.weimann.reinger@geemail.com	Charleston	South Carolina	503835593071059	5275475fb0bcea3ff938bc61614fbca7	JCB 16 digit	32.9000470214053991	-79.9611512557286801
18757	2020-04-06 18:13:59	2020-04-06	Lynsey Halvorson	lynsey.halvorson@geemail.com	Virginia Beach	Virginia	3112511306949373180	68d067947c982495b0247ac515806924	Diners Club / Carte Blanche	36.8295382728055145	-76.0512004862211626
18758	2020-04-06 18:40:27	2020-04-06	Nelly Walker	nelly.walker@warmmail.com	San Francisco	California	4369933747900683	0353fe816836786fe2d03f7f19017334	JCB 16 digit	37.8058366972952768	-122.435142607641197
18759	2020-04-06 18:48:59	2020-04-06	Dr. Dorathy Schaden MD	dr.dorathy.schaden.md@geemail.com	Minneapolis	Minnesota	3750230128257476	914e996ee1d4f9adc0a6ba5dec7a3b7e	VISA 16 digit	44.8865104571536122	-93.2843831839777522
18760	2020-04-06 18:51:51	2020-04-06	Mr. Roderick Kunde Sr.	mr.roderick.kunde.sr.@geemail.com	Omaha	Nebraska	3783626546414378	4762a46fb0d155a6db920557376a91e1	VISA 16 digit	41.3159690353699034	-96.0729540886472932
18761	2020-04-06 19:00:46	2020-04-06	Logan Lindgren	logan.lindgren@warmmail.com	San Francisco	California	869919499652636682	d62f4c1607a370c7db4419119553f26c	VISA 16 digit	37.7585522677304795	-122.439466594493865
18762	2020-04-06 19:25:37	2020-04-06	Johnna Dare	johnna.dare@geemail.com	Chicago	Illinois	4955798087309740	9cb6e0576e8f3ecdfaca6c2fe289b3f6	VISA 16 digit	41.9054362587466827	-87.7114072141267371
18763	2020-04-06 19:28:14	2020-04-06	Dinah Schoen	dinah.schoen@woohoo.com	Stockton	California	4355265632517389	50582f282b08ef3c9f9e4b37844510cd	VISA 16 digit	37.9383207821019042	-121.281222507366166
18764	2020-04-06 19:31:25	2020-04-06	Dyan Reichel	dyan.reichel@geemail.com	Los Angeles	California	3000432717785443	a9656eb161c73f0679e586d3b827dafe	VISA 13 digit	33.9237714170809781	-118.468017391068116
18765	2020-04-06 20:38:57	2020-04-06	Rosena Kuhic	rosena.kuhic@geemail.com	Los Angeles	California	3031470887051120	55020a23f0ae8f7f86446a61bc1452e5	JCB 15 digit	34.0281064395192985	-118.492480315034456
18766	2020-04-06 20:49:55	2020-04-06	Josef Bartell-Block	josef.bartell.block@geemail.com	Berkeley	California	180004457891052696	4b7ea0735e4cae72b5b6d6238192312d	JCB 16 digit	37.8901277039211806	-122.273410499828898
18767	2020-04-06 21:07:50	2020-04-06	Deion Pfannerstill	deion.pfannerstill@geemail.com	New York	New York	3012958743719467	506e8e8aab7d50cc84358dfcfc2cbb5d	American Express	40.6005727477129525	-74.0102708183124633
18768	2020-04-06 22:07:25	2020-04-06	Nathen Powlowski	nathen.powlowski@geemail.com	Bridgeport	Connecticut	4534560875730424	5224aa7753abd9c8b27e849b86d1ca0c	JCB 16 digit	41.2658683054778663	-73.1688140205472735
18769	2020-04-06 22:25:16	2020-04-06	Keena Reichert	keena.reichert@geemail.com	Omaha	Nebraska	4301569011662798	ab8a83226618dc016c09c10a8dab580a	Discover	41.3332649710267788	-96.0858530583441279
18770	2020-04-06 22:51:11	2020-04-06	Devante Yundt V	devante.yundt.v@warmmail.com	San Francisco	California	869938688386787095	b13198d00926cc0851e3aef89ba1e21e	VISA 16 digit	37.7571271132765176	-122.441937654150337
18771	2020-04-06 22:56:05	2020-04-06	Christa Erdman-Runolfsdottir	christa.erdman.runolfsdottir@geemail.com	Centennial	Colorado	3337990034674041679	89ddc8cc727a17bb32dee4afd9b0b997	American Express	39.617308052400503	-104.830732665013898
18772	2020-04-06 23:08:56	2020-04-06	Claribel Quigley-Gerhold	claribel.quigley.gerhold@warmmail.com	Kansas City	Kansas	51294876759166448	a630048865d794649307358cfc3313a8	Maestro	39.0409864772018054	-94.782048157503084
18773	2020-04-06 23:09:05	2020-04-06	Manila Dickens	manila.dickens@geemail.com	Toledo	Ohio	4929217336212483	89d615bc75ecb9e606046e2c6399e78b	Mastercard	41.5817043224055283	-83.6522294502105552
18774	2020-04-06 23:30:57	2020-04-06	Rock Greenholt-Padberg	rock.greenholt.padberg@geemail.com	New York	New York	180010791684849229	249e6ff2db47df79be1cf7125862b19f	VISA 16 digit	40.7301779905557595	-73.9023120066046744
18775	2020-04-06 23:39:19	2020-04-06	Chestina Sipes	chestina.sipes@warmmail.com	Provo	Utah	3421448599505092	a4d1bc2ef0a3bccf191246f19e4f2651	Maestro	40.2480430178597572	-111.636067232596872
18776	2020-04-06 23:53:56	2020-04-06	Cade Koss	cade.koss@woohoo.com	Boise	Idaho	4799298310076	91f98761f8caa931a6a763eb5bacda3d	Maestro	43.5056498733021328	-116.313231230453411
18777	2020-04-06 23:56:27	2020-04-06	Domenico Simonis-Ruecker	domenico.simonis.ruecker@geemail.com	Fort Worth	Texas	502065063712411	36c6fc99ff5e3a58cf70282a858ad41b	Maestro	32.7591659979019312	-97.2903675963923291
18778	2020-04-06 23:58:11	2020-04-06	Esther Ferry	esther.ferry@geemail.com	San Antonio	Texas	3000851151729460	46d1242491714b6d3ac34e75ab1d4408	Voyager	29.3974660062301894	-98.4571579458028054
18779	2020-04-07 00:02:28	2020-04-07	Leanne Gibson-Stehr	leanne.gibson.stehr@geemail.com	Oakland	California	3721658438604159	ccb74b4b7a0395c19eb685088006defc	VISA 16 digit	37.8202752581020576	-122.261257599065914
18780	2020-04-07 00:08:23	2020-04-07	Baylie Hagenes DVM	baylie.hagenes.dvm@warmmail.com	St. Louis	Missouri	6011834274593004610	4912c9cfcd564ab6040f8a7af397453b	Mastercard	38.6467132254194468	-90.1678487338595147
18781	2020-04-07 00:10:37	2020-04-07	Mrs. Cathryn Thiel	mrs.cathryn.thiel@geemail.com	Philadelphia	Pennsylvania	3528929952017205683	7eabe3030e5a690c66b87cd3d244c6dd	Discover	40.0612799494486325	-75.1609717850007115
18782	2020-04-07 00:23:54	2020-04-07	Simon Gerhold	simon.gerhold@geemail.com	New York	New York	3487372047174494	5d7c4ecf673ddca0075f2a68b2df9240	JCB 15 digit	40.6589057234339393	-74.013488890546185
18783	2020-04-07 00:28:06	2020-04-07	Miss Sarai Krajcik DVM	miss.sarai.krajcik.dvm@geemail.com	Tucson	Arizona	639029981563934	35f88f71d71ed7abcb19d23a2dfe5063	Discover	32.1772689781192724	-110.834541149925812
18784	2020-04-07 00:36:28	2020-04-07	Texie Sipes	texie.sipes@warmmail.com	Berkeley	California	210053282762058493	3cac4936be52f1186167267a5183306c	JCB 16 digit	37.925990905744861	-122.275467996775106
18785	2020-04-07 00:43:10	2020-04-07	Dr. Stone O'Hara	dr.stone.o'hara@woohoo.com	Frisco	Texas	4561099053341	740ca6cc9f239812f8a6f1914d437ee5	JCB 15 digit	33.1006264082618031	-96.7749924180772041
18786	2020-04-07 00:52:57	2020-04-07	Shelbi Veum	shelbi.veum@woohoo.com	Garden Grove	California	6011224186108674489	cc7e4ebce3d66eaf35dced4dcc1b012c	VISA 16 digit	33.7048059080086588	-117.927868357442321
18787	2020-04-07 01:13:55	2020-04-07	Amanda Smith-Keeling	amanda.smith.keeling@geemail.com	North Las Vegas	Nevada	4886858819461	7c262e7b3003f6af267b4315c013c6b8	Maestro	36.2284035599481271	-115.051761314574264
18788	2020-04-07 01:44:46	2020-04-07	Carnell Stokes	carnell.stokes@geemail.com	Las Cruces	New Mexico	561287281722246	34746bfe62e283dac728a8b6ed2a6dfa	American Express	32.3630530587896672	-106.842357066658138
18789	2020-04-07 02:09:23	2020-04-07	Lawrence Prohaska	lawrence.prohaska@geemail.com	San Francisco	California	869904860541850528	5e29e6327c0dc1bb06716e7e1a83e3aa	VISA 16 digit	37.7598255812266714	-122.418428872436323
18790	2020-04-07 02:22:03	2020-04-07	Tristen Ledner	tristen.ledner@geemail.com	San Francisco	California	4176954972848	0d1cf6fbf238995f04e072f3d9c1d5cf	JCB 16 digit	37.7748186832085011	-122.448996217062955
18791	2020-04-07 02:22:33	2020-04-07	Romeo Rau	romeo.rau@geemail.com	Pembroke Pines	Florida	4851195611088	9f197a4ec91e7f8dabeba2ac6810d602	Mastercard	26.1104889533519753	-80.3433929522890651
18792	2020-04-07 02:32:17	2020-04-07	Mr. Ivory Champlin Sr.	mr.ivory.champlin.sr.@woohoo.com	Dallas	Texas	3158056701448480992	c8ac542d3e3b6082fe850feaaabc4be1	Diners Club / Carte Blanche	32.8016683348726517	-96.7025646157059811
18793	2020-04-07 02:38:06	2020-04-07	Dr. Christian Willms	dr.christian.willms@geemail.com	Oakland	California	3158819653966588565	108118b34c1a9c7c527f523962a8316a	JCB 16 digit	37.7754350639984366	-122.267684003028975
18794	2020-04-07 02:53:30	2020-04-07	Dr. Coleman Denesik II	dr.coleman.denesik.ii@warmmail.com	Montgomery	Alabama	53339250544693370	fb179705543aca20e3c0e22e93c5270a	American Express	32.328468502306194	-86.3374149014394732
18795	2020-04-07 03:14:24	2020-04-07	Math Schmitt	math.schmitt@geemail.com	Kansas City	Missouri	3088303088457156742	2e241397e691e047cab393e149f3fc70	VISA 13 digit	39.0817524944268229	-94.4713667070716667
18796	2020-04-07 03:29:15	2020-04-07	Dr. Wayne Trantow	dr.wayne.trantow@geemail.com	Ontario	California	4023873729620925	751f88c7aad2219289b7300441046121	VISA 13 digit	34.0006627583555883	-117.609277282991272
18797	2020-04-07 03:46:11	2020-04-07	Maureen Price	maureen.price@geemail.com	Las Vegas	Nevada	6011904134213736659	61a73205c477d5f03b82aa346eec2da6	JCB 15 digit	36.3108443199757502	-115.239376283970103
18798	2020-04-07 03:58:11	2020-04-07	Ms. Oneida Heller MD	ms.oneida.heller.md@woohoo.com	Berkeley	California	4073851064507286	575f62b30d758afded8b1ad3eee2bd15	VISA 16 digit	37.8360762847532115	-122.248160865337496
18799	2020-04-07 04:50:25	2020-04-07	Kennedi Swaniawski PhD	kennedi.swaniawski.phd@geemail.com	Richmond	Virginia	3337227836202576892	bddc52c0c0b6a936e3dd8c1ac10dcce0	Voyager	37.567230772249026	-77.4457171655483592
18800	2020-04-07 04:53:37	2020-04-07	Manford Collier DDS	manford.collier.dds@geemail.com	Salt Lake City	Utah	54233753967957708	498a9adb3f30246144936569a66bebfa	Maestro	40.8589242616347974	-112.003626262530688
18801	2020-04-07 05:27:40	2020-04-07	Sylvan Kautzer	sylvan.kautzer@geemail.com	Elizabeth	New Jersey	4678304162558	791346d0199afb47feeaf31899a60224	Diners Club / Carte Blanche	40.5687406740743697	-74.1688544853068947
18802	2020-04-07 05:32:12	2020-04-07	Kelsie Ritchie MD	kelsie.ritchie.md@geemail.com	Costa Mesa	California	3528038440313924429	10ebaff2d46cc6ec46c023f8431e72ed	Maestro	33.5680101332735248	-117.988490644502647
18803	2020-04-07 05:32:52	2020-04-07	Leslie Huel	leslie.huel@warmmail.com	Omaha	Nebraska	53832825338430634	2e4426ea2de6f1a93072c41d2a926d33	Voyager	41.312972418186817	-95.9566485443267965
18804	2020-04-07 05:50:25	2020-04-07	Mrs. Hope Hilpert	mrs.hope.hilpert@geemail.com	Memphis	Tennessee	3096557475847690287	217675ba32176ef6fdd53a53351253d3	Mastercard	35.0209056193076123	-89.9501665277198015
18805	2020-04-07 06:23:26	2020-04-07	Ms. Ciera Gerlach MD	ms.ciera.gerlach.md@warmmail.com	Santa Clarita	California	869987123473538342	a9f5a0eec3870fada98d7dd4ccd5f8be	JCB 15 digit	34.3831065981388093	-118.566318861125779
18806	2020-04-07 06:28:45	2020-04-07	Denzel Kulas	denzel.kulas@woohoo.com	Ontario	California	3528607807804645237	8235d5c494a91837251ce90a5304e14c	Maestro	34.001966641252487	-117.645102308234954
18807	2020-04-07 06:50:04	2020-04-07	Isai Wilkinson	isai.wilkinson@geemail.com	Berkeley	California	3494287736642521	d49aed025751c1f97c5f94aec01f6642	Diners Club / Carte Blanche	37.8840511220507992	-122.259118692406929
18808	2020-04-07 07:16:33	2020-04-07	Mrs. Kinsley Abshire	mrs.kinsley.abshire@geemail.com	New York	New York	3088656706759661274	4fcded0377e1dbf000223d71566ac077	Maestro	40.6798817836437365	-73.8428692171245729
18809	2020-04-07 07:17:28	2020-04-07	Ola Weissnat	ola.weissnat@warmmail.com	New York	New York	4998939207424	b969ea4472b5d64416dfb69f8d4cfe0a	VISA 16 digit	40.7227882663942893	-73.9616990120977107
18810	2020-04-07 07:23:38	2020-04-07	Destiny Waelchi	destiny.waelchi@geemail.com	San Francisco	California	3475857065570882	5b2aa147077abee851a91e974b8276ce	VISA 16 digit	37.7642784023450986	-122.456615150024845
18811	2020-04-07 07:34:31	2020-04-07	Malissie Wehner	malissie.wehner@geemail.com	New Orleans	Louisiana	210043672007597623	448e61dbc232712f988b9a3164b84546	JCB 16 digit	30.0562033362701548	-89.8645053966697276
18812	2020-04-07 07:51:53	2020-04-07	Terese Corkery	terese.corkery@geemail.com	Hartford	Connecticut	3158441710654223917	38e0693a990e15a721e406ff3bbbb697	VISA 13 digit	41.7470190693639225	-72.7200181721135976
18813	2020-04-07 08:16:43	2020-04-07	Christion Swift	christion.swift@warmmail.com	Riverside	California	4239775898947	929cea22828f4af5eff31e56fea55105	Diners Club / Carte Blanche	33.9667049108952241	-117.368676673431693
18814	2020-04-07 08:28:51	2020-04-07	Brenton Bergnaum Sr.	brenton.bergnaum.sr.@geemail.com	Columbus	Ohio	675903115833596	9fc98ced3ead8ea01585a5fa59773580	Diners Club / Carte Blanche	40.031274217883869	-82.9748552615057804
18815	2020-04-07 08:35:44	2020-04-07	Sanai Brekke	sanai.brekke@geemail.com	Charlotte	North Carolina	6011547451704970941	5a93b56cf4b6e97313d818fda792d195	VISA 16 digit	35.2616670619018393	-80.818566847214484
18816	2020-04-07 08:41:43	2020-04-07	Tayshaun Dickinson-Hackett	tayshaun.dickinson.hackett@geemail.com	San Diego	California	6011121947421335213	f1e0a4e8a47ae5e6fcf32d16fbfeb648	Maestro	32.8585149963453418	-117.142611418049782
18817	2020-04-07 08:43:35	2020-04-07	Jaelyn Champlin-Thiel	jaelyn.champlin.thiel@geemail.com	New York	New York	3337944413113396786	d45e721f6840176870e438f6081de49e	Mastercard	40.6275234073624034	-73.8927551672689589
18818	2020-04-07 08:55:09	2020-04-07	Nichol Gislason	nichol.gislason@geemail.com	Long Beach	California	3096185976164170423	4391c1662f47d67875c7ce206b785447	Maestro	33.8084875694297224	-118.115505035284158
18819	2020-04-07 09:05:31	2020-04-07	Edie Kemmer	edie.kemmer@woohoo.com	Atlanta	Georgia	4739318304600	52c73184b6cd0f3c79af63f911d43608	Discover	33.7970040191706289	-84.4981151683766427
18820	2020-04-07 09:20:01	2020-04-07	Ancel Kuvalis	ancel.kuvalis@warmmail.com	New York	New York	3337506304283280050	330506e703e866eefe528d2005dcf610	Voyager	40.6737478753775363	-74.0327809660125524
18821	2020-04-07 09:33:29	2020-04-07	Marcela Jacobi	marcela.jacobi@geemail.com	Nashville	Tennessee	3337267311216452754	0938dd821a63372a455de92b3c522b4d	Discover	36.1888950965490181	-86.8600372229609548
18822	2020-04-07 09:49:29	2020-04-07	Miss Shaina Mante DDS	miss.shaina.mante.dds@geemail.com	Austin	Texas	3096849170178050619	b6a4a064e8fe9d783076ff0bdc4a73db	Discover	30.2866135801315295	-97.6773398889932878
18823	2020-04-07 09:50:55	2020-04-07	Ms. Marely Spinka	ms.marely.spinka@geemail.com	Brownsville	Texas	4456215491441492	1605f7c02c7d8c26764f452f3cb85549	VISA 13 digit	26.0314296812828623	-97.5164379977807414
18824	2020-04-07 10:14:36	2020-04-07	Dr. Whitley Thiel	dr.whitley.thiel@geemail.com	San Francisco	California	4405955474708555	24e7105860aedebaf7cb1bd407c781d0	Diners Club / Carte Blanche	37.8048507201560184	-122.455641680098054
18825	2020-04-07 10:27:05	2020-04-07	Silvio Hauck	silvio.hauck@warmmail.com	San Francisco	California	676329712290880	379e4d17fb3b159fcebd1815bfb8a41b	Mastercard	37.7867406441437836	-122.461985999400966
18826	2020-04-07 10:28:01	2020-04-07	Lassie Cremin	lassie.cremin@warmmail.com	Hillsboro	Oregon	4351930430537574	9d56294f9fd0428ea21a529350d5d4ac	VISA 16 digit	45.4720692510921509	-122.926977700569481
18827	2020-04-07 10:38:53	2020-04-07	Latifah Stiedemann	latifah.stiedemann@woohoo.com	Los Angeles	California	4721795703267545	664f1ce6f63d5857a9453673ab2dcec1	Discover	33.9593527732748512	-118.361637775459513
18828	2020-04-07 10:39:21	2020-04-07	Essie Harvey	essie.harvey@geemail.com	San Francisco	California	3056440822186443	cdf5c19da4bd933cf95f3d1fc00b8b2a	VISA 13 digit	37.8104616956866835	-122.416036828555548
18829	2020-04-07 10:41:16	2020-04-07	Mora Feil	mora.feil@geemail.com	Moreno Valley	California	6011561908576756717	2f81b6b70062bd1238819420a81b65ad	JCB 15 digit	33.9318698387119895	-117.23410941729955
18830	2020-04-07 10:42:59	2020-04-07	Brittany Ondricka-Macejkovic	brittany.ondricka.macejkovic@geemail.com	New Orleans	Louisiana	3096280966332254237	badc4e3a27e6df61c48c5a1cd9327eff	American Express	30.1481507023345685	-89.8361187675297259
18831	2020-04-07 10:47:33	2020-04-07	Bobby Brown	bobby.brown@geemail.com	Raleigh	North Carolina	3528999083301233952	621f780c55f21d166f4d1b71199f44b4	JCB 15 digit	35.9121986647270575	-78.5796786617890035
18832	2020-04-07 11:01:22	2020-04-07	Ely Nader	ely.nader@warmmail.com	Philadelphia	Pennsylvania	210046962777173086	7adaf80631d8b1ac4ffaa2bda484246f	Diners Club / Carte Blanche	39.9558512536302217	-75.0767154542163127
18833	2020-04-07 11:15:24	2020-04-07	Mrs. Gennie Braun DVM	mrs.gennie.braun.dvm@geemail.com	Henderson	Nevada	4402755943497266	b07e2f92b4d81ff51bd6eb9573515c4f	American Express	36.0309416237220219	-114.968297343809908
18834	2020-04-07 11:27:26	2020-04-07	Lyndia Kuvalis	lyndia.kuvalis@geemail.com	Reno	Nevada	51216881378471828	81c7c00816c8cd5c81748edb5c329a08	JCB 15 digit	39.5437178906597211	-119.758085669500389
18835	2020-04-07 11:33:48	2020-04-07	Sibyl Lang	sibyl.lang@warmmail.com	Vallejo	California	869990126082050141	7305bcecd24605b742e090d4b981e7c2	Mastercard	38.1131524419035799	-122.209784263871612
18836	2020-04-07 11:38:00	2020-04-07	Arturo Streich	arturo.streich@geemail.com	Riverside	California	3158223056624539188	59bbaf4dead2fc6c4e4014b132961c99	VISA 13 digit	33.9751072584133595	-117.318837859292316
18837	2020-04-07 11:41:22	2020-04-07	Mittie Heller-Kreiger	mittie.heller.kreiger@geemail.com	New Orleans	Louisiana	4146359294991620	b2b9ac5a137f6435dcdd0d60d4428a88	Maestro	29.9674828248579068	-89.8608193145394267
18838	2020-04-07 11:46:44	2020-04-07	Shaun Nienow	shaun.nienow@geemail.com	Houston	Texas	4868269095040988	8d1baebd4c80d9c8f8245c6a1fdec742	Voyager	29.8398228220254182	-95.477072244930639
18839	2020-04-07 11:58:19	2020-04-07	Rob Grant	rob.grant@geemail.com	San Francisco	California	3158538871151971285	fde2dc128d0628201161b50fe2ae521f	Voyager	37.781718494788386	-122.427621736069369
18840	2020-04-07 12:00:24	2020-04-07	Shatara Feil-Lebsack	shatara.feil.lebsack@warmmail.com	San Diego	California	6011396642444707062	9af3588580538ba611a8da4011e70aa8	Maestro	32.7480627373393602	-117.118345699543141
18841	2020-04-07 12:07:35	2020-04-07	Mr. Horatio Swift PhD	mr.horatio.swift.phd@geemail.com	Los Angeles	California	630421367177744	21da78dc2a4cca3b6a6351b1ddc3110c	Voyager	33.9929981663688991	-118.413638039863855
18842	2020-04-07 12:12:01	2020-04-07	Laurance Reichert	laurance.reichert@geemail.com	Fresno	California	6011389838126219256	a7a967c1fba989f02eff4bbd51bafd8c	Mastercard	36.7925738958515254	-119.750538467766347
18843	2020-04-07 12:16:37	2020-04-07	Chantal Senger	chantal.senger@geemail.com	San Francisco	California	869935384859671569	26728decee979c5e34bbce4bb707475a	JCB 16 digit	37.7623928561620801	-122.42756901389771
18844	2020-04-07 12:19:40	2020-04-07	Mrs. Bulah Kuhn PhD	mrs.bulah.kuhn.phd@geemail.com	El Paso	Texas	501841614217960	0faf3495b7e5abd612aafffbbd36dd3f	JCB 16 digit	31.9446516876403273	-106.500134906636561
18845	2020-04-07 12:21:02	2020-04-07	Marques McKenzie	marques.mckenzie@geemail.com	Lexington	Kentucky	4472501327562464	fccc57db9443a44f1429117dcd5c0e4f	JCB 16 digit	37.998552318463851	-84.5185595620322943
18846	2020-04-07 12:22:38	2020-04-07	Jarrad Pacocha-Torphy	jarrad.pacocha.torphy@woohoo.com	Los Angeles	California	4307908619168242	2fb1ea1de56cdb707a4fad3b98caf9f5	JCB 16 digit	33.9535131671331811	-118.415271960570664
18847	2020-04-07 13:05:17	2020-04-07	Dr. Shawn Sanford DDS	dr.shawn.sanford.dds@geemail.com	Lexington	Kentucky	3337199617801923758	881447a2ef27d17cff9b1690cb9c7318	VISA 16 digit	37.9874399057466547	-84.4215044231519016
18848	2020-04-07 13:39:12	2020-04-07	Mace Batz	mace.batz@geemail.com	Frisco	Texas	676325118336871	2bd9443c83f4f2d4a8f59d58e638656e	Mastercard	33.1664915997996914	-96.9173500205598657
18849	2020-04-07 13:39:52	2020-04-07	Carolynn Pouros	carolynn.pouros@geemail.com	Costa Mesa	California	4633186488529985	4b0475fe11de1a9f9819582a549567b5	Mastercard	33.6732829092551	-117.924016834409159
18850	2020-04-07 13:42:28	2020-04-07	Dr. Orris Emard	dr.orris.emard@woohoo.com	Omaha	Nebraska	4981943048639870	b587efc5d8af9138efbda62123c51ca0	Maestro	41.2211087316885596	-96.1410822194650763
18851	2020-04-07 13:47:51	2020-04-07	Keegan Durgan	keegan.durgan@woohoo.com	Amarillo	Texas	869950477372343110	6184f2b1c8920f7b989bba5e98755db4	VISA 16 digit	35.1605099452357734	-101.777271204893296
18852	2020-04-07 13:51:56	2020-04-07	Mr. Ephram Keebler	mr.ephram.keebler@geemail.com	New York	New York	4957596574757	148ced45829b36c2479f205338844320	American Express	40.7288920580167328	-73.8989274048607712
18853	2020-04-07 13:55:08	2020-04-07	Lovey Heaney-Walter	lovey.heaney.walter@geemail.com	Grand Rapids	Michigan	4765100000403	d1f37406e93c6ce2e5f0834ec93bcdaa	American Express	42.8877567993279527	-85.6857071563269983
18854	2020-04-07 13:58:37	2020-04-07	Gusta Hackett DDS	gusta.hackett.dds@geemail.com	Philadelphia	Pennsylvania	210049650506937445	2fc3a6fad29ebc03f0e0f88f93bdd1fa	JCB 16 digit	39.9318544291850159	-75.1563414498131834
18855	2020-04-07 14:16:45	2020-04-07	Kerry Windler V	kerry.windler.v@geemail.com	San Francisco	California	4189761403998	1597be85cb32c47229408e4ff6dec271	Voyager	37.7898053333999968	-122.399462942858591
18856	2020-04-07 14:18:51	2020-04-07	Leona Hoppe	leona.hoppe@geemail.com	San Francisco	California	3750800697726463	0a5805b2abf260f0c7ed2650ffa8de43	Discover	37.7829520907935361	-122.436513554080463
18857	2020-04-07 14:23:07	2020-04-07	Arman Hamill	arman.hamill@geemail.com	Los Angeles	California	51133207708361820	a83f728308effb2e97ee2312bae7d803	Diners Club / Carte Blanche	33.9980966733168799	-118.315039730583493
18858	2020-04-07 14:25:05	2020-04-07	Mack Rodriguez	mack.rodriguez@geemail.com	Fort Wayne	Indiana	6011674634127383314	1ca820a5e8780e6abed9d1aa77ee69ac	JCB 16 digit	41.1468474725976563	-85.0937655889648994
18859	2020-04-07 15:11:28	2020-04-07	Dr. Deangelo O'Hara DDS	dr.deangelo.o'hara.dds@geemail.com	New York	New York	3484883163141904	3aa64acd165a25da0d0a0deddcdeb280	JCB 16 digit	40.6448852804247309	-73.8871225643332963
18860	2020-04-07 15:11:49	2020-04-07	Marianna Mertz	marianna.mertz@geemail.com	Dallas	Texas	501869236425349	06b866f1237bec92b6995ffb22321036	VISA 16 digit	32.8604040370129056	-96.8449279778599674
18861	2020-04-07 16:09:34	2020-04-07	Cheryle Nicolas	cheryle.nicolas@warmmail.com	San Francisco	California	6011008415069969535	058668e2f8db54a7a50f26355133abbc	VISA 13 digit	37.7873162909693434	-122.47095306415531
18862	2020-04-07 16:13:52	2020-04-07	Ashlee West-Lemke	ashlee.west.lemke@woohoo.com	San Francisco	California	180069714687889091	b8b296a58baf3aea6c2843b2fd8aa62c	Voyager	37.7869008864404918	-122.415068895665215
18863	2020-04-07 16:29:33	2020-04-07	Tricia Howe	tricia.howe@geemail.com	Mesa	Arizona	3088740345649575614	88b6d776d770d002550c89f94ac2b32b	JCB 15 digit	33.3728613827522835	-111.72523291771077
18864	2020-04-07 16:33:02	2020-04-07	Omie Schuppe	omie.schuppe@geemail.com	Philadelphia	Pennsylvania	675980569407713	1c827b2b6ba512da765c4241d36233d0	American Express	40.0701746536377783	-75.0460059872262235
18865	2020-04-07 16:36:40	2020-04-07	Kizzy Ondricka	kizzy.ondricka@geemail.com	Kansas City	Missouri	4005644931982490	9250cfeca0b820961e3bd8288d79cef8	VISA 16 digit	39.1832773405429009	-94.6239640015401022
18866	2020-04-07 16:36:56	2020-04-07	Kandice Kling	kandice.kling@geemail.com	Columbus	Ohio	561256532047984	fc13a2f613a8e4e5bfc6698f6e464330	VISA 16 digit	39.9933365198828241	-82.9613726792626096
18867	2020-04-07 17:06:19	2020-04-07	Dosia Vandervort MD	dosia.vandervort.md@warmmail.com	Portland	Oregon	561273672939656	de76aad2feda528f65aba80ce492eb06	JCB 15 digit	45.5943053437750763	-122.69624236295931
18868	2020-04-07 17:40:26	2020-04-07	Zayden Gusikowski	zayden.gusikowski@geemail.com	San Francisco	California	3528620551842813356	37540bea8de7af52d6c66ca9cc2cef94	VISA 13 digit	37.7802642804645572	-122.464756603392559
18869	2020-04-07 17:53:34	2020-04-07	Dr. Keion Ondricka	dr.keion.ondricka@geemail.com	Victorville	California	4515415168009304	75c173b6325d61518b575125394f7306	JCB 16 digit	34.5983725273281379	-117.451998577980703
18870	2020-04-07 18:12:04	2020-04-07	Mr. Britt Nienow Sr.	mr.britt.nienow.sr.@geemail.com	Los Angeles	California	3112589097596900295	2cd134d133c9dc110047f1c84b8fed68	Mastercard	33.921334700924902	-118.49089460088797
18871	2020-04-07 18:12:24	2020-04-07	Viviana Hamill	viviana.hamill@warmmail.com	Phoenix	Arizona	6011776118622456236	278e8b029723e02fb28d215fa2271731	Voyager	33.5240485296517647	-112.05362501814254
18872	2020-04-07 18:14:21	2020-04-07	Daisy Steuber-Ferry	daisy.steuber.ferry@geemail.com	Phoenix	Arizona	3058511588225829	e82ceec69cda3834f95797d9b295498f	Discover	33.5132637496504984	-112.117815688431648
18873	2020-04-07 18:19:30	2020-04-07	Launa Jakubowski PhD	launa.jakubowski.phd@geemail.com	Honolulu	Hawaii	3337196718439067712	b45e7d945e2a4912627e278f7e9899dd	VISA 16 digit	21.2614338447090248	-157.89397029683218
18874	2020-04-07 18:32:25	2020-04-07	Miss Jaye Eichmann MD	miss.jaye.eichmann.md@geemail.com	Thousand Oaks	California	180011328490629518	98a9ef9378c6fdaf4d81b79196142c42	Diners Club / Carte Blanche	34.1623567314159118	-118.788284523310892
18875	2020-04-07 18:51:32	2020-04-07	Citlali Harber-Kertzmann	citlali.harber.kertzmann@geemail.com	Fort Collins	Colorado	4377806217963433	474dae33ecd19a4d638b970bdec9f848	Diners Club / Carte Blanche	40.5942126978810904	-104.994589110412832
18876	2020-04-07 19:03:33	2020-04-07	Simpson Powlowski	simpson.powlowski@warmmail.com	San Francisco	California	6011941921319179072	c9a688f73dd47b16e3bb65de17cf043e	VISA 16 digit	37.7561457888216978	-122.461743040726418
18877	2020-04-07 19:30:27	2020-04-07	Ivy Heaney	ivy.heaney@warmmail.com	San Francisco	California	3793244837243767	079df5c4f50a8f2c670d00934deeb6bf	Maestro	37.7663531308400238	-122.413562109108327
18878	2020-04-07 19:30:33	2020-04-07	Niles Medhurst	niles.medhurst@geemail.com	Corpus Christi	Texas	3528594410355276950	859d5b22c4fc207ac84d76a339a88019	Discover	27.6711603325262665	-97.2685913334894963
18879	2020-04-07 19:44:51	2020-04-07	Mr. Bertrand Schuppe	mr.bertrand.schuppe@woohoo.com	Orange	California	4070516790564215	db8d9a657c05ae2dfc1175fa01fc9f37	Discover	33.8141908412687471	-117.866176059619704
18880	2020-04-07 19:47:30	2020-04-07	Wood Walsh IV	wood.walsh.iv@geemail.com	San Francisco	California	4180743345123647	f3b210ac40c57aef6618bcb5771e3a50	JCB 16 digit	37.7828533296550617	-122.429203962095954
18881	2020-04-07 19:50:42	2020-04-07	Ms. Odie Grant MD	ms.odie.grant.md@woohoo.com	West Covina	California	52778963126644128	11706b5974948ba8a1cf524bed68405c	JCB 16 digit	33.9780709395293172	-117.820310748608406
18882	2020-04-07 19:52:09	2020-04-07	Hobert Dicki-Block	hobert.dicki.block@geemail.com	Detroit	Michigan	4700117958136561	1df10f86845c6564f7a872eb62fd9073	Discover	42.3602318013012464	-83.1286130568131796
18883	2020-04-07 20:06:24	2020-04-07	Orvil Stracke-Stanton	orvil.stracke.stanton@geemail.com	Cleveland	Ohio	55184588365022039	9b8b2a0803b610b75e07e62e7394afbb	VISA 13 digit	41.5292192857563478	-81.596813745960219
18884	2020-04-07 21:01:36	2020-04-07	Lu Halvorson	lu.halvorson@geemail.com	Eugene	Oregon	869919326680539523	f719afcff719400ea7787f866e310c40	JCB 16 digit	44.0139983028367183	-123.171272490498424
18885	2020-04-07 21:02:19	2020-04-07	Gannon Kub-McKenzie	gannon.kub.mckenzie@geemail.com	Detroit	Michigan	4959361056218	ae66c3f82a177e491fabdc7a737e51d1	Mastercard	42.4398188712932196	-83.0645585156630659
18886	2020-04-07 21:09:26	2020-04-07	Dr. Wilhelmine Kulas	dr.wilhelmine.kulas@woohoo.com	San Francisco	California	6011954069368924511	7b955058019a45f68c9c390398b4b238	Discover	37.7972348106627507	-122.433959575511437
18887	2020-04-07 21:21:52	2020-04-07	Dr. Milas McGlynn	dr.milas.mcglynn@geemail.com	El Paso	Texas	6011419427653942888	63e37345c9e6d0f4b7e997253b092e18	Voyager	31.8365364230532215	-106.500236715467651
18888	2020-04-07 21:35:29	2020-04-07	Blaise Farrell	blaise.farrell@geemail.com	San Francisco	California	869933695275569067	b8333a64d5df77ed5b96cc90f3caa861	American Express	37.7700096522073423	-122.420600748335403
18889	2020-04-07 22:16:41	2020-04-07	Dr. Latrice Shields DVM	dr.latrice.shields.dvm@geemail.com	Phoenix	Arizona	6011118042412312317	d04da75b748a8baefd7c79902e48c0ec	JCB 16 digit	33.4779073025964209	-112.019636118078978
18890	2020-04-07 22:17:21	2020-04-07	Mercer Will-Hoppe	mercer.will.hoppe@woohoo.com	Berkeley	California	52091756236847791	18c683e4fa95453c03ee1a244b2b6b49	American Express	37.8768483823434821	-122.302952085719497
18891	2020-04-07 22:25:11	2020-04-07	Ms. Lesia Corkery	ms.lesia.corkery@woohoo.com	Austin	Texas	4325032299555	d7647047b350f4bb7b646efbb90a7dc8	Maestro	30.2366323657926159	-97.7233703808166183
18892	2020-04-07 22:27:18	2020-04-07	Elfreda Spencer-Feil	elfreda.spencer.feil@geemail.com	Dallas	Texas	4137698909496	a192d5350af664815d79387166e8805a	JCB 16 digit	32.7907233753047933	-96.8559979324657405
18893	2020-04-07 22:43:42	2020-04-07	Ardell Welch MD	ardell.welch.md@geemail.com	Brownsville	Texas	3088989601743528622	9b0ba76ac74d37f8b350683ee682a222	Maestro	25.9768039955370114	-97.4828751774225424
18894	2020-04-07 22:50:18	2020-04-07	Otis Parker DDS	otis.parker.dds@geemail.com	Milwaukee	Wisconsin	210009242385951016	e1e35f023538d4fdd3f8100ab7a4681e	Mastercard	43.0859301911752652	-88.011453517070791
18895	2020-04-07 23:00:30	2020-04-07	Gee Bergstrom	gee.bergstrom@geemail.com	Dallas	Texas	180035036201027821	5d8713d7bda194cf22906fdd92b3b1ed	JCB 16 digit	32.8059372559927453	-96.7044542634822335
18896	2020-04-07 23:12:00	2020-04-07	Jensen Corkery	jensen.corkery@geemail.com	Shreveport	Louisiana	4823812364334	53cf149e0aa22cc8feaa8edd1d7f8033	JCB 16 digit	32.5133854328427461	-93.7147119341630486
18897	2020-04-07 23:12:36	2020-04-07	Mittie Kessler	mittie.kessler@geemail.com	San Diego	California	4429229253878	bac9d412a86394d0abc0a59267fb23da	Mastercard	32.7404283866818986	-117.098429091731091
18898	2020-04-07 23:36:41	2020-04-07	Theresia Hamill-Heathcote	theresia.hamill.heathcote@woohoo.com	Philadelphia	Pennsylvania	3158068416120605693	49e01d44e1ae5a357f8470a807eb9278	VISA 16 digit	40.0913054005667533	-75.1146653522636853
18899	2020-04-07 23:37:05	2020-04-07	Esta Pollich DVM	esta.pollich.dvm@geemail.com	Hialeah	Florida	52577158903796208	5cc3764beb05c4b1179a9b5eb5aa6502	VISA 16 digit	25.860275335467982	-80.2929439652614292
18900	2020-04-07 23:38:37	2020-04-07	Noel Kub-Miller	noel.kub.miller@geemail.com	Las Vegas	Nevada	869922127020184433	06eb366358c859c4df5c0f7f85a20642	JCB 16 digit	36.1365962118476602	-115.319079845885184
18901	2020-04-07 23:47:08	2020-04-07	Mr. Kole Leuschke III	mr.kole.leuschke.iii@geemail.com	Cleveland	Ohio	53750940788353430	866e87838d4e087f2184465c2124a0b6	Maestro	41.4376402078047334	-81.5992717172257613
18902	2020-04-07 23:49:23	2020-04-07	Mrs. Andria Hagenes MD	mrs.andria.hagenes.md@geemail.com	Minneapolis	Minnesota	3435461069896374	9f8b5d2563ff04b92bdfbbe059e8827c	JCB 16 digit	44.9313376911070179	-93.1808576057471356
18903	2020-04-07 23:52:25	2020-04-07	Katelynn Oberbrunner DVM	katelynn.oberbrunner.dvm@geemail.com	Modesto	California	3480269785948393	66a0751ab2058bbd5ab49dc003c15c22	JCB 15 digit	37.5766854302957682	-120.936753432147199
18904	2020-04-07 23:54:52	2020-04-07	Dr. Kale Donnelly	dr.kale.donnelly@woohoo.com	Plano	Texas	4673988886796	b2399631fe2a181713780138c2a09fb8	JCB 16 digit	32.9565695454917886	-96.6873861488137436
18905	2020-04-08 00:04:28	2020-04-08	Barnett Buckridge V	barnett.buckridge.v@geemail.com	San Francisco	California	6011414728380655312	f0d6ee22c4cf373de8547df43f2faa39	VISA 13 digit	37.7916976119588313	-122.428099606320686
18906	2020-04-08 00:13:15	2020-04-08	Mr. Selmer Emard	mr.selmer.emard@geemail.com	San Francisco	California	4635767860372892	8b6869b658d7dc639482d321ec209207	Diners Club / Carte Blanche	37.7566095765013401	-122.415875201469959
18907	2020-04-08 00:15:09	2020-04-08	Ashlynn O'Connell	ashlynn.o'connell@geemail.com	Santa Clara	California	4698201244770	7ff5fdadc52e84b2762e54931f19172b	VISA 16 digit	37.2651275320727393	-121.898027231404185
18908	2020-04-08 00:22:13	2020-04-08	Kallie Lockman	kallie.lockman@geemail.com	Providence	Rhode Island	6011399664646070229	ecf7e72784be30a234deb81befb793ed	VISA 16 digit	41.7898636336293023	-71.3323521426331268
18909	2020-04-08 00:24:35	2020-04-08	Mr. Johney Effertz III	mr.johney.effertz.iii@warmmail.com	Olathe	Kansas	3021177260941385	f5862bcc2f5d945d6c2a90431716024c	Voyager	38.828994303395227	-94.7854329637419539
18910	2020-04-08 00:32:26	2020-04-08	Letty Wisozk	letty.wisozk@geemail.com	Los Angeles	California	55278802527430742	9e12867eaafc11e07dd36311db0af3ad	Diners Club / Carte Blanche	33.9655031833663585	-118.426267029204581
18911	2020-04-08 00:42:28	2020-04-08	Mr. Bentley Kilback	mr.bentley.kilback@warmmail.com	Lexington	Kentucky	869939301446468784	bc510af10915024b4d66ef1f365f55d7	JCB 16 digit	38.1005628470674154	-84.4376531224597215
18912	2020-04-08 00:47:04	2020-04-08	Mammie Johns	mammie.johns@geemail.com	San Jose	California	54528151620012207	9d02853fb96c78800fef3dbd21300946	Mastercard	37.2982901023056357	-121.834466997556021
18913	2020-04-08 00:51:06	2020-04-08	Christena VonRueden	christena.vonrueden@geemail.com	Meridian	Idaho	4673168891210	41818d27a970f26d19fb565269ddb4a9	JCB 15 digit	43.5567611161626829	-116.332530253747109
18914	2020-04-08 00:57:00	2020-04-08	Dakoda Schmitt	dakoda.schmitt@warmmail.com	Kent	Washington	561283406216073	9a2da7ffa9a43ce200a711cdba8f0b4a	American Express	47.4052387106809761	-122.175256412955747
18915	2020-04-08 00:57:16	2020-04-08	Enola Brekke	enola.brekke@geemail.com	Wichita	Kansas	210008124111812194	fd0ce35a5c3d17e8ba4768e0909ccefb	Maestro	37.774447953921559	-97.3951003850638841
18916	2020-04-08 01:10:30	2020-04-08	Vincent Klein	vincent.klein@geemail.com	San Francisco	California	3096091209048185190	145c5086710488b984c45580c0e85270	JCB 16 digit	37.7881711603088988	-122.420222453101857
18917	2020-04-08 01:12:58	2020-04-08	Myrtle Ferry	myrtle.ferry@geemail.com	Irvine	California	3337573864384590887	1bc8b201c6df13467d28dd2fdabe1f0f	JCB 16 digit	33.6065276503577834	-117.788309002901613
18918	2020-04-08 01:25:50	2020-04-08	Donna Schoen	donna.schoen@geemail.com	Sunnyvale	California	3028348627259992	03cfb8a20b077b9a10b183af334a1c28	VISA 16 digit	37.3978432046707781	-122.098163259468237
18919	2020-04-08 01:47:31	2020-04-08	Brandie Murazik	brandie.murazik@woohoo.com	New York	New York	51348740082057748	b13f617c308718be5dfa844910c335b7	JCB 16 digit	40.5641146631669258	-73.8824336861621589
18920	2020-04-08 01:49:11	2020-04-08	Geri Kulas	geri.kulas@geemail.com	San Francisco	California	4597822730102	b9a534c16ea2e250586cd0b21decb6a3	Mastercard	37.7961477527435363	-122.47227090419814
18921	2020-04-08 01:58:35	2020-04-08	Francis Ruecker	francis.ruecker@warmmail.com	Mesa	Arizona	060463198034330	382ae01cbf4b7b6b368e9ff8603f38aa	VISA 16 digit	33.3883905423950367	-111.748649814713374
18922	2020-04-08 02:07:17	2020-04-08	Maddux Effertz	maddux.effertz@geemail.com	Jackson	Mississippi	869937209938537952	9ed4e8b731f7d0fb96c8ced8e01b2417	American Express	32.3408486247707216	-90.295693139403312
18923	2020-04-08 02:16:48	2020-04-08	Mikala Schinner	mikala.schinner@geemail.com	Sparks	Nevada	3004531398553966	b1a5695f672b117dda054e5b670eed05	Maestro	39.4704714298021031	-119.740302964378529
18924	2020-04-08 02:17:02	2020-04-08	Art Greenfelder-Swaniawski	art.greenfelder.swaniawski@woohoo.com	Richardson	Texas	180083207790124219	2eff77807ef021f64ceb71db570773ae	JCB 15 digit	32.8864815520357325	-96.6163103131804633
18925	2020-04-08 02:26:25	2020-04-08	Lisette Sporer	lisette.sporer@warmmail.com	Victorville	California	6011328262745729773	0e32aa81d39bd5a0131fcc9dbc5ffea9	VISA 13 digit	34.5179606455143571	-117.427037804542479
18926	2020-04-08 02:29:57	2020-04-08	Dr. Raven Lebsack	dr.raven.lebsack@warmmail.com	Henderson	Nevada	4924472594382636	a2a23c4be2abc79b11843db157263fbe	Maestro	36.0673725068967812	-114.968967498668292
18927	2020-04-08 02:43:02	2020-04-08	Harrie Dibbert	harrie.dibbert@geemail.com	Springfield	Illinois	3481614690991484	5d1fd2294faf41fab2b5ceddac6552b5	American Express	39.798242453407866	-89.5845843000806781
18928	2020-04-08 02:43:21	2020-04-08	Ebbie Cummings	ebbie.cummings@woohoo.com	Oakland	California	3528686689190263328	d18eaff84065cbe1ee4c53d4e12605a3	Mastercard	37.8489619110454498	-122.272514301031222
18929	2020-04-08 02:46:53	2020-04-08	Mr. Kris Roberts	mr.kris.roberts@geemail.com	New York	New York	3770263263100892	8a7363711d6c2272012233c0eba33135	American Express	40.6825251260530223	-74.0164599437162281
18930	2020-04-08 03:04:10	2020-04-08	Lynne Moen	lynne.moen@warmmail.com	Athens	Georgia	53675641836384920	dad2122ef065eb564fc5e5e13bf7ee8c	American Express	33.9327602965947221	-83.3204700507804716
18931	2020-04-08 03:11:37	2020-04-08	Evie Boehm	evie.boehm@geemail.com	Portland	Oregon	4122205861902722	00974c429eb4d0b2d67e80dcd8b804e5	VISA 16 digit	45.5556584359500576	-122.62603067820892
18932	2020-04-08 03:16:11	2020-04-08	Jan Jaskolski	jan.jaskolski@geemail.com	San Francisco	California	210091455227975394	44a4880b7ea9107de29c59de9a53bda0	Mastercard	37.7817168599100341	-122.431413249139922
18933	2020-04-08 03:17:02	2020-04-08	Pearley Morar	pearley.morar@geemail.com	McAllen	Texas	3096818442432550263	8dd0a354da82193cc2b4c0dd9a490e29	VISA 16 digit	26.3104532698940474	-98.2848096459019871
18934	2020-04-08 03:29:22	2020-04-08	Granville Grimes	granville.grimes@geemail.com	Riverside	California	3088053173677256183	f44fda125c6397d44ca8c738f98dccd6	VISA 16 digit	33.8912107065733537	-117.395739569884526
18935	2020-04-08 03:39:15	2020-04-08	Lemma Dickens	lemma.dickens@geemail.com	San Diego	California	3778868950106366	18f0c51a85fecc8762dffbd4931fcc63	VISA 13 digit	32.8844508728545151	-117.20285327312537
18936	2020-04-08 03:41:16	2020-04-08	Derik Collier	derik.collier@warmmail.com	Phoenix	Arizona	180088363270640854	c823b785ab2a9b339780edb51b263ef8	JCB 16 digit	33.6044571409866251	-112.128440063393128
18937	2020-04-08 03:42:50	2020-04-08	Walker Quigley	walker.quigley@geemail.com	Los Angeles	California	3528546394945010021	2859ea21510d7f08e82d5798b0a4bdb7	VISA 16 digit	34.0973551838990261	-118.456352143594245
18938	2020-04-08 04:16:57	2020-04-08	Dorla Bradtke	dorla.bradtke@warmmail.com	Boston	Massachusetts	3088071194806346644	41914985bf9f3997a9b6243574c21d2b	JCB 15 digit	42.2841146895363948	-70.9916445329271255
18939	2020-04-08 04:32:56	2020-04-08	Eliot Mitchell-Koss	eliot.mitchell.koss@geemail.com	Chicago	Illinois	4843744310960095	de4096260b42f53c61a8944383a8bec1	VISA 16 digit	41.798351314414667	-87.6908680587571041
18940	2020-04-08 04:44:59	2020-04-08	Seth Fahey-Dietrich	seth.fahey.dietrich@geemail.com	Rialto	California	869976672143429012	0ba228eb595c702500a713cdfef0cd24	JCB 15 digit	34.0354915081739478	-117.399134841337059
18941	2020-04-08 04:46:03	2020-04-08	Kaitlynn Hoppe	kaitlynn.hoppe@geemail.com	Gainesville	Florida	589390113851860	6d67ad8270040193c043402ba2a1bc5e	JCB 15 digit	29.7694841844320273	-82.4338582327462746
18942	2020-04-08 04:46:52	2020-04-08	Phyllis Shields-Lehner	phyllis.shields.lehner@geemail.com	Meridian	Idaho	060422406888473	ba0d8b6d9551f45b217807c6e8e861e7	VISA 16 digit	43.5698051160674495	-116.361899505596227
18943	2020-04-08 04:47:04	2020-04-08	Jaslene Hoppe	jaslene.hoppe@geemail.com	Fort Worth	Texas	6011764410109325321	06f63a7a9c0df7c6205269120b0f28e6	Voyager	32.8088376066237686	-97.2639605754807519
18944	2020-04-08 04:47:58	2020-04-08	Garnet Tremblay PhD	garnet.tremblay.phd@warmmail.com	Phoenix	Arizona	4895210455142672	61c0c9778ecdc2340df5f1fb79b499b7	JCB 16 digit	33.6385661701604732	-112.017977573017035
18945	2020-04-08 05:10:46	2020-04-08	Miss Lillian Parker	miss.lillian.parker@geemail.com	Green Bay	Wisconsin	4718896762530644	3291e2029b93f4d02c1cdfb63417a732	Mastercard	44.5940813141938293	-88.0740007819428996
18946	2020-04-08 05:14:01	2020-04-08	Robin Bernhard PhD	robin.bernhard.phd@geemail.com	Honolulu	Hawaii	3452011135065344	66dc1a4583976367754d1f3cbf6ab462	JCB 16 digit	21.3315778988629603	-157.879859947294364
18947	2020-04-08 05:35:45	2020-04-08	Mackenzie Aufderhar	mackenzie.aufderhar@warmmail.com	Cape Coral	Florida	3158068102413839088	882d71bb48d0165f7a3b039b1c6d5851	JCB 16 digit	26.6038033914256857	-81.9390779511142568
18948	2020-04-08 05:40:20	2020-04-08	Dr. Adrien Prosacco V	dr.adrien.prosacco.v@woohoo.com	Los Angeles	California	3480247764867016	20363c3c4708966e29acf6b0b26c28e7	VISA 13 digit	33.9766347931098167	-118.391245817857978
18949	2020-04-08 05:43:41	2020-04-08	Jewell Hettinger	jewell.hettinger@geemail.com	Scottsdale	Arizona	3337425057668389932	9117da98fa65fd8fd377274877b267b6	VISA 13 digit	33.5913888088084747	-111.801755010938635
18950	2020-04-08 05:43:59	2020-04-08	Gasper Jast	gasper.jast@woohoo.com	San Francisco	California	4032493379665408	e50f5b20086dd8ecd95a16e07e064b51	Discover	37.7782188804266994	-122.452108873047052
18951	2020-04-08 05:49:30	2020-04-08	Esmeralda Champlin	esmeralda.champlin@geemail.com	New York	New York	4644540962664485	c0ef63832e4639d8fbf68063f03c4607	American Express	40.7505968149974933	-73.9795221588935732
18952	2020-04-08 05:49:46	2020-04-08	Lucretia Gottlieb	lucretia.gottlieb@woohoo.com	Fayetteville	North Carolina	6011630299717943324	a11b3e23a0df498073988959005ea0a6	Discover	35.0519793598234628	-79.0637771795634166
18953	2020-04-08 06:18:00	2020-04-08	Lenord Runolfsdottir	lenord.runolfsdottir@geemail.com	Rockford	Illinois	3528329905039611342	da3162be4cdb586871e1546730443897	Maestro	42.2286167433962234	-89.1586746184904086
18954	2020-04-08 06:18:30	2020-04-08	Haven Ritchie IV	haven.ritchie.iv@woohoo.com	Garland	Texas	060406356805272	96295eead2fd05f5d04dd26357fe4816	VISA 16 digit	32.8350909423783364	-96.6834058055348748
18955	2020-04-08 06:21:40	2020-04-08	Friend Adams	friend.adams@geemail.com	Memphis	Tennessee	6011065513077117459	185d6b01b7b6135704be9474f6721cbb	Mastercard	35.1819042346507302	-90.0471439402341929
18956	2020-04-08 06:29:47	2020-04-08	Niles Walsh	niles.walsh@woohoo.com	Denver	Colorado	4658257718655	3bc200f801e435217aa1efe067f83d98	VISA 16 digit	39.8352281123917535	-104.962589997589959
18957	2020-04-08 06:42:48	2020-04-08	Dortha Schamberger	dortha.schamberger@geemail.com	Atlanta	Georgia	3466695430952109	4399fdcf963194c97a5510b1f01151fb	Mastercard	33.7452929464910198	-84.4456671572800843
18958	2020-04-08 06:58:21	2020-04-08	Miller Cruickshank Sr.	miller.cruickshank.sr.@geemail.com	San Francisco	California	180095308090835813	e6e9256aea82bfcb8c073bad114ba41c	Maestro	37.8167840908743003	-122.447596948731103
18959	2020-04-08 07:04:16	2020-04-08	Marcy Johns	marcy.johns@geemail.com	Frisco	Texas	4023726080999660	447d92cac289b644ba9e3cdfd847a735	JCB 16 digit	33.0795072545293749	-96.8516455262176663
18960	2020-04-08 07:05:13	2020-04-08	Russell Quigley-Hagenes	russell.quigley.hagenes@geemail.com	Scottsdale	Arizona	869947288103208886	ee2f295c7bf478d913bb85cac9493b74	VISA 13 digit	33.6123763335525965	-111.927970117373761
18961	2020-04-08 07:09:30	2020-04-08	Brien Feest	brien.feest@woohoo.com	Tucson	Arizona	3337624161805904121	1aae1b147478e8df96737a9682381cd0	Diners Club / Carte Blanche	32.1510743401054313	-110.939349948497863
18962	2020-04-08 07:16:30	2020-04-08	Dr. Allyn Koss	dr.allyn.koss@woohoo.com	Phoenix	Arizona	639014733739586	fff0266dbe65ad863281943af69d101b	Discover	33.5060784883264446	-112.148482500521851
18963	2020-04-08 07:18:57	2020-04-08	Krysten Osinski	krysten.osinski@geemail.com	West Palm Beach	Florida	639054080680652	e3b9adb1c678805413a671896b2e4c61	Mastercard	26.665738759267704	-80.077971642354882
18964	2020-04-08 07:22:32	2020-04-08	Bishop Mayer IV	bishop.mayer.iv@geemail.com	Oakland	California	4161575506488705	b82201e0c647ca8ba405ac203cf7a7db	VISA 16 digit	37.784040707011755	-122.235595209692164
18965	2020-04-08 07:57:35	2020-04-08	Clinton Dibbert-Hoppe	clinton.dibbert.hoppe@woohoo.com	Berkeley	California	4064365582513644	38484038556808472a8ab2318b90dd86	VISA 16 digit	37.8872403323717322	-122.263144654088251
18966	2020-04-08 08:00:36	2020-04-08	Kaye Okuneva	kaye.okuneva@geemail.com	Lubbock	Texas	3112251255498769948	baa51faa253cdcc3e132434e3aaed50a	VISA 16 digit	33.5088130138389815	-101.897103384594246
18967	2020-04-08 08:09:57	2020-04-08	Mrs. Ammie Von DVM	mrs.ammie.von.dvm@woohoo.com	Dallas	Texas	180036165451970460	06cb261f0906df131691456db5d0bf53	Maestro	32.885521721261739	-96.8602492301221929
18968	2020-04-08 08:51:03	2020-04-08	Metta Swaniawski-Muller	metta.swaniawski.muller@geemail.com	San Diego	California	3706536379059741	ed42f7ae768baf13ab8c0dd51a33a994	JCB 16 digit	32.8304304690632947	-117.209867168022328
18969	2020-04-08 09:04:12	2020-04-08	Miss Kerri Blick	miss.kerri.blick@geemail.com	Oklahoma City	Oklahoma	6011784526719170132	20cb8f6ba3bc90693bcc5988ae58ba08	JCB 15 digit	35.4138931333929321	-97.5400790722936364
18970	2020-04-08 09:09:11	2020-04-08	Mrs. Haley Blanda DVM	mrs.haley.blanda.dvm@geemail.com	Austin	Texas	6011539610064130061	ff7f163cf67e7442e8b37f558e8ad15d	Discover	30.2367278155531736	-97.7345956681069055
18971	2020-04-08 09:13:54	2020-04-08	Gussie Baumbach	gussie.baumbach@warmmail.com	Naperville	Illinois	4308711474378198	45553c471ad04e81f4ccb55aa717e1ce	VISA 16 digit	41.7676113201685268	-88.1073285082709106
18972	2020-04-08 09:20:18	2020-04-08	Forest Mueller	forest.mueller@geemail.com	Jackson	Mississippi	4993560121100855	c71512d0ac1db76121dca02f7e394e9b	Discover	32.3275842913139613	-90.2847109819270628
18973	2020-04-08 09:24:09	2020-04-08	Mr. Quinn Heathcote	mr.quinn.heathcote@geemail.com	Houston	Texas	4737413102533044	ec2928662ffe6b71c7fdb90af26469a5	Diners Club / Carte Blanche	29.7216153651088462	-95.3384624918006409
18974	2020-04-08 09:37:10	2020-04-08	Joell Streich	joell.streich@warmmail.com	Oakland	California	3337293266476915395	dc318f6f45fff8831e95baac2b9400b8	Maestro	37.826783351754095	-122.268826741888645
18975	2020-04-08 09:45:22	2020-04-08	Isla Bergstrom	isla.bergstrom@geemail.com	New York	New York	3112264562227819117	cdeee992c527d00619d625e51b2ec42c	Voyager	40.6554417249038806	-73.924582723471147
18976	2020-04-08 09:52:40	2020-04-08	Mckenzie Hyatt	mckenzie.hyatt@geemail.com	San Francisco	California	503857839154234	c34c94afff0895ad59773c99cdb15006	JCB 15 digit	37.7744134297137606	-122.390856186589332
18977	2020-04-08 09:57:58	2020-04-08	Demetric Bosco	demetric.bosco@geemail.com	Seattle	Washington	6011633561997733536	e35d39ac606a89253a6b3dc722fdae3a	VISA 13 digit	47.5528547072242915	-122.419422578058757
18978	2020-04-08 09:59:57	2020-04-08	Sydni Hoeger	sydni.hoeger@geemail.com	Detroit	Michigan	180048510909448260	2f2ebffcbc294e365fdfe44ba196f511	JCB 15 digit	42.3631568177994353	-83.0577015860125414
18979	2020-04-08 10:12:32	2020-04-08	Walter Stamm	walter.stamm@geemail.com	Frisco	Texas	3158136347637029028	bed2b11deff3b884775dfe950b0b22b6	Diners Club / Carte Blanche	33.0765112671531725	-96.7658886617723795
18980	2020-04-08 10:12:35	2020-04-08	Dr. Florance Zieme	dr.florance.zieme@geemail.com	San Francisco	California	676380922942398	4ac775bbaf29761dd80c3889a8d86148	Diners Club / Carte Blanche	37.7785079067908072	-122.425566387972438
18981	2020-04-08 10:44:57	2020-04-08	Justus Bartoletti IV	justus.bartoletti.iv@geemail.com	San Francisco	California	3405240362568112	711e67a1fc59813f16a22c73d32fd556	Diners Club / Carte Blanche	37.7609204422244602	-122.435075814365007
18982	2020-04-08 11:01:13	2020-04-08	Shaina Ernser	shaina.ernser@geemail.com	Omaha	Nebraska	52080084689555883	678922135da573587055e9679809c5cf	JCB 16 digit	41.2473562714789068	-96.0391635384060436
18983	2020-04-08 11:02:48	2020-04-08	Brennon Schowalter-Frami	brennon.schowalter.frami@woohoo.com	Houston	Texas	3769092746550826	655dded0b070204c83e6601c178e8507	Maestro	29.7871915315356119	-95.3014129465926487
18984	2020-04-08 11:18:54	2020-04-08	Tex Mante III	tex.mante.iii@geemail.com	Rancho Cucamonga	California	869946234272235921	a3471f269f2c4ebdf72840d020835939	JCB 16 digit	34.0916988446835418	-117.631561145559701
18985	2020-04-08 11:24:01	2020-04-08	Mr. Arden Corkery	mr.arden.corkery@geemail.com	Pittsburgh	Pennsylvania	503845637595971	800356cafb39eaa224cfba4314e39c76	JCB 16 digit	40.4466591937422706	-80.0391128671526957
18986	2020-04-08 11:25:07	2020-04-08	Meda Spinka	meda.spinka@geemail.com	Las Vegas	Nevada	180038121473443711	0e7358d357358dd7a203f23b6121b603	VISA 16 digit	36.2846026578087333	-115.23195271671041
18987	2020-04-08 11:55:15	2020-04-08	Ms. Iris Runolfsson	ms.iris.runolfsson@geemail.com	Santa Ana	California	3088501906697163642	982fd796b7b420494395e08d7511eb78	Voyager	33.7217590331669896	-117.941482273109258
18988	2020-04-08 12:13:04	2020-04-08	Finley O'Reilly	finley.o'reilly@woohoo.com	Oakland	California	53479296550281634	d4bd305ea30e11583cdac3659abe2853	Maestro	37.8193892859420018	-122.286145233392929
18989	2020-04-08 12:35:47	2020-04-08	Contina Bailey-Kuphal	contina.bailey.kuphal@geemail.com	Chicago	Illinois	6011329558653617622	b644701f0ed060a94a4764eea545c776	Discover	41.7734972330577676	-87.7505337596435027
18990	2020-04-08 12:40:24	2020-04-08	Kamren Wiza-Hodkiewicz	kamren.wiza.hodkiewicz@geemail.com	Washington	District of Columbia	53142441877986229	fe06c18925d80c4fe0cd33ebdbab8431	VISA 13 digit	38.9515520020652559	-76.9509466629222061
18991	2020-04-08 12:43:29	2020-04-08	Dock Cummings DVM	dock.cummings.dvm@woohoo.com	Anchorage	Alaska	3445000545206168	a238469cbf996df4c53e6cd3a314c4d4	JCB 16 digit	61.2193855156872431	-149.221003928234069
18992	2020-04-08 13:08:02	2020-04-08	Pratt Trantow	pratt.trantow@geemail.com	Mesquite	Texas	3088520154548801014	6b5aac5e9fd88278fd8b2b31b057e9c8	Mastercard	32.8579016298796986	-96.5448841186437789
18993	2020-04-08 13:15:49	2020-04-08	Dalton Kris	dalton.kris@geemail.com	Indianapolis	Indiana	3011937936399569	757c0eb9529e50b294caa76b9443383d	VISA 13 digit	39.8433778458282362	-86.0683449996836458
18994	2020-04-08 13:42:54	2020-04-08	Dave Kling	dave.kling@woohoo.com	Columbia	Missouri	3158506901028322848	2fc0982a054c7876937c75c08af32adb	JCB 15 digit	39.0372742232282306	-92.268187725782127
18995	2020-04-08 13:50:37	2020-04-08	Minoru Kling-Strosin	minoru.kling.strosin@woohoo.com	Anchorage	Alaska	4375178594807449	bf3365dd4140a200a5dccc8e7dda95a6	Voyager	61.122617626072099	-149.284023694333797
18996	2020-04-08 13:51:11	2020-04-08	Siobhan Tillman	siobhan.tillman@warmmail.com	Salinas	California	180038850798498881	843f0743bd42adc718f3f4d94e184f16	Maestro	36.7793604695003467	-121.552823709667479
18997	2020-04-08 13:58:09	2020-04-08	Buena Bernhard	buena.bernhard@woohoo.com	New York	New York	3736807469758821	5c4fdfa5aaa31fd6b11726d14535038e	Discover	40.7068783078566199	-73.9091893456771913
18998	2020-04-08 14:06:41	2020-04-08	Hailie Fisher MD	hailie.fisher.md@geemail.com	Raleigh	North Carolina	210060567708251967	d78d2d1197d05668ec865fcaa4f2489b	VISA 13 digit	35.8563126506883592	-78.7274265438720562
18999	2020-04-08 14:07:24	2020-04-08	Miss Leafy Kassulke PhD	miss.leafy.kassulke.phd@geemail.com	San Francisco	California	210090410083349631	65694ccc912110518cff260d1bccedcd	Maestro	37.7835734037276723	-122.470656095520141
19000	2020-04-08 14:13:58	2020-04-08	Winifred Veum-Bergstrom	winifred.veum.bergstrom@geemail.com	Vacaville	California	180095009330479046	ba9f91dc00e18a41c60359e5b046cf79	VISA 16 digit	38.2977444579020201	-122.047896374377615
19001	2020-04-08 14:40:42	2020-04-08	Abdul Oberbrunner-Baumbach	abdul.oberbrunner.baumbach@warmmail.com	San Francisco	California	3020943431460014	e838c6efcb568cf42dcecb8c41ee199b	JCB 16 digit	37.7765691325475856	-122.423478263767933
19002	2020-04-08 14:44:54	2020-04-08	Gene Pacocha	gene.pacocha@geemail.com	Raleigh	North Carolina	503887628809284	8b0e3ced9cdcf123fddd904d494b23e6	American Express	35.9080532588664383	-78.6207229244925117
19003	2020-04-08 15:20:13	2020-04-08	Dessa Weissnat	dessa.weissnat@geemail.com	Phoenix	Arizona	3033456556516384	165d32dfed685bc8aaf645900937a5ec	Discover	33.5040124454934158	-112.180913110815368
19004	2020-04-08 15:35:40	2020-04-08	Sol Auer	sol.auer@geemail.com	Norfolk	Virginia	3096772404440090819	fda28a40a6e1d20a98fad0cf98d5b75a	American Express	36.897429929675539	-76.2445850180000093
19005	2020-04-08 16:06:01	2020-04-08	Vaughn Runte-Herzog	vaughn.runte.herzog@geemail.com	San Francisco	California	3528711404642928521	860aaaf86d502618a75bf3af488a1053	Voyager	37.7775606206554642	-122.459549889187457
19006	2020-04-08 16:08:30	2020-04-08	Brenden Hamill-Zboncak	brenden.hamill.zboncak@geemail.com	Lafayette	Louisiana	869927411633747769	ec508ad168307107b928aca007427253	JCB 15 digit	30.2485622880492357	-92.0038921829629572
19007	2020-04-08 16:30:21	2020-04-08	Herlinda Trantow	herlinda.trantow@woohoo.com	Columbus	Ohio	3337088753197995755	165cd3f7c64dee8a5e9764cffd565453	VISA 13 digit	40.0810747251890618	-83.0108063498746702
19008	2020-04-08 16:30:30	2020-04-08	Sharita Hills-Prohaska	sharita.hills.prohaska@geemail.com	Dayton	Ohio	3096480006584587584	29e102bdeaa59a6711b2f5efa3768783	JCB 16 digit	39.8753320152197048	-84.2575046343918928
19009	2020-04-08 16:49:38	2020-04-08	Mrs. Karis Waters	mrs.karis.waters@woohoo.com	Tampa	Florida	4953100330671970	6fa63c9d34d813eb01cc582dfeadbff9	VISA 16 digit	28.0229597014956155	-82.5485011178746788
19010	2020-04-08 16:57:49	2020-04-08	Wiliam Turner	wiliam.turner@geemail.com	Austin	Texas	4807030158835555	cb5c307e2bf499dc37ac47ecfa866ce6	VISA 16 digit	30.2474580516699696	-97.7936521748785026
19011	2020-04-08 17:13:29	2020-04-08	Chrissy Metz	chrissy.metz@geemail.com	San Francisco	California	3337209699748645536	3e96722a5af60fc74782821051a2e001	JCB 15 digit	37.798473503343736	-122.419929899417099
19012	2020-04-08 17:35:34	2020-04-08	Mr. Braydon Nicolas	mr.braydon.nicolas@geemail.com	New York	New York	3112689375627354362	f1d2e1bfd263d4df45ab62849ddf297b	American Express	40.6445527482070048	-74.0270099772501737
19013	2020-04-08 17:48:08	2020-04-08	Ms. Keeley Lebsack	ms.keeley.lebsack@woohoo.com	Los Angeles	California	4309419045054	be84337af7acd28087e98208148391db	Diners Club / Carte Blanche	33.9635907723434229	-118.493418534006167
19014	2020-04-08 17:59:42	2020-04-08	Elia Stamm MD	elia.stamm.md@woohoo.com	Berkeley	California	869991733522740980	4b008314a5174226e0752b38daea5387	Mastercard	37.8863097122339525	-122.257748729613979
19015	2020-04-08 18:07:35	2020-04-08	Posey Kemmer	posey.kemmer@geemail.com	Baltimore	Maryland	51748112110317005	192eacc401ee0bd4c36ca464c4bb77a5	VISA 13 digit	39.3954856108408364	-76.6872016424797494
19016	2020-04-08 18:09:31	2020-04-08	Aurelio Mraz	aurelio.mraz@geemail.com	Atlanta	Georgia	4653664617400059	e1b749913f9b3582a73bee022a3f95c5	Voyager	33.6900267352625775	-84.4366810722321333
19017	2020-04-08 18:14:04	2020-04-08	Opal Langworth-Konopelski	opal.langworth.konopelski@geemail.com	San Francisco	California	3013963976927471	238d4a443ba0953a3d1b9751967582f2	JCB 15 digit	37.7435052524467594	-122.418868716398066
19018	2020-04-08 18:21:33	2020-04-08	Sabastian Haag	sabastian.haag@woohoo.com	Los Angeles	California	4433370326814	cf404e9dec9e0490c8e4cb7661461d1b	American Express	34.0801188530731949	-118.320887595880023
19019	2020-04-08 18:29:17	2020-04-08	Mrs. Citlalli Cruickshank	mrs.citlalli.cruickshank@geemail.com	New York	New York	51359320208066976	6ade678e8a9085318918d6cc29f0fb2e	American Express	40.5752487951181848	-73.9539837221044962
19020	2020-04-08 18:38:28	2020-04-08	Regan Denesik-Gulgowski	regan.denesik.gulgowski@geemail.com	El Monte	California	503857697847754	153f15027caf42bb069e322055c2da2a	Mastercard	34.103341774614897	-118.055956022607532
19021	2020-04-08 18:39:26	2020-04-08	Young Nicolas V	young.nicolas.v@warmmail.com	Memphis	Tennessee	503855403417979	af3642731ce75471db844b295ee0d6f3	JCB 16 digit	35.1758986558832234	-89.9168704168662458
19022	2020-04-08 18:46:32	2020-04-08	Trena Murazik-Ortiz	trena.murazik.ortiz@geemail.com	Chicago	Illinois	4384344510325135	d25ff73ec83571ea287feca5b8064b7e	VISA 16 digit	41.7604407562244688	-87.6446535749856395
19023	2020-04-08 18:49:22	2020-04-08	Loren Grimes	loren.grimes@warmmail.com	Corpus Christi	Texas	52333752444496214	a9bb6a86fd3f0bd2fe10d208ac3cf023	JCB 15 digit	27.7504798158008619	-97.106989624427257
19024	2020-04-08 19:00:45	2020-04-08	Milan Carter	milan.carter@geemail.com	Oakland	California	53369801884684958	fa008c1f231b7c20baf804db4d7dd2ba	Mastercard	37.8034531937104816	-122.291143558807136
19025	2020-04-08 19:02:05	2020-04-08	Miss Ilene Lemke PhD	miss.ilene.lemke.phd@warmmail.com	Miramar	Florida	180055955090926659	37eb4ccfdf162254358a53ac26d5090f	Maestro	25.985646151423456	-80.2432769517872515
19026	2020-04-08 19:13:25	2020-04-08	Candace Effertz PhD	candace.effertz.phd@woohoo.com	Austin	Texas	4410212595991311	9d38a6530e9653ccf7c3e448dbfe7326	VISA 13 digit	30.2053098413288588	-97.7184397232957167
19027	2020-04-08 19:20:47	2020-04-08	Lulah Ward DDS	lulah.ward.dds@geemail.com	New York	New York	4245613018192	3ef735d0374037dd0d5e62a61abb1b70	Mastercard	40.5850897533111237	-74.0160306575603784
19028	2020-04-08 19:39:24	2020-04-08	Lim Kassulke	lim.kassulke@warmmail.com	Salt Lake City	Utah	6011733218917399992	3ffbf5abe5a0472406664c0aef6c3d6c	JCB 16 digit	40.7164106012932905	-111.842555612552914
19029	2020-04-08 19:50:55	2020-04-08	Elna Hayes	elna.hayes@geemail.com	Omaha	Nebraska	3158154866317536587	e4b4c9c5038ee82c51183c4add8000e0	VISA 16 digit	41.2836172150593299	-95.9950212166294534
19030	2020-04-08 19:53:56	2020-04-08	Trista Schmidt	trista.schmidt@geemail.com	New York	New York	180093021735833224	a88b31620859a2a7bde384b03cb5f7fa	Mastercard	40.6793066423144154	-74.0326709211233975
19031	2020-04-08 20:04:29	2020-04-08	Dorcas Reynolds	dorcas.reynolds@geemail.com	Fort Worth	Texas	3022503414419656	cb185b46e3692063ef8473a0e9d614e4	JCB 16 digit	32.7342186597231759	-97.3389574846539603
19032	2020-04-08 20:09:51	2020-04-08	Mertie Rath	mertie.rath@geemail.com	Kenosha	Wisconsin	561203840625341	4cd2021d5a921cc10371bc6389bdd9a3	Voyager	42.5898297700870785	-87.8754494054470285
19033	2020-04-08 20:16:57	2020-04-08	Chandler Goodwin I	chandler.goodwin.i@geemail.com	Charlotte	North Carolina	3035122931831660	043039cac610455ee8954f563e035396	Discover	35.1643262619405945	-80.7565907681770625
19034	2020-04-08 20:30:59	2020-04-08	Miss Cassidy Waters	miss.cassidy.waters@geemail.com	San Francisco	California	4828720550254	e2c286467bd22895fd11c286a11bdc27	Discover	37.7768501371661714	-122.421810375856623
19035	2020-04-08 20:31:17	2020-04-08	Mr. Perry Lemke Sr.	mr.perry.lemke.sr.@geemail.com	Mesa	Arizona	55202506642420246	8bc8ac2bfe30c98693910d02a6d6ec20	Voyager	33.423744743192195	-111.639008509309591
19036	2020-04-08 20:38:25	2020-04-08	Charlton Torp	charlton.torp@geemail.com	New York	New York	3766751199257329	0c0e2ec89734d7104c2bb6d825885a00	JCB 16 digit	40.7171299215164026	-73.9062915758591146
19037	2020-04-08 20:45:15	2020-04-08	Latoria Dach	latoria.dach@warmmail.com	Chicago	Illinois	180050149307873202	a6f4d5446d75e5bb2552abdae28ec4e2	Voyager	41.8552583206746718	-87.6616797678668007
19038	2020-04-08 20:45:19	2020-04-08	Rita Sanford	rita.sanford@woohoo.com	Sacramento	California	869976781625178201	7ae496d38ee63832bb19e3847e2c7242	Maestro	38.5100152658097485	-121.47601021069697
19039	2020-04-08 20:51:39	2020-04-08	Tamra O'Connell	tamra.o'connell@geemail.com	Philadelphia	Pennsylvania	4931936959648	1836080c1c319e5e9648f225b7433967	Mastercard	39.9939212265849093	-75.0376770281132366
19040	2020-04-08 20:53:30	2020-04-08	Mr. Jule Jacobi	mr.jule.jacobi@woohoo.com	Chesapeake	Virginia	3088383594781661672	edf96b0fc0e0289b2ad17afcf3e98e9f	JCB 16 digit	36.6860215814556909	-76.330966643926871
19041	2020-04-08 21:03:54	2020-04-08	Ethelbert Quigley	ethelbert.quigley@geemail.com	Virginia Beach	Virginia	869941945426092596	e5368928e3e0be1647dbca122e149324	JCB 15 digit	36.8216622559074338	-76.0403010041125071
19042	2020-04-08 21:12:24	2020-04-08	Dr. Caroline Christiansen DVM	dr.caroline.christiansen.dvm@geemail.com	Berkeley	California	3096076972863087366	7ccf92ec24e0896972b50deca323bed8	American Express	37.8829019503504725	-122.25885657745043
19043	2020-04-08 22:08:38	2020-04-08	Chaya Prosacco	chaya.prosacco@geemail.com	Los Angeles	California	869978603689346698	4ad5acc0e95d4f91b91c419bc4fe67a6	American Express	33.9680691686324749	-118.381383647117019
19044	2020-04-08 22:50:45	2020-04-08	Katherine Larson	katherine.larson@geemail.com	Fort Lauderdale	Florida	3023966815768956	936e70840c81131d3979e711615b8099	Diners Club / Carte Blanche	26.2167762913264362	-80.0660298599216986
19045	2020-04-08 23:00:21	2020-04-08	Maud Stoltenberg	maud.stoltenberg@geemail.com	Provo	Utah	3096515831703590733	fb9f89de7e31e3ce68cb805fe42d5646	American Express	40.2980569276746365	-111.739683993128324
19046	2020-04-08 23:23:26	2020-04-08	Scarlet Windler	scarlet.windler@geemail.com	San Francisco	California	3337723350858591535	8e53e12733545caaadf13221dcc5ddfd	Maestro	37.7954162045243081	-122.425966720945397
19047	2020-04-08 23:25:39	2020-04-08	Dr. Murphy Von	dr.murphy.von@geemail.com	New York	New York	54059659190495351	798c92f1441aa4a31bf6193cecebc142	JCB 15 digit	40.64433979017101	-73.9472497255902681
19048	2020-04-08 23:30:10	2020-04-08	Jaycie Yundt	jaycie.yundt@geemail.com	Fontana	California	4775055880647133	36cf5ae3c49eb0098f1ac713aee47df8	Maestro	34.1052921911384956	-117.540130603480719
19049	2020-04-08 23:45:10	2020-04-08	Flint Mosciski	flint.mosciski@geemail.com	Long Beach	California	869913157408003393	01ad191f39c6801730de1a57b6d8f493	VISA 13 digit	33.7838867940761105	-118.179978423069414
19050	2020-04-08 23:58:33	2020-04-08	Alyson Ryan DVM	alyson.ryan.dvm@woohoo.com	Milwaukee	Wisconsin	4425166466187420	65f2e7c2399284f2641896a4a7792d9b	JCB 16 digit	43.0630926034033266	-87.890028957660121
19051	2020-04-09 00:14:23	2020-04-09	Shirlee Lubowitz	shirlee.lubowitz@woohoo.com	San Francisco	California	561286590408497	2524d3e4ba258d8ac5490054ddb95395	Diners Club / Carte Blanche	37.7950662707967666	-122.467320318811915
19052	2020-04-09 00:23:53	2020-04-09	Ms. Paisley Zieme	ms.paisley.zieme@woohoo.com	San Francisco	California	3035316734878445	2d79212137d79eb75a07481ae11fbf41	Diners Club / Carte Blanche	37.7588932134134154	-122.407304695887859
19053	2020-04-09 00:42:42	2020-04-09	Nallely Gutkowski	nallely.gutkowski@geemail.com	San Francisco	California	4166038096986682	1add55dd7d89089be22f2f4dfa72a607	VISA 16 digit	37.7814381703664779	-122.419783101489116
19054	2020-04-09 00:45:28	2020-04-09	Kunta Luettgen	kunta.luettgen@woohoo.com	El Paso	Texas	3158920070919258038	88bb38ea414bedbe7640cc5a49f09694	Diners Club / Carte Blanche	31.8615770883686871	-106.403692548347649
19055	2020-04-09 00:46:11	2020-04-09	Tony Dietrich	tony.dietrich@geemail.com	San Francisco	California	060493288362556	0ece7e2881631cad37c8f97e5ab43461	JCB 16 digit	37.7706412118653105	-122.433127156313219
19056	2020-04-09 00:47:04	2020-04-09	Mr. Vick Pacocha DDS	mr.vick.pacocha.dds@geemail.com	New Orleans	Louisiana	54542343693982703	c4f8d6313b8b16c22a5fc66cf4f295b4	JCB 16 digit	30.04622978558913	-89.9021164149306742
19057	2020-04-09 00:52:39	2020-04-09	Shona Borer	shona.borer@geemail.com	Waterbury	Connecticut	210089886830817793	fc2651abac6e6d77d81189d66fe9cf1e	American Express	41.4622245646119154	-73.0111452546350677
19058	2020-04-09 00:58:33	2020-04-09	Ms. Marcelle Koch PhD	ms.marcelle.koch.phd@geemail.com	Mobile	Alabama	4135075016624116	c5ddcbcf824687adcec76e783ee122d3	Maestro	30.6072964581303282	-88.1362082174651391
19059	2020-04-09 01:11:13	2020-04-09	Leona O'Hara	leona.o'hara@geemail.com	Denton	Texas	3112843651839799138	716e5f8426340a7cd69a43dca143df92	Voyager	33.2058702972982047	-97.1632811591621532
19060	2020-04-09 01:16:22	2020-04-09	Miss Katia Conroy DVM	miss.katia.conroy.dvm@geemail.com	Antioch	California	3446633706122920	659e4152091126386602bdd23eebfa47	Discover	38.0036475592091705	-121.768831128644564
19061	2020-04-09 01:21:07	2020-04-09	Mr. Aidyn Medhurst	mr.aidyn.medhurst@woohoo.com	Tuscaloosa	Alabama	639091769687434	e80a5f7ca3fec8df68a371fc5cad229a	VISA 16 digit	33.3016051292009649	-87.5390397602789108
19062	2020-04-09 01:25:39	2020-04-09	Arne Kilback	arne.kilback@geemail.com	New York	New York	3773964027579266	6651293150355768552fa50ff7884233	JCB 16 digit	40.6186903745159498	-73.9555961410876392
19063	2020-04-09 01:36:21	2020-04-09	Tyrone Langworth	tyrone.langworth@geemail.com	San Francisco	California	3443175997629190	d746e1bc827516e98b71fcfc5d78bdec	American Express	37.7919751964118831	-122.484006048141836
19064	2020-04-09 01:38:57	2020-04-09	Ms. Starr Nikolaus PhD	ms.starr.nikolaus.phd@geemail.com	Oakland	California	4552843731563	f4c8e7df270b9ec8b0651c89bfafaecd	Maestro	37.8126858555158876	-122.267941041184244
19065	2020-04-09 01:49:39	2020-04-09	Kristin Leffler	kristin.leffler@geemail.com	Cary	North Carolina	869966039534690374	d84d6b69d69cea847cf3be324b290376	Voyager	35.8200437098849562	-78.8710833532821312
19066	2020-04-09 01:50:05	2020-04-09	Camryn Brekke	camryn.brekke@geemail.com	Portland	Oregon	869968731539644012	9717663f80deb812e984b516cbcb8ce6	VISA 16 digit	45.6073028731513759	-122.714040747797128
19067	2020-04-09 01:54:26	2020-04-09	Savon Watsica	savon.watsica@woohoo.com	Indianapolis	Indiana	503807685238524	b11b86399ce18bdfb1f737c4b3d09bb2	Diners Club / Carte Blanche	39.7987378841273483	-86.0915039151642389
19068	2020-04-09 02:02:05	2020-04-09	Horton Nitzsche-Lindgren	horton.nitzsche.lindgren@geemail.com	Murfreesboro	Tennessee	3528806156212448605	7e7b7d51335e8b4474c5cd3375b22e57	Diners Club / Carte Blanche	35.9272171390362089	-86.5015591623112527
19069	2020-04-09 02:05:18	2020-04-09	Donnie Emmerich	donnie.emmerich@geemail.com	Antioch	California	3045123903939770	29c03ca137423dd2d392600e145dc5d5	JCB 15 digit	38.057716089140996	-121.721748573350538
19070	2020-04-09 02:19:16	2020-04-09	Talon West	talon.west@warmmail.com	Wichita	Kansas	55938704069328296	7378f83dacadc931c9cdc1f2d0193099	Diners Club / Carte Blanche	37.6478994121652093	-97.4025896989941629
19071	2020-04-09 02:20:14	2020-04-09	Drew Aufderhar	drew.aufderhar@geemail.com	San Francisco	California	869953723572213893	7a40ff7a6a94f79c9e42b9763213892b	JCB 15 digit	37.7742184980651459	-122.454065577406695
19072	2020-04-09 02:35:01	2020-04-09	Iverson Schaden-Cruickshank	iverson.schaden.cruickshank@geemail.com	San Francisco	California	4598133388515758	f18bf750dd54f529b1ff3774d3259b1e	Discover	37.7777016210441801	-122.411128572439324
19073	2020-04-09 02:37:17	2020-04-09	Jonell Feest	jonell.feest@geemail.com	Hialeah	Florida	4395471944218441	56e1da3cafa851e02bac42297104576a	American Express	25.8133434693306683	-80.3503115338176457
19074	2020-04-09 02:59:12	2020-04-09	Davie Kub V	davie.kub.v@geemail.com	Saint Paul	Minnesota	4687207705876	3d41d5af7f02d2953b07755ddaba35c4	Mastercard	44.8772797807991495	-93.0986408208761418
19075	2020-04-09 03:01:39	2020-04-09	Elissa Mohr-Cruickshank	elissa.mohr.cruickshank@warmmail.com	San Francisco	California	180086702238963944	1cfd48a9bc4b92b368891decd0595aa1	Voyager	37.7926272163587029	-122.426670323416275
19076	2020-04-09 03:19:07	2020-04-09	Mr. Matt Stracke	mr.matt.stracke@geemail.com	Houston	Texas	4315384735885525	3a2db35acf2ae54f4c44200094a9675e	VISA 16 digit	29.694287366660685	-95.3772223556894829
19077	2020-04-09 03:27:55	2020-04-09	Reubin Rowe	reubin.rowe@geemail.com	Washington	District of Columbia	3088901856601453652	b05615ceeb3cd9acfad48f432bb4f1e5	VISA 13 digit	38.8985760353770118	-76.9240081119097852
19078	2020-04-09 04:02:59	2020-04-09	Mr. Clemon Schinner	mr.clemon.schinner@geemail.com	Oakland	California	51725136067096400	482640380e0208457eccea2a9c519651	VISA 13 digit	37.8331348741483708	-122.248908859255977
19079	2020-04-09 04:17:06	2020-04-09	Braxton Hessel Sr.	braxton.hessel.sr.@geemail.com	Los Angeles	California	3016249922698177	6924bdd619607f31d81c47b3a0d324a1	JCB 15 digit	34.0148056345392007	-118.47180776446983
19080	2020-04-09 04:22:09	2020-04-09	Denton Gleichner	denton.gleichner@geemail.com	North Las Vegas	Nevada	210041454074482803	00898a2121adbe4f786242b5f1ba65d7	Voyager	36.3611106971900924	-115.134572969399031
19081	2020-04-09 04:27:12	2020-04-09	Joselyn Lesch-Nienow	joselyn.lesch.nienow@woohoo.com	San Francisco	California	4600542074506408	4d3c2e0fb8d2ed19dedaec8b276a821c	VISA 13 digit	37.7806976857247747	-122.460979038830857
19082	2020-04-09 04:29:02	2020-04-09	Miss Lesli Kessler	miss.lesli.kessler@geemail.com	Elk Grove	California	3425860057417865	7bf44bbe9966fca22dd3c6e603ddf89b	Voyager	38.4364359803315239	-121.38287309002132
19083	2020-04-09 04:31:20	2020-04-09	Elna Corkery DDS	elna.corkery.dds@warmmail.com	Dallas	Texas	53422022544619202	20b349da31ca4874aab7f51825b124fe	American Express	32.872131664286556	-96.7164939937610058
19084	2020-04-09 05:11:51	2020-04-09	Melissia Powlowski	melissia.powlowski@woohoo.com	New York	New York	180090703435534367	c211342178ea7e8e77c1bb37a8f446b6	JCB 16 digit	40.6553556340504443	-73.8438035997923379
19085	2020-04-09 05:22:18	2020-04-09	Ms. Nada Hilpert DDS	ms.nada.hilpert.dds@warmmail.com	Fayetteville	North Carolina	3112745332814380439	47e2477e2d5e72e80667b571b06e15fe	Voyager	34.9894146162338515	-78.9577008887324467
19086	2020-04-09 05:52:53	2020-04-09	Hezekiah Breitenberg-Morar	hezekiah.breitenberg.morar@geemail.com	San Francisco	California	180013787327065618	f8114417334164e0e735d35fa5bee3e8	Discover	37.7745294711064403	-122.410673464277792
19087	2020-04-09 05:55:41	2020-04-09	Orson Osinski	orson.osinski@geemail.com	Berkeley	California	3158929590395730888	e03bcef5d19c1366a94bc2da87f73168	Mastercard	37.9066233262233183	-122.281455583173198
19088	2020-04-09 06:43:54	2020-04-09	Kaydence Bode PhD	kaydence.bode.phd@geemail.com	Indianapolis	Indiana	3528547363541839520	f1fb3b1cf956f4a5735a9edb705d438e	JCB 15 digit	39.7237141967758518	-86.2050595546342464
19089	2020-04-09 07:11:39	2020-04-09	Mrs. Gwenda Kuvalis	mrs.gwenda.kuvalis@woohoo.com	Portland	Oregon	3528532680753928700	70fea2e9a1c4c00bb9f6b7398bf74adc	VISA 13 digit	45.5036702318470887	-122.578932176623496
19090	2020-04-09 07:25:45	2020-04-09	Carolyne Emard	carolyne.emard@geemail.com	San Diego	California	3707660190695704	35f8c05ab86fe28b715950ea135e3285	Diners Club / Carte Blanche	32.8155000562846695	-117.154509774167096
19091	2020-04-09 07:27:27	2020-04-09	Bailey Wintheiser	bailey.wintheiser@geemail.com	San Francisco	California	3088000835088372692	26fe9256380207322e23bd9a17517701	American Express	37.7395933870203351	-122.440762891707777
19092	2020-04-09 07:34:25	2020-04-09	Saniyah Abshire	saniyah.abshire@geemail.com	San Francisco	California	180029939580879225	209852dc3dfafcdd9f81f214564b3def	JCB 15 digit	37.753586146005091	-122.419301236191444
19093	2020-04-09 08:30:25	2020-04-09	Amit Bins DDS	amit.bins.dds@geemail.com	Bakersfield	California	869956189610519419	39f5e09156fab2237c67d3443627f43f	JCB 16 digit	35.3461076530802956	-118.927779968575763
19094	2020-04-09 08:57:13	2020-04-09	Amare Parisian	amare.parisian@warmmail.com	Jurupa Valley	California	060469091116827	55d8fb80c47df732d22d772c2b65c7cc	Discover	34.0157343821994971	-117.467629303925122
19095	2020-04-09 09:06:34	2020-04-09	Winter Gleichner DDS	winter.gleichner.dds@geemail.com	Seattle	Washington	3025819678869866	3e7afcd3e542aee31ff2cf84ddc667ab	VISA 16 digit	47.6345122198034048	-122.276493372341235
19096	2020-04-09 09:08:18	2020-04-09	Gail Lindgren	gail.lindgren@geemail.com	Oakland	California	3088692868579047294	6687b29dcd22368ca7b72c6d7c684080	VISA 16 digit	37.7730633497176029	-122.280929409732423
19097	2020-04-09 09:10:25	2020-04-09	Collins Leannon	collins.leannon@geemail.com	Chesapeake	Virginia	4551655261891	13077cc090070926a5ec4b9ea5c37dc2	VISA 13 digit	36.6491324124630538	-76.3552709480125458
19098	2020-04-09 10:03:24	2020-04-09	Mardell Hermann	mardell.hermann@warmmail.com	Glendale	Arizona	630402333793079	8f40e55d526accd76468f05984a27334	Voyager	33.6328329331003104	-112.180202331605926
19099	2020-04-09 10:13:16	2020-04-09	Miss Alina Schinner MD	miss.alina.schinner.md@geemail.com	McAllen	Texas	4724795580061521	608f918c60731a13aed8d63c6f4aad9e	VISA 13 digit	26.21728063238114	-98.2570646044645457
19100	2020-04-09 10:18:55	2020-04-09	Hessie Borer	hessie.borer@geemail.com	San Francisco	California	869921015520128813	b98b981b170cc654d3138860b9015b5a	JCB 16 digit	37.7891011414236999	-122.470092325755857
19101	2020-04-09 10:20:14	2020-04-09	Larae Bednar	larae.bednar@geemail.com	Kansas City	Missouri	3022577181315792	73066cca4152dec1794e828092ed10b6	Discover	39.0607882939580833	-94.6363711756412016
19102	2020-04-09 10:26:08	2020-04-09	Alexus Kemmer	alexus.kemmer@geemail.com	Nashville	Tennessee	6011012679936247284	ba75a1daffc3c055f2a845a8fa3bdde9	JCB 15 digit	36.195231097203866	-86.7783346772566375
19103	2020-04-09 10:43:50	2020-04-09	Jerimy Hilpert	jerimy.hilpert@geemail.com	Lubbock	Texas	3047723555528736	05656ce60e2649074b92fd7b95ffea46	Diners Club / Carte Blanche	33.6650402030482923	-101.954477247447528
19104	2020-04-09 10:46:01	2020-04-09	Jajuan Lehner MD	jajuan.lehner.md@woohoo.com	Miami	Florida	53096791556144144	95cfc326fefe4e855e82965b87bf7bf7	JCB 15 digit	25.7451790795799376	-80.1342038332358015
19105	2020-04-09 10:46:49	2020-04-09	Nyla Larkin	nyla.larkin@geemail.com	Richmond	Virginia	6011790080796953129	2616bdcbd7dfeffaaaad52eeed299fd3	Voyager	37.4318723529797026	-77.5022192645110124
19106	2020-04-09 11:18:44	2020-04-09	Dr. Arba Kunze I	dr.arba.kunze.i@geemail.com	Springfield	Massachusetts	3778404177878676	8c75adafe71fad93c926c2dda8dec1fa	Voyager	42.0966495041474644	-72.6258073160983741
19107	2020-04-09 11:26:40	2020-04-09	Dr. Fernando Casper	dr.fernando.casper@geemail.com	Los Angeles	California	3158270666968213851	8f72a6334d243198c797d5d6ed897ae5	Discover	34.057723374744505	-118.434735765307394
19108	2020-04-09 11:29:47	2020-04-09	Wendi Boyle-Willms	wendi.boyle.willms@warmmail.com	Pomona	California	4831192409678	ae36dc6ec5b1bad7927fb1cd506ebc76	Mastercard	34.0710309415161632	-117.825634969907256
19109	2020-04-09 11:44:24	2020-04-09	Nada Cormier	nada.cormier@woohoo.com	Vallejo	California	3088272635916193240	1603aad7e4cf24facd08922358c73ad4	JCB 15 digit	38.016773435482385	-122.282521460890763
19110	2020-04-09 11:46:11	2020-04-09	Alfredo Lesch-Turner	alfredo.lesch.turner@geemail.com	San Diego	California	4996977479120730	8842c03e5c2d96a6488057ff440edfa0	JCB 16 digit	32.834312002041564	-117.057474891273316
19111	2020-04-09 12:00:09	2020-04-09	Ozell Roob DVM	ozell.roob.dvm@warmmail.com	Tulsa	Oklahoma	3743786515166976	6d048f44afdec152a3c01a917078095c	JCB 16 digit	36.1140104433424725	-95.9673027233175873
19112	2020-04-09 12:11:55	2020-04-09	Mahalie Abbott	mahalie.abbott@geemail.com	Houston	Texas	869962906457305004	b32181f01f8b1b162e373b16ffd6f940	Diners Club / Carte Blanche	29.7707710647568113	-95.4152267981801145
19113	2020-04-09 12:30:27	2020-04-09	Laila Hickle	laila.hickle@geemail.com	Frisco	Texas	869947569631389896	81f2ce9e0239069c71c6358792662947	Mastercard	33.25048486632258	-96.782339583171904
19114	2020-04-09 12:39:12	2020-04-09	Aurthur Bergnaum	aurthur.bergnaum@geemail.com	New York	New York	676261620162083	79a2fe994bc17ed507bb39769c16e2a9	VISA 13 digit	40.66447896112129	-73.9602464557986679
19115	2020-04-09 12:57:57	2020-04-09	Tianna Marks-Mills	tianna.marks.mills@geemail.com	San Jose	California	3010761265188596	c25b7c96c93cf2ac8e327108f5cbc4b6	VISA 13 digit	37.3704151280511212	-121.747953171025586
19116	2020-04-09 13:19:11	2020-04-09	Ceasar Feest	ceasar.feest@warmmail.com	Saint Paul	Minnesota	4098070735838779	034e7bf8b1c9473acc238decf3458612	Discover	44.8681913597449693	-93.1699812762703772
19117	2020-04-09 13:22:48	2020-04-09	Evon Connelly	evon.connelly@geemail.com	Jacksonville	Florida	4753036213423	8fae4fd32b8e7d8d373a663ab4c7f0af	Discover	30.382919321866332	-81.6821229384824647
19118	2020-04-09 13:27:26	2020-04-09	Mr. Clide Mertz IV	mr.clide.mertz.iv@geemail.com	Hayward	California	869944215221471297	443e271fc87feee31b9ecf1bb484d370	Diners Club / Carte Blanche	37.5491532513394972	-122.008314564104751
19119	2020-04-09 13:52:38	2020-04-09	Delma Rempel	delma.rempel@woohoo.com	Indianapolis	Indiana	869941512064879377	1b8b26ca1841b5058a1e479042f59986	JCB 16 digit	39.6996231287725223	-86.0909696205720252
19120	2020-04-09 13:54:34	2020-04-09	Dr. Percy Jenkins PhD	dr.percy.jenkins.phd@warmmail.com	Detroit	Michigan	869947206831651151	ad9b25d5d0b9ec173e0f3ef417a00b2f	JCB 16 digit	42.2910766385886845	-83.1864838388402035
19121	2020-04-09 14:18:25	2020-04-09	Dr. Georgianna Fay MD	dr.georgianna.fay.md@warmmail.com	San Francisco	California	6011377061944858106	f689acb0402c21b52154a9c285b5c063	Discover	37.7735591058370233	-122.424198863851601
19122	2020-04-09 14:39:19	2020-04-09	Austin Fadel	austin.fadel@warmmail.com	Sacramento	California	4015433242201347	2502365b8e19e3351bf135eefc4683c1	JCB 16 digit	38.5009454998452227	-121.555130805705105
19123	2020-04-09 15:13:54	2020-04-09	Jalissa Adams-Sporer	jalissa.adams.sporer@geemail.com	Fort Lauderdale	Florida	3042150868372484	04f7c292db42256d72eb860bdf2de930	Discover	26.1369593855913749	-80.1896325072560359
19124	2020-04-09 15:14:50	2020-04-09	Amelia Turner DDS	amelia.turner.dds@geemail.com	New York	New York	4796575860765303	81d0e62dd629cb5187acad4dd3799e5d	Discover	40.7225669843833913	-73.8830012680858346
19125	2020-04-09 15:20:45	2020-04-09	Lanny Wunsch	lanny.wunsch@geemail.com	Berkeley	California	4171315211698399	8de00f8b7f21c8cbea7357d2003501c0	Voyager	37.9168529633111646	-122.273371918634993
19126	2020-04-09 15:48:48	2020-04-09	Onnie Gottlieb-Schroeder	onnie.gottlieb.schroeder@geemail.com	Birmingham	Alabama	4113958125438	7ddf0b5798afd04bd19309337eb5854b	VISA 13 digit	33.610454161584002	-86.8729704151637918
19127	2020-04-09 16:02:16	2020-04-09	Sydnee Russel	sydnee.russel@geemail.com	Toledo	Ohio	3045463135738115	5f8e81be2b645dcacb0ea7be0be13273	Diners Club / Carte Blanche	41.6597651750486335	-83.4852758479170518
19128	2020-04-09 16:15:09	2020-04-09	Liane Kiehn	liane.kiehn@woohoo.com	Houston	Texas	869998146636332532	afa134cc4a99130f07e20e28178fb179	Diners Club / Carte Blanche	29.7325682199172689	-95.4833048935063147
19129	2020-04-09 16:21:34	2020-04-09	Karina Rath	karina.rath@woohoo.com	Berkeley	California	3337234326553492239	a3ead9d3aaaa7fe785a76e59fb03bb28	Voyager	37.8636079073296941	-122.283167372957678
19130	2020-04-09 16:21:59	2020-04-09	Hervey Bradtke	hervey.bradtke@geemail.com	Chicago	Illinois	210097715262414623	2a153c39e4e48e457f6ceb2faa105dc4	American Express	41.878895594489201	-87.6292754952359871
19131	2020-04-09 16:30:38	2020-04-09	Dr. Jonnie Dibbert PhD	dr.jonnie.dibbert.phd@geemail.com	San Diego	California	6011082983341564688	4c9cf016f0f5cfabc6b6d86585a0b45b	Discover	32.7465939168885356	-117.085374101148929
19132	2020-04-09 16:32:02	2020-04-09	Tommy Gutmann	tommy.gutmann@warmmail.com	South Bend	Indiana	869969878979509921	6eb70ed8f52fd17534edb33d21668987	American Express	41.6933405813440743	-86.322688390180474
19133	2020-04-09 16:56:26	2020-04-09	Rand Streich	rand.streich@geemail.com	Denver	Colorado	3112368984814115060	ea5cdb2a07573b13e317ac05ca987b69	JCB 16 digit	39.6973227460455149	-104.977616963560138
19134	2020-04-09 17:10:27	2020-04-09	Perry Hilpert Sr.	perry.hilpert.sr.@geemail.com	Corpus Christi	Texas	675923324593070	cd4a37406584fb3401a23b9c07860df3	VISA 13 digit	27.7535287232540568	-97.2368887002874231
19135	2020-04-09 17:11:28	2020-04-09	Dr. Rolanda Huels PhD	dr.rolanda.huels.phd@geemail.com	Austin	Texas	3790148357345634	00aecdb443a8fc9dd6fc8acf60fdf303	Discover	30.3662371776659015	-97.6760344432439638
19136	2020-04-09 17:13:08	2020-04-09	Pink West	pink.west@warmmail.com	Sacramento	California	3745697894754001	a980cba38069ad272a2f151b49f22232	VISA 16 digit	38.6304332291040566	-121.448281338928638
19137	2020-04-09 17:19:31	2020-04-09	Miss Pheobe Harris PhD	miss.pheobe.harris.phd@warmmail.com	San Francisco	California	55176897675665472	fa058af03d0c05e33da7b6660ff48587	JCB 15 digit	37.765588410886636	-122.43735680284108
19138	2020-04-09 17:35:00	2020-04-09	Levar Bartoletti	levar.bartoletti@woohoo.com	Greensboro	North Carolina	869944187103647916	dc8b84bbeea9ce9d042be0a949554ab5	JCB 16 digit	36.0162828045547059	-79.8651998476106684
19139	2020-04-09 17:48:20	2020-04-09	Carroll Bergstrom	carroll.bergstrom@woohoo.com	Kenosha	Wisconsin	3035232133939508	57de3f941f7045cb3ec0739585116f67	Diners Club / Carte Blanche	42.6493352265402663	-87.8450452675338909
19140	2020-04-09 18:22:59	2020-04-09	Jesse Goldner	jesse.goldner@geemail.com	Atlanta	Georgia	3337592115781469606	4040ffe444d98d1a303647403ee2e1a8	Mastercard	33.7774730014890423	-84.4022455649029553
19141	2020-04-09 18:27:05	2020-04-09	Altha Kreiger PhD	altha.kreiger.phd@geemail.com	Anaheim	California	6011538352428154898	c221330b633b7ab7182d8e7c82a4e889	Discover	33.9322824583221205	-117.789336892657346
19142	2020-04-09 18:35:59	2020-04-09	Mrs. Phoenix Boehm	mrs.phoenix.boehm@geemail.com	Pittsburgh	Pennsylvania	869973097889260061	5ada3b00657abb9c3109fb6ff5071cb7	Maestro	40.4449752484869194	-80.0160617992453354
19143	2020-04-09 18:44:46	2020-04-09	Marco Smitham	marco.smitham@geemail.com	New York	New York	3031694628238387	77d3ee2354fce7151d734abb6277e95d	Maestro	40.6617712783850749	-73.8786722235742985
19144	2020-04-09 18:50:28	2020-04-09	Birtie Hartmann	birtie.hartmann@geemail.com	Oakland	California	4006369640176197	98c21ae44918f1c51d24200a6e2534e0	Maestro	37.7868617866195606	-122.255875158642993
19145	2020-04-09 19:04:33	2020-04-09	Dr. Derrick Lindgren III	dr.derrick.lindgren.iii@geemail.com	Albuquerque	New Mexico	3088741096380541369	6c7388cf58fbbf32e02f09b96f0dfa7c	JCB 16 digit	35.0720672639686626	-106.548296807946272
19146	2020-04-09 19:11:50	2020-04-09	Hamilton Bailey	hamilton.bailey@geemail.com	Amarillo	Texas	869973476418850610	38a3d8da89500771d074d311c71e8e43	Diners Club / Carte Blanche	35.243366691207143	-101.925312741179766
19147	2020-04-09 19:21:54	2020-04-09	Lars Langworth	lars.langworth@geemail.com	Lexington	Kentucky	3088615392221214891	2ed13a286fcdfe69ded1d40d73f1db0d	JCB 16 digit	38.1306186991620848	-84.4306441143520061
19148	2020-04-09 19:35:17	2020-04-09	Lars Kuphal	lars.kuphal@geemail.com	New York	New York	4191388356963	528e50c82efe0fb0fd977efdc5dca984	American Express	40.7472628514040238	-74.0059569351736428
19149	2020-04-09 19:40:11	2020-04-09	Manley Schroeder MD	manley.schroeder.md@woohoo.com	Grand Rapids	Michigan	3412012203933073	4a83fd5655e7d11df3505c4b144f9884	Maestro	43.0261083416443313	-85.7451021918695488
19150	2020-04-09 20:06:10	2020-04-09	Nataly Koelpin-Kiehn	nataly.koelpin.kiehn@geemail.com	Jurupa Valley	California	869925651913622461	39e195ce1c31a2d9de87d684630a6405	VISA 16 digit	34.0950458759836863	-117.43192637949474
19151	2020-04-09 20:11:35	2020-04-09	Talan Mueller	talan.mueller@geemail.com	Oakland	California	6011764493043853327	4d495e99bad4ebe669b437683e831f8a	Discover	37.8174542403029434	-122.297251236244065
19152	2020-04-09 20:12:05	2020-04-09	Ben Jacobs-Bahringer	ben.jacobs.bahringer@geemail.com	Sandy Springs	Georgia	639026962684580	b5a8356f9b1e0815772d6e7770ed608e	Diners Club / Carte Blanche	34.0196835598032905	-84.2959090519778442
19153	2020-04-09 20:19:25	2020-04-09	Eugenia Langosh	eugenia.langosh@geemail.com	Milwaukee	Wisconsin	3096150312247688499	f76223636fdb06bfb2eb6a8f2ae23964	JCB 16 digit	43.1062466318804738	-87.9390246165085614
19154	2020-04-09 20:23:00	2020-04-09	Shyann Pollich	shyann.pollich@woohoo.com	Albuquerque	New Mexico	4328603095683	945bb58d5a576aef44fbc2d47e11520b	Maestro	35.1026402386970844	-106.695347577014573
19155	2020-04-09 20:30:36	2020-04-09	China Kshlerin	china.kshlerin@woohoo.com	New York	New York	3030251595715060	aca62859b4aaad3ac97001d973c16215	Mastercard	40.6628301150389007	-74.0326789468888222
19156	2020-04-09 20:33:15	2020-04-09	Alivia Rowe	alivia.rowe@woohoo.com	Chicago	Illinois	4054939617671114	b8c7d45198d78d52a3744ba6ce2c68b5	Voyager	41.7792096937842672	-87.6553496285371381
19157	2020-04-09 20:39:05	2020-04-09	Braiden Emmerich	braiden.emmerich@geemail.com	Anaheim	California	6011601721754489700	cb0651858dc8472a27a1ec46f3d71313	Mastercard	33.9460130045954145	-117.669730568977442
19158	2020-04-09 21:09:30	2020-04-09	Miss Carolann Steuber	miss.carolann.steuber@geemail.com	Boulder	Colorado	52158179027507294	ecd6bfc1a5eaefd0fb7a8f4a747c3f80	VISA 13 digit	40.0150187730770597	-105.195406642756993
19159	2020-04-09 21:09:54	2020-04-09	Matthias Kilback IV	matthias.kilback.iv@warmmail.com	San Francisco	California	210090475235014029	d6831b2917804ee6fdba50e0a236997a	JCB 16 digit	37.8372387518054865	-122.420522837483475
19160	2020-04-09 21:10:30	2020-04-09	Lionel Luettgen-Carter	lionel.luettgen.carter@warmmail.com	Columbus	Ohio	503867056913311	770a18f1c32e93cb66a7973f3e3d3351	Mastercard	39.9396348415452991	-82.990809791092957
19161	2020-04-09 21:12:31	2020-04-09	Mr. Lukas Reilly	mr.lukas.reilly@woohoo.com	New York	New York	869945031266242553	d7676ce15e9da6887e861350f7a2ef09	Mastercard	40.737301963962615	-74.0084680012322877
19162	2020-04-09 21:19:28	2020-04-09	Dr. Siddie Denesik DVM	dr.siddie.denesik.dvm@geemail.com	Lafayette	Louisiana	4320451063939	c261a8d54774ccd9a55e9d95bd20517a	JCB 16 digit	30.2612565528579047	-92.1050129054430755
19163	2020-04-09 21:21:20	2020-04-09	Crystal Wyman	crystal.wyman@geemail.com	Oklahoma City	Oklahoma	676100177113065	096a791b8adf1ea81600cfa2cbef9ae4	VISA 13 digit	35.3974588713984986	-97.4824489327043295
19164	2020-04-09 21:25:07	2020-04-09	Beatrix Brekke-Abbott	beatrix.brekke.abbott@woohoo.com	West Palm Beach	Florida	3158627458131519871	679b499cdb148be8723d223cd4691819	Maestro	26.7908236037321394	-80.1116370371378963
19165	2020-04-09 21:32:47	2020-04-09	Adelbert Parker	adelbert.parker@warmmail.com	Columbus	Ohio	3088032829547219836	47d671dbce53e12e2ef61bd3143e9806	JCB 15 digit	39.9970214974645515	-82.9491890339415647
19166	2020-04-09 21:43:11	2020-04-09	Soren Huels	soren.huels@woohoo.com	San Jose	California	6011214048956272075	0c3f7c7a97fe06279c55b096d98b195c	American Express	37.3203180342733845	-121.749654790222266
19167	2020-04-09 21:51:28	2020-04-09	Tammi Champlin	tammi.champlin@geemail.com	Sacramento	California	6011790600491960663	395026417cc212aab1b23e71acab3573	VISA 16 digit	38.4938587947081814	-121.561300818926085
19168	2020-04-09 22:05:52	2020-04-09	Mr. Tyler Schowalter DVM	mr.tyler.schowalter.dvm@geemail.com	Killeen	Texas	3528591168825747223	f559569680de2ddc4b6146a59cf46c50	Discover	31.0763576383002089	-97.8285320139192009
19169	2020-04-09 22:13:54	2020-04-09	Dr. Gideon Emmerich DVM	dr.gideon.emmerich.dvm@geemail.com	San Francisco	California	54346410201048901	a4f9dff59e72dbaa8b321bb899fec584	VISA 13 digit	37.7868274233732535	-122.417530141709435
19170	2020-04-09 22:27:47	2020-04-09	Rollo Krajcik PhD	rollo.krajcik.phd@woohoo.com	Chattanooga	Tennessee	4197834430922	bf57494c3fb84fb39afa19e45de4bd1e	American Express	35.1231187286172073	-85.1896621654570083
19171	2020-04-09 22:51:49	2020-04-09	Derrick Johnston Jr.	derrick.johnston.jr.@warmmail.com	New York	New York	4454385466844053	6e4c9ab723341228197a844ab2132a48	Maestro	40.6579900978822266	-73.9075748772721681
19172	2020-04-09 23:06:38	2020-04-09	Yvonne Spencer	yvonne.spencer@geemail.com	Westminster	Colorado	6011748097037472605	e48ecf56af2f17806ef0666c8aad566e	Mastercard	39.8329918474264417	-105.064120729514968
19173	2020-04-09 23:18:55	2020-04-09	Humphrey Kulas	humphrey.kulas@geemail.com	Austin	Texas	3027516161535123	eed319c567823dc035240f4810e3bba1	VISA 16 digit	30.2101661948613796	-97.7693760162923553
19174	2020-04-09 23:23:45	2020-04-09	Eli Senger DVM	eli.senger.dvm@geemail.com	Costa Mesa	California	3158035627887678034	e906eeaacd32a4f8252de39c055b3cc7	JCB 15 digit	33.6328899982865934	-117.81952813848406
19175	2020-04-09 23:47:54	2020-04-09	Hughie Nikolaus	hughie.nikolaus@geemail.com	Washington	District of Columbia	869928858840020126	d81aa6e48f818083b463f55b7a25827c	Mastercard	38.8985117031525789	-76.9355156131766762
19176	2020-04-09 23:54:13	2020-04-09	Euphemia Fay	euphemia.fay@geemail.com	Tampa	Florida	3112566885534280532	e40799bc55bec50d5f0f8d50f8306765	Diners Club / Carte Blanche	27.8915513482060256	-82.5262800247620731
19177	2020-04-10 00:23:45	2020-04-10	Aubrey Considine	aubrey.considine@geemail.com	San Francisco	California	3442526898324904	1bdfaaf2ca094ea31fe053d7725db19e	JCB 15 digit	37.765598790624594	-122.427457462262154
19178	2020-04-10 00:25:08	2020-04-10	Amirah Weimann DDS	amirah.weimann.dds@woohoo.com	Fayetteville	North Carolina	53832525970321220	fa3711e41e36888ffb1de52350621f2f	Maestro	35.1068498526487502	-79.051394730959089
19179	2020-04-10 00:26:23	2020-04-10	Jadon Bode III	jadon.bode.iii@woohoo.com	San Francisco	California	3759790726693332	6c705053575c541e2a6341c1cd76e609	JCB 16 digit	37.7547912784447419	-122.413181023182631
19180	2020-04-10 00:29:46	2020-04-10	Mariah Wiegand-Monahan	mariah.wiegand.monahan@woohoo.com	Houston	Texas	4713897486449710	8b4e95267c932b9d29f2b061cedf68fd	VISA 16 digit	29.8259239688128233	-95.3726342385184012
19181	2020-04-10 00:39:31	2020-04-10	Johny Douglas	johny.douglas@geemail.com	San Francisco	California	3096650023108997391	44280fc2484bab53be4a8e8a4f4c3918	VISA 16 digit	37.7688452435805004	-122.430535516320802
19182	2020-04-10 00:43:16	2020-04-10	Dedrick Cummings	dedrick.cummings@geemail.com	San Francisco	California	210070298163120376	1b1c9839c9ac4148aba0a6bfc21754e6	JCB 16 digit	37.7793359640832804	-122.40744487357226
19183	2020-04-10 00:44:21	2020-04-10	Mrs. Birtie Waters	mrs.birtie.waters@geemail.com	San Francisco	California	4253301837717467	b7967c872c4de8451b01750af077d278	American Express	37.8034173262842046	-122.449638188745993
19184	2020-04-10 00:47:07	2020-04-10	Miss Geraldine Wisozk	miss.geraldine.wisozk@geemail.com	Tampa	Florida	210021625353702441	0f6f956167c153cebf9c6c4eabbffb40	JCB 16 digit	28.069652027322352	-82.386218031656739
19185	2020-04-10 00:47:50	2020-04-10	Stephanie Smith	stephanie.smith@geemail.com	Baltimore	Maryland	869919280275465109	cecda213ecaed39aab247d07a43f5896	Discover	39.388950135326013	-76.690887177225207
19186	2020-04-10 00:49:45	2020-04-10	Haylie Kertzmann	haylie.kertzmann@geemail.com	Oakland	California	3757051327246083	8d52a8953e985901d31ab779b25d3407	VISA 13 digit	37.7958133721111409	-122.285736084271193
19187	2020-04-10 01:00:51	2020-04-10	Jaidyn Zemlak	jaidyn.zemlak@geemail.com	Gainesville	Florida	3725168671411334	280ab02d75618889751f45628739414c	Diners Club / Carte Blanche	29.6925645108159628	-82.334781090576584
19188	2020-04-10 01:21:36	2020-04-10	Latifah Gleichner	latifah.gleichner@geemail.com	Mesa	Arizona	53771995238858938	9a91e4673e0e754132f001f3a95199c8	Maestro	33.3356242667563265	-111.762336111895365
19189	2020-04-10 01:25:52	2020-04-10	Westin Leuschke	westin.leuschke@geemail.com	Chicago	Illinois	4220153296287544	9c5e1eabd04ce76d4250a3c734a1eaa8	JCB 16 digit	41.9337133636534247	-87.7350287442590968
19190	2020-04-10 01:47:05	2020-04-10	Rex Ruecker	rex.ruecker@woohoo.com	Scottsdale	Arizona	501851185963744	7ff86e08ddfec6eddf039a32471ef6c7	Voyager	33.691313857970016	-111.956220453787964
19191	2020-04-10 01:50:09	2020-04-10	Owens Beahan	owens.beahan@woohoo.com	San Francisco	California	3158415009216330951	849e3024a582b08d663de1cb29857409	American Express	37.7521238141184199	-122.446278273667247
19192	2020-04-10 01:59:48	2020-04-10	Ms. Minnie Reichel MD	ms.minnie.reichel.md@geemail.com	Augusta	Georgia	3750976632955084	9cfc8ce3223ebd0d6baeb55b22723195	American Express	33.2697387930210624	-82.0551964524962045
19193	2020-04-10 02:31:10	2020-04-10	Payten Ziemann-Sipes	payten.ziemann.sipes@woohoo.com	Portland	Oregon	4041662149941	da88583a7e35a5a1f7dadff8ee1e6922	JCB 15 digit	45.5270121934246248	-122.601025036163634
19194	2020-04-10 02:33:44	2020-04-10	Dr. Desirae Ledner MD	dr.desirae.ledner.md@warmmail.com	Las Vegas	Nevada	210067870286592569	0998e53292ce7a1338583597991170ec	Voyager	36.1491645752552913	-115.341529900275532
19195	2020-04-10 02:49:56	2020-04-10	Hubert Jacobi	hubert.jacobi@woohoo.com	New York	New York	3489018004507139	4bca08d63097e7d5bd7ace402d557944	JCB 15 digit	40.6759194123316519	-73.8911963799863969
19196	2020-04-10 03:00:43	2020-04-10	Lisandro Renner Jr.	lisandro.renner.jr.@warmmail.com	San Francisco	California	4050891010253	94f72254819722af414cd49304950122	VISA 16 digit	37.7466896956933056	-122.439809531691523
19197	2020-04-10 03:02:41	2020-04-10	Izaiah Thompson	izaiah.thompson@geemail.com	New York	New York	6011459194806697089	a1b02572feaaa1ca2ea6fc2d6258e4e3	Maestro	40.7591482538022092	-74.0057669365208568
19198	2020-04-10 03:06:13	2020-04-10	Lurena Connelly-Shanahan	lurena.connelly.shanahan@warmmail.com	Austin	Texas	3158436342562664615	fbe0a136ca4cbb6312b3231a36d318d3	Maestro	30.3073732621628764	-97.7930766635812887
19199	2020-04-10 03:27:09	2020-04-10	Megan Koepp	megan.koepp@woohoo.com	Houston	Texas	4525689344452087	cd4ea201c025e2fa5b0ff74562e4bdfa	VISA 13 digit	29.8235271654170013	-95.3818513141959983
19200	2020-04-10 03:48:53	2020-04-10	Mr. Jered Bergstrom	mr.jered.bergstrom@warmmail.com	Houston	Texas	4620148404184	dbd9ce30499c92ddb69c18859c443d3f	Mastercard	29.7689237129952744	-95.3837653831593713
19201	2020-04-10 03:55:56	2020-04-10	Imelda Fritsch	imelda.fritsch@woohoo.com	Seattle	Washington	55026789553320530	da84b9f5ddf42c1a355b490c4b653528	VISA 16 digit	47.6669272755198179	-122.36107005410976
19202	2020-04-10 03:56:53	2020-04-10	Arielle Zboncak	arielle.zboncak@geemail.com	Aurora	Colorado	676153710281618	c29905e1f6cff4b8f5172a5c3680ddfd	Maestro	39.7218741309009502	-104.721292981424185
19203	2020-04-10 04:03:18	2020-04-10	Ms. Martine Upton	ms.martine.upton@geemail.com	Norwalk	California	3014117356353084	c3897447231b71cb0b27bd91d1953247	VISA 16 digit	33.9371944611076302	-118.132673178803174
19204	2020-04-10 04:09:22	2020-04-10	Mr. Hardin Sawayn	mr.hardin.sawayn@geemail.com	Victorville	California	3112095591783699055	59cd2aa825170bc060a552a93f3f16f6	Voyager	34.4817696052368774	-117.402166319281235
19205	2020-04-10 04:20:46	2020-04-10	Colon Treutel	colon.treutel@geemail.com	Oklahoma City	Oklahoma	4576060293222525	1488d3204042857c170e025cbd718c54	American Express	35.4283951312679832	-97.4317935367941885
19206	2020-04-10 04:35:43	2020-04-10	Mrs. Georgie Schmidt MD	mrs.georgie.schmidt.md@warmmail.com	Tallahassee	Florida	869955624336021564	f7b3bf082db8d0eb9f3c12a8ec7589ed	JCB 15 digit	30.4862241956893385	-84.1710477370783678
19207	2020-04-10 04:48:33	2020-04-10	Tempie Wyman	tempie.wyman@woohoo.com	New York	New York	501839197494394	43e051f9f51c4bed7027fc22bfe05a34	Maestro	40.6585060349889105	-73.9623606071237418
19208	2020-04-10 04:51:51	2020-04-10	Jordin Bahringer	jordin.bahringer@geemail.com	San Francisco	California	4185359220933466	08626b6c6d1c4d9f9a6a3151d6d7a523	Diners Club / Carte Blanche	37.7481253658300844	-122.435623992003556
19209	2020-04-10 04:52:45	2020-04-10	Harrison Bruen II	harrison.bruen.ii@geemail.com	Cleveland	Ohio	51667189247145126	64db5cea2e51d4363af23c108e5483f3	JCB 15 digit	41.3879639485701887	-81.7716733278013805
19210	2020-04-10 04:55:21	2020-04-10	Evangeline Kuvalis	evangeline.kuvalis@geemail.com	Charlotte	North Carolina	6011029390744678675	462d0126a65f60c52e90e8815f11c5bf	Discover	35.1494027822531763	-80.7538576052468358
19211	2020-04-10 05:00:06	2020-04-10	Gladis Fritsch	gladis.fritsch@woohoo.com	West Jordan	Utah	3528671328613777005	cf4b501daa3d028e239a91c352833a0e	VISA 16 digit	40.5293416477065591	-112.057621016641335
19212	2020-04-10 05:04:12	2020-04-10	Elbert Hane II	elbert.hane.ii@geemail.com	San Francisco	California	4261536569260	90db94acaa8cc608c84f657c1632bf46	Voyager	37.7539283800718053	-122.435565747273586
19213	2020-04-10 05:12:12	2020-04-10	Amil Bins	amil.bins@geemail.com	Peoria	Arizona	4462627020402989	8b9902f1ecdc2f432b32abece385d6a2	Diners Club / Carte Blanche	33.871102732074263	-112.229046366123484
19214	2020-04-10 05:15:51	2020-04-10	Dr. Kelton Koch	dr.kelton.koch@geemail.com	Dallas	Texas	869985051126526582	0c075691a991f06a1d469290806b9778	VISA 16 digit	32.8435283554058515	-96.8130377711690926
19215	2020-04-10 05:28:59	2020-04-10	Harlene Goldner	harlene.goldner@geemail.com	Washington	District of Columbia	502072967404079	5075a2c1502794fba4ad15e5f7aa535d	JCB 16 digit	38.9622954960245664	-76.9299375636249749
19216	2020-04-10 05:30:05	2020-04-10	Marius Batz	marius.batz@geemail.com	Nashville	Tennessee	3001515768474211	fad26d520a880ad695a539faeec557f9	Diners Club / Carte Blanche	36.2350029410917287	-86.7827695217356023
19217	2020-04-10 05:41:32	2020-04-10	Mrs. Love Pouros MD	mrs.love.pouros.md@geemail.com	Atlanta	Georgia	210054277824136872	68ad3754bdc5c429df0d21bdd3b1f450	Diners Club / Carte Blanche	33.6683641708731685	-84.5210725789003163
19218	2020-04-10 05:45:25	2020-04-10	Chantal Rau	chantal.rau@warmmail.com	Oakland	California	52211967782530377	a122d0ef7ef4f4395ea95f2b6e941a01	JCB 15 digit	37.808715462274165	-122.26338875008129
19219	2020-04-10 05:56:11	2020-04-10	Ozie Zulauf	ozie.zulauf@geemail.com	Los Angeles	California	51017770069227527	4813e6e9a416751939c49762c8a0e064	Mastercard	34.097621916034818	-118.377163672865549
19220	2020-04-10 06:13:15	2020-04-10	Taryn Quitzon	taryn.quitzon@geemail.com	San Francisco	California	3442421418578736	a567ba62418b7545ac173f488d5f4cde	JCB 15 digit	37.7598090177010022	-122.424661478335437
19221	2020-04-10 06:28:47	2020-04-10	Chelsey Considine DDS	chelsey.considine.dds@warmmail.com	Topeka	Kansas	55403854701622600	48b43018edd34d125f4ab1d1b0130e09	Mastercard	39.0084055751960719	-95.6742977066606386
19222	2020-04-10 06:48:09	2020-04-10	Bette Jacobs	bette.jacobs@geemail.com	Akron	Ohio	4809512161221137	ae6feb78d52da78a3147757ab8db6259	VISA 16 digit	41.1451765096578725	-81.4490439428795128
19223	2020-04-10 06:51:53	2020-04-10	Maury Krajcik	maury.krajcik@geemail.com	Salinas	California	3799293082783104	fc6ad3cfc6df87c7440e3a6e90af14bf	Diners Club / Carte Blanche	36.7662527173057185	-121.570374952227624
19224	2020-04-10 06:52:43	2020-04-10	Pink Gutkowski-Reichert	pink.gutkowski.reichert@geemail.com	Elizabeth	New Jersey	3034906486591526	2591a4c5f8234f7d2415ff609514ed01	VISA 16 digit	40.7557443598412021	-74.2396627796757969
19225	2020-04-10 07:13:17	2020-04-10	Gabe Hahn	gabe.hahn@geemail.com	Carlsbad	California	869998563577580111	bedf627e539355db3e5f3031abc1148e	Diners Club / Carte Blanche	33.0428400478266155	-117.347916879949338
19226	2020-04-10 07:21:37	2020-04-10	Jaheem Effertz	jaheem.effertz@warmmail.com	San Bernardino	California	4813351106335056	fddc33f4eda091fd3618c3ab174ac6c1	Maestro	34.1677016090400514	-117.369056862989808
19227	2020-04-10 07:32:19	2020-04-10	Theodis Beatty I	theodis.beatty.i@geemail.com	Berkeley	California	3528474186682872530	78b84ebc50eacaa7708591697265feb7	JCB 15 digit	37.8615192614433624	-122.287290928129082
19228	2020-04-10 07:44:49	2020-04-10	Toriano Koepp	toriano.koepp@woohoo.com	Denton	Texas	4259083138893	a8ebb342a51cdae27d9bdc2c6831a00d	JCB 16 digit	33.224608321374653	-97.1392001501876905
19229	2020-04-10 07:47:08	2020-04-10	Alejandra Harber-Hills	alejandra.harber.hills@woohoo.com	New York	New York	4414871867439279	421ad94dc31f6c2d163a2c49c38a58e6	JCB 16 digit	40.6977184409033512	-73.9125582018762799
19230	2020-04-10 08:16:08	2020-04-10	Giada Toy DVM	giada.toy.dvm@warmmail.com	Tulsa	Oklahoma	51140148753369774	6b7b3ec35caca66544b24caccc726040	Maestro	36.0465579189263252	-95.916948070745164
19231	2020-04-10 08:18:21	2020-04-10	Leslie Wilderman	leslie.wilderman@geemail.com	Rochester	New York	3047310758664219	cfdb5ae420b93b55c7930652811a647d	Discover	43.0760707201413808	-77.7030314597073897
19232	2020-04-10 08:19:55	2020-04-10	Orval Crist	orval.crist@geemail.com	Lakewood	Colorado	3088108035844071321	e6e0897892d03e5a8196d5ac32066862	VISA 13 digit	39.7981583769373586	-105.091171207560592
19233	2020-04-10 08:36:54	2020-04-10	Maleah Dicki-Jakubowski	maleah.dicki.jakubowski@geemail.com	San Francisco	California	3528823188124329994	7823e11f0b4b21a0958950f31556578c	VISA 13 digit	37.7605300497247143	-122.416469930751063
19234	2020-04-10 08:45:14	2020-04-10	Electa Towne	electa.towne@warmmail.com	Los Angeles	California	51506121310968030	f8191f4cd7964f06a5e9bc1519b0dbbb	JCB 16 digit	34.008361320463564	-118.453213151962672
19235	2020-04-10 08:55:44	2020-04-10	Adalynn Pfeffer	adalynn.pfeffer@geemail.com	Riverside	California	4634113296095875	1b2e8ab58d38e21bcd053e224b19138c	Mastercard	34.0299556562624872	-117.368882491390025
19236	2020-04-10 08:56:04	2020-04-10	Mervyn Mayer	mervyn.mayer@geemail.com	Fresno	California	3112400295467604346	0eb5d979a5fccd8c3ba138848bfe94c6	JCB 15 digit	36.8342722444668382	-119.762666568170872
19237	2020-04-10 09:09:59	2020-04-10	Rico Leffler-Durgan	rico.leffler.durgan@warmmail.com	New York	New York	4642694786896815	4dbcaac00b6b06e93b942c1ce1189b24	JCB 16 digit	40.607010324927046	-73.9452578136593104
19238	2020-04-10 09:14:07	2020-04-10	Nia Hodkiewicz	nia.hodkiewicz@warmmail.com	San Francisco	California	3337034178439202429	e02e08f3af04db44e404da3c35cac999	JCB 15 digit	37.7429750487638529	-122.410191486701436
19239	2020-04-10 09:22:08	2020-04-10	Perley Kautzer Sr.	perley.kautzer.sr.@warmmail.com	Tampa	Florida	869937728274454928	cdb0a8584a28019ef247866b0bb48056	Voyager	27.9250895050935419	-82.5452893395189164
19240	2020-04-10 09:41:54	2020-04-10	Alvy Dicki II	alvy.dicki.ii@woohoo.com	Albuquerque	New Mexico	4415308370414456	f8b2fafebdde1cdc415eacfe6c610ce3	Voyager	35.0819311201240893	-106.714122627775751
19241	2020-04-10 09:45:02	2020-04-10	Judd Cartwright	judd.cartwright@geemail.com	Chicago	Illinois	3112601500981105085	2faedad6a3896dd6bc6be777ea1a7d49	VISA 16 digit	41.7620416811503503	-87.763692035854973
19242	2020-04-10 10:27:48	2020-04-10	Ignacio Botsford	ignacio.botsford@woohoo.com	Salt Lake City	Utah	4139575837121	e81c5cb18a4f8f206cc87e46028df922	Mastercard	40.8442858021385931	-111.86874331957101
19243	2020-04-10 10:38:26	2020-04-10	Sally Bernier	sally.bernier@geemail.com	San Francisco	California	3096101040886409782	84a7f51cdffbb0e9b15c066f8a6f51d8	Diners Club / Carte Blanche	37.7890236965637527	-122.434608487779414
19244	2020-04-10 10:42:02	2020-04-10	Mikala Schimmel	mikala.schimmel@geemail.com	Jersey City	New Jersey	4523423161679	d056698833a0ad25ed7f9c68025d20bc	Discover	40.6255704371198973	-74.0621143561277648
19245	2020-04-10 10:48:47	2020-04-10	Dr. Talmage Bayer	dr.talmage.bayer@geemail.com	Coral Springs	Florida	51836593736581178	79b7a22872e517dfd902908217314e6d	Mastercard	26.2320167985342465	-80.3288605613291224
19246	2020-04-10 10:50:11	2020-04-10	Tilla Macejkovic MD	tilla.macejkovic.md@warmmail.com	Milwaukee	Wisconsin	869944251439834166	94784e42787f8f0187b70cd68e8513dc	American Express	42.9874930434480262	-87.9420160609398067
19247	2020-04-10 10:52:51	2020-04-10	Ms. Sharyn Hane	ms.sharyn.hane@geemail.com	Indianapolis	Indiana	3042807343161564	be58b34407b868cd88d30b29f166154e	Voyager	39.7629491732463194	-86.1929706732477996
19248	2020-04-10 10:57:14	2020-04-10	Arminda Bauch	arminda.bauch@geemail.com	Los Angeles	California	3055300237780928	da1da83cb8ba545b449702ff1c67e46e	Mastercard	34.0574971522536103	-118.441412819269289
19249	2020-04-10 11:10:15	2020-04-10	Mr. Fredric Rath	mr.fredric.rath@geemail.com	Orlando	Florida	675934863461041	6db29179cc7e3e2050cbb5cb96475c89	JCB 15 digit	28.4173413197308768	-81.3072945402901581
19250	2020-04-10 11:11:31	2020-04-10	Braxton Parisian III	braxton.parisian.iii@warmmail.com	Charleston	South Carolina	4501243293599809	794a8790d9d59b02db6bb03da039ca75	American Express	32.9020402110643673	-80.0037898734826598
19251	2020-04-10 11:48:13	2020-04-10	Luana Gusikowski	luana.gusikowski@geemail.com	Dallas	Texas	502032961240192	5bc99ae14b751d6643a67bfe0582c54b	Voyager	32.8089277058646118	-96.7737319902479527
19252	2020-04-10 11:57:03	2020-04-10	Eliza Stokes	eliza.stokes@geemail.com	West Palm Beach	Florida	3000129733940610	70cc5d16f77fd9edbf4f3d0566d2ab78	JCB 15 digit	26.791124714802578	-80.1511636530816531
19253	2020-04-10 12:00:00	2020-04-10	Jeffry Hilll PhD	jeffry.hilll.phd@geemail.com	Houston	Texas	3780798559329281	19210ade33fc4611c1cedb950bd8d16f	Maestro	29.7565195445515229	-95.4431163064684682
19254	2020-04-10 12:05:51	2020-04-10	Lida Schmidt	lida.schmidt@woohoo.com	Henderson	Nevada	869905159075025709	cca513b3714a7b29a63f89226a28e1ab	Discover	35.9600093733917916	-114.984162691018369
19255	2020-04-10 12:14:22	2020-04-10	Shelby Herzog	shelby.herzog@geemail.com	Oakland	California	6011507725871728549	35616734b6398e2243c55fcafeb3ad4c	Mastercard	37.8119841705497564	-122.314761041550554
19256	2020-04-10 12:14:29	2020-04-10	Stan Kilback III	stan.kilback.iii@woohoo.com	San Francisco	California	3088545945939725261	84d19e2991b5daed670cfafaad11fedb	JCB 16 digit	37.7826813030025761	-122.408427213246554
19257	2020-04-10 12:21:20	2020-04-10	Tonja Hyatt-Ruecker	tonja.hyatt.ruecker@geemail.com	Murrieta	California	6011485302007935251	cb9199ec5913d104c627a7d0d8700f1a	Mastercard	33.5995872252251928	-117.207530051879203
19258	2020-04-10 12:25:46	2020-04-10	Clyde Considine	clyde.considine@geemail.com	New York	New York	54665193671221637	874897278f6a85c5cbaef476ce328a0b	Maestro	40.7618867616858296	-73.9975331654202222
19259	2020-04-10 12:26:00	2020-04-10	Darien Hammes	darien.hammes@geemail.com	San Antonio	Texas	639058691928889	0fe5297be89f608f6ae1e232d107537a	Mastercard	29.4064937369968753	-98.4450895207770174
19260	2020-04-10 12:27:19	2020-04-10	Zaire Lemke II	zaire.lemke.ii@geemail.com	Davenport	Iowa	4919812546784073	460feb07bd9d38e3a4f5359b63b4922d	JCB 15 digit	41.523254113251717	-90.6791703888643497
19261	2020-04-10 12:33:41	2020-04-10	Amy Wintheiser DDS	amy.wintheiser.dds@geemail.com	Elizabeth	New Jersey	3096808756110369981	3bb01d2d9caca6825345035a9c4d2695	Maestro	40.6873136727731719	-74.2639953644424651
19262	2020-04-10 12:35:32	2020-04-10	Damion Dooley	damion.dooley@geemail.com	New York	New York	4929044677375	6bce82b45148ed10137a7f835405e811	Maestro	40.6210613442342705	-74.0232818410627544
19263	2020-04-10 12:57:41	2020-04-10	Fernand Weimann PhD	fernand.weimann.phd@woohoo.com	Modesto	California	3056462397015039	7b66dc8655c5ab75a67cc2d7a413aa8f	JCB 16 digit	37.5459108233917505	-121.027184554070232
19264	2020-04-10 12:59:28	2020-04-10	Huey Bergnaum	huey.bergnaum@geemail.com	Waterbury	Connecticut	6011604168417148751	553f6c4a09aee6f013d36935c1d6bfb9	VISA 16 digit	41.5206806169860059	-73.0131775613788534
19265	2020-04-10 13:00:19	2020-04-10	Sophie Dibbert	sophie.dibbert@geemail.com	Elk Grove	California	3112828531310728963	b88cc2a55e4ac9ceadcca4082d0c7de8	VISA 16 digit	38.3962607407294243	-121.448048393977814
19266	2020-04-10 13:13:57	2020-04-10	Dayana Hegmann	dayana.hegmann@warmmail.com	Boise	Idaho	3435510848492010	e0dd2b79980467c9e8d2d247feb2ace8	American Express	43.6976665632005776	-116.151001070459188
19267	2020-04-10 13:16:25	2020-04-10	Mckinley Zieme	mckinley.zieme@geemail.com	Providence	Rhode Island	6011664098793797441	89c74ab960a9e805f64b007289999544	VISA 16 digit	41.7725975636247497	-71.3719528151128486
19268	2020-04-10 13:55:11	2020-04-10	Ruthie Denesik	ruthie.denesik@geemail.com	Oakland	California	676105080381907	9f46a0a3759c7dac21ac7c8d7a3f063e	VISA 16 digit	37.7861549947329536	-122.245664034673183
19269	2020-04-10 13:59:11	2020-04-10	Esmeralda Huels	esmeralda.huels@geemail.com	San Francisco	California	3158986955012134154	84883ddc4e5aef86e93810d463dc920e	Maestro	37.7782784916913101	-122.444728227250238
19270	2020-04-10 14:01:50	2020-04-10	Tyquan Bode-Cummings	tyquan.bode.cummings@geemail.com	Oakland	California	676399812163097	bf8244b2a5ddd8fcb18c46d2e15847e7	VISA 16 digit	37.7891715793358003	-122.285554400130025
19271	2020-04-10 14:07:27	2020-04-10	Lillis Runolfsson	lillis.runolfsson@geemail.com	Charlotte	North Carolina	6011254138105182852	dfd008267372b93e0f0a84072d992ac9	VISA 16 digit	35.2925276350483301	-80.8727406497057615
19272	2020-04-10 14:25:51	2020-04-10	Rusty Carter-Hane	rusty.carter.hane@warmmail.com	Berkeley	California	869964497915181243	7634db2b0b1c34a3b0984a8a1b1d238b	VISA 16 digit	37.8873498446832784	-122.293466009765609
19273	2020-04-10 14:39:19	2020-04-10	Brandt Kilback	brandt.kilback@geemail.com	Minneapolis	Minnesota	639002853222582	9b9a147669dbea1711353d538466eb77	Mastercard	44.8886988376818579	-93.2033546383298841
19274	2020-04-10 14:39:42	2020-04-10	Donnie McGlynn	donnie.mcglynn@geemail.com	Washington	District of Columbia	4261974826088890	78a931080eb74fdbeec2dc903a189e50	VISA 16 digit	38.9929247631490199	-76.946680397421872
19275	2020-04-10 15:02:51	2020-04-10	Shiela Greenholt	shiela.greenholt@geemail.com	Oakland	California	4812357165172	e4d5229115dc2cbe5fc93ec13c51151f	JCB 16 digit	37.787787189623721	-122.283257873181483
19276	2020-04-10 15:06:32	2020-04-10	Selmer Osinski	selmer.osinski@geemail.com	San Francisco	California	3449406312465331	bffb50458bc7a1f5c0bcec8d6438f257	American Express	37.7454488772837635	-122.468987865111046
19277	2020-04-10 15:23:59	2020-04-10	Colin Bednar	colin.bednar@geemail.com	Oakland	California	3744670900911163	48f87548d36f8be816ee20beb9c4ca1d	JCB 16 digit	37.816652056639569	-122.255234091212969
19278	2020-04-10 15:31:24	2020-04-10	West Gibson II	west.gibson.ii@warmmail.com	Buffalo	New York	210076954752868973	4215e2b429bf5a637e983f1b6340a4f5	VISA 16 digit	42.9669257008656871	-78.9080243907801844
19279	2020-04-10 15:50:33	2020-04-10	Miss Angelic Lynch DDS	miss.angelic.lynch.dds@geemail.com	Los Angeles	California	54612573054006180	57f1c23853f6bbbd4787aadc5ae520d2	VISA 16 digit	34.0665707609016408	-118.410357796446604
19280	2020-04-10 16:14:17	2020-04-10	Eugene Dare	eugene.dare@geemail.com	El Paso	Texas	4714441114077	4c6e1b006de8b4ed01e7e612c6e5603b	Diners Club / Carte Blanche	31.9138605934396402	-106.328032909285284
19281	2020-04-10 16:14:24	2020-04-10	Mr. Alvia Cummings III	mr.alvia.cummings.iii@geemail.com	Saint Paul	Minnesota	4089965225282860	43ee5593daea2a55c2b6cdf9cad71cdc	Maestro	45.0373464855305841	-93.1404834585994479
19282	2020-04-10 16:35:38	2020-04-10	Daniela Feest	daniela.feest@geemail.com	Denver	Colorado	180042073334182711	47b5f71e0f2878912de37ab8384bcc51	VISA 16 digit	39.7915318898443076	-104.945542323520783
19283	2020-04-10 16:50:19	2020-04-10	Lyda Donnelly	lyda.donnelly@geemail.com	Cary	North Carolina	6011213632004443134	b733470790799b18cdac4977c8c99564	VISA 16 digit	35.6936987482585053	-78.8484914040278682
19284	2020-04-10 16:55:08	2020-04-10	Joseluis Zboncak	joseluis.zboncak@geemail.com	Rochester	Minnesota	3770010919015259	0e004485da0f62aa22e18fbee851e6e8	VISA 16 digit	43.9931359412983056	-92.5049000175323357
19285	2020-04-10 16:55:19	2020-04-10	Luka Prosacco	luka.prosacco@geemail.com	Gainesville	Florida	869948504773797191	d76d4d1a365f5e9e2941070c068135f0	VISA 16 digit	29.7740135365922001	-82.3237004862971702
19286	2020-04-10 16:58:15	2020-04-10	Brayden Gaylord DVM	brayden.gaylord.dvm@geemail.com	Oakland	California	4919278658431	d767bdad5b6b03016b7b6107829ef9db	VISA 13 digit	37.8114742794885856	-122.28582769808861
19287	2020-04-10 17:18:21	2020-04-10	Vickie Marks MD	vickie.marks.md@geemail.com	Oakland	California	3426917593422509	b81e0e0d7409ee304134a9120b91d0a8	Discover	37.833565160216267	-122.247463741779356
19288	2020-04-10 17:24:18	2020-04-10	Mr. Louis Reichert II	mr.louis.reichert.ii@woohoo.com	Houston	Texas	675917004687061	1192ae134d5af1560fc4c2a48179c0c1	VISA 16 digit	29.7982644434165209	-95.3244532550699972
19289	2020-04-10 17:30:54	2020-04-10	Morton Anderson V	morton.anderson.v@geemail.com	Scottsdale	Arizona	4060361701778501	043774e27d2ccc519d433d920e86841f	Mastercard	33.7614237790118921	-111.902350490210949
19290	2020-04-10 18:10:20	2020-04-10	Terrie Thompson	terrie.thompson@woohoo.com	Salinas	California	3528359179974900952	4fe1597fc506ad18d5120842a5b9a45a	VISA 13 digit	36.6735133819978643	-121.720799679140384
19291	2020-04-10 18:17:42	2020-04-10	Ms. Jaycee Mante	ms.jaycee.mante@geemail.com	New York	New York	3768672404825338	e538b94684918697c812e348be49f104	Diners Club / Carte Blanche	40.7462552312053745	-73.9330579035345465
19292	2020-04-10 18:21:58	2020-04-10	Terrell Gleichner	terrell.gleichner@woohoo.com	Durham	North Carolina	210067216257560211	aceb2e25c2ecdb02f5c747ea174c898d	JCB 16 digit	35.9336134969037033	-78.9271398511152711
19293	2020-04-10 18:25:26	2020-04-10	Dr. Donavan Morissette	dr.donavan.morissette@warmmail.com	Lincoln	Nebraska	4642854618468	7c16726ccb10bcedcedb41202b6e34ba	JCB 16 digit	40.8023528889305851	-96.6869861061845057
19294	2020-04-10 18:35:20	2020-04-10	Lorenzo O'Kon	lorenzo.o'kon@warmmail.com	Chicago	Illinois	3039578103659245	a4869c81966f11f5bcb77858f98cece5	JCB 15 digit	41.8693196965217638	-87.6755901367898929
19295	2020-04-10 18:38:41	2020-04-10	Lanita Hane	lanita.hane@woohoo.com	Nashville	Tennessee	4364353786537905	fcde70fa7d8d0a90d1dddf4b3969affe	JCB 16 digit	36.0738389677491043	-86.7274453708808863
19296	2020-04-10 18:42:21	2020-04-10	Samatha Cormier	samatha.cormier@geemail.com	Edison	New Jersey	869968569780062967	1ea10194a5ae7d1b941dcbca2724f0e6	Diners Club / Carte Blanche	40.5002966275401377	-74.2825624297890812
19297	2020-04-10 18:47:03	2020-04-10	Kadyn Jacobi	kadyn.jacobi@geemail.com	Raleigh	North Carolina	51922621014828378	c26a6f8876ab4028b32459dd3d1bb0a2	Diners Club / Carte Blanche	35.7732192473620145	-78.5701524978440347
19298	2020-04-10 18:50:17	2020-04-10	Orelia Rau	orelia.rau@geemail.com	San Francisco	California	52637810267723131	cb8eaba39f9d372bc598ee7db69f6474	Mastercard	37.7605865576457091	-122.408047503791749
19299	2020-04-10 19:04:30	2020-04-10	Kahlil Nader	kahlil.nader@geemail.com	Fremont	California	3050156786383679	29ceee4a63970d9215e874529e8389c1	VISA 16 digit	37.557845987861981	-121.866231518377361
19300	2020-04-10 19:12:53	2020-04-10	Zoa Dicki	zoa.dicki@geemail.com	San Francisco	California	6011664992586695079	540e85c3c44e2c2f14f7aa7649ea8c76	JCB 16 digit	37.7726848217195723	-122.442313028185225
19301	2020-04-10 19:14:01	2020-04-10	Sharlene Reilly	sharlene.reilly@geemail.com	San Diego	California	3112275642847646178	a68adf2c04ebcfe1bd2e19e7c125a821	Discover	32.7486308614324813	-117.138850158909335
19302	2020-04-10 19:16:17	2020-04-10	Mont Friesen-Abbott	mont.friesen.abbott@geemail.com	Mesquite	Texas	6011415064747005945	f6f06ad59aecd9b31a3fd206705a1336	Voyager	32.7655653547771308	-96.679206036144123
19303	2020-04-10 19:32:03	2020-04-10	Ezell Nienow	ezell.nienow@geemail.com	Fullerton	California	4878630031210704	080bf93ac0ff9d1d0022b8d3bd8458b4	VISA 16 digit	33.9336180084541468	-117.999291420562187
19304	2020-04-10 19:39:57	2020-04-10	Dr. Litzy Harris	dr.litzy.harris@woohoo.com	San Francisco	California	3790322237971154	0dc4ac5164c1eaa89676a372cf4e53c0	Maestro	37.7289140611843692	-122.449793235099307
19305	2020-04-10 19:40:35	2020-04-10	Sylvester Abernathy-Zboncak	sylvester.abernathy.zboncak@geemail.com	Vancouver	Washington	4750535922360471	284d7c93706ec1f0ea5384e9450c179e	Diners Club / Carte Blanche	45.6528242910351594	-122.504729995463777
19306	2020-04-10 19:43:11	2020-04-10	Shyheim Hintz	shyheim.hintz@warmmail.com	Peoria	Arizona	3528356948892562315	1f6360e62fc8ac6eee30c88cef16d821	JCB 16 digit	33.7285476966097946	-112.27772613367253
19307	2020-04-10 19:48:38	2020-04-10	Martina Buckridge	martina.buckridge@warmmail.com	Indianapolis	Indiana	3004263552120545	e2201dfea24fd7dbc3ecce6ad7e38d9e	Voyager	39.7472340488348124	-86.196049110332126
19308	2020-04-10 19:51:35	2020-04-10	Sandy Spinka-Heller	sandy.spinka.heller@geemail.com	San Mateo	California	4201221687704	342d1195d11a6ad0088f51b0df617258	JCB 16 digit	37.5624955252159367	-122.390594047060603
19309	2020-04-10 20:07:35	2020-04-10	Alisha Denesik	alisha.denesik@geemail.com	San Francisco	California	3059266324839784	adeb53935681931213ac211692b7c003	Maestro	37.7290920018363423	-122.454905781246822
19310	2020-04-10 20:09:41	2020-04-10	Zona Stracke-Koch	zona.stracke.koch@warmmail.com	Cincinnati	Ohio	869924219017391077	9c5e7b70583fb6d3e49aff2048dec36d	JCB 16 digit	39.1948305704396205	-84.5024791578568397
19311	2020-04-10 20:18:45	2020-04-10	Orlena Batz	orlena.batz@woohoo.com	Chicago	Illinois	3088312664470291820	252a776d76b7d0ac188cfd03f36633d9	VISA 13 digit	41.8517263405326787	-87.7620659467328323
19312	2020-04-10 20:43:07	2020-04-10	Alois Hoeger-Pfannerstill	alois.hoeger.pfannerstill@woohoo.com	Kansas City	Missouri	4568319352155	0f4fbc408627a9a57b58ce16019f8a38	JCB 16 digit	39.0603126605808768	-94.5636289408653994
19313	2020-04-10 20:47:43	2020-04-10	Kelan O'Conner	kelan.o'conner@geemail.com	Berkeley	California	676257955263827	1a04bf9e17a2d94084ab2c47fbbd8a4d	JCB 16 digit	37.8490568986282554	-122.295739811778276
19314	2020-04-10 20:50:21	2020-04-10	Trudie Lesch	trudie.lesch@geemail.com	New York	New York	4465556206870015	6703d114e0fbc781c0f9138c9a6d759a	VISA 16 digit	40.5883711212538145	-73.9492386001989246
19315	2020-04-10 20:52:51	2020-04-10	Lizabeth Zemlak-Hermiston	lizabeth.zemlak.hermiston@geemail.com	Little Rock	Arkansas	561257771434933	a41c39608a34887ce705e4c1096a8fdd	Voyager	34.6320068270243695	-92.454056100022413
19316	2020-04-10 20:56:35	2020-04-10	Mrs. Stasia O'Keefe DVM	mrs.stasia.o'keefe.dvm@geemail.com	Orlando	Florida	3047379332484311	89e6408ba61b76690ac24365b977b01c	VISA 13 digit	28.4800406508412216	-81.3396853354725948
19317	2020-04-10 21:13:24	2020-04-10	Vira Cummerata	vira.cummerata@geemail.com	Richardson	Texas	4584808093507	6b5ba7036940641eba63d97b6b53d055	VISA 16 digit	32.8833972778405936	-96.7843982402928162
19318	2020-04-10 21:23:55	2020-04-10	Mr. Reynold Hettinger Jr.	mr.reynold.hettinger.jr.@geemail.com	San Francisco	California	6011906593386854664	b74b39fe8d44da356bcd5efe8a297b1d	Voyager	37.7750940113904221	-122.428839926036076
19319	2020-04-10 21:31:15	2020-04-10	Mr. Welton Daugherty II	mr.welton.daugherty.ii@woohoo.com	Grand Prairie	Texas	3158337366151539094	e2652d6976fe3fd9ba8e30688bd74dcf	Discover	32.6914614921022206	-97.0609750028573046
19320	2020-04-10 21:34:17	2020-04-10	Berton Bartoletti	berton.bartoletti@geemail.com	Dallas	Texas	6011746624495248979	4dce020258dd98fe176cb89f85e42fa6	VISA 16 digit	32.8859190576516127	-96.6977374295201031
19321	2020-04-10 21:40:07	2020-04-10	Pedro Kilback	pedro.kilback@woohoo.com	Berkeley	California	869973854559987518	943f3df009683faaeaa939eb2308d962	JCB 15 digit	37.8797339325938367	-122.285849383527321
19322	2020-04-10 22:01:46	2020-04-10	Kevan Schamberger	kevan.schamberger@geemail.com	New York	New York	4995487236995	6e4785cc81e7112581a6d71aa09eb125	Discover	40.6578618074525124	-74.0002459727123352
19323	2020-04-10 22:08:35	2020-04-10	Mazie Rippin	mazie.rippin@geemail.com	Houston	Texas	501882260025042	e3be66c61754db39dfbeafc7959ff716	VISA 16 digit	29.833319109872356	-95.3106974502108955
19324	2020-04-10 22:12:15	2020-04-10	Corine Kassulke	corine.kassulke@geemail.com	Sparks	Nevada	3426715723142603	3d792c371600ba01a4b0f19b6d190f1f	JCB 15 digit	39.6336147987056506	-119.773318789465733
19325	2020-04-10 22:35:19	2020-04-10	Rondal Marks	rondal.marks@warmmail.com	Seattle	Washington	676272105003155	adcd90d3897794511083e297e3896859	VISA 16 digit	47.6918056823704362	-122.331506638314195
19326	2020-04-10 22:44:20	2020-04-10	Coraima Brown	coraima.brown@geemail.com	Austin	Texas	55397634964323460	f8b608c21686cc57c193094af4de818e	VISA 13 digit	30.3106497249692666	-97.7892709397949318
19327	2020-04-10 22:45:20	2020-04-10	Curt Hermann	curt.hermann@geemail.com	Amarillo	Texas	4835619356540391	e07712c115346d44454d76380d14b77b	American Express	35.1146566230967636	-101.793825345099719
19328	2020-04-10 22:46:39	2020-04-10	Miss Laci Schmeler MD	miss.laci.schmeler.md@geemail.com	Richardson	Texas	4296117691656313	f61371f7407bb5c34e4aa7bcc46a7dc2	Maestro	33.0567209684990289	-96.6518725579366134
19329	2020-04-10 22:48:48	2020-04-10	Dr. Delbert Hagenes MD	dr.delbert.hagenes.md@warmmail.com	Los Angeles	California	4728293272270	39fef13c56f6edaf82cd305600fdd4f9	JCB 16 digit	34.0900294282805163	-118.367188702569521
19330	2020-04-10 22:50:08	2020-04-10	Baylee Langosh	baylee.langosh@geemail.com	Hialeah	Florida	3059260069907963	d9aca2d8a5aea9776e33e609c35f9622	VISA 16 digit	25.7760465178616371	-80.3481463654335499
19331	2020-04-10 22:52:50	2020-04-10	Mrs. Ottie Bednar	mrs.ottie.bednar@geemail.com	Fayetteville	North Carolina	6011710792717898020	f63315735a8c61f8ec48f47c46c48538	JCB 15 digit	35.1465595919892166	-79.0728799459654823
19332	2020-04-10 23:50:04	2020-04-10	Hays Blanda	hays.blanda@woohoo.com	Lowell	Massachusetts	869909544473878864	7e65e979129197966d93f2a1ab48e5e8	Mastercard	42.5647846935652225	-71.321106322329868
19333	2020-04-10 23:55:42	2020-04-10	Dolly Weber DDS	dolly.weber.dds@geemail.com	Chicago	Illinois	4682926992962	b8b22f585091c35b8602636d8ca86fde	American Express	41.8168850454337928	-87.7311906047660841
19334	2020-04-11 00:04:01	2020-04-11	Nyah Koelpin	nyah.koelpin@woohoo.com	New York	New York	639091972440225	e3d9947116ea063a4e7721eb584375e0	Discover	40.6428817159719742	-73.9288380817871484
19335	2020-04-11 00:05:41	2020-04-11	Mr. Hilton Kessler	mr.hilton.kessler@geemail.com	Virginia Beach	Virginia	55238334892860096	2239c8eba7500bd5d9d6fd03ac568a6c	JCB 15 digit	36.8603394487127645	-76.0525429012391641
19336	2020-04-11 00:31:03	2020-04-11	Rene Walker	rene.walker@geemail.com	San Francisco	California	4039536099632646	6089e9cffc91b5167cd0be49550ae847	Diners Club / Carte Blanche	37.7238795244306431	-122.410708859817603
19337	2020-04-11 00:33:23	2020-04-11	Jamison Haley-Volkman	jamison.haley.volkman@geemail.com	Washington	District of Columbia	4944071482930054	858d8d75a1674c570e24fdaca5abf980	VISA 16 digit	38.9589284166492504	-77.058687093176701
19338	2020-04-11 00:35:07	2020-04-11	Saint Block	saint.block@geemail.com	San Francisco	California	3337702647019559599	a46d11ddd958ec0234c8897abf1d9e94	Discover	37.7972479832354864	-122.419604454293747
19339	2020-04-11 00:38:34	2020-04-11	Dr. Devyn Walter DVM	dr.devyn.walter.dvm@geemail.com	Chicago	Illinois	4891678055115237	e37daca511d109709c61223e3ab49404	JCB 16 digit	41.9022960422396693	-87.6940323631774561
19340	2020-04-11 00:54:40	2020-04-11	Clarice Abbott	clarice.abbott@geemail.com	Ventura	California	676234197861759	765c4a84f4949a197bb76d6826f056dc	VISA 16 digit	34.3176322178143991	-119.23519281475879
19341	2020-04-11 01:07:21	2020-04-11	Dr. Guss Hauck PhD	dr.guss.hauck.phd@geemail.com	New York	New York	4077694208057	1e39e574480be3cc56baf9bb265d9f4c	JCB 16 digit	40.7439709419142417	-73.9671340504556838
19342	2020-04-11 01:30:44	2020-04-11	Jeramy Rowe-Cremin	jeramy.rowe.cremin@geemail.com	San Bernardino	California	502049466398374	724045e07317c3c97cf7f0d14f7b7ca1	JCB 16 digit	34.0925689942933587	-117.245582756284989
19343	2020-04-11 01:33:54	2020-04-11	Cloyd Botsford	cloyd.botsford@geemail.com	Lubbock	Texas	3443312404630392	eed45a1840e8944d04bc62e3a564e509	VISA 16 digit	33.5040395000524853	-101.933559112987297
19344	2020-04-11 01:38:40	2020-04-11	Jeremiah Weber	jeremiah.weber@woohoo.com	Salinas	California	3112523387014350390	7898462c202ecdf347f7b46ce859a3c0	VISA 16 digit	36.646459276345368	-121.669465614407144
19345	2020-04-11 01:50:49	2020-04-11	Richard Hettinger	richard.hettinger@geemail.com	Jersey City	New Jersey	869905759579141025	4d051852a0c371aea09972f718393245	Discover	40.7669093772243656	-74.024724786677595
19346	2020-04-11 02:03:49	2020-04-11	Joanna Gleichner-Bradtke	joanna.gleichner.bradtke@geemail.com	Miami	Florida	3096644128340573311	e25882ab70bdb908f2b0a0376fa20759	Mastercard	25.7339619954720149	-80.2563910746354594
19347	2020-04-11 02:03:52	2020-04-11	Nelly Huels	nelly.huels@geemail.com	New York	New York	3528040179686692272	bbb60c02e1e5d89c05dd9e5a9a89f4c5	VISA 13 digit	40.6222786198593653	-73.8856395956490104
19348	2020-04-11 02:07:22	2020-04-11	Lorine Kulas	lorine.kulas@warmmail.com	Los Angeles	California	3444041180441703	b7a283658aa34a60b0e9698799814fe5	Diners Club / Carte Blanche	34.0873369819816148	-118.347921989345167
19349	2020-04-11 02:24:09	2020-04-11	Dr. Justin Jones	dr.justin.jones@geemail.com	Arlington	Texas	210041236221167878	979c177904867ff167dd6f40f82bbc37	VISA 13 digit	32.6635185305744358	-97.1176139799438403
19350	2020-04-11 02:26:17	2020-04-11	Lance Huel	lance.huel@geemail.com	Phoenix	Arizona	4729321301973509	e6ea26777e968984983e3caa7999d23d	VISA 13 digit	33.6579445504982075	-112.045156438874457
19351	2020-04-11 02:32:15	2020-04-11	Roby Terry	roby.terry@warmmail.com	New York	New York	54785685041659920	6683afebb63022b769666da6b047e921	VISA 16 digit	40.6596444179527481	-73.936604710052535
19352	2020-04-11 02:54:42	2020-04-11	Jaylen Senger	jaylen.senger@geemail.com	New York	New York	4817010008953855	5c7a1f2a6d972f30314bb82a3afdc50f	JCB 15 digit	40.5779212025683336	-73.9425321826606989
19353	2020-04-11 02:59:06	2020-04-11	Posey Cremin MD	posey.cremin.md@geemail.com	New York	New York	3337782288740878637	334145ba65b4537f7da9cd0ec62691af	VISA 16 digit	40.5742715317979474	-73.9516959873389368
19354	2020-04-11 03:00:15	2020-04-11	Ms. Kierra Grady PhD	ms.kierra.grady.phd@geemail.com	Atlanta	Georgia	869946421128943424	dc45d1d6f4ca1b08a250dcdac2740709	VISA 16 digit	33.6638550447110134	-84.4184219031639458
19355	2020-04-11 03:09:04	2020-04-11	Amare Kerluke	amare.kerluke@geemail.com	New York	New York	3766700534762386	cdc71cfc011c542087ed56ac541c06c1	Discover	40.5901748300753553	-73.8567986686609714
19356	2020-04-11 03:10:20	2020-04-11	Candice Rogahn	candice.rogahn@geemail.com	Houston	Texas	180047031373200492	7e00f7dfe8c97425334c5560b5c16b3b	VISA 16 digit	29.8062839216165258	-95.4709495975185263
19357	2020-04-11 03:24:44	2020-04-11	Shirley Jones	shirley.jones@woohoo.com	San Francisco	California	3048334369681130	6e19fe8841b674e428d7d0c038a406fd	JCB 16 digit	37.7606030902043628	-122.439674505634457
19358	2020-04-11 03:39:17	2020-04-11	Mrs. Mona Fahey DDS	mrs.mona.fahey.dds@woohoo.com	Thornton	Colorado	210099050132551216	cf807cfd0f76d7ae7505ddeab37abb24	VISA 13 digit	39.8754208265204042	-104.921165176031366
19359	2020-04-11 03:43:19	2020-04-11	Alphonsus Raynor	alphonsus.raynor@geemail.com	Grand Rapids	Michigan	4763734532943322	8943e2b9da7bfbad36cf86a8b55349d8	VISA 16 digit	43.0404242504190648	-85.6305640455469614
19360	2020-04-11 03:44:07	2020-04-11	Ethen Cole	ethen.cole@geemail.com	San Francisco	California	210048526993904422	a4ab6d464173f0a3ff6e2b24f20b5f81	VISA 16 digit	37.7941544257367354	-122.432395740372272
19361	2020-04-11 04:01:01	2020-04-11	Orra Marquardt-Balistreri	orra.marquardt.balistreri@geemail.com	San Francisco	California	4675391469188947	9094885bdaf528f03d8e2703dc686a06	VISA 13 digit	37.7842204922096343	-122.431110789454053
19362	2020-04-11 04:06:42	2020-04-11	Rashawn Turner DVM	rashawn.turner.dvm@geemail.com	San Francisco	California	54837345039931447	ec4812cc832531bb20a1446c7bbcbe24	JCB 16 digit	37.7714169246993379	-122.43890089663789
19363	2020-04-11 04:18:54	2020-04-11	Dorman Shields	dorman.shields@geemail.com	Cambridge	Massachusetts	869993207258836559	48f51fdcca5d5e0a43fa77922d47338d	VISA 16 digit	42.3003851854465864	-71.0309126592323281
19364	2020-04-11 04:30:07	2020-04-11	Dwight Larkin IV	dwight.larkin.iv@geemail.com	Santa Rosa	California	4186777824453384	0da805f557d7120b123028b5681bf44e	Mastercard	38.3550389475777749	-122.740689289594442
19365	2020-04-11 04:34:36	2020-04-11	Tabatha Legros-Pollich	tabatha.legros.pollich@geemail.com	New York	New York	3088931433487885672	4f442a6657f8d3c7584561e7d682ed94	Voyager	40.702462823804467	-73.8811615330994158
19366	2020-04-11 04:36:40	2020-04-11	Norval Wolf	norval.wolf@geemail.com	Huntsville	Alabama	869988218019709727	7b8bc1731b441f79823cec5040496a60	JCB 16 digit	34.7815578155927341	-86.6332244796697069
19367	2020-04-11 04:41:11	2020-04-11	Jacquelin Reichel-Barrows	jacquelin.reichel.barrows@geemail.com	San Diego	California	4382934203275720	652f27ee32ee209f1e7cca0823c0f48d	JCB 16 digit	32.7732244460910564	-117.124551418181511
19368	2020-04-11 04:45:07	2020-04-11	Landan Homenick	landan.homenick@warmmail.com	Jacksonville	Florida	55924255167572125	b961d7e5b57e541583655aa1cc46c90a	Mastercard	30.4055133028939366	-81.5849386721927772
19369	2020-04-11 04:50:39	2020-04-11	Mr. Laurence Tillman V	mr.laurence.tillman.v@geemail.com	Denton	Texas	6011000144188774968	efc590ae9e5b613e92fa4073e1d3eba5	Mastercard	33.1192379809714836	-97.2368225140158131
19370	2020-04-11 04:54:37	2020-04-11	Rollin Cronin	rollin.cronin@geemail.com	San Jose	California	503895216895755	9757943782f1e940bc84149151e81b81	Diners Club / Carte Blanche	37.2071702013544723	-121.759481147326156
19371	2020-04-11 05:04:54	2020-04-11	Serena Bahringer	serena.bahringer@geemail.com	New York	New York	4517488370263173	99347edbfe11c33637db371ea414302d	VISA 16 digit	40.6568930580504215	-73.9942567647330378
19372	2020-04-11 05:11:44	2020-04-11	Ms. Helma Rippin MD	ms.helma.rippin.md@geemail.com	Antioch	California	4256360745440	7cf517f6d20b4be336ed9e6296622772	Discover	38.0189146942257921	-121.874888382543617
19373	2020-04-11 05:25:33	2020-04-11	Dr. Saint Hudson V	dr.saint.hudson.v@geemail.com	Macon	Georgia	4884322797249	9448cb39b6c882aa873f3185901c760b	American Express	32.8593286409985268	-83.6944825879957506
19374	2020-04-11 05:28:33	2020-04-11	Toy Schumm	toy.schumm@geemail.com	San Diego	California	3158416225576705009	344e0ddd43da0bbfb4dd388252c705af	VISA 16 digit	32.7761687361236653	-117.067402467261999
19375	2020-04-11 05:39:35	2020-04-11	Park Block-Herman	park.block.herman@geemail.com	New York	New York	3112416471267002302	1c33f21145d04aac4d7028b3f3697f70	VISA 16 digit	40.57734450979531	-73.8824109624035685
19376	2020-04-11 05:45:45	2020-04-11	Channing Adams	channing.adams@geemail.com	Milwaukee	Wisconsin	3088172584367891889	d0595b4aa0362a6b53a3deac096f3e2b	JCB 16 digit	43.1236621516376744	-88.024428520128879
19377	2020-04-11 05:47:14	2020-04-11	Mr. Holden Greenfelder	mr.holden.greenfelder@geemail.com	Overland Park	Kansas	3158239158806369996	35ad4862b9ee58c07a40670423c3bb04	Mastercard	38.8876676967237174	-94.5980065356049664
19378	2020-04-11 05:53:16	2020-04-11	James Leuschke	james.leuschke@geemail.com	San Antonio	Texas	869955552576748770	e819e80c1bd33434dd4f9c14b0ecdfbe	Voyager	29.4516600427754227	-98.4490338660612707
19379	2020-04-11 05:56:47	2020-04-11	Ilo Funk-Kovacek	ilo.funk.kovacek@warmmail.com	Vallejo	California	561297939265381	bae27c1cb42f12e048c9cb99f74201c3	Discover	38.1459956513341538	-122.354567703545086
19380	2020-04-11 06:07:44	2020-04-11	Macy Mosciski-Price	macy.mosciski.price@geemail.com	Detroit	Michigan	4723896608547078	1f6850448741d16a7a25635ae890db93	Voyager	42.3936278023216886	-83.0146027253594241
19381	2020-04-11 06:09:25	2020-04-11	Mr. Melvyn Langworth PhD	mr.melvyn.langworth.phd@geemail.com	Tallahassee	Florida	3772751182679655	36de3ddc802debaa193c9cd915a687aa	American Express	30.3835913720097395	-84.2797373832218284
19382	2020-04-11 06:21:09	2020-04-11	Lindbergh Volkman	lindbergh.volkman@geemail.com	San Francisco	California	676390643275424	4fac084afc60c74e9300ba010d555f8f	Diners Club / Carte Blanche	37.786455705860611	-122.432442784242937
19383	2020-04-11 06:22:00	2020-04-11	Dorothea Jakubowski	dorothea.jakubowski@geemail.com	Columbus	Ohio	4921732213996261	c12a855bb86eabafc85016549a87c30c	Diners Club / Carte Blanche	39.9023183994505573	-83.0176516943845968
19384	2020-04-11 06:25:41	2020-04-11	Dr. Verner Kiehn	dr.verner.kiehn@geemail.com	Vancouver	Washington	4438010146096996	a215a53294f76683e8204deecd5351a6	VISA 16 digit	45.6509746165551249	-122.518655246921625
19385	2020-04-11 06:41:35	2020-04-11	Amanda Zemlak	amanda.zemlak@geemail.com	Renton	Washington	3528371100932853111	ddb7e894117884cd18726ca09169ae48	Voyager	47.5500075002260516	-122.167084805954246
19386	2020-04-11 06:50:06	2020-04-11	Margarette Nolan	margarette.nolan@geemail.com	McAllen	Texas	561244558224653	d40e12cf4fa7eda70c3df83dfea5d14b	JCB 16 digit	26.282044609107821	-98.2067806364349991
19387	2020-04-11 06:50:58	2020-04-11	Ignatz Jaskolski Sr.	ignatz.jaskolski.sr.@geemail.com	San Francisco	California	210056078122041915	08771f695b44e56cffafdd50bff23002	JCB 16 digit	37.787952135781957	-122.421718327159439
19388	2020-04-11 06:58:42	2020-04-11	Lexie Bradtke	lexie.bradtke@woohoo.com	San Francisco	California	869924735904301036	e3cf38a4ae9af186e8ea1adfe889a451	VISA 16 digit	37.8235057792234812	-122.424065463650251
19389	2020-04-11 07:09:48	2020-04-11	Dr. Gorge Gutkowski III	dr.gorge.gutkowski.iii@warmmail.com	Amarillo	Texas	869952817216280754	462f72431607bd88358700839df8d6d4	Diners Club / Carte Blanche	35.1553425102192918	-101.753970878510557
19390	2020-04-11 07:13:03	2020-04-11	Mrs. Ceil Quigley	mrs.ceil.quigley@warmmail.com	Kansas City	Missouri	3112778400750351795	b1bb6a2a4d97c40f8b7a3525e7595c01	VISA 16 digit	39.0704406331129377	-94.5353432618770739
19391	2020-04-11 07:15:11	2020-04-11	Lewis Bauch	lewis.bauch@warmmail.com	San Francisco	California	4600014520156	26057b01a67ab5775687372ddea1cca0	VISA 16 digit	37.8202302942715889	-122.40983723991387
19392	2020-04-11 07:53:35	2020-04-11	Tula Williamson	tula.williamson@geemail.com	Pasadena	Texas	3716715730275224	be31373be38910dbb98890643fb9b39c	Mastercard	29.5708898186557008	-95.1538646160107078
19393	2020-04-11 07:54:28	2020-04-11	Mrs. Sherrie Legros	mrs.sherrie.legros@geemail.com	Phoenix	Arizona	4825304186646	dfe69029e19dd85387990dd4d107716c	VISA 13 digit	33.5513442713234582	-112.029297086310024
19394	2020-04-11 07:55:45	2020-04-11	Allyson Thompson-Lubowitz	allyson.thompson.lubowitz@geemail.com	San Francisco	California	4112645529067842	f623e59aae0786966d2c2a88e8f892b3	Maestro	37.7815892180211037	-122.457114436948615
19395	2020-04-11 08:03:13	2020-04-11	Ms. Gennie Collier	ms.gennie.collier@geemail.com	Overland Park	Kansas	4274709515862865	7836a7d1079ce5bc012de13aa652c43a	VISA 16 digit	38.9635917432941525	-94.7253504833247604
19396	2020-04-11 08:09:46	2020-04-11	Brooklyn Tromp	brooklyn.tromp@geemail.com	San Francisco	California	869967139071354779	feb5b83b34a76811bfb08f6f2b7c7f83	Voyager	37.7556892265154076	-122.417166792986535
19397	2020-04-11 08:14:55	2020-04-11	Marcellus Kulas	marcellus.kulas@geemail.com	Lexington	Kentucky	3017937215710274	06112c7ee423538622311d43810dd705	American Express	37.9708253899931947	-84.4526607104942144
19398	2020-04-11 08:17:37	2020-04-11	Ivie Fritsch-Durgan	ivie.fritsch.durgan@warmmail.com	New York	New York	6011870602535503312	3a8d479000bbf4f993a2cf7485784d05	JCB 16 digit	40.6935772716756929	-73.9875958112895518
19399	2020-04-11 08:20:11	2020-04-11	Lonie Gleason	lonie.gleason@warmmail.com	Philadelphia	Pennsylvania	3018869294465422	31413d24452132b51c93bd096ed80bc1	JCB 15 digit	39.9880026789341088	-75.168828439050543
19400	2020-04-11 08:42:10	2020-04-11	Dr. Arnetta Barrows DDS	dr.arnetta.barrows.dds@warmmail.com	Baltimore	Maryland	6011676588885648821	163f328cc1da2bc9c96f995b60bb111d	Maestro	39.294990970240903	-76.5801842396166137
19401	2020-04-11 08:49:53	2020-04-11	Beau Jaskolski	beau.jaskolski@woohoo.com	Costa Mesa	California	55258205365093941	5c7a73e8ce6bb6d61f8ecae7219914fd	JCB 15 digit	33.6855208737324929	-117.950902980086582
19402	2020-04-11 08:50:30	2020-04-11	Cyril Hand	cyril.hand@geemail.com	New York	New York	210064994272793016	1a01a9d994fc90c7ceb234466bc1a5de	American Express	40.6189730130825168	-74.0266394488874795
19403	2020-04-11 08:56:12	2020-04-11	Saundra Leannon	saundra.leannon@geemail.com	Shreveport	Louisiana	3088616427238620570	a0a570fd42a3c6c9aa191447dc561a7e	VISA 16 digit	32.5233642541110513	-93.8284636771053044
19404	2020-04-11 08:56:43	2020-04-11	Ulises Brakus	ulises.brakus@geemail.com	Plano	Texas	3715410696356033	54f999d569e1a41011a0b3d15bb92140	VISA 16 digit	33.1266168879430793	-96.6590597022507296
19405	2020-04-11 09:10:38	2020-04-11	Dr. Frances Lang V	dr.frances.lang.v@geemail.com	Little Rock	Arkansas	3013095380066677	07b0a4765f89d32d0ccbf33f02294074	Maestro	34.7131261391840908	-92.4058575782332525
19406	2020-04-11 09:16:29	2020-04-11	Jonell Eichmann	jonell.eichmann@geemail.com	Philadelphia	Pennsylvania	3337139197953276514	a74c5f121a2f14a91466befbf853d7d5	Mastercard	39.9951119100634003	-75.0867160665236497
19407	2020-04-11 09:16:48	2020-04-11	Jude Prosacco Jr.	jude.prosacco.jr.@geemail.com	Beaumont	Texas	3057927785585149	ae735a057be7f8b46fdd078f261788ca	JCB 16 digit	29.9932651221822972	-94.1391122282270345
19408	2020-04-11 09:38:38	2020-04-11	Miss Annis Gleichner DDS	miss.annis.gleichner.dds@warmmail.com	Renton	Washington	4154516556854163	70e221875715cdf8f78a29bc2618e329	Diners Club / Carte Blanche	47.4632347859967538	-122.095407938778393
19409	2020-04-11 09:45:33	2020-04-11	Lashawn Harris PhD	lashawn.harris.phd@geemail.com	Seattle	Washington	4666958341487	3ae35470b0de062105d4cde143c0de95	Mastercard	47.626851413764058	-122.347808006910228
19410	2020-04-11 09:53:07	2020-04-11	Jayson Mitchell	jayson.mitchell@geemail.com	Berkeley	California	4549368436917	cf23878e634a9e3e1450a4d1507de170	VISA 16 digit	37.8644350632967956	-122.283662508784843
19411	2020-04-11 10:00:31	2020-04-11	Miss Clydie Douglas DDS	miss.clydie.douglas.dds@geemail.com	Los Angeles	California	3096159252496579406	1eaae53ec101b7816b01d9a6ea52ab53	Mastercard	34.0213785375334297	-118.437011847970254
19412	2020-04-11 10:21:24	2020-04-11	Thresa Casper MD	thresa.casper.md@geemail.com	Fort Worth	Texas	3034958301759762	527e24a2f4588956d26a533c32814344	VISA 16 digit	32.7838325465153915	-97.3305619780726659
19413	2020-04-11 10:27:05	2020-04-11	Judyth Bashirian MD	judyth.bashirian.md@geemail.com	Charlotte	North Carolina	4707357549058683	95741349ef467f2ff8abb689ce10f580	VISA 13 digit	35.2237798739012291	-80.8874062153920619
19414	2020-04-11 10:27:39	2020-04-11	Malaya Morar	malaya.morar@warmmail.com	Fort Worth	Texas	3054464434503656	e92156a95770eddfb12057b1a723be9c	VISA 16 digit	32.7735516282320063	-97.41835643475018
19415	2020-04-11 10:27:44	2020-04-11	Nolia Stroman	nolia.stroman@geemail.com	Salinas	California	869977506157849773	3949d402e327ab62e7c6a00169aa17cf	JCB 16 digit	36.5991559827465522	-121.650510160083698
19416	2020-04-11 10:28:56	2020-04-11	Jarret Grady-Stehr	jarret.grady.stehr@geemail.com	Cleveland	Ohio	3088237323883018492	ca85282eb88b3e123ccdfb1508066e22	Voyager	41.511813767518845	-81.6338840153772338
19417	2020-04-11 10:57:48	2020-04-11	Jammie O'Reilly	jammie.o'reilly@geemail.com	Salinas	California	53317080454132978	cc8208bc2d09f7353f98a3feb4c6d40c	VISA 16 digit	36.6245382533173967	-121.715073092764996
19418	2020-04-11 11:17:23	2020-04-11	Jalynn Zemlak	jalynn.zemlak@geemail.com	Woodbridge	New Jersey	3096713651333383162	2768bbdca1dbc94bec74a9b41a430558	Diners Club / Carte Blanche	40.4986027263727024	-74.3252062714051362
19419	2020-04-11 11:21:54	2020-04-11	Deante Vandervort DDS	deante.vandervort.dds@geemail.com	Mesa	Arizona	869917669051100348	0c4b9490a140f0658cc412955c578554	VISA 16 digit	33.4377574132435029	-111.798207918543
19420	2020-04-11 11:22:33	2020-04-11	Dr. Hadley Mraz	dr.hadley.mraz@geemail.com	San Francisco	California	3052460114306263	2e556dfe2712e85e25c73555ba3a398f	American Express	37.7663721264966554	-122.4439559705569
19421	2020-04-11 11:23:31	2020-04-11	Mr. Rowland Weimann DVM	mr.rowland.weimann.dvm@woohoo.com	San Diego	California	3096355375250769863	6d0dce46287efcd0f1122767c2b4255b	Diners Club / Carte Blanche	32.8065544851656981	-117.194259468130767
19422	2020-04-11 11:30:34	2020-04-11	Mr. Arland Braun PhD	mr.arland.braun.phd@geemail.com	New York	New York	501876557128055	82121fb45ed0deded4c1dd4354684dcc	American Express	40.6252877400945849	-73.877664113453406
19423	2020-04-11 11:34:46	2020-04-11	Mr. Phillip D'Amore IV	mr.phillip.d'amore.iv@geemail.com	Surprise	Arizona	869934052139619036	c34a8503ebc3982a3b9c6705a0f9e332	VISA 16 digit	33.7271211537759754	-112.369413577508922
19424	2020-04-11 11:44:13	2020-04-11	Valentine Wolf	valentine.wolf@geemail.com	Detroit	Michigan	869920814258692615	14cac50bd9de8d812d1fab5f93cdf301	VISA 16 digit	42.3476578154061016	-83.1428747339759013
19425	2020-04-11 11:47:14	2020-04-11	Jessie Quitzon	jessie.quitzon@geemail.com	Salem	Oregon	639006952816053	bef9e680599cf04e832721b0ed55d7fd	JCB 16 digit	45.0081402097165579	-122.986916334337366
19426	2020-04-11 12:05:23	2020-04-11	Mr. Adalberto Gusikowski MD	mr.adalberto.gusikowski.md@woohoo.com	San Francisco	California	869953059408157073	4eca6d6fbbaa29d8d37b44ce948d18e4	VISA 16 digit	37.7779151656306027	-122.439289229207404
19427	2020-04-11 12:09:14	2020-04-11	Ms. Eithel Rogahn	ms.eithel.rogahn@warmmail.com	Los Angeles	California	869973022996965295	086f8218fa6d72579836b50839307ab1	Voyager	34.1186285599466359	-118.418168706539262
19428	2020-04-11 12:12:37	2020-04-11	Michele Lang PhD	michele.lang.phd@warmmail.com	New York	New York	3112770428898563193	3e177922aa214d4106d1af5b03cf1a4e	Voyager	40.7474367759414022	-73.9540723219875247
19429	2020-04-11 12:26:59	2020-04-11	Jill Donnelly PhD	jill.donnelly.phd@geemail.com	Mesa	Arizona	4063454347236	0eb6e154aba61db3a2d93ce7e68a1560	JCB 16 digit	33.3676586611341648	-111.726942471542955
19430	2020-04-11 12:27:47	2020-04-11	Elvin McKenzie	elvin.mckenzie@geemail.com	Jacksonville	Florida	3096844308856276412	5d2cd7d6fd8ee6de761f245456e18fe1	JCB 15 digit	30.3645884823106229	-81.5743101746387822
19431	2020-04-11 12:44:11	2020-04-11	Ms. Moira Hane	ms.moira.hane@geemail.com	Detroit	Michigan	4275085914016	ab9b507aff63a66d036fc6673afb2bca	VISA 13 digit	42.4467184755876659	-83.1362691460296475
19432	2020-04-11 12:49:04	2020-04-11	Adriana Kozey PhD	adriana.kozey.phd@geemail.com	North Las Vegas	Nevada	3112840369741805801	980052a31506e5abaed85ab8ebfd004c	Mastercard	36.1946000370353431	-115.11372569536195
19433	2020-04-11 12:57:53	2020-04-11	Della Baumbach MD	della.baumbach.md@geemail.com	Chicago	Illinois	869927633982276807	6f1696ec0ea8329f9397ef1fd5e74854	Diners Club / Carte Blanche	41.8900885427206759	-87.6437655625894649
19434	2020-04-11 13:19:45	2020-04-11	Edwina Auer	edwina.auer@geemail.com	San Francisco	California	3797028897383001	3415132e0090dff10a1898fda088d6cf	Discover	37.7524109134503618	-122.436503264110314
19435	2020-04-11 13:23:23	2020-04-11	Mr. Hervey Johnson DVM	mr.hervey.johnson.dvm@geemail.com	San Francisco	California	3006527889795353	ce87816d2607f7cb58e7b68adfae78ad	Diners Club / Carte Blanche	37.7942286649015458	-122.407729875462095
19436	2020-04-11 13:44:24	2020-04-11	Mrs. Shante Hayes MD	mrs.shante.hayes.md@woohoo.com	Wichita	Kansas	6011086912459083138	e6f2101a999c5752588f0ad33d5c968e	JCB 15 digit	37.6343603181529787	-97.2844994770564142
19437	2020-04-11 13:50:00	2020-04-11	Evelyn Bradtke	evelyn.bradtke@geemail.com	Tulsa	Oklahoma	6011303577262498323	756141a5833bb9572606c0670308b69c	Diners Club / Carte Blanche	36.196000454052907	-95.8668767782349107
19438	2020-04-11 13:52:05	2020-04-11	Mr. Donnell Cassin IV	mr.donnell.cassin.iv@geemail.com	Oakland	California	210075503042870702	9cf34490c80ff2fded95971bb62114aa	Diners Club / Carte Blanche	37.7997343678768942	-122.29534306781629
19439	2020-04-11 14:04:03	2020-04-11	Emanuel Deckow	emanuel.deckow@geemail.com	Vancouver	Washington	3112641298395768497	59adaf2dd1697bb74c2a0c761a4443f3	Voyager	45.7275266198977874	-122.607399370387938
19440	2020-04-11 14:17:01	2020-04-11	Lonnie Schaden	lonnie.schaden@woohoo.com	Peoria	Arizona	54016237178183604	88f7b85d797ab9cfc5cb46048eeaf29a	American Express	33.8668884583085799	-112.366964316872881
19441	2020-04-11 14:22:45	2020-04-11	Meagan Halvorson	meagan.halvorson@geemail.com	New Orleans	Louisiana	3027550826009265	0889a8956d8ab6100802608c72e81309	Voyager	30.1343408509638166	-89.8535364283509494
19442	2020-04-11 14:32:47	2020-04-11	Lyndon McClure	lyndon.mcclure@geemail.com	Oakland	California	4469890791020	2a1fd24b692bf4f07c79dfb61572cee0	Maestro	37.8263234495834624	-122.280097634475439
19443	2020-04-11 14:33:20	2020-04-11	Kaliyah Ernser	kaliyah.ernser@warmmail.com	Sandy Springs	Georgia	3158200651305942979	7e962ffd64004afbca7525e063293b30	Diners Club / Carte Blanche	33.892591029969978	-84.4399401290424265
19444	2020-04-11 14:46:54	2020-04-11	Ahmad Davis-Romaguera	ahmad.davis.romaguera@woohoo.com	New York	New York	3492258355198519	ab9e9166b02df2a6c2b0709664b1560c	VISA 16 digit	40.584421300724145	-73.8525410431798548
19445	2020-04-11 15:10:30	2020-04-11	Mr. Ayaan Harvey	mr.ayaan.harvey@geemail.com	Phoenix	Arizona	6011339954294213376	3069e2edfb0b91b21046cf1d876f5f98	VISA 16 digit	33.5325516391944163	-112.090713715453077
19446	2020-04-11 15:17:11	2020-04-11	Alonza Hills	alonza.hills@geemail.com	Miami	Florida	4844467144730174	969b21fa2bd6658214ac07c77fd029ca	JCB 16 digit	25.8508968187168264	-80.1994908203244279
19447	2020-04-11 15:20:40	2020-04-11	Jahiem Stehr	jahiem.stehr@geemail.com	San Francisco	California	3096258429276098696	a03fa9d5e1433040fa1bacbb834a85d7	VISA 13 digit	37.8183385849841827	-122.414896999036173
19448	2020-04-11 15:26:41	2020-04-11	Cheryle Osinski	cheryle.osinski@woohoo.com	Bakersfield	California	3158940561592803807	30d93cec3f8986e7b99329a5b0fb5bb9	Voyager	35.4066393677320335	-119.013295953841137
19449	2020-04-11 15:43:15	2020-04-11	Johnie Zemlak	johnie.zemlak@warmmail.com	Charlotte	North Carolina	3716749743154035	ad3cc0e746708fa0dd388f7f046117a1	JCB 15 digit	35.1381075488191073	-80.7330983310882004
19450	2020-04-11 15:46:39	2020-04-11	Onnie Willms	onnie.willms@woohoo.com	Charlotte	North Carolina	4510351886708	18564e337ee0d1237b3e992b4ad2f41e	Mastercard	35.1463216596536299	-80.7501644349135432
19451	2020-04-11 15:55:00	2020-04-11	Berenice Emard	berenice.emard@geemail.com	New York	New York	4749470441989572	3f32530fa3020fb9850b32e83c525633	Maestro	40.6460887440238139	-74.0129306187748881
19452	2020-04-11 15:58:26	2020-04-11	Humphrey Pacocha	humphrey.pacocha@geemail.com	Berkeley	California	869979744712662831	fef5f276d4c7473fa5dbdd65fb61b1bb	American Express	37.8773881577289089	-122.260455532553408
19453	2020-04-11 16:09:17	2020-04-11	Hoover Nader	hoover.nader@woohoo.com	New York	New York	4398836779012084	ebe223ef344c498769d0e8706e40bb1d	JCB 16 digit	40.7114014036711325	-74.0310161109443783
19454	2020-04-11 16:14:32	2020-04-11	Dr. Brayan Koepp	dr.brayan.koepp@warmmail.com	Stamford	Connecticut	180064019230888656	4955255f45f1c5a15dce861950c4c7eb	Maestro	41.0027302529081723	-73.498295718900863
19455	2020-04-11 16:16:13	2020-04-11	Mr. Posey Kreiger III	mr.posey.kreiger.iii@woohoo.com	Oakland	California	3789859593803219	94ea1608a7121d9122c884b8ded171c8	VISA 13 digit	37.7828247612574017	-122.268999463639176
19456	2020-04-11 16:16:16	2020-04-11	Dr. Marylin Christiansen	dr.marylin.christiansen@warmmail.com	Waco	Texas	561286767357923	c6e92352f6c721e23ae842f906720cd7	Maestro	31.6046264636073246	-97.0986679752487731
19457	2020-04-11 16:19:20	2020-04-11	Alexandro Flatley	alexandro.flatley@geemail.com	Stockton	California	4152029768805058	199b18e58ff1acfcfedb226ebe309d4b	American Express	38.0651460318092276	-121.268077847044168
19458	2020-04-11 16:21:47	2020-04-11	Dr. Lexis Weber DVM	dr.lexis.weber.dvm@geemail.com	Chicago	Illinois	4356018032363	bf76443ca340e1ce41e2505597329b65	Discover	41.8181140602402408	-87.6960851744312748
19459	2020-04-11 16:26:24	2020-04-11	Devyn Vandervort-Marks	devyn.vandervort.marks@warmmail.com	Phoenix	Arizona	869914357175036647	23de0d579b94befb2289361da83ededf	Diners Club / Carte Blanche	33.5007059124231361	-112.072182074787477
19460	2020-04-11 16:40:01	2020-04-11	Frona Fahey MD	frona.fahey.md@warmmail.com	Jacksonville	Florida	4554985662341	44aa0b9f42a5460d079d8fcbaa803a51	Mastercard	30.3544517674535506	-81.6372081609521132
19461	2020-04-11 16:49:39	2020-04-11	Primus Murphy-McKenzie	primus.murphy.mckenzie@warmmail.com	San Francisco	California	3019936454092665	6cdf39b812d8d4eba3fe03219d845e4e	VISA 13 digit	37.7730291833859297	-122.425256169483973
19462	2020-04-11 16:57:43	2020-04-11	Isla Wisozk	isla.wisozk@geemail.com	San Francisco	California	502022801925417	c8da9a32488b5fe00cdb42eb4159ec17	Mastercard	37.7794720808792874	-122.418993102764674
19463	2020-04-11 17:03:16	2020-04-11	Luka Gutmann	luka.gutmann@geemail.com	El Paso	Texas	4424743970253442	923d3ee7163221083bd1d30a21c23472	JCB 16 digit	31.9223376457873762	-106.476089144030595
19464	2020-04-11 17:10:10	2020-04-11	Anissa White	anissa.white@warmmail.com	Dallas	Texas	210057539857492465	b2cbf03b2e942c7964ae8a4fd1e250aa	Discover	32.8841229786902716	-96.8308427500966928
19465	2020-04-11 17:14:06	2020-04-11	Siena Hoppe	siena.hoppe@geemail.com	Houston	Texas	4883574213702067	fc913d3e9860b6adf44111c16be9f293	VISA 16 digit	29.7778708693183951	-95.4806459642961585
19466	2020-04-11 17:27:30	2020-04-11	Mr. Tommy Schmidt	mr.tommy.schmidt@woohoo.com	Honolulu	Hawaii	4036062335555775	46972514b27663fd7b1058c059c269a8	VISA 16 digit	21.3204153022479268	-157.784222384516511
19467	2020-04-11 17:39:35	2020-04-11	Alger Davis	alger.davis@geemail.com	Lakeland	Florida	3462700047621115	ad37c930b896039d5507f1b779821ad8	JCB 15 digit	28.0865296062380061	-81.9149869379471909
19468	2020-04-11 17:45:27	2020-04-11	Rosetta Murray MD	rosetta.murray.md@geemail.com	Chicago	Illinois	4238411742881447	fe34f675a58f1a4eada78825bdbd3399	Discover	41.7554226505871853	-87.7801512022998196
19469	2020-04-11 17:53:44	2020-04-11	Pedro Davis	pedro.davis@geemail.com	McAllen	Texas	6011984406440224441	44ee59d31f80b38193986136d982868a	JCB 16 digit	26.2139827816121276	-98.3252269210606755
19470	2020-04-11 17:58:55	2020-04-11	Seward Blanda	seward.blanda@geemail.com	Waterbury	Connecticut	869986162432132657	7f734d74a1e6b4903b00559a063128e1	Discover	41.4866021198723516	-73.0440118766304067
19471	2020-04-11 18:20:12	2020-04-11	Minor Wiza IV	minor.wiza.iv@geemail.com	Waterbury	Connecticut	6011948033216786810	f39aee60ba96c38bb66c26f15f0a1e62	Discover	41.5532617118712508	-73.0165295904416496
19472	2020-04-11 18:21:20	2020-04-11	Mr. Dwaine Schamberger	mr.dwaine.schamberger@geemail.com	Rochester	Minnesota	210047850914101103	28987ab9b64c23166fe977ac4922171b	Discover	44.1053735272862042	-92.5037413592569493
19473	2020-04-11 18:24:55	2020-04-11	Anders Morissette	anders.morissette@geemail.com	Los Angeles	California	6011556157823203852	3d1231b83f9f689daab81989fe7aff76	Maestro	33.9581502681463903	-118.47698268401362
19474	2020-04-11 18:25:31	2020-04-11	Beda Tromp	beda.tromp@warmmail.com	San Francisco	California	3088121519000623614	e90932366f03d52d8c056ff3c9f61982	VISA 13 digit	37.7693000298857768	-122.445603580140983
19475	2020-04-11 18:37:30	2020-04-11	Skyler White	skyler.white@geemail.com	Lewisville	Texas	54403766019605640	970c638ce5948c0d8f8c3a12b50913b6	VISA 16 digit	33.1151867855325293	-97.0476614097163122
19476	2020-04-11 18:39:00	2020-04-11	Adam Nolan	adam.nolan@geemail.com	Oakland	California	3158950696015545911	b744b5850ee3a903dc5d83454ff56618	JCB 16 digit	37.7859350685106605	-122.294641538112785
19477	2020-04-11 19:01:18	2020-04-11	Marsh Schneider	marsh.schneider@geemail.com	Omaha	Nebraska	869917734002312044	08772a88e71324a5516ec6571e3840f5	Voyager	41.3427312912099083	-95.9873367569524873
19478	2020-04-11 19:02:41	2020-04-11	Nira Hansen	nira.hansen@geemail.com	New York	New York	869960534371151031	00110a5827ca69d36e77e5a42013c349	JCB 16 digit	40.6668156909514238	-73.9779547109164213
19479	2020-04-11 19:13:18	2020-04-11	Bowman Connelly	bowman.connelly@warmmail.com	Toledo	Ohio	3088077453180002742	16ad0fe0395bec05f7d91b26e7a761f7	VISA 13 digit	41.6854407678995287	-83.6373218105040479
19480	2020-04-11 19:17:45	2020-04-11	Kristen Frami	kristen.frami@geemail.com	Chicago	Illinois	3751839595907899	3ba94655d5f1e87708276b3e41294fc8	Maestro	41.7991823043044661	-87.6802106948133542
19481	2020-04-11 19:21:10	2020-04-11	Halley Windler	halley.windler@warmmail.com	Plano	Texas	6011878073890454925	89ac9446cd4c90391ddaaeaf406ec08d	JCB 15 digit	33.1416709889743473	-96.8382996869456036
19482	2020-04-11 19:35:09	2020-04-11	Mame Prohaska	mame.prohaska@woohoo.com	Washington	District of Columbia	869924846909416230	6443873a64e825f0d6e99e5aa518ce9e	Discover	38.8873763069774938	-77.0117285679772579
19483	2020-04-11 19:36:50	2020-04-11	Vera Morissette	vera.morissette@woohoo.com	Baton Rouge	Louisiana	869923095591395572	8a24ec633615d8218d149b37a7d58c47	Voyager	30.3673883438322676	-91.1921818039953678
19484	2020-04-11 19:42:55	2020-04-11	Sudie Nolan	sudie.nolan@geemail.com	Glendale	California	3739007798603262	d29e99f2754f2a0ded79a824be7ae6fc	Diners Club / Carte Blanche	34.1656568077146972	-118.172650313926113
19485	2020-04-11 19:44:12	2020-04-11	Erie Kiehn-Collier	erie.kiehn.collier@woohoo.com	Tucson	Arizona	4171584805003429	8278aa7c7343862037351a0fff0fa219	VISA 16 digit	32.1650310214184216	-110.860269053023671
19486	2020-04-11 19:56:52	2020-04-11	Alyse Stracke MD	alyse.stracke.md@woohoo.com	San Francisco	California	3337688744981668108	e1ac13c26430ca826febc087395e1a46	JCB 15 digit	37.7625143640851348	-122.432737374064089
19487	2020-04-11 20:03:58	2020-04-11	Cesar Sipes	cesar.sipes@geemail.com	Aurora	Colorado	3088926181785603324	9d107d890bd31f336bba31454b98b035	Diners Club / Carte Blanche	39.7631213968731458	-104.612393704441189
19488	2020-04-11 20:11:02	2020-04-11	Ms. Arlena Schroeder PhD	ms.arlena.schroeder.phd@geemail.com	Cincinnati	Ohio	3419954331279239	568aafebe35d5a911a9730520bfcba5f	Maestro	39.2238462824605421	-84.4922290200639452
19489	2020-04-11 20:14:37	2020-04-11	Hope Hudson	hope.hudson@warmmail.com	Wichita	Kansas	180054756991616253	3b478c1943d38dac5cd3fee4379c4f0b	Voyager	37.7827830049086373	-97.2656836743667697
19490	2020-04-11 20:15:49	2020-04-11	Ulises Rosenbaum DVM	ulises.rosenbaum.dvm@warmmail.com	Oakland	California	210007271629272337	3455d4509a2acdd2368cda8d6f29aa5b	Discover	37.8174095629841602	-122.293892282134891
19491	2020-04-11 20:21:18	2020-04-11	Guthrie Kuhlman	guthrie.kuhlman@geemail.com	San Francisco	California	210077674061004529	bdf57d1b870f7271a4a3837af472a433	JCB 16 digit	37.7303056263136867	-122.414081008506784
19492	2020-04-11 20:23:07	2020-04-11	Dr. Dakotah Collins	dr.dakotah.collins@woohoo.com	New Orleans	Louisiana	180037237496363990	2aaf0157e10279a092ce997f6d97aecb	Voyager	30.0753898271374389	-90.0231926825623958
19493	2020-04-11 20:31:01	2020-04-11	Dr. Shonda Turcotte	dr.shonda.turcotte@woohoo.com	Los Angeles	California	6011084451489960629	e5c19647e1c302e697c4ef6cbb324172	Diners Club / Carte Blanche	34.010014656871185	-118.370922934961683
19494	2020-04-11 20:47:47	2020-04-11	Mariyah DuBuque	mariyah.dubuque@geemail.com	Seattle	Washington	4148538394989	fa75e7afb1f71219d70c7f917051854a	VISA 16 digit	47.6249841880444436	-122.306788701044013
19495	2020-04-11 20:50:34	2020-04-11	Dr. Stephan Grant III	dr.stephan.grant.iii@geemail.com	High Point	North Carolina	3754957049786367	edc7e5f81ebcc65793954f68d042753f	Discover	36.026342906625942	-80.0875587797462885
19496	2020-04-11 21:13:28	2020-04-11	Celie Schmitt	celie.schmitt@woohoo.com	Fort Collins	Colorado	180038923938554812	04ab9c632fc503eb50a0d6f6d68677c9	JCB 16 digit	40.501636678461729	-105.119109097956866
19497	2020-04-11 21:16:48	2020-04-11	Benard Wintheiser	benard.wintheiser@woohoo.com	Syracuse	New York	3037124823797965	1867a93a86da15ee146b06768ed52fe4	JCB 16 digit	42.9764995184577998	-76.0710315173737825
19498	2020-04-11 21:17:36	2020-04-11	Mr. Hakim McClure III	mr.hakim.mcclure.iii@geemail.com	San Diego	California	869961543225800429	c52cca485fbd1824f56eac29f5082336	JCB 15 digit	32.7381425157256416	-117.148162940321498
19499	2020-04-11 21:31:49	2020-04-11	Scottie Feest	scottie.feest@geemail.com	Dallas	Texas	4948268310737	c1bf9e465b64a217f97323248136ba06	Voyager	32.8590023396343014	-96.7730173369832301
19500	2020-04-11 21:40:38	2020-04-11	Jaden Balistreri	jaden.balistreri@geemail.com	San Antonio	Texas	675987860318986	bc9081db38f4dcefeea234591feade27	Discover	29.5605924426183115	-98.4369706511799194
19501	2020-04-11 21:53:37	2020-04-11	Mr. Fitzhugh Gutkowski DDS	mr.fitzhugh.gutkowski.dds@geemail.com	Lancaster	California	4501795064598161	f2894b8a556b97bc141502a38b90504a	Mastercard	34.7389801289200832	-118.090841110187768
19502	2020-04-11 21:54:12	2020-04-11	Trevion Reinger IV	trevion.reinger.iv@geemail.com	Colorado Springs	Colorado	3112760055825157161	b94b27c758b33d56adc9069e553c748f	VISA 13 digit	38.9535876444589348	-104.789304713547978
19503	2020-04-11 21:54:47	2020-04-11	Tito Veum PhD	tito.veum.phd@warmmail.com	Sugar Land	Texas	210054303460573150	82ee6ff0f46e1d69a2c6573b41615387	JCB 16 digit	29.6941599947452524	-95.5675957960084048
19504	2020-04-11 22:08:03	2020-04-11	Vina Cartwright	vina.cartwright@geemail.com	San Francisco	California	4759009320999380	b37165900d612ade63f4d7d9bcfe1e85	Diners Club / Carte Blanche	37.7932805026158647	-122.452911813673708
19505	2020-04-11 22:18:04	2020-04-11	Mrs. Verna Jacobi DDS	mrs.verna.jacobi.dds@geemail.com	San Francisco	California	3088244573321897250	90623672382f1cdcf180a6bab5a5758a	JCB 15 digit	37.7863359630992903	-122.403243711968813
19506	2020-04-11 22:51:35	2020-04-11	Jaxson Nolan MD	jaxson.nolan.md@geemail.com	Oakland	California	6011360791817809104	450ef8ff0e9bb42120b5391ae6dcda29	Diners Club / Carte Blanche	37.7845600954253626	-122.266687794602475
19507	2020-04-11 23:00:11	2020-04-11	Dr. Prosper Schulist	dr.prosper.schulist@geemail.com	New York	New York	3337591344143855945	cd7168f2b25b53a65e40d319109be01e	VISA 13 digit	40.5947132210005037	-73.9750348618149758
19508	2020-04-11 23:02:31	2020-04-11	Tyron Volkman	tyron.volkman@geemail.com	Glendale	California	3442901522774347	55509c1af6691b33cccbaf75c01e9839	Maestro	34.1753173918683046	-118.161518828653925
19509	2020-04-11 23:09:35	2020-04-11	Karin Upton	karin.upton@geemail.com	San Diego	California	561201669741454	63a887d8acec7e9ae978f17ed55b09c0	Mastercard	32.8264817202530779	-117.157899719607087
19510	2020-04-11 23:23:38	2020-04-11	Hali Smitham	hali.smitham@geemail.com	New York	New York	4688415884465864	4228c0da01f92ed6f7769e2198b50df1	VISA 16 digit	40.5825245136152972	-73.8862415582768648
19511	2020-04-11 23:31:53	2020-04-11	Nikhil Goyette	nikhil.goyette@geemail.com	New York	New York	503806497895802	8c00d4879ad86262cc6d5ff4bb4a12ca	VISA 16 digit	40.6320590556822694	-73.8707886948145926
19512	2020-04-11 23:36:51	2020-04-11	Mrs. Pheobe Hirthe	mrs.pheobe.hirthe@geemail.com	Durham	North Carolina	180064931835849224	d564b4afa13d6b3f2b6eb7dcf90603ae	Maestro	36.0101038607083268	-78.8443346806239305
19513	2020-04-12 00:11:15	2020-04-12	Beula Okuneva	beula.okuneva@geemail.com	Worcester	Massachusetts	4160655165584035	599dcd328517bb1d8f005440dde820d9	Discover	42.2188981535546475	-71.7802620436318222
19514	2020-04-12 00:17:34	2020-04-12	Bell Hauck	bell.hauck@geemail.com	San Francisco	California	210066276310721144	246b7bb71723f53e24ad593e6d4d3dc6	Maestro	37.7798917921082946	-122.42688385237831
19515	2020-04-12 00:48:59	2020-04-12	Eustace Stracke PhD	eustace.stracke.phd@geemail.com	San Diego	California	4547597094309	ac3a5366a88e0921baaa6c3471f29d29	American Express	32.7406499127458801	-117.078012545723467
19516	2020-04-12 00:50:24	2020-04-12	Beckham Runte-Boyer	beckham.runte.boyer@geemail.com	San Francisco	California	4037739542222815	acf52e820168dfd582a0b1d9f74ac192	Discover	37.7868346736720255	-122.41686939546409
19517	2020-04-12 00:53:22	2020-04-12	Emogene Ritchie	emogene.ritchie@geemail.com	San Antonio	Texas	4988234719199	52becf2c2a00f26a5071e3ebb7f8cdc0	JCB 15 digit	29.4165869922447953	-98.544461466960982
19518	2020-04-12 00:56:40	2020-04-12	Alissa Yundt	alissa.yundt@geemail.com	New York	New York	4604608468178	fc22e3fc51662889748befd422e17a98	JCB 16 digit	40.5671137861199682	-73.8602747487265532
19519	2020-04-12 00:57:19	2020-04-12	Dr. Maryam Collins DDS	dr.maryam.collins.dds@warmmail.com	St. Louis	Missouri	3088529064703292746	f3851f71aefb66152ceeae845f208d8c	JCB 16 digit	38.5469728583160816	-90.2155036197979001
19520	2020-04-12 01:02:33	2020-04-12	Channing Cormier	channing.cormier@woohoo.com	San Francisco	California	3446644127788173	a589e9cefbd4bad18bb616c9973e6823	VISA 16 digit	37.790406003141932	-122.391021175555792
19521	2020-04-12 01:04:30	2020-04-12	Ephriam Stark	ephriam.stark@warmmail.com	Tampa	Florida	4437972083376	ae70e4c6b9c5bf79cf8dfe4511f1c54c	JCB 15 digit	28.0009303996454904	-82.4782595453064857
19522	2020-04-12 01:07:11	2020-04-12	Ms. Karli Schaefer	ms.karli.schaefer@geemail.com	Boise	Idaho	6011768007895889209	cca9e67c5b231b6007930debeb88dbda	JCB 16 digit	43.6482351162608708	-116.293376571331919
19523	2020-04-12 01:10:50	2020-04-12	Marlen Yost	marlen.yost@geemail.com	San Francisco	California	3088977218646022753	0883f2d174708739ce8ceee700c8caed	JCB 15 digit	37.7955341623981695	-122.422581567341439
19524	2020-04-12 01:33:59	2020-04-12	Dr. Tatia Dach MD	dr.tatia.dach.md@geemail.com	Philadelphia	Pennsylvania	3088513738929196769	8f0c90b4715f28fd355373dfd5bccb6d	JCB 16 digit	40.0555580200120787	-75.0692433209523671
19525	2020-04-12 01:45:00	2020-04-12	Demetric Volkman	demetric.volkman@geemail.com	San Francisco	California	3043048727871655	b2b0a21788f622e89d82880a77f0b5fd	Discover	37.7918939211631795	-122.447015293776388
19526	2020-04-12 02:09:10	2020-04-12	Della Swaniawski	della.swaniawski@geemail.com	Fresno	California	503874644912219	be307562f3bf879efa1506433b6f14e3	Maestro	36.7423271623779115	-119.705298572137579
19527	2020-04-12 02:19:30	2020-04-12	Dequan Osinski	dequan.osinski@geemail.com	Birmingham	Alabama	54979164854755510	eda4c4205598d0e56114ffd903c7e1ee	JCB 16 digit	33.5398889567960055	-86.8405900291409409
19528	2020-04-12 02:39:35	2020-04-12	Mrs. Pepper Gutkowski	mrs.pepper.gutkowski@geemail.com	Detroit	Michigan	4668712209820821	603f887ca1b841537de8809780cc0cf4	Diners Club / Carte Blanche	42.4736888072378989	-83.0780561673574169
19529	2020-04-12 02:42:06	2020-04-12	Lynne Crona	lynne.crona@geemail.com	Athens	Georgia	3088751278101933516	648ab0e10f355d194e83546fd5cab8c8	Discover	34.0150844293836485	-83.4047265067346331
19530	2020-04-12 03:42:06	2020-04-12	Vester Von	vester.von@geemail.com	Clovis	California	4504262400054695	b2949932fe503a2384b5c71fba4409f0	VISA 16 digit	36.8636071797337408	-119.594363342046364
19531	2020-04-12 03:48:32	2020-04-12	Shelton Skiles IV	shelton.skiles.iv@geemail.com	New Orleans	Louisiana	54709003724100837	cb79449529a2dbfddf378cf4e52ddeca	JCB 16 digit	30.0356285828180596	-90.0145252692308304
19532	2020-04-12 04:26:33	2020-04-12	Karley Grimes-Schmitt	karley.grimes.schmitt@geemail.com	Concord	California	4454806472702175	6feffb3afec478cfbf1bbfa33d8bad4a	American Express	37.9873088383048767	-121.996658644423263
19533	2020-04-12 04:29:35	2020-04-12	Mr. Darin Swaniawski	mr.darin.swaniawski@geemail.com	Columbia	South Carolina	3112127189825788119	eedf4d7a219a164e6f6c28aa5f99b9b2	Discover	33.9752151454597708	-80.8833536169510268
19534	2020-04-12 04:33:25	2020-04-12	Theadore Konopelski	theadore.konopelski@geemail.com	San Francisco	California	4434320311682445	87a9b3b1ce1eabafa95927466c8e0a5c	Maestro	37.76374426924842	-122.413092634926173
19535	2020-04-12 04:45:29	2020-04-12	Jacey Gaylord MD	jacey.gaylord.md@geemail.com	Westminster	Colorado	4302086638234975	3eb4c2114f2120b0a34725bdb68c2666	JCB 16 digit	39.8127411375593354	-105.139307373590398
19536	2020-04-12 04:47:11	2020-04-12	Tevin Wyman I	tevin.wyman.i@geemail.com	Riverside	California	210014625583736333	8ee6aec98120e45cb0a2d3ddbcbd0de5	JCB 16 digit	33.9113374226208748	-117.340105393386253
19537	2020-04-12 04:50:12	2020-04-12	Ardella Jakubowski	ardella.jakubowski@warmmail.com	San Francisco	California	180083253798544768	cd7b78421149aaf31820e3a49ef7f642	JCB 16 digit	37.7632513514037953	-122.428306375233007
19538	2020-04-12 04:53:15	2020-04-12	Katie Runte	katie.runte@warmmail.com	Glendale	Arizona	4223500512452855	1dac9b8000a2e98e1707a73fdc150cbe	Discover	33.4703609201818679	-112.104771450606734
19539	2020-04-12 05:16:16	2020-04-12	Tyreke Ziemann V	tyreke.ziemann.v@geemail.com	San Francisco	California	869932124488775909	ff43d690734f9724ec899d2892d0451b	American Express	37.7863710315588364	-122.402560850604132
19540	2020-04-12 05:21:45	2020-04-12	Dr. Elliot Mayer	dr.elliot.mayer@geemail.com	Hillsboro	Oregon	3088107669855859512	662b0ea45badea66f52146305fcae9f6	VISA 16 digit	45.5170730014070841	-122.846121225475144
19541	2020-04-12 05:25:55	2020-04-12	Almus Gorczany	almus.gorczany@geemail.com	San Francisco	California	675970848995455	84a25d8dffa20bfb5e44e62be1cd82b5	VISA 13 digit	37.7887508681439286	-122.448920422705143
19542	2020-04-12 05:42:30	2020-04-12	Jana Hahn MD	jana.hahn.md@geemail.com	North Charleston	South Carolina	180064346466140605	7f79954fe95398c7ca40dea36b433b6e	Mastercard	32.8730197670098363	-79.9807144421245937
19543	2020-04-12 05:45:09	2020-04-12	Brielle Koch	brielle.koch@geemail.com	Cleveland	Ohio	4236964331531791	5d1871fc533fca82b825dcfbb1c8c75d	Maestro	41.3867225306890845	-81.764729746361823
19544	2020-04-12 05:55:41	2020-04-12	Dr. Clemente Emard II	dr.clemente.emard.ii@woohoo.com	Richmond	Virginia	4336298477009	c3e6bb4c21771c2e9571fd52f3c5c71c	Voyager	37.6083488346297301	-77.5566409039068958
19545	2020-04-12 06:00:47	2020-04-12	Cindy Larkin	cindy.larkin@geemail.com	Pasadena	California	51887531602701544	39e27561de0d57455a7a7cb425eeb52f	VISA 16 digit	34.1642178096197568	-118.108859494775913
19546	2020-04-12 06:35:26	2020-04-12	Dr. Zechariah Fay MD	dr.zechariah.fay.md@geemail.com	New York	New York	501889735812847	52b0c180234b66a0284c3fb95583d89d	VISA 16 digit	40.7282105387412017	-73.9642175027064894
19547	2020-04-12 06:45:45	2020-04-12	Mr. Colbert Nicolas II	mr.colbert.nicolas.ii@geemail.com	Columbia	South Carolina	4195041073619248	142ce9eca43eb2a9fd1994bf8428393a	VISA 16 digit	33.95216263321079	-80.8674840582087597
19548	2020-04-12 07:09:47	2020-04-12	Cleora Keeling MD	cleora.keeling.md@woohoo.com	Akron	Ohio	4896414600376735	9f97cae2d8fef302e8a506dfb47a5270	JCB 16 digit	41.0142221673224157	-81.6037990419041392
19549	2020-04-12 07:11:33	2020-04-12	Demarion Hamill	demarion.hamill@geemail.com	New Orleans	Louisiana	3736291494042941	c5051ed7342acf7bb63c071006e1ee52	Voyager	30.0352198114167912	-89.9871619862765044
19550	2020-04-12 07:26:22	2020-04-12	Shelba Kunze	shelba.kunze@geemail.com	Oakland	California	3158107439191596560	68c31d4f35efc1089f613ce4ca91e617	Mastercard	37.8048713330164503	-122.276089459567359
19551	2020-04-12 07:44:41	2020-04-12	Tony Sipes Jr.	tony.sipes.jr.@geemail.com	San Francisco	California	4361812370027	3c4900edee9de7b83f438169cf3677d2	JCB 16 digit	37.8251235995933968	-122.421393622236778
19552	2020-04-12 07:49:31	2020-04-12	Callum McDermott	callum.mcdermott@geemail.com	Los Angeles	California	4141776616196197	e599ed645e0faaeae60f21c2b9813a05	Diners Club / Carte Blanche	34.0308640761632475	-118.43953731693253
19553	2020-04-12 07:54:42	2020-04-12	Arvin Hodkiewicz	arvin.hodkiewicz@geemail.com	Atlanta	Georgia	6011478942785974144	7661b37254e6e581ac7382d088fdd5c8	Maestro	33.718098282795026	-84.4244423125449686
19554	2020-04-12 08:03:38	2020-04-12	Ota Stamm-Sipes	ota.stamm.sipes@geemail.com	Oakland	California	3418417921537854	9ebb7b3a1a8b32308adab24366743575	JCB 15 digit	37.8167141289224986	-122.290339570343647
19555	2020-04-12 08:21:02	2020-04-12	Tyson Thompson	tyson.thompson@woohoo.com	Milwaukee	Wisconsin	4914853962993637	fe0528bcae5ffee5028bedf96eaafc10	JCB 15 digit	43.0625542615160342	-87.8776244702849567
19556	2020-04-12 08:27:55	2020-04-12	Norton Hoppe	norton.hoppe@geemail.com	Plano	Texas	3440503847879140	f75dbfa0ba2b43fb1938691c1d02d104	Diners Club / Carte Blanche	33.0271996687717788	-96.6785235372088891
19557	2020-04-12 08:27:58	2020-04-12	Dr. Cleola Satterfield	dr.cleola.satterfield@geemail.com	Oakland	California	869976316704958296	9a508ed6fb5ff937722e2d7a130adf76	Voyager	37.7924369955997719	-122.262213565903437
19558	2020-04-12 08:36:44	2020-04-12	Thomas Berge-Hilll	thomas.berge.hilll@geemail.com	Fresno	California	3017734018429131	1e8612d77fffcd47d329b673135b4f8c	Maestro	36.7518370467111453	-119.808494246901574
19559	2020-04-12 08:43:22	2020-04-12	Olive Koch	olive.koch@geemail.com	San Francisco	California	676210408607447	0aa193cb4099a3141add73d5e41b34a9	Discover	37.7824094408723212	-122.459753501757177
19560	2020-04-12 08:53:09	2020-04-12	Mr. Festus Wolff III	mr.festus.wolff.iii@warmmail.com	Oakland	California	869934983750850684	2e84a87fb8f4a395ff8f6a3b8f84beaa	JCB 16 digit	37.7873999571304537	-122.260843778981965
19561	2020-04-12 08:56:50	2020-04-12	Trevon Haag PhD	trevon.haag.phd@geemail.com	Austin	Texas	3006813210771010	502496dc55b255dfc3cf2819ba2a0a8c	Maestro	30.309322287480903	-97.8072587223961989
19562	2020-04-12 09:08:24	2020-04-12	Alfredo Sporer-Hilpert	alfredo.sporer.hilpert@warmmail.com	Paterson	New Jersey	6011643708123303068	299e98ba46ab68fcf8402a886308beb7	Maestro	40.9501766922373349	-74.245754540429644
19563	2020-04-12 09:19:47	2020-04-12	Hermine Gibson DVM	hermine.gibson.dvm@geemail.com	Houston	Texas	869908853306188537	51091cb13ac4d7eaa82c8716f12cd009	Voyager	29.7340708936177194	-95.4320487858742439
19564	2020-04-12 09:20:25	2020-04-12	Domenico Cormier	domenico.cormier@geemail.com	Eugene	Oregon	3037977196125456	3592f10eeb5affa32c47c318306d4723	Voyager	44.1203208581738195	-123.144066846602414
19565	2020-04-12 09:40:07	2020-04-12	Constance Dach	constance.dach@warmmail.com	Fort Collins	Colorado	3787112656609699	e32a7d3f28278dc018b37f15b5d9088d	American Express	40.5102856587775051	-105.150646176324415
19566	2020-04-12 09:58:35	2020-04-12	Julio Skiles	julio.skiles@geemail.com	Temecula	California	4330475176996101	0015c073ac6b2da74889dd928235b0ca	Diners Club / Carte Blanche	33.4858049839869096	-117.228994180933384
19567	2020-04-12 10:03:18	2020-04-12	Ayana Weber	ayana.weber@geemail.com	Clarksville	Tennessee	180038990843506062	247bc8bcd91330d069bdcea7bdc75dcf	JCB 15 digit	36.4701583224475385	-87.4055124369867258
19568	2020-04-12 10:16:17	2020-04-12	Wash Treutel	wash.treutel@geemail.com	Lexington	Kentucky	676397279034454	ae11f01e617b769549862941e546e82f	JCB 16 digit	38.1200195132631805	-84.5199497586481243
19569	2020-04-12 10:19:34	2020-04-12	Jacquelyn Nienow	jacquelyn.nienow@woohoo.com	Austin	Texas	3337642080297216034	ac8b73b2bbb9810245c2cafac80a7c50	American Express	30.2053838255476208	-97.8529513288527824
19570	2020-04-12 10:33:26	2020-04-12	Shepherd McCullough	shepherd.mccullough@geemail.com	San Diego	California	676153735082975	08cb595ea7d2f187a78bae92394917f5	Voyager	32.7943989703498815	-117.148540570344778
19571	2020-04-12 10:38:22	2020-04-12	Blake Murray	blake.murray@geemail.com	Cambridge	Massachusetts	4272430219910	dffec2faf31252367f87157b1dff1874	JCB 15 digit	42.2894944889694457	-71.068406175364558
19572	2020-04-12 10:45:37	2020-04-12	Ms. Clem Langosh	ms.clem.langosh@geemail.com	Oceanside	California	3787119338746468	a05c2de745b2233fa939a4de8d906e08	Discover	33.1764314548466359	-117.346686845979477
19573	2020-04-12 10:50:22	2020-04-12	Mr. Royal Wintheiser	mr.royal.wintheiser@geemail.com	Indianapolis	Indiana	53901552804912137	c66fd8f6e1e8d3e1c1a2048dea7698db	American Express	39.8059977438308294	-86.2365003550160623
19574	2020-04-12 10:50:52	2020-04-12	Glenn Reilly-Cummings	glenn.reilly.cummings@geemail.com	Cleveland	Ohio	3337594368106318119	cea6877c1a05339b7b8a8642c26859be	JCB 16 digit	41.4553051668070225	-81.6419041693448975
19575	2020-04-12 10:58:49	2020-04-12	Miss Gustie Streich	miss.gustie.streich@geemail.com	Alexandria	Virginia	869954564277576716	f269f517332382bc7ee20d28db40faf5	Discover	38.9111723402630503	-77.1666420315843169
19576	2020-04-12 11:03:22	2020-04-12	Mr. Eric Eichmann	mr.eric.eichmann@woohoo.com	Charlotte	North Carolina	4514398909039387	cbcb4fe09ba27b09e7343ad059c6ff8d	VISA 16 digit	35.1752294918775519	-80.921644795540729
19577	2020-04-12 11:08:05	2020-04-12	Johnathan O'Conner	johnathan.o'conner@woohoo.com	Berkeley	California	3750642065923714	135cb2e79ff767e1cbfd98cad0ace1cd	Maestro	37.8584845012485545	-122.254453959973361
19578	2020-04-12 11:24:27	2020-04-12	Aloysius Robel-Kiehn	aloysius.robel.kiehn@geemail.com	Chicago	Illinois	4030667928177	5beeb7310de41da69ca88d133f83b227	VISA 13 digit	41.8332788130570208	-87.607618682741375
19579	2020-04-12 11:28:36	2020-04-12	Marlyn Parisian DDS	marlyn.parisian.dds@woohoo.com	Syracuse	New York	4237111387400492	44d492e1b8eac4cae442b0ba9069d24e	American Express	43.1051304924152774	-76.1503970455624284
19580	2020-04-12 11:47:40	2020-04-12	Spencer Kutch	spencer.kutch@geemail.com	Peoria	Illinois	3112193918902377811	021ebc369d6ed92fc48933fca41e8b3d	JCB 16 digit	40.6617385803591489	-89.6239252393484094
19581	2020-04-12 11:50:42	2020-04-12	Mr. Elton Pouros Jr.	mr.elton.pouros.jr.@woohoo.com	El Paso	Texas	676102761707500	4cd2e3d523d07ba2fb554b386164c255	American Express	31.9437319073654713	-106.505742067888391
19582	2020-04-12 11:53:28	2020-04-12	Carley Shields-Wehner	carley.shields.wehner@geemail.com	New York	New York	3043834956163223	beade887d1226428e476ea1618d13559	VISA 16 digit	40.6494014704823456	-73.9929557948268979
19583	2020-04-12 11:53:47	2020-04-12	Dr. Ahmed Auer I	dr.ahmed.auer.i@geemail.com	Anchorage	Alaska	869936916979740565	f52105335dfb275afe61b9f0a2aea7e1	Voyager	61.2183098903607572	-149.360357357760137
19584	2020-04-12 11:57:48	2020-04-12	Mr. Isreal Hills IV	mr.isreal.hills.iv@warmmail.com	Los Angeles	California	3404013151183067	87989f2794d2318e06ec1b3eb3062b0e	Mastercard	34.0174082661379131	-118.359908669348059
19585	2020-04-12 12:04:21	2020-04-12	Mrs. Connie Howe	mrs.connie.howe@geemail.com	Dallas	Texas	3001506169653461	d1e31d6e30db002e95ef9a78b9151880	Voyager	32.8857379691015979	-96.834962558323511
19586	2020-04-12 12:15:42	2020-04-12	Mr. Jaylan Lubowitz	mr.jaylan.lubowitz@geemail.com	Los Angeles	California	3023101857751575	14ced494a5a56e2473a5c2012a93bb20	Voyager	33.9340611088886845	-118.485683533967659
19587	2020-04-12 12:18:20	2020-04-12	Liliana Mann	liliana.mann@woohoo.com	Fontana	California	6011573855849599166	bc4741391c1296a512a2b39a4a25a9ff	Diners Club / Carte Blanche	34.1595737808067383	-117.460663862367724
19588	2020-04-12 12:30:55	2020-04-12	Miss Oliva O'Connell DVM	miss.oliva.o'connell.dvm@geemail.com	Oakland	California	4707825626820985	be042ea5225e94e70bb5d092da06195d	Voyager	37.837238525676284	-122.247648626149669
19589	2020-04-12 12:45:22	2020-04-12	Rome Little-Armstrong	rome.little.armstrong@woohoo.com	Montgomery	Alabama	6011304355504796542	1fc5dbe6ee7c24a79e60bc575518fe23	VISA 16 digit	32.3605894759695971	-86.2664558928612593
19590	2020-04-12 12:59:28	2020-04-12	Elgie Halvorson	elgie.halvorson@geemail.com	Los Angeles	California	4764360590066019	24db6b1592274de2aeaa8493236bfb4d	Diners Club / Carte Blanche	34.0127889735490072	-118.335027477284143
19591	2020-04-12 13:12:59	2020-04-12	Melodie Heathcote	melodie.heathcote@woohoo.com	Provo	Utah	4974484584526758	0d007623cdd9220cff874d4649240bbb	American Express	40.2143680094063285	-111.701648474545408
19592	2020-04-12 13:15:32	2020-04-12	Karyn Rippin DVM	karyn.rippin.dvm@geemail.com	Oklahoma City	Oklahoma	4599038053825920	251d064f7934d915d1ca4bb217c57970	VISA 16 digit	35.498485913630951	-97.5853112116351724
19593	2020-04-12 13:16:45	2020-04-12	Ernesto Trantow-Lowe	ernesto.trantow.lowe@woohoo.com	Modesto	California	869933011455247849	064a45d77af7dc7df6a0dad2e9d40f66	JCB 16 digit	37.5590416481718421	-120.904911234203723
19594	2020-04-12 13:29:38	2020-04-12	Florance Rolfson	florance.rolfson@geemail.com	New York	New York	3029323580801592	f1cda1b9501daf857c1d0e8f00bfdd42	VISA 16 digit	40.7170123196430467	-73.9147136642493336
19595	2020-04-12 13:33:28	2020-04-12	Lahoma Schoen	lahoma.schoen@geemail.com	Buffalo	New York	3043029412944668	c8bd0e07d6ab1ccbfb1200842a600685	JCB 16 digit	42.8175990573316767	-78.8618664390806146
19596	2020-04-12 13:48:49	2020-04-12	Jame Miller MD	jame.miller.md@geemail.com	Dallas	Texas	180086105917474508	98d78cb23967b10b31747367845d4837	Discover	32.7226911789543919	-96.7722406838051938
19597	2020-04-12 14:12:52	2020-04-12	Colie Hansen DDS	colie.hansen.dds@geemail.com	Lexington	Kentucky	53950067573192761	9a16b574dc9ddd42d3e406f577258bc9	Voyager	38.0800930142745386	-84.4153230973418687
19598	2020-04-12 14:16:53	2020-04-12	Yahir Christiansen	yahir.christiansen@geemail.com	San Francisco	California	4132676734826	9c83683c828385daa02371e1036c0451	VISA 16 digit	37.759877369062572	-122.420965126037487
19599	2020-04-12 14:24:46	2020-04-12	Rey Schulist	rey.schulist@woohoo.com	Salem	Oregon	501803888146689	78c6a5213c5be220b518c2495e4b2d9b	Voyager	44.9100295084331123	-123.017487398084995
19600	2020-04-12 14:46:13	2020-04-12	Mr. Wes Hessel Jr.	mr.wes.hessel.jr.@geemail.com	Dallas	Texas	3012325549753811	f494ddc02b3f6eb08e78420f6671d4e3	VISA 16 digit	32.8309962308306282	-96.789716415662312
19601	2020-04-12 15:09:04	2020-04-12	Lucien Green II	lucien.green.ii@geemail.com	San Francisco	California	55906219173766974	2f035213dcc1afeb9f288db101d53581	VISA 16 digit	37.790816194563746	-122.43988198273594
19602	2020-04-12 15:23:51	2020-04-12	Lisa Goodwin	lisa.goodwin@geemail.com	San Francisco	California	3474211367172982	75f7b06ab82446dc2b54c0c8203e942e	Voyager	37.755283939365583	-122.431098287172688
19603	2020-04-12 15:46:46	2020-04-12	Taryn Champlin	taryn.champlin@warmmail.com	New York	New York	3473475920695273	0103027f99fa43e19b30e27662a5f2da	JCB 16 digit	40.5653514026887692	-74.0327206487197458
19604	2020-04-12 15:59:38	2020-04-12	Pryor Bailey I	pryor.bailey.i@warmmail.com	Indianapolis	Indiana	3045030779621061	3efc78602546941bc5d365be4653528b	VISA 13 digit	39.7681798785000993	-86.2222202641624875
19605	2020-04-12 16:10:25	2020-04-12	Pearley Osinski	pearley.osinski@geemail.com	New York	New York	3528335328298369217	54639dae9ab0baa260c267dd9841769f	JCB 16 digit	40.680805800085885	-74.0205386997561874
19606	2020-04-12 16:21:17	2020-04-12	Tanner Olson	tanner.olson@geemail.com	Oakland	California	869959598281196140	09cb3b09bc211047e4e08301330930af	JCB 16 digit	37.8030909847825853	-122.289781814408443
19607	2020-04-12 16:55:59	2020-04-12	Mrs. Karel Muller	mrs.karel.muller@geemail.com	Lubbock	Texas	3096445105075252627	285bdb586533495b4c8e86261b7d8475	JCB 16 digit	33.6639360646292616	-101.788077708185469
19608	2020-04-12 17:14:18	2020-04-12	Barney Gutmann-Fisher	barney.gutmann.fisher@geemail.com	Anaheim	California	6011138983976746158	e3653ac5d44f9a885d12ddff1abf1025	Maestro	33.8068330124318592	-117.825741277516258
19609	2020-04-12 17:19:56	2020-04-12	Uriel Renner IV	uriel.renner.iv@geemail.com	Riverside	California	639097556217970	442c2438bad29a0d30aa3ce415650518	Mastercard	33.8482927577983546	-117.368410397550832
19610	2020-04-12 17:29:00	2020-04-12	Toshiko Veum-Ziemann	toshiko.veum.ziemann@warmmail.com	Ontario	California	6011626084859480616	ad345da758be1f7cf5fc06cbb584abe4	JCB 15 digit	33.9767489333316703	-117.521115324050939
19611	2020-04-12 17:34:53	2020-04-12	Djuna Swift	djuna.swift@geemail.com	Long Beach	California	869913688405419661	886bcb8a4ee24da654e78b756b0a5d8c	JCB 16 digit	33.7479315507978157	-118.137363967501742
19612	2020-04-12 18:11:43	2020-04-12	Almus Blick	almus.blick@woohoo.com	Simi Valley	California	4901854766477301	b7d572e650e0328ebf89b3a2112bb2f4	JCB 15 digit	34.2641417003940774	-118.77326651431062
19613	2020-04-12 18:14:00	2020-04-12	Dawn Goyette	dawn.goyette@geemail.com	Detroit	Michigan	4882975571020375	b57c126f5a3b64f4b86cf08a99f090b8	American Express	42.3158193766064983	-83.1726537574667475
19614	2020-04-12 18:21:56	2020-04-12	Brittany Langworth	brittany.langworth@warmmail.com	Columbus	Ohio	53787525125727219	3100418c56c4c59f11ec6b22a1d5dfc0	American Express	40.0414627240549734	-82.8947765281193085
19615	2020-04-12 18:50:55	2020-04-12	Mr. Woody Gorczany	mr.woody.gorczany@geemail.com	San Francisco	California	210042674772238079	274d371830367c9e569006170dcb6b4f	Diners Club / Carte Blanche	37.7942448006872382	-122.443285587145482
19616	2020-04-12 18:53:47	2020-04-12	Nella Anderson-Brown	nella.anderson.brown@geemail.com	San Jose	California	561257790273981	2b52fac3b04e9122bd7ad2a7716892d9	Discover	37.3748135388649985	-121.7345140432693
19617	2020-04-12 18:56:43	2020-04-12	Bud Reinger	bud.reinger@geemail.com	Birmingham	Alabama	3337258245611412438	d2548f343469d7d7053544be6595353b	JCB 15 digit	33.5872244332708405	-86.7385492985844735
19618	2020-04-12 19:00:54	2020-04-12	Mr. Esco Goodwin	mr.esco.goodwin@warmmail.com	Dallas	Texas	3088258323141808043	d0ee77691540107e9109fc0667a5f2e8	Voyager	32.8482475952517277	-96.794892235981294
19619	2020-04-12 19:05:51	2020-04-12	Ova Bayer	ova.bayer@geemail.com	Milwaukee	Wisconsin	561232351881811	82f33c4e22c5f0cdf0198b9347aea8e5	JCB 16 digit	43.1284187314186198	-87.9851078957885591
19620	2020-04-12 19:30:16	2020-04-12	Tobi Nicolas DVM	tobi.nicolas.dvm@woohoo.com	Peoria	Arizona	4749910614812572	3dcedfb4e782c9c97acd96139c6180cd	JCB 16 digit	33.6925361752312611	-112.270442830437801
19621	2020-04-12 19:31:19	2020-04-12	Estelle Boyer	estelle.boyer@warmmail.com	Richmond	Virginia	180082385911682165	9d717a3fccd9772500a42840477e8d5c	VISA 13 digit	37.4324676239617133	-77.4523450801372491
19622	2020-04-12 19:48:26	2020-04-12	Frona Predovic-Quitzon	frona.predovic.quitzon@geemail.com	Columbia	Missouri	52895325155863565	de5a4d8eaf6cc303c55b504e4bbd3b9c	JCB 15 digit	38.8636295904752416	-92.3560548972857305
19623	2020-04-12 19:58:52	2020-04-12	Mrs. Alysa Emmerich DDS	mrs.alysa.emmerich.dds@warmmail.com	Louisville	Kentucky	4622796589301879	bb86cf79b530a6ba2debd0f91419e77d	Mastercard	38.1568090062957239	-85.7333486710280255
19624	2020-04-12 20:02:23	2020-04-12	Rosalee Wisozk	rosalee.wisozk@geemail.com	Oakland	California	3020189296895098	8e2befeb9eba7cf3bc83c524879235e3	JCB 16 digit	37.8023062041316749	-122.316725557783172
19625	2020-04-12 20:03:57	2020-04-12	Elisha Reichel	elisha.reichel@geemail.com	Boston	Massachusetts	3738105898454478	12bd73b0810363b06eeb1e44f32f140d	Discover	42.4062541722953341	-70.9728163314934903
19626	2020-04-12 20:15:48	2020-04-12	Welton Hintz	welton.hintz@geemail.com	College Station	Texas	3112767750189619565	cb5cc2e1e7f1edb919a7dee921da0f0a	VISA 16 digit	30.5774870132606473	-96.3195725524645354
19627	2020-04-12 20:19:52	2020-04-12	Violeta Mohr	violeta.mohr@geemail.com	Aurora	Colorado	4732015624403682	0e91e83e6f5745c5cdb06551ab3d1ed5	JCB 16 digit	39.7034658963438147	-104.775734791916605
19628	2020-04-12 20:29:26	2020-04-12	Mrs. Ruthe Nikolaus DDS	mrs.ruthe.nikolaus.dds@geemail.com	Norman	Oklahoma	060439939778997	077cd078d05ef1b4b39f5a927e97041d	VISA 16 digit	35.2713431574445195	-97.3258197552312083
19629	2020-04-12 20:31:53	2020-04-12	Jamya Ullrich	jamya.ullrich@geemail.com	Raleigh	North Carolina	54458483113448158	4dba57767400aeb0dd63b359081d1470	VISA 13 digit	35.9171876358468083	-78.6106846670091244
19630	2020-04-12 20:37:22	2020-04-12	Jaydin Aufderhar	jaydin.aufderhar@geemail.com	Gainesville	Florida	180076394712146253	e372b83d53d11858735609d4761ae86f	JCB 16 digit	29.6690219566982236	-82.3622573803052376
19631	2020-04-12 20:52:44	2020-04-12	Tenika Kozey-Wyman	tenika.kozey.wyman@warmmail.com	New York	New York	4649388698791	dcfdc11ae8e92c8df6d924de271ad7e7	Discover	40.7111396209094636	-73.9235245524801314
19632	2020-04-12 20:54:37	2020-04-12	Flora Spinka	flora.spinka@geemail.com	Santa Maria	California	3023421602090818	7b81c65e53e8edadd158a36081866699	Discover	34.9202294370222859	-120.484338651915266
19633	2020-04-12 20:57:19	2020-04-12	Dr. Hayley Lockman	dr.hayley.lockman@geemail.com	Berkeley	California	3528523860491952565	7b5b695b73a778762a6b30c9ab2f8cd7	Mastercard	37.873373082560235	-122.281835783312133
19634	2020-04-12 21:37:53	2020-04-12	Zavier Rutherford V	zavier.rutherford.v@geemail.com	Columbia	Missouri	869901750786021559	a396402871a2caba6eaa2f502abf3360	Voyager	39.0373907485392522	-92.3426502639946563
19635	2020-04-12 21:41:49	2020-04-12	Marvel Lehner	marvel.lehner@geemail.com	San Francisco	California	503833131739832	295bf738868fe5e497cb4edc28fda279	VISA 13 digit	37.7476341588669726	-122.460532909618692
19636	2020-04-12 21:49:41	2020-04-12	America Boehm	america.boehm@woohoo.com	New York	New York	4691960812575156	46678d88c583f050bb7ee7cc9375fee2	Diners Club / Carte Blanche	40.5953309040740109	-73.9694204621378333
19637	2020-04-12 22:06:16	2020-04-12	Paris Lebsack	paris.lebsack@warmmail.com	Oakland	California	3088236255596128542	8892707f43898f57bd184dddb65000c5	Voyager	37.7822501902877264	-122.271857830607104
19638	2020-04-12 22:09:04	2020-04-12	Alexandr Halvorson DVM	alexandr.halvorson.dvm@geemail.com	Dayton	Ohio	180058315898386480	dd79324a80445c00de6c5a545f41289a	Discover	39.8210537306290107	-84.2134596233446189
19639	2020-04-12 22:14:55	2020-04-12	Layla Rau-Kuphal	layla.rau.kuphal@woohoo.com	Colorado Springs	Colorado	3466035880916439	176de789cf07ea0fdb73d67a5431eacf	American Express	38.9314986299306156	-104.794591672082248
19640	2020-04-12 22:17:15	2020-04-12	Dr. Ballard Nitzsche DVM	dr.ballard.nitzsche.dvm@woohoo.com	Billings	Montana	4093853248570160	91fa8959272926e7cbb743d4b70a131b	Discover	45.7443318558614678	-108.620425715732935
19641	2020-04-12 22:39:17	2020-04-12	Sally Huel	sally.huel@geemail.com	Denver	Colorado	3528498218099262773	b18edfc35f15100fdced81bbffe19f6d	JCB 16 digit	39.7524923429876509	-104.916451040866235
19642	2020-04-12 22:45:16	2020-04-12	Torrence Orn-Reinger	torrence.orn.reinger@woohoo.com	Phoenix	Arizona	3053073588834162	050bfed3fb8e6e93f22cc66a8842f2f4	American Express	33.6496989838711968	-112.11720866862909
19643	2020-04-12 22:46:52	2020-04-12	Allene Konopelski	allene.konopelski@woohoo.com	Fort Collins	Colorado	210044345045665293	0ae88005916b0b6998fdcbd63c695c01	Maestro	40.5423178137902198	-105.101568272053456
19644	2020-04-12 23:06:32	2020-04-12	Jeremy Rutherford DDS	jeremy.rutherford.dds@woohoo.com	Long Beach	California	869971497436985164	bff46a4e09812a2fd24ead919d95b893	Mastercard	33.9048144875381112	-118.228562816993517
19645	2020-04-12 23:13:17	2020-04-12	Sybilla Feil	sybilla.feil@woohoo.com	San Francisco	California	676286658126213	514007aaa194501c220372ce174e20e8	VISA 16 digit	37.7900534273709496	-122.443113487345471
19646	2020-04-12 23:22:16	2020-04-12	Dr. Tracey Yost	dr.tracey.yost@woohoo.com	Lubbock	Texas	630467069850690	2a695dab6938f90c1db22a408cb4afe7	VISA 16 digit	33.4937431227456841	-101.821824128498136
19647	2020-04-12 23:24:38	2020-04-12	Ms. Angelic Roob DDS	ms.angelic.roob.dds@geemail.com	Austin	Texas	180074932542212407	1cea6e07ce1c34949692b01b8db6eb6f	Discover	30.3353801014959785	-97.7672937831148516
19648	2020-04-12 23:33:56	2020-04-12	Olena Jacobs	olena.jacobs@geemail.com	Austin	Texas	4466261223856	9755d87d070ba59002b3df1aabf71f7d	VISA 16 digit	30.3393649297427359	-97.8190228214260173
19649	2020-04-12 23:47:41	2020-04-12	Giovanna Kautzer PhD	giovanna.kautzer.phd@geemail.com	Washington	District of Columbia	4260279360947795	8242d1a821f1d462a0eae5e77909b9ec	VISA 16 digit	38.8264011159803744	-77.0369340931277691
19650	2020-04-12 23:52:19	2020-04-12	Olene Casper	olene.casper@woohoo.com	New York	New York	869926856953060543	1d4b9e579cc61b236b3f0cc181f45c3d	JCB 15 digit	40.6215360701773278	-73.8462963975861584
19651	2020-04-12 23:55:53	2020-04-12	Roy Barrows	roy.barrows@geemail.com	Frisco	Texas	6011479473765876678	bf3b3585e6a12cbf2fa289b56de1f2c2	VISA 13 digit	33.2008279661178562	-96.8815078077580694
19652	2020-04-12 23:58:45	2020-04-12	Foster Nolan	foster.nolan@woohoo.com	New York	New York	3088142755825542366	59bd618772c509c53d8fc4ead96443c0	VISA 16 digit	40.6047095095030954	-73.9917897636897806
19653	2020-04-13 00:10:14	2020-04-13	Glenna Ward	glenna.ward@geemail.com	North Charleston	South Carolina	869996014647507710	be24654237df86e6026ed3c37c9c754d	JCB 15 digit	32.9993611314494188	-80.0210779449529923
19654	2020-04-13 00:37:12	2020-04-13	Mikel Hudson	mikel.hudson@geemail.com	Augusta	Georgia	869960196222118872	9b7708c38a7c4efc0c9f7532f70e5977	VISA 16 digit	33.2768041092175935	-82.0829318423584198
19655	2020-04-13 00:37:40	2020-04-13	Dr. Rory Lemke	dr.rory.lemke@geemail.com	Mesa	Arizona	4105876393906935	86ddc62dc392bac34891056ed960ff7d	VISA 16 digit	33.319898146824535	-111.719980231055615
19656	2020-04-13 00:49:54	2020-04-13	Luda Kuhic	luda.kuhic@geemail.com	Jacksonville	Florida	4451675125939	fbf974a3218cb32132570d5754fa4320	JCB 16 digit	30.2372915142267935	-81.58955676123351
19657	2020-04-13 00:59:58	2020-04-13	Denine Zboncak	denine.zboncak@woohoo.com	San Antonio	Texas	3528174215167077183	87c8921f6b5c328e9cc0f9f7121e4aca	VISA 13 digit	29.5511758759222936	-98.4851526402238733
19658	2020-04-13 01:16:00	2020-04-13	Mr. Ferman Lockman Jr.	mr.ferman.lockman.jr.@woohoo.com	San Jose	California	3088867768744586284	fa73db4793ee2b2fa93656bd6fcec99a	VISA 13 digit	37.2996473353177294	-121.728336151804399
19659	2020-04-13 01:28:09	2020-04-13	Dr. Keenen Kerluke DVM	dr.keenen.kerluke.dvm@geemail.com	Houston	Texas	3719551691534318	873f2b3fb0509417557f93adc08b04f9	VISA 13 digit	29.752649436060711	-95.4269965956468127
19660	2020-04-13 01:28:32	2020-04-13	Lilianna Waelchi	lilianna.waelchi@geemail.com	Lubbock	Texas	6011548340607492435	3a4863e9efdc57a04e5b766a50614259	Diners Club / Carte Blanche	33.5069278190884745	-101.95656014507712
19661	2020-04-13 01:41:46	2020-04-13	Icie Daugherty	icie.daugherty@geemail.com	Corona	California	55223541527833945	a9acbfd1d6af961ba39f9e8b12edbfe0	Discover	33.9439114793092003	-117.497207386625931
19662	2020-04-13 01:42:57	2020-04-13	Broderick Boyle	broderick.boyle@geemail.com	Lakewood	Colorado	52614564359582874	293ca51a1493072edfac8455d0cd7169	VISA 13 digit	39.7359531218126421	-105.068988418674465
19663	2020-04-13 01:48:52	2020-04-13	Gerold Doyle	gerold.doyle@geemail.com	Salinas	California	3032262871817023	97f6cfa306ee899e619750efe6a1f946	VISA 16 digit	36.7870718824908138	-121.540546139393754
19664	2020-04-13 02:00:55	2020-04-13	Lorna Harvey	lorna.harvey@geemail.com	San Francisco	California	52676795292106448	a27f7d4ed21d97ec7c44a608191de790	Maestro	37.7643521490250507	-122.448281335461445
19665	2020-04-13 02:06:33	2020-04-13	Barry Cormier	barry.cormier@woohoo.com	Long Beach	California	060465217946725	34873b59c50d4a7d3d9517d9d112b86b	VISA 13 digit	33.7269205164451122	-118.226658498744669
19666	2020-04-13 02:09:38	2020-04-13	Keila Wilkinson MD	keila.wilkinson.md@warmmail.com	Los Angeles	California	4296664638354	eccd9be73a6cc4d5098608959974293d	JCB 16 digit	34.0898275214113298	-118.452373312925175
19667	2020-04-13 02:12:00	2020-04-13	Marybelle Schumm	marybelle.schumm@warmmail.com	Louisville	Kentucky	4512843688172430	bd093a577b027b7d1a301230af7466ec	Mastercard	38.0856567312866403	-85.6888259254001099
19668	2020-04-13 02:14:14	2020-04-13	Miss Fronnie McDermott	miss.fronnie.mcdermott@geemail.com	Oklahoma City	Oklahoma	869928718893074166	6b0254fb3ab5435c2cf18959440bf631	JCB 15 digit	35.5368599475737668	-97.5393222147494612
19669	2020-04-13 02:28:25	2020-04-13	Tawnya Lindgren PhD	tawnya.lindgren.phd@woohoo.com	Jacksonville	Florida	52453880610963032	74284896b52d39ab75c80a6788c9847c	American Express	30.2898225077014409	-81.7538877955250456
19670	2020-04-13 02:32:18	2020-04-13	Miss Patricia Langosh DDS	miss.patricia.langosh.dds@warmmail.com	Bridgeport	Connecticut	4622419687278564	46d284913a2402a580a57f3c48aaf5d0	Mastercard	41.1797090887255948	-73.1587345993511491
19671	2020-04-13 02:46:07	2020-04-13	Dr. Dina DuBuque	dr.dina.dubuque@geemail.com	Little Rock	Arkansas	3038069465059027	679229ea5a792c8bf3860edbb4dd9e6a	VISA 16 digit	34.7883126296378649	-92.4019272622060015
19672	2020-04-13 02:48:22	2020-04-13	Miss Gussie Kub	miss.gussie.kub@geemail.com	Seattle	Washington	3096891154734015040	c4ac5ef0eeaab731d3dc831e7d9dc08d	Discover	47.6222380008939652	-122.343491889994212
19673	2020-04-13 02:49:34	2020-04-13	Carole Bernier	carole.bernier@geemail.com	Gilbert	Arizona	4985818227415829	34a138a10397bbd5e0f1a9c6a08c71cf	Discover	33.355690467206017	-111.770244224755459
19674	2020-04-13 02:57:50	2020-04-13	Dr. Aryan West V	dr.aryan.west.v@warmmail.com	Huntington Beach	California	3020122054603891	1a01aa259a041e243484cba7317c22bf	Discover	33.741228703599802	-118.0204913124565
19675	2020-04-13 03:03:28	2020-04-13	Dr. Jedidiah Herman	dr.jedidiah.herman@geemail.com	Washington	District of Columbia	4455475688528284	95361b423eaebd777fb90f5581b9e818	Voyager	38.9015071651231494	-76.9722258867908238
19676	2020-04-13 03:06:47	2020-04-13	Tera Price	tera.price@geemail.com	Victorville	California	4121420782892	bae1e8698f605f159bc87d000f4ef8a4	JCB 15 digit	34.4565097512908309	-117.333206898874039
19677	2020-04-13 03:07:03	2020-04-13	Zane Lang	zane.lang@geemail.com	Greensboro	North Carolina	3088478033754763849	853376b9a90666ce091e2a05e805cab4	JCB 16 digit	36.0045661607407084	-79.9070259632989774
19678	2020-04-13 03:17:02	2020-04-13	Rose Quitzon PhD	rose.quitzon.phd@warmmail.com	Rochester	New York	869913507049129397	b908b9d180e40230fecaa3ca70933024	Mastercard	43.1950153799705205	-77.7094163301173637
19679	2020-04-13 03:23:28	2020-04-13	Mrs. Chanel Yost	mrs.chanel.yost@woohoo.com	Evansville	Indiana	3112842200451663593	96f8f815c8561edc5dd40f6ead63912b	Diners Club / Carte Blanche	38.0647818147342605	-87.5037363436006075
19680	2020-04-13 03:36:35	2020-04-13	Sage Wyman	sage.wyman@geemail.com	New York	New York	3017853379265510	8b8b405c3d70be90b4e1fd99a1e29918	JCB 16 digit	40.596048424834386	-73.8595907704334707
19681	2020-04-13 03:41:04	2020-04-13	Dr. Maryjo Schuppe DVM	dr.maryjo.schuppe.dvm@geemail.com	Irvine	California	3023285869582258	5df29d0bc0ca78c49cb3042e24733b89	Maestro	33.7250902161948432	-117.693351465278482
19682	2020-04-13 03:58:23	2020-04-13	Ireland West	ireland.west@geemail.com	San Diego	California	3758586582423389	179a2ec02057147010851d0670631716	Maestro	32.7924328638307756	-117.045499974899002
19683	2020-04-13 04:17:31	2020-04-13	Jason Auer-Jakubowski	jason.auer.jakubowski@geemail.com	Lakeland	Florida	54760808593007772	5d1cc9ece799ed791744bae5131c494a	Diners Club / Carte Blanche	27.9714108797088237	-81.864688322541852
19684	2020-04-13 04:21:32	2020-04-13	Dr. Holmes Goldner	dr.holmes.goldner@woohoo.com	Oakland	California	3528359616061687125	77f167107b0c484d4dfaa1c067b98eb6	American Express	37.8301279891562956	-122.264703192444387
19685	2020-04-13 04:28:23	2020-04-13	Lanette Koepp-Purdy	lanette.koepp.purdy@geemail.com	Des Moines	Iowa	3088420173281305190	d8463434786f6bef64919bf52a5e5f71	JCB 16 digit	41.6568898135073482	-93.7039145513016791
19686	2020-04-13 04:38:19	2020-04-13	Mrs. Jacalyn O'Keefe MD	mrs.jacalyn.o'keefe.md@geemail.com	Providence	Rhode Island	869969022379932462	8b46479aab2fa1b1c6ef31072b1c9a38	American Express	41.8071904581826175	-71.4967536707326872
19687	2020-04-13 04:48:09	2020-04-13	Ashly Morar	ashly.morar@woohoo.com	Berkeley	California	6011208856341783418	4cb16712b849c9dc08b0a8793a35019c	JCB 15 digit	37.8673191834377789	-122.302505857942876
19688	2020-04-13 04:57:38	2020-04-13	Sylvia Prosacco	sylvia.prosacco@geemail.com	San Diego	California	501865743816806	e70baae36e6f8e20388674eda9b393d1	Discover	32.7165852727901196	-117.16824208925479
19689	2020-04-13 05:05:37	2020-04-13	Braxton Rodriguez	braxton.rodriguez@geemail.com	San Francisco	California	52927506145411852	797cc546ec8f97df978cd471bd16c173	Diners Club / Carte Blanche	37.7578789736251395	-122.414187102958238
19690	2020-04-13 05:10:42	2020-04-13	Infant Veum	infant.veum@geemail.com	New York	New York	55541721769511467	c3e04ccca95fbca807221e9d4c807fe4	VISA 13 digit	40.6302647066526106	-73.8696718650765689
19691	2020-04-13 05:22:49	2020-04-13	Orange Schmeler	orange.schmeler@geemail.com	Fayetteville	North Carolina	6011853381845736570	8db8a8d93952c9cdd4c539fa6cc721ca	JCB 16 digit	35.1249645206864898	-79.0615967993289246
19692	2020-04-13 05:26:10	2020-04-13	Dr. Blane Goodwin	dr.blane.goodwin@geemail.com	Long Beach	California	639032826385604	67e4350bde3c68db7c9ab34f67f3e825	JCB 16 digit	33.8897273625534012	-118.202709271821377
19693	2020-04-13 05:38:33	2020-04-13	Jazmyn Gerlach MD	jazmyn.gerlach.md@geemail.com	Elk Grove	California	3337990475233055926	2dba520a001d0a5f102adafae63de5b2	Discover	38.3642672454290121	-121.40657434783877
19694	2020-04-13 05:44:42	2020-04-13	Dafne Pfeffer	dafne.pfeffer@geemail.com	Tucson	Arizona	4409082549778	efe372017e0673d4b69a8d836c0397bc	Maestro	32.0734419963363564	-110.8310394132737
19695	2020-04-13 05:48:10	2020-04-13	Mr. Alcee Grimes	mr.alcee.grimes@geemail.com	San Francisco	California	501800751953613	efa0df48e6980ec9e62e6ed39036d730	JCB 16 digit	37.7758322750020881	-122.442606175058614
19696	2020-04-13 05:50:03	2020-04-13	Lovina Jast DDS	lovina.jast.dds@woohoo.com	Paterson	New Jersey	51922137216071204	47546564d8280c4e36697af5c87bf927	American Express	40.8448751725677397	-74.2322517921190723
19697	2020-04-13 05:51:29	2020-04-13	Karma Balistreri	karma.balistreri@geemail.com	Norfolk	Virginia	869900409458577106	89c9a69d016e86cfbca6128673debc28	JCB 16 digit	36.9664264892246592	-76.2428296641916035
19698	2020-04-13 06:07:40	2020-04-13	Mr. Imanol Streich I	mr.imanol.streich.i@geemail.com	Cleveland	Ohio	4931603380334	3cee38cef744c72e4ceae9118a97fd67	Diners Club / Carte Blanche	41.4925882637351719	-81.6936176905646931
19699	2020-04-13 06:09:21	2020-04-13	Mr. Cecil Reichert	mr.cecil.reichert@geemail.com	Carrollton	Texas	53644009595278485	1209c9a4f9531b3181c4ef09791124b5	JCB 16 digit	32.9977353001866476	-96.8098372841116088
19700	2020-04-13 06:10:03	2020-04-13	Dr. Venus Mitchell	dr.venus.mitchell@geemail.com	Milwaukee	Wisconsin	4044111660997	7ca6a60cae9fc85d2ed6c705ed9df1d6	American Express	43.0899542529687238	-87.9163501019690159
19701	2020-04-13 06:18:43	2020-04-13	Armani Skiles	armani.skiles@woohoo.com	Chicago	Illinois	210044831321907749	29ab66494f006dd8b4d340ec7abd5eca	Mastercard	41.7565026245381716	-87.6999898848153663
19702	2020-04-13 06:31:18	2020-04-13	Oswaldo Schmitt	oswaldo.schmitt@geemail.com	Saint Paul	Minnesota	6011508221905783030	f30e155131604a40375f9a82d2b404c2	Voyager	45.0292476937115183	-93.0469427429404163
19703	2020-04-13 06:45:48	2020-04-13	Dr. Tony Graham III	dr.tony.graham.iii@warmmail.com	Springfield	Massachusetts	3794661166293783	365bd9c4b325ddd75c94e75eb2b565f8	Maestro	42.1137194534968557	-72.5519707825593656
19704	2020-04-13 06:46:38	2020-04-13	Thyra Lindgren	thyra.lindgren@geemail.com	Anaheim	California	4227959968297	2534ca99fa40233b6b8af5a1e1abc430	VISA 13 digit	33.765156737884503	-117.838707161156833
19705	2020-04-13 06:50:28	2020-04-13	Hedwig Schaefer	hedwig.schaefer@warmmail.com	Fort Wayne	Indiana	869966328244659708	908dde51660ff4b13d6a23491ac9a7e1	Voyager	41.1253280801482504	-85.1438218196142458
19706	2020-04-13 06:59:18	2020-04-13	Ms. Miracle Corkery	ms.miracle.corkery@geemail.com	Lewisville	Texas	3019205463360855	1f4877cb9317a03b1b7b8393d4bba601	Discover	33.1270042967967697	-96.9605995871156523
19707	2020-04-13 06:59:58	2020-04-13	Dr. Janice Prohaska	dr.janice.prohaska@geemail.com	Las Cruces	New Mexico	869915278569019545	ee973f56dc6e0beebec303dc2e1aa6fd	Maestro	32.2756508696392146	-106.736101884872468
19708	2020-04-13 07:01:18	2020-04-13	Ayaan Muller	ayaan.muller@warmmail.com	Las Vegas	Nevada	6011534534608824515	36aeca416b76172b40a336dfd4348cec	JCB 16 digit	36.2572045172665227	-115.252598553683981
19709	2020-04-13 07:03:19	2020-04-13	Dr. Mandi Carroll	dr.mandi.carroll@geemail.com	San Francisco	California	4024876657733775	5d6f2ff1784c8d7cb54b1f9ed92df57a	JCB 16 digit	37.7479623927508925	-122.414687986557311
19710	2020-04-13 07:16:34	2020-04-13	Jada Terry DDS	jada.terry.dds@geemail.com	Glendale	Arizona	561238752354415	d7e10d78f3c256c27470d3baf8f86d11	VISA 16 digit	33.4692004322301599	-112.191509377283595
19711	2020-04-13 07:37:01	2020-04-13	Jaliyah Greenholt DDS	jaliyah.greenholt.dds@woohoo.com	Oakland	California	3490874308107340	45a86802c1ad3a460247ac0a615681c6	Discover	37.7734774921356191	-122.289393173848055
19712	2020-04-13 07:47:11	2020-04-13	Antonio Green	antonio.green@geemail.com	Memphis	Tennessee	6011630434578345364	e73267f23d3d3065d1e02806923e72cc	Maestro	35.1141221027422716	-89.8958779294766543
19713	2020-04-13 08:07:19	2020-04-13	Dakoda Rolfson-Eichmann	dakoda.rolfson.eichmann@geemail.com	Pasadena	California	180019461843793178	8e0750c38397e995d0571edece99d497	Diners Club / Carte Blanche	34.2545863467589058	-118.070194527907674
19714	2020-04-13 08:10:32	2020-04-13	Huey Schumm	huey.schumm@geemail.com	Dallas	Texas	180056572326860088	0324cb136a960008d2d7e4b69f9482bc	VISA 16 digit	32.8649517271939686	-96.8597324468158121
19715	2020-04-13 08:15:30	2020-04-13	Quint Ritchie	quint.ritchie@warmmail.com	Green Bay	Wisconsin	4237035785920514	a245779ab4dfba4b20f92ffe5cf2e2c5	Voyager	44.5516114347212024	-87.9492321544613702
19716	2020-04-13 08:23:36	2020-04-13	Darion Kunde	darion.kunde@geemail.com	Knoxville	Tennessee	4061254823356521	b5b5d47a9312f826c1f22f12ba71777a	VISA 16 digit	36.0168113838944564	-83.9181709472306068
19717	2020-04-13 08:31:14	2020-04-13	Jorge Crona	jorge.crona@geemail.com	San Francisco	California	3088111881418470869	d7f89dd843f27d66ac6ec9fc0dd1f55e	VISA 16 digit	37.7817128192591198	-122.429031334738184
19718	2020-04-13 08:33:53	2020-04-13	Westley Bosco	westley.bosco@geemail.com	Broken Arrow	Oklahoma	4074199256392	f30b5697a07566821df34cd0966dbbc7	VISA 16 digit	36.003034033697098	-95.8790507879983664
19719	2020-04-13 08:38:45	2020-04-13	Wendell Strosin-Kessler	wendell.strosin.kessler@geemail.com	Lubbock	Texas	52360245491917410	04ec48286e0601f9748f99483981b75d	VISA 16 digit	33.4719966337591472	-101.970246588011094
19720	2020-04-13 08:45:35	2020-04-13	Scottie Kuphal	scottie.kuphal@geemail.com	Visalia	California	3005916185241611	11ce95f2d8080ba5bfe362de61cbcc91	Diners Club / Carte Blanche	36.4005605888042609	-119.234265569377328
19721	2020-04-13 08:45:46	2020-04-13	Dr. Britni Buckridge	dr.britni.buckridge@woohoo.com	Buffalo	New York	180061926941363964	0f91182d0cd6f67192c939464d8833c8	Discover	42.9432241622079118	-78.7876716335237006
19722	2020-04-13 08:52:26	2020-04-13	Dr. Tristian Kemmer	dr.tristian.kemmer@geemail.com	Wichita	Kansas	3096008950913509103	3b1eeafc8f6a6788bebd1635dcc07dd1	Mastercard	37.6109580140437956	-97.3767875804767016
19723	2020-04-13 09:03:27	2020-04-13	Lydia Koss	lydia.koss@geemail.com	Jacksonville	Florida	869958786094951535	07989626c2b671997c409e573e729619	VISA 16 digit	30.3129308849625296	-81.7302118859332154
19724	2020-04-13 09:08:23	2020-04-13	Katharina Frami	katharina.frami@woohoo.com	Clovis	California	3112767067709017273	ec1e94e5483224a7a256f6ab419b8b5b	Diners Club / Carte Blanche	36.7462544555187236	-119.753051552602642
19725	2020-04-13 09:31:34	2020-04-13	Evelyn Nitzsche	evelyn.nitzsche@woohoo.com	Davenport	Iowa	180043182285547316	fd87d786036e1346175d139677e00c24	JCB 16 digit	41.5853885355669988	-90.645039980016648
19726	2020-04-13 09:42:28	2020-04-13	Hope Hickle	hope.hickle@warmmail.com	Los Angeles	California	3444313006304567	81282aad44dcc4ccd549d1dedca1f2ff	Diners Club / Carte Blanche	34.1106589033134284	-118.381986352428044
19727	2020-04-13 09:44:54	2020-04-13	Miss Sheryll Shields	miss.sheryll.shields@woohoo.com	Pearland	Texas	4728699449514	8aa09745edaa02e44f619a3b3d475bff	VISA 16 digit	29.6335035060804337	-95.3497073327511515
19728	2020-04-13 09:47:01	2020-04-13	Keesha Weissnat	keesha.weissnat@geemail.com	Austin	Texas	4623568459109073	88fe10f38a5e7050d1e623916ed63430	JCB 15 digit	30.3863583536013948	-97.7317316500708557
19729	2020-04-13 09:49:00	2020-04-13	Ms. Eugenie Padberg	ms.eugenie.padberg@geemail.com	San Francisco	California	4877486622443	c5b0fc7951f1a6d51d3a20feb4fb7e1c	JCB 16 digit	37.7535335067892177	-122.407609660236233
19730	2020-04-13 09:51:52	2020-04-13	Leala Mertz-Upton	leala.mertz.upton@woohoo.com	Oakland	California	3112702026434756397	69a943887bbb24531b396e2dbbfd0fc5	Voyager	37.8117161268855995	-122.285134756847384
19731	2020-04-13 09:53:55	2020-04-13	Jovani Hickle	jovani.hickle@geemail.com	Ann Arbor	Michigan	4978119952742	452e7619cb89f59caa1c817d838b6279	JCB 16 digit	42.2285980405811188	-83.6723492450654618
19732	2020-04-13 10:11:19	2020-04-13	Nicki Volkman	nicki.volkman@geemail.com	Odessa	Texas	3496434959043262	f3e00a8da0fb9a39c0598b1d566b01a6	Voyager	31.7960160080354655	-102.34490584583618
19733	2020-04-13 10:13:54	2020-04-13	Crockett Gutkowski	crockett.gutkowski@geemail.com	Philadelphia	Pennsylvania	676237510846241	806098b8214dcef730d9fc9a451b2239	Discover	39.9748830333776795	-75.1516983435388681
19734	2020-04-13 10:24:31	2020-04-13	Jacquelin Tromp-Harber	jacquelin.tromp.harber@geemail.com	Portland	Oregon	4477413973512733	c30ebec60c83c7e6859f2395cca393b9	Diners Club / Carte Blanche	45.5421947294268747	-122.647075777221474
19735	2020-04-13 10:27:26	2020-04-13	Miss Oralia Bailey MD	miss.oralia.bailey.md@geemail.com	Cape Coral	Florida	3003316436008210	26259f0f3236304e2ff1af3d72cf2f89	Mastercard	26.5640213228266688	-82.0652536878898786
19736	2020-04-13 10:47:01	2020-04-13	Genesis Huel MD	genesis.huel.md@geemail.com	Overland Park	Kansas	54595632779652214	5dec71232139003401cf6091b9eb1332	VISA 16 digit	38.9819801871068776	-94.6257977604441436
19737	2020-04-13 10:58:57	2020-04-13	Ms. Jordan Abshire	ms.jordan.abshire@woohoo.com	Lansing	Michigan	3007270658882321	207cdc7cbab47e7f1e3e7831b21abf82	VISA 13 digit	42.7091356832843303	-84.5460089136503541
19738	2020-04-13 11:06:04	2020-04-13	Dr. Amir Dooley	dr.amir.dooley@geemail.com	Louisville	Kentucky	561224479926594	31883a9b077df933d91be0c56d464673	American Express	38.1492300406467137	-85.679866379459952
19739	2020-04-13 11:12:40	2020-04-13	Sie Hoppe	sie.hoppe@geemail.com	Pittsburgh	Pennsylvania	4421717245311220	83575a61007ba581bde9e2570d991117	Diners Club / Carte Blanche	40.4792772566854921	-79.9466992113910635
19740	2020-04-13 11:21:17	2020-04-13	Nona Gutmann-Romaguera	nona.gutmann.romaguera@woohoo.com	Riverside	California	4373393677936	e804dd3cc2fc6747e47d9cc47332d4e2	Discover	34.0191484204441323	-117.397239724729943
19741	2020-04-13 11:23:08	2020-04-13	Allean Predovic	allean.predovic@geemail.com	New York	New York	869967460338444223	edd114bf5dffeae5d623472a959e2249	VISA 16 digit	40.6540991642735889	-73.8447979896225064
19742	2020-04-13 11:25:14	2020-04-13	Dr. Kacy Cummerata PhD	dr.kacy.cummerata.phd@warmmail.com	Los Angeles	California	869968679228344461	2cade14d4684c82a913a46ac150d8100	JCB 16 digit	34.0037837428372356	-118.327436561229817
19743	2020-04-13 11:29:05	2020-04-13	Lolla Lehner	lolla.lehner@warmmail.com	South Bend	Indiana	3112712192488086806	480909074706f194be0995f50f50945e	American Express	41.7379636871308151	-86.3454410590752985
19744	2020-04-13 11:43:52	2020-04-13	Demond Hills	demond.hills@geemail.com	Houston	Texas	4910625121995206	aae6ec68d0389ef557427fb71c07c80c	JCB 15 digit	29.8192153315138064	-95.351844140935313
19745	2020-04-13 12:06:49	2020-04-13	Mr. Conor Satterfield III	mr.conor.satterfield.iii@geemail.com	Philadelphia	Pennsylvania	639007123106622	df6679f76b55b0d63dc8a2ac8c6a526f	Mastercard	40.0438541844446192	-75.1165847200334156
19746	2020-04-13 12:08:52	2020-04-13	Mr. Eber Denesik DDS	mr.eber.denesik.dds@geemail.com	Lafayette	Louisiana	501809331560517	e10958088652a2bd04e5f30cc07aec7f	VISA 16 digit	30.1812550974056109	-92.0897111734691975
19747	2020-04-13 12:11:22	2020-04-13	Dr. Jan Jacobs DVM	dr.jan.jacobs.dvm@geemail.com	San Francisco	California	3462866141328749	9cb0639e94801dc110d3fc3078891c9e	Maestro	37.7429670591282047	-122.427510518895275
19748	2020-04-13 12:11:25	2020-04-13	Karie Cruickshank MD	karie.cruickshank.md@geemail.com	Memphis	Tennessee	3444796068351304	fedd73dd16973373f181aaa49c59e2a1	JCB 16 digit	35.0422119279459139	-90.0334247357934743
19749	2020-04-13 12:19:09	2020-04-13	Horace O'Conner	horace.o'conner@woohoo.com	Atlanta	Georgia	6011026767791326006	de64da69908d85237da67e08d11b4ce2	JCB 15 digit	33.6707861623536786	-84.4553897040009502
19750	2020-04-13 12:25:24	2020-04-13	Marquise Ernser-Raynor	marquise.ernser.raynor@geemail.com	Springfield	Missouri	869989591377735974	f1d1b8cf4a521a35ec330912e757a96b	JCB 15 digit	37.2620116885479575	-93.358463063166667
19751	2020-04-13 12:28:57	2020-04-13	Mr. Maverick Hermann PhD	mr.maverick.hermann.phd@geemail.com	Tampa	Florida	4986972718835687	fcf70aeddc735ec6d784343f5fb3f01a	Mastercard	27.8922669457387151	-82.4279458318583664
19752	2020-04-13 12:42:01	2020-04-13	Taylor Greenfelder	taylor.greenfelder@geemail.com	San Francisco	California	561297701710655	fe93a772bb90a75234fae09de300470a	VISA 16 digit	37.7950928361878766	-122.428602095698366
19753	2020-04-13 12:51:56	2020-04-13	Dr. Burke O'Reilly Jr.	dr.burke.o'reilly.jr.@geemail.com	Arlington	Texas	3024410543838285	4bc7912a639ca9b6fb6be9a16f162613	Mastercard	32.6698970319952764	-97.0722781508255821
19754	2020-04-13 13:04:48	2020-04-13	Ernestine Toy-Raynor	ernestine.toy.raynor@geemail.com	Oklahoma City	Oklahoma	3158140203701517899	ab131e20921eee8177782141c84bc3bd	Mastercard	35.4883631151545842	-97.5556436743017343
19755	2020-04-13 13:05:13	2020-04-13	Dariana Grimes	dariana.grimes@warmmail.com	Salt Lake City	Utah	4923009954972290	9cf0f8cc4100c786ba8f8500c641fde4	VISA 16 digit	40.8637709262926094	-111.944364418642593
19756	2020-04-13 13:14:31	2020-04-13	Lottie Franecki-Moore	lottie.franecki.moore@geemail.com	Tacoma	Washington	4436021806811	cf3908c5280959d82a78fd84a3357868	VISA 16 digit	47.1940511230964219	-122.431001723720883
19757	2020-04-13 13:31:55	2020-04-13	Redden Davis	redden.davis@geemail.com	Norfolk	Virginia	53262180437906541	b3247035c7678e5a3ddfd26008220360	VISA 16 digit	36.971906119912866	-76.2247443157252036
19758	2020-04-13 13:34:07	2020-04-13	Issac Terry	issac.terry@geemail.com	Hayward	California	3096277893129450759	ab58e0d0bbd7fd22d0dacde9b3e46603	Maestro	37.602153394742686	-122.014820952180401
19759	2020-04-13 13:42:31	2020-04-13	Madyson Breitenberg PhD	madyson.breitenberg.phd@geemail.com	Lancaster	California	4911601790079704	deb67ae072dee1656a43da230dab9529	Diners Club / Carte Blanche	34.7536105519406533	-118.095443138756963
19760	2020-04-13 13:49:32	2020-04-13	Lorena Langworth	lorena.langworth@woohoo.com	Fullerton	California	53328604442120501	2b1fe27aee04974b95dc7bac93d2a868	Mastercard	33.9011250607360139	-117.923284403720871
19761	2020-04-13 13:57:20	2020-04-13	Mr. Thornton Morissette	mr.thornton.morissette@geemail.com	San Francisco	California	3750015595365443	083cfd41d1d4d602dbb69f6c82ae296a	VISA 13 digit	37.7693397754077296	-122.414237288346271
19762	2020-04-13 14:39:15	2020-04-13	Mr. Abel Zulauf V	mr.abel.zulauf.v@warmmail.com	Dallas	Texas	3025807718077525	cf5e8f54bd25fdacd3f1e8300acb936c	Voyager	32.8166718669973321	-96.844386429103082
19763	2020-04-13 14:50:39	2020-04-13	Agustin Runolfsson	agustin.runolfsson@geemail.com	Fort Worth	Texas	6011002009231138388	1b51e45edd79c597282138bff6e9a43f	VISA 13 digit	32.7384367575459194	-97.2622959499999808
19764	2020-04-13 15:11:56	2020-04-13	Manuel Cassin	manuel.cassin@geemail.com	Lafayette	Louisiana	3528796907860903479	8a10aa04496d61487904b98e1b413e53	JCB 15 digit	30.2789920369140795	-91.9852708241287615
19765	2020-04-13 15:15:40	2020-04-13	Mr. Keyon Larson	mr.keyon.larson@woohoo.com	Overland Park	Kansas	869928696122847372	afe30d5eec4a397643563c4f40197caa	JCB 16 digit	38.9235931431744291	-94.5984245845623377
19766	2020-04-13 15:18:11	2020-04-13	Hale Muller II	hale.muller.ii@geemail.com	San Jose	California	3796463883621273	0f7470541ab39cb823d4228b7b03e689	American Express	37.2542907486025285	-121.898126698586722
19767	2020-04-13 15:21:02	2020-04-13	Izabella O'Keefe	izabella.o'keefe@woohoo.com	Huntsville	Alabama	869911770791142362	e02a86a67f3cb3dbd53c692913692d2b	VISA 16 digit	34.6590177833344768	-86.6504511494208174
19768	2020-04-13 15:43:47	2020-04-13	Montana Johns	montana.johns@woohoo.com	San Francisco	California	561264019790159	7fa9cebb93eae75a87b0b01a516884cf	VISA 16 digit	37.7584977441664122	-122.423333571275805
19769	2020-04-13 15:44:21	2020-04-13	Frida Stanton PhD	frida.stanton.phd@warmmail.com	Henderson	Nevada	3096136884689247454	b0de517a028f28de393ada90cd47e7cd	Maestro	35.9275670831024669	-115.115346728420633
19770	2020-04-13 15:49:59	2020-04-13	Marleigh Wiegand-Gutkowski	marleigh.wiegand.gutkowski@geemail.com	San Antonio	Texas	501860625007525	2e7f4fd64d457e2137b59392e94fa9b8	VISA 16 digit	29.4914780993551027	-98.5849152956925252
19771	2020-04-13 16:09:00	2020-04-13	Arjun Renner	arjun.renner@geemail.com	Philadelphia	Pennsylvania	3158449479062001974	d3ecbc8a5b799af06460acd44f67c84e	Discover	39.9167107396252447	-75.2049921548359208
19772	2020-04-13 16:11:55	2020-04-13	Mr. Ronal Wolf	mr.ronal.wolf@geemail.com	Denver	Colorado	3337854714300295873	4628da03afc69ce8c1d7221617f84546	Discover	39.7522208948206099	-104.840035914421463
19773	2020-04-13 16:19:45	2020-04-13	Erland Ward	erland.ward@geemail.com	Lincoln	Nebraska	3003082477719384	0298b0330996e256b2b0d657507ef474	Diners Club / Carte Blanche	40.8587610193546809	-96.6834821527984047
19774	2020-04-13 16:26:46	2020-04-13	Miss Vicy Ferry DVM	miss.vicy.ferry.dvm@geemail.com	New York	New York	3158395911896797561	2a09910af2f46ecfa581deb385a27259	Diners Club / Carte Blanche	40.6166348331365725	-73.9069505875360164
19775	2020-04-13 16:29:38	2020-04-13	Paulette Marquardt	paulette.marquardt@geemail.com	Oakland	California	3763305828108941	69ca40e56d35a260853e1004135a9679	JCB 16 digit	37.7718852057340797	-122.238937738952728
19776	2020-04-13 16:33:41	2020-04-13	Alani McDermott	alani.mcdermott@geemail.com	San Francisco	California	4001151176881894	8e1d53e1129255ff3f2df7891b11e964	American Express	37.7684870530392942	-122.438870149708322
19777	2020-04-13 16:35:40	2020-04-13	Mrs. Mahalie Jakubowski DDS	mrs.mahalie.jakubowski.dds@geemail.com	Philadelphia	Pennsylvania	4803940424432	a4154feea98c95e7251d08fe655d2612	JCB 16 digit	39.9577202818781103	-75.1142119848534549
19778	2020-04-13 16:37:49	2020-04-13	Mr. Gabriel Dickens I	mr.gabriel.dickens.i@geemail.com	Buffalo	New York	869930338441497326	030c76856dacc9cf8d991920d5e4af96	Diners Club / Carte Blanche	42.8266809617355477	-78.9464149264551764
19779	2020-04-13 16:42:35	2020-04-13	Andria Shields PhD	andria.shields.phd@warmmail.com	Chula Vista	California	676178574213803	425c55e028b707a821c9d2a221aed4e3	Diners Club / Carte Blanche	32.5942709540713551	-116.977309929090353
19780	2020-04-13 16:57:09	2020-04-13	Miss Dusty Kautzer DDS	miss.dusty.kautzer.dds@geemail.com	Atlanta	Georgia	3007965217563888	a729c51d3c4fbe6add6325b7bfbd2c15	Maestro	33.7155404542382797	-84.5198937399823222
19781	2020-04-13 17:00:19	2020-04-13	Milo Raynor	milo.raynor@warmmail.com	Cape Coral	Florida	51444540778611292	341c3fe6152e01f8dc00377ea0b6d694	Diners Club / Carte Blanche	26.7109338205277922	-81.9211353193107925
19782	2020-04-13 17:05:35	2020-04-13	Monroe Gottlieb	monroe.gottlieb@geemail.com	Hialeah	Florida	3528034700524251860	bbfbe9343d4e131efd1201fcc51c158f	Discover	25.8497454843461512	-80.3688500716254026
19783	2020-04-13 17:05:48	2020-04-13	Dr. Colbert Ortiz	dr.colbert.ortiz@woohoo.com	Los Angeles	California	180015983833534621	6d8b16655612a3d927f31d4b10972693	Diners Club / Carte Blanche	33.9938862194638673	-118.374111509927729
19784	2020-04-13 17:22:11	2020-04-13	Travon Emard	travon.emard@geemail.com	New York	New York	4747954587883	7defad3912875b4b82ae1b14643acff1	Voyager	40.7195616184491627	-73.9904548861447751
19785	2020-04-13 17:27:15	2020-04-13	Grant Stamm V	grant.stamm.v@warmmail.com	Lakewood	Colorado	3048888080799695	c1e9f852118a407e65dad9a7b9f88f10	Maestro	39.7856449535056953	-105.134068478413297
19786	2020-04-13 17:28:40	2020-04-13	Elenor Gibson	elenor.gibson@woohoo.com	Ann Arbor	Michigan	4673945098718937	4b746345e610dcd3fe22ddb60ac8ecd5	Discover	42.2315188292939183	-83.7043730570111535
19787	2020-04-13 17:54:42	2020-04-13	Pauline Borer MD	pauline.borer.md@warmmail.com	Fort Worth	Texas	54168741909773928	d4ea237f2e4ec24e617fadeeca813425	Diners Club / Carte Blanche	32.8755226539038148	-97.4290136663064317
19788	2020-04-13 18:14:48	2020-04-13	Nella Wehner	nella.wehner@geemail.com	Saint Paul	Minnesota	6011928499295518362	f4e4e83250271038abda0143a8f1698a	Voyager	44.9938634151067589	-93.1788757337987477
19789	2020-04-13 18:21:05	2020-04-13	Kinsey Harvey DDS	kinsey.harvey.dds@geemail.com	Santa Clara	California	3088013904442131684	ee01c93ad953ab53004aa64232cb65f7	JCB 15 digit	37.4558654388696013	-121.900874876323712
19790	2020-04-13 18:47:37	2020-04-13	Blair Kiehn-Macejkovic	blair.kiehn.macejkovic@geemail.com	Los Angeles	California	210022526553927144	0daf494efc967853a790277928a19914	Discover	33.9849299427919078	-118.314620738475767
19791	2020-04-13 18:50:19	2020-04-13	Dr. Dean Hand	dr.dean.hand@woohoo.com	Honolulu	Hawaii	4656332756047	8d9caf30f4ec0fc7e54f94b3b9940f13	Diners Club / Carte Blanche	21.3347078382719317	-157.875754435521003
19792	2020-04-13 18:51:57	2020-04-13	Jaylee Hayes	jaylee.hayes@woohoo.com	Jacksonville	Florida	869989769965348331	b47564c02b1809ef0aa25bfbdd071f32	JCB 16 digit	30.36953101922348	-81.6604431048113923
19793	2020-04-13 18:58:09	2020-04-13	Verner Thiel	verner.thiel@warmmail.com	Greensboro	North Carolina	3112978201557898956	0ea39092e4de69ca015f7657aff6d467	Maestro	36.1094485016655184	-79.8765697023812606
19794	2020-04-13 18:59:04	2020-04-13	Dr. Seymour Hessel	dr.seymour.hessel@geemail.com	Oklahoma City	Oklahoma	6011975227702082017	5d882478256cda147d60125d74f38b0e	Discover	35.4263945046257263	-97.505503922131652
19795	2020-04-13 19:04:09	2020-04-13	Dr. Alonza Kiehn	dr.alonza.kiehn@geemail.com	Manchester	New Hampshire	3024665960266332	d5d88283fcd91636966ba9073a45aebc	VISA 16 digit	43.0567096184544269	-71.3724110920805543
19796	2020-04-13 19:23:43	2020-04-13	Mannie VonRueden DDS	mannie.vonrueden.dds@warmmail.com	Clarksville	Tennessee	180082777650943644	6799f85bc6e2ca81f628347f713f2b43	Maestro	36.5219903419386611	-87.3561843541868086
19797	2020-04-13 19:24:38	2020-04-13	Alisha Ryan MD	alisha.ryan.md@woohoo.com	New York	New York	4424641403987	bd850da5bd569716012b643dfa9d50b3	Discover	40.6960543749146169	-73.9961099541176139
19798	2020-04-13 19:35:52	2020-04-13	Jodie Moen	jodie.moen@geemail.com	Oakland	California	4078420332640991	0c807899c28e069032d26eeb8c3ee3c7	VISA 16 digit	37.7826058306796924	-122.273406956192503
19799	2020-04-13 19:39:10	2020-04-13	Ewin Larson	ewin.larson@woohoo.com	South Bend	Indiana	3158434142258420575	cc3df61b8192eb03123d7daa6e3044a3	VISA 16 digit	41.6020436503604074	-86.2802144776619997
19800	2020-04-13 19:40:36	2020-04-13	Dr. Sanders Murphy	dr.sanders.murphy@geemail.com	Santa Ana	California	55674382220545302	db24cb0e865ba8bdd9c67bc97ceb5d8d	Voyager	33.8182693433120818	-117.893139700444408
19801	2020-04-13 19:47:00	2020-04-13	Wilkie Orn	wilkie.orn@warmmail.com	Laredo	Texas	3770732969724445	8623f89ee292d2b37185d6c72beea941	VISA 13 digit	27.5779265470985351	-99.4127517075285283
19802	2020-04-13 20:03:15	2020-04-13	Dr. Darcy Stehr MD	dr.darcy.stehr.md@woohoo.com	Mesa	Arizona	55295643868703407	c0a288fdf7bb642dfc6fb2609a4641ef	JCB 15 digit	33.3218166524223989	-111.815655519056691
19803	2020-04-13 20:03:17	2020-04-13	Corliss Bruen	corliss.bruen@geemail.com	San Francisco	California	6011912297936437770	017f835c588bdbac18dab82ed7cbd289	Maestro	37.7632450175836638	-122.424654764944819
19804	2020-04-13 20:11:42	2020-04-13	Ashby Buckridge	ashby.buckridge@geemail.com	San Diego	California	6011198582883959925	04876240efb12c2ad414e899ac049124	Diners Club / Carte Blanche	32.7958236982647335	-117.126029753349727
19805	2020-04-13 20:13:49	2020-04-13	Mr. Francisco Weissnat	mr.francisco.weissnat@geemail.com	San Francisco	California	6011061653297640007	4b9d6ac142e6470518b91582754ba26b	Voyager	37.7622615590643562	-122.448641322052268
19806	2020-04-13 20:28:32	2020-04-13	Sylvia Cole	sylvia.cole@geemail.com	San Francisco	California	3112873521078770806	7877f094e11f02232a9e0f7328d1c85f	VISA 13 digit	37.7930791399842647	-122.419897439811706
19807	2020-04-13 20:31:20	2020-04-13	Dr. Tanya Yost PhD	dr.tanya.yost.phd@geemail.com	San Francisco	California	6011665406425513319	ffba1b4e8223bf1300b40a39a982abc0	Diners Club / Carte Blanche	37.7654633588647002	-122.45580275681391
19808	2020-04-13 20:36:52	2020-04-13	Kristan Bosco	kristan.bosco@geemail.com	Houston	Texas	4420199705917344	d1e5a3283f077d3079b034c1afdf7ae2	Voyager	29.7595609328322119	-95.4348179906621539
19809	2020-04-13 20:50:05	2020-04-13	Vita Gleason	vita.gleason@geemail.com	Chicago	Illinois	4416804466626630	445f7798b49a6af3662ba442310d1b51	JCB 15 digit	41.8851061057601157	-87.6378822555329577
19810	2020-04-13 21:00:00	2020-04-13	Ms. Dorla Heidenreich	ms.dorla.heidenreich@woohoo.com	San Francisco	California	55077100518946138	05125780e9c4c71b472cd700f847f014	Maestro	37.7556530467430917	-122.471257095197501
19811	2020-04-13 21:38:08	2020-04-13	Gracia Stanton	gracia.stanton@geemail.com	Washington	District of Columbia	210002584504144438	0c4273bb828bea1cd3aa2c4d1364b513	VISA 16 digit	38.8590895289353995	-77.0130977091126141
19812	2020-04-13 21:42:58	2020-04-13	Christina Feil-Toy	christina.feil.toy@geemail.com	Pasadena	Texas	3006640904864847	98c6dc3e25cd15154c8c679de913160b	JCB 15 digit	29.5977728786285965	-95.0784444354422362
19813	2020-04-13 21:43:09	2020-04-13	Randall Kuhic	randall.kuhic@warmmail.com	Grand Prairie	Texas	52234853231944794	02874f1b3b42d22483e632ef14ef1931	Discover	32.7558717478118879	-97.0156414314977837
19814	2020-04-13 21:52:09	2020-04-13	Chelsi Orn	chelsi.orn@geemail.com	San Bernardino	California	3007636571203375	a4fb4b821f6e229afec028c823bf6aaf	VISA 13 digit	34.1374841300103782	-117.231020870969076
19815	2020-04-13 21:52:50	2020-04-13	Dr. Amare Lang	dr.amare.lang@warmmail.com	San Francisco	California	3437183408617703	20dbec7706c0772e4a61001df205d5bf	American Express	37.7491375195471122	-122.446566321468126
19816	2020-04-13 21:55:22	2020-04-13	Nakita Tillman PhD	nakita.tillman.phd@woohoo.com	Oakland	California	4794753944816333	d5549b3431ee7619d7c303d288e1591c	JCB 16 digit	37.7864216272329685	-122.28867249758764
19817	2020-04-13 22:22:10	2020-04-13	Rosalinda Auer	rosalinda.auer@geemail.com	Sterling Heights	Michigan	55974597908860478	2a03a87f7087fa9390eb4a246d1bdae1	JCB 16 digit	42.4943933635100777	-82.9478122518092391
19818	2020-04-13 22:42:25	2020-04-13	Wade Kris	wade.kris@geemail.com	Tampa	Florida	6011609884661581563	b5a4ebffd7b85363dd3069f13b751ecb	JCB 16 digit	28.0065406574517475	-82.4440908956553784
19819	2020-04-13 22:43:29	2020-04-13	Gael Adams	gael.adams@geemail.com	Fort Worth	Texas	4355386444052959	836eaaca3baae1fe76e2a85bd63d050e	Mastercard	32.8201231415439381	-97.3211031731970593
19820	2020-04-13 22:50:16	2020-04-13	Willia Schumm	willia.schumm@geemail.com	Oakland	California	210027868143470796	80a081364ff50e4eb5627d8a41ee06e1	Voyager	37.7987072502374915	-122.286057470144044
19821	2020-04-13 22:50:49	2020-04-13	Dr. Burk Douglas MD	dr.burk.douglas.md@geemail.com	Nashville	Tennessee	3470725486291658	759fee4a840034758e78a1ef4b88285c	VISA 13 digit	36.2367135307874477	-86.8467459584958874
19822	2020-04-13 23:08:44	2020-04-13	Dr. Corbin Goyette	dr.corbin.goyette@geemail.com	Round Rock	Texas	4450417822035086	177c78013dd0e443455c11140dcd3e9d	JCB 16 digit	30.5891504547696584	-97.6921888882610858
19823	2020-04-13 23:09:48	2020-04-13	Delos Mueller-Stokes	delos.mueller.stokes@geemail.com	Bridgeport	Connecticut	210098879614815041	287ba80448e9ddf820a02a4049ac45b5	Diners Club / Carte Blanche	41.2433913320466843	-73.195052798315146
19824	2020-04-13 23:36:45	2020-04-13	Miss Dallas Lubowitz DDS	miss.dallas.lubowitz.dds@woohoo.com	Las Cruces	New Mexico	3479974340818253	42aa85cf37c9822c5a3fa535828ac735	American Express	32.2891144552301625	-106.716102898225927
19825	2020-04-13 23:55:55	2020-04-13	Hurley Lueilwitz	hurley.lueilwitz@warmmail.com	Houston	Texas	6011308356953175358	bade99ad6852a468c52fccf942dc21a2	VISA 13 digit	29.8838062728367753	-95.397655001004793
19826	2020-04-14 00:03:52	2020-04-14	Hunter Hahn-Bernier	hunter.hahn.bernier@geemail.com	Arlington	Texas	3158036124735905198	36e869cbe5fe0a1e3ba64d556668db10	Maestro	32.7979358466591648	-97.1473866154931471
19827	2020-04-14 00:14:30	2020-04-14	Sincere Lind	sincere.lind@woohoo.com	Berkeley	California	869943251474871587	13a9ddec6add871630779a2552130788	JCB 16 digit	37.8980012814643459	-122.258571029044489
19828	2020-04-14 00:37:47	2020-04-14	Eleonore Daugherty PhD	eleonore.daugherty.phd@geemail.com	San Francisco	California	4495000224980146	b3406ea77dc2b5f28158cd16be329e5c	American Express	37.7730586296864956	-122.447064719402618
19829	2020-04-14 00:46:47	2020-04-14	Felicie Shields-Jakubowski	felicie.shields.jakubowski@woohoo.com	Plano	Texas	54619568083375823	56f4e0876101d435bbcf0b5804a112a5	American Express	32.9743646784305611	-96.6671055725958155
19830	2020-04-14 01:23:33	2020-04-14	Minor Schmeler	minor.schmeler@geemail.com	Long Beach	California	180039464921528777	318c8df24d7a221ac239449b765266a4	Maestro	33.8251867049194814	-118.077096168852592
19831	2020-04-14 01:34:30	2020-04-14	Mr. Hence Haley	mr.hence.haley@geemail.com	Pearland	Texas	502004222771794	bfc65dcb53b51dd4cbc98c58df1ad01f	Maestro	29.5909467227563283	-95.2724918367661502
19832	2020-04-14 01:38:33	2020-04-14	Nathen Kemmer	nathen.kemmer@geemail.com	Detroit	Michigan	869925351508619051	7421564659d88e0501634f58232879c0	JCB 16 digit	42.341316374523565	-83.0434273567169896
19833	2020-04-14 01:46:01	2020-04-14	Carroll Franecki PhD	carroll.franecki.phd@geemail.com	San Francisco	California	3337955301680165880	5975ddae6cf72da78a9d1ada3232a3e5	American Express	37.8133568227439127	-122.446952700002072
19834	2020-04-14 01:47:56	2020-04-14	Cecil Bednar PhD	cecil.bednar.phd@geemail.com	Houston	Texas	3783802789517348	dbc3e130cb83edad77dcfeac024c295b	JCB 16 digit	29.8609826913181706	-95.3694918388981421
19835	2020-04-14 01:49:02	2020-04-14	Cher Bechtelar	cher.bechtelar@woohoo.com	Hollywood	Florida	4834789317652535	97b4db6c3a279629e9a661693076d132	JCB 16 digit	25.9319371627122166	-80.1424469329699747
19836	2020-04-14 02:01:08	2020-04-14	Justyn Swift	justyn.swift@geemail.com	Salt Lake City	Utah	55879896466260220	0fee341e256eb9266ce92f8e11669224	American Express	40.7747036935441187	-111.840315929142761
19837	2020-04-14 02:04:26	2020-04-14	Caleb Bernhard	caleb.bernhard@geemail.com	San Francisco	California	4313057236058	8333615e38d4c27706e53452b1a03ec6	JCB 16 digit	37.7653846043535708	-122.444086559405505
19838	2020-04-14 02:13:52	2020-04-14	Oneida Schmidt	oneida.schmidt@geemail.com	El Cajon	California	51578937775973410	3cd7a18c2172cfde0d6aae79b8c7986b	JCB 16 digit	32.7088164756081952	-117.003216672753553
19839	2020-04-14 02:18:56	2020-04-14	Dr. Denzil Walker	dr.denzil.walker@warmmail.com	Houston	Texas	210031557582935831	2e31414756cd73667850504f9dfa8e45	JCB 16 digit	29.6975358976129442	-95.3841272644713598
19840	2020-04-14 02:29:41	2020-04-14	Shep Klein	shep.klein@geemail.com	Madison	Wisconsin	4069807428821	37912ed204cfe9d3e01946795871e1ab	Maestro	43.1019782492864891	-89.3824494085159245
19841	2020-04-14 02:33:19	2020-04-14	Trilby Ratke	trilby.ratke@geemail.com	San Francisco	California	869911017793990368	5e2206be1859aab238cc7bd4692af7f5	VISA 16 digit	37.7633129172983857	-122.451648971362218
19842	2020-04-14 02:52:22	2020-04-14	Krista Stamm	krista.stamm@geemail.com	Chesapeake	Virginia	3528038825292733777	2d5d004ece9bc4a51c9732ff42984e7b	Diners Club / Carte Blanche	36.7704043848212834	-76.2681172389846296
19843	2020-04-14 03:17:41	2020-04-14	Mal Labadie-Kerluke	mal.labadie.kerluke@woohoo.com	Columbia	Missouri	180005631788353180	fce5db4070dd52262b684b172b2246bf	Diners Club / Carte Blanche	38.9197633242581631	-92.3366297769413364
19844	2020-04-14 03:18:48	2020-04-14	Kristin Willms	kristin.willms@warmmail.com	Surprise	Arizona	3709984448808366	f7be09761d770d4d696b5d88365fc9a7	Voyager	33.6699626268580587	-112.38343717532679
19845	2020-04-14 03:34:20	2020-04-14	Celia Corwin	celia.corwin@geemail.com	San Francisco	California	869985989212383030	d7845de05552c92c632bb62127150693	Diners Club / Carte Blanche	37.7665514717333792	-122.428971024731794
19846	2020-04-14 04:03:39	2020-04-14	Ms. Kim Smith	ms.kim.smith@warmmail.com	San Francisco	California	4384492200549207	5a7eeac91b644ebb490d2d7cb7f09a2a	Diners Club / Carte Blanche	37.7615146992910127	-122.433117804208251
19847	2020-04-14 04:07:06	2020-04-14	Jerad Beier	jerad.beier@geemail.com	Abilene	Texas	4916567819172017	a922dcb5a219803e6da7d3401d0d60ff	Discover	32.5113442274350675	-99.7570297167584386
19848	2020-04-14 04:12:59	2020-04-14	Lisa Batz DVM	lisa.batz.dvm@geemail.com	Portland	Oregon	3030495339015952	2cb4505cd60cd20543c04013dd972a5d	Maestro	45.5760375139191751	-122.653294500289491
19849	2020-04-14 04:30:41	2020-04-14	Gigi Wilderman	gigi.wilderman@geemail.com	New York	New York	869953285549464470	db585160527ab555a56741e57953528b	JCB 16 digit	40.6073788604922612	-74.0137977189745726
19850	2020-04-14 04:33:27	2020-04-14	Dr. Ballard VonRueden	dr.ballard.vonrueden@geemail.com	Long Beach	California	4484036245206221	431c5f9d7bef79c689c944b576ee9541	Discover	33.755737602366878	-118.067025722625843
19851	2020-04-14 04:35:08	2020-04-14	Jovita Berge	jovita.berge@geemail.com	Sparks	Nevada	3720414665242219	689d8b560b588cfa4cacab57f4084a6e	Diners Club / Carte Blanche	39.5872155403491135	-119.766552730821445
19852	2020-04-14 04:41:36	2020-04-14	Joaquin Collier	joaquin.collier@woohoo.com	Macon	Georgia	180087371969067157	c93e7f06bab712395e5d1f6e950ddff2	VISA 16 digit	32.8152833235926877	-83.7657507211163619
19853	2020-04-14 04:56:05	2020-04-14	Tess Runolfsdottir	tess.runolfsdottir@geemail.com	Detroit	Michigan	639022575157171	219966c68d359883e50fca06854ddd51	Diners Club / Carte Blanche	42.3988450838178395	-83.110628203547364
19854	2020-04-14 05:03:18	2020-04-14	Dashawn Nicolas-Gibson	dashawn.nicolas.gibson@woohoo.com	Durham	North Carolina	3088079805142392511	89348ef09bdea95eeee1fe99d218a741	VISA 16 digit	36.0125948993734966	-78.9880733659859828
19855	2020-04-14 05:13:09	2020-04-14	Hayden Gleichner PhD	hayden.gleichner.phd@geemail.com	Salt Lake City	Utah	6011271375850078211	04a06fd22dab5d6dd4dd33bc70a395e5	JCB 15 digit	40.7837957847543038	-111.948925415327764
19856	2020-04-14 05:17:29	2020-04-14	Woody Sauer	woody.sauer@woohoo.com	Milwaukee	Wisconsin	501881731426490	d6b4829ed9286985f2a88e2028133c84	Mastercard	42.9760987818326754	-88.0606381020609348
19857	2020-04-14 05:18:08	2020-04-14	Mylie Wolff DVM	mylie.wolff.dvm@geemail.com	El Paso	Texas	4447527221967	f60911a41027c77517bf02a731f3e956	JCB 16 digit	31.8464464425869309	-106.382348624521867
19858	2020-04-14 05:18:38	2020-04-14	Francis Lehner	francis.lehner@geemail.com	Des Moines	Iowa	503834081490061	219c13b57342a519b880bbfca9b302c9	JCB 16 digit	41.5494062850926085	-93.5357027338396847
19859	2020-04-14 05:26:14	2020-04-14	Dr. Ottie Leffler	dr.ottie.leffler@geemail.com	Montgomery	Alabama	3096491408431786178	875df1adacb40a675c494b7809ac7a9e	JCB 16 digit	32.3355073419798202	-86.2042564305163808
19860	2020-04-14 05:36:59	2020-04-14	Debroah Heaney	debroah.heaney@geemail.com	Lubbock	Texas	3112243311689377198	d2fb21bf0d8c80b02b9402520642a670	JCB 16 digit	33.4871871592052344	-101.891391961919894
19861	2020-04-14 06:15:12	2020-04-14	Author Smitham	author.smitham@geemail.com	Overland Park	Kansas	54842417090307917	8d596cd4a24a6018e3fbd5384f5ed8fe	Maestro	38.8538511716164692	-94.7443106076255503
19862	2020-04-14 06:20:54	2020-04-14	Alex Kuvalis	alex.kuvalis@geemail.com	Miami	Florida	51521726237525761	0745fe50d80ad8d125ee4532a350fe80	VISA 13 digit	25.8265836584053936	-80.1431544570125709
19863	2020-04-14 07:00:18	2020-04-14	Jerimy Beier	jerimy.beier@geemail.com	Port St. Lucie	Florida	53147784469375326	4f7987f19e0e51819df60020f39ae022	Diners Club / Carte Blanche	27.3470998663589349	-80.4495683812156273
19864	2020-04-14 07:02:07	2020-04-14	Nunzio Klein	nunzio.klein@geemail.com	San Diego	California	4974890497339925	2a63e7e22018de28290bacd4811914d7	VISA 16 digit	32.7771980730418093	-117.101458384273585
19865	2020-04-14 07:03:18	2020-04-14	Price Nolan	price.nolan@geemail.com	Saint Paul	Minnesota	4396660761490732	042756302887a065e6d605673bab625a	Diners Club / Carte Blanche	45.0325202086880836	-93.1994491494059645
19866	2020-04-14 07:04:46	2020-04-14	Edmond Von	edmond.von@warmmail.com	Akron	Ohio	3112929823496263362	2b6e5f6084834082069c5b2b869db536	VISA 13 digit	41.0940104970075168	-81.4728879893977194
19867	2020-04-14 07:05:22	2020-04-14	Julianna Cummerata	julianna.cummerata@warmmail.com	San Francisco	California	4735325771690	f2ff729a9a978c6816228e0551acfbde	JCB 15 digit	37.8172568015108368	-122.45670541414151
19868	2020-04-14 07:09:28	2020-04-14	Maurice Treutel-Heller	maurice.treutel.heller@geemail.com	Oakland	California	6011650969132180190	66404bb49f354f0a50e6da8c04911730	JCB 16 digit	37.8455820019236882	-122.26151677228377
19869	2020-04-14 07:18:36	2020-04-14	Harlie Dicki	harlie.dicki@geemail.com	Meridian	Idaho	3481644355358224	9de30d5f5ad9c449972f5a0993a83891	VISA 16 digit	43.6644196819055779	-116.375713097856931
19870	2020-04-14 07:23:19	2020-04-14	Bernardo Goodwin	bernardo.goodwin@warmmail.com	New York	New York	869907692688895926	55e708c1036568af535557c8e3347a9a	VISA 16 digit	40.6638469238523399	-73.8662103471707496
19871	2020-04-14 07:26:37	2020-04-14	Gennaro Hyatt	gennaro.hyatt@geemail.com	Berkeley	California	3528403370830746772	78d3c0af1df96a1d0071e29d83d2741f	JCB 16 digit	37.8692072536268469	-122.286312393051929
19872	2020-04-14 07:48:18	2020-04-14	Braedon Crooks-Wunsch	braedon.crooks.wunsch@geemail.com	Springfield	Massachusetts	3018312546542599	bcee07fe0881c9dbe0a1ca863893ec29	VISA 16 digit	42.1578306822776767	-72.6072421716153684
19873	2020-04-14 07:53:06	2020-04-14	Erna Sawayn	erna.sawayn@geemail.com	Long Beach	California	4314271322153	ee248cd31dc2366d81bb0ce53bdac247	American Express	33.7921958547837988	-118.093335289058459
19874	2020-04-14 07:53:44	2020-04-14	Renard Berge IV	renard.berge.iv@geemail.com	Oakland	California	4213565714655	36fd9c873f9ee31f71299430326e5815	Mastercard	37.8173219950076103	-122.268487779775498
19875	2020-04-14 07:56:54	2020-04-14	Latrice Bashirian	latrice.bashirian@geemail.com	New York	New York	060498688509524	06a176a1dd6b5c7032744f1bedba6401	JCB 16 digit	40.7112090800181008	-73.9994020813971787
19876	2020-04-14 08:07:36	2020-04-14	Enid Pouros	enid.pouros@geemail.com	Columbus	Ohio	52761725374941301	d173c3af0f49e085f6a7e68530663d72	Discover	39.9914196954153454	-83.0112427549205734
19877	2020-04-14 08:15:26	2020-04-14	Joey Dicki	joey.dicki@geemail.com	Chicago	Illinois	4831737954672483	9e0eed9433b7fce7f962361909cd556c	JCB 15 digit	41.8491626000799286	-87.6869180256530569
19878	2020-04-14 08:15:37	2020-04-14	Lylah Williamson	lylah.williamson@geemail.com	Berkeley	California	561261250337153	cf464f7a3cae199d5e11d219f877051d	Voyager	37.8789711555531596	-122.252281275526599
19879	2020-04-14 08:21:41	2020-04-14	Daulton Rath	daulton.rath@geemail.com	Los Angeles	California	3044839003260848	dde7d50e96e45b66748a905e5b90376d	VISA 13 digit	34.0124510370992112	-118.453113705151893
19880	2020-04-14 08:37:13	2020-04-14	Cadence Bruen	cadence.bruen@woohoo.com	Washington	District of Columbia	3096825017373137071	10c455076594644cdde5475090e65568	American Express	38.8242390042435375	-77.0723414357498342
19881	2020-04-14 08:42:08	2020-04-14	Tonja Rempel	tonja.rempel@geemail.com	El Cajon	California	6011978315318801560	c7a6e572a8fa8e982578f90db330ec21	JCB 15 digit	32.8527654344689068	-116.984060697927703
19882	2020-04-14 09:08:37	2020-04-14	Lucinda Quigley	lucinda.quigley@warmmail.com	Carrollton	Texas	4053287423627701	826fbc021369aaa7c91648703a00ddcc	Mastercard	32.9580904374286519	-96.9452052979126506
19883	2020-04-14 09:32:40	2020-04-14	Adamaris Skiles	adamaris.skiles@warmmail.com	New York	New York	6011431704457841217	3efbf2ec1e96ae835bea6e96b29da816	JCB 15 digit	40.6325345925744585	-73.9573007435433567
19884	2020-04-14 09:40:31	2020-04-14	Cristin Lindgren-Walter	cristin.lindgren.walter@warmmail.com	Winston–Salem	North Carolina	4776481075171847	8a65995f890b90423d4efed45cdca30c	JCB 16 digit	36.1426345632176833	-80.2282999052796413
19885	2020-04-14 09:42:12	2020-04-14	Ola Feest	ola.feest@geemail.com	San Jose	California	210005967406472410	1f2ac6eb32af85f18feaf72b7faa095d	Voyager	37.219962257268655	-121.868953417962047
19886	2020-04-14 09:47:01	2020-04-14	Edwina Glover-Berge	edwina.glover.berge@geemail.com	San Antonio	Texas	4196304152936845	dbdb5837f58d28d178e904cda0ea6b6d	American Express	29.5192744530808184	-98.6233136169448414
19887	2020-04-14 10:54:27	2020-04-14	Lugenia Ernser	lugenia.ernser@geemail.com	Winston–Salem	North Carolina	51909373575995512	6c654d338b5264e1cdd48a9bcebff7e6	JCB 15 digit	36.0078227547228309	-80.3343693263959153
19888	2020-04-14 11:26:06	2020-04-14	Dr. Tyler Rippin	dr.tyler.rippin@geemail.com	Washington	District of Columbia	4522442668743282	abb3981e067d636696da50705e969e3a	American Express	38.8178353377416698	-77.1076582468327132
19889	2020-04-14 11:51:06	2020-04-14	Miss Jada Nader	miss.jada.nader@geemail.com	Lansing	Michigan	675950139605518	1c931eff72a4ea847c39748b3441648a	VISA 16 digit	42.7746802734985963	-84.4693661027245213
19890	2020-04-14 12:10:36	2020-04-14	Esperanza Wilderman DVM	esperanza.wilderman.dvm@geemail.com	Los Angeles	California	3528981279728247837	1cf259f69a1e20f896ac8f59e6e2b142	VISA 16 digit	34.0958485849998851	-118.390534765598545
19891	2020-04-14 12:12:54	2020-04-14	Titus Nader-Hintz	titus.nader.hintz@woohoo.com	San Jose	California	53152984267601996	5ae1d7b552ca7094c9ff8f0305db1980	VISA 16 digit	37.2147880962405395	-121.820113328866285
19892	2020-04-14 12:28:41	2020-04-14	Von Mills	von.mills@geemail.com	Minneapolis	Minnesota	4415993041300	b51b893c2d20bf8f4ab874a6a98dedf0	Voyager	44.8711753379173572	-93.3654241972874814
19893	2020-04-14 12:38:08	2020-04-14	Donia Ward	donia.ward@geemail.com	San Francisco	California	4322881745831747	7e54206a8c1be7025197ad6727df1f1c	JCB 16 digit	37.7519617632526021	-122.432325674535278
19894	2020-04-14 12:43:18	2020-04-14	Dr. Gideon McClure	dr.gideon.mcclure@geemail.com	San Francisco	California	4162738034343987	b8ffab2fe9866a1a04e0917d067b142c	Mastercard	37.7741755554948355	-122.428191745272883
19895	2020-04-14 12:44:29	2020-04-14	Cheyanne Conroy	cheyanne.conroy@geemail.com	Columbus	Ohio	4380486405331	22c2ba96dfc53dc09325a3e41acdb323	Discover	39.9621457924179708	-82.9499558054611157
19896	2020-04-14 12:56:31	2020-04-14	Alyce Boyle	alyce.boyle@geemail.com	Columbus	Ohio	869918895057214861	510704d2d06771e0941ce75c0e155e98	American Express	40.035360214304923	-82.9490257298342897
19897	2020-04-14 13:20:05	2020-04-14	Mrs. Kaelynn O'Conner DDS	mrs.kaelynn.o'conner.dds@warmmail.com	Yonkers	New York	869979247149828751	f6d60c7d421256b79e191b117d6c91ee	Maestro	40.8516577347382892	-73.8468539650436497
19898	2020-04-14 13:20:44	2020-04-14	Lovie Bernier	lovie.bernier@geemail.com	Peoria	Arizona	4637272475574667	1301ef525870e2f93872000493a2a863	American Express	33.7902294947568365	-112.244369405174638
19899	2020-04-14 13:35:37	2020-04-14	Worley Bartoletti	worley.bartoletti@geemail.com	San Francisco	California	4864980576828709	082b240ea7eba348f9c96d50d0fd5c0d	Voyager	37.7991636711036492	-122.457093428803503
19900	2020-04-14 13:36:49	2020-04-14	Isa Stracke	isa.stracke@geemail.com	Fort Worth	Texas	4710826916219008	af4fc0310191290dbfd0d546226e3f1a	Discover	32.8115471629947422	-97.3223305569317176
19901	2020-04-14 13:43:31	2020-04-14	Cortney Sauer	cortney.sauer@geemail.com	Memphis	Tennessee	6011461076315732463	a8a3f9fce6b55acf3917dce6b7d99e32	JCB 16 digit	35.0931915724717101	-90.0561815765943408
19902	2020-04-14 13:46:50	2020-04-14	Dr. Nickolas Yundt	dr.nickolas.yundt@geemail.com	Omaha	Nebraska	6011682370528029418	f65042d648047964cda832bd8e54b479	JCB 16 digit	41.1783380333479485	-95.987728534976398
19903	2020-04-14 13:50:27	2020-04-14	Imogene Kertzmann DVM	imogene.kertzmann.dvm@geemail.com	Kent	Washington	3528458922959300437	d5615602ac771683a2e2fa1510e6a640	Diners Club / Carte Blanche	47.3316375526711326	-122.301173043451087
19904	2020-04-14 13:52:13	2020-04-14	Benjaman Kuphal	benjaman.kuphal@geemail.com	North Las Vegas	Nevada	6011669541758579341	e4f343d406863938be5188e550841c34	JCB 15 digit	36.3810262974508092	-115.108199754844989
19905	2020-04-14 13:53:33	2020-04-14	Ms. Essa Wolf DDS	ms.essa.wolf.dds@geemail.com	Honolulu	Hawaii	4683478173785033	08d48f59fd3afb4e916862a59908023f	Voyager	21.2253799942538137	-157.781356105089571
19906	2020-04-14 14:06:09	2020-04-14	Shae Koch-Wilderman	shae.koch.wilderman@geemail.com	Elgin	Illinois	6011541394306639942	6ff571ab2f7fcfdbb70d04f2aa52d29a	JCB 15 digit	42.0183138009909527	-88.3826926715027668
19907	2020-04-14 14:22:28	2020-04-14	Xander Smitham	xander.smitham@geemail.com	New York	New York	869979341596521165	6686441098071492be85affa01f61291	Discover	40.6704699903484439	-74.0223122892796965
19908	2020-04-14 14:23:29	2020-04-14	Mellisa Kiehn	mellisa.kiehn@warmmail.com	Tulsa	Oklahoma	6011755449603593720	cf08b32def6f5ddb0f1b86b7c58cd8fd	Mastercard	36.1986977822516067	-95.9829884488556502
19909	2020-04-14 14:34:24	2020-04-14	Tammy Funk	tammy.funk@geemail.com	Albuquerque	New Mexico	4972865810243139	77b36bc8ca2d2e08cfe85622b94bb557	VISA 16 digit	35.0190745609015224	-106.584982632899283
19910	2020-04-14 14:40:37	2020-04-14	Barney Watsica	barney.watsica@geemail.com	West Palm Beach	Florida	869992734501588779	f7e4d371e732c8894b29547debf1dbb3	Diners Club / Carte Blanche	26.8134742271468056	-80.1280243541881418
19911	2020-04-14 14:51:00	2020-04-14	Lue Wolf-Bernier	lue.wolf.bernier@geemail.com	Berkeley	California	4122172547333815	f768685661d4b80a0998f1bcb1b8a474	VISA 16 digit	37.8859299773011102	-122.278097337499062
19912	2020-04-14 15:02:17	2020-04-14	Terrell Hand	terrell.hand@woohoo.com	San Antonio	Texas	180074901488509696	acb09491af536fb5ebc5a990030e3b60	Maestro	29.4778443393833953	-98.4999559887520917
19913	2020-04-14 15:18:27	2020-04-14	Angelic Beer	angelic.beer@geemail.com	St. Petersburg	Florida	3528879776091244148	dbe73674556ea7834752e80cbe253070	VISA 13 digit	27.8265864269696195	-82.6431629597101249
19914	2020-04-14 15:25:24	2020-04-14	Terry Upton I	terry.upton.i@geemail.com	Oakland	California	869990594711943137	678c746881504696b90e6163420bc7bf	Maestro	37.8233710806585464	-122.260636428149368
19915	2020-04-14 15:27:02	2020-04-14	Kris Bernhard-Stamm	kris.bernhard.stamm@geemail.com	New York	New York	869992028221310048	36588f8d5232371932f32b7df7f6e889	Voyager	40.6881177935507168	-73.8914217340655597
19916	2020-04-14 15:35:52	2020-04-14	Alvan Kirlin	alvan.kirlin@geemail.com	Bakersfield	California	4446052192163	abaaa9050b71f543bc4a78197c4b72a2	JCB 16 digit	35.3631228927697947	-119.074480876959115
19917	2020-04-14 15:50:35	2020-04-14	Mrs. Aspen Fay	mrs.aspen.fay@woohoo.com	Killeen	Texas	4105012377120	4ba37ed0f762d49784274839087247fd	Maestro	31.1620169461004437	-97.6955568212252103
19918	2020-04-14 15:52:53	2020-04-14	Emaline Roob PhD	emaline.roob.phd@geemail.com	Chicago	Illinois	4580703554049	6ab8560a21e58e510ac242992b522e5a	Voyager	41.8141424509067079	-87.663842412413274
19919	2020-04-14 15:56:06	2020-04-14	Mr. Alphons Skiles IV	mr.alphons.skiles.iv@geemail.com	Houston	Texas	4381242189748	bff2fb5a24efdd71f78c2853f1011e05	Mastercard	29.8547386944372199	-95.2922901350088409
19920	2020-04-14 16:01:26	2020-04-14	Ransom Jerde III	ransom.jerde.iii@geemail.com	Columbia	Missouri	3088327674618471997	ecd0722ded56d7ab97dbd2653668ba5b	American Express	38.9483287715700115	-92.3598042594787785
19921	2020-04-14 16:34:19	2020-04-14	Miss Ansley Weber MD	miss.ansley.weber.md@woohoo.com	El Paso	Texas	6011980310280135986	e75c14b53113cd066c806fb6c7d33a45	American Express	31.8485944743562506	-106.488025455873469
19922	2020-04-14 17:04:16	2020-04-14	Vernal Ruecker	vernal.ruecker@geemail.com	North Las Vegas	Nevada	3784256968403417	68aca222f563f4972e758323a35c1cbd	JCB 16 digit	36.3155794375732555	-115.067924736508729
19923	2020-04-14 17:13:26	2020-04-14	Arie Cremin	arie.cremin@geemail.com	North Charleston	South Carolina	53039055711090679	0be245e43a309c749539e3b32a2279b0	Mastercard	32.9164532720271481	-80.1212817113008384
19924	2020-04-14 17:18:55	2020-04-14	Polk Conn	polk.conn@woohoo.com	New York	New York	3337898499730399416	c06736a40ae106d26a6ae281c6ec96cc	VISA 16 digit	40.5902073384020454	-73.9659852689493391
19925	2020-04-14 17:24:58	2020-04-14	Ricky Hermiston	ricky.hermiston@geemail.com	San Francisco	California	4446050325879788	954f901384c82b7b700f7e23580d9a86	JCB 16 digit	37.7594758646472712	-122.454114354713184
19926	2020-04-14 17:34:22	2020-04-14	Oddie Cruickshank	oddie.cruickshank@geemail.com	New York	New York	3710056068539691	b1b34d9b55d780f33b71d28dbcfda564	Discover	40.6565911006405969	-73.9612792319979491
19927	2020-04-14 17:44:11	2020-04-14	Dr. Bailey Heidenreich PhD	dr.bailey.heidenreich.phd@geemail.com	Allen	Texas	52202733489913865	7b43929e66ae334d2c1b73b2798d5fbb	JCB 15 digit	33.0174340828813584	-96.6758124387305173
19928	2020-04-14 18:10:59	2020-04-14	Henderson Kautzer	henderson.kautzer@geemail.com	Peoria	Illinois	3023417032336110	67bd40f710b67300ea7ec5fe4d8ff6e6	Discover	40.6939092029221356	-89.6813431623276358
19929	2020-04-14 18:37:45	2020-04-14	Mr. Aurelio Abernathy DDS	mr.aurelio.abernathy.dds@geemail.com	McKinney	Texas	4262140159189957	2a7d969b7804a090388a5ae1cca3b744	Voyager	33.1487952809445616	-96.7362044761721052
19930	2020-04-14 18:38:51	2020-04-14	Ollie Pacocha	ollie.pacocha@warmmail.com	Oakland	California	502009814447570	159ba9280044310c0496f31fa72e0e9f	Diners Club / Carte Blanche	37.8453345481960142	-122.258426526052475
19931	2020-04-14 19:13:05	2020-04-14	Porsche O'Hara PhD	porsche.o'hara.phd@geemail.com	Oakland	California	4339234990686591	5d04f5f026c4a41db9575ebffd0e51fc	Diners Club / Carte Blanche	37.8047753433592817	-122.263181003180861
19932	2020-04-14 19:15:06	2020-04-14	Lorayne Lebsack	lorayne.lebsack@geemail.com	Laredo	Texas	4700121616702194	d78b61340c9c2a7246e2cadc6f183301	VISA 16 digit	27.607486067544297	-99.5439540223691637
19933	2020-04-14 19:18:30	2020-04-14	Kamari Steuber	kamari.steuber@geemail.com	Wilmington	North Carolina	3158972005680178616	1b855bb04423f4abc9fb1408008eea59	VISA 16 digit	34.1938037847455618	-77.8178349147077739
19934	2020-04-14 19:20:33	2020-04-14	Mr. Nolen Botsford PhD	mr.nolen.botsford.phd@woohoo.com	Washington	District of Columbia	6011700147394307955	b8cb2bc16d87c7e46323b41f3ccd59c8	Mastercard	38.9510111063051951	-76.9873457262970504
19935	2020-04-14 19:37:54	2020-04-14	Kael Howell	kael.howell@geemail.com	Westminster	Colorado	3012138088195884	14288fb8e320776984dcb69178f5971b	VISA 16 digit	39.8291968818593745	-105.156990331751857
19936	2020-04-14 20:20:45	2020-04-14	Omer Schoen	omer.schoen@geemail.com	Austin	Texas	3088384441013344462	0fc914b359214c87e22f75d36676724a	Mastercard	30.3398353430569152	-97.7436669690772959
19937	2020-04-14 20:22:55	2020-04-14	Laurene Corwin-Johns	laurene.corwin.johns@woohoo.com	Plano	Texas	4590644545220	de0374d708788f59dea8af9f7dbf1ebe	Discover	32.9984973802782591	-96.6721663408163892
19938	2020-04-14 20:24:36	2020-04-14	Quinten Ferry III	quinten.ferry.iii@woohoo.com	San Francisco	California	3053523827783182	88d76c325b1df5b6eeed37ef554a718f	Discover	37.7807934610807195	-122.449582956261338
19939	2020-04-14 20:31:12	2020-04-14	Kianna Kertzmann	kianna.kertzmann@geemail.com	Rialto	California	4525097654846775	ad4906af870b83f1a86fe7afa573d38f	Mastercard	34.0421551934193829	-117.377242568097259
19940	2020-04-14 20:50:28	2020-04-14	Judd Orn	judd.orn@geemail.com	Memphis	Tennessee	3421080818076959	11ceb0ee1dde3add6175fd19f88535d2	VISA 16 digit	35.1805509527280975	-90.0095058496367244
19941	2020-04-14 20:52:43	2020-04-14	Markell Durgan IV	markell.durgan.iv@geemail.com	Newport News	Virginia	3749550704713087	054a3addc664f6e60a1e0fb657d410fc	American Express	37.1161822037201361	-76.5848612608183288
19942	2020-04-14 20:53:38	2020-04-14	Derick Corwin	derick.corwin@geemail.com	Lowell	Massachusetts	4058316323359	424e610c5e72288866749dc77011469b	Maestro	42.6740045863539024	-71.3008817680053397
19943	2020-04-14 21:14:40	2020-04-14	Shaunna Kris-Ritchie	shaunna.kris.ritchie@warmmail.com	Ventura	California	3055458592424829	e405cc1cc77613835e2d3c6a8e1c8b70	American Express	34.1942261405449344	-119.156871818342054
19944	2020-04-14 21:21:13	2020-04-14	Leaner Ledner	leaner.ledner@woohoo.com	Phoenix	Arizona	6011876056670426934	94e0e4a384f1cd95ff1e6a9de8635651	Diners Club / Carte Blanche	33.4776555494803958	-112.160160635451234
19945	2020-04-14 21:24:02	2020-04-14	Dominique Tremblay-Bechtelar	dominique.tremblay.bechtelar@geemail.com	Wichita	Kansas	3453737782020849	64293cdc35d6f923fd11b2c4ce41b4de	Voyager	37.723770944016799	-97.4118843375440662
19946	2020-04-14 21:24:25	2020-04-14	Dr. French Champlin	dr.french.champlin@geemail.com	Kenosha	Wisconsin	869991127210773595	afcab45722134efa61ddf1a54e7fc4f7	American Express	42.5003425456423329	-87.8061111924000102
19947	2020-04-14 21:25:07	2020-04-14	Colvin Fay Jr.	colvin.fay.jr.@geemail.com	Raleigh	North Carolina	4251697300875704	f96a18582f09b30368f004d3c96e486f	VISA 16 digit	35.8228272299416304	-78.7335470469139551
19948	2020-04-14 21:53:57	2020-04-14	Mr. Huy Abbott Sr.	mr.huy.abbott.sr.@geemail.com	Berkeley	California	3734136526456977	1cd676b4fb5952371eba61e0c11feb06	American Express	37.8821845463583671	-122.255351477194395
19949	2020-04-14 21:54:42	2020-04-14	Bobby Hartmann	bobby.hartmann@geemail.com	Des Moines	Iowa	3770407944222092	52fc36985165ec2c0b0b97751c3dcb6a	American Express	41.4983160616572988	-93.5499482263855668
19950	2020-04-14 21:58:54	2020-04-14	Romeo Senger	romeo.senger@geemail.com	San Antonio	Texas	3002369990066299	c6348d95b9dc5ecc681910d4fabbe126	VISA 16 digit	29.5099322772189971	-98.5333411344628729
19951	2020-04-14 22:14:40	2020-04-14	Mandi Konopelski	mandi.konopelski@woohoo.com	Virginia Beach	Virginia	4414629535223339	4a1675420cff27ca8afaa1797dd4eaef	American Express	36.7829249277897219	-75.9353458224002225
19952	2020-04-14 22:30:31	2020-04-14	Deneen Lesch	deneen.lesch@geemail.com	Modesto	California	869961095272394442	4030ddf88b0d85f409fffa665d4fb79f	JCB 16 digit	37.5745587111916421	-121.003751928100357
19953	2020-04-14 22:36:25	2020-04-14	Mckenzie Moen	mckenzie.moen@geemail.com	Broken Arrow	Oklahoma	55662588731979137	555769e7ba9751fec4833f5a92420808	JCB 16 digit	35.9665729578826543	-95.7337681978419539
19954	2020-04-14 22:53:26	2020-04-14	Dr. Winthrop Kris	dr.winthrop.kris@geemail.com	San Francisco	California	869994624253380822	e39cb4118af4dccea7858d0969d28a77	JCB 16 digit	37.7636346982304119	-122.438250504328408
19955	2020-04-14 23:01:18	2020-04-14	Kailyn Cronin DVM	kailyn.cronin.dvm@warmmail.com	Topeka	Kansas	3047318770865631	644170b2bcfad1e354e98a9151869987	JCB 16 digit	39.0650641623817378	-95.6462670199748146
19956	2020-04-14 23:11:19	2020-04-14	Barnie Effertz	barnie.effertz@woohoo.com	Denton	Texas	3337635734350822976	73e8bc8df37f522a981bc524ce1a8780	VISA 16 digit	33.2518234506513934	-97.0946621000893515
19957	2020-04-14 23:19:56	2020-04-14	Dr. Kory Rutherford III	dr.kory.rutherford.iii@geemail.com	San Francisco	California	3737180302280141	57acdaa1839b2fc931822c4eaf888b5e	American Express	37.7880853819922677	-122.416751089719526
19958	2020-04-14 23:22:06	2020-04-14	Bruce Runolfsdottir	bruce.runolfsdottir@woohoo.com	Des Moines	Iowa	3337004522914453492	84ebe84b7a601e68f41d5a01d719a849	VISA 13 digit	41.6229584006801261	-93.525550795630366
19959	2020-04-14 23:24:37	2020-04-14	Sebastian Cormier	sebastian.cormier@geemail.com	Minneapolis	Minnesota	869943797912437928	702c1340c6039dba807f17ca1457dc45	Discover	44.8872806346595254	-93.2732304827116394
19960	2020-04-14 23:31:20	2020-04-14	Janie Kulas	janie.kulas@geemail.com	San Francisco	California	180085316762096657	fea9ab5013c7d91771223e7ed804f282	VISA 16 digit	37.7651303992286884	-122.416479657722249
19961	2020-04-14 23:57:34	2020-04-14	Miss Missouri Reynolds DVM	miss.missouri.reynolds.dvm@geemail.com	Knoxville	Tennessee	4571233061903429	6bcb6f7ee6fd3964d18bda1303a8ba82	JCB 16 digit	35.9650022754508996	-84.0382547931030359
19962	2020-04-15 00:24:15	2020-04-15	Mrs. Jonnie Weber MD	mrs.jonnie.weber.md@geemail.com	Los Angeles	California	180021464304524138	c9a70212770559794762e29a1db5ac58	JCB 16 digit	34.0685650572512273	-118.359820808190108
19963	2020-04-15 00:39:24	2020-04-15	Ira Littel-Volkman	ira.littel.volkman@geemail.com	Chicago	Illinois	869969820125364926	b1b31d119775e1edf3b355f2569da97b	Voyager	41.7504988223616067	-87.609472701142721
19964	2020-04-15 00:41:34	2020-04-15	Albertus Wehner	albertus.wehner@geemail.com	Cincinnati	Ohio	4816747415833	ae7a10684e120c3d9ef61b6e3d1031b8	JCB 16 digit	39.1517967954974608	-84.5734278644241328
19965	2020-04-15 00:49:57	2020-04-15	Kirstin Bernhard	kirstin.bernhard@geemail.com	Little Rock	Arkansas	869997719406347103	6e3f12abeb5f1e4378524792ef967e48	Diners Club / Carte Blanche	34.6368165571052558	-92.4222546676978425
19966	2020-04-15 00:53:07	2020-04-15	Junia Rosenbaum-Rutherford	junia.rosenbaum.rutherford@geemail.com	Dayton	Ohio	210006708505141616	7ae85f4405fd1b89d66db3c349d232c1	Maestro	39.8684131520591691	-84.279385384330908
19967	2020-04-15 00:54:51	2020-04-15	Jaylynn McCullough	jaylynn.mccullough@geemail.com	Los Angeles	California	3112923526366559977	8d241bad6b57d1c6c6b55eae05d34374	VISA 13 digit	34.020462893681227	-118.456692938273022
19968	2020-04-15 00:55:11	2020-04-15	Gaye Konopelski-Kertzmann	gaye.konopelski.kertzmann@warmmail.com	Baltimore	Maryland	3035265763503368	1de6dd9b98af39dfc643f0271072d33c	VISA 13 digit	39.2001205150503651	-76.6995133093111292
19969	2020-04-15 01:00:37	2020-04-15	Elbridge Sanford	elbridge.sanford@woohoo.com	San Francisco	California	51314687777584702	de51201074bd47168f288f91a02eb805	Voyager	37.7839942854330815	-122.422538878367931
19970	2020-04-15 01:05:55	2020-04-15	Dr. Eduardo Mayer	dr.eduardo.mayer@geemail.com	New York	New York	869955469002953744	5aead5505321c191bfd69b8da19bed77	Voyager	40.623891723690555	-73.9258524549089344
19971	2020-04-15 01:07:16	2020-04-15	Raelynn Morar	raelynn.morar@geemail.com	New York	New York	3528241759381978022	2ab94441a4a99e5c50db1046b5db286b	American Express	40.7570743604786685	-73.9798004836205365
19972	2020-04-15 01:09:14	2020-04-15	Charolette Powlowski-Macejkovic	charolette.powlowski.macejkovic@geemail.com	Denver	Colorado	676337578812325	ce50fe93a26f69dd48bb395576e1f4e5	VISA 16 digit	39.826223337003583	-104.841240186641372
19973	2020-04-15 01:18:45	2020-04-15	Reilly Cartwright	reilly.cartwright@geemail.com	Tallahassee	Florida	3112835309585139153	b777c74e343a91844494a692cdf3240e	VISA 16 digit	30.5049209695331776	-84.3493863709285847
19974	2020-04-15 01:27:03	2020-04-15	Ronnie Bechtelar	ronnie.bechtelar@geemail.com	Oakland	California	180024409397139812	3e95f2cc38855a0414cedc1b8f6642b0	Maestro	37.8112450921465708	-122.292121201190724
19975	2020-04-15 01:30:12	2020-04-15	Keenan Towne	keenan.towne@warmmail.com	Houston	Texas	4964478645558927	f266f6fe002cc0adb00457cf23cb9e6b	JCB 15 digit	29.8805116094727055	-95.4858490765109735
19976	2020-04-15 01:42:48	2020-04-15	Kamilah Kuphal	kamilah.kuphal@geemail.com	San Francisco	California	676242714741305	3f70d71a7c8cf8e9abfc720801fedc7b	VISA 16 digit	37.799991744659529	-122.432644539008521
19977	2020-04-15 01:45:51	2020-04-15	Donovan Hoeger	donovan.hoeger@geemail.com	Saint Paul	Minnesota	4747603330392571	9b14a0f131a7459c3721c27f97a92d9e	VISA 16 digit	44.8815673902571248	-93.1507111796442473
19978	2020-04-15 01:53:14	2020-04-15	Silas Gusikowski	silas.gusikowski@warmmail.com	Los Angeles	California	55879464391471238	acc36dbdaa8328d9434de36b0f7efa46	Maestro	34.0075680937018205	-118.456993849574772
19979	2020-04-15 01:54:49	2020-04-15	Mohammad Boyle IV	mohammad.boyle.iv@geemail.com	Roseville	California	3112019495409589166	2dd6c45d34be0c5ebc1d5a63862d1536	VISA 16 digit	38.7150404820740235	-121.282009211064874
19980	2020-04-15 01:55:30	2020-04-15	Miss Anika Schneider MD	miss.anika.schneider.md@warmmail.com	New York	New York	501887227810352	c1cf428537c516b5dee7555c6bb61be1	Maestro	40.7540184567440278	-73.9908570883225565
19981	2020-04-15 01:57:56	2020-04-15	Ms. Delphine White	ms.delphine.white@geemail.com	Los Angeles	California	6011725378554063796	47ae7b53a04223c50f2bcd528545bc99	VISA 16 digit	33.955774005768447	-118.367027018823848
19982	2020-04-15 02:00:59	2020-04-15	Mack Spencer	mack.spencer@geemail.com	El Paso	Texas	6011410723342664621	ed52335d29d4a8ef881cb0a62debfb10	JCB 16 digit	31.8114973414517941	-106.478330375904221
19983	2020-04-15 02:08:38	2020-04-15	Dr. Konner Spinka DDS	dr.konner.spinka.dds@geemail.com	Simi Valley	California	3471662297068729	eb5ecc59ed817614f6c22222396db5cb	VISA 16 digit	34.1922368161618735	-118.736556858535863
19984	2020-04-15 02:20:56	2020-04-15	Haven Armstrong	haven.armstrong@geemail.com	Worcester	Massachusetts	3528362697281443007	79a9b05796c0c274614e6e4cf15c8972	Discover	42.3275353961326175	-71.8454905821263736
19985	2020-04-15 02:21:56	2020-04-15	Verlin Feil-Bradtke	verlin.feil.bradtke@woohoo.com	Oakland	California	3528408060049532429	0404fb9420f6ad5c5f459608e9d830e1	Voyager	37.769317485555959	-122.27747853043563
19986	2020-04-15 02:30:41	2020-04-15	Ricky Wiza MD	ricky.wiza.md@geemail.com	Fort Lauderdale	Florida	869950522224158073	ef6d1da3760ae1623dbc6b68ed361585	VISA 16 digit	26.2182275860093554	-80.1498361557077601
19987	2020-04-15 02:37:27	2020-04-15	Racheal Huel	racheal.huel@warmmail.com	League City	Texas	4510287850973609	8de3f0b1a901cf0f063d38172984a3de	JCB 16 digit	29.5208618500664848	-95.0382949055623243
19988	2020-04-15 02:48:14	2020-04-15	Cordelia Kub-Maggio	cordelia.kub.maggio@geemail.com	Omaha	Nebraska	676324212060271	07468c79c17482ebccb97e3b2d5c9cd4	JCB 16 digit	41.1855518755648333	-95.9846526762120504
19989	2020-04-15 03:04:10	2020-04-15	Julius Waters DVM	julius.waters.dvm@geemail.com	Coral Springs	Florida	4703668717043305	1293031b3bd5e4b01e81b18313176078	Mastercard	26.1986459617566325	-80.303927397134899
19990	2020-04-15 03:28:02	2020-04-15	Dr. Ryley Kutch PhD	dr.ryley.kutch.phd@geemail.com	Modesto	California	3054886071974016	11cefc35930f042a28629d4873efbc68	Diners Club / Carte Blanche	37.682714459998536	-120.983588000640268
19991	2020-04-15 04:05:24	2020-04-15	Maleah White	maleah.white@geemail.com	San Francisco	California	210052579850272147	4b3b6701fcc7d6a0bd0e8920856e32cc	JCB 15 digit	37.7940716540610993	-122.412130078404161
19992	2020-04-15 04:27:41	2020-04-15	Lolla Sipes-Stehr	lolla.sipes.stehr@woohoo.com	Portland	Oregon	3059295199382075	63aa9c77a96b367d5e6e27de986aae06	Voyager	45.6288881407938902	-122.658700446225708
19993	2020-04-15 04:29:33	2020-04-15	Karlee Quitzon	karlee.quitzon@geemail.com	Boston	Massachusetts	4485206270389064	b1d06838f9cf62f7c43b7053e0226018	JCB 15 digit	42.3202237342186294	-70.9928315776817556
19994	2020-04-15 04:31:34	2020-04-15	Dr. Ramona Kihn DDS	dr.ramona.kihn.dds@geemail.com	San Antonio	Texas	180085867287684278	95153789cf57ca6d2a3376088ba97ab7	Voyager	29.4696409290261556	-98.6115572631660768
19995	2020-04-15 04:31:53	2020-04-15	Damond Bartell	damond.bartell@geemail.com	Richmond	Virginia	6011065221254211869	9212f93fb37af6ac195c20b43af97015	Voyager	37.591716427238282	-77.5653804848659831
19996	2020-04-15 04:34:27	2020-04-15	Clark Prohaska-Ernser	clark.prohaska.ernser@geemail.com	Fort Worth	Texas	3528551624341452019	d621f997216a151d9d319e87930f2a95	Mastercard	32.8055250033792092	-97.4335211843539071
19997	2020-04-15 04:38:07	2020-04-15	Kassie Bayer	kassie.bayer@geemail.com	North Las Vegas	Nevada	3058646200320440	b6ccf3191011afe793d188fba8b55312	JCB 15 digit	36.2395789665792094	-115.007848279200132
19998	2020-04-15 04:39:29	2020-04-15	Sherron Hoeger	sherron.hoeger@woohoo.com	Allen	Texas	3158982907265825701	255a25d3be9c2a96674b36f9a065011a	JCB 16 digit	33.0369569478582576	-96.74332287553176
19999	2020-04-15 04:45:22	2020-04-15	Olie Rogahn-Johnson	olie.rogahn.johnson@geemail.com	Port St. Lucie	Florida	3112455527460768031	4af51d48c9a5f3ffa1a0031fe5a72de5	American Express	27.2421840113256124	-80.4382219805002165
20000	2020-04-15 04:48:05	2020-04-15	Casimir Wolf-Von	casimir.wolf.von@warmmail.com	Mesa	Arizona	3724497523702454	4186dba32a14ebaa4caeb81954815e2a	JCB 16 digit	33.4567052143305546	-111.727947763900829
20001	2020-04-15 04:54:41	2020-04-15	Eda Murazik MD	eda.murazik.md@woohoo.com	Hialeah	Florida	6011366304884900725	f7806dc145c990dcecc1c90ddd79aa38	VISA 16 digit	25.8371023853752781	-80.3086908051647157
20002	2020-04-15 05:03:22	2020-04-15	Neha Littel	neha.littel@warmmail.com	Lafayette	Louisiana	3337667411520393037	df9a48e2346119e05290ab968dac6976	JCB 15 digit	30.2643292683154357	-92.0396704434268145
20003	2020-04-15 05:11:07	2020-04-15	Clydie Kshlerin	clydie.kshlerin@geemail.com	Las Vegas	Nevada	3440996287860010	8bc5305e6b63a04c9ae1e1068e7d8f98	JCB 16 digit	36.2353438128352181	-115.357280168470368
20004	2020-04-15 05:13:08	2020-04-15	Dr. Carole Kassulke DVM	dr.carole.kassulke.dvm@geemail.com	Houston	Texas	3088735222407196981	3f53b00bcf58d20c7ca2ce26af6af915	JCB 16 digit	29.7920721665568635	-95.4369918928496617
20005	2020-04-15 05:14:52	2020-04-15	Dr. Marlie Osinski DVM	dr.marlie.osinski.dvm@geemail.com	Providence	Rhode Island	4193848064496663	1c8eacf4eb070bbbcce0be58315be3f1	Discover	41.8096377404727022	-71.3761533825576322
20006	2020-04-15 05:18:26	2020-04-15	Kaitlynn Schamberger	kaitlynn.schamberger@geemail.com	Ontario	California	4769135577510915	a025ed5af84befbad2a3faa1d0654597	Voyager	34.0072158178925505	-117.687363228165367
20007	2020-04-15 05:24:44	2020-04-15	Lexie Cruickshank-Schuster	lexie.cruickshank.schuster@geemail.com	Clovis	California	6011845887276576716	70841e4d7ada57edb97d1dd3dfab1af3	VISA 13 digit	36.8991274168126324	-119.643971235498412
20008	2020-04-15 05:41:33	2020-04-15	Gracia Koch	gracia.koch@warmmail.com	Glendale	California	210021552442790981	b784715f6a00cf50bead2c946d1a23ae	Mastercard	34.1850875261925111	-118.341871262517941
20009	2020-04-15 05:44:16	2020-04-15	Roswell Casper	roswell.casper@woohoo.com	San Francisco	California	3403061212659006	dbb1a190a615cbad4c4434b94e3fb1a9	JCB 15 digit	37.7644694698963477	-122.448869015489478
20010	2020-04-15 05:51:55	2020-04-15	Odalys Klocko	odalys.klocko@geemail.com	Denver	Colorado	4371694983073843	e2d22af6a2e703b0c0ca64e9382ae66a	VISA 16 digit	39.711011162638286	-104.891165711010245
20011	2020-04-15 05:59:56	2020-04-15	Izabella Nienow	izabella.nienow@geemail.com	Houston	Texas	3424725667142578	7bea9a3bdcf1e82edab0586fdc491f54	Mastercard	29.7837248138230279	-95.2978710796233344
20012	2020-04-15 06:29:04	2020-04-15	Latrell Connelly IV	latrell.connelly.iv@warmmail.com	Pomona	California	3112403035227059986	65e2282a6f94afb8e6626be4588278ce	JCB 16 digit	34.1353621573690376	-117.794808259463309
20013	2020-04-15 06:36:27	2020-04-15	Mrs. Venessa Altenwerth MD	mrs.venessa.altenwerth.md@geemail.com	Moreno Valley	California	3096164046885245683	5dae743e3bb346c2ef0ca88f6daddd1e	JCB 15 digit	33.9824925147920851	-117.205203191933023
20014	2020-04-15 06:45:17	2020-04-15	Enzo Miller-Klein	enzo.miller.klein@geemail.com	Fresno	California	3528203749185239024	79c73fc8105014819f6231928d86e85a	Diners Club / Carte Blanche	36.8084353586066513	-119.844630740593757
20015	2020-04-15 07:05:38	2020-04-15	Winnie Dooley	winnie.dooley@warmmail.com	Detroit	Michigan	4115428159171748	1601450bd0a0db2d3cd9e645c4873d42	Diners Club / Carte Blanche	42.479695378329609	-83.1884477097660238
20016	2020-04-15 07:08:12	2020-04-15	Mr. Corey Funk	mr.corey.funk@warmmail.com	Irvine	California	4626024316268923	ea9b2e295136e12a7005f42d9107b2fa	Voyager	33.6288104714840657	-117.856680203695959
20017	2020-04-15 07:12:46	2020-04-15	Glen Bechtelar Sr.	glen.bechtelar.sr.@geemail.com	New York	New York	4647742009507	e2db6714f67739b48b3966e9b0b99259	Mastercard	40.6747018013838684	-74.0130423317093431
20018	2020-04-15 07:16:32	2020-04-15	Alina Ortiz	alina.ortiz@warmmail.com	Charlotte	North Carolina	3088269898529995311	94abae06c020d11379f5aea7c92c4625	Voyager	35.2608875228345369	-80.7334786879774242
20019	2020-04-15 07:24:42	2020-04-15	Mrs. London Moore PhD	mrs.london.moore.phd@geemail.com	Greensboro	North Carolina	54900708482917126	64a9d5197544e9e057db20baa99c5d26	Maestro	36.0546315726473949	-79.8332801524996682
20020	2020-04-15 07:26:45	2020-04-15	Anner Nitzsche	anner.nitzsche@warmmail.com	San Francisco	California	589360395751112	1b6a157ed2692dbf397c655dc67cae13	VISA 16 digit	37.7714105196513685	-122.41951982342394
20021	2020-04-15 07:33:34	2020-04-15	Stevie Olson	stevie.olson@geemail.com	San Francisco	California	501838426895926	1aaa4c59f678ea948f27a9448a6326b4	JCB 16 digit	37.8000288977301793	-122.423633788822741
20022	2020-04-15 08:21:53	2020-04-15	Glen Davis Jr.	glen.davis.jr.@geemail.com	Chattanooga	Tennessee	3088607845514126072	080e4aaeb94d2336b5bff5c05a924822	Mastercard	35.1609792463332411	-85.218807001581041
20023	2020-04-15 08:45:04	2020-04-15	Myra Harvey	myra.harvey@geemail.com	San Francisco	California	3158760873061873436	60a4d6f59c0297616fca756cc5e9710d	Mastercard	37.7978311441932888	-122.4108330927114
20024	2020-04-15 09:21:01	2020-04-15	Lulie Lemke	lulie.lemke@geemail.com	San Francisco	California	4160329554434786	8f55c650f14adf0a7f2f84fffa3a2f31	American Express	37.7892562614068552	-122.434785093402795
20025	2020-04-15 09:30:24	2020-04-15	Robbie Moen	robbie.moen@geemail.com	Atlanta	Georgia	4502430327700078	03f1a02ae50d09240219c344d2a21e8b	JCB 16 digit	33.6709383866559762	-84.3401449610523883
20026	2020-04-15 09:35:25	2020-04-15	Dr. Erica Boehm DVM	dr.erica.boehm.dvm@warmmail.com	Houston	Texas	3056124188209722	8521d8804c9075edcd66bad8f0baef95	Diners Club / Carte Blanche	29.7856861500613377	-95.4151597837932428
20027	2020-04-15 10:05:40	2020-04-15	Heber Frami	heber.frami@geemail.com	Roseville	California	4678568986130	b74d9221e228cdd4dd95d30e015ccbd5	Diners Club / Carte Blanche	38.7129156666398018	-121.408120137521621
20028	2020-04-15 10:05:42	2020-04-15	Brionna Rohan MD	brionna.rohan.md@warmmail.com	San Francisco	California	501843279913693	07cd6154d1000b89b773c49482d2ed49	JCB 16 digit	37.7805002715406886	-122.456792523331586
20029	2020-04-15 10:21:55	2020-04-15	Clytie Douglas	clytie.douglas@geemail.com	Modesto	California	3528404290544387623	9419d9a827a47d5a6cf5e8a02103b04b	Mastercard	37.6638830732554197	-120.918536769758916
20030	2020-04-15 10:24:14	2020-04-15	Blake O'Conner	blake.o'conner@geemail.com	Los Angeles	California	52979369508936933	f973c41010e57fdc871002418ff687f8	Maestro	34.0900510686781217	-118.467996043338616
20031	2020-04-15 10:40:08	2020-04-15	Ruthie Sauer	ruthie.sauer@geemail.com	Minneapolis	Minnesota	4283736305815935	aaaeb84637720a084dde0fffca3997f8	VISA 13 digit	45.0593890735033895	-93.3231494562506612
20032	2020-04-15 10:43:00	2020-04-15	Mr. Amerigo Brekke II	mr.amerigo.brekke.ii@geemail.com	Clinton	Michigan	6011522013719302673	55fd16e32608cbbc7bf7896a04f7a44c	JCB 16 digit	42.6314194363608934	-82.981219367690386
20033	2020-04-15 10:48:28	2020-04-15	Cheyanne Huel	cheyanne.huel@warmmail.com	Charlotte	North Carolina	3158370971603755319	4618a9b3345aeb3cdd412509012394c2	JCB 15 digit	35.192344814890248	-80.7985741501618264
20034	2020-04-15 11:04:09	2020-04-15	Delmus Hodkiewicz	delmus.hodkiewicz@geemail.com	Aurora	Colorado	869960915582186298	a457b17095aa0aba3712ea3243918ebd	VISA 16 digit	39.741048868291081	-104.78487329069786
20035	2020-04-15 11:10:21	2020-04-15	Tangela Cummings	tangela.cummings@warmmail.com	Santa Rosa	California	869958613605760702	d5271f54a2c83371e7f52c99d3d58b3b	Mastercard	38.3831283838145438	-122.730599624688182
20036	2020-04-15 11:10:21	2020-04-15	Harve Koelpin	harve.koelpin@geemail.com	Nashville	Tennessee	3748426499358902	1f92e501d0c88c5ebb09d163d3a98642	VISA 13 digit	36.1562813114497814	-86.8395747034251713
20037	2020-04-15 11:19:27	2020-04-15	Ottie Nitzsche MD	ottie.nitzsche.md@woohoo.com	Houston	Texas	4802993687133310	4f5960f2c802bc225d335d752ed045ee	JCB 16 digit	29.8199524894434944	-95.4557586584720781
20038	2020-04-15 11:45:16	2020-04-15	Bertina Kautzer-Ryan	bertina.kautzer.ryan@geemail.com	Gilbert	Arizona	180039689349213251	13e465f952f09e59100a07830e6c9351	VISA 13 digit	33.3062425012581045	-111.816244997563217
20039	2020-04-15 11:54:12	2020-04-15	Jase Dare-Orn	jase.dare.orn@geemail.com	San Francisco	California	3158869234930928846	3c778bbe6a60d4ea67e6989fbfcb5416	Diners Club / Carte Blanche	37.742098639583908	-122.425083869780394
20040	2020-04-15 11:58:48	2020-04-15	Lute Beier	lute.beier@geemail.com	San Francisco	California	869998640259929129	157e1b425c317bc30ee4fa295fefc771	VISA 16 digit	37.7727461090717185	-122.436998057055419
20041	2020-04-15 12:20:00	2020-04-15	Infant Will	infant.will@geemail.com	Grand Rapids	Michigan	53830582890131553	b2d618af5b744faa14732f0c83a5eb50	VISA 13 digit	42.9878272991895685	-85.6170623420406258
20042	2020-04-15 12:36:03	2020-04-15	Daxton Auer	daxton.auer@geemail.com	Victorville	California	3528126210378853554	890854af774b6115920b8e049a5ff580	Maestro	34.5662612118523569	-117.393099219879502
20043	2020-04-15 12:41:33	2020-04-15	Dr. Donat Sanford	dr.donat.sanford@geemail.com	Honolulu	Hawaii	3052350069045885	d19fbe65e9bcd042bf5a7c269d6f296f	JCB 16 digit	21.3362184046983714	-157.884723865634214
20044	2020-04-15 12:53:09	2020-04-15	Gus Barton	gus.barton@woohoo.com	Gresham	Oregon	3470198235009872	d22ac1bcfb865ecfea18ed196b7f967d	Mastercard	45.4587346399623868	-122.419752294550079
20045	2020-04-15 12:59:11	2020-04-15	Moises Bauch	moises.bauch@geemail.com	Chicago	Illinois	4095556747460779	f508f97265d7d10e0ea98f3ea2ea6e17	JCB 16 digit	41.8204767335508052	-87.6709730329953061
20046	2020-04-15 13:21:08	2020-04-15	Lissa Sporer PhD	lissa.sporer.phd@geemail.com	Sacramento	California	4089508473257463	c4a727664bcd8e72db238ffa5f66a2b9	VISA 13 digit	38.579941268943621	-121.475660100929801
20047	2020-04-15 13:23:56	2020-04-15	Odie Schneider	odie.schneider@warmmail.com	San Francisco	California	4864765839054	4e66809b6542a2cf2d0adb62441f21dd	Voyager	37.7800415702165537	-122.464373379813168
20048	2020-04-15 13:27:47	2020-04-15	Spurgeon Berge PhD	spurgeon.berge.phd@warmmail.com	Cape Coral	Florida	630491349307552	2c9a541168ab17932f3858e2515340e7	VISA 13 digit	26.7192195298120367	-82.0873303422775109
20049	2020-04-15 13:30:49	2020-04-15	Abb Treutel II	abb.treutel.ii@geemail.com	Beaumont	Texas	3096574603131168970	274dd33215e3b46d24b68b565bae8575	Diners Club / Carte Blanche	30.0573429306574162	-94.1240018022965756
20050	2020-04-15 13:33:12	2020-04-15	Sariah Mann-Vandervort	sariah.mann.vandervort@warmmail.com	Los Angeles	California	6011141595772366737	21580f9c3b32a97dc200d5d422b0da14	JCB 16 digit	34.0864639385003585	-118.441429755556584
20051	2020-04-15 13:40:11	2020-04-15	Noemie Langworth	noemie.langworth@warmmail.com	Paterson	New Jersey	6011584643827782641	e66cad3f42a4ef607f5a42f76b456294	VISA 16 digit	40.8646321156017507	-74.0958661552958233
20052	2020-04-15 13:41:18	2020-04-15	Effie Harber DDS	effie.harber.dds@geemail.com	Detroit	Michigan	4298908859556	81760550325bea73ccb30be488a1c311	American Express	42.4655407061725896	-83.1202189052596623
20053	2020-04-15 13:55:08	2020-04-15	Hart Feeney	hart.feeney@warmmail.com	Los Angeles	California	3337720190921664130	8b7ad9ba4868fb9dadd4527bf0b7a95e	JCB 15 digit	34.096834640564019	-118.505817833355806
20054	2020-04-15 14:06:51	2020-04-15	Mrs. Taina Kunde	mrs.taina.kunde@geemail.com	New York	New York	180038112038183082	cfaf4f895f12376e2c1076fd663dd080	VISA 16 digit	40.7161577565819002	-74.0329607498262021
20055	2020-04-15 14:13:35	2020-04-15	Gaylene Block	gaylene.block@warmmail.com	Indianapolis	Indiana	4776204453687	2f3421c1455b31a09f4f2b2880bb2568	VISA 16 digit	39.813684867649151	-86.2409677332468334
20056	2020-04-15 14:18:40	2020-04-15	Mr. Harvey Konopelski	mr.harvey.konopelski@geemail.com	San Antonio	Texas	51636529821317112	b4cca74e05c2abfaa608418e5ba1a936	JCB 16 digit	29.4950299926638593	-98.5488446872051753
20057	2020-04-15 14:21:38	2020-04-15	Starling Wyman	starling.wyman@geemail.com	Syracuse	New York	4606766539229	5160ed25f986a37da1b395df7bd75013	Maestro	43.0347101712450382	-76.070305943979335
20058	2020-04-15 14:28:18	2020-04-15	Jailyn Beatty	jailyn.beatty@geemail.com	San Francisco	California	6011298258826537206	a94102373225787f99641c17e0d59144	VISA 16 digit	37.7496849467508113	-122.46293352109096
20059	2020-04-15 14:30:06	2020-04-15	Dr. Merlin Hammes IV	dr.merlin.hammes.iv@geemail.com	Virginia Beach	Virginia	6011332956116267206	564786badbabc2f61064c0987b431f1d	Maestro	36.6934654055815201	-75.9926944792408534
20060	2020-04-15 14:38:27	2020-04-15	Rian Funk PhD	rian.funk.phd@geemail.com	Berkeley	California	3337357110949538926	a0de4e8c3fcbd3aff859952b46b94ac6	American Express	37.8660518313686509	-122.266085407398833
20061	2020-04-15 14:43:18	2020-04-15	Kristyn Stamm	kristyn.stamm@geemail.com	Odessa	Texas	4003695547872923	f69ca86951376984c8e1b93317d38e96	VISA 13 digit	31.8650369865830996	-102.413351373575992
20062	2020-04-15 14:52:38	2020-04-15	Mrs. Alesha Wiza PhD	mrs.alesha.wiza.phd@geemail.com	Washington	District of Columbia	3337913999510903197	d1d70fe52985a373be037a7f787084f0	VISA 16 digit	38.8471926909670202	-76.9569725797723976
20063	2020-04-15 15:08:32	2020-04-15	Estel Ledner	estel.ledner@geemail.com	Milwaukee	Wisconsin	4660075099755	ed16b3349113110160a5c038876e3619	Discover	43.0602833131413902	-87.924266054724157
20064	2020-04-15 15:09:16	2020-04-15	Lydia Lakin	lydia.lakin@geemail.com	Fremont	California	4246924117377239	20d7bc4bca8a548bb6c30d192edfa54f	Voyager	37.4061333381272902	-121.915328036852927
20065	2020-04-15 15:10:34	2020-04-15	Finnegan Reilly	finnegan.reilly@geemail.com	Dallas	Texas	4553183551875813	f120f802c8ca3294b1f45d6d2033eb82	JCB 16 digit	32.8166030535280697	-96.7678426748104386
20066	2020-04-15 15:57:02	2020-04-15	Lovell Heathcote	lovell.heathcote@geemail.com	Norfolk	Virginia	4461445511433	437b3c29e669c625decaca8dc4576278	Discover	36.9891234652157905	-76.1746736159086311
20067	2020-04-15 16:04:53	2020-04-15	Dr. Royce Gibson	dr.royce.gibson@geemail.com	Round Rock	Texas	6011977048882746728	b03265eee8f65d8c1287fc4b779dba02	Mastercard	30.5325584054596746	-97.6325156376082361
20068	2020-04-15 16:09:28	2020-04-15	Irine Jenkins	irine.jenkins@geemail.com	New York	New York	180010829318308368	b49e642828335b6130d23a5844d674b5	VISA 13 digit	40.6859377417471251	-73.9821047599323123
20069	2020-04-15 16:28:16	2020-04-15	Destin Nader	destin.nader@geemail.com	New York	New York	210007216791892339	bde3beec82943352eeae72a3bfa581ea	JCB 15 digit	40.7121280097626155	-73.9462394408311638
20070	2020-04-15 16:30:18	2020-04-15	Devin Sporer PhD	devin.sporer.phd@geemail.com	Mesa	Arizona	4572881041310898	88450c417b9b1b16c86f3083e12fa285	American Express	33.4525718148011677	-111.710882212070373
20071	2020-04-15 16:39:09	2020-04-15	Rasheed Smith	rasheed.smith@geemail.com	Austin	Texas	869979137053978025	f1356ab6dc888e56a190e7178a92bb13	JCB 16 digit	30.2809846174098531	-97.7566711489815248
20072	2020-04-15 16:43:07	2020-04-15	Edwina Haag MD	edwina.haag.md@geemail.com	Spokane	Washington	3096906735279358382	7b27ca2169c5c70923c048a16de03195	Discover	47.689128104528038	-117.532715371101347
20073	2020-04-15 16:45:04	2020-04-15	Adams Pouros	adams.pouros@geemail.com	San Francisco	California	180066187171066356	410eb745089c484047a5f0bebcfbdee7	Voyager	37.7492729047512796	-122.424738609681526
20074	2020-04-15 16:51:47	2020-04-15	Ms. Exie Hettinger DDS	ms.exie.hettinger.dds@warmmail.com	Berkeley	California	630419468857321	e07296bec5c17d8a12641041362f9936	Diners Club / Carte Blanche	37.881114174598288	-122.297787311263107
20075	2020-04-15 16:54:05	2020-04-15	Rexford Lockman	rexford.lockman@geemail.com	Mesa	Arizona	6011210850033417191	f3ba63372f61dd9d61d6c237f0a0b030	American Express	33.4812104632291891	-111.701816114026684
20076	2020-04-15 16:59:10	2020-04-15	Lavonia Hartmann	lavonia.hartmann@geemail.com	Little Rock	Arkansas	4493608148365681	66fa4bf41e9a9d347b9ff06830cba3fb	JCB 16 digit	34.6566310139648621	-92.2619719123806732
20077	2020-04-15 17:27:43	2020-04-15	Eddie Ziemann	eddie.ziemann@woohoo.com	New York	New York	3494451924106299	43eaa433b9080b4ab07d3b9737aa1b22	Maestro	40.5996586890649027	-73.8655668156117144
20078	2020-04-15 17:46:24	2020-04-15	Miss Lue Sanford DVM	miss.lue.sanford.dvm@warmmail.com	Oakland	California	869954573529922685	c3cd379c12eecb310c1fd22eea1cfd82	JCB 16 digit	37.7933119711562	-122.233963904735617
20079	2020-04-15 17:50:30	2020-04-15	Frederick Lindgren Jr.	frederick.lindgren.jr.@geemail.com	Memphis	Tennessee	675918478620711	c713f0cdc28b618d1353dba5f7502f0b	VISA 13 digit	35.0943452347137068	-90.0352746907878725
20080	2020-04-15 17:53:30	2020-04-15	Felice Moen DVM	felice.moen.dvm@geemail.com	Everett	Washington	180040679981920625	de14b6571318b448844a2638a99d7333	VISA 16 digit	48.0482392676532299	-122.099336566602446
20081	2020-04-15 17:58:33	2020-04-15	Therman Marvin PhD	therman.marvin.phd@geemail.com	San Francisco	California	3337122056251849852	5e66d317fb80825508562a36286c324c	VISA 16 digit	37.778485993263935	-122.466428829780156
20082	2020-04-15 17:59:54	2020-04-15	Shanon Kiehn Sr.	shanon.kiehn.sr.@geemail.com	Kansas City	Missouri	210087519265867148	e07bbce9c36b8f041e337c361841b805	VISA 16 digit	39.1909135198988068	-94.5473900585658811
20083	2020-04-15 18:06:08	2020-04-15	Jaylon Cole-Harber	jaylon.cole.harber@geemail.com	West Jordan	Utah	3458809291731763	684caaab087c453c78e003afabb89a90	Mastercard	40.6173882429279445	-112.077808219854901
20084	2020-04-15 18:07:25	2020-04-15	Seth Carroll	seth.carroll@warmmail.com	Grand Rapids	Michigan	676180845073990	5c7b0b2b19c3407b0e4e615e68e2e4d2	Discover	42.9144614351250198	-85.6458900547720532
20085	2020-04-15 18:14:49	2020-04-15	Letta Pacocha	letta.pacocha@geemail.com	Philadelphia	Pennsylvania	4526649115069428	7aebcd572b14a3e439ff132d12e80e90	Maestro	39.9199178517755087	-75.212036202651646
20086	2020-04-15 18:26:47	2020-04-15	Vincent Spencer	vincent.spencer@geemail.com	Las Cruces	New Mexico	869906385846430345	273d75b64e3d1cd7c0421e308ba85c34	Maestro	32.3880615367587623	-106.765150962269672
20087	2020-04-15 18:45:03	2020-04-15	Mr. Quint Waelchi Sr.	mr.quint.waelchi.sr.@geemail.com	Killeen	Texas	4420594053459263	aa869b088d6f2a58bddbe164a43c81f5	Voyager	30.9839902722042062	-97.804495786612847
20088	2020-04-15 19:04:32	2020-04-15	Miss Cathey Dickens	miss.cathey.dickens@geemail.com	Fresno	California	4598813667278539	43584a543bb307d09f785231e12770ce	VISA 16 digit	36.8762080175675422	-119.832948512734475
20089	2020-04-15 19:05:09	2020-04-15	Doug Rodriguez-McGlynn	doug.rodriguez.mcglynn@geemail.com	Phoenix	Arizona	3713755370973129	85df86d3d6020d0b43b08e7cda2ca264	Voyager	33.5474381993457698	-112.149399485059462
20090	2020-04-15 19:06:01	2020-04-15	Zela Larkin-Lindgren	zela.larkin.lindgren@geemail.com	Cape Coral	Florida	869981795616233653	03a2ab770096ea1b4c9f670c853973f5	VISA 16 digit	26.5813968698929983	-82.0613301084447642
20091	2020-04-15 19:07:03	2020-04-15	Myrna Gibson	myrna.gibson@geemail.com	Bellevue	Washington	6011064627295394947	b7b88d89d14eab6310b56665bfcb94d6	Maestro	47.6916047760468018	-122.150360633065915
20092	2020-04-15 19:26:18	2020-04-15	Claiborne Kling	claiborne.kling@geemail.com	Dallas	Texas	4291397672663	83810690a809c4afaf17b4691317ddc9	Diners Club / Carte Blanche	32.7118351820662667	-96.8018341095149424
20093	2020-04-15 19:38:18	2020-04-15	Miss Aggie Spinka	miss.aggie.spinka@geemail.com	San Francisco	California	6011504623555258557	ec8cb23bf511babd0c5ddd35f8319bf6	JCB 16 digit	37.7704466864566299	-122.416111123825672
20094	2020-04-15 19:57:20	2020-04-15	Dr. Bush Mohr	dr.bush.mohr@woohoo.com	Chesapeake	Virginia	4025711592325651	b279f35a6c72d9f5d948b65c9198b1af	VISA 13 digit	36.6836562000453483	-76.332748480637747
20095	2020-04-15 20:00:33	2020-04-15	Goldia Stokes	goldia.stokes@geemail.com	Kansas City	Missouri	55292561746007499	ef5ad0a8553bcff05bb57931a67165d4	Mastercard	39.115520620143414	-94.5442413467671798
20096	2020-04-15 20:02:18	2020-04-15	Nichelle Wehner	nichelle.wehner@geemail.com	Jacksonville	Florida	676377767617671	ac953d9717cd49d8c5d0e334319fff27	VISA 16 digit	30.3378647916536792	-81.6630530537184427
20097	2020-04-15 20:18:13	2020-04-15	Emanuel Stracke	emanuel.stracke@warmmail.com	New York	New York	6011073347709602780	31c0b76620e832a8b008218b8c589c13	VISA 16 digit	40.684292991528288	-73.932143461135027
20098	2020-04-15 20:19:39	2020-04-15	Yosef Hartmann-Muller	yosef.hartmann.muller@warmmail.com	San Francisco	California	869978930825767630	758f3889de0207ab1b4f73f9a8e9ebd3	VISA 16 digit	37.7539112660905971	-122.447577538669563
20099	2020-04-15 20:47:27	2020-04-15	Rubin Keebler	rubin.keebler@geemail.com	Virginia Beach	Virginia	869956774212083730	518e990794779895a09cd379ac926f27	JCB 15 digit	36.8461251878365914	-76.053138862191517
20100	2020-04-15 21:01:55	2020-04-15	Muhammad Reilly-Ryan	muhammad.reilly.ryan@geemail.com	San Antonio	Texas	180067808019165337	ce50c0589e70ebb76f08abb376fdc819	JCB 16 digit	29.4349407477375138	-98.495149819210539
20101	2020-04-15 21:03:47	2020-04-15	Dr. Verlin Watsica	dr.verlin.watsica@woohoo.com	Jacksonville	Florida	4942517876604434	bc75cac97688a5c865fa6c382648ebaf	JCB 16 digit	30.2450379373557858	-81.6139255625739821
20102	2020-04-15 21:26:41	2020-04-15	Fate Smitham	fate.smitham@geemail.com	Fort Worth	Texas	869986765561423927	b54547098b3395ff416f8b198b41b9b9	VISA 16 digit	32.7230605617221428	-97.298500030888988
20103	2020-04-15 21:28:38	2020-04-15	Ananias Gleichner	ananias.gleichner@geemail.com	San Jose	California	3001133420119321	99eb543aec45756b8181a2d252da48de	VISA 13 digit	37.2771319807328325	-121.819212439538532
20104	2020-04-15 21:40:40	2020-04-15	Marvin Vandervort	marvin.vandervort@woohoo.com	New York	New York	180076588245264356	1a2cdb43d08ee71c1fcceedd16b42018	VISA 16 digit	40.5983911255598073	-73.8917093831475853
20105	2020-04-15 21:44:53	2020-04-15	Quint Hegmann	quint.hegmann@geemail.com	Tampa	Florida	3042522492267936	74f9cdf10fc4ee800a416891e4b70c28	Diners Club / Carte Blanche	27.9327134605146945	-82.56804178824909
20106	2020-04-15 21:46:39	2020-04-15	Larissa Rutherford	larissa.rutherford@geemail.com	Tempe	Arizona	6011939932305008088	050a1d7d9bd854146491e6fc597bc2a7	Mastercard	33.3649185292344512	-111.982190557106577
20107	2020-04-15 21:50:13	2020-04-15	Cruz Grady	cruz.grady@woohoo.com	San Francisco	California	3486873714065320	555992d608590a8eef9d151242525b62	VISA 16 digit	37.7867389107812812	-122.405507509343821
20108	2020-04-15 21:50:53	2020-04-15	London Bartoletti PhD	london.bartoletti.phd@geemail.com	Los Angeles	California	3712984196361639	5d4dbd0e2f8ea2ff5c6c3847dac46710	JCB 15 digit	34.0868223200418043	-118.346768103120098
20109	2020-04-15 21:53:16	2020-04-15	Darcy Collier	darcy.collier@geemail.com	Jersey City	New Jersey	869987595592012400	60852d1c56d5d861de948e69295e2f5d	Maestro	40.6965926120463735	-73.9733250773467148
20110	2020-04-15 22:01:50	2020-04-15	Mr. Alanzo Goodwin III	mr.alanzo.goodwin.iii@warmmail.com	Lexington	Kentucky	3112041100837941680	63910c1e975c27e4ef9e62798e509059	JCB 16 digit	38.0156387433752414	-84.3992427721053247
20111	2020-04-15 22:17:12	2020-04-15	Derrek Adams DDS	derrek.adams.dds@geemail.com	Mesquite	Texas	3029119644091398	6400bcd28ae8ec9bff96edd332fc5e17	Mastercard	32.6650076191682359	-96.5499732131801665
20112	2020-04-15 22:22:02	2020-04-15	Kadyn Runolfsson	kadyn.runolfsson@geemail.com	Stamford	Connecticut	3498285119822658	db525a37837a45e7a02d6aa38c18a0a7	American Express	41.1498551864061497	-73.5311003373507504
20113	2020-04-15 22:29:57	2020-04-15	Loretto D'Amore	loretto.d'amore@geemail.com	San Francisco	California	4854727466716	0e06ae427496656f5fd25ef7dd4391c0	JCB 15 digit	37.8094368428488963	-122.428488956499095
20114	2020-04-15 22:39:19	2020-04-15	Jennette Harris-Gulgowski	jennette.harris.gulgowski@geemail.com	Frisco	Texas	3013374103765513	1b2c6cb5ac775726a952ab3b25e6414c	Discover	33.1413112947713557	-96.7341097046364098
20115	2020-04-15 22:48:57	2020-04-15	Calvin Kihn	calvin.kihn@geemail.com	San Antonio	Texas	869945744928903418	1b37ce7156382568d2d907a1102c50d4	Diners Club / Carte Blanche	29.5202879654780048	-98.4436543270781641
20116	2020-04-15 23:13:11	2020-04-15	Vinton Gusikowski-Little	vinton.gusikowski.little@woohoo.com	San Francisco	California	4822402407420	120c0bb3609a33ec24e41ace7ef61577	JCB 15 digit	37.8010299118027078	-122.461734767733674
20117	2020-04-15 23:21:26	2020-04-15	Mr. Glenwood Kuvalis MD	mr.glenwood.kuvalis.md@geemail.com	Salinas	California	4556803231278842	16eea6358b3e2b73369869d1f9fa4d37	Diners Club / Carte Blanche	36.5929362619992347	-121.591136476554723
20118	2020-04-15 23:23:39	2020-04-15	Mr. Neil Huels	mr.neil.huels@woohoo.com	Costa Mesa	California	4941274371183693	6c2c5c5f1b0d8daefa9961d9c32a544a	JCB 16 digit	33.656140732161326	-117.934536480936416
20119	2020-04-15 23:23:46	2020-04-15	Mr. Woodie Schultz Jr.	mr.woodie.schultz.jr.@geemail.com	New York	New York	4310996260720945	73aa7148cd46177fd5063a477f033ea7	JCB 16 digit	40.6653618030473609	-74.0136466891866149
20120	2020-04-15 23:24:48	2020-04-15	Mrs. Celine Russel DVM	mrs.celine.russel.dvm@geemail.com	New York	New York	3001210037129727	cb74ecefe4e9e9150854ca419c9e1be3	Voyager	40.6010984195619784	-73.870323231433332
20121	2020-04-15 23:30:52	2020-04-15	Major Gottlieb-Bernhard	major.gottlieb.bernhard@geemail.com	Los Angeles	California	869946579876508903	3b3e93feaae111e2858619ef76bd9887	American Express	34.0652587551955079	-118.434969938219709
20122	2020-04-15 23:37:16	2020-04-15	Kyson Treutel III	kyson.treutel.iii@geemail.com	Eugene	Oregon	4965260796846	9bb58d7ef759481bbde5d5be3d02b0b0	Mastercard	44.0854746770307386	-123.147423371159292
20123	2020-04-15 23:55:49	2020-04-15	Hakeem Mohr DVM	hakeem.mohr.dvm@geemail.com	New York	New York	3745505401577346	2c3d26584da8d7378182a5ba4e2596db	American Express	40.6454837944116463	-73.937568213966486
20124	2020-04-16 00:07:00	2020-04-16	Cloe Haley MD	cloe.haley.md@geemail.com	Garland	Texas	4542711758574	efa9cb61b0bd46cae26cb87ce0001780	American Express	32.9921520165402384	-96.5551118538409554
20125	2020-04-16 00:15:52	2020-04-16	Oneta Walter-Armstrong	oneta.walter.armstrong@woohoo.com	Saint Paul	Minnesota	3088306916158177756	629ac8974ca6b5373f4ab0d3052a7c58	Voyager	44.9471365243136916	-93.0246193121917599
20126	2020-04-16 00:24:19	2020-04-16	Mr. Najee Cartwright IV	mr.najee.cartwright.iv@geemail.com	Denver	Colorado	3158724409268787148	74d54e068b2ff2a8b8fa8b56c49f21a0	Maestro	39.7296836023736688	-104.877788366727913
20127	2020-04-16 00:27:20	2020-04-16	Leonidas Hand	leonidas.hand@geemail.com	Costa Mesa	California	4852546112285847	8d0355be2d433389d650323ddb3c5692	JCB 15 digit	33.6272303612917653	-117.952799945357441
20128	2020-04-16 00:44:56	2020-04-16	Bethel Stoltenberg	bethel.stoltenberg@geemail.com	Downey	California	3487563144075960	8f5704378f7caac3695267327661696b	Maestro	33.9836638075549189	-118.04429586293324
20129	2020-04-16 00:48:03	2020-04-16	Ms. Kendal Legros PhD	ms.kendal.legros.phd@geemail.com	New York	New York	55882908942817542	52ff52ecbb8e82bab8d0c2ece842be1c	JCB 15 digit	40.6021581389233432	-73.9866340423829882
20130	2020-04-16 01:00:09	2020-04-16	Mercy Bauch	mercy.bauch@geemail.com	New York	New York	3741707585476774	ea68fec1ac31e5c8356cf6780924fde2	Mastercard	40.5697483221292501	-73.9813747598685296
20131	2020-04-16 01:00:15	2020-04-16	Lura Larkin	lura.larkin@woohoo.com	Saint Paul	Minnesota	3112017545073681384	407098208437d0c2ce2b205cb43b5fda	Discover	44.969233095081151	-93.0912532321441972
20132	2020-04-16 01:05:45	2020-04-16	Kimber Conn	kimber.conn@geemail.com	Oklahoma City	Oklahoma	4337692270344300	f3d9d27e41448ffff024e26c1f51ac0b	VISA 16 digit	35.4433082070577896	-97.5003852530743984
20133	2020-04-16 01:08:14	2020-04-16	Mettie Dickinson	mettie.dickinson@warmmail.com	San Francisco	California	869939117353871822	c05f6a47375012265c2b2846b34227ca	Diners Club / Carte Blanche	37.7715840876710089	-122.431590947818265
20134	2020-04-16 01:08:57	2020-04-16	Dr. Ammie Brekke DVM	dr.ammie.brekke.dvm@geemail.com	San Francisco	California	4336517421614	4af77d9175316de7b2e241833d262607	Voyager	37.7586831579714968	-122.45004306209573
20135	2020-04-16 01:09:02	2020-04-16	Emery Langosh II	emery.langosh.ii@geemail.com	Philadelphia	Pennsylvania	4321284859033641	6430fe3bbac5a8dcc64257b36c61214a	VISA 13 digit	40.05456921034083	-75.1536348129522054
20136	2020-04-16 01:16:44	2020-04-16	Ms. Bessie Terry PhD	ms.bessie.terry.phd@geemail.com	Oakland	California	3337626580782411669	114f7ba35a2b5d703333fa485c48216d	Diners Club / Carte Blanche	37.8052596635081599	-122.262929826098102
20137	2020-04-16 01:25:13	2020-04-16	Oda Roberts-Schaden	oda.roberts.schaden@geemail.com	Los Angeles	California	4651929177067040	427da2013cc8b2bba9f4504e53529f6c	Diners Club / Carte Blanche	34.0592542040959003	-118.480532052087781
20138	2020-04-16 01:30:10	2020-04-16	Mr. Marius Kozey IV	mr.marius.kozey.iv@geemail.com	Oxnard	California	3112856115006336656	4ab14a9f75603903d2e113e7e5c325fb	VISA 16 digit	34.2837527424983719	-119.29306939080395
20139	2020-04-16 01:45:28	2020-04-16	Babe Dibbert III	babe.dibbert.iii@geemail.com	Tempe	Arizona	869906890846279006	3202efdfb3ea4977ef81cecb5bc605fe	Voyager	33.4226351836152347	-111.911600501326092
20140	2020-04-16 01:47:39	2020-04-16	Shanna Herzog	shanna.herzog@geemail.com	San Francisco	California	3037355106244958	e96348f7e7b34e01f21336dd6405d7c6	JCB 16 digit	37.8176260655356486	-122.428288429362539
20141	2020-04-16 01:59:56	2020-04-16	Luis Schroeder	luis.schroeder@geemail.com	Denver	Colorado	4418428724499099	8eb4ea1d92e4e1ae4cabbd8097ddb925	VISA 13 digit	39.8120210726797552	-104.892134270003439
20142	2020-04-16 02:24:22	2020-04-16	Ms. Kimber O'Keefe	ms.kimber.o'keefe@geemail.com	Fort Worth	Texas	4291009293146857	d260600c78af164a901bd51f87af46f5	VISA 16 digit	32.7206980370972289	-97.3151759947005672
20143	2020-04-16 02:30:01	2020-04-16	Mrs. Leota Maggio PhD	mrs.leota.maggio.phd@woohoo.com	San Francisco	California	54388987844758490	022fbdaf9f10f18400966c27c9f93f82	VISA 13 digit	37.7863963282990269	-122.464519672947617
20144	2020-04-16 02:40:43	2020-04-16	Orelia Cormier	orelia.cormier@geemail.com	Durham	North Carolina	3401487758816944	2ce29830770c453cea07b5fda2f66b7e	Discover	35.8885025996494988	-78.8572628862593348
20145	2020-04-16 02:47:39	2020-04-16	Sonia Carroll	sonia.carroll@geemail.com	Rancho Cucamonga	California	4376295703007	64b0b662b3063d33b5ca3d1bff91d5fa	Mastercard	34.0909765934564177	-117.651556897210696
20146	2020-04-16 02:53:43	2020-04-16	Sophie Mohr-Doyle	sophie.mohr.doyle@geemail.com	San Francisco	California	869985359318105713	c8464bf3f32650b9466074c99f8eac15	Voyager	37.7820132326904954	-122.41292634038183
20147	2020-04-16 02:54:26	2020-04-16	Mrs. Adline Rau	mrs.adline.rau@woohoo.com	Murfreesboro	Tennessee	4832679939318445	68eee0bf0ee3f5b43b75dc68b1a47c77	JCB 16 digit	35.811331682524461	-86.4546178993154228
20148	2020-04-16 03:10:34	2020-04-16	Janie Thompson	janie.thompson@warmmail.com	Cleveland	Ohio	4863935313752886	3c1c134e085d3c86e3b87a1338b4ddd6	JCB 16 digit	41.5587452959585875	-81.6660239537950616
20149	2020-04-16 03:35:11	2020-04-16	Ms. Noemi Hegmann DVM	ms.noemi.hegmann.dvm@warmmail.com	San Francisco	California	6011717291064778425	c1461d186e35f1e3977e0067aa8657e3	JCB 15 digit	37.7526568620751206	-122.441397294540494
20150	2020-04-16 03:41:05	2020-04-16	Mr. Curt Collins	mr.curt.collins@woohoo.com	Garden Grove	California	180020390146503272	cb507ab59d22f77a8a8b51515c961b6a	VISA 16 digit	33.8127201936963928	-118.026397814184421
20151	2020-04-16 03:50:49	2020-04-16	Pleasant Leuschke	pleasant.leuschke@geemail.com	New York	New York	3043951053544525	2713afa2a4724b7aade38e491158ae8a	VISA 16 digit	40.5867048299629261	-73.9679397839017128
20152	2020-04-16 04:18:42	2020-04-16	Robin Glover	robin.glover@geemail.com	Boise	Idaho	4389543055704191	cec249896476c2196a115991e35c2135	Mastercard	43.5087661299992376	-116.239718874144188
20153	2020-04-16 04:27:21	2020-04-16	Jake Feest-Carroll	jake.feest.carroll@geemail.com	San Francisco	California	6011520641511250427	01b280ad14b7b48c8e605593576f70fc	Mastercard	37.7829875728882598	-122.364504545899621
20154	2020-04-16 04:43:23	2020-04-16	Philomena Parisian	philomena.parisian@woohoo.com	Ann Arbor	Michigan	180029968590992132	90ed7752adcf40bdf372156960e8db34	Mastercard	42.3740099211283052	-83.8155292431000731
20155	2020-04-16 04:43:45	2020-04-16	Squire Parisian	squire.parisian@geemail.com	Los Angeles	California	3337979247277745224	35d43e7881dd42f6faeb9a0049c6cb62	VISA 13 digit	33.9918539152346497	-118.46132881985902
20156	2020-04-16 05:01:18	2020-04-16	Jenna Bartoletti	jenna.bartoletti@woohoo.com	Houston	Texas	3763071551520799	57ef03b76c7bfcc89cce3e2bc0ead700	Maestro	29.70113762864694	-95.4040759591866276
20157	2020-04-16 05:14:45	2020-04-16	Malik Douglas-Mayer	malik.douglas.mayer@woohoo.com	Thousand Oaks	California	180096162451357001	bb0675ad0942fb415d81634115038df2	Discover	34.20579217083678	-118.884440345168855
20158	2020-04-16 05:25:30	2020-04-16	Alayna Goldner	alayna.goldner@warmmail.com	Orlando	Florida	52702222109487430	276fbe3fdd5e73457ef8bfa28bdd5ee2	Maestro	28.3952822206340727	-81.3203734364327033
20159	2020-04-16 05:30:46	2020-04-16	Ms. Isabella Walker	ms.isabella.walker@geemail.com	Chicago	Illinois	3158856395055258726	8c187803979e03f75315351d21785ffe	JCB 16 digit	41.9111959582496425	-87.6613265775639547
20160	2020-04-16 05:31:56	2020-04-16	Mr. Davante Balistreri	mr.davante.balistreri@warmmail.com	Rancho Cucamonga	California	180082384065187287	989578e69d379ddaba1e0a34078febac	JCB 16 digit	34.1073104463510219	-117.475873097359013
20161	2020-04-16 05:32:13	2020-04-16	Nim Boehm	nim.boehm@geemail.com	Los Angeles	California	3528967677492679242	e3cc45a18d0db895b710f2f0d88506b1	Mastercard	34.0264169326849242	-118.493205563071371
20162	2020-04-16 05:51:46	2020-04-16	Ms. Georganna Labadie MD	ms.georganna.labadie.md@woohoo.com	Kansas City	Kansas	6011078411962904773	9d7b954b190051ca31e907e0dbe4b41b	Mastercard	39.0484520946070575	-94.7870156909741439
20163	2020-04-16 05:53:41	2020-04-16	Clark O'Hara	clark.o'hara@geemail.com	McKinney	Texas	639004676049085	1f59ab6f1490b59d555e49787b39ae82	Maestro	33.1082943589091343	-96.6798045141454878
20164	2020-04-16 05:56:57	2020-04-16	Mr. Zavier Barton Sr.	mr.zavier.barton.sr.@geemail.com	Las Vegas	Nevada	3158053899973417885	c7598b9fb7c4ce54701907cab04a5cdd	JCB 15 digit	36.2588510812826428	-115.349150565473735
20165	2020-04-16 06:19:14	2020-04-16	Fremont Abshire	fremont.abshire@geemail.com	Clearwater	Florida	3465788927917346	4d30d9aacaba49f2b0cc8a6390dcc7e0	JCB 15 digit	27.93795631831847	-82.7511732111018148
20166	2020-04-16 06:20:02	2020-04-16	Michal Feest	michal.feest@geemail.com	San Francisco	California	3088325020976457032	8242e5d72200d60a01327ae2c411c8e2	Mastercard	37.7530173744235711	-122.448058988609461
20167	2020-04-16 06:38:47	2020-04-16	Buster Streich PhD	buster.streich.phd@geemail.com	Athens	Georgia	869956832656049748	0d9eebc1877f7c2dafc49f3dfd673c35	JCB 16 digit	33.9638321266233874	-83.4010346375986842
20168	2020-04-16 07:06:14	2020-04-16	Dr. Newman Lesch	dr.newman.lesch@woohoo.com	Newark	New Jersey	3528948461415918548	ac53e871fb362500effca90146b87f0f	Diners Club / Carte Blanche	40.7286232658110592	-74.1488719290796752
20169	2020-04-16 07:07:53	2020-04-16	Leota Hintz-Barrows	leota.hintz.barrows@warmmail.com	Anchorage	Alaska	675960644446761	1f7c9af7072d9e4402f9a0f6e02e9acd	American Express	61.1719379352156096	-149.212085647287978
20170	2020-04-16 07:25:22	2020-04-16	Tavon Kohler	tavon.kohler@geemail.com	Peoria	Arizona	4176479059873	73324bc69065fbcf07170bf994ffd321	VISA 16 digit	33.8143341068912306	-112.209217280328275
20171	2020-04-16 07:29:46	2020-04-16	Mark O'Connell	mark.o'connell@geemail.com	Toledo	Ohio	4406550240282016	b7176ddf404655e2a56bb49947fdf53f	Discover	41.610165716911105	-83.6760755440086115
20172	2020-04-16 07:38:46	2020-04-16	Riley Franecki	riley.franecki@geemail.com	Anchorage	Alaska	54958207618448883	3e01654b0efe6c86e69f702560383e79	Mastercard	61.1439944432798796	-149.185382133082669
20173	2020-04-16 07:40:07	2020-04-16	Reta Haley-Sauer	reta.haley.sauer@geemail.com	Berkeley	California	676386117852771	69c0a67f4d48c47d18ef90ef7a52b2f6	Diners Club / Carte Blanche	37.862110687941076	-122.271839995375672
20174	2020-04-16 07:41:19	2020-04-16	Mrs. Penni Mohr MD	mrs.penni.mohr.md@geemail.com	North Las Vegas	Nevada	869913466550957722	aa5cd95ddb55c01a137f4ae7d90a9933	American Express	36.2096110584370763	-115.041775344660138
20175	2020-04-16 07:49:59	2020-04-16	Mrs. Makala Gutkowski DVM	mrs.makala.gutkowski.dvm@geemail.com	San Francisco	California	3022859882173872	4c232bbfd71c7624dbd965af969b3cf5	VISA 16 digit	37.7787170638867522	-122.430791745531565
20176	2020-04-16 07:54:01	2020-04-16	Cathern Sawayn	cathern.sawayn@geemail.com	Washington	District of Columbia	869980665417999201	af6ad1ddd59dc0e801f9398e4efece1a	American Express	38.9373328820601117	-76.9373217805501071
20177	2020-04-16 07:55:16	2020-04-16	Mrs. Arly Corwin	mrs.arly.corwin@geemail.com	Providence	Rhode Island	4446774354612931	8fb604167900fc9e267580b8f51b04f6	VISA 16 digit	41.8690161075297738	-71.5088359964929623
20178	2020-04-16 08:06:13	2020-04-16	Olinda Rempel	olinda.rempel@geemail.com	Tucson	Arizona	561256072796016	63c63bc823209025845e43fde8d446d8	JCB 16 digit	32.1167257207952446	-110.868405775841694
20179	2020-04-16 08:11:07	2020-04-16	Michele Rosenbaum-Shanahan	michele.rosenbaum.shanahan@geemail.com	Gilbert	Arizona	3112039985943976065	796dcf6b4cad2b20ccf231f17b2bd7ae	VISA 16 digit	33.2561064302802052	-111.718576591289036
20180	2020-04-16 08:18:08	2020-04-16	Dr. Makai Schultz V	dr.makai.schultz.v@geemail.com	Santa Ana	California	3745077306449971	b4ff46d9ae6969296dfbc0d671ae0f9b	VISA 16 digit	33.7081978232238413	-117.951552374280979
20181	2020-04-16 08:53:36	2020-04-16	Ashtyn Langosh	ashtyn.langosh@geemail.com	Warren	Michigan	6011382136671387652	94b415232380d718ab23b47ccc0e484a	Voyager	42.4297074188474568	-83.1107581375166831
20182	2020-04-16 08:58:38	2020-04-16	Allyson Thiel	allyson.thiel@geemail.com	Lansing	Michigan	4061073766286952	76af53bab8ee185d06f7589d42a3db4f	Voyager	42.7285356649972528	-84.5266931328114026
20183	2020-04-16 09:07:23	2020-04-16	Layne Howell	layne.howell@geemail.com	Pembroke Pines	Florida	3528579196753564076	aeed78faaf18454befd6a41696c92628	Diners Club / Carte Blanche	26.036304659726099	-80.4320184965986726
20184	2020-04-16 09:18:14	2020-04-16	Pepper Bahringer	pepper.bahringer@woohoo.com	Fremont	California	210056389031018237	512e1417e50e09edb9a16d4b8dd29ad6	Discover	37.5457089846655734	-121.850659842042987
20185	2020-04-16 09:25:03	2020-04-16	Chrissy Mayer	chrissy.mayer@geemail.com	Charlotte	North Carolina	3005812955549319	96387c358e81dcce966f82fded5f1673	VISA 13 digit	35.236893421762808	-80.7687203199081125
20186	2020-04-16 09:51:11	2020-04-16	Dr. Ali Wehner	dr.ali.wehner@geemail.com	Broken Arrow	Oklahoma	3727973409120836	25bb5590b6998e5e226ad240e98d1f8e	Mastercard	36.1307115353420372	-95.7266215615850058
20187	2020-04-16 09:57:42	2020-04-16	Dr. Jacque Jenkins MD	dr.jacque.jenkins.md@geemail.com	Baltimore	Maryland	3112348681461058784	b44690a73f0dd01c24a4e77545b6fda6	Diners Club / Carte Blanche	39.2251536480616778	-76.6658968865890103
20188	2020-04-16 09:58:12	2020-04-16	Dr. Graham Collier I	dr.graham.collier.i@geemail.com	San Diego	California	3158946455732171924	3e6d5945523ed5f4ece0b44133942465	Diners Club / Carte Blanche	32.9146856753222679	-117.232902349103242
20189	2020-04-16 10:42:46	2020-04-16	Chris Corkery	chris.corkery@geemail.com	New York	New York	3026378541815191	67de88cb2595e57507fdb23331c7333a	Discover	40.7516988061591974	-73.9228756543610217
20190	2020-04-16 10:47:08	2020-04-16	Dr. Whitney Langosh V	dr.whitney.langosh.v@geemail.com	Akron	Ohio	561242195359023	8ec93063750c2de17e043fc2453b93a3	VISA 16 digit	40.9968226735312484	-81.4433174585770843
20191	2020-04-16 10:54:57	2020-04-16	Yolonda Connelly	yolonda.connelly@geemail.com	Austin	Texas	210056029842740591	169d1449fc7b00ee8e8a7bec9ee60824	Voyager	30.2531033476941289	-97.7258437241666087
20233	2020-04-16 17:23:42	2020-04-16	Georgiann Beer	georgiann.beer@geemail.com	Overland Park	Kansas	4198633607835998	de398caf82e8791bb30a25706d32b05d	Discover	38.8115765271578042	-94.7657018395647412
20192	2020-04-16 11:06:56	2020-04-16	Hallie Jakubowski	hallie.jakubowski@geemail.com	Worcester	Massachusetts	4559902599054840	7cddac732e0b8449fb7a8645e11b82d1	Diners Club / Carte Blanche	42.2247991474047311	-71.8665606482673383
20193	2020-04-16 11:09:17	2020-04-16	Geoff Senger	geoff.senger@geemail.com	Manchester	New Hampshire	3404965406996280	0e04c78c6b9cc19eaefaf767368ceb43	VISA 16 digit	43.0612378307689028	-71.4034043089844346
20194	2020-04-16 11:10:31	2020-04-16	Bernetta Ullrich	bernetta.ullrich@geemail.com	Modesto	California	6011383277699121225	d07fd2477e5d3dad8210ccf0d6e7cf8a	Voyager	37.6946622024755982	-121.041831561757249
20195	2020-04-16 11:19:42	2020-04-16	Jaquelin Johns	jaquelin.johns@warmmail.com	Chula Vista	California	3337053069049735385	ebce41fa36212de0cb830100b1d3e4e3	Diners Club / Carte Blanche	32.7250605660721661	-116.92415274155772
20196	2020-04-16 11:29:31	2020-04-16	Beverley Wisozk	beverley.wisozk@geemail.com	Miami	Florida	3337608833003421377	1414715dd52bd4440948efbb562c3b60	JCB 16 digit	25.7910132450655105	-80.1467061436142814
20197	2020-04-16 11:43:49	2020-04-16	Mrs. Pauline Hane DDS	mrs.pauline.hane.dds@woohoo.com	Killeen	Texas	4040947564166316	5f8b70a455943a49bc52c477cc844cfd	VISA 16 digit	31.0623439534798251	-97.6465045059267425
20198	2020-04-16 12:00:15	2020-04-16	Ms. Fatima Brakus	ms.fatima.brakus@geemail.com	Henderson	Nevada	869932679342793026	edbc96e38cf5e4445219d52101e4d6c9	Mastercard	36.0032140921734296	-115.012069719021028
20199	2020-04-16 12:02:04	2020-04-16	Claudie Jones	claudie.jones@woohoo.com	Sioux Falls	South Dakota	3337997290387427869	268e1e3b3a18a745f2aadfe725119871	JCB 16 digit	43.6177051014818247	-96.7532937351316207
20200	2020-04-16 12:24:40	2020-04-16	Mr. Hartwell Veum II	mr.hartwell.veum.ii@geemail.com	Austin	Texas	3096999336178870177	48d30e4d86891aa1d35cdfc9a4b260a8	Discover	30.2042005587495836	-97.6551467939984121
20201	2020-04-16 12:27:51	2020-04-16	Koda Rohan-Shanahan	koda.rohan.shanahan@warmmail.com	Kenosha	Wisconsin	3788173600875769	64b03fe5ad87f525f47a6245cc141893	Voyager	42.6456931946638989	-87.8234533922042715
20202	2020-04-16 12:39:35	2020-04-16	Laurine Bergnaum DDS	laurine.bergnaum.dds@warmmail.com	Grand Prairie	Texas	503871477606207	271a831388d77ec9a2996b50311a253e	JCB 16 digit	32.6448286901745988	-97.053148394763852
20203	2020-04-16 12:43:24	2020-04-16	Sheron Cummings	sheron.cummings@geemail.com	Raleigh	North Carolina	4456536406179632	96336ab43e9fde8ef0e82bebecf69db2	American Express	35.8174069005198774	-78.666140913956994
20204	2020-04-16 12:58:21	2020-04-16	Nils Robel	nils.robel@warmmail.com	Santa Maria	California	3096513249062499713	2eb57b08e938f85cec92584784571a93	VISA 16 digit	34.96209104052447	-120.486543624607094
20205	2020-04-16 13:05:09	2020-04-16	Abby Schuppe	abby.schuppe@woohoo.com	Scottsdale	Arizona	54888140067660291	91c83e41679ab9766055c811cabdad6d	Voyager	33.7569204910315577	-111.893406554634112
20206	2020-04-16 13:05:49	2020-04-16	Dr. Azaria Beahan	dr.azaria.beahan@geemail.com	Santa Clara	California	869956805949851856	4fcb92eb70d6b8b8f290a3981a7602ac	Voyager	37.3688643917724548	-121.983046071510387
20207	2020-04-16 13:16:45	2020-04-16	Olympia Lang	olympia.lang@warmmail.com	Roseville	California	3528529349306230999	57f4401c988c658ee730b142e4b5a26e	Maestro	38.7801516205593941	-121.246341401593384
20208	2020-04-16 13:20:50	2020-04-16	Elisha Harvey	elisha.harvey@geemail.com	Los Angeles	California	3461121781622741	20f20956c52e9fbf4b5e7166c11f2880	VISA 16 digit	33.9571363207284307	-118.375188589467854
20209	2020-04-16 13:33:12	2020-04-16	Mrs. Maurine Abbott DDS	mrs.maurine.abbott.dds@woohoo.com	Philadelphia	Pennsylvania	3088902350237381700	bae11e2cbee61a5afef2f93a05e7fd7b	JCB 16 digit	39.9473441149998436	-75.1034177104376255
20210	2020-04-16 13:48:44	2020-04-16	Mr. Bush Jones	mr.bush.jones@geemail.com	Houston	Texas	180067193945422718	586a7bc7ee97451b1d97a37a13e1be31	Diners Club / Carte Blanche	29.8791698307342841	-95.401871368197348
20211	2020-04-16 13:58:06	2020-04-16	Arlie Ritchie-Boyer	arlie.ritchie.boyer@warmmail.com	Jacksonville	Florida	3030334552879002	48903c772f0e470848f085aa27d67073	JCB 16 digit	30.3052482425753027	-81.5788656201291928
20212	2020-04-16 14:02:13	2020-04-16	Brant Bogisich	brant.bogisich@geemail.com	Lubbock	Texas	180037028140268341	eb746fb4b1fafd861b24fc08a55e8b6e	JCB 16 digit	33.5774036671541651	-101.959455234269427
20213	2020-04-16 14:12:05	2020-04-16	Eliana Treutel	eliana.treutel@woohoo.com	Santa Rosa	California	210006449927195480	1a7a6515ca239a295a6f0384ac9714e2	Discover	38.4314366938203591	-122.685866072798532
20214	2020-04-16 14:12:38	2020-04-16	Zora Stehr	zora.stehr@geemail.com	Fremont	California	3158731034915619634	fa13ca4f74248d3d39e111b9a4e9ddf1	VISA 16 digit	37.5579163602255335	-121.903658566203703
20215	2020-04-16 14:17:44	2020-04-16	Sommer Stoltenberg	sommer.stoltenberg@geemail.com	San Francisco	California	53481052071461270	1cf757db69af31231455adc45150113a	Diners Club / Carte Blanche	37.7599839625753262	-122.444713728805397
20216	2020-04-16 14:46:41	2020-04-16	Jackeline Jones-Ferry	jackeline.jones.ferry@geemail.com	San Francisco	California	3011610731846452	1485fcc3616e70c33e9632eda2bdafd9	American Express	37.7888905754072013	-122.441259275970708
20217	2020-04-16 15:09:16	2020-04-16	Jeanna Moen	jeanna.moen@geemail.com	San Francisco	California	51566743076138370	156bab7581d26b00d7d72a5bccc8718b	JCB 15 digit	37.7909207827449336	-122.432213697397614
20218	2020-04-16 15:10:57	2020-04-16	Kamya Mann-Leffler	kamya.mann.leffler@woohoo.com	Rockford	Illinois	3402944828336880	3a236cae1aafe3367c2fbbf9e4d89b41	Voyager	42.2470051979191581	-89.1627731332372804
20219	2020-04-16 15:12:14	2020-04-16	Adam Kuphal	adam.kuphal@geemail.com	Chandler	Arizona	4739996461839	671377d4b73d9e0e075acb4c421f5936	VISA 16 digit	33.3066127637024962	-111.838577779231215
20220	2020-04-16 15:39:09	2020-04-16	Marilyn Wolff MD	marilyn.wolff.md@geemail.com	Rialto	California	3015415426516022	a27e06e931dcfa58678c5034e908b9e0	JCB 16 digit	34.1270892698999546	-117.478866381346435
20221	2020-04-16 15:52:33	2020-04-16	Hymen Romaguera	hymen.romaguera@geemail.com	Killeen	Texas	6011628217318505049	964a3df65cfba06462ed143d5169b3f7	Voyager	31.1165440276030445	-97.6719503921624295
20222	2020-04-16 16:08:45	2020-04-16	Dionicio Bode IV	dionicio.bode.iv@geemail.com	New York	New York	6011188521814985288	d26d9e1303883a4fdbfcb9c08bf8a4b1	JCB 15 digit	40.7265269310902767	-73.965626896115765
20223	2020-04-16 16:17:18	2020-04-16	Marnita Hudson	marnita.hudson@woohoo.com	Westminster	Colorado	6011632583602529506	f9da7602313ff24058d2d2cab4d684d4	VISA 16 digit	39.8362148768573974	-105.045767257377136
20224	2020-04-16 16:18:09	2020-04-16	Len Rutherford	len.rutherford@geemail.com	Austin	Texas	561268568778606	9f07c9a24d55d1b1ae460fa54c820867	Diners Club / Carte Blanche	30.3157691158946605	-97.8483669550862203
20225	2020-04-16 16:21:17	2020-04-16	Isadore Cormier-Cole	isadore.cormier.cole@geemail.com	Los Angeles	California	53611315629635429	92e5cf247787d0207f198bb1c6946a12	JCB 15 digit	33.979470871468628	-118.451047682761399
20226	2020-04-16 16:26:54	2020-04-16	Karyme Wilkinson	karyme.wilkinson@geemail.com	San Jose	California	52539277457013211	b0404544ade1e63e3987ee202ced9d0a	VISA 16 digit	37.2850398799225715	-121.870248223304372
20227	2020-04-16 16:27:42	2020-04-16	Leonardo Hills	leonardo.hills@geemail.com	San Francisco	California	53981804832626848	5cb4f2a4faea172a920c645383656f89	Discover	37.7624826617378204	-122.42462314535139
20228	2020-04-16 16:36:34	2020-04-16	Tarik Abshire	tarik.abshire@geemail.com	New York	New York	4954598069799939	2272dbb787826e839277b750e3ad2f9c	JCB 16 digit	40.6132111518867305	-73.9974414202280286
20229	2020-04-16 16:47:47	2020-04-16	Dr. Pierre Oberbrunner V	dr.pierre.oberbrunner.v@geemail.com	Los Angeles	California	4209788085014	ec5d2d00d89895d8c97b510de9d82b4e	Mastercard	34.0445960167195594	-118.51028616088368
20230	2020-04-16 16:52:49	2020-04-16	Vonnie McClure-Gleason	vonnie.mcclure.gleason@woohoo.com	Fort Worth	Texas	6011616444626300681	cff3031fb711831f2e956b0631df67bf	JCB 15 digit	32.8664142565391941	-97.3100624255191491
20231	2020-04-16 17:12:02	2020-04-16	Arlo Wuckert-Hyatt	arlo.wuckert.hyatt@geemail.com	Berkeley	California	3018207490781724	3d49527ec39d6f192e934fd525e7c345	JCB 16 digit	37.8670866027499358	-122.249858870547854
20232	2020-04-16 17:14:44	2020-04-16	Miss Debbra Flatley PhD	miss.debbra.flatley.phd@geemail.com	Worcester	Massachusetts	4320902319799	13e4cb933777dffd99d5432b37ea66fe	Maestro	42.3111837830096462	-71.7775581490501793
20234	2020-04-16 17:24:15	2020-04-16	Toccara Hyatt-Mayer	toccara.hyatt.mayer@geemail.com	Philadelphia	Pennsylvania	4318175144720	dfd8e64e724ad97704b1ef747b3f5b9e	American Express	40.0198078816715608	-75.1833783323776004
20235	2020-04-16 17:27:16	2020-04-16	Ceola Kreiger	ceola.kreiger@warmmail.com	Aurora	Colorado	4540277142847368	aab945279d4d741a4e0a4f57a3282ab6	VISA 16 digit	39.7512091143634194	-104.67220100961886
20236	2020-04-16 17:32:32	2020-04-16	Katherine Simonis	katherine.simonis@geemail.com	Oceanside	California	3028925737349704	1ef639c1e2ca57a24686eef0f263f9bf	VISA 16 digit	33.3192628465946754	-117.215465625430269
20237	2020-04-16 17:32:45	2020-04-16	Miss Diana Pouros	miss.diana.pouros@geemail.com	Jackson	Mississippi	4210741159279418	e8ec5b9a948170b01bab1417dc36cefb	JCB 15 digit	32.3718626917518719	-90.2517076811727179
20238	2020-04-16 17:52:59	2020-04-16	Dakota Koelpin	dakota.koelpin@geemail.com	Oakland	California	210035903758033330	df2db6ca0d93b3fd8a6c378524da13e5	Mastercard	37.8279419093350171	-122.289217236899617
20239	2020-04-16 17:56:52	2020-04-16	Kassandra Mertz MD	kassandra.mertz.md@geemail.com	Sugar Land	Texas	4631376072350540	215d1eaebba84497749dfad30cea91c7	American Express	29.6895082507800296	-95.6963448174770832
20240	2020-04-16 18:10:26	2020-04-16	Winnie Kub-Stoltenberg	winnie.kub.stoltenberg@geemail.com	Fort Wayne	Indiana	4993727846103197	04e8e6e9d0677afc654e65dc2adc2c47	Mastercard	40.9891169051889364	-85.148312406589838
20241	2020-04-16 18:14:31	2020-04-16	Chanelle Hane	chanelle.hane@warmmail.com	Yonkers	New York	3088426874321582847	05f62b19881adc2e7ba6451472691f1b	JCB 16 digit	40.9919821155458735	-73.7826129650115945
20242	2020-04-16 18:39:04	2020-04-16	Metro Kunde	metro.kunde@geemail.com	Chicago	Illinois	4563449342139035	672d78464faa70755100f618d5706f10	JCB 15 digit	41.9169385788332676	-87.5986042991775946
20243	2020-04-16 18:46:13	2020-04-16	Monroe Ledner	monroe.ledner@woohoo.com	Albuquerque	New Mexico	4026774586900052	677bb8e50b1ca81effb7a5f37e387019	Diners Club / Carte Blanche	35.1470603360928635	-106.614009023371722
20244	2020-04-16 18:49:39	2020-04-16	Terrell Kozey	terrell.kozey@geemail.com	Los Angeles	California	4604060505177398	486bd3c4c09937493f738f9d0424c475	JCB 16 digit	34.0581635625898826	-118.435286159719524
20245	2020-04-16 19:02:28	2020-04-16	Burrel Hand-Sawayn	burrel.hand.sawayn@geemail.com	Atlanta	Georgia	3035268600274565	4823f355be06ae513ac4930f3e09f9e2	JCB 16 digit	33.8255175553072291	-84.5198252733375881
20246	2020-04-16 19:12:37	2020-04-16	Mrs. Belen Morissette DDS	mrs.belen.morissette.dds@geemail.com	Kansas City	Missouri	4652398503405671	d579a59bb2a856cbf75b7d28bafbd756	JCB 15 digit	39.0908889413647387	-94.4531046512760213
20247	2020-04-16 19:17:10	2020-04-16	Miss Danna Schmeler	miss.danna.schmeler@geemail.com	Pomona	California	3088884310920305731	91642d4bc0a3b4e0d891cd13e31960b9	Diners Club / Carte Blanche	34.0836146540045775	-117.825914173011114
20248	2020-04-16 19:34:07	2020-04-16	Alyson Schmitt	alyson.schmitt@geemail.com	New York	New York	3112342666610026242	9e7994365fcbf3830265e0f0e72c3760	Voyager	40.5965080500338189	-73.8453570864058975
20249	2020-04-16 19:39:19	2020-04-16	Miss Marcella Dooley	miss.marcella.dooley@geemail.com	Fremont	California	3096552505725817241	d064915fe4eba3497c88ba50f89f256d	JCB 15 digit	37.5331105038691319	-121.842705967183036
20250	2020-04-16 20:00:42	2020-04-16	Marlie Roob	marlie.roob@geemail.com	Newport News	Virginia	4203054035296013	14580ff220b4c54ebafa66087e7eda0e	Discover	37.1402347983222469	-76.5380950781311924
20251	2020-04-16 20:05:30	2020-04-16	Federico West	federico.west@geemail.com	Allen	Texas	54707080190629343	20a3c6857e89c99c07270dadcc01087c	JCB 15 digit	33.1148450453326078	-96.581076723192254
20252	2020-04-16 20:10:05	2020-04-16	Miss Iris Abernathy	miss.iris.abernathy@geemail.com	Macon	Georgia	4669360322913	44cf6db9a0328363d13c353380e22d8d	VISA 16 digit	32.8646314140886062	-83.624069193490584
20253	2020-04-16 20:22:09	2020-04-16	Fulton Stamm	fulton.stamm@geemail.com	Oklahoma City	Oklahoma	4637965533592478	750fbc1b31755faa087c04e2e1b53532	JCB 15 digit	35.5035982690196477	-97.5608453978680075
20254	2020-04-16 20:25:05	2020-04-16	Jennings Spencer-Pfannerstill	jennings.spencer.pfannerstill@geemail.com	Memphis	Tennessee	3451663205025722	3b778f496c5a0f8c597190880df2b914	Voyager	35.1687163846634334	-90.0114132583864119
20255	2020-04-16 20:56:54	2020-04-16	Harrison Crooks	harrison.crooks@geemail.com	Albuquerque	New Mexico	869903257118203861	561acccea1f4d135bddd0ed12efba286	VISA 13 digit	35.0999670684471781	-106.688327600115542
20256	2020-04-16 21:01:27	2020-04-16	Carisa Abbott-Corkery	carisa.abbott.corkery@geemail.com	San Francisco	California	3004780154075033	3f91114cb0eef6524fcbc38b931bc65e	VISA 13 digit	37.7803314155956471	-122.412103955353388
20257	2020-04-16 21:11:48	2020-04-16	Dr. Sondra Eichmann	dr.sondra.eichmann@geemail.com	New Orleans	Louisiana	4451887068448	d940880a8d95504efc03055e3127ed6e	Discover	30.0416614992558948	-89.9515410689432144
20258	2020-04-16 21:19:01	2020-04-16	Chaney Yost	chaney.yost@geemail.com	Berkeley	California	869907887401585396	0ec3a21eb953e15c10c88c2d2f0bc4ed	Discover	37.8630753280417025	-122.261813497878848
20259	2020-04-16 21:22:37	2020-04-16	Amy Schulist MD	amy.schulist.md@warmmail.com	San Francisco	California	6011995508777604892	1bc97f4a05d52fada441b945274c89f5	VISA 16 digit	37.7723700361917594	-122.432064384018446
20260	2020-04-16 21:28:54	2020-04-16	Teddy Goyette	teddy.goyette@geemail.com	Austin	Texas	6011474027305050288	f4ec9206b61d62d49aaa25a3fcc8ad41	VISA 16 digit	30.2573761057235302	-97.6748541168175706
20261	2020-04-16 21:40:26	2020-04-16	Dorcas Harber-Okuneva	dorcas.harber.okuneva@geemail.com	Dallas	Texas	210046700288179139	f78fecf624fe07280434f5aa00472a57	VISA 16 digit	32.8589234554946472	-96.760563640432423
20262	2020-04-16 21:42:45	2020-04-16	Idella Jerde	idella.jerde@woohoo.com	Colorado Springs	Colorado	869969045511939889	0ac57f6d33c55d97b9c1d13177bc47f2	Voyager	38.9495715532500313	-104.67194651925638
20263	2020-04-16 21:57:32	2020-04-16	Sloane Wisoky	sloane.wisoky@geemail.com	Virginia Beach	Virginia	3029573870736573	4467dfffc02e6e504f310dd078819049	VISA 13 digit	36.8074859564844559	-75.986986992568518
20264	2020-04-16 22:10:01	2020-04-16	Amaris Fadel	amaris.fadel@woohoo.com	Miami	Florida	6011013223202601475	88066ee8e7e3dee7bf7d0ac6492b1fc1	Diners Club / Carte Blanche	25.6974000323235998	-80.1329054354097678
20265	2020-04-16 22:19:27	2020-04-16	Marie Hettinger-Keeling	marie.hettinger.keeling@geemail.com	Vancouver	Washington	3158966531832312868	0d0d9aedbab24c36e8d932f4c9241ed8	Diners Club / Carte Blanche	45.7117493862822641	-122.593716613349315
20266	2020-04-16 22:21:46	2020-04-16	Mr. Jennings Haag	mr.jennings.haag@geemail.com	Fort Wayne	Indiana	630447391953644	3f3c96740382a9516cd514f5c6511e48	VISA 13 digit	40.9899096871510125	-85.2072637609425954
20267	2020-04-16 22:51:58	2020-04-16	Kizzie Jerde	kizzie.jerde@geemail.com	Phoenix	Arizona	180097586413024490	b4c02c0f2652d3617fa713c6be48149d	Mastercard	33.5909904958147578	-112.1484252767101
20268	2020-04-16 23:01:52	2020-04-16	Bell Haley	bell.haley@geemail.com	Cary	North Carolina	6011700096446396401	b981e0f3eeaa598c4980cb79d025918a	Discover	35.846834774838392	-78.820707759176571
20269	2020-04-16 23:06:40	2020-04-16	Davie Schulist	davie.schulist@geemail.com	Atlanta	Georgia	4510139593213068	b7082a996d2dbe14791e9ed3375ee9c5	American Express	33.8228372317548889	-84.3825208689596593
20270	2020-04-16 23:12:08	2020-04-16	Math Wolf-Mills	math.wolf.mills@geemail.com	Berkeley	California	869997233231323289	f021279b707ada15277de31483b79250	Discover	37.8646517433769674	-122.224463825105204
20271	2020-04-16 23:18:58	2020-04-16	Mr. Aydan Schmidt Sr.	mr.aydan.schmidt.sr.@warmmail.com	New York	New York	210068537420725145	757036fc7e8949c30548a5b0d2a9e313	Maestro	40.7041647055875515	-73.9803399697307498
20272	2020-04-16 23:19:39	2020-04-16	Mr. Rowan Hyatt V	mr.rowan.hyatt.v@warmmail.com	Gilbert	Arizona	210091704316545257	b600e6f2bcc61e1d414b0e6a0e4f9ffd	JCB 16 digit	33.2956582852054339	-111.834427525163065
20273	2020-04-16 23:35:11	2020-04-16	Kamden Grady-Heaney	kamden.grady.heaney@geemail.com	Vallejo	California	3112020417226796516	f4b46c55fed74cdb7ca80c69607fb0be	Voyager	38.0370437323205195	-122.225396422609677
20274	2020-04-16 23:43:15	2020-04-16	Robin Prohaska	robin.prohaska@geemail.com	Oakland	California	4326018740809982	e31050e7d7f9e6246ea66cb5ce92ff51	American Express	37.8467900138725426	-122.255726496220419
20275	2020-04-16 23:49:28	2020-04-16	Orah Dickens	orah.dickens@geemail.com	Oakland	California	4436637929766940	8d819ac58c0e0695ba9229451e09a16f	American Express	37.7762166893705214	-122.252009941917834
20276	2020-04-16 23:56:23	2020-04-16	Blanch Pouros	blanch.pouros@woohoo.com	Boston	Massachusetts	676274811442180	bb0ceba2718cbff94069bf66cf2b201f	VISA 16 digit	42.2556636419314913	-70.9594884279135698
20277	2020-04-16 23:59:29	2020-04-16	Dr. Joana Morar DDS	dr.joana.morar.dds@geemail.com	Fontana	California	3096111437456436849	8cb749c5931eb6d99dbb6903d9e13381	JCB 16 digit	34.1669914521891656	-117.517744129923742
20278	2020-04-17 00:02:36	2020-04-17	Cinnamon Bartell	cinnamon.bartell@geemail.com	New Haven	Connecticut	54128321744549681	3edbe61f3fe17ea210b682394d4c8c45	VISA 16 digit	41.3322204813819383	-72.9876478489488392
20279	2020-04-17 00:12:42	2020-04-17	Reanna Luettgen	reanna.luettgen@geemail.com	New York	New York	869998101581324653	4411bc718d6dcc6b806ad18e2fe4d3a0	VISA 16 digit	40.7433709592316262	-73.9214375046908856
20280	2020-04-17 00:26:51	2020-04-17	Ramon Ortiz	ramon.ortiz@woohoo.com	New York	New York	6011583521974824260	d2a9c4c9ca1999cf58545a0e9c075337	JCB 16 digit	40.5654705280195884	-73.8531749905913983
20281	2020-04-17 00:34:24	2020-04-17	Dr. Kellan Hintz	dr.kellan.hintz@woohoo.com	San Francisco	California	55139140538680628	ff07d1defef2253507a6127645c3af66	Voyager	37.8007978971288452	-122.48418903919378
20282	2020-04-17 00:36:52	2020-04-17	Mrs. Raelyn Gleichner DDS	mrs.raelyn.gleichner.dds@geemail.com	Anchorage	Alaska	3045693384945488	ea9c857df3b56b5c7ecbd8a25cad6443	VISA 16 digit	61.1178334118548818	-149.380163964920854
20283	2020-04-17 00:42:26	2020-04-17	Deloris Mertz	deloris.mertz@geemail.com	Palm Bay	Florida	676346211740108	4f1493e61fa0049acaadcee4ba186e74	Voyager	27.9604314223252253	-80.6961335989948338
20284	2020-04-17 00:45:08	2020-04-17	Elinore Kozey	elinore.kozey@geemail.com	Honolulu	Hawaii	3420958140562534	5123c9f13b1ea9ca1ea62f79734bd9e0	JCB 15 digit	21.2851988167252415	-157.787087666729832
20285	2020-04-17 01:22:13	2020-04-17	Lavonda Lehner	lavonda.lehner@geemail.com	Indianapolis	Indiana	54134233221301225	31ca1c9694387b701feca0eb2d7b864f	American Express	39.7018458415295896	-86.0562350178804252
20286	2020-04-17 01:38:06	2020-04-17	Annika Bosco-Lang	annika.bosco.lang@geemail.com	Jurupa Valley	California	52101207208041987	99c0c87497e79f665e5329cafeb77267	American Express	33.9803397931553448	-117.37833014019057
20287	2020-04-17 01:51:53	2020-04-17	Eva Rogahn	eva.rogahn@geemail.com	Tucson	Arizona	3528183610694163895	b26faf6b9a44f10260d8c65ce75a8bf6	JCB 15 digit	32.1785948102869099	-110.94972557674572
20288	2020-04-17 02:09:57	2020-04-17	Loree Anderson	loree.anderson@geemail.com	Las Vegas	Nevada	6011039588369888812	7f045f1e54085daaf46601404ffa14bc	Mastercard	36.3164241195756929	-115.293993476193762
20289	2020-04-17 02:14:16	2020-04-17	Graydon Lind MD	graydon.lind.md@geemail.com	Chicago	Illinois	4238782076066890	422a59152fd7371e2c74dc183ef04720	Voyager	41.8778233873494017	-87.759573708058511
20290	2020-04-17 02:21:09	2020-04-17	Charlsie Runolfsdottir	charlsie.runolfsdottir@warmmail.com	Salem	Oregon	676159422278768	a6eb60f159047c103fec1d35088ac2e2	Discover	44.9307975475944517	-123.083751049793136
20291	2020-04-17 02:27:20	2020-04-17	Blanch Barrows-Ortiz	blanch.barrows.ortiz@geemail.com	Charleston	South Carolina	4883800967174082	927210a889e2cabc31709f3c205d9d8f	VISA 13 digit	32.8743185407944054	-79.9034692707620593
20292	2020-04-17 02:28:25	2020-04-17	Glenn McClure	glenn.mcclure@geemail.com	Las Vegas	Nevada	3036023188458075	b025c481eb4ec76afcbaf8d04edebb94	Mastercard	36.2403475900281222	-115.245830872582644
20293	2020-04-17 02:33:42	2020-04-17	Ms. Annamarie Brakus DVM	ms.annamarie.brakus.dvm@woohoo.com	San Francisco	California	869956089246453399	69be6cc46cf6fc56797e6a070fea7dd2	JCB 16 digit	37.7885892334202467	-122.399125542845283
20294	2020-04-17 02:34:41	2020-04-17	Marty Fritsch	marty.fritsch@geemail.com	Sacramento	California	3096876760674313390	f40201c1bd7ef99bcc790d8e5c8d7158	Mastercard	38.6325574073739375	-121.495223822003595
20295	2020-04-17 02:52:27	2020-04-17	Theo King	theo.king@warmmail.com	Atlanta	Georgia	3337242315153057302	a8698846959ec752371e7ee9607e01cf	Diners Club / Carte Blanche	33.707808967753877	-84.4549487877216194
20296	2020-04-17 03:09:36	2020-04-17	Flora Conn	flora.conn@geemail.com	Savannah	Georgia	4746949391274328	8cda242d1901fef9b51a0944da4e3e68	JCB 15 digit	32.0971514863986513	-81.0991366725567673
20297	2020-04-17 03:20:53	2020-04-17	Kallie Schiller PhD	kallie.schiller.phd@geemail.com	Killeen	Texas	4574536423758530	2b2a9cb5d6ba6758a1de1a2c8242e939	Discover	30.9865428973685937	-97.6810572120062943
20298	2020-04-17 03:21:44	2020-04-17	Mr. Eduardo Heathcote	mr.eduardo.heathcote@geemail.com	Los Angeles	California	4682126753719	5dc529b76963662f454d794a83b27a44	Mastercard	33.9632687041401837	-118.464838062551991
20299	2020-04-17 03:29:36	2020-04-17	Lonzo Brown PhD	lonzo.brown.phd@warmmail.com	Springfield	Massachusetts	180005647087880699	9e0fcf811bda63d742c94b85c0d2980a	Maestro	42.1274248479139004	-72.4908795035537423
20300	2020-04-17 03:37:15	2020-04-17	Miss Mitzi Lehner DVM	miss.mitzi.lehner.dvm@geemail.com	San Francisco	California	4315563908427955	9c65786ca18bd8a79aee77eae75c6639	VISA 16 digit	37.791449696654233	-122.44856571310828
20301	2020-04-17 03:39:52	2020-04-17	Annamae Sawayn	annamae.sawayn@geemail.com	Naperville	Illinois	6011822730856291446	87a5052af125718669e8e628fced4466	VISA 13 digit	41.7355485354464548	-88.2569637718033135
20302	2020-04-17 03:48:05	2020-04-17	Elam Block	elam.block@geemail.com	Madison	Wisconsin	4412057459401388	1e1240913c070d9793abbe77108a4a35	VISA 13 digit	43.1390246691621826	-89.331338371371487
20303	2020-04-17 03:48:28	2020-04-17	Codi Kreiger IV	codi.kreiger.iv@warmmail.com	New York	New York	869930603411292241	f76ced000fc15262c1ae127ee1d0868d	VISA 16 digit	40.585088535839688	-73.9324544308137064
20304	2020-04-17 03:48:46	2020-04-17	Frankie Toy	frankie.toy@geemail.com	San Francisco	California	4021574889776	245a44b455334db55ca9dc04a1d909d1	VISA 16 digit	37.7593303377465261	-122.371293121747655
20305	2020-04-17 04:11:54	2020-04-17	Lawson Cassin	lawson.cassin@geemail.com	Houston	Texas	4602116291333256	6c609184f13ac9e2329b5514a3a27261	JCB 16 digit	29.7152649854853763	-95.4475074524074785
20306	2020-04-17 04:16:02	2020-04-17	Arland Pagac	arland.pagac@woohoo.com	San Francisco	California	4801528924922	f5705ef35991a2d14d67e537e5778ed4	VISA 16 digit	37.7712437172974873	-122.466372730781345
20307	2020-04-17 04:24:21	2020-04-17	Vannie Sawayn-Roberts	vannie.sawayn.roberts@geemail.com	Richmond	Virginia	4010586986589659	dcd76abd0bb630276ac6143faf4692e2	American Express	37.4779712833218284	-77.3982216623369652
20308	2020-04-17 04:45:48	2020-04-17	Mrs. Alvina Little	mrs.alvina.little@geemail.com	Chicago	Illinois	53554691648470041	60ff37738c90fc21cc9d51997eca9302	Mastercard	41.8821128614548641	-87.6766522965423718
20309	2020-04-17 04:49:13	2020-04-17	Mrs. Rachel Morar DVM	mrs.rachel.morar.dvm@geemail.com	McKinney	Texas	3015295991412736	2b71f2801dfd3e03362ed947c2af6973	JCB 16 digit	33.1541513553950935	-96.7025312631689076
20310	2020-04-17 05:05:12	2020-04-17	Josue Ullrich-Bashirian	josue.ullrich.bashirian@geemail.com	Seattle	Washington	869965098790569277	7ebdbc33d7a4795b91bc6ee6fd6636c9	Maestro	47.7090571361985027	-122.421473444291948
20311	2020-04-17 05:16:13	2020-04-17	Connie Lehner	connie.lehner@geemail.com	Lancaster	California	6011695850975119064	ff8ebfa2465cf8f48b21f7a16464ca98	Voyager	34.7381730993989919	-118.081759291372435
20312	2020-04-17 05:17:36	2020-04-17	Madeleine Corwin	madeleine.corwin@geemail.com	San Francisco	California	180095306062051443	b1a587c063e50a95f7dbe6d22f5904a5	Diners Club / Carte Blanche	37.7842961358218972	-122.432422872803002
20313	2020-04-17 05:19:22	2020-04-17	Tana Nolan	tana.nolan@geemail.com	Columbus	Ohio	6011184802594519693	c21a3eaeda9b869341ada022b844be8b	VISA 13 digit	39.9495429770600055	-83.0717777869898839
20314	2020-04-17 05:28:00	2020-04-17	Maia Farrell-Lind	maia.farrell.lind@geemail.com	Seattle	Washington	4462374415924034	2496ac6d323203d7a5a0bec5fed6290a	JCB 16 digit	47.6390495391022384	-122.252932438805317
20315	2020-04-17 05:28:47	2020-04-17	Riley Kozey	riley.kozey@geemail.com	Philadelphia	Pennsylvania	3528691016553540279	192649b626f026f87e0ff8abb205a7f3	Mastercard	40.0648414771031582	-75.1748345873218113
20316	2020-04-17 05:29:02	2020-04-17	Dr. Maximilian Yundt	dr.maximilian.yundt@geemail.com	San Diego	California	4015758207458775	b2e6e973ba20624df2dc82a5b770fc0f	JCB 15 digit	32.8711437591884277	-117.212867666538813
20317	2020-04-17 05:32:32	2020-04-17	Jarvis DuBuque	jarvis.dubuque@geemail.com	Garden Grove	California	6011718760063079760	4b08d116fedbcb91a1d3a422357b44d1	Voyager	33.8578231863036692	-117.899283618947493
20318	2020-04-17 05:33:26	2020-04-17	Stoney Hegmann	stoney.hegmann@geemail.com	Seattle	Washington	675968751998615	efde295c64da3537ab8be8408115ccee	Maestro	47.6709354910459382	-122.318427260631324
20319	2020-04-17 05:35:05	2020-04-17	Dr. Altha Baumbach	dr.altha.baumbach@geemail.com	Orlando	Florida	501848187820856	1b1cb5bc52ce75f9ec1552023664e48a	Maestro	28.3770624576866624	-81.1738165391109874
20320	2020-04-17 05:38:45	2020-04-17	Bo Braun-Ritchie	bo.braun.ritchie@geemail.com	Philadelphia	Pennsylvania	3096397617979321884	27290bc3ac3a8f53958ed6a8486b9731	JCB 16 digit	40.0771316351328011	-75.2204841339860195
20321	2020-04-17 05:44:48	2020-04-17	Jean Frami	jean.frami@warmmail.com	Downey	California	869931781290171154	59f7665c076cb31a246aa44dfb35e60e	JCB 15 digit	33.9836282415565094	-118.155270098439971
20322	2020-04-17 06:01:04	2020-04-17	Montana Herman	montana.herman@woohoo.com	New York	New York	4519001366441	5bd33e3831bf92c93343d90683e871c6	Mastercard	40.6609027374759293	-74.0308304907649699
20323	2020-04-17 06:28:08	2020-04-17	Hjalmer Feeney-Mraz	hjalmer.feeney.mraz@geemail.com	Elgin	Illinois	3456107964659326	325619af629852571e28145e0e7c2d94	VISA 16 digit	41.953677252103013	-88.3039909002658021
20324	2020-04-17 06:34:51	2020-04-17	Eleonora Rolfson DVM	eleonora.rolfson.dvm@woohoo.com	Tucson	Arizona	55611086800187742	e63897619cfd2b31d90fe69869af3fa7	Discover	32.1521868138615048	-110.855508856172108
20325	2020-04-17 06:37:13	2020-04-17	Kristoffer Lang	kristoffer.lang@geemail.com	Washington	District of Columbia	3112532831124304978	3b3e51033a22af6dd482b04d09a586bb	Diners Club / Carte Blanche	38.9044090563695875	-77.0543994073037055
20326	2020-04-17 06:47:35	2020-04-17	Miss Sienna Friesen DDS	miss.sienna.friesen.dds@woohoo.com	Antioch	California	3769585462749183	878e7c670461caddd527c20da0f1218f	Maestro	37.9982504017915588	-121.816531789366906
20327	2020-04-17 06:49:35	2020-04-17	Kizzy Thiel PhD	kizzy.thiel.phd@geemail.com	San Francisco	California	3471607290526090	2ab0865b85cd55270ad7a01698c2e78d	VISA 13 digit	37.7672585035437152	-122.420298229299689
20328	2020-04-17 06:54:42	2020-04-17	Mell Corkery	mell.corkery@geemail.com	San Francisco	California	6011952486366007192	ff9bcc2b24a0a44caab3d0de61863cdc	JCB 16 digit	37.8175474558129849	-122.407991822441929
20329	2020-04-17 06:59:28	2020-04-17	Mrs. Elaina Bode	mrs.elaina.bode@woohoo.com	Allen	Texas	180035136733635750	fa0674b379686aa98fd4a0d78c2b26d6	Discover	33.0609320884130895	-96.667481210030985
20330	2020-04-17 07:05:58	2020-04-17	Madelynn Jast MD	madelynn.jast.md@woohoo.com	Oakland	California	52103791747407641	4b0a3d4abe2fa407d0c2bd626483a46e	JCB 16 digit	37.7911935834772805	-122.279577383445172
20331	2020-04-17 07:07:10	2020-04-17	Braden Beahan	braden.beahan@warmmail.com	Oakland	California	3337672733701265749	f9a73bec85f39e6241ae3e1388e44251	JCB 15 digit	37.8101397230874738	-122.270558783862725
20332	2020-04-17 07:21:42	2020-04-17	Marshall Leuschke	marshall.leuschke@warmmail.com	El Paso	Texas	502065199171789	68bbc47b8a895e4ebde0f34eef813fc3	VISA 16 digit	31.9217568116556869	-106.44355485746452
20333	2020-04-17 07:25:33	2020-04-17	Assunta Leannon	assunta.leannon@geemail.com	Long Beach	California	869995264380481406	529de14006fde2988880085d935d7f9f	VISA 13 digit	33.8011573968742027	-118.228661379932603
20334	2020-04-17 07:37:58	2020-04-17	Dr. Cortez Marquardt	dr.cortez.marquardt@woohoo.com	Gilbert	Arizona	3096661202724604808	fcda7016e65967944e21e63e940518e5	Voyager	33.2497020237028593	-111.801774090867866
20335	2020-04-17 07:46:48	2020-04-17	Dr. Terell Wisoky DVM	dr.terell.wisoky.dvm@geemail.com	Los Angeles	California	6011293022418379442	934df43a4de1c4de5fceaea7d7532b1d	JCB 15 digit	33.9752940418530258	-118.363132941722114
20336	2020-04-17 07:52:32	2020-04-17	Jesus Bogan	jesus.bogan@geemail.com	Phoenix	Arizona	3787820803930160	ac43e8b0daac503d4d928a8588f196ac	JCB 15 digit	33.5237372483525462	-112.126715812359379
20337	2020-04-17 07:54:30	2020-04-17	Alexis Breitenberg	alexis.breitenberg@geemail.com	Los Angeles	California	639088359910234	10cef1a406dee3a54591a4dc368f7694	VISA 16 digit	34.0534624932199677	-118.502693230378625
20338	2020-04-17 07:57:47	2020-04-17	Bette Welch	bette.welch@geemail.com	Berkeley	California	4808363247475	9e72eea420b75e33d2a265c858fe4cf4	American Express	37.8601568144828136	-122.280949707169384
20339	2020-04-17 08:08:54	2020-04-17	Dr. Art Murazik	dr.art.murazik@geemail.com	North Las Vegas	Nevada	4262974635898579	651e3f380d737b46077dd398e006b491	Discover	36.2392757469944655	-115.102169763877626
20340	2020-04-17 08:11:02	2020-04-17	Thompson Hayes	thompson.hayes@geemail.com	Indianapolis	Indiana	180058253729364980	0ea30be25e171a5457319d4a7d94ba75	Maestro	39.8659014697659728	-86.1225455734614229
20341	2020-04-17 08:12:19	2020-04-17	Miah Weimann	miah.weimann@geemail.com	Tyler	Texas	4717116470134220	f993dbb2b11568ce27f82535cdfd011b	Maestro	32.2777821830987932	-95.3139591458361508
20342	2020-04-17 08:32:16	2020-04-17	Mathias Conroy DDS	mathias.conroy.dds@woohoo.com	Dallas	Texas	6011497847864620780	5373dded43b028f86139e735c6d3fa23	Discover	32.7033296996999567	-96.7036403787285082
20343	2020-04-17 08:33:11	2020-04-17	Mrs. Marcy Hane	mrs.marcy.hane@geemail.com	Boston	Massachusetts	3528439379160140181	6e4739301a069cb6bac74a5fa4160351	VISA 13 digit	42.2838299303017564	-70.9441581052679595
20344	2020-04-17 08:38:09	2020-04-17	Dr. Ewart Boyle DVM	dr.ewart.boyle.dvm@woohoo.com	Norfolk	Virginia	4300107883799	e7338b99113b8aa9e110d08c81ac6faf	JCB 16 digit	36.9031823117304612	-76.153394103423139
20345	2020-04-17 08:39:44	2020-04-17	Huey Carter	huey.carter@woohoo.com	Topeka	Kansas	4818357048540054	6846eac3a55bb9425748474526174b1a	American Express	39.0118953077521198	-95.6854695069313124
20346	2020-04-17 08:45:51	2020-04-17	Mrs. Luda Mosciski DDS	mrs.luda.mosciski.dds@woohoo.com	San Angelo	Texas	4148443798308	e1b48fa49762624ed3662d9e6af69432	JCB 16 digit	31.4655451544713216	-100.354429858934139
20347	2020-04-17 08:48:06	2020-04-17	Tricia Lehner	tricia.lehner@woohoo.com	San Diego	California	4023586373385	b49b001b314d7631f6bc89a8d827d1b2	VISA 16 digit	32.8952550750758519	-117.084758584285154
20348	2020-04-17 09:04:27	2020-04-17	Mrs. Itzel Zieme	mrs.itzel.zieme@geemail.com	New York	New York	3740684360943818	82e9a17eee547e6f744d1a7dc30c83a2	JCB 15 digit	40.5853190681654965	-73.9777476716682258
20349	2020-04-17 09:13:19	2020-04-17	Mr. Horatio Yost DDS	mr.horatio.yost.dds@geemail.com	Los Angeles	California	676345450081844	549b8d7e5326ebb6bcbcada60d0a2b1a	VISA 13 digit	34.0334100784599727	-118.389541759201506
20350	2020-04-17 09:31:11	2020-04-17	Rosey McCullough	rosey.mccullough@warmmail.com	Anaheim	California	3112277821156374998	7c40bcfda362bd317766567f24a6cb15	American Express	33.7622069712094941	-117.84248386628218
20351	2020-04-17 09:32:26	2020-04-17	Hillery Connelly	hillery.connelly@geemail.com	Kansas City	Missouri	4319391735691965	778e41f35d76efcda71fc2cc28888384	Mastercard	39.1947978861000408	-94.5476718497220503
20352	2020-04-17 09:36:17	2020-04-17	Elianna Stoltenberg-Bednar	elianna.stoltenberg.bednar@geemail.com	Los Angeles	California	3528861500630933734	aceb3242bbe6cf4f5ea8f38605d35ea4	VISA 16 digit	34.0687130101356601	-118.508309453957892
20353	2020-04-17 09:46:28	2020-04-17	Mrs. Danae Goodwin PhD	mrs.danae.goodwin.phd@geemail.com	Berkeley	California	4722193873381339	c7d41001233d06f5f018bfccede37922	Mastercard	37.8424612102011295	-122.272093516185592
20354	2020-04-17 09:50:08	2020-04-17	Risa Gorczany-Mertz	risa.gorczany.mertz@geemail.com	Thornton	Colorado	3494295450287860	196905bab748009f179874bd407b58c3	Voyager	39.8373772762581737	-104.856039940814682
20355	2020-04-17 09:50:39	2020-04-17	Maralyn Legros	maralyn.legros@geemail.com	Gilbert	Arizona	060485592453055	3bad87c137ed30b54f50fa4e2701a1c2	JCB 16 digit	33.3281758468478913	-111.690793802975122
20356	2020-04-17 09:53:00	2020-04-17	Amirah Rau-Jakubowski	amirah.rau.jakubowski@woohoo.com	Omaha	Nebraska	869973585326304674	c78a6cd3ef35396a4c7e6f600f9639c4	VISA 16 digit	41.2627962915837756	-96.0715168867841385
20357	2020-04-17 09:56:21	2020-04-17	Nannette Hegmann	nannette.hegmann@geemail.com	San Francisco	California	54926842429958024	1d9b381e80008d55862a29993067044b	VISA 13 digit	37.7887637747866165	-122.469673706872612
20358	2020-04-17 10:01:15	2020-04-17	Sheena Wilderman	sheena.wilderman@warmmail.com	San Francisco	California	3428498485390839	aa33deee5e35a4e7962080221918c467	VISA 16 digit	37.7465773798110291	-122.416756598269359
20359	2020-04-17 10:19:21	2020-04-17	Braden Trantow	braden.trantow@geemail.com	Albuquerque	New Mexico	869988644911584753	bab0134f0f4727e977cb60be887814fb	JCB 16 digit	35.1874685356061931	-106.599444272283094
20360	2020-04-17 10:35:10	2020-04-17	Brad Halvorson	brad.halvorson@geemail.com	Columbus	Ohio	210079767697540318	9b888e5d7fb45eb6ec7857062edc7d8a	Diners Club / Carte Blanche	40.045961610791089	-82.9438142413508217
20361	2020-04-17 10:35:40	2020-04-17	Durwood Vandervort	durwood.vandervort@woohoo.com	San Francisco	California	869991290171738096	90186a882487a28e752ddbd23b560ad2	American Express	37.7831224746320373	-122.442634705465196
20362	2020-04-17 10:39:58	2020-04-17	Miss Floy Muller	miss.floy.muller@geemail.com	Philadelphia	Pennsylvania	869994472004739213	29a45265e3294406d81d2b559a9d3527	Voyager	40.1073373707436005	-75.1904530802175515
20363	2020-04-17 11:04:28	2020-04-17	Santana Will-Lemke	santana.will.lemke@geemail.com	Memphis	Tennessee	4961036602665	9d47dba536e26b04ae0135e7dc9c7b56	Mastercard	35.1741079803623293	-90.0482072636742146
20364	2020-04-17 11:05:12	2020-04-17	Dr. Donny Rau I	dr.donny.rau.i@geemail.com	Los Angeles	California	630408413050629	e72d4196ca345230d30479992ddba9fb	JCB 15 digit	34.0375658666580918	-118.397225142269576
20365	2020-04-17 11:15:41	2020-04-17	Bertha Bosco	bertha.bosco@warmmail.com	Westminster	Colorado	3419927987235986	0ada6c76ea15136a60c95e41a7d959da	VISA 16 digit	39.8492634750742454	-105.011546754805011
20366	2020-04-17 11:22:37	2020-04-17	Graciela Bins	graciela.bins@geemail.com	San Jose	California	3528543643468162079	5712cd43dc76ec83ca665e28d93b9e89	Voyager	37.3327268518794355	-121.796584078691524
20367	2020-04-17 11:26:22	2020-04-17	Malorie Gulgowski	malorie.gulgowski@geemail.com	Columbus	Ohio	4620755680418802	49ff0f235f92ed03eeb329b57eb2baa5	JCB 16 digit	40.0223813420206298	-82.9584142670270097
20368	2020-04-17 11:27:09	2020-04-17	Hurley Mertz	hurley.mertz@geemail.com	San Diego	California	676117082878913	fbba6cce4016ddd6243007f801747b3f	VISA 16 digit	32.7847496220909065	-117.140446988949563
20369	2020-04-17 11:31:19	2020-04-17	Bettina Hodkiewicz	bettina.hodkiewicz@woohoo.com	Miami Gardens	Florida	4271231764955103	0af88c4e67ecc2e58aea036aff85c940	VISA 16 digit	25.9941199775259939	-80.3275400148484806
20370	2020-04-17 11:38:13	2020-04-17	Demario Lindgren	demario.lindgren@geemail.com	Huntsville	Alabama	4429810433654394	483c3a4a2128b97fceac4ffbaa9197b2	VISA 13 digit	34.6895754852108666	-86.5988121840190104
20371	2020-04-17 11:41:07	2020-04-17	Albertha Macejkovic	albertha.macejkovic@geemail.com	Aurora	Illinois	3010434899742861	e09aa824289454a6027406374aba82ea	JCB 16 digit	41.8542038691919274	-88.3534964386768564
20372	2020-04-17 11:49:54	2020-04-17	Joette Rolfson	joette.rolfson@geemail.com	Milwaukee	Wisconsin	210095743033002958	79822902552ec5b0110d4e2c560a46eb	Diners Club / Carte Blanche	43.1370578186672162	-88.0459163634207158
20373	2020-04-17 12:02:23	2020-04-17	Remy Kunde	remy.kunde@geemail.com	San Francisco	California	6011721528152055560	76721d3ee2ebcc275cda14f79dc9df3f	JCB 15 digit	37.7545687541282007	-122.434475764699982
20374	2020-04-17 12:03:01	2020-04-17	Ms. Mabelle Luettgen	ms.mabelle.luettgen@geemail.com	Las Vegas	Nevada	3158426936846884550	1b7b60b33ada774ce3af188906e494f3	Mastercard	36.1692313746184126	-115.318761618456236
20375	2020-04-17 12:07:56	2020-04-17	Selena Steuber PhD	selena.steuber.phd@warmmail.com	Charlotte	North Carolina	3435865716982918	a6faf63b6e8d0eef54e53bda52498f2f	JCB 16 digit	35.1708035144742581	-80.7448945848681063
20376	2020-04-17 12:18:17	2020-04-17	Arbie Stiedemann-Weissnat	arbie.stiedemann.weissnat@woohoo.com	Wichita Falls	Texas	561230679337318	f8998d483e86d48752aaf2f6fbf64dae	JCB 16 digit	33.8082688379295178	-98.4663888359829684
20377	2020-04-17 12:20:49	2020-04-17	Wiliam Corwin MD	wiliam.corwin.md@geemail.com	Allentown	Pennsylvania	869992316148447195	6811273a5679b173bf109a40a0cd0ad9	JCB 16 digit	40.66953638584949	-75.5546642065063025
20378	2020-04-17 12:37:49	2020-04-17	Keenan Hand III	keenan.hand.iii@geemail.com	Richardson	Texas	869902957722857165	5d239b0f73f31d5458bd312a3093abf6	JCB 16 digit	33.0541554976955041	-96.7152238419041055
20379	2020-04-17 12:51:55	2020-04-17	Marylouise Quitzon	marylouise.quitzon@woohoo.com	San Francisco	California	6011893331551018756	cae247cc4465a7e1875832e5ba48841a	Discover	37.8117743806271633	-122.440681579007176
20380	2020-04-17 12:55:23	2020-04-17	Lynsey Stroman MD	lynsey.stroman.md@woohoo.com	Los Angeles	California	3096131891633818871	622ec19b74445854d3619187e5a0baf2	Voyager	34.1122184891119602	-118.39283631676733
20381	2020-04-17 12:58:35	2020-04-17	Dr. Tinie Zieme DVM	dr.tinie.zieme.dvm@woohoo.com	Albuquerque	New Mexico	55353855215746629	ce81d59a8daed88a3bc2d54fe09c3624	American Express	35.0100121654704211	-106.645490527579199
20382	2020-04-17 13:04:17	2020-04-17	Solon Beatty-Fisher	solon.beatty.fisher@geemail.com	Orange	California	869997016157325705	823312417739506ac084e41a5c64be79	JCB 16 digit	33.690606740757822	-117.761330466634774
20383	2020-04-17 13:24:27	2020-04-17	Dallin Harris	dallin.harris@geemail.com	Laredo	Texas	4105266220865688	fb36e071a6e5f5facfa5d78734ae10be	Mastercard	27.5018109433535507	-99.5521673628136483
20384	2020-04-17 13:46:24	2020-04-17	Rettie Rodriguez	rettie.rodriguez@geemail.com	Orange	California	3337508013601514722	2a3b2bdf1d56178cc6ead4a5e52f852e	VISA 16 digit	33.8858597295712656	-117.946536850986263
20385	2020-04-17 13:57:16	2020-04-17	Lana Hilpert	lana.hilpert@geemail.com	New York	New York	3337684837367894431	129cee66476e12954fc9ebeea4e99d3e	Maestro	40.5819967732056952	-74.0198070565599977
20386	2020-04-17 14:07:12	2020-04-17	Miesha Koch	miesha.koch@geemail.com	San Francisco	California	54054678566685531	892ce99fe00e53f6657f4050001d3edf	VISA 16 digit	37.8110162465357078	-122.412203811300046
20387	2020-04-17 14:10:07	2020-04-17	Dr. Drema Hammes	dr.drema.hammes@woohoo.com	Clovis	California	6011053738784925167	cf6804a18f5e0205211a1791c8f8192a	JCB 16 digit	36.8325842346873173	-119.645018351550775
20388	2020-04-17 14:10:23	2020-04-17	Mr. Othel Kemmer III	mr.othel.kemmer.iii@geemail.com	Toledo	Ohio	6011161913165534982	18023af56696ab6ef41ae976da11bc56	Mastercard	41.7449974012266836	-83.6098233001172559
20389	2020-04-17 14:11:15	2020-04-17	Christian Shanahan	christian.shanahan@geemail.com	Carrollton	Texas	4776775832495252	9a23c37e23a06ffbb4d0db2d172e15a4	Discover	33.027361876742539	-96.9840051892541339
20390	2020-04-17 14:15:36	2020-04-17	Aiden Howe III	aiden.howe.iii@warmmail.com	New York	New York	3088326379850947065	d68389e883bc6fde9c2884506d18f46c	VISA 13 digit	40.6982718174569271	-73.8934383306548028
20391	2020-04-17 14:16:41	2020-04-17	Hosie Connelly	hosie.connelly@warmmail.com	Oakland	California	3088178427368456084	5ed98cd5672c1d0c39acaf8b1a9eaaca	JCB 15 digit	37.7992435362617485	-122.257391025467783
20392	2020-04-17 14:26:43	2020-04-17	Dr. Beverlee McKenzie MD	dr.beverlee.mckenzie.md@woohoo.com	Independence	Missouri	4736648305303106	3f1527a5e12f50518bfc3eeb5e840411	Mastercard	39.0880469188112798	-94.3592157134603582
20393	2020-04-17 14:41:32	2020-04-17	Shaneka Hoppe	shaneka.hoppe@geemail.com	Kansas City	Missouri	4590341840780195	e0d197b5d443c6abb5885381266b4418	VISA 16 digit	39.0534546989783706	-94.5096551477201245
20394	2020-04-17 14:46:43	2020-04-17	Fidencio Mills-Hudson	fidencio.mills.hudson@geemail.com	Lincoln	Nebraska	3010780721629118	b77b85b1e07a16bcf66c5639e065ca44	VISA 16 digit	40.7375357211120388	-96.6161053499832718
20395	2020-04-17 14:47:54	2020-04-17	Eulalie O'Conner	eulalie.o'conner@geemail.com	Chicago	Illinois	6011299268668469573	f70a869df012adb31859be72c9b138cc	Diners Club / Carte Blanche	41.9303627313882146	-87.7803176726244345
20396	2020-04-17 15:11:01	2020-04-17	Vesta Mills-Jaskolski	vesta.mills.jaskolski@geemail.com	Houston	Texas	4848587530034968	5a87218d3ef4c1cc31e74ca8355a0fa9	VISA 13 digit	29.8614174149077378	-95.4824219686459799
20397	2020-04-17 15:16:20	2020-04-17	Amaris Mills	amaris.mills@geemail.com	Buffalo	New York	4424601960682394	345e16a7f7a2327157cee782b7b28b5e	JCB 16 digit	42.8842384328786252	-78.9303970280967633
20398	2020-04-17 15:30:23	2020-04-17	Darryl Cremin I	darryl.cremin.i@warmmail.com	McKinney	Texas	6011878894311311661	a65fb5007f1e258d957e7c3b92f57a4d	Maestro	33.1795845913831187	-96.7415350291710467
20399	2020-04-17 15:45:46	2020-04-17	Zigmund Sporer-Murazik	zigmund.sporer.murazik@geemail.com	Chandler	Arizona	6011861950949319820	7c191239927829ba8e768f3b9b08be2a	JCB 16 digit	33.2372922349344933	-111.890822305611891
20400	2020-04-17 15:46:03	2020-04-17	Evangelina Waelchi	evangelina.waelchi@geemail.com	New York	New York	4042802359860870	ad21e097290a31b7c06f6ddd7fc8e870	Discover	40.7488640631772583	-74.0278705863177748
20401	2020-04-17 15:56:12	2020-04-17	Jessie Will	jessie.will@geemail.com	San Francisco	California	676239137191456	74878436e2dbcbeffa11ed2dffe08fff	Diners Club / Carte Blanche	37.7850946889370931	-122.432926802545367
20402	2020-04-17 16:08:09	2020-04-17	Jazlynn Howe-Wolff	jazlynn.howe.wolff@geemail.com	Oakland	California	3492056610378805	d178a16a10bdc61b6629f01edaa04bd6	VISA 16 digit	37.8078880392233074	-122.263072265120215
20403	2020-04-17 16:09:53	2020-04-17	Colton Erdman	colton.erdman@geemail.com	Chicago	Illinois	869954117378452608	c13402d93b2a5a3835548a88695b29eb	American Express	41.8468125019989898	-87.7303032920259938
20404	2020-04-17 16:25:25	2020-04-17	Dr. Reinhold Hills	dr.reinhold.hills@geemail.com	Oakland	California	869916135620916292	095ef0fd4add91f74ac702349780b630	JCB 16 digit	37.7943211905172447	-122.289994793173719
20405	2020-04-17 16:31:42	2020-04-17	Kirstin Lynch	kirstin.lynch@geemail.com	Newark	New Jersey	210044638964234160	580c64fc33c53a14cdc0502fe0e3397e	American Express	40.6672586009286405	-74.2685127417765614
20406	2020-04-17 16:36:12	2020-04-17	Dr. Darla Kuhn DDS	dr.darla.kuhn.dds@geemail.com	Sioux Falls	South Dakota	51200007510330809	d16258c35c00ecd745dc4c728e8d611a	JCB 15 digit	43.5360527027949686	-96.8281116140242659
20407	2020-04-17 16:38:00	2020-04-17	Ms. Layla Rohan	ms.layla.rohan@geemail.com	Seattle	Washington	210081988718095324	3fad93fa6d519d88a7067e824a9c3fd6	JCB 16 digit	47.664651514954862	-122.36161995305828
20408	2020-04-17 16:39:37	2020-04-17	Malinda Cassin	malinda.cassin@woohoo.com	San Francisco	California	3112630895650829337	0fdc87a6d1c3d0575a530f881f446ac9	JCB 16 digit	37.7771521314958747	-122.437103779461211
20409	2020-04-17 16:52:50	2020-04-17	Thaddeus Rolfson IV	thaddeus.rolfson.iv@geemail.com	West Valley City	Utah	3088093486387330482	93be562387b2b5d03be1d2d3e2bfb98d	Maestro	40.6316925995741016	-112.083500556296855
20410	2020-04-17 16:57:31	2020-04-17	Lavon Gerhold	lavon.gerhold@geemail.com	Mesa	Arizona	3444447430202326	8e1ca663c391ec6a4a4eaa2d48747e36	Discover	33.4325121737696236	-111.742354972323028
20411	2020-04-17 17:16:17	2020-04-17	Miss Katarina Barrows	miss.katarina.barrows@geemail.com	Elizabeth	New Jersey	3736311842554619	14531ca66567451db2701b4f91d60bd7	Mastercard	40.7251833496276348	-74.2910676217116475
20412	2020-04-17 17:22:41	2020-04-17	Tab Murphy	tab.murphy@geemail.com	Los Angeles	California	869919654032910336	ebf997647fb86618106e99497b6668e6	Maestro	34.0361033807374511	-118.396593668497346
20413	2020-04-17 17:25:02	2020-04-17	Arden Ortiz-Koepp	arden.ortiz.koepp@warmmail.com	San Francisco	California	51945456575363603	041c073d5e381ba2133c18ce723b19a6	VISA 16 digit	37.7854892467449019	-122.444788708605017
20414	2020-04-17 17:56:23	2020-04-17	Dr. Catharine Cruickshank	dr.catharine.cruickshank@woohoo.com	Shreveport	Louisiana	54075110915110834	c8d4d8a1feae36b6b341689f325e114f	Maestro	32.5115004732977653	-93.7447786404032257
20415	2020-04-17 18:06:20	2020-04-17	Delano Block-Lang	delano.block.lang@warmmail.com	New York	New York	501805805622817	736f0b07e529a334c54d9abe1274f3da	JCB 15 digit	40.7595404403507686	-73.8613751740556239
20416	2020-04-17 18:09:10	2020-04-17	Mr. Alger Wolf I	mr.alger.wolf.i@geemail.com	Springfield	Missouri	6011189504586914800	b3c18eb5566cf8d148738d43152711bb	VISA 16 digit	37.119199725166709	-93.2895028071768593
20417	2020-04-17 18:09:42	2020-04-17	Dr. Elder Bailey	dr.elder.bailey@warmmail.com	Kansas City	Missouri	55576380694554122	2aa77d18dae3acb6055f680dbac74e1a	Diners Club / Carte Blanche	39.1065713609404924	-94.5746454571131636
20418	2020-04-17 18:23:56	2020-04-17	Jacqulyn Waters	jacqulyn.waters@geemail.com	San Francisco	California	3088088437220203516	8064f92b45acd87a9253ebbbac344a92	Voyager	37.7860234483922497	-122.436283102593947
20419	2020-04-17 18:56:25	2020-04-17	Mr. Obe Ziemann V	mr.obe.ziemann.v@geemail.com	Philadelphia	Pennsylvania	210055481648425433	4b1a04777eae28f7394f2787b7df8f13	Voyager	39.9953031545463915	-75.1587154371097768
20420	2020-04-17 19:20:46	2020-04-17	Durward Prosacco	durward.prosacco@geemail.com	Colorado Springs	Colorado	4271202822973917	5cba7b260109620943132e4398b56b1b	Diners Club / Carte Blanche	38.9008767124779524	-104.805566158068174
20421	2020-04-17 19:24:35	2020-04-17	Dr. Cordero Moen	dr.cordero.moen@geemail.com	Stockton	California	4456958657253249	ad38316d660a8622541eb13017151d13	VISA 13 digit	37.9042938785359311	-121.28131789361052
20422	2020-04-17 19:25:01	2020-04-17	Mr. Branden Monahan	mr.branden.monahan@geemail.com	Los Angeles	California	54072267990200378	8e0a89795a01dac4f4b167fefd90f152	VISA 16 digit	34.0996183212246748	-118.326377143477274
20423	2020-04-17 19:36:02	2020-04-17	Miss Raelynn Jacobi DDS	miss.raelynn.jacobi.dds@geemail.com	Salinas	California	54432497347934891	b2590fee3113b4942e31da2b430c5f82	American Express	36.6793900962218586	-121.674024836876242
20424	2020-04-17 19:43:35	2020-04-17	Homer Wunsch	homer.wunsch@geemail.com	Las Cruces	New Mexico	3112404594740821974	931836a1f27263cce929ba032a208014	JCB 15 digit	32.2707837665487105	-106.716458261630308
20425	2020-04-17 19:53:09	2020-04-17	Dr. Arra Hartmann DVM	dr.arra.hartmann.dvm@geemail.com	Victorville	California	51821181652110524	2e31825df15d6957229e3370832d63d8	VISA 16 digit	34.5980977782279311	-117.360213466609267
20426	2020-04-17 19:56:04	2020-04-17	Mr. Damarcus Schmidt	mr.damarcus.schmidt@geemail.com	Arvada	Colorado	6011319055974918575	37e8171cabe8c99d95fda0de781bd0b9	Discover	39.9326189378451559	-105.143708307060606
20427	2020-04-17 19:59:12	2020-04-17	Mykel Beier	mykel.beier@geemail.com	San Antonio	Texas	4735159253252	4e3d50d57a236efe64b70660ec0e5847	VISA 13 digit	29.5209914170742032	-98.578942778969548
20428	2020-04-17 20:05:32	2020-04-17	Dr. Edmonia Toy DVM	dr.edmonia.toy.dvm@geemail.com	Kansas City	Missouri	4366941097445665	9a28968c2205a0a964097cb44156220c	JCB 16 digit	39.0436167301911894	-94.5855561156980684
20429	2020-04-17 20:07:58	2020-04-17	Mr. Loney Lind V	mr.loney.lind.v@woohoo.com	Westminster	Colorado	6011415229334897760	3cc63b6765a70af68d5948dc1d37269e	American Express	39.8196243384227131	-105.16430954264068
20430	2020-04-17 20:11:12	2020-04-17	Denisha Osinski	denisha.osinski@woohoo.com	New York	New York	180082916836132256	7c5a3e48866cd4259a7627c3ecf2aaaf	JCB 16 digit	40.7265232235416761	-73.9817448174010934
20431	2020-04-17 20:16:02	2020-04-17	Trace Davis	trace.davis@warmmail.com	San Francisco	California	4910613407791580	3e1bda20fdad6e6a9de169a08130aaff	Maestro	37.768383281925459	-122.425122739776114
20432	2020-04-17 20:20:24	2020-04-17	Dottie Kovacek	dottie.kovacek@geemail.com	Boulder	Colorado	4025606096688812	ee3008d92aa9959417953d274b7120b0	JCB 15 digit	39.9579477477800111	-105.349643134293714
20433	2020-04-17 20:22:49	2020-04-17	Orren Murazik	orren.murazik@geemail.com	New York	New York	4602767286607573	816b8e9b0d8f8bd4be4c3299f014dfe5	JCB 16 digit	40.5822114926520712	-73.9575551146537009
20434	2020-04-17 20:25:46	2020-04-17	Dayne Bernhard DVM	dayne.bernhard.dvm@geemail.com	New York	New York	210054695839668581	b974b181d7fd2cc8b923e1a35140bf9e	Maestro	40.7198321556895948	-73.939514371323213
20435	2020-04-17 20:30:28	2020-04-17	Clabe Cassin	clabe.cassin@geemail.com	Sunnyvale	California	180043991933083874	b716b6083eaeb20a161f40c50589797c	VISA 16 digit	37.3653488063711734	-122.097699014769134
20436	2020-04-17 20:32:09	2020-04-17	Jagger Turcotte-Okuneva	jagger.turcotte.okuneva@geemail.com	Round Rock	Texas	3022304112837111	fedbfa2ca2cdf56d9fe98ac4e3f74167	Voyager	30.5845270656187118	-97.6320292809363366
20437	2020-04-17 20:37:05	2020-04-17	Dominik Lebsack	dominik.lebsack@geemail.com	Vancouver	Washington	869927155396413156	8475a7347502c1c1b401c55e9956272f	Voyager	45.6748294905364531	-122.565530995611837
20438	2020-04-17 20:37:40	2020-04-17	Dr. Malcom Waters IV	dr.malcom.waters.iv@geemail.com	New York	New York	4807275627360	cfd78c4fd5a6a941309b7be1b0b71472	Maestro	40.7392677667774237	-73.9472816715378229
20439	2020-04-17 20:48:11	2020-04-17	Meghann Hermiston	meghann.hermiston@woohoo.com	Chesapeake	Virginia	6011772810432721627	d32febfd8600e64296ed6ff60caf8eb5	JCB 16 digit	36.7543255786649894	-76.3485037356924323
20440	2020-04-17 20:49:04	2020-04-17	Brandy Kerluke IV	brandy.kerluke.iv@geemail.com	Fort Worth	Texas	3112736070838226375	d4227e173e5e4a81b3e68ed25714cdd3	JCB 15 digit	32.7046637150049193	-97.3927672878194528
20441	2020-04-17 21:12:15	2020-04-17	Lauryn Harvey-Sipes	lauryn.harvey.sipes@woohoo.com	Syracuse	New York	51073005229960282	ec84261a59ac33bd5786f5c5aeef764e	Maestro	43.091468945689499	-76.2098516223266813
20442	2020-04-17 21:26:08	2020-04-17	Rolf Conroy	rolf.conroy@geemail.com	Pembroke Pines	Florida	3710138071537779	dea3f7f1972bebbb9c8d5cba7e1dbfb0	VISA 16 digit	26.0625056174621008	-80.400997262252119
20443	2020-04-17 21:36:33	2020-04-17	Bluford Stoltenberg	bluford.stoltenberg@geemail.com	Gainesville	Florida	54558448074458354	dd2a67ec771253833416db6a40557f3f	JCB 15 digit	29.7019182614341375	-82.2630817473739455
20444	2020-04-17 21:37:11	2020-04-17	Mr. Augustine Schuster	mr.augustine.schuster@woohoo.com	Austin	Texas	3112151136373967016	0f864ac97458f99fdfc1f46eda363d6b	Diners Club / Carte Blanche	30.2957880729936058	-97.7564352913998107
20445	2020-04-17 21:40:30	2020-04-17	Dr. Rishi Hahn	dr.rishi.hahn@geemail.com	New York	New York	869987968328287770	d0d4e66deb29f4012e70b8c678f3c522	Discover	40.5916823179218937	-73.9592334603786412
20446	2020-04-17 21:51:11	2020-04-17	Mr. Efren Gislason	mr.efren.gislason@geemail.com	Round Rock	Texas	210044830526503030	de0ab42e64db5be82309e39418ea4902	VISA 13 digit	30.582343830601129	-97.6568265606034487
20447	2020-04-17 21:54:57	2020-04-17	Ms. Jenelle Ratke MD	ms.jenelle.ratke.md@geemail.com	New York	New York	869916520827094623	c113672cd4293b9cb29dc23161abafa4	VISA 16 digit	40.6891409821100538	-73.8516759096540483
20448	2020-04-17 21:57:53	2020-04-17	Ferris Adams	ferris.adams@geemail.com	Oakland	California	180018335468673215	35387465e7a0badb976cf656c289f4a7	VISA 13 digit	37.8156263341117835	-122.298766975786648
20449	2020-04-17 22:16:19	2020-04-17	Terence Greenfelder-Homenick	terence.greenfelder.homenick@geemail.com	Fort Worth	Texas	210035074355293675	0763549e453ca70ab644b48269d84aca	VISA 13 digit	32.8679063528366413	-97.3656109561964911
20450	2020-04-17 22:18:09	2020-04-17	Jameel Davis	jameel.davis@geemail.com	San Francisco	California	180017701450174929	5a84e97b9bc1ce164cb8a7cb853f26b2	Discover	37.7742403574930137	-122.433179409053409
20451	2020-04-17 22:19:21	2020-04-17	Hilda Mante-Paucek	hilda.mante.paucek@geemail.com	Los Angeles	California	3112450627360312529	606e8304dad3e198fa08ce3f175bd1ae	JCB 15 digit	33.9697745232708712	-118.421806448511035
20452	2020-04-17 22:19:47	2020-04-17	Harvie Lynch	harvie.lynch@geemail.com	San Francisco	California	3088261956104349912	c65535a3002b1abc73e47c8d5ac8d383	Maestro	37.7973489359153376	-122.432296160597943
20453	2020-04-17 22:24:32	2020-04-17	Khalil Hermiston-Goodwin	khalil.hermiston.goodwin@geemail.com	Mesa	Arizona	676188657835737	36f6258fcc5173a0c1fd5a982554197e	Diners Club / Carte Blanche	33.4876174178585373	-111.733312283910436
20454	2020-04-17 22:30:00	2020-04-17	Salome Waelchi DVM	salome.waelchi.dvm@geemail.com	Lakewood	Colorado	180031735942035654	e5ab4e014a91a13f560af4873a862389	Voyager	39.7590964570116299	-105.112639278827601
20455	2020-04-17 22:52:54	2020-04-17	Isabel Mosciski	isabel.mosciski@woohoo.com	Shreveport	Louisiana	4567998731686846	ca0509578ea8863141e196669baca2af	Maestro	32.5292963492922524	-93.699774188616118
20456	2020-04-17 22:53:21	2020-04-17	Ballard Mosciski	ballard.mosciski@geemail.com	New York	New York	180053033882145946	9a3a88b1db966eb34bb6538d03878355	Maestro	40.6178084373231982	-73.9352450703166397
20457	2020-04-17 23:10:48	2020-04-17	Joette Deckow DDS	joette.deckow.dds@geemail.com	Fayetteville	North Carolina	180047058642650801	eb7ef7bbada1751ac4d18081572c6282	Diners Club / Carte Blanche	34.9926657566122685	-78.8930733548607748
20458	2020-04-17 23:19:37	2020-04-17	Vernita Maggio	vernita.maggio@geemail.com	Woodbridge	New Jersey	4593534624311	0b69c33f4d39b93aff17016e3286ab52	VISA 13 digit	40.4944022108491453	-74.210286497450241
20459	2020-04-17 23:19:43	2020-04-17	Ilona Turner	ilona.turner@woohoo.com	San Diego	California	4989666787671307	fa38097fd46bd9863d39ca6db5f90279	American Express	32.8236556853234802	-117.105254552690312
20460	2020-04-17 23:27:45	2020-04-17	Mr. Rosendo Farrell III	mr.rosendo.farrell.iii@geemail.com	Anchorage	Alaska	3088463714428148528	175c8e19f941fe16b6a104e2a39c0a9f	American Express	61.1250983356714244	-149.294959837676203
20461	2020-04-17 23:46:31	2020-04-17	Hassie Blanda	hassie.blanda@woohoo.com	San Francisco	California	4171106214348	9f415232166eace0a97071332eae7770	JCB 15 digit	37.7735509118229729	-122.445896082074341
20462	2020-04-18 00:09:44	2020-04-18	Orie Gibson PhD	orie.gibson.phd@woohoo.com	Albuquerque	New Mexico	869901090178676227	6af605e1be208d7d933950ebe75045ab	VISA 16 digit	35.1565894443675901	-106.671961467068272
20463	2020-04-18 00:21:24	2020-04-18	Mahlon Barrows	mahlon.barrows@geemail.com	San Francisco	California	53716990490106561	d058326873258a4d7d38e23ad4a131f8	VISA 16 digit	37.7912655932924366	-122.470898695527538
20464	2020-04-18 00:22:46	2020-04-18	Francesco Predovic	francesco.predovic@woohoo.com	Santa Clarita	California	4961905165776847	0a9f2d6ea168d37de30253d65c1f58af	Voyager	34.3173965450581164	-118.41507297452614
20465	2020-04-18 00:30:44	2020-04-18	Collins Swift	collins.swift@geemail.com	Seattle	Washington	4434648231530595	c68dee6148129e95f06053db71469494	Voyager	47.7087505033630848	-122.390826152816032
20466	2020-04-18 00:35:47	2020-04-18	Dr. Dillie Gulgowski	dr.dillie.gulgowski@woohoo.com	Denton	Texas	4551174941023	cda633e17ddb76eebed9b8081d93497a	VISA 16 digit	33.2784837072979656	-97.1320330633908497
20467	2020-04-18 00:40:37	2020-04-18	Dr. Robbin Bins	dr.robbin.bins@geemail.com	Pompano Beach	Florida	676203218854085	50e786ff7387c8428c7ae5e95c18a61d	Mastercard	26.2098228927966197	-80.1031587258759856
20468	2020-04-18 00:56:05	2020-04-18	Mrs. Miriah Schulist DVM	mrs.miriah.schulist.dvm@geemail.com	San Francisco	California	3096570817965307389	5230412fc41502bece1a912140e06cd4	American Express	37.7439159021688866	-122.448556323151422
20469	2020-04-18 00:59:55	2020-04-18	Ethyl Sipes	ethyl.sipes@geemail.com	Hollywood	Florida	3054475516035169	cfb9f1c3c65cb9e778a777a867962d21	Maestro	26.0611171370781953	-80.1080579035267135
20470	2020-04-18 01:08:09	2020-04-18	Carson Romaguera	carson.romaguera@woohoo.com	Cleveland	Ohio	4565777170558241	118c3518602d361a446b7037cfd06fc2	JCB 15 digit	41.3996767693981482	-81.5996880206983519
20471	2020-04-18 01:19:13	2020-04-18	Dr. Mathew Barton MD	dr.mathew.barton.md@geemail.com	New York	New York	4437408487349027	3f519ddef73df8deb7d60b21ac081ab4	Diners Club / Carte Blanche	40.6365089447926735	-74.01356148211174
20472	2020-04-18 01:24:49	2020-04-18	Eric Barrows	eric.barrows@warmmail.com	New York	New York	3042914275360972	105919bb5899078196b7daa4a3c6bcd2	VISA 16 digit	40.598983208065853	-73.9469255604211213
20473	2020-04-18 01:34:36	2020-04-18	Dr. Haleigh Erdman MD	dr.haleigh.erdman.md@geemail.com	Fort Worth	Texas	3056766731003422	a7c57cc7aaf20bd5565fd46244d27a6e	JCB 16 digit	32.878015486529101	-97.4444211566176222
20474	2020-04-18 02:07:03	2020-04-18	Lorin Batz	lorin.batz@geemail.com	Augusta	Georgia	3738739009241141	50c4f2a3ff0a727619bdbe538d239f11	American Express	33.4048245247192668	-81.9743237177204378
20475	2020-04-18 02:23:16	2020-04-18	Berniece Funk	berniece.funk@geemail.com	Los Angeles	California	3158450787395256578	a0f1b57eaa3960910c0a294c48d1e25a	American Express	33.9570344550866636	-118.352461548288531
20476	2020-04-18 02:28:26	2020-04-18	Mrs. Arianna Ortiz	mrs.arianna.ortiz@geemail.com	Kansas City	Missouri	180063219692617194	7c8cb42e332ad352bfbb3e252126858f	Discover	39.143903783599292	-94.6158442797828485
20477	2020-04-18 02:32:15	2020-04-18	Vita Dickens	vita.dickens@geemail.com	Oakland	California	3112778960128248809	f43e973e8b81d4c603dfb012688f3fa7	Discover	37.7931516326980486	-122.26739168934256
20478	2020-04-18 02:37:47	2020-04-18	Mr. Deryl Schiller DVM	mr.deryl.schiller.dvm@geemail.com	Pasadena	California	55299398033595230	c49d8c91af03d5941689a9f764ecf1fc	Mastercard	34.1835231232311614	-118.078898033621158
20479	2020-04-18 02:54:12	2020-04-18	Butler McClure	butler.mcclure@geemail.com	New Orleans	Louisiana	3032353981453252	14aaaf4bc635c915a23f859d19f06867	Voyager	30.080276800321041	-89.8556894789245035
20480	2020-04-18 04:00:04	2020-04-18	Cannie Sanford-Raynor	cannie.sanford.raynor@warmmail.com	Norman	Oklahoma	3528015254117292769	0e32993ad687ed68fcd532b9b29c1ef7	JCB 16 digit	35.2715549925848819	-97.3182365997016348
20481	2020-04-18 04:01:03	2020-04-18	Jaylan Beahan	jaylan.beahan@warmmail.com	Berkeley	California	4200161569115890	32549dd6710e13fc3a711b447affda94	Mastercard	37.8377395257158611	-122.259418772551271
20482	2020-04-18 04:01:17	2020-04-18	Sienna Ryan PhD	sienna.ryan.phd@woohoo.com	Green Bay	Wisconsin	3088490516805230945	75aeaa6dfddd01ec4d4e932451349802	Maestro	44.462831151398639	-87.9214937887441437
20483	2020-04-18 04:07:33	2020-04-18	Joseluis Lang	joseluis.lang@geemail.com	New York	New York	6011766362506785631	dd2fbcbd5fdea7fa334c67b2a07dcb6d	Voyager	40.63861283829808	-73.8881017763994663
20484	2020-04-18 04:48:06	2020-04-18	Elon Gulgowski	elon.gulgowski@geemail.com	Seattle	Washington	3158403906651024102	3ac74689a9438804a9be062e19840394	VISA 16 digit	47.5346543760895699	-122.418284108202528
20485	2020-04-18 05:03:25	2020-04-18	Mr. Eric Bailey	mr.eric.bailey@geemail.com	Athens	Georgia	6011066994204456581	c3c13742bb07edcdddbbe046841fd63a	JCB 16 digit	33.8668287162393327	-83.4229183963615384
20486	2020-04-18 05:04:37	2020-04-18	Mrs. Carlota Terry	mrs.carlota.terry@woohoo.com	Syracuse	New York	3056814892338151	b30374600e1be990e4a275fd39872d2d	VISA 16 digit	42.9772239282578212	-76.1860846014939312
20487	2020-04-18 05:08:43	2020-04-18	Carey Ebert	carey.ebert@geemail.com	Chesapeake	Virginia	869967162670368214	21f43aeafbf9b6f93df816d06e399dbe	VISA 16 digit	36.705861231661963	-76.3495078193798662
20488	2020-04-18 05:18:08	2020-04-18	Jammie Collins	jammie.collins@geemail.com	Bakersfield	California	6011781503599726856	e98082eccc646adab1468342c6b51699	Voyager	35.227363377361371	-118.950844907089319
20489	2020-04-18 05:20:09	2020-04-18	Lillie Hoppe	lillie.hoppe@geemail.com	Fairfield	California	210031751182920653	cc4552c13be4141fd03a1e7b5dee307a	JCB 16 digit	38.2608123196877585	-121.974995969189706
20490	2020-04-18 05:23:15	2020-04-18	Eveline Kunde	eveline.kunde@geemail.com	San Francisco	California	869974506799094450	90da52dddf8e5d99d9e235b488a5cd2f	Maestro	37.7523962103844042	-122.429642532923239
20491	2020-04-18 05:35:48	2020-04-18	Spring Harber	spring.harber@geemail.com	Westminster	Colorado	501829176036365	a412f4ca0834d544d9a6a1d5a0cadcfc	JCB 16 digit	39.9419081605344957	-104.992043507346523
20492	2020-04-18 05:49:38	2020-04-18	Gaye Gaylord	gaye.gaylord@geemail.com	Fort Worth	Texas	503820892549401	3aca9ca7eaded04634542ebcbad27122	JCB 15 digit	32.7728800033275078	-97.269991550530122
20493	2020-04-18 06:06:36	2020-04-18	Ronny Stamm	ronny.stamm@geemail.com	San Francisco	California	180088693772085210	a239e41fe771c643f2a0718c4a6a88d7	JCB 16 digit	37.7689699139030921	-122.438910218022002
20494	2020-04-18 06:10:37	2020-04-18	Rod Bashirian II	rod.bashirian.ii@geemail.com	New York	New York	4799091842385647	8564da959535ca2022bc3fefbd333490	Mastercard	40.58786161190271	-73.9067294882506047
20495	2020-04-18 06:13:13	2020-04-18	Linton Hoppe	linton.hoppe@woohoo.com	Joliet	Illinois	3088338238513568971	af47a95d4ce8ca21c90edcb587241094	American Express	41.4429557273488456	-88.0749987300589652
20496	2020-04-18 06:15:24	2020-04-18	Lukas Hilll DVM	lukas.hilll.dvm@geemail.com	New York	New York	869988704859853543	5474f8306648dbd167ebc87b48cff980	Mastercard	40.7062575959824002	-74.0286759934749483
20497	2020-04-18 06:21:04	2020-04-18	Dr. Kirstin Barrows MD	dr.kirstin.barrows.md@geemail.com	Springfield	Illinois	4368547159845821	5492603f569c8ba99446a89526abb9fc	JCB 16 digit	39.8093614722289146	-89.623722320190069
20498	2020-04-18 07:10:00	2020-04-18	Domenica Wolff-Baumbach	domenica.wolff.baumbach@geemail.com	Los Angeles	California	3747688278136251	12eea27f6b67130936cf7a9f928d7a27	Discover	33.9496188630215769	-118.400929130473358
20499	2020-04-18 07:19:49	2020-04-18	Fredrick Abernathy	fredrick.abernathy@woohoo.com	Waterbury	Connecticut	675935875924116	70817ba96917bdd0fb3ff69458e02180	JCB 16 digit	41.6428182609882214	-72.9591215662572523
20500	2020-04-18 07:20:56	2020-04-18	Mayra Doyle	mayra.doyle@woohoo.com	Jacksonville	Florida	869965166240108689	546f2833a9c3cc3643b1b40499aab333	JCB 16 digit	30.2901752796076238	-81.621520697705833
20501	2020-04-18 07:30:56	2020-04-18	Frona Windler	frona.windler@geemail.com	Tucson	Arizona	180029813266118598	0386db2f804f1c3ac5457ef352ec6e79	VISA 16 digit	32.1674929947633288	-110.9605865516927
20502	2020-04-18 07:47:13	2020-04-18	Nunzio Feeney	nunzio.feeney@geemail.com	Newark	New Jersey	3011251015591058	a2088ed15cb2b42525727541bc751cc4	VISA 13 digit	40.6953436078418065	-74.109878928235176
20503	2020-04-18 08:22:08	2020-04-18	Mr. Gaylord Gutkowski IV	mr.gaylord.gutkowski.iv@warmmail.com	San Francisco	California	4894318541385949	36589358852969fe17a8854886f44430	VISA 16 digit	37.7495134645308639	-122.443121042356864
20504	2020-04-18 08:24:17	2020-04-18	Howard Legros	howard.legros@geemail.com	San Francisco	California	6011155287175549068	4374d819541fa15eee9f9bd7ab8d9b2b	American Express	37.7610241809743812	-122.445448658689401
20505	2020-04-18 08:24:18	2020-04-18	Misty Barton	misty.barton@geemail.com	Newport News	Virginia	180090472177917509	3a5fae1ccbb090a85309d343c0236c6e	Discover	37.1167885918065892	-76.5390514341443833
20506	2020-04-18 08:24:54	2020-04-18	Mrs. Paris Witting	mrs.paris.witting@geemail.com	New Orleans	Louisiana	6011394452991376895	dc0e11e929aede2d76c23486d23bf0f4	JCB 15 digit	30.1495332549341022	-89.8857113439850508
20507	2020-04-18 08:26:48	2020-04-18	Clay Volkman	clay.volkman@geemail.com	San Jose	California	3024882661572914	45a1f394cbeee3021f5bfaefeef1049d	Diners Club / Carte Blanche	37.331272928491984	-121.746482907676693
20508	2020-04-18 08:30:08	2020-04-18	Mrs. Jeffie Walker DDS	mrs.jeffie.walker.dds@geemail.com	San Francisco	California	3028994760128930	da950393e7d0293e3894a2a95529eee0	Discover	37.7924495957840847	-122.457555131618619
20509	2020-04-18 08:33:33	2020-04-18	Dr. Tim Schmeler	dr.tim.schmeler@geemail.com	Peoria	Illinois	4335614888551953	fedd6853322e1376c2b65534515dbd23	Maestro	40.8088580796364724	-89.5896936316393351
20510	2020-04-18 08:41:58	2020-04-18	Arnett Green DDS	arnett.green.dds@geemail.com	Mesa	Arizona	180074754441010587	2e53f3a12e070b216802fb3bbc49d943	VISA 16 digit	33.4774047517362945	-111.691104104358331
20511	2020-04-18 08:43:38	2020-04-18	Mr. Demetrius Swift	mr.demetrius.swift@geemail.com	McKinney	Texas	3029287205476546	4866885832122e6142fe1d6885d20107	Discover	33.1100296770818545	-96.6814143793955481
20512	2020-04-18 08:52:47	2020-04-18	Ellen Kerluke	ellen.kerluke@geemail.com	Hialeah	Florida	51985966301756491	54172ae198755a764160ffb0b001d55b	VISA 16 digit	25.8534054717957993	-80.2663282528888402
20513	2020-04-18 08:54:27	2020-04-18	Ms. Regan Koss MD	ms.regan.koss.md@geemail.com	Elizabeth	New Jersey	869993124175527619	ece98db4f667cc769accd925efb3a2f3	VISA 16 digit	40.5733050007965446	-74.160633960267532
20514	2020-04-18 09:28:27	2020-04-18	Dr. Fidencio Fay	dr.fidencio.fay@geemail.com	Surprise	Arizona	6011389893452447427	80b58ec149d45894b2e862db36d7138b	American Express	33.6676738299656648	-112.433994038658952
20515	2020-04-18 09:32:15	2020-04-18	Dr. Author Greenfelder	dr.author.greenfelder@geemail.com	Berkeley	California	3088367112818789406	87507f5330d460cebfffb3b0e570fec4	VISA 13 digit	37.9166929094718768	-122.25604626712375
20516	2020-04-18 09:46:12	2020-04-18	Dr. Golda Bergstrom DDS	dr.golda.bergstrom.dds@geemail.com	San Francisco	California	676165465289844	75214f4175ba03dbb508d7ab188df210	JCB 16 digit	37.797138985336062	-122.470713601982084
20517	2020-04-18 09:47:13	2020-04-18	Dr. Jeramie Jones	dr.jeramie.jones@warmmail.com	San Francisco	California	51962253206958952	6f5f51eba964dbffd954808ce839fbb9	Discover	37.777157594504267	-122.424231964734744
20518	2020-04-18 09:56:40	2020-04-18	Dr. Cleo Johnson PhD	dr.cleo.johnson.phd@woohoo.com	Wichita	Kansas	4929662416552888	e43709395c9518df9f6aae753a59cba9	JCB 16 digit	37.6534119839657109	-97.356179688937587
20519	2020-04-18 10:09:48	2020-04-18	Dr. Burney Smith	dr.burney.smith@geemail.com	Berkeley	California	3112701562048907910	55f7f4efbcacae1e11e49dd03fcb9532	Voyager	37.8895812459135684	-122.279293889585617
20520	2020-04-18 10:14:02	2020-04-18	Eartha Hickle	eartha.hickle@geemail.com	Nashville	Tennessee	060432367273987	47352a935cc73caf03805e40edfab436	VISA 16 digit	36.2508287889074481	-86.7266968888137484
20521	2020-04-18 10:19:35	2020-04-18	Miss Rebeca Haag	miss.rebeca.haag@warmmail.com	Houston	Texas	54030395549845228	ab99be96c53d3853c468213f26832085	Maestro	29.7112375393588088	-95.3621222697213256
20522	2020-04-18 10:46:52	2020-04-18	Elliott Hahn	elliott.hahn@geemail.com	Madison	Wisconsin	4159183078710	e409b013f5245be0a1082c7f66d29dbb	Diners Club / Carte Blanche	43.1427655047710985	-89.509917714854339
20523	2020-04-18 10:49:25	2020-04-18	Maggie Dare DDS	maggie.dare.dds@geemail.com	New York	New York	180085420492444144	30b9fdc0d6244fc0e814a1af07f54eba	JCB 16 digit	40.683580786617469	-73.9928641466785137
20524	2020-04-18 10:51:03	2020-04-18	Brantley Bernier	brantley.bernier@woohoo.com	Oklahoma City	Oklahoma	3088714964556384513	124a7307c2ac5373f34a2c9da7846eae	JCB 16 digit	35.4335658341091175	-97.4954071439232735
20525	2020-04-18 11:13:31	2020-04-18	Callum Grant	callum.grant@geemail.com	Dallas	Texas	4298742828726	c66a27abe7ebbeb51589fce33519af60	Discover	32.8776221263960053	-96.7144928798507806
20526	2020-04-18 11:54:20	2020-04-18	Dr. Debbie Zemlak DVM	dr.debbie.zemlak.dvm@geemail.com	New York	New York	52935747773734096	0a6eaa4debb29dbb2ebb568b373c661d	VISA 13 digit	40.695235124206171	-73.8564696319296985
20527	2020-04-18 12:05:50	2020-04-18	Madden Bins	madden.bins@geemail.com	New York	New York	4084182169877292	ecdb91d7ef5a18b57d6202458e2aae3e	VISA 16 digit	40.751949499802663	-74.0069455241680174
20528	2020-04-18 12:18:19	2020-04-18	Alana Kreiger	alana.kreiger@geemail.com	North Las Vegas	Nevada	3337201278109500115	5cae939b9f69176ed53014fa95a0e9d6	Diners Club / Carte Blanche	36.2459911901194616	-115.05459743786939
20529	2020-04-18 12:26:21	2020-04-18	Shelia Bradtke	shelia.bradtke@geemail.com	New York	New York	4447868446074	03184bad9920c42deb45c8991136c999	American Express	40.6653494590185574	-73.9389145277336155
20530	2020-04-18 12:28:41	2020-04-18	Ronna Jacobi PhD	ronna.jacobi.phd@warmmail.com	Jacksonville	Florida	54802568556143713	a1990b7286405a20b07e98881d3422dd	JCB 16 digit	30.4006665405403815	-81.7039225271981309
20531	2020-04-18 12:32:52	2020-04-18	Carleton O'Reilly MD	carleton.o'reilly.md@geemail.com	Memphis	Tennessee	210084432922300706	c47ab29da363d1a59af1d69bba123653	VISA 13 digit	35.1522502111338113	-89.9721695624083253
20532	2020-04-18 12:51:25	2020-04-18	Duane Becker	duane.becker@geemail.com	Toledo	Ohio	639008604578289	2368cc28f55f1c6fd33006a9a85f1131	JCB 15 digit	41.7073532109785816	-83.5205759981978701
20533	2020-04-18 12:54:33	2020-04-18	Kade Schmidt	kade.schmidt@geemail.com	Berkeley	California	6011206125103947427	579bd90d4094bc8a2cfc3cdcdecc6429	Diners Club / Carte Blanche	37.870563549913058	-122.267702240956353
20534	2020-04-18 13:04:45	2020-04-18	Joline Eichmann	joline.eichmann@geemail.com	Anaheim	California	4514360703553690	5d14916c2a52b11f52c8de7aa96cb80f	Mastercard	33.9288534169849001	-117.710471001614252
20535	2020-04-18 13:08:45	2020-04-18	Lurline Leffler	lurline.leffler@geemail.com	Jacksonville	Florida	3765709480742137	3f14d3aacbd8946a61a7f08c75c979ba	VISA 16 digit	30.3443435810558491	-81.7005376437291631
20536	2020-04-18 13:10:07	2020-04-18	Eliot Roob	eliot.roob@geemail.com	Chesapeake	Virginia	6011949931254549314	b04d43ce5ebd9a0ad59c73037df822e3	Voyager	36.7238397518411261	-76.2445086061798065
20537	2020-04-18 13:25:29	2020-04-18	Levy Spinka-Gulgowski	levy.spinka.gulgowski@geemail.com	New York	New York	630498748181066	ffe049ae6d3d5a274fb981976727621c	JCB 16 digit	40.6036701954659094	-73.8586003511574063
20538	2020-04-18 13:45:53	2020-04-18	Nia Hilpert-Schoen	nia.hilpert.schoen@warmmail.com	Oakland	California	3158237189997728734	db2426150edffc9c9b43babea117233d	JCB 16 digit	37.8061127587372923	-122.284827585186363
20539	2020-04-18 13:59:22	2020-04-18	Kerwin Hegmann	kerwin.hegmann@geemail.com	Hialeah	Florida	869907347843294776	de15db56162ece68a5d79b2229671deb	VISA 16 digit	25.9622469549976316	-80.3153706315807909
20540	2020-04-18 14:04:11	2020-04-18	Mrs. Deneen Rohan PhD	mrs.deneen.rohan.phd@woohoo.com	San Francisco	California	54998186572064047	315ff26997543cee1d50087b720370ba	VISA 13 digit	37.7923861344950751	-122.408923504433176
20541	2020-04-18 14:06:07	2020-04-18	Mr. Ruby Vandervort	mr.ruby.vandervort@geemail.com	Chandler	Arizona	3469284135250486	a06b68be6a75795024e1e8a47a295fb7	Diners Club / Carte Blanche	33.3177946563899496	-111.926715369464461
20542	2020-04-18 14:20:55	2020-04-18	Aisha Kautzer	aisha.kautzer@geemail.com	Mesquite	Texas	6011299300429566742	06d5ee4cf45c0580dc540be23796a9ab	Diners Club / Carte Blanche	32.6804663891714071	-96.4920183866482262
20543	2020-04-18 14:26:47	2020-04-18	Ms. Roseanne O'Reilly	ms.roseanne.o'reilly@geemail.com	Austin	Texas	4825249904264773	75f682b84eb380284a2fe7445944160c	JCB 15 digit	30.3326592242937529	-97.8084810314472861
20544	2020-04-18 14:34:59	2020-04-18	Dr. Rashad Ward	dr.rashad.ward@geemail.com	West Palm Beach	Florida	210086465167847617	fe2e8651b8596e66aa49e266035d5fb0	VISA 13 digit	26.7890916246302453	-80.1246215463452103
20545	2020-04-18 14:44:09	2020-04-18	Arvid Torphy	arvid.torphy@woohoo.com	Louisville	Kentucky	6011819260944398941	443e83f7461ae320fdd61449f4997e1d	JCB 16 digit	38.0730329266652419	-85.5678564302694156
20546	2020-04-18 14:49:08	2020-04-18	Valerie Stoltenberg	valerie.stoltenberg@geemail.com	San Francisco	California	3004668819642422	021cf27319032ffaefce56eccca7f0fa	VISA 16 digit	37.7908474252352704	-122.449849661139552
20547	2020-04-18 14:54:07	2020-04-18	Chanel Jones	chanel.jones@woohoo.com	Virginia Beach	Virginia	3043598225858364	a252678be8f97740512485db2a10083e	Voyager	36.7754287476837618	-76.0986320527873943
20548	2020-04-18 15:00:44	2020-04-18	Elroy Wintheiser	elroy.wintheiser@geemail.com	Colorado Springs	Colorado	4070579676589	1e87b9820406843c0d94dc2f6651018b	JCB 16 digit	38.8192412395078676	-104.774925299097603
20549	2020-04-18 15:09:38	2020-04-18	Mr. Geary Hartmann IV	mr.geary.hartmann.iv@warmmail.com	San Francisco	California	3402486270915456	ffedc141f0cb536d4c7cae8cee30762e	Mastercard	37.7828115826300746	-122.436329015434026
20550	2020-04-18 15:18:44	2020-04-18	Odalys King	odalys.king@geemail.com	Fresno	California	3019729948904516	eb5d415c95d1a391cac7f3a6e971632b	Maestro	36.8271269288718699	-119.702257057848954
20551	2020-04-18 15:25:49	2020-04-18	Axel Dare	axel.dare@geemail.com	Tacoma	Washington	3337427345842493052	f969490b9ef5c8a8b48334a1788e1435	Maestro	47.3499797875646493	-122.48884485268519
20552	2020-04-18 15:28:31	2020-04-18	Tennie Bode-Lakin	tennie.bode.lakin@geemail.com	Berkeley	California	6011289392603429864	7ca973a0d5ac67f16320b12834f322c6	JCB 15 digit	37.8644785511002695	-122.247062747396512
20553	2020-04-18 15:42:16	2020-04-18	Carmen Lind II	carmen.lind.ii@geemail.com	Fremont	California	3088987649100727545	4803750e57076e39b1d432876d4ecfaa	American Express	37.4698151675686262	-121.874803875664995
20554	2020-04-18 15:49:59	2020-04-18	Cyril Parker	cyril.parker@woohoo.com	Oakland	California	3037367346859362	d6d444abae7e1c5ceaeb22776fb51f10	Maestro	37.8281641705481135	-122.257581094502541
20555	2020-04-18 16:04:14	2020-04-18	Clytie Hoppe	clytie.hoppe@geemail.com	Fayetteville	North Carolina	210003786894019109	6558b579e9be703ec325c5a368e53269	Maestro	35.0960308349944654	-79.0203219940550667
20556	2020-04-18 16:17:00	2020-04-18	Saverio Collins	saverio.collins@geemail.com	San Diego	California	4253175023794781	c0700a01ebf45f486e3b47d9b2916d92	Mastercard	32.8479759504620006	-117.195110190417623
20557	2020-04-18 16:30:13	2020-04-18	Rylee Considine	rylee.considine@geemail.com	Arvada	Colorado	3337005293450610890	339758c8b115cd7680dda5aeba7c5c36	JCB 16 digit	39.8248769709549819	-105.205872284385563
20558	2020-04-18 16:42:42	2020-04-18	Ryley Connelly	ryley.connelly@warmmail.com	New York	New York	3088500860602736615	d0fbba06c353855b7215a581f1818147	VISA 16 digit	40.7265383953917777	-73.877562946769217
20559	2020-04-18 16:58:53	2020-04-18	Toma Stoltenberg	toma.stoltenberg@geemail.com	San Francisco	California	55283089897337854	d63bfc9964557ce10d6b679a77765e06	Discover	37.7447149314649053	-122.449422980517809
20560	2020-04-18 17:10:16	2020-04-18	Durrell Harber	durrell.harber@geemail.com	Fresno	California	210022001249845191	95254ed2f6e39842b3bc8efddebdcb28	American Express	36.8446112012829659	-119.844247481004899
20561	2020-04-18 17:16:55	2020-04-18	Cathrine Treutel	cathrine.treutel@geemail.com	Jurupa Valley	California	4046791292996980	8f79fc3e797a7079fd7efd2e8419ae0c	Discover	33.9699679527826603	-117.416920757528771
20562	2020-04-18 17:21:19	2020-04-18	Carry Haag	carry.haag@geemail.com	New York	New York	3088901387962839248	96c61066e984c08a4d7ca85599d5c73b	Maestro	40.7030949283149113	-74.0330143237382146
20563	2020-04-18 17:25:31	2020-04-18	Quinten Schneider-Doyle	quinten.schneider.doyle@geemail.com	Sugar Land	Texas	6011107252753059095	85e557f60ddc11208ce7185e8e68cf88	JCB 15 digit	29.6343724928848431	-95.588750759140396
20564	2020-04-18 17:29:09	2020-04-18	Shelia Zieme	shelia.zieme@warmmail.com	Chicago	Illinois	4576009600176171	a35e5e29a7364bb52f50aa0bae1932f5	Maestro	41.7915482458028933	-87.7084253437846826
20565	2020-04-18 17:33:30	2020-04-18	Dr. Estrella Dach PhD	dr.estrella.dach.phd@geemail.com	Dallas	Texas	6011539215273596449	2cdf4b52718be1ada86a92c0a34e424e	Diners Club / Carte Blanche	32.8769284911260016	-96.7729692468847986
20566	2020-04-18 17:53:53	2020-04-18	Marceline Kemmer MD	marceline.kemmer.md@geemail.com	Los Angeles	California	4937198524418	f3839dbd75c4ad60519cf04dcefa059b	JCB 16 digit	34.0553523967839737	-118.41145442365594
20567	2020-04-18 18:04:46	2020-04-18	Geovanni Crona	geovanni.crona@geemail.com	Memphis	Tennessee	4531959786559349	c540e20d80f62f0d2af3e62d15735f63	Voyager	35.1713379028320361	-89.906935494279125
20568	2020-04-18 18:05:45	2020-04-18	Randi Haag DVM	randi.haag.dvm@geemail.com	Jackson	Mississippi	6011291454601378976	50fdc344f3d3fc14a8ef9aeba6ef8d46	Maestro	32.3260135754656091	-90.2920076184414313
20569	2020-04-18 18:13:38	2020-04-18	Keenen Kohler	keenen.kohler@geemail.com	New York	New York	3030979688401640	e5cec0e69e80bdf52906d89e24aa0f3c	Voyager	40.5767503204513318	-73.9829114993464145
20570	2020-04-18 18:18:21	2020-04-18	Fredrick Hilll	fredrick.hilll@geemail.com	San Francisco	California	3158048041305259788	cf66d81beed6ffbb66184b9fd7feebe0	VISA 13 digit	37.7553814820986631	-122.455588532651916
20571	2020-04-18 18:21:00	2020-04-18	Darion Howe-Hayes	darion.howe.hayes@geemail.com	Long Beach	California	4728676679420701	7801fd33794b3d1a153fe3e4aae1a8b5	VISA 16 digit	33.7546785468522401	-118.090527509774262
20572	2020-04-18 18:29:59	2020-04-18	Ryann Howe	ryann.howe@warmmail.com	Fort Worth	Texas	4696007949272813	4ff6e7392a7186c259a47347deada96c	JCB 16 digit	32.7036699796151353	-97.3210668053764891
20573	2020-04-18 18:32:13	2020-04-18	Fidencio Wisoky	fidencio.wisoky@geemail.com	Richmond	Virginia	55919990962041572	6af254dc6032af0fa135f181f249a0c7	JCB 15 digit	37.4899004620719651	-77.4609463829770704
20574	2020-04-18 18:48:26	2020-04-18	Paisley Ryan	paisley.ryan@geemail.com	Temecula	California	4522208532593439	945362ea2573a575bcba312a08a49ffc	JCB 16 digit	33.566659237411244	-117.061559736748038
20575	2020-04-18 18:52:25	2020-04-18	Caylee Bailey	caylee.bailey@geemail.com	New York	New York	180048973598506626	df28afcf3184caf7ffa944a8ec07d5f1	JCB 16 digit	40.620051370676606	-73.9765021392971249
20576	2020-04-18 18:55:14	2020-04-18	Kristin Sporer V	kristin.sporer.v@geemail.com	Alexandria	Virginia	52757584957913211	26bcc225ecd3fe25be2a719b783d118e	American Express	38.9002099708303746	-76.9890955431371964
20577	2020-04-18 18:57:59	2020-04-18	Dr. Chalmers Gusikowski I	dr.chalmers.gusikowski.i@woohoo.com	Los Angeles	California	3112685436085171708	a1788393ee89d535871b5566c79b10bd	Discover	34.0453063659701485	-118.311392358410359
20578	2020-04-18 19:21:43	2020-04-18	Dennis Carroll DDS	dennis.carroll.dds@geemail.com	San Francisco	California	3096677722045493070	bce0e49eacf2406515dad2881c0ea594	VISA 16 digit	37.7591630874087514	-122.425994927639877
20579	2020-04-18 19:32:04	2020-04-18	Loula Hilll	loula.hilll@woohoo.com	Rancho Cucamonga	California	3337888425064674704	bc5eb6627b97689c886275867c137031	Mastercard	34.2043418917797482	-117.65286708124988
20580	2020-04-18 19:53:28	2020-04-18	Verner Ruecker	verner.ruecker@warmmail.com	Portland	Oregon	502088853872401	672f4a063287fd811c64ace3655b4fcd	Mastercard	45.5277116546295559	-122.699455690151083
20581	2020-04-18 19:56:10	2020-04-18	Miner Sawayn-Kunde	miner.sawayn.kunde@woohoo.com	Los Angeles	California	6011816675367826636	830bc47ee56ac4777ce2e604ac54cc29	Voyager	34.08069668308422	-118.346416141045466
20582	2020-04-18 20:03:34	2020-04-18	Mr. Alford Kovacek Sr.	mr.alford.kovacek.sr.@geemail.com	Omaha	Nebraska	4447672598115936	11f134461145d7b6b324be977d6d8bf5	JCB 15 digit	41.2965143646724542	-96.0194986868299623
20583	2020-04-18 20:10:43	2020-04-18	Yareli Wunsch	yareli.wunsch@warmmail.com	Dayton	Ohio	6011973854287417995	eeeec7b95fd374b3d26d13c51facbb2f	Mastercard	39.8638200241863743	-84.1273720481623002
20584	2020-04-18 20:15:33	2020-04-18	Miss Rettie Jenkins MD	miss.rettie.jenkins.md@geemail.com	Phoenix	Arizona	4835418695241278	e4218d81828e35d87dcba699c61cf287	Discover	33.5480622911293054	-112.165553824270518
20585	2020-04-18 20:22:47	2020-04-18	Nigel Veum	nigel.veum@geemail.com	Glendale	Arizona	4878430584504201	adc36310d6adeb9e22e6ad06382e8fcb	JCB 16 digit	33.5642169881373604	-112.2171121715825
20586	2020-04-18 20:26:35	2020-04-18	Simpson Kuphal	simpson.kuphal@geemail.com	Portland	Oregon	869979843789526562	7d58777dc475a5792186fc744b9940b3	American Express	45.5842377228550575	-122.587908418243757
20587	2020-04-18 20:32:57	2020-04-18	Calla Corwin	calla.corwin@geemail.com	Des Moines	Iowa	3158560611077337984	78e3afcf99a3f05377ac4944d80532eb	Diners Club / Carte Blanche	41.4954251282591358	-93.6176579066597014
20588	2020-04-18 20:48:24	2020-04-18	Doss Hills	doss.hills@geemail.com	San Francisco	California	3498803061431599	274724f2abba53badc8c7c826daddb84	Voyager	37.7942958376646487	-122.413561075205024
20589	2020-04-18 20:51:17	2020-04-18	Dalia Powlowski	dalia.powlowski@woohoo.com	Denver	Colorado	180045318875587837	30429309648ba9606d920ebf9fd90c40	JCB 16 digit	39.8581344175204606	-104.961036370486397
20590	2020-04-18 21:04:04	2020-04-18	Cephus Kilback-Stokes	cephus.kilback.stokes@geemail.com	New York	New York	3474120690466237	cc475a67a0e58dd3e6c18a6c8bf071e2	Maestro	40.6291911129131904	-73.9469710149697903
20591	2020-04-18 21:07:18	2020-04-18	Gertha Hammes	gertha.hammes@woohoo.com	Los Angeles	California	869991355920303508	2b3574acb761eb10d66505c2dfa996c6	Diners Club / Carte Blanche	34.0742472332768145	-118.43431555991917
20592	2020-04-18 21:21:51	2020-04-18	Patience Schaefer	patience.schaefer@geemail.com	Ontario	California	180072671247928915	7ac769784702ddd0efa774052dbe39ac	JCB 15 digit	34.0320760288421056	-117.58156959871836
20593	2020-04-18 21:35:35	2020-04-18	Salma Haag	salma.haag@woohoo.com	San Antonio	Texas	3158693596778700343	e6d4eaccce9ca01297a656f6dad01891	American Express	29.4111892854865644	-98.4531076725874073
20594	2020-04-18 21:38:03	2020-04-18	Sophronia Wiza	sophronia.wiza@geemail.com	Macon	Georgia	51315223650077330	67dd630b5571b4331ae60a8b7361d921	JCB 16 digit	32.8341824136685574	-83.6206350755605854
20595	2020-04-18 21:40:02	2020-04-18	Adelle Jast	adelle.jast@geemail.com	Oakland	California	55088575030126219	af22a9c74210174e8e790a3e95e05140	American Express	37.8216042169616884	-122.275504572915381
20596	2020-04-18 22:03:18	2020-04-18	Pheobe Wilderman	pheobe.wilderman@woohoo.com	Phoenix	Arizona	3112680929889137201	c451ca2fca37ce6c1362a6ad17695466	JCB 16 digit	33.6247565173011296	-112.112573465558143
20597	2020-04-18 22:12:31	2020-04-18	Mr. Tyrese Marvin I	mr.tyrese.marvin.i@geemail.com	Houston	Texas	53054341371257695	6799013ea1755785e553ee14381e17e5	Mastercard	29.8211233576372265	-95.3019695093870212
20598	2020-04-18 22:20:40	2020-04-18	Hezzie Hettinger	hezzie.hettinger@woohoo.com	Berkeley	California	6011336993208559402	058ee5efd6ef820900e0834cc1b30830	American Express	37.8773521740475658	-122.282021543286049
20599	2020-04-18 22:27:54	2020-04-18	Almus Bailey PhD	almus.bailey.phd@warmmail.com	San Francisco	California	6011048134675745922	121b8ae4eb5922dba1bad60cb7aae919	Maestro	37.8272334474885739	-122.448167595598434
20600	2020-04-18 22:34:32	2020-04-18	Benjamen Morar	benjamen.morar@geemail.com	Tempe	Arizona	6011817771443804843	e55ba27d2a8dad0da1ee2629b9452a98	Diners Club / Carte Blanche	33.3522913394883247	-111.999737130620701
20601	2020-04-18 22:47:25	2020-04-18	Trudie Miller	trudie.miller@geemail.com	Plano	Texas	210054795261894513	ae302131bfb30215bebff4b6d5c183e3	Discover	33.006470915218074	-96.7028379376228884
20602	2020-04-18 23:00:43	2020-04-18	Douglass Windler-Jones	douglass.windler.jones@warmmail.com	Norman	Oklahoma	4494577016502098	7d76963b6ce734c5cd3219345eeb4322	Discover	35.2729252690956017	-97.4404113251503503
20603	2020-04-18 23:03:46	2020-04-18	Dr. Leatrice Schowalter	dr.leatrice.schowalter@geemail.com	San Francisco	California	4812029580033907	824d22225ef034bea22d37cea30d82ce	JCB 16 digit	37.7671235883876832	-122.420304545196501
20604	2020-04-18 23:05:54	2020-04-18	Denice Powlowski PhD	denice.powlowski.phd@geemail.com	Los Angeles	California	3088915507984262491	24d59d6f5ec0744bbf54523bcbea60ce	Mastercard	34.0838006570335423	-118.483938938983897
20605	2020-04-18 23:07:29	2020-04-18	Ms. Paityn Grant DDS	ms.paityn.grant.dds@woohoo.com	Des Moines	Iowa	3112190456635965639	287c17a44bb862bbbe8d59549cddb6ba	VISA 16 digit	41.6705731956496876	-93.6527200875382988
20606	2020-04-18 23:11:19	2020-04-18	Mr. Sylvanus Bernhard	mr.sylvanus.bernhard@geemail.com	Killeen	Texas	51454164710809075	46297feb1dff88cf30a75ef6ebc8e67e	Discover	31.1606710059333594	-97.7380794386081391
20607	2020-04-18 23:15:49	2020-04-18	Mrs. Kathrine Satterfield	mrs.kathrine.satterfield@geemail.com	San Diego	California	6011657080646761633	283dfcac3214ea44d25c30fef6cc8ed5	Mastercard	32.8936766387030488	-117.035798022327953
20608	2020-04-18 23:28:46	2020-04-18	Liller Schoen PhD	liller.schoen.phd@geemail.com	Los Angeles	California	55266671449906665	f3f8d2013e690d4004bf4c2f31f47751	Mastercard	34.0207561542611572	-118.50816044597812
20609	2020-04-18 23:34:14	2020-04-18	Robbie Koelpin	robbie.koelpin@geemail.com	Philadelphia	Pennsylvania	55265993511440394	db1986d53c2264b3db5c0990c5c98666	JCB 16 digit	40.0498125692322873	-75.0388201420094845
20610	2020-04-18 23:35:50	2020-04-18	Gerry White Sr.	gerry.white.sr.@geemail.com	Atlanta	Georgia	3112404021586891804	d13574c459eee62f629f16c8d0f277d1	Discover	33.7954639239978079	-84.4530597381338595
20611	2020-04-18 23:40:08	2020-04-18	Darius Purdy IV	darius.purdy.iv@geemail.com	El Paso	Texas	869955376678394352	dd8586b43bbc8f38038dba48802690b5	JCB 16 digit	31.876777577709035	-106.492819629095507
20612	2020-04-18 23:57:26	2020-04-18	Ross Lynch	ross.lynch@warmmail.com	Chesapeake	Virginia	6011811193511091318	7073d4a8e937cd7ef17cf986f342d2d6	Discover	36.6675902544759253	-76.25352879416495
20613	2020-04-18 23:58:32	2020-04-18	Elvera Heathcote	elvera.heathcote@geemail.com	Gilbert	Arizona	869991863643476378	fb66a47f4244c64c2290b3c5b48813bc	VISA 16 digit	33.3182407102428328	-111.68136776421629
20614	2020-04-19 00:39:29	2020-04-19	Mr. Rayan Zboncak	mr.rayan.zboncak@geemail.com	Louisville	Kentucky	4363725079693159	d26f6320c451a73a77d5a8a51d1f8498	Voyager	38.1813215792082232	-85.6109312727652565
20615	2020-04-19 00:47:49	2020-04-19	Corda O'Conner	corda.o'conner@geemail.com	Vancouver	Washington	502059519443960	e168a396de16adbfcb70f0bc3e70ba41	Diners Club / Carte Blanche	45.647652144970003	-122.557416966750097
20616	2020-04-19 00:59:02	2020-04-19	Annabell Muller	annabell.muller@geemail.com	Sandy Springs	Georgia	3037134902720770	fe59e4f9e9bde9345da857d88bcc20a2	American Express	33.9939551250599337	-84.4022228790529141
20617	2020-04-19 01:13:19	2020-04-19	Cael Mueller DVM	cael.mueller.dvm@geemail.com	Greensboro	North Carolina	180083329100436966	ad17dea8f578c514e42186a10687ed7e	American Express	36.139030967617785	-79.919275043344129
20618	2020-04-19 01:22:03	2020-04-19	Mr. Angelo Ferry II	mr.angelo.ferry.ii@geemail.com	Columbus	Ohio	52224612000587131	ecc392f7f97c22fcca3d371a27c927d2	VISA 16 digit	40.0164430697958906	-82.9997387900717598
20619	2020-04-19 01:24:29	2020-04-19	Dr. Elwyn Mante DDS	dr.elwyn.mante.dds@geemail.com	South Bend	Indiana	4043949661662186	3e0c36d4e12b514cbf7b4c4b4fc3a9da	VISA 16 digit	41.6177738648984601	-86.1741230502314863
20620	2020-04-19 01:32:24	2020-04-19	Milas Bode PhD	milas.bode.phd@geemail.com	Berkeley	California	4149346541463153	8324b034088067bcaa3e7a5ceab8704a	Discover	37.8453275988939524	-122.287738287509057
20621	2020-04-19 02:02:04	2020-04-19	Miss Mariel Dietrich	miss.mariel.dietrich@geemail.com	Philadelphia	Pennsylvania	3528749887719656700	789310e97694ec9e95eb45b676d8340f	Mastercard	39.9486423835117392	-75.129320308788877
20622	2020-04-19 02:03:55	2020-04-19	Vincenzo Pfannerstill	vincenzo.pfannerstill@geemail.com	Tulsa	Oklahoma	53431296575045375	2a47d54639d97d2ef2301a443ba7d083	JCB 16 digit	36.2107402808867391	-95.9320917508054549
20623	2020-04-19 02:06:56	2020-04-19	Araceli Buckridge	araceli.buckridge@geemail.com	Sacramento	California	3088398795770616394	b0f0801df0a114315c38a9a0969a6f9c	JCB 15 digit	38.498513754995912	-121.493466808857761
20624	2020-04-19 02:07:30	2020-04-19	Violet Marvin	violet.marvin@geemail.com	Thornton	Colorado	4191518597767	c3bc54206b818affa6d1a10a2b0cfb91	Maestro	39.8208293979853423	-104.87281506901347
20625	2020-04-19 02:10:08	2020-04-19	Jackie Hand	jackie.hand@geemail.com	San Francisco	California	869940613426578086	39768004ba62428821a89d0042689eef	VISA 16 digit	37.7781525525792361	-122.46724684947209
20626	2020-04-19 02:19:09	2020-04-19	Robyn Wiegand-Bins	robyn.wiegand.bins@geemail.com	Seattle	Washington	6011820402982229771	73650ce0065440bdf064be6280cc3b84	VISA 13 digit	47.5998329667765674	-122.416708268031101
20627	2020-04-19 02:39:30	2020-04-19	Ember Jacobs	ember.jacobs@geemail.com	New York	New York	630462441683273	9f6369d0226acce215fa1b5ad4052dd2	Maestro	40.5685582080613827	-73.8943371912360192
20628	2020-04-19 02:48:52	2020-04-19	Clytie Hintz	clytie.hintz@geemail.com	Berkeley	California	3024620845851964	6d80cd77a47db6f383db50275a02dca2	Maestro	37.8679857890078964	-122.270848144563431
20629	2020-04-19 02:53:01	2020-04-19	Dr. Celena Roberts DDS	dr.celena.roberts.dds@warmmail.com	Fresno	California	3337700069246981250	de2c0e21bcdcd67c2f8ac9bcda8f0a09	JCB 16 digit	36.7153867386154857	-119.830073985188832
20630	2020-04-19 03:00:10	2020-04-19	Rafe Rath	rafe.rath@geemail.com	Austin	Texas	3158921214027830721	5d461835ffa3fc6397476b07224d56eb	JCB 16 digit	30.3234091240573669	-97.8339170027762748
20631	2020-04-19 03:27:22	2020-04-19	Miss Rosamond Parisian DVM	miss.rosamond.parisian.dvm@geemail.com	Los Angeles	California	676200481064426	5965347c6964eed6747a4d86df769033	Diners Club / Carte Blanche	33.9352243686426434	-118.386594095965094
20632	2020-04-19 03:38:39	2020-04-19	Teddy Gleichner	teddy.gleichner@geemail.com	El Cajon	California	3010475217411044	a0ea5ef06b235eac73ed1f014c1f7f24	American Express	32.8913189968567323	-116.880216028187064
20633	2020-04-19 03:44:59	2020-04-19	Tressie Collins	tressie.collins@geemail.com	Worcester	Massachusetts	4565795066192	7ecf5aafb4eb8ff8f6f3f3fbc1aec1ea	VISA 13 digit	42.2915171804539867	-71.856437283034623
20634	2020-04-19 03:53:17	2020-04-19	Troy Gleason PhD	troy.gleason.phd@geemail.com	Chicago	Illinois	060499268305218	59d629e0fc011b380586ff8aa5d70d31	Discover	41.830624004483596	-87.7720314806822586
20635	2020-04-19 04:03:34	2020-04-19	Suellen Hoeger	suellen.hoeger@geemail.com	New Orleans	Louisiana	3425083375570535	02072664c8680118723c42ec74b954dd	VISA 13 digit	29.9824605790447443	-89.9215654004160285
20636	2020-04-19 04:06:56	2020-04-19	Anissa Davis	anissa.davis@woohoo.com	Overland Park	Kansas	869975534254922022	aa16967ddb1582206e24a5111d1f6110	Maestro	38.8698195872698022	-94.7048698463518264
20637	2020-04-19 04:09:09	2020-04-19	Joette Tremblay-Mills	joette.tremblay.mills@geemail.com	Detroit	Michigan	4354181068963420	2aee13887b135cb0475c77d9464e0e49	VISA 16 digit	42.4131968859508675	-83.0023838563010088
20638	2020-04-19 04:17:37	2020-04-19	Dwane Larson-Prosacco	dwane.larson.prosacco@geemail.com	Washington	District of Columbia	501837352278362	d2a51b062e93b0121f7473354c896270	American Express	38.8542934726256846	-76.9263330341994731
20639	2020-04-19 04:22:49	2020-04-19	Durell Torp	durell.torp@geemail.com	Nashville	Tennessee	4352587208935973	395205fab0b1847d3cc988a0cbb41ed3	Diners Club / Carte Blanche	36.2138257895719207	-86.7337699304707286
20640	2020-04-19 04:25:38	2020-04-19	Tex Ritchie	tex.ritchie@geemail.com	Louisville	Kentucky	6011012893663846032	cfe7c062ffad8f312e087b73d88cf343	Discover	38.2258370841290755	-85.6070031823195592
20641	2020-04-19 04:28:34	2020-04-19	Case Carter	case.carter@geemail.com	Las Vegas	Nevada	3088823740899622837	9205036630e36f0b513a17c4b1c0f3f0	Diners Club / Carte Blanche	36.2137249248668525	-115.213737465834612
20642	2020-04-19 04:31:15	2020-04-19	Abraham Hoeger	abraham.hoeger@warmmail.com	Anaheim	California	3051258446713656	e03a34ce2672742630c99508b35b57c5	Diners Club / Carte Blanche	33.7647235482763506	-117.853127477432039
20643	2020-04-19 04:36:38	2020-04-19	Adline Klocko	adline.klocko@geemail.com	Temecula	California	869993703572077870	c758d618bf3a61d4520ca2dcefaa1d1d	Diners Club / Carte Blanche	33.5473378897778645	-117.072022831831873
20644	2020-04-19 04:43:19	2020-04-19	Minna Zieme-Ryan	minna.zieme.ryan@geemail.com	Los Angeles	California	4789058880665414	771680fe5f6dd02776642062b291cfa5	VISA 16 digit	34.0834653088223192	-118.454086533048368
20645	2020-04-19 04:58:02	2020-04-19	Mozella Prosacco DVM	mozella.prosacco.dvm@geemail.com	Green Bay	Wisconsin	51819593685980315	bbb3f0579614c9db9cd65c2afe8d23a2	JCB 16 digit	44.5367895864479237	-87.9980975876383553
20646	2020-04-19 05:38:55	2020-04-19	Brittney Grimes	brittney.grimes@woohoo.com	Los Angeles	California	3038636324389967	5c150f720a7b263012b4ecd0bed43192	JCB 16 digit	34.0927646822161918	-118.324095954093337
20647	2020-04-19 05:39:26	2020-04-19	Leander Conroy-Rippin	leander.conroy.rippin@geemail.com	Fort Worth	Texas	4076468659317430	dcdcc63da4e6082e3fd26f0b63f8b9fa	Mastercard	32.7018818396199507	-97.3943035614497887
20648	2020-04-19 05:46:01	2020-04-19	Romello Weissnat	romello.weissnat@geemail.com	Charlotte	North Carolina	51726203187088698	891fc0b61a66679e82c7e39cd4b5e379	Voyager	35.2627658017232974	-80.8135408303644596
20649	2020-04-19 05:48:26	2020-04-19	Dorene Kassulke	dorene.kassulke@geemail.com	South Bend	Indiana	4034323509163669	2d54ad537fb76b90a8d1c539812174a6	VISA 16 digit	41.7523831997677703	-86.2952265366967879
20650	2020-04-19 06:11:39	2020-04-19	Nanci Lowe PhD	nanci.lowe.phd@geemail.com	Fresno	California	4576776641201016	3390f6bdd4b3d40977b880a3051b2ac0	VISA 16 digit	36.8082688416693387	-119.819486883200341
20651	2020-04-19 06:26:13	2020-04-19	Mr. Wheeler Farrell V	mr.wheeler.farrell.v@warmmail.com	San Francisco	California	4860381774527	541fd6ea6f578c955e9af4003403e730	JCB 15 digit	37.8031633078932074	-122.443576254769823
20652	2020-04-19 06:27:44	2020-04-19	Kash Stamm	kash.stamm@woohoo.com	Los Angeles	California	180055954371989734	f5ae418b8d7cd0bb6d1aa1529cfbb1c0	VISA 16 digit	34.0438613193441171	-118.436937436786664
20653	2020-04-19 06:59:22	2020-04-19	Ms. Enola Rutherford DDS	ms.enola.rutherford.dds@geemail.com	Aurora	Colorado	3789866280111947	2cff58e14487920c1f1203438296a930	Discover	39.6800549736823882	-104.704558302380889
20654	2020-04-19 06:59:59	2020-04-19	Dr. Adeline Raynor	dr.adeline.raynor@warmmail.com	Jersey City	New Jersey	4281436660237310	10582b4fe303502cd96c83ea79a23f0d	Maestro	40.7243139261320195	-73.9985763474322908
20655	2020-04-19 07:06:27	2020-04-19	Ms. Stacy Schoen DDS	ms.stacy.schoen.dds@warmmail.com	Sacramento	California	869930979524238283	65cdb1727d76b10759e91c0f7f03defe	American Express	38.6263255916800361	-121.465862349259098
20656	2020-04-19 07:21:36	2020-04-19	Kanisha Kohler PhD	kanisha.kohler.phd@geemail.com	Memphis	Tennessee	869947283828494796	0ed3260bdf28d281728db3ab15dfb05f	VISA 16 digit	35.187936152058839	-90.0563507410954713
20657	2020-04-19 07:28:21	2020-04-19	Rodrigo Blick	rodrigo.blick@geemail.com	Portland	Oregon	6011736411511683658	7ad2cc8f9b832e06fd000d1b12856ce4	VISA 13 digit	45.6006069137137402	-122.746809486579153
20658	2020-04-19 07:31:17	2020-04-19	Louise Jenkins	louise.jenkins@geemail.com	Minneapolis	Minnesota	4598972438787945	d987477991da8a267d424d3c1d8f93d4	Maestro	44.8653224631298286	-93.3076514964263879
20659	2020-04-19 07:32:01	2020-04-19	Phoebe Hermann	phoebe.hermann@warmmail.com	San Francisco	California	3088808175823452275	152234dd753140572aeda74028a6ee0f	VISA 13 digit	37.7739262056507883	-122.41652744991552
20660	2020-04-19 07:37:56	2020-04-19	Laila Dach	laila.dach@geemail.com	Bridgeport	Connecticut	3048335078011147	290ad250110a91eda8efac4141b2285d	JCB 16 digit	41.1160607585381683	-73.112060917205369
20661	2020-04-19 08:05:33	2020-04-19	Dell Shanahan	dell.shanahan@geemail.com	Memphis	Tennessee	4562003133744619	cba1dbf73ed667ce2215661bd63525a9	Mastercard	35.1440418590858599	-89.9982950064610776
20662	2020-04-19 08:11:05	2020-04-19	Bettye Reinger	bettye.reinger@geemail.com	Edison	New Jersey	3000824447453823	4086041deb888d67f0d8beaa969d13d8	American Express	40.4625559073369914	-74.3177453402947634
20663	2020-04-19 08:11:58	2020-04-19	Ms. Eulalie Hartmann	ms.eulalie.hartmann@geemail.com	Philadelphia	Pennsylvania	3405674773917114	b538be356915e29e5fd8656545048bed	Diners Club / Carte Blanche	40.1002992581069435	-75.0591373992051984
20664	2020-04-19 08:24:48	2020-04-19	Harding Bayer	harding.bayer@geemail.com	San Francisco	California	3112508960904494616	e39e5af7e6df0b813f79798bb5511858	VISA 13 digit	37.7901858236076862	-122.438242540976177
20665	2020-04-19 08:36:46	2020-04-19	Mr. Braedon Steuber	mr.braedon.steuber@geemail.com	Fort Worth	Texas	53312482267987496	4727decc856de5e24a9ad4a357d92b15	VISA 16 digit	32.7418799539618206	-97.4451710849355948
20666	2020-04-19 08:39:22	2020-04-19	Mr. Richmond Kovacek Sr.	mr.richmond.kovacek.sr.@geemail.com	Cary	North Carolina	502012705356488	6c22a01d9a3aa8ff490650143474dd12	JCB 15 digit	35.7477715059757273	-78.7528694419741555
20667	2020-04-19 08:44:08	2020-04-19	Aliana Parker	aliana.parker@geemail.com	San Francisco	California	3088967290650123043	958df0dda483b81993d9155895708991	VISA 16 digit	37.7829458037049193	-122.423251381326367
20668	2020-04-19 08:47:58	2020-04-19	Mr. Samual Yost Jr.	mr.samual.yost.jr.@geemail.com	San Francisco	California	180065576370872120	641dbb70cfd678afa64d1a50c35e848e	VISA 16 digit	37.7626806255854248	-122.425917263353696
20669	2020-04-19 08:48:09	2020-04-19	Joye Roberts	joye.roberts@geemail.com	San Francisco	California	3528409379324706303	d502a17c4db1c637189c97058060acae	VISA 16 digit	37.772749324419749	-122.421231742622538
20670	2020-04-19 09:21:16	2020-04-19	Kalen Wilkinson MD	kalen.wilkinson.md@geemail.com	San Francisco	California	3014437015788169	2993dde1456749ea3de3ae6acf034e9e	Mastercard	37.7762826970253442	-122.432212045067658
20671	2020-04-19 09:23:37	2020-04-19	Dr. Marco Schroeder	dr.marco.schroeder@woohoo.com	Chicago	Illinois	3055541658574676	406528cd6ab3fbbd48266764fabe6870	American Express	41.9207998233683412	-87.6101408856485051
20672	2020-04-19 09:28:15	2020-04-19	Mrs. Florine Koepp	mrs.florine.koepp@woohoo.com	Sioux Falls	South Dakota	3489257682997242	d766cc8e45f7a8b63557b915e916a0c3	Mastercard	43.4765322781719235	-96.7716035146899571
20673	2020-04-19 09:33:42	2020-04-19	Justus Douglas	justus.douglas@warmmail.com	Santa Clarita	California	3158482010180779684	323bf71a817bcaf715fc914ea7210d2d	Mastercard	34.3704895589239854	-118.537922446300087
20674	2020-04-19 09:34:03	2020-04-19	Kaley Hirthe	kaley.hirthe@geemail.com	Simi Valley	California	4337146045186009	2fbe6c627f288e24d35ecfcf64fa23e8	JCB 16 digit	34.2050331507116567	-118.786918476469822
20675	2020-04-19 09:35:23	2020-04-19	Venita Halvorson	venita.halvorson@geemail.com	Palmdale	California	180067173343486432	f36a6ccf3d075bef9d12c62daf0bae3b	Voyager	34.6218504878543314	-118.114423344190797
20676	2020-04-19 09:36:02	2020-04-19	Holden Maggio	holden.maggio@geemail.com	San Francisco	California	3461707380746657	ffae07bb7188fa405ca6f7df3e26d7f5	Discover	37.768394495058125	-122.43696439394526
20677	2020-04-19 09:38:22	2020-04-19	Dr. Levi Lemke	dr.levi.lemke@geemail.com	San Francisco	California	55546692097800747	8081add12bc40e83f87290e7e91bb804	Mastercard	37.764909879725046	-122.446492876324527
20678	2020-04-19 09:46:41	2020-04-19	Suellen Waters	suellen.waters@geemail.com	Bakersfield	California	3088140532288090353	08b4487c06645ba9d4eb291ab661da10	Discover	35.3241372794553641	-118.999431389318033
20679	2020-04-19 10:08:37	2020-04-19	Irl Miller	irl.miller@geemail.com	Portland	Oregon	51126690802111333	7a159e135e84d6197c381ab5a63dbb47	JCB 15 digit	45.4376106862332634	-122.56279111295008
20680	2020-04-19 10:15:26	2020-04-19	Ricardo Cole	ricardo.cole@geemail.com	Vista	California	6011828964798379993	599f296bb37a34af9b0179732aff45c9	JCB 16 digit	33.2481949257645795	-117.253370122570928
20681	2020-04-19 10:24:52	2020-04-19	Darlene Schaden	darlene.schaden@warmmail.com	Abilene	Texas	3096637794846399623	8458189c9ff393489585fb251059a61a	Discover	32.3967507118433744	-99.7391680015664548
20682	2020-04-19 10:28:39	2020-04-19	Jaycie Buckridge	jaycie.buckridge@geemail.com	Memphis	Tennessee	4031255916540795	f29780defc108e54e3938cf1ef5dadf8	VISA 16 digit	35.1057325713403543	-90.0072961061053007
20683	2020-04-19 10:32:39	2020-04-19	Lydia Thiel	lydia.thiel@warmmail.com	Aurora	Illinois	869903802318057037	ba8f37f37fef9f76c14c3cd2ca5b0e39	VISA 16 digit	41.7910354105979209	-88.2102327578630252
20684	2020-04-19 10:32:40	2020-04-19	Dr. Marcos Steuber II	dr.marcos.steuber.ii@warmmail.com	Virginia Beach	Virginia	3054588715502209	54821a3541a9115f4be3cee82336eca0	VISA 16 digit	36.866746233887973	-75.9647947026088843
20685	2020-04-19 10:37:57	2020-04-19	Tommy Bartoletti	tommy.bartoletti@geemail.com	San Antonio	Texas	6011339640306015277	c37cff3466c91baf7257453b2c2a70ad	American Express	29.5524798916257936	-98.4496987027417845
20686	2020-04-19 10:43:56	2020-04-19	Dr. Ashton Kozey I	dr.ashton.kozey.i@geemail.com	Los Angeles	California	869917292820846024	b679eddbd7dcfcc6d750cd97127f0701	JCB 15 digit	33.9549619784444516	-118.357322069256753
20687	2020-04-19 10:49:53	2020-04-19	Dawne King	dawne.king@geemail.com	Tampa	Florida	4668255072112	f8428bd790a4981af2f8a371c689a057	JCB 16 digit	28.0262258768197121	-82.5153587926391481
20688	2020-04-19 11:05:13	2020-04-19	Zella Hand DVM	zella.hand.dvm@geemail.com	San Francisco	California	210035708059784675	2abbd18378f7cd76ef095ff63b619d4a	Diners Club / Carte Blanche	37.7420342606053154	-122.440306133982915
20689	2020-04-19 11:32:38	2020-04-19	Magdalene Kozey	magdalene.kozey@geemail.com	Pasadena	California	3015281838672542	7dd0004acac445780cbc7ad9cda1790f	Maestro	34.099914431557437	-118.106337414197995
20690	2020-04-19 11:51:53	2020-04-19	Mr. Hoy Dickens MD	mr.hoy.dickens.md@geemail.com	Berkeley	California	6011029597959479405	28c63e2766ee5e464abfe7d1d20e14f3	JCB 16 digit	37.8936002689378881	-122.288524297749774
20691	2020-04-19 11:56:06	2020-04-19	Mabell Anderson	mabell.anderson@woohoo.com	San Francisco	California	3056896812423031	dcbfa8ef8cfc52a76430e7926afde17c	JCB 16 digit	37.7661276294289294	-122.423303903494684
20692	2020-04-19 12:06:39	2020-04-19	Dr. Brannon Parisian	dr.brannon.parisian@geemail.com	Pembroke Pines	Florida	6011209392424668663	fddacf0b806591ee439d7029117afb49	JCB 16 digit	26.0612266965713353	-80.3228868861120162
20693	2020-04-19 12:09:42	2020-04-19	Ludwig Lang	ludwig.lang@geemail.com	Berkeley	California	4009661465465169	0dd4b98a82d81c7e306f7a3177ce6aa1	Maestro	37.8912646435514802	-122.24371918630041
20694	2020-04-19 12:15:43	2020-04-19	Karim Hettinger	karim.hettinger@geemail.com	San Francisco	California	3337646049720746236	26abd09d834be20f21bb3730aec967f0	VISA 16 digit	37.7856451940706748	-122.418546609260218
20695	2020-04-19 12:22:07	2020-04-19	Jadiel Corwin-Greenholt	jadiel.corwin.greenholt@geemail.com	Oakland	California	3730660699051350	cdc8962d481bae447a7014e848e76ec1	Discover	37.7587013101068436	-122.273964257545472
20696	2020-04-19 12:32:26	2020-04-19	Miss Danelle Langosh PhD	miss.danelle.langosh.phd@geemail.com	San Francisco	California	4527981958929874	886ba79c12d40968f2d08d92c5cb5219	JCB 16 digit	37.7787617178567672	-122.413873630230356
20697	2020-04-19 12:32:38	2020-04-19	Carly Renner MD	carly.renner.md@warmmail.com	San Francisco	California	3732848639099039	5984c1b151f9f8371312418f4b75d6ab	Discover	37.7712481057660128	-122.465467377118443
20698	2020-04-19 12:50:02	2020-04-19	Mrs. Joella Kutch	mrs.joella.kutch@geemail.com	Los Angeles	California	4593046339633865	5c68f41bbea4420dc1441d118daffd2e	VISA 16 digit	34.0652335635717947	-118.403336357464269
20699	2020-04-19 12:53:02	2020-04-19	Dr. Tad Klein Sr.	dr.tad.klein.sr.@geemail.com	Visalia	California	54832904530524278	1d32df6b95d3c60e23ce75e0736c4456	Mastercard	36.3846620203416791	-119.379126358231161
20700	2020-04-19 13:07:38	2020-04-19	Miss Chanie Lindgren	miss.chanie.lindgren@woohoo.com	Richardson	Texas	639062144932845	20445dd95bf04220556e3f797de44322	Maestro	33.0071018274176851	-96.7248508211452531
20701	2020-04-19 13:21:23	2020-04-19	Aric Hartmann	aric.hartmann@geemail.com	Chesapeake	Virginia	51290909617010740	37db57f9acd318647c06890bbe2cb027	VISA 16 digit	36.5908076446276169	-76.2617566055927369
20702	2020-04-19 13:32:48	2020-04-19	Halie Hettinger	halie.hettinger@warmmail.com	Costa Mesa	California	3158098354330607155	42764cf48b280e25bc08b6eb9246c627	JCB 16 digit	33.7394741060692809	-117.977593793566527
20703	2020-04-19 13:34:32	2020-04-19	Parrish Gusikowski	parrish.gusikowski@woohoo.com	Fort Worth	Texas	3756115032472515	67dac39836244845efc4844831ffae96	American Express	32.7990319225527358	-97.2563908111590933
20704	2020-04-19 13:38:58	2020-04-19	Daisy Bashirian DDS	daisy.bashirian.dds@geemail.com	San Diego	California	3337132913223494878	4c8d6ff9f88bc02b2b7c210d4ad72d59	Maestro	32.8326687847796848	-117.138621223429226
20705	2020-04-19 13:51:20	2020-04-19	Mr. Susie Weber DVM	mr.susie.weber.dvm@geemail.com	Los Angeles	California	3337574197281488619	80b2d796231bf8734924b14bc69a209b	VISA 16 digit	34.0308664501044902	-118.450162170267845
20706	2020-04-19 14:50:06	2020-04-19	Else Heller	else.heller@geemail.com	Columbus	Georgia	869983322183757580	2bba0d68b8fc2b203c7188ecb5a7ee50	JCB 16 digit	32.4862777276940591	-84.8132615861181165
20707	2020-04-19 14:53:26	2020-04-19	Kaydence Mante-Collins	kaydence.mante.collins@geemail.com	San Diego	California	6011311450996014198	635da93f07ff70e8d0303c2e88b91fc6	JCB 15 digit	32.816645695136117	-117.084855402903642
20708	2020-04-19 15:02:40	2020-04-19	Djuna Kovacek	djuna.kovacek@geemail.com	Carrollton	Texas	180019677360604890	c748bf65c95cb4d79075f761e893c25a	Discover	33.0776218908760669	-96.9915004397138887
20709	2020-04-19 15:29:47	2020-04-19	Aldona Price	aldona.price@woohoo.com	New York	New York	4420812403873045	511c21a9de498de84ff8a6ee1b276362	VISA 16 digit	40.6370644014086579	-73.9052885786991567
20710	2020-04-19 15:31:29	2020-04-19	Cara Tremblay-Kuvalis	cara.tremblay.kuvalis@geemail.com	Midland	Texas	3031039819818052	980914cd5737546e4550e45e5c1b567e	Maestro	31.9367254975441845	-102.164073189836003
20711	2020-04-19 15:34:27	2020-04-19	Blain Olson	blain.olson@geemail.com	Tucson	Arizona	4191117860645689	6d4ec9287891999d562247d24d2cb61d	JCB 16 digit	32.2178038242779721	-110.818243382521345
20712	2020-04-19 15:53:36	2020-04-19	Dr. Layton Bauch	dr.layton.bauch@geemail.com	Virginia Beach	Virginia	3096348721256731425	1431c357bc6b1aeb1591da10524121b0	VISA 13 digit	36.7209023652784552	-76.1033526581849884
20713	2020-04-19 16:01:23	2020-04-19	Giancarlo Crooks-Abshire	giancarlo.crooks.abshire@geemail.com	Oakland	California	3337766518154406636	675572b97d68890c93c9c43e2e107926	VISA 16 digit	37.7880450014920513	-122.297188220863134
20714	2020-04-19 16:10:44	2020-04-19	Amit Skiles-Lueilwitz	amit.skiles.lueilwitz@geemail.com	Tulsa	Oklahoma	51902867152814373	1f2937f7d08644a7a2f000547d309f0d	Discover	36.120708361724013	-95.9689495600715219
20715	2020-04-19 16:15:43	2020-04-19	Mrs. Ashlea Wisoky	mrs.ashlea.wisoky@geemail.com	San Francisco	California	869942860691271719	0456b40a8d185ee41041cd00cf571f8c	VISA 13 digit	37.7978095341337124	-122.422085061049842
20716	2020-04-19 16:39:20	2020-04-19	Marcella Schaefer	marcella.schaefer@woohoo.com	Lowell	Massachusetts	180064233276137569	6198e872d512c9b33c26203701e293cc	Maestro	42.6608510758597461	-71.3077694883443485
20717	2020-04-19 16:43:02	2020-04-19	Dr. Benjamen Rohan	dr.benjamen.rohan@geemail.com	New York	New York	4240649154141398	700211d395fc57b8539aa128552ed0f8	Maestro	40.6637804117742903	-73.9702944298170451
20718	2020-04-19 16:52:17	2020-04-19	Dr. Edmon Kirlin	dr.edmon.kirlin@geemail.com	Greensboro	North Carolina	4326699700406	a5cd47c08068a9c13d11cf6e003850ec	Discover	36.0353817410416895	-79.8250652793776254
20719	2020-04-19 17:50:49	2020-04-19	Mr. Randell Lockman II	mr.randell.lockman.ii@geemail.com	Downey	California	180075005915333073	b2a3ec8fa73469b6e39a3c40868ea0ff	American Express	34.0126691655505482	-118.144249827518678
20720	2020-04-19 17:57:41	2020-04-19	Latoyia Wisozk PhD	latoyia.wisozk.phd@warmmail.com	Los Angeles	California	869907690812884162	52c803b5a870934dcbc1dd32b0ebcb6f	VISA 16 digit	34.1118057326279569	-118.336855684220041
20721	2020-04-19 18:00:25	2020-04-19	Mr. Colten Williamson	mr.colten.williamson@geemail.com	Cleveland	Ohio	3013531739989730	fb34314392430be86b6a23aa812f9e45	Discover	41.4911492898911192	-81.5811219664994667
20722	2020-04-19 18:13:11	2020-04-19	Katrina Bernier	katrina.bernier@warmmail.com	Boston	Massachusetts	210099905080061197	7448ef58f085279ffb9e66179fb92ec1	Mastercard	42.3863835283257089	-71.001321321721008
20723	2020-04-19 18:22:12	2020-04-19	Racheal Rath	racheal.rath@geemail.com	Houston	Texas	180021996602775557	0f5f0139b01e60c082976fe1a0ce1a13	Voyager	29.7256230684075504	-95.3953620916247331
20724	2020-04-19 18:28:24	2020-04-19	Dr. Priscilla Braun DDS	dr.priscilla.braun.dds@geemail.com	San Diego	California	3047254769387602	aa2c53230eefd324e43cdc7f76f2b29c	Diners Club / Carte Blanche	32.7830929064258925	-117.21367184374482
20725	2020-04-19 18:30:40	2020-04-19	Marcy Lesch	marcy.lesch@geemail.com	San Francisco	California	4066449790892178	f2e7e878249953c1351e1db800a4c21b	Maestro	37.7394331950681732	-122.423747117852926
20726	2020-04-19 18:34:03	2020-04-19	Mr. Dana Bosco	mr.dana.bosco@geemail.com	New York	New York	3743850480506564	c555a6c6cfff5375ef5308a09e05c850	VISA 16 digit	40.7634939096625857	-73.944935729204488
20727	2020-04-19 18:55:36	2020-04-19	Stevan Kertzmann	stevan.kertzmann@geemail.com	Las Vegas	Nevada	4944899412984	dc1748d4999aa9c3b26103a7f001849a	American Express	36.2399088096905473	-115.162777339315411
20728	2020-04-19 18:57:45	2020-04-19	Davonte Gusikowski	davonte.gusikowski@warmmail.com	Westminster	Colorado	3112419088189887748	41fbc74ca9bbe76ae189ff0cddbf5ecc	JCB 15 digit	39.8986518810342972	-105.068153225971017
20729	2020-04-19 19:01:39	2020-04-19	Rossie Shanahan	rossie.shanahan@geemail.com	Waco	Texas	4787081823064265	6e15777c65b1f5c61eb576425644331f	American Express	31.6345282448198617	-97.269313535107301
20730	2020-04-19 19:12:59	2020-04-19	Theda Davis PhD	theda.davis.phd@geemail.com	Philadelphia	Pennsylvania	3010183367445776	3bfbfdfb3154a029eff5ae6c798da588	Maestro	40.094292250783738	-75.0786756865579719
20731	2020-04-19 19:23:46	2020-04-19	Alexandro Kirlin	alexandro.kirlin@geemail.com	West Jordan	Utah	3158830269675913179	d5a8a6ecf2db093facb571b3bf5c9579	VISA 13 digit	40.6352382153995393	-111.922931020342929
20732	2020-04-19 19:25:01	2020-04-19	Lavinia Rau	lavinia.rau@geemail.com	Atlanta	Georgia	869921293363886801	c0c179c1906035197141e470f2c50c32	Mastercard	33.8457427804168347	-84.4754282512281094
20733	2020-04-19 19:38:23	2020-04-19	Stevan Maggio	stevan.maggio@warmmail.com	Orlando	Florida	3337165478324749190	c04060340c3a17d0b076b4cfa9ed1c6a	VISA 13 digit	28.3237969802957004	-81.251247590078421
20734	2020-04-19 19:45:01	2020-04-19	Diandra Satterfield DDS	diandra.satterfield.dds@geemail.com	Tulsa	Oklahoma	4828063308998093	74b3fc926a109637b429115ef8652e7e	Mastercard	36.0664893606115129	-95.9537317763503665
20735	2020-04-19 19:49:53	2020-04-19	Christ Grant	christ.grant@geemail.com	Chicago	Illinois	6011881807104880614	82b529065eb9d10cbe60f9fb4853970c	JCB 16 digit	41.8311574423056101	-87.7632212343655453
20736	2020-04-19 19:53:56	2020-04-19	Shanelle Botsford PhD	shanelle.botsford.phd@geemail.com	Raleigh	North Carolina	3528181475134422554	8ca826e5c464cdff3d26ba8defc5dcda	VISA 16 digit	35.8668686504144176	-78.6848335504002847
20737	2020-04-19 20:38:47	2020-04-19	Marcelina Harvey	marcelina.harvey@warmmail.com	Los Angeles	California	4696401487967	8e2df9a5f2b555af305024554768dac0	American Express	34.0484993873029893	-118.321519674499697
20738	2020-04-19 20:55:26	2020-04-19	Heidy Gutkowski	heidy.gutkowski@woohoo.com	Oakland	California	6011843845389440719	acc82b735015869dc2b658ddc1d46c6c	JCB 16 digit	37.7588229053486373	-122.249880297586529
20739	2020-04-19 21:15:19	2020-04-19	Arizona Streich DDS	arizona.streich.dds@geemail.com	West Palm Beach	Florida	3158279166239758561	301e8938e55b9ff38f913f66b90920ba	Voyager	26.7223771523997193	-80.1063220064457511
20740	2020-04-19 21:16:09	2020-04-19	Mr. Louie Ledner IV	mr.louie.ledner.iv@woohoo.com	Anaheim	California	3485180737385284	ff732db7fe9104aab0a7feb89d490579	JCB 16 digit	33.9384804838169387	-117.832408715712276
20741	2020-04-19 21:21:39	2020-04-19	Dino Reichel	dino.reichel@geemail.com	Baltimore	Maryland	51381853253229885	9612525fb7557357bd429787774d7765	Voyager	39.302630562195553	-76.5594148373249936
20742	2020-04-19 21:35:36	2020-04-19	Tiney Ondricka	tiney.ondricka@warmmail.com	Glendale	California	3498998514306917	397481e1b250f2799d2676b4427f7e93	JCB 16 digit	34.1277494297116988	-118.329846818083155
20743	2020-04-19 21:47:46	2020-04-19	Verena Block DDS	verena.block.dds@geemail.com	Wilmington	North Carolina	4741680320640256	41e659f1edec62c99576e362efbb4d9a	American Express	34.110074940725049	-77.8375520416062301
20744	2020-04-19 22:20:54	2020-04-19	Lynn Conn	lynn.conn@woohoo.com	San Antonio	Texas	3112682793407326938	9655c15dd07924b1f961c6a27e097aa2	VISA 16 digit	29.5101768268343072	-98.5502690186094412
20745	2020-04-19 22:30:02	2020-04-19	Kash Thiel-Murphy	kash.thiel.murphy@geemail.com	Berkeley	California	869999168344804452	d895fa170fd7911ff03220f38de1ed22	JCB 16 digit	37.8541892087756935	-122.241777076153753
20746	2020-04-19 22:38:59	2020-04-19	Michaele Fadel MD	michaele.fadel.md@geemail.com	Greeley	Colorado	4166645300546936	0d762f6443d5d3ff2690a6bb47b67241	JCB 16 digit	40.3944222507134114	-104.756419207558778
20747	2020-04-19 22:40:19	2020-04-19	Ferd Bogisich	ferd.bogisich@geemail.com	San Francisco	California	3337778837117111083	54043edf0e40732065d38e5927041ecb	JCB 16 digit	37.7410433304058728	-122.444604146544933
20748	2020-04-19 22:47:55	2020-04-19	Cleone Steuber	cleone.steuber@geemail.com	Durham	North Carolina	501812659616812	42581e76da60749e405bb43a41cbf66b	VISA 13 digit	36.0092095344107577	-78.9569088737849114
20749	2020-04-19 23:04:18	2020-04-19	Javier Pollich	javier.pollich@geemail.com	Warren	Michigan	3112945332402119858	1e23e0d8e8398e5693abb0d9eb090ff7	American Express	42.4724668145641644	-83.0623248970136103
20750	2020-04-19 23:27:37	2020-04-19	Hadassah Roob-Morar	hadassah.roob.morar@warmmail.com	Shreveport	Louisiana	3158429831840279666	55e964b74d504fac9352aba587d53a14	American Express	32.3971699298132236	-93.8920390002641767
20751	2020-04-19 23:29:13	2020-04-19	Lane Harber	lane.harber@geemail.com	Costa Mesa	California	6011394031782439326	092bce24d392740a4129c5e62377458a	VISA 13 digit	33.7060766614522791	-117.815017897389083
20752	2020-04-19 23:31:00	2020-04-19	Elvia Becker-Olson	elvia.becker.olson@geemail.com	Santa Maria	California	4847892272527893	ee3e4baf1b9f0a0b257be3774481cb94	VISA 16 digit	34.9445641378004126	-120.432455343651768
20753	2020-04-19 23:32:30	2020-04-19	Danita Gerlach	danita.gerlach@geemail.com	Fremont	California	52230667392854574	2b58a45fde4e5873808e7ae6dd5123d9	JCB 15 digit	37.5599330569785081	-121.869990763905264
20754	2020-04-19 23:39:42	2020-04-19	Leroy Murphy I	leroy.murphy.i@geemail.com	Berkeley	California	3528414684046000973	dc47194649c302e9be93019e820f279a	Maestro	37.8520925204962992	-122.269846392046247
20755	2020-04-19 23:41:05	2020-04-19	Lynnette Hilpert	lynnette.hilpert@geemail.com	Houston	Texas	3112973162077574771	1d4668afe5537da144a0d93bff23c5a2	JCB 16 digit	29.8233065453436232	-95.3612013624995996
20756	2020-04-19 23:42:24	2020-04-19	Shirlee Medhurst	shirlee.medhurst@woohoo.com	Nashville	Tennessee	6011412968082973280	fa8ee596f4c307a4952ecb6d5cdbc489	Mastercard	36.0949089023873171	-86.8493772836774554
20757	2020-04-19 23:44:09	2020-04-19	Tayla Price	tayla.price@geemail.com	Greensboro	North Carolina	869936848321042848	d6f62f88f654998329e21e05c1a97308	VISA 13 digit	36.1038325800210274	-79.738941653490059
20758	2020-04-20 00:00:56	2020-04-20	Mr. Rosco Romaguera DVM	mr.rosco.romaguera.dvm@woohoo.com	Lakewood	New Jersey	869947191511738058	7b63c25e276d862727bf09c379c233e7	Discover	40.1622526767946795	-74.1440850669328171
20759	2020-04-20 00:16:12	2020-04-20	Stephanie Ratke	stephanie.ratke@geemail.com	San Francisco	California	4899334578527704	aa7d147acaa42290aae77a09b23d582c	Mastercard	37.7707154302488561	-122.441270896452252
20760	2020-04-20 00:39:52	2020-04-20	Barry Koepp	barry.koepp@woohoo.com	New York	New York	3040734981376449	56bf547aef705215168c34620a421478	JCB 15 digit	40.577022355817256	-74.0149471118941875
20761	2020-04-20 00:39:54	2020-04-20	Clemie Ortiz	clemie.ortiz@geemail.com	San Francisco	California	3046468182753478	ff93434ea94d5ee25c1d5ec6b3a65274	Maestro	37.7736707847875124	-122.438409222242896
20762	2020-04-20 00:50:38	2020-04-20	Camryn Witting	camryn.witting@geemail.com	Green Bay	Wisconsin	3735097197406684	325cfe47195a427602565c577a0c0cc6	Discover	44.5401352048914845	-88.0043634081080626
20763	2020-04-20 01:16:08	2020-04-20	Arsenio Pacocha	arsenio.pacocha@geemail.com	Phoenix	Arizona	3096143053494210526	22a6f74887eb7254b869f14e5a6e704f	VISA 13 digit	33.6135136871531657	-112.06961468820684
20764	2020-04-20 01:31:16	2020-04-20	Blair Schmitt	blair.schmitt@geemail.com	Paterson	New Jersey	4146322883776190	edaf45da4bca11ec11bda1a0b827bb1c	JCB 16 digit	40.9341537666928019	-74.1011454821072562
20765	2020-04-20 01:36:38	2020-04-20	Coby Gleason	coby.gleason@woohoo.com	Berkeley	California	6011777252877829299	9462eddefbae91c04eb29ab6015454c0	Voyager	37.8631226782992556	-122.305204985614537
20766	2020-04-20 01:39:57	2020-04-20	Linnie Murphy	linnie.murphy@geemail.com	Baltimore	Maryland	3735912645617049	ef0f1afae76b2f1ab3afa487ce48b4bd	VISA 16 digit	39.3839000456966417	-76.6399621899258392
20767	2020-04-20 01:46:45	2020-04-20	Stanton King-Block	stanton.king.block@geemail.com	Hayward	California	869964862625783721	e1e9c598f84c6a7746d8bde832221cc9	Discover	37.6381308396801373	-122.092580904697627
20768	2020-04-20 01:47:45	2020-04-20	Mr. Orley Bogan Jr.	mr.orley.bogan.jr.@woohoo.com	Austin	Texas	53179990548560348	9785274715557fb6d3e2a0504d715921	VISA 16 digit	30.2111879552841174	-97.673990106513358
20769	2020-04-20 01:49:31	2020-04-20	Dr. Parthenia Zboncak	dr.parthenia.zboncak@warmmail.com	West Jordan	Utah	6011476784180501581	1085f7751b9fa1bb98a8893c37a9a0d2	VISA 16 digit	40.5123339744541795	-111.977350742145632
20770	2020-04-20 02:12:29	2020-04-20	Braedon Moore	braedon.moore@geemail.com	Austin	Texas	4105128252199933	3baae404a0e658ce8bcdb2173bacd371	Discover	30.2891889557369041	-97.7449001186300137
20771	2020-04-20 02:33:43	2020-04-20	Newton Deckow	newton.deckow@warmmail.com	Chicago	Illinois	4664188442125951	20cbd60fa5e020d78840d95cd391db67	VISA 13 digit	41.7758902293466079	-87.5872193496704057
20772	2020-04-20 02:47:10	2020-04-20	Kyara Larkin	kyara.larkin@woohoo.com	Murrieta	California	060420186014526	9fdeefedc7b21e005f22d92fc963cf26	Maestro	33.5989486266955737	-117.263712530014658
20773	2020-04-20 03:18:06	2020-04-20	Dr. Jerry Effertz PhD	dr.jerry.effertz.phd@warmmail.com	Colorado Springs	Colorado	4345526645556398	725c2afb19cd64319dc49b3892786cb2	VISA 13 digit	38.8510071899324672	-104.755195507283133
20774	2020-04-20 03:22:58	2020-04-20	Toshio Willms	toshio.willms@geemail.com	Stamford	Connecticut	3436522142973024	bae24c44f678726d899717da928e798a	VISA 16 digit	41.0515089200228473	-73.6165124821979617
20775	2020-04-20 03:31:50	2020-04-20	Isabela Luettgen	isabela.luettgen@geemail.com	New York	New York	869929977369112426	3281920dcfe85ea498f6d250aae44745	Diners Club / Carte Blanche	40.6165181348789446	-73.9608803789958387
20776	2020-04-20 03:38:49	2020-04-20	Vergil D'Amore	vergil.d'amore@geemail.com	Orlando	Florida	3775445742992362	73f8690d9c20b666a46955d185699b89	VISA 16 digit	28.4146212768074129	-81.2508018157411414
20777	2020-04-20 03:40:07	2020-04-20	Tyrese Kuvalis-Ward	tyrese.kuvalis.ward@geemail.com	Fort Lauderdale	Florida	561253048545940	a20b4e22842197e561eb3c694991ae49	American Express	26.1197715213511152	-80.1016749605823293
20778	2020-04-20 03:42:54	2020-04-20	Fate Deckow	fate.deckow@woohoo.com	San Francisco	California	4188349578506581	ceb9c45e258aab162f3ff15620916a5e	VISA 16 digit	37.7626651470665919	-122.388370800517208
20779	2020-04-20 03:51:55	2020-04-20	Clementine Cremin	clementine.cremin@woohoo.com	Baltimore	Maryland	51319934950881900	b9d6556059ab010a8ce2766cf02992ec	Voyager	39.3697331061586695	-76.6749460928626405
20780	2020-04-20 04:00:21	2020-04-20	Blaze Aufderhar	blaze.aufderhar@geemail.com	Oakland	California	3528840703387669974	32e2c17c8695c0cbcb81e98d31ceb696	Voyager	37.8193672302250334	-122.279852233675655
20781	2020-04-20 04:02:12	2020-04-20	Russ Rolfson MD	russ.rolfson.md@geemail.com	Sacramento	California	3096936757551842671	e729cc758d2d2b15bc87d1a0cb091084	American Express	38.5573705174759027	-121.41784564738758
20782	2020-04-20 04:13:10	2020-04-20	Makhi Roberts	makhi.roberts@geemail.com	San Francisco	California	4040503884708	d3fa01e6ee66c0888f7f853264bcd760	Voyager	37.7647900182919543	-122.455423797136078
20783	2020-04-20 04:28:08	2020-04-20	Tomie Raynor IV	tomie.raynor.iv@geemail.com	Athens	Georgia	55684890767279950	88e91b3efac7a31fe1be142a9096d5a5	Diners Club / Carte Blanche	34.0275785426333499	-83.4658140357699239
20784	2020-04-20 04:29:16	2020-04-20	Shirley Weissnat	shirley.weissnat@warmmail.com	Miami Gardens	Florida	3088937296877212748	ffd5c0ff13c37ab9e010635ca120204a	JCB 16 digit	26.028842680476231	-80.3215921007808333
20785	2020-04-20 05:03:28	2020-04-20	Rosella Bosco	rosella.bosco@woohoo.com	Bellevue	Washington	4490971971257	96490f2510c9518b90293d0924c87794	Discover	47.6031729014772935	-122.10004968392289
20786	2020-04-20 05:22:23	2020-04-20	Zadie Keeling DVM	zadie.keeling.dvm@warmmail.com	Santa Maria	California	869922094400254121	2a3fe28d83b5c4b316dc3decf344ee8f	VISA 16 digit	34.8940474990352953	-120.389208296771343
20787	2020-04-20 05:27:29	2020-04-20	Doyle Schmidt	doyle.schmidt@geemail.com	Sacramento	California	3158813168379643069	2f8222050bd3da806ce2d38226a98aa7	VISA 13 digit	38.5998060149405191	-121.486226615241165
20788	2020-04-20 05:37:59	2020-04-20	Kirstin Mueller	kirstin.mueller@geemail.com	Portland	Oregon	4985670731639	6c87a350503654110de0ede79945b0fc	VISA 16 digit	45.576079941436646	-122.642306986963376
20789	2020-04-20 05:43:23	2020-04-20	Galen Kub	galen.kub@geemail.com	Little Rock	Arkansas	210060279625834756	d84b810e294cd946f391f24ab0efb8a4	VISA 13 digit	34.6279502601172808	-92.3299424752000704
20790	2020-04-20 06:03:58	2020-04-20	Mireya Jacobs	mireya.jacobs@geemail.com	Dallas	Texas	3724896118342149	0d09eb7ad1c93859eda1d3f31dc7f6fc	Diners Club / Carte Blanche	32.8211001596219845	-96.7611798605378652
20791	2020-04-20 06:05:18	2020-04-20	Dr. Nan VonRueden DVM	dr.nan.vonrueden.dvm@geemail.com	Laredo	Texas	6011676830205482873	47d6c5fd57535d576a87c7aced1b6f7f	Voyager	27.5541179222237318	-99.4489097627352834
20792	2020-04-20 06:07:14	2020-04-20	Donato Baumbach	donato.baumbach@geemail.com	Los Angeles	California	4771118031114546	810e6194123707c458fa94738bb1db47	Diners Club / Carte Blanche	34.030665159072349	-118.404959124465648
20793	2020-04-20 06:20:13	2020-04-20	Ephram Goodwin-Spencer	ephram.goodwin.spencer@geemail.com	Los Angeles	California	52982171601878805	9ee1a063d82ad96c25a152686a802c6d	VISA 16 digit	34.0946196157351125	-118.415470149367295
20794	2020-04-20 06:21:29	2020-04-20	Eber Haag	eber.haag@geemail.com	Columbus	Ohio	676206130373522	0ba75e5a13aea3156c8146b583279594	Discover	39.9881870749451238	-82.9253066779349126
20795	2020-04-20 06:31:43	2020-04-20	Freda Weimann	freda.weimann@geemail.com	Wichita	Kansas	4329962422586128	db6216c64cadfb47b1b496eb7b15b30c	Diners Club / Carte Blanche	37.618357527709378	-97.4129933662448053
20796	2020-04-20 06:33:53	2020-04-20	Roe Prosacco	roe.prosacco@geemail.com	Los Angeles	California	6011779701332496027	ef72863f0c03cabfbc8c386cea27e5d3	JCB 16 digit	33.966029087440667	-118.348291773068894
20797	2020-04-20 06:46:29	2020-04-20	Marsha Hilpert PhD	marsha.hilpert.phd@geemail.com	San Francisco	California	6011175254222872741	b4af6c62178c9eef5d4ff931c54ebeb0	American Express	37.8036151336773969	-122.391233082803936
20798	2020-04-20 06:46:35	2020-04-20	Geoffrey Beer III	geoffrey.beer.iii@geemail.com	Denver	Colorado	3796807166545114	c683ac2015fb0214fb58df65322a4d07	Discover	39.6911779613751889	-104.865743798321489
20799	2020-04-20 06:55:12	2020-04-20	Amberly Dietrich-Bernhard	amberly.dietrich.bernhard@geemail.com	Los Angeles	California	6011439641130736715	d04212daf155f2b70e05ef2e3661ce8d	JCB 15 digit	34.1041025158815074	-118.496612621936194
20800	2020-04-20 06:56:44	2020-04-20	Nakia Hagenes	nakia.hagenes@geemail.com	Detroit	Michigan	3528660243619623785	be0c5bb0a8109c1f575c801d169b96bc	Discover	42.4642450390774755	-83.1834393264845033
20801	2020-04-20 07:13:13	2020-04-20	Dr. Mikalah Welch DVM	dr.mikalah.welch.dvm@geemail.com	Columbus	Ohio	52467219559681921	9bfc5bd1e7092e6e27954698655e1c5f	VISA 13 digit	39.9295649815395493	-82.9029888021994452
20802	2020-04-20 07:18:57	2020-04-20	Mrs. Sarrah Kertzmann MD	mrs.sarrah.kertzmann.md@warmmail.com	San Francisco	California	210009276327314446	4ef21ef56f248cfdca8ec34bb3e0cdf3	VISA 16 digit	37.7695696258593898	-122.411627708729213
20803	2020-04-20 07:21:37	2020-04-20	Barnie Ritchie	barnie.ritchie@geemail.com	Houston	Texas	3495075057515437	1cf6512902d9a0e6586b7e449cc9451c	Mastercard	29.699136130379884	-95.4231138190269519
20804	2020-04-20 07:22:08	2020-04-20	Pattie Mante	pattie.mante@geemail.com	Oakland	California	3096739818014873379	6d020f0c35e38c3e877f33edb5717cb2	Voyager	37.8153599105848244	-122.270780835573262
20805	2020-04-20 07:39:10	2020-04-20	Rexford Hettinger	rexford.hettinger@warmmail.com	San Francisco	California	52458663765042314	059e5a4eea11065c15a88d862773c212	Discover	37.7909306407367467	-122.434249845897469
20806	2020-04-20 07:48:07	2020-04-20	Barnard Lesch	barnard.lesch@geemail.com	San Francisco	California	3409388396029282	4c76bb4a21e6cb8e7afb7b2cf7f63bb0	Discover	37.7688831371660925	-122.435208967149876
20807	2020-04-20 08:09:25	2020-04-20	Dr. Gladis Schaefer	dr.gladis.schaefer@warmmail.com	Spokane	Washington	6011380582728249100	051ee8efff6b5125a9ffa792d99e40b2	JCB 15 digit	47.7351607743423401	-117.528727713822576
20808	2020-04-20 08:28:18	2020-04-20	Adda McKenzie	adda.mckenzie@woohoo.com	Dallas	Texas	55921745660370376	6f2a794ea29ba81497e194cdc113a7ff	Maestro	32.7915381724752493	-96.7376562948301313
20809	2020-04-20 08:32:24	2020-04-20	Mr. Leeroy Powlowski Sr.	mr.leeroy.powlowski.sr.@warmmail.com	San Francisco	California	639080225180290	1cd80dfb9212b390e15551c749d8df15	Maestro	37.7942935576955961	-122.430459450539772
20810	2020-04-20 08:43:18	2020-04-20	Madilynn Leffler	madilynn.leffler@geemail.com	Los Angeles	California	869940205600672205	6dd339a2077c3a30a2387af07e6fc742	VISA 16 digit	33.9502478921186182	-118.443944696243108
20811	2020-04-20 08:54:00	2020-04-20	Madeline Lueilwitz-Schultz	madeline.lueilwitz.schultz@geemail.com	Anaheim	California	6011312685250586386	950770c2ab768e64bec970ff1b43fe4c	Diners Club / Carte Blanche	33.8800483155362286	-117.726851456260675
20812	2020-04-20 08:56:33	2020-04-20	Dr. Beatriz Jakubowski	dr.beatriz.jakubowski@geemail.com	San Jose	California	4230849134347238	2231a5f070edef5809b30f82e2588605	Maestro	37.3469377035561934	-121.797507086511331
20813	2020-04-20 09:15:22	2020-04-20	Faith Jacobi-Witting	faith.jacobi.witting@geemail.com	Memphis	Tennessee	675930145641426	45264cc5ffd7f5b040ec632a2770a313	Voyager	35.1915180156540117	-89.9462182542566211
20814	2020-04-20 09:21:33	2020-04-20	Bradly Abbott	bradly.abbott@geemail.com	Los Angeles	California	55832005946324384	56c94e7480b97c85f03f8964860c2948	JCB 15 digit	34.0532006209116389	-118.320763671769939
20815	2020-04-20 09:22:11	2020-04-20	Dr. Eveline Orn	dr.eveline.orn@warmmail.com	Chicago	Illinois	54218619611746384	faccd7ea5e0d9f68a09f1eb8a21c2097	Voyager	41.8073080267127608	-87.7038800100360021
20816	2020-04-20 09:28:52	2020-04-20	Winifred Kemmer	winifred.kemmer@geemail.com	Houston	Texas	55412187439341980	7cf50df96d714f750ad7c9e02a50bad6	Mastercard	29.8036519329141818	-95.4518290568623655
20817	2020-04-20 09:31:10	2020-04-20	Girtha Quitzon	girtha.quitzon@woohoo.com	San Jose	California	4569374869352601	5c55748b026015e8b9dd1b9b9b875c0e	VISA 16 digit	37.251773292134331	-121.901523356767001
20818	2020-04-20 09:31:40	2020-04-20	Alexus Nikolaus	alexus.nikolaus@geemail.com	Nashville	Tennessee	3337380271263968080	a2d6ffd1e2de7db8a05bf104b891b73c	American Express	36.2238792946219448	-86.7991262764576845
20819	2020-04-20 09:34:37	2020-04-20	Marius Lynch PhD	marius.lynch.phd@geemail.com	San Antonio	Texas	6011038562406650726	f87af1a23fc069df456b5cf3e444d5a4	Diners Club / Carte Blanche	29.4940161196585748	-98.5387276017874427
20820	2020-04-20 09:48:47	2020-04-20	Genoveva Kutch	genoveva.kutch@woohoo.com	Berkeley	California	3088763442751128324	59e8069fee6635effdffc7dd979225e6	Voyager	37.8395418360428337	-122.281585444348579
20821	2020-04-20 09:50:55	2020-04-20	Mr. Jaydin Sipes I	mr.jaydin.sipes.i@geemail.com	Miami	Florida	53388472017006688	f5e7ddf99310b8971fbaab28206ee83c	JCB 15 digit	25.8440706673681753	-80.1226469883102936
20822	2020-04-20 10:11:16	2020-04-20	Miss Ieshia Grimes	miss.ieshia.grimes@woohoo.com	Chicago	Illinois	4134070124312416	8eb4380b24570debb7e93edd64281e20	American Express	41.7411670703276982	-87.7043583956111235
20823	2020-04-20 10:17:13	2020-04-20	Dr. Tobe Bartell	dr.tobe.bartell@geemail.com	San Diego	California	54120803411781273	d71b8f72d99aa556c31fd5df25bc1d91	Voyager	32.7871223595526047	-117.170585788590842
20824	2020-04-20 10:25:34	2020-04-20	Irine Haley	irine.haley@geemail.com	Washington	District of Columbia	3158716463814570391	26e66bfffdc1a46c17f49be3f1c9dd86	American Express	38.8451024012438921	-77.077202349549907
20825	2020-04-20 10:35:15	2020-04-20	Tasha Mueller DVM	tasha.mueller.dvm@geemail.com	New York	New York	4701572161795	32f84bdb7292482fd20999ae69e84453	JCB 15 digit	40.6918590064384063	-73.8894842810824457
20826	2020-04-20 10:46:40	2020-04-20	Dr. Wilburn Crooks DVM	dr.wilburn.crooks.dvm@geemail.com	Las Vegas	Nevada	4290924023747587	6ae7b0dd28aa9f08d66f12128981a1ec	JCB 15 digit	36.2027412989743027	-115.305455967618514
20827	2020-04-20 11:02:17	2020-04-20	Velma Fisher	velma.fisher@woohoo.com	Berkeley	California	4832301664211	dd54d52100468924f612556ab7c91e1d	VISA 16 digit	37.8706597095475175	-122.276328735099057
20828	2020-04-20 11:06:35	2020-04-20	Lucie Quigley-Kerluke	lucie.quigley.kerluke@geemail.com	Mesquite	Texas	639099035844416	2275111b03a507e387925bccbd5a91c6	JCB 16 digit	32.768438452602922	-96.5295147429417852
20829	2020-04-20 11:17:10	2020-04-20	Mr. Jameel Reynolds	mr.jameel.reynolds@geemail.com	Independence	Missouri	4699285822290576	bec4f7a649a75410614e5070e4fd1bf6	VISA 13 digit	39.1643479908369514	-94.3719843208607188
20830	2020-04-20 11:27:58	2020-04-20	Ms. Aliza Bartoletti PhD	ms.aliza.bartoletti.phd@geemail.com	Louisville	Kentucky	180087697843166629	e030a0781be58f9b927629b3a4ac46dd	VISA 16 digit	38.0872852761201557	-85.6729338577087987
20831	2020-04-20 11:28:08	2020-04-20	Lotta West	lotta.west@geemail.com	Louisville	Kentucky	4137550920703220	b026397e8fe188f1263a5340adb7a570	Discover	38.1456701666019811	-85.5834082242172229
20832	2020-04-20 11:36:02	2020-04-20	Mr. Nigel Hartmann IV	mr.nigel.hartmann.iv@geemail.com	Santa Ana	California	55298473714502051	b2262b2b008fa80f2a087cfac5494d0f	Discover	33.659187799097225	-117.787181569116186
20833	2020-04-20 11:37:47	2020-04-20	Kindra Waters	kindra.waters@warmmail.com	Cambridge	Massachusetts	869930515253915111	3ab0017646e549ffa71d3a23a56e2f57	JCB 16 digit	42.3359606522824592	-71.1725088576868217
20834	2020-04-20 11:43:07	2020-04-20	Mrs. Vicy Gusikowski MD	mrs.vicy.gusikowski.md@geemail.com	Houston	Texas	51609819203241029	292a4da50869134829f89ab082d2d903	JCB 16 digit	29.725277645148708	-95.3180442121826133
20835	2020-04-20 11:43:18	2020-04-20	Mr. Delos Morar PhD	mr.delos.morar.phd@geemail.com	San Francisco	California	6011767020964243001	2e1a3692924420c5de98d7bfe694d336	VISA 16 digit	37.7463108694547103	-122.428278797337938
20836	2020-04-20 12:00:27	2020-04-20	Lary Gerhold	lary.gerhold@geemail.com	Corpus Christi	Texas	210039905235721383	3ca296768a79c917a7e04b0fe54ece6a	JCB 15 digit	27.7862272703956812	-97.2379022036973453
20837	2020-04-20 12:03:39	2020-04-20	Parker Donnelly	parker.donnelly@geemail.com	Charleston	South Carolina	4615495907653926	a82f49f8f37a17729138e8a9ab520ea9	VISA 16 digit	32.8903722437560546	-79.9494657396487867
20838	2020-04-20 12:20:49	2020-04-20	Minna Murphy	minna.murphy@geemail.com	Seattle	Washington	869942577256826071	bd36263a9171ddd438fc84bf92b461de	VISA 16 digit	47.5996870765387996	-122.288379510251431
20839	2020-04-20 12:34:21	2020-04-20	Zack Ziemann	zack.ziemann@woohoo.com	Killeen	Texas	210073801760205925	8968b2bfdfd5e6ef08bee4fd29a5f98a	JCB 15 digit	31.1295545782659211	-97.6671955222897168
20840	2020-04-20 12:39:37	2020-04-20	Ananias Satterfield	ananias.satterfield@geemail.com	New York	New York	3096943505221506163	15f6a4fbce39879e3a65e754896b597d	American Express	40.6990947305913977	-73.9770681374136387
20841	2020-04-20 12:41:29	2020-04-20	Hennie Lindgren	hennie.lindgren@geemail.com	New York	New York	3057956630891659	e7a04cd0991ba869bb0848d6b6e3bffa	VISA 13 digit	40.5952926542367791	-73.9949943525146665
20842	2020-04-20 12:41:36	2020-04-20	Miss Chanie Lemke DVM	miss.chanie.lemke.dvm@warmmail.com	Fullerton	California	4096558656741966	f8d49b8da69757b16e518a715f20cbdc	Mastercard	33.833488766166198	-117.91187127718888
20843	2020-04-20 12:44:02	2020-04-20	Mr. Damien Prosacco	mr.damien.prosacco@geemail.com	Henderson	Nevada	4202946685577009	2f70eda3b6485b77cba4dca0251fa874	JCB 15 digit	36.0525181950468578	-115.021930684630576
20844	2020-04-20 13:03:10	2020-04-20	Rance Batz	rance.batz@geemail.com	Beaumont	Texas	4450218953930	58a9c69c686767736f40c697cb13f611	JCB 16 digit	30.070768024593221	-94.2452938808381617
20845	2020-04-20 13:03:58	2020-04-20	Handy West	handy.west@geemail.com	Los Angeles	California	3429998604931255	53b474beb97bba4396ab0a63eb0d9aff	JCB 16 digit	33.9643470563325991	-118.32589789568371
20846	2020-04-20 13:07:59	2020-04-20	Teagan Herman	teagan.herman@geemail.com	Pompano Beach	Florida	6011795087082038015	879cab9539ad743ed3545d147181f284	Voyager	26.1504454339653236	-80.1224784078855095
20847	2020-04-20 13:30:47	2020-04-20	Miss Gayla Okuneva	miss.gayla.okuneva@woohoo.com	Chicago	Illinois	4918828929730	823a0a255b014913ab9138197c0f5835	VISA 16 digit	41.776787164558101	-87.717932209794597
20848	2020-04-20 13:31:08	2020-04-20	Ryder Lubowitz	ryder.lubowitz@geemail.com	Dallas	Texas	180029940620999627	09926ad52c87b80c7e9033a2bc511b0a	Maestro	32.7350740733828403	-96.6849012314770277
20849	2020-04-20 13:34:51	2020-04-20	Estill Bergstrom-Boyer	estill.bergstrom.boyer@woohoo.com	San Diego	California	3158997810101531298	60f3e83c322a384a41c5603a028315a3	JCB 16 digit	32.7499465370617813	-117.043010243484758
20850	2020-04-20 13:34:55	2020-04-20	Cris Price-Cummerata	cris.price.cummerata@geemail.com	San Francisco	California	6011448008457436742	59a470c8e20c28c1d27d859f119b36c2	Discover	37.7672894133087951	-122.428503604744137
20851	2020-04-20 13:55:33	2020-04-20	Zina Balistreri	zina.balistreri@geemail.com	Sandy Springs	Georgia	3528742954920412476	f5dde408b1009ffa81c9b66bfdd7a182	JCB 16 digit	34.0241360035780787	-84.2993570760440178
20852	2020-04-20 14:07:51	2020-04-20	Prudie Miller	prudie.miller@warmmail.com	Los Angeles	California	3747086007541877	a35122a0c566ff26eb23f0bec386b439	Voyager	34.016981858420742	-118.338091111787776
20853	2020-04-20 14:19:04	2020-04-20	Burnice Schimmel DDS	burnice.schimmel.dds@geemail.com	New York	New York	3492463502848962	7fb29f64480472dbc71c141bdaf2d74a	American Express	40.6962758859377374	-74.0137282333232491
20854	2020-04-20 14:19:29	2020-04-20	Jalen Thiel	jalen.thiel@warmmail.com	Oklahoma City	Oklahoma	869986686384894427	282c95e5decf4dc76f8282a87659e853	JCB 16 digit	35.5465706726446768	-97.4204808026447893
20855	2020-04-20 14:34:28	2020-04-20	Tamie Quitzon-Ruecker	tamie.quitzon.ruecker@geemail.com	Gresham	Oregon	060428126330605	353ddbfc4ca7c0b5467794c9e7c98743	Maestro	45.4393784742757632	-122.461883983135593
20856	2020-04-20 14:42:55	2020-04-20	Slade Rempel	slade.rempel@geemail.com	Boston	Massachusetts	4756418204316	a0c4c1c4d4e0a42a8d15a7b43103fac1	JCB 16 digit	42.4272173881698436	-70.9793245596297169
20857	2020-04-20 14:58:34	2020-04-20	Sharon Mante	sharon.mante@woohoo.com	Miramar	Florida	869938269246535873	a40d1056433d28bb4e5107ba61af466d	VISA 16 digit	25.9964802347105	-80.3267973050467674
20858	2020-04-20 15:06:59	2020-04-20	Ms. Jessye Morissette	ms.jessye.morissette@geemail.com	Pomona	California	3158536111780270227	a9e41761ad2ae44fadb98572448f6e0d	VISA 16 digit	34.0397375064007974	-117.727133422108736
20859	2020-04-20 15:09:11	2020-04-20	Annemarie Halvorson	annemarie.halvorson@geemail.com	Memphis	Tennessee	3048762083731213	2f4b5a39f6de32e85c8a75548ce18e30	Mastercard	35.1191530287798486	-89.9021104214038758
20860	2020-04-20 15:19:17	2020-04-20	Karim Runte	karim.runte@woohoo.com	Inglewood	California	4381888301660426	fba6a45c11c2a736bbd85741bb0b568e	VISA 16 digit	33.9973484384607545	-118.4234055789683
20861	2020-04-20 15:33:25	2020-04-20	Dr. Cinda Corwin DDS	dr.cinda.corwin.dds@geemail.com	Little Rock	Arkansas	180096333672433984	21365c08cc20df554f1dfd7ed27c36ed	JCB 16 digit	34.6265640395503524	-92.2964172106575234
20862	2020-04-20 15:34:16	2020-04-20	Phoenix Schneider	phoenix.schneider@woohoo.com	Philadelphia	Pennsylvania	4795204009315	b75ecf39d59959488888c4b2e05448a4	Diners Club / Carte Blanche	40.0696771315258005	-75.0646097941223616
20863	2020-04-20 15:43:34	2020-04-20	Jamar Boehm	jamar.boehm@geemail.com	Buffalo	New York	3027898353828999	b988d80f4e7622cca97db7aef5c2a4ce	Diners Club / Carte Blanche	42.8401309786084994	-78.9213537173744299
20864	2020-04-20 15:57:34	2020-04-20	Ms. Tisha Abshire DDS	ms.tisha.abshire.dds@woohoo.com	Henderson	Nevada	6011631958747824593	a1d09334dd2b12d94690a78b3f4d6c14	Voyager	35.9397468743778816	-115.038830453266215
20865	2020-04-20 16:17:16	2020-04-20	Elian McGlynn	elian.mcglynn@warmmail.com	Jersey City	New Jersey	180019757794214050	89af65e7940d22372a970957c8f97f5a	JCB 15 digit	40.7095432313565126	-73.9685071047816507
20866	2020-04-20 16:21:32	2020-04-20	Blake Feest	blake.feest@geemail.com	San Francisco	California	4116501701957712	cea502f45a96658872c0276b9d5661bd	Voyager	37.7803216842875926	-122.417547301808369
20867	2020-04-20 16:31:52	2020-04-20	Tyler Powlowski	tyler.powlowski@geemail.com	Milwaukee	Wisconsin	869941175013759551	68fbf380990303d2f5f4b2e06be1f827	American Express	42.9840693277392489	-87.9563503809839489
20868	2020-04-20 16:47:42	2020-04-20	Dr. Benjman Collins	dr.benjman.collins@geemail.com	Baltimore	Maryland	3158633250595982634	3c6eb80f3b9ef91d88af69e2b4b3c18e	VISA 16 digit	39.2721633705310467	-76.5652617805190374
20869	2020-04-20 17:00:00	2020-04-20	Warren Rutherford-Kozey	warren.rutherford.kozey@warmmail.com	Worcester	Massachusetts	3014338762266732	3d54f6413d9d98ef5774fa7fc996dc22	Voyager	42.360479268075899	-71.7871355362489822
20870	2020-04-20 17:13:11	2020-04-20	Lexi Carroll	lexi.carroll@woohoo.com	San Francisco	California	54348778159162579	1dad57dc157b9422b15c8e64258e8f0b	JCB 15 digit	37.7779183365100124	-122.43488396951831
20871	2020-04-20 17:35:16	2020-04-20	Jammie McCullough-Fadel	jammie.mccullough.fadel@woohoo.com	Davenport	Iowa	060413317554486	994de68ad1e0070e8aeb43380d75a808	Discover	41.5118003380749343	-90.6953755174260579
20872	2020-04-20 17:36:19	2020-04-20	Loris Hartmann	loris.hartmann@geemail.com	Tucson	Arizona	6011701354134210650	0ab82a67d7ea8bd46f6529cc863c5b9b	JCB 16 digit	32.1062737448181963	-110.896494024735318
20873	2020-04-20 17:39:04	2020-04-20	Marnie Frami	marnie.frami@warmmail.com	El Paso	Texas	869938392255425677	82ff56ec455caf19ba5e0cf351c9c47f	American Express	31.7504893950015337	-106.365757107453433
20874	2020-04-20 17:43:45	2020-04-20	Babyboy Hills	babyboy.hills@warmmail.com	Mesa	Arizona	6011542634349801218	c0617f24a7a7a59ac1ba3f70113f24c3	VISA 13 digit	33.3486674534302168	-111.69208126956373
20875	2020-04-20 18:01:00	2020-04-20	Birtie Lubowitz	birtie.lubowitz@warmmail.com	Mesa	Arizona	180078596052325259	742b0976a9a4225b6b91036961b87e92	VISA 16 digit	33.4945082295365637	-111.72499744634851
20876	2020-04-20 18:06:06	2020-04-20	Heaven Bartell	heaven.bartell@geemail.com	Toledo	Ohio	4695814055567832	1946bf00d8c0639607f2139fb357fb90	American Express	41.6461420618634648	-83.5148884909093425
20877	2020-04-20 18:11:58	2020-04-20	Izetta Kuhn-Casper	izetta.kuhn.casper@warmmail.com	Pittsburgh	Pennsylvania	52288714271972688	57494950bb5e7d7bbce75a9699fac014	Voyager	40.4169725693717581	-80.0559034596368662
20878	2020-04-20 18:17:58	2020-04-20	Jedidiah Schuster	jedidiah.schuster@geemail.com	Houston	Texas	4282375387362036	66a3d522ac66c912af3174bfa2533ced	Discover	29.6903917896639555	-95.342445863179492
20879	2020-04-20 18:30:33	2020-04-20	Dr. Texas Murray DVM	dr.texas.murray.dvm@geemail.com	San Francisco	California	676303730767427	7a3b16743c3650c7c3f93c798dc05a71	American Express	37.7865231092812905	-122.453956325087205
20880	2020-04-20 18:32:43	2020-04-20	Katerina Fay	katerina.fay@woohoo.com	Mesa	Arizona	3096439347661803524	b53af728bae9fd5b5dccee599f477139	Mastercard	33.3704332749038883	-111.62185974855683
20881	2020-04-20 18:40:58	2020-04-20	Bernetta Simonis	bernetta.simonis@geemail.com	Jacksonville	Florida	4823530099822844	caacf269d9a6a91d7b08da427f57c3bb	Discover	30.2502020083885625	-81.5895474909417402
20882	2020-04-20 18:48:46	2020-04-20	Jahiem Walsh III	jahiem.walsh.iii@geemail.com	San Francisco	California	675903906218114	b3a1e3a0f207932e85f508d8368bfd6e	Diners Club / Carte Blanche	37.7935051041256571	-122.411245681934062
20883	2020-04-20 18:58:57	2020-04-20	Sara Schinner DDS	sara.schinner.dds@geemail.com	Berkeley	California	630433310048757	8ab6dd800ac987aa341b612e55dd6f67	VISA 13 digit	37.8827127743494074	-122.274572905609261
20884	2020-04-20 19:12:04	2020-04-20	Mr. Woodrow Koepp	mr.woodrow.koepp@geemail.com	Charlotte	North Carolina	6011583826674868388	e5c1f09aa308d23ee22c72abd656b252	Maestro	35.1357640991706361	-80.830030450265852
20885	2020-04-20 19:31:18	2020-04-20	Alferd Hegmann	alferd.hegmann@geemail.com	Indianapolis	Indiana	51761142337194681	343ebd140bd3d9b40dfa0881daec84d1	American Express	39.8598468818243603	-86.1279803477894461
20886	2020-04-20 19:48:35	2020-04-20	Laverne Marvin-Hermann	laverne.marvin.hermann@warmmail.com	Santa Clarita	California	4925785276922	32f1e2d3db09050100ed8b120925f4b7	Mastercard	34.419429741401224	-118.504984936640412
20887	2020-04-20 19:52:59	2020-04-20	Desirae Labadie	desirae.labadie@geemail.com	Columbus	Ohio	3031497993966966	b71a9e9eea0435a7f04fc714764f7fb9	VISA 16 digit	39.995175851094352	-82.9904635205168404
20888	2020-04-20 19:54:58	2020-04-20	Dr. Shan Hagenes	dr.shan.hagenes@woohoo.com	Colorado Springs	Colorado	210006590144579806	a550b8da106c570530c4c4c2ee59a1f4	JCB 15 digit	38.8237824844710531	-104.845408969760683
20889	2020-04-20 19:55:44	2020-04-20	Dr. Dori Simonis MD	dr.dori.simonis.md@warmmail.com	Augusta	Georgia	4913937978215373	9700b8906f255d6cb9e81449ba90635a	VISA 16 digit	33.4357295954339193	-82.1691772972528014
20890	2020-04-20 20:05:48	2020-04-20	Zebulon Mann	zebulon.mann@geemail.com	Lakeland	Florida	55670471914400736	67259152ff4a70853de0eb393947fb2d	Discover	28.1082021346148103	-81.92956755025088
20891	2020-04-20 20:08:41	2020-04-20	Abigail Wolff	abigail.wolff@warmmail.com	Toledo	Ohio	4123631248630	7d2e689b7b5b2a086ddd47e0ede38a45	JCB 16 digit	41.5734988930806466	-83.5849927210580574
20892	2020-04-20 20:08:50	2020-04-20	Magnolia Morar	magnolia.morar@warmmail.com	Chicago	Illinois	639091631518650	0e172927a9a480d6abae314a8a481b11	VISA 13 digit	41.8036808806307647	-87.6073180606618536
20893	2020-04-20 20:20:07	2020-04-20	Cassandra Torphy	cassandra.torphy@geemail.com	Baltimore	Maryland	3012630297271985	758ea277c1f5a78b748a87cfb7bbef7a	Mastercard	39.3209798470139447	-76.593127732539557
20894	2020-04-20 20:22:51	2020-04-20	Harlen Schroeder	harlen.schroeder@geemail.com	Austin	Texas	3158005318856893772	f6f345179c03a05b19da9e8ca51344cf	VISA 16 digit	30.2188608578067246	-97.8363627442862906
20895	2020-04-20 20:29:41	2020-04-20	Bev Pfannerstill PhD	bev.pfannerstill.phd@warmmail.com	McKinney	Texas	4678547758340435	892a4da6fa356e264c3a6e4dcb383bc8	JCB 15 digit	33.2980361268054708	-96.7064299145080213
20896	2020-04-20 20:37:52	2020-04-20	Stewart McClure	stewart.mcclure@geemail.com	Spokane	Washington	3055577538838089	af7359194f33e40d20350b44b57d637f	VISA 16 digit	47.6495913710683539	-117.426506416023898
20897	2020-04-20 20:40:26	2020-04-20	Fisher McDermott-Gulgowski	fisher.mcdermott.gulgowski@woohoo.com	Atlanta	Georgia	3726363979190107	f1dba6ffa2e8cbbb9985c5999cb3cfd2	VISA 13 digit	33.8419321649983544	-84.3624932133637486
20898	2020-04-20 20:54:17	2020-04-20	Ms. Athena Gleason	ms.athena.gleason@geemail.com	New York	New York	3096740868052243289	b7b9fe785d2eb6cf2e4f43c6a2c4d85f	Diners Club / Carte Blanche	40.6147224218808134	-73.8492443837121044
20899	2020-04-20 21:03:29	2020-04-20	Margarita Jenkins	margarita.jenkins@geemail.com	Lakewood	New Jersey	4833708710552564	456f7eaf7f135e85849a9831f7e9517b	American Express	40.0963698128521457	-74.2608588927701163
20900	2020-04-20 21:11:32	2020-04-20	Leamon Cartwright	leamon.cartwright@warmmail.com	Virginia Beach	Virginia	4082116403200822	6c4b057fb4abca356f5a57c8acd0c814	JCB 16 digit	36.6914614091347886	-76.0761336069691936
20901	2020-04-20 21:24:03	2020-04-20	Alf Walker Sr.	alf.walker.sr.@geemail.com	Houston	Texas	3746528269639122	dcb4c966a00778a865b51fc982c3d21c	VISA 13 digit	29.8002697979178279	-95.365733263410263
20902	2020-04-20 21:41:47	2020-04-20	Ollie Stracke	ollie.stracke@geemail.com	Santa Clara	California	53032788092498098	1c79b87f7bc026cfa723dab8bc7e0409	VISA 16 digit	37.3511221712272672	-121.893537425854802
20903	2020-04-20 21:49:58	2020-04-20	Miss Jesse West	miss.jesse.west@warmmail.com	Phoenix	Arizona	676290877268111	c09331c34fba70bd706fc51017fcfdeb	VISA 16 digit	33.6218870142407766	-112.158707821920899
20904	2020-04-20 22:35:34	2020-04-20	Janine Goodwin	janine.goodwin@geemail.com	San Francisco	California	6011436013945055355	c4a980a6db87361fdb8070bd6db8dd55	Maestro	37.7394348188282294	-122.462181153281378
20905	2020-04-20 22:43:55	2020-04-20	Dr. Eugene Keebler	dr.eugene.keebler@geemail.com	San Francisco	California	869963660513707146	6cf3fd4fb37e370db2736b308f144917	JCB 15 digit	37.7297355599352713	-122.42642257169328
20906	2020-04-20 22:47:37	2020-04-20	Loula Bailey	loula.bailey@geemail.com	San Francisco	California	52962824863876206	e56430e81a3827ddf5744e42b8c2ce65	VISA 16 digit	37.7744087373964632	-122.459214517759676
20907	2020-04-20 23:06:50	2020-04-20	Orren Wisoky-Runte	orren.wisoky.runte@geemail.com	Los Angeles	California	4578743217312	717dea0e370f900981cce04b9ce51018	VISA 16 digit	33.9717911803495127	-118.34538478334359
20908	2020-04-20 23:13:07	2020-04-20	Ms. Reta Feest	ms.reta.feest@geemail.com	New York	New York	53020611039913330	c98f5c81f2b7910006be7864af878a6e	American Express	40.6907206122986977	-74.0214740578446566
20909	2020-04-20 23:14:43	2020-04-20	Aldo Halvorson	aldo.halvorson@woohoo.com	San Francisco	California	3337827184833121000	52ad3422c9a9cc65c1c1d8e6c658de63	JCB 16 digit	37.7978313758479061	-122.375800160683681
20910	2020-04-20 23:21:40	2020-04-20	Danielle Schowalter	danielle.schowalter@geemail.com	Berkeley	California	4348959999463373	d00f4f39623d6d87c4f8a3dfb0bb05b6	VISA 16 digit	37.856351211427608	-122.275924070384292
20911	2020-04-20 23:25:19	2020-04-20	Cinnamon Bradtke DDS	cinnamon.bradtke.dds@geemail.com	Austin	Texas	3764924964077907	aad9eebef40deaf79ca5bcaedd66553b	VISA 16 digit	30.2951183546461138	-97.8009376232285064
20912	2020-04-20 23:37:06	2020-04-20	Dr. Sammy Herman IV	dr.sammy.herman.iv@woohoo.com	Los Angeles	California	4483295579448822	4f92be04fb2cc0075cae9200bdacc6ff	VISA 16 digit	34.0869844683311882	-118.361004552523781
20913	2020-04-20 23:48:08	2020-04-20	Dr. Ewing McDermott	dr.ewing.mcdermott@geemail.com	Berkeley	California	675900335000303	789783e930ec9b6994ce581cc1910beb	VISA 13 digit	37.8669743067781468	-122.285497685253006
20914	2020-04-20 23:51:14	2020-04-20	Mckinley Denesik	mckinley.denesik@geemail.com	El Paso	Texas	3027144407703221	97ab840cd4eb824fc524327b32f7fd2d	JCB 15 digit	31.8124116801485428	-106.363339437682185
20915	2020-04-20 23:55:47	2020-04-20	Josefita Kautzer	josefita.kautzer@geemail.com	New Orleans	Louisiana	869933626065541362	bea95dd9ee15ff7e923a3dafd579b8b4	Discover	30.1011297160308793	-89.94755569512769
20916	2020-04-21 00:07:44	2020-04-21	Judyth Price	judyth.price@warmmail.com	Detroit	Michigan	55473985075866970	75cdd407cb1cf99d33cf74a450639768	Diners Club / Carte Blanche	42.4766234665568945	-83.0788383379697706
20917	2020-04-21 00:14:38	2020-04-21	Kristan Lynch PhD	kristan.lynch.phd@warmmail.com	Houston	Texas	3016737344489969	393fe032e283406202942d78501fdb08	Maestro	29.7446855483654886	-95.3218855673927834
20918	2020-04-21 00:17:24	2020-04-21	Zetta Rice	zetta.rice@geemail.com	Fresno	California	54040877760056328	fa7f7a635db92b1113a8ea0015b29e76	Voyager	36.8296618332959724	-119.852313458092141
20919	2020-04-21 00:29:43	2020-04-21	Camren Fisher	camren.fisher@woohoo.com	McAllen	Texas	4545511304622911	8bc3a28140f563ffaa2efd78487a2355	Maestro	26.1711905951451484	-98.275164881193632
20920	2020-04-21 00:31:47	2020-04-21	Lena Tillman-Brekke	lena.tillman.brekke@woohoo.com	New York	New York	869957488190946946	2c57ce30fe8efd59cbedaf50f0e46c00	American Express	40.7052974874842874	-73.8544186812255532
20921	2020-04-21 00:41:31	2020-04-21	Ernst Schoen	ernst.schoen@geemail.com	Fort Worth	Texas	3766185956350896	a18886e7a9581f351d006940bb6d831b	Mastercard	32.7910641338732134	-97.3561147134572309
20922	2020-04-21 00:42:15	2020-04-21	Miss Evelynn Cronin	miss.evelynn.cronin@geemail.com	Oakland	California	869905608940341154	0f3473ca173378a4358bf336f9b67814	JCB 16 digit	37.8254125548055029	-122.292009593113704
20923	2020-04-21 00:55:26	2020-04-21	Dr. Velvet Daniel	dr.velvet.daniel@geemail.com	Irvine	California	180052909430687854	d5b93489b3c9c6fb2323badf8b650a94	Voyager	33.5909761140603607	-117.796838909481835
20924	2020-04-21 01:01:30	2020-04-21	Mrs. Margy Carter	mrs.margy.carter@geemail.com	Chicago	Illinois	3112270846004452776	8729e4df4f91151fe9330cc384f674cf	Maestro	41.8005689270164851	-87.6390692126966968
20925	2020-04-21 01:12:01	2020-04-21	Mr. Marcelino Yost	mr.marcelino.yost@geemail.com	Baltimore	Maryland	4508175096132599	8a76612923ccf79880a9f58e9939b905	JCB 16 digit	39.2842023918405161	-76.577410900035872
20926	2020-04-21 01:12:55	2020-04-21	Dr. Deon Rogahn II	dr.deon.rogahn.ii@geemail.com	Los Angeles	California	6011971722930841113	346bbd208c5727dfc89d6aa5ca95c303	Voyager	33.9895631739269888	-118.406305727874113
20927	2020-04-21 01:29:15	2020-04-21	Byrd Watsica	byrd.watsica@geemail.com	Berkeley	California	869952483067987243	4f8e3e3abf8ae807c8d462fbee030590	VISA 13 digit	37.8664657681565728	-122.246093196259238
20928	2020-04-21 01:37:24	2020-04-21	Mr. Armond Witting	mr.armond.witting@woohoo.com	Honolulu	Hawaii	3044765737840649	17f62884cc2d49bd805bffc6716f6e54	JCB 16 digit	21.3039847695484781	-157.784977728475269
20929	2020-04-21 01:51:57	2020-04-21	Dr. Myron Douglas MD	dr.myron.douglas.md@warmmail.com	New York	New York	4231603838382945	39938ba47137e540ba8e407444d07a24	JCB 16 digit	40.7247857511267028	-74.0341659833107144
20930	2020-04-21 02:03:49	2020-04-21	Justus Daugherty	justus.daugherty@geemail.com	New York	New York	6011859260328290954	d09245c21e0957abbebb823f5cd01543	JCB 16 digit	40.7264742097575194	-73.9139285236492753
20931	2020-04-21 02:41:18	2020-04-21	Tara Bernier-McDermott	tara.bernier.mcdermott@woohoo.com	Aurora	Colorado	3046926236232633	b26293a5038bcce622b6671771826def	JCB 16 digit	39.7781877230033274	-104.666071947303422
20932	2020-04-21 02:49:48	2020-04-21	Dr. Tristian Baumbach Sr.	dr.tristian.baumbach.sr.@geemail.com	San Francisco	California	869929101388076575	358b84725399796f781c2a326e5e408e	Mastercard	37.7520340082794661	-122.431518335997438
20933	2020-04-21 02:54:57	2020-04-21	Dr. Filomena Bergstrom PhD	dr.filomena.bergstrom.phd@geemail.com	El Paso	Texas	52303963276749648	4c55e664ce3e1899ebd27a55a17a5f80	JCB 16 digit	31.9131701791953297	-106.387267468774695
20934	2020-04-21 02:58:51	2020-04-21	Mr. Alan Hudson III	mr.alan.hudson.iii@warmmail.com	Waco	Texas	6011684017285133663	018df46e2db5d920c2f887e48ff94f6b	American Express	31.5161891765169777	-97.1904051019474906
20935	2020-04-21 03:01:40	2020-04-21	Aurore Koepp-Bernhard	aurore.koepp.bernhard@geemail.com	Phoenix	Arizona	4447247242956116	0675d98edab16cc34d0cbb9f7491c8c3	Discover	33.6056285418503009	-112.122321165951348
20936	2020-04-21 03:06:58	2020-04-21	Julie Jaskolski	julie.jaskolski@warmmail.com	Jacksonville	Florida	180032389390731650	08a2c59dd3aca15aea18d2bc560a2279	JCB 15 digit	30.2839217760652311	-81.6565764230754354
20937	2020-04-21 03:44:47	2020-04-21	Miss Jazlyn Corwin DDS	miss.jazlyn.corwin.dds@geemail.com	Indianapolis	Indiana	3158218796811473561	7e3ec01d69e57c55fb10e733c6ba022b	JCB 15 digit	39.846657283698022	-86.1396752135563588
20938	2020-04-21 03:48:52	2020-04-21	Sandy Jones	sandy.jones@warmmail.com	Irving	Texas	3096646015552496950	a925163bbae86a9e2789084c257b1697	Maestro	32.7979152055408818	-96.9156158453598664
20939	2020-04-21 03:56:22	2020-04-21	Cristofer McCullough	cristofer.mccullough@geemail.com	Fullerton	California	6011677081982100853	e97ca17c35b4ae7ae24110c461db6643	Diners Club / Carte Blanche	33.8795263301737606	-118.008963273579255
20940	2020-04-21 04:11:26	2020-04-21	Epsie Schmitt MD	epsie.schmitt.md@geemail.com	Hialeah	Florida	54292892543878166	f85b7e3991093852d877e2fdd270c299	Maestro	25.7826863467671004	-80.2782644217271297
20941	2020-04-21 04:15:49	2020-04-21	Ms. Gertha Sporer	ms.gertha.sporer@geemail.com	New York	New York	3528567569314541797	5d3d6bf2b20a0af54b4dc94dd05582c3	VISA 13 digit	40.6681626654919199	-73.8529628374509457
20942	2020-04-21 04:17:29	2020-04-21	Darline Hahn	darline.hahn@geemail.com	San Jose	California	3769200893085526	d2270e1e1ae74b1bd30ef0270ff75495	Diners Club / Carte Blanche	37.3905788224477362	-121.774978640138727
20943	2020-04-21 04:29:37	2020-04-21	Harrie O'Kon	harrie.o'kon@geemail.com	Lubbock	Texas	210072510397763443	6c179a4626cc72154f260556f904af5d	JCB 16 digit	33.5782485202927177	-101.818087096736591
20944	2020-04-21 04:41:32	2020-04-21	Gorge Nienow	gorge.nienow@woohoo.com	Colorado Springs	Colorado	3014654856176268	5b4d10830b7f802209ce02f28d1a1edc	American Express	38.8089251615621151	-104.737960975819078
20945	2020-04-21 04:45:00	2020-04-21	Tobi Krajcik	tobi.krajcik@warmmail.com	Las Vegas	Nevada	4559848798489	3dc8d0dfd36ab7017245a5575d9992b2	JCB 15 digit	36.2267702163763303	-115.209582762115076
20946	2020-04-21 04:50:17	2020-04-21	Glinda Orn	glinda.orn@geemail.com	New York	New York	4965144861008117	fef38f8185cc2225b628889b9e6fedba	Diners Club / Carte Blanche	40.5680057777781045	-73.8855670460861091
20947	2020-04-21 04:55:30	2020-04-21	Lizzie Pacocha-Rice	lizzie.pacocha.rice@geemail.com	Houston	Texas	4360916735648611	cc06c5db9df452d5a95292b83539e204	VISA 13 digit	29.696272794910147	-95.32794698779621
20948	2020-04-21 05:03:31	2020-04-21	Ximena D'Amore-Stark	ximena.d'amore.stark@geemail.com	Mesa	Arizona	4421557951336734	44ca0ba3903c0faf82cce3c12bbe92d6	Maestro	33.3081249704264053	-111.643563682155303
20949	2020-04-21 05:08:36	2020-04-21	Verl Gleason-Zemlak	verl.gleason.zemlak@geemail.com	San Francisco	California	6011633524740582121	9c6d76b719a2c9926fb92fcd76bf2812	Maestro	37.794880979309724	-122.447533531563721
20950	2020-04-21 05:16:46	2020-04-21	Lyndon Jaskolski-Stokes	lyndon.jaskolski.stokes@woohoo.com	San Diego	California	3012325716220941	164eb30910a3aba99657e27b2db00da3	Voyager	32.7359916605588026	-117.205317753031849
20951	2020-04-21 05:18:13	2020-04-21	Braiden Torphy-Jast	braiden.torphy.jast@geemail.com	Santa Clarita	California	3088981847867302462	2c2574d0ed545a6bd52e802ad7b10a97	JCB 16 digit	34.4339532511979343	-118.540161622418836
20952	2020-04-21 05:23:53	2020-04-21	Mellisa Little	mellisa.little@geemail.com	Denver	Colorado	4634919749548249	5b88bd61a0082cfa8f36eec24719a6da	VISA 13 digit	39.6879719259269521	-104.824200082548344
20953	2020-04-21 05:29:34	2020-04-21	Ms. Becky Luettgen PhD	ms.becky.luettgen.phd@woohoo.com	Los Angeles	California	561257576788517	2547a3e5d6230806765e4ccaafa0f83a	VISA 16 digit	33.9237569242116024	-118.363968997447927
20954	2020-04-21 05:43:41	2020-04-21	Mrs. Victorine Boyer PhD	mrs.victorine.boyer.phd@woohoo.com	Santa Clarita	California	869996523088040411	a44e302394cdb70841fab889200553fb	VISA 16 digit	34.498749545749277	-118.535130493399492
20955	2020-04-21 05:44:54	2020-04-21	Miss Trista Davis DDS	miss.trista.davis.dds@woohoo.com	Fort Worth	Texas	676350425692097	90d3e89ea478fd2a3c7a9168b151907a	JCB 16 digit	32.870032548211519	-97.2471504218697476
20956	2020-04-21 05:56:46	2020-04-21	Elbert Olson-Schulist	elbert.olson.schulist@geemail.com	Warren	Michigan	53464131417303015	5f4c974b74d334df2476d937db08d397	Mastercard	42.4981691923454363	-83.0290690046735165
20957	2020-04-21 05:58:57	2020-04-21	Beverley Heidenreich	beverley.heidenreich@geemail.com	New Orleans	Louisiana	6011248742818185364	eccc95828655000035e67dab5f68caa2	Mastercard	29.9923103821013122	-89.8640509293209817
20958	2020-04-21 06:19:10	2020-04-21	Ola Gottlieb	ola.gottlieb@warmmail.com	Baltimore	Maryland	4853282757139	155d8d85e4fd790e3901ef7a2fd3a91a	VISA 13 digit	39.2913758273236411	-76.5842387835048157
20959	2020-04-21 06:30:08	2020-04-21	Johnnie Bogisich	johnnie.bogisich@geemail.com	Houston	Texas	3021900707690731	6824f927c1e45899ea323709a1760e65	VISA 13 digit	29.7837307366620756	-95.4547745295815133
20960	2020-04-21 06:32:23	2020-04-21	Josiah Hilpert V	josiah.hilpert.v@geemail.com	Long Beach	California	53612388331713254	e111acba02f6eb444f549ff0c37820e8	VISA 16 digit	33.8149289824821011	-118.092793151938537
20961	2020-04-21 06:42:19	2020-04-21	Antionette Funk PhD	antionette.funk.phd@warmmail.com	Oakland	California	3158309380304569126	3412dfe4814794abba01857598c9d342	Diners Club / Carte Blanche	37.8048345152293948	-122.245559631143152
20962	2020-04-21 07:04:43	2020-04-21	Frederic Tillman	frederic.tillman@geemail.com	Arvada	Colorado	53481350323165891	8639a952d3ab12ed2aa14004eea47dc6	JCB 15 digit	39.8902406806301357	-105.1619479117889
20963	2020-04-21 07:06:24	2020-04-21	Shawnda Streich-Durgan	shawnda.streich.durgan@geemail.com	Pembroke Pines	Florida	3096221747870947438	a410d65ff1c39025b3edd4306f7b5f37	JCB 16 digit	25.933377934716642	-80.4184241501051957
20964	2020-04-21 07:14:25	2020-04-21	Charly Hermiston	charly.hermiston@geemail.com	San Francisco	California	6011842240034222160	4aae504530712954a2703658caa63215	Diners Club / Carte Blanche	37.7915622667511499	-122.445203488957119
20965	2020-04-21 07:18:06	2020-04-21	Gracia Paucek	gracia.paucek@geemail.com	Phoenix	Arizona	869973159781437013	7b3032cdafbcd9a60cbc98cd686aca6d	Diners Club / Carte Blanche	33.6015376523070088	-112.130854821570594
20966	2020-04-21 07:18:37	2020-04-21	Ellyn Beier-Olson	ellyn.beier.olson@woohoo.com	Los Angeles	California	3337057050291832837	500fc7b89d2b47db2c79783c71ddc6a7	American Express	33.9583817480929184	-118.328893615444372
20967	2020-04-21 07:28:47	2020-04-21	Golden Runolfsson-Jenkins	golden.runolfsson.jenkins@woohoo.com	Atlanta	Georgia	6011976151650947931	ad6e13df9d6ce609b78bab251c23bda1	JCB 16 digit	33.6896814547289196	-84.3477586290843817
20968	2020-04-21 07:30:06	2020-04-21	Carmel Brekke	carmel.brekke@woohoo.com	New York	New York	51549090867737115	e28c04e2319a0a35d7c82b3853446cb7	Maestro	40.6514142266232525	-73.8524067405972602
20969	2020-04-21 07:35:13	2020-04-21	Mr. Candido Dickens DVM	mr.candido.dickens.dvm@woohoo.com	Denton	Texas	4157190141448	6752e416999ae49ddde5a0c5beb5e0f7	Mastercard	33.287950350929421	-97.1278928223192679
20970	2020-04-21 07:47:13	2020-04-21	Miss Madilyn O'Connell MD	miss.madilyn.o'connell.md@geemail.com	Berkeley	California	6011354148007592719	318ae4cca1f3de199b2c2ea94a4cf468	Diners Club / Carte Blanche	37.902779113538088	-122.274161322579232
20971	2020-04-21 07:49:36	2020-04-21	Kacey Schiller	kacey.schiller@geemail.com	Las Vegas	Nevada	210006387186028879	56f108ffc256700150b9c071febf6e87	American Express	36.2103642445623848	-115.266096460607272
20972	2020-04-21 08:11:41	2020-04-21	Latonya Gorczany DDS	latonya.gorczany.dds@warmmail.com	Spokane	Washington	3337352221521677274	b3c2ceb7723ee93f600981ba7f7f2ecc	American Express	47.670250705746561	-117.36261759743951
20973	2020-04-21 08:12:19	2020-04-21	Vincenza Harvey	vincenza.harvey@geemail.com	Berkeley	California	639007218571250	aff9585630b33181e9455dafcb1b92cb	VISA 13 digit	37.8574798104939774	-122.29046908895495
20974	2020-04-21 08:22:24	2020-04-21	Miss Byrd Baumbach MD	miss.byrd.baumbach.md@geemail.com	Plano	Texas	869912208777482220	05e1dc38bc3c919f25e1175056e37d79	Voyager	33.0221455218821802	-96.742274081073333
20975	2020-04-21 08:40:01	2020-04-21	Lisha Davis-Langworth	lisha.davis.langworth@geemail.com	San Francisco	California	180056952604170840	ae104fdc2e18a64db14cb00f9da30794	Discover	37.8096738803787318	-122.399896636062607
20976	2020-04-21 08:49:22	2020-04-21	Beula Luettgen PhD	beula.luettgen.phd@geemail.com	Columbus	Ohio	676120201157599	7898c4cfca1dd992f78d9ba002aa9a2b	Maestro	40.0701141948390713	-83.0576763285558712
20977	2020-04-21 09:00:24	2020-04-21	Gaither Weimann	gaither.weimann@warmmail.com	Indianapolis	Indiana	54180390516659148	0d2357d61bcca95960a8c3528319cd71	Mastercard	39.7865884658887978	-86.1608153822101599
20978	2020-04-21 09:00:35	2020-04-21	Lynda Hauck	lynda.hauck@geemail.com	Tampa	Florida	3793123396396135	c4db0d2ba9eb7988d81e740cf2e16cb6	Voyager	27.9112294685211033	-82.5211389909710675
20979	2020-04-21 09:50:06	2020-04-21	Dr. Mazie Grant	dr.mazie.grant@warmmail.com	Oklahoma City	Oklahoma	3465478859975062	c4db7d968846ff421cd3a4a39cfc6f1f	Discover	35.4020962810520103	-97.5230369581270935
20980	2020-04-21 09:52:19	2020-04-21	Joretta Dickens	joretta.dickens@geemail.com	New York	New York	4779171090623	5d346d81bdeaf9aca057aa8be14bb6fe	JCB 16 digit	40.585577678283677	-73.9079333559971303
20981	2020-04-21 09:55:26	2020-04-21	Ms. Cayla Glover PhD	ms.cayla.glover.phd@geemail.com	Tucson	Arizona	180090577904328067	3f31fc5a782fc5ae2dc7b8e88172b642	Voyager	32.1688595375552779	-110.9231080550462
20982	2020-04-21 09:58:51	2020-04-21	Ms. Albina Cartwright PhD	ms.albina.cartwright.phd@geemail.com	San Francisco	California	51203811855515230	6d6ba5e5e5d62fe57595b339eec33d8b	Discover	37.7547264515356247	-122.472105839330936
20983	2020-04-21 10:34:02	2020-04-21	Rutha Altenwerth	rutha.altenwerth@geemail.com	San Antonio	Texas	675951301225986	690542afe5851c87fb0d2823474c5fae	VISA 13 digit	29.4088660013932746	-98.4418323034256701
20984	2020-04-21 10:39:48	2020-04-21	Mr. Emile Gerlach	mr.emile.gerlach@geemail.com	San Francisco	California	3337043757089019222	bfc223a5c62b99b3d062e98426376021	JCB 16 digit	37.7714374090342133	-122.409288668749539
20985	2020-04-21 10:41:25	2020-04-21	Jessee Legros	jessee.legros@woohoo.com	Huntington Beach	California	3528639774177681185	5b266ac75fe85bbaf235ec40133ae28f	Mastercard	33.7636840224772712	-117.989669034269824
20986	2020-04-21 10:59:08	2020-04-21	Cristofer Casper	cristofer.casper@woohoo.com	San Antonio	Texas	4897187620686	ff696dd04756fb954506ac56d410eb57	American Express	29.5339509636234503	-98.5828034532558064
20987	2020-04-21 11:01:11	2020-04-21	King Mertz	king.mertz@warmmail.com	Houston	Texas	3790785782943747	ff0e833a5ab9b3fd5401f75b18763d0c	VISA 16 digit	29.6914350517638042	-95.3987248074743945
20988	2020-04-21 11:06:53	2020-04-21	Malvin Franecki	malvin.franecki@warmmail.com	Amarillo	Texas	6011264116923439835	014967f2c7a0d0610a2a706408576f70	Discover	35.2364131423808615	-101.841806317432599
20989	2020-04-21 11:12:09	2020-04-21	Zenobia Streich-Konopelski	zenobia.streich.konopelski@geemail.com	San Francisco	California	3491061868414618	084235e6d12be7aaabd2b5f5d7a456d1	Discover	37.7481214448331244	-122.450723843684131
20990	2020-04-21 11:27:54	2020-04-21	Jude Luettgen	jude.luettgen@geemail.com	Worcester	Massachusetts	3773163989261878	02a470670e5a7b3426219f99b9d2eb34	Diners Club / Carte Blanche	42.2245398651976132	-71.8230809707447833
20991	2020-04-21 11:36:01	2020-04-21	Darryle Olson	darryle.olson@geemail.com	Palm Bay	Florida	180029720540664141	8b22ce256f380e2b372fb801dd381560	Discover	28.0572955346986674	-80.5968189125716634
20992	2020-04-21 11:40:34	2020-04-21	Idabelle Spencer	idabelle.spencer@geemail.com	Las Vegas	Nevada	4945533453144	d8a4fe869be1d0960e35f3344553487c	VISA 16 digit	36.20004959442727	-115.297138951087732
20993	2020-04-21 11:41:51	2020-04-21	Marylouise Lynch	marylouise.lynch@geemail.com	Newark	New Jersey	3045497756483031	60d95d6d2acb820e17cf66a3189b15f8	VISA 13 digit	40.8228694565042858	-74.0789732535578338
20994	2020-04-21 11:54:45	2020-04-21	Tallie Predovic	tallie.predovic@geemail.com	Nashville	Tennessee	869911698809281064	3702048fc12ffa03b3f59c1e1040c3b7	American Express	36.1781807583413979	-86.8848524072579949
20995	2020-04-21 12:05:42	2020-04-21	Lanny Will	lanny.will@geemail.com	Clearwater	Florida	6011967218343456207	a0c4e407a54b17213c20cbebf9d61e0a	JCB 15 digit	27.9173048784151661	-82.8293245178446114
20996	2020-04-21 12:13:24	2020-04-21	Clementine Keeling	clementine.keeling@geemail.com	Virginia Beach	Virginia	4146624455937096	0809fe5dfdf9aacc0be9e58e48561a91	Voyager	36.7360484878253217	-76.1123764429379293
20997	2020-04-21 12:17:09	2020-04-21	Arnold Mitchell	arnold.mitchell@geemail.com	Phoenix	Arizona	869951443030889687	08de0d4c90c8ecbaaeaa4cfbb2f88a2f	Diners Club / Carte Blanche	33.5308751543916799	-112.114826677360014
20998	2020-04-21 12:28:50	2020-04-21	Siobhan Schuppe-Lind	siobhan.schuppe.lind@geemail.com	El Paso	Texas	180065409498420178	acff652bbce9412394c7cf456c9dbce5	VISA 13 digit	31.8165903456337773	-106.460718492044137
20999	2020-04-21 12:45:31	2020-04-21	Gerardo Macejkovic	gerardo.macejkovic@geemail.com	Jersey City	New Jersey	6011166796374091687	bf3830131cb4219ba7738c76b8f0579f	Mastercard	40.7876213173788003	-74.0654443144753571
21000	2020-04-21 12:46:58	2020-04-21	Gustaf Eichmann	gustaf.eichmann@geemail.com	Gainesville	Florida	869973714150352837	1c52ef5817326f580bbc09eba7f96c81	Diners Club / Carte Blanche	29.608416197897121	-82.4054917638529218
21001	2020-04-21 13:10:10	2020-04-21	Ryleigh Barton	ryleigh.barton@geemail.com	Houston	Texas	4373993410830082	aa5f705cb1755967984ddbca05df1377	Discover	29.7074682130556553	-95.3376587285209496
21002	2020-04-21 13:12:27	2020-04-21	Lyric Kris	lyric.kris@woohoo.com	Oakland	California	676101935802098	95f5cbb598c8eaa5d9a38d9d54f7eaa3	American Express	37.7690167461310722	-122.215948412178392
21003	2020-04-21 13:13:23	2020-04-21	Maureen Jacobs	maureen.jacobs@warmmail.com	New York	New York	3088198356623789995	8a3181812848dcb3fb678cef48c8c86c	JCB 16 digit	40.5769694633074067	-74.0365051960002631
21004	2020-04-21 13:17:43	2020-04-21	Bryce Pagac-Kilback	bryce.pagac.kilback@geemail.com	Little Rock	Arkansas	3337757902611999931	ef6c5999b55b757bd452ad9526fbbdae	JCB 15 digit	34.6765811292730248	-92.4132964773442609
21005	2020-04-21 13:24:30	2020-04-21	Freda Metz	freda.metz@geemail.com	Columbia	Missouri	3741219402086109	046b70c0749113c645481a6c3f6f970a	JCB 16 digit	38.9910624264620793	-92.2296156427410523
21006	2020-04-21 13:37:28	2020-04-21	Dinah Gutkowski	dinah.gutkowski@geemail.com	Chicago	Illinois	3158552103993612963	ef6f40fc9147a9caf600470153e44c65	JCB 16 digit	41.7636092000942725	-87.6704379984207378
21007	2020-04-21 13:41:05	2020-04-21	Elenore Rolfson	elenore.rolfson@geemail.com	Wichita	Kansas	4038934950984795	524c1133bd09419e51eea1f74157aae0	Mastercard	37.6653401854790744	-97.3001955807875873
21008	2020-04-21 13:47:14	2020-04-21	Jeanine Bailey	jeanine.bailey@woohoo.com	Beaumont	Texas	3794156569365536	68e7c6139f77e69b389929b0edc5a280	JCB 15 digit	30.1778792460985485	-94.1601033858276963
21009	2020-04-21 13:47:43	2020-04-21	Prentiss Schmidt	prentiss.schmidt@warmmail.com	Oakland	California	3036848620252201	112bcbe41d61dc9f9afa6a38aec86acd	Mastercard	37.7861380418525457	-122.24968176930399
21010	2020-04-21 13:50:44	2020-04-21	Clint Lynch	clint.lynch@woohoo.com	Cincinnati	Ohio	3009021061189442	e2106f1483943c9c0ac635e51c55a0e8	Diners Club / Carte Blanche	39.1343683667246225	-84.5763141650512722
21011	2020-04-21 14:06:24	2020-04-21	Carmelo Deckow	carmelo.deckow@geemail.com	Broken Arrow	Oklahoma	3088562020785558808	7d69be20c199e80c458d43099f27f933	American Express	36.0964435172975016	-95.8321229532770928
21012	2020-04-21 14:16:36	2020-04-21	Jim Beier	jim.beier@warmmail.com	Boston	Massachusetts	6011850315973567822	0428ce22c4fd5d6a42f371bea81e5582	VISA 13 digit	42.2663584970105433	-70.9574960618231501
21013	2020-04-21 14:19:50	2020-04-21	Rubin VonRueden	rubin.vonrueden@geemail.com	Killeen	Texas	869909188817499878	de9d7a9ec21d6cdf58a3624a07af652f	Maestro	31.0717755649935441	-97.7498271682932938
21014	2020-04-21 14:21:08	2020-04-21	Miss Mckenzie Frami	miss.mckenzie.frami@woohoo.com	Oakland	California	4506621543886131	642e56775ee5d100fb8c0de2b3641b78	Maestro	37.7853543187868652	-122.288437232873278
21015	2020-04-21 14:26:49	2020-04-21	Dayse Hilpert	dayse.hilpert@warmmail.com	San Francisco	California	4311075635892157	cd8aa65100e4b33a36168dd65c1507d2	JCB 15 digit	37.8236967708688923	-122.447562877060548
21016	2020-04-21 14:40:14	2020-04-21	Mannie Spinka	mannie.spinka@warmmail.com	Richmond	Virginia	3042139154614865	6a0c5c12743662bd8882c97125542085	JCB 16 digit	37.4325208506766671	-77.494859217083075
21017	2020-04-21 14:46:45	2020-04-21	Kobe Barrows-Schmeler	kobe.barrows.schmeler@geemail.com	San Jose	California	4989552027848113	b8be28b66066fe35e35fffeea4075126	JCB 15 digit	37.2438313200891002	-121.904736634319278
21018	2020-04-21 14:49:14	2020-04-21	Amiah Steuber-Wehner	amiah.steuber.wehner@woohoo.com	New York	New York	3112475614139088326	2541ce8b3900184e85de18dd2b6ae102	JCB 16 digit	40.65505740197748	-73.9944034110184674
21019	2020-04-21 15:08:26	2020-04-21	Elfie Reichel	elfie.reichel@geemail.com	San Jose	California	52240029741020449	b05f9b5c321159cacf665d1de7f43d5d	American Express	37.3249873954158318	-121.842767114400488
21020	2020-04-21 15:14:56	2020-04-21	Anabelle Monahan	anabelle.monahan@geemail.com	San Francisco	California	4678774639769521	6358d4d24f5918a5d8a4ab7ba08c9ff8	VISA 13 digit	37.7411828071470126	-122.445387649566612
21021	2020-04-21 15:29:32	2020-04-21	Saniya Pollich	saniya.pollich@geemail.com	St. Petersburg	Florida	4339233492364	cad4542e1dda2d6a6281fc534a76536d	Mastercard	27.7211862696222973	-82.6843352134231395
21022	2020-04-21 15:34:59	2020-04-21	Anastacia Paucek	anastacia.paucek@geemail.com	Peoria	Arizona	060407101637275	65c59c93b13d815a20d390824950cc3d	Diners Club / Carte Blanche	33.7091607823304855	-112.316543230826042
21023	2020-04-21 15:38:01	2020-04-21	Jaeda Runte DVM	jaeda.runte.dvm@geemail.com	Philadelphia	Pennsylvania	4119128480298	e16c4b37d4070d77f65a319c4869d0a1	VISA 13 digit	39.9310951049398639	-75.1658383838731794
21024	2020-04-21 15:44:43	2020-04-21	Marlon Hermann	marlon.hermann@geemail.com	Albuquerque	New Mexico	3112721478550569806	f1af68f65e268a0b0eb3beb2ab70f818	Discover	35.1843900297436889	-106.620801829367508
21025	2020-04-21 15:44:48	2020-04-21	Ason Reichert	ason.reichert@geemail.com	Memphis	Tennessee	180040634789637954	3d70f4a30c8b21597740a0143885f6dc	Mastercard	35.1969584131680477	-90.023351664634049
21026	2020-04-21 15:50:45	2020-04-21	Flint Kiehn II	flint.kiehn.ii@geemail.com	New York	New York	3735319530818304	40659bcc39cd19fd50f325e30fa2848e	JCB 16 digit	40.5787383807580895	-73.8787428334716623
21027	2020-04-21 16:06:40	2020-04-21	Ms. Ebony Flatley DDS	ms.ebony.flatley.dds@woohoo.com	Houston	Texas	6011307384233460342	73e0cac213bd2dcc95645578eea0355f	VISA 16 digit	29.837152735663949	-95.3040897205021196
21028	2020-04-21 16:20:05	2020-04-21	Migdalia Harris	migdalia.harris@woohoo.com	Sacramento	California	3158379107541612715	2af61254e770ea64d136bc7dbb07cbd8	Diners Club / Carte Blanche	38.6617728329528134	-121.542823969783626
21029	2020-04-21 16:22:59	2020-04-21	Dr. Jameel Kuvalis	dr.jameel.kuvalis@geemail.com	San Francisco	California	3528497560053097583	279279fe811f1a4958588c72dd4017d0	VISA 16 digit	37.7689358198480036	-122.454253478205715
21030	2020-04-21 16:24:07	2020-04-21	Mr. Brain Fisher	mr.brain.fisher@geemail.com	Los Angeles	California	869999291900689354	cc9940bf763c3cf8103387d6711c2429	VISA 16 digit	34.0856485080771137	-118.452854604273284
21031	2020-04-21 16:24:34	2020-04-21	Christoper Wehner	christoper.wehner@warmmail.com	Cincinnati	Ohio	3096888257172419452	900484f9dc683930551f0d61f8804e83	Voyager	39.1632495422147215	-84.5755796449065116
21032	2020-04-21 17:12:14	2020-04-21	Orilla Howell	orilla.howell@warmmail.com	New York	New York	3158465954502496470	aa2b75c041ff85c4cb24b276d6a9a74e	American Express	40.6094333027247316	-73.9187470538903
21033	2020-04-21 17:15:16	2020-04-21	Gina Thompson-Runte	gina.thompson.runte@geemail.com	Anchorage	Alaska	210077157141564761	9aa6ea23b664c49b1928518eb5378de4	Discover	61.111105998580534	-149.36501459666826
21034	2020-04-21 17:17:15	2020-04-21	Delle Bartell	delle.bartell@geemail.com	San Francisco	California	3528627545406327913	63a1d747f3e511ac51dfcef7bf770dea	JCB 16 digit	37.7710653671143959	-122.417435996582938
21035	2020-04-21 17:27:51	2020-04-21	Miguelangel Grant	miguelangel.grant@geemail.com	West Palm Beach	Florida	4671561784867	e9b0611a850001cc42a2069b18655ae5	JCB 15 digit	26.7453229565486339	-80.2049336236271984
21036	2020-04-21 17:34:54	2020-04-21	Juliann Hilll	juliann.hilll@geemail.com	San Francisco	California	54403525323255215	77035697b6bfa8264bf785c0e44ee36c	American Express	37.7633448461146912	-122.414081548970657
21037	2020-04-21 17:38:53	2020-04-21	Dr. Lilie Kub	dr.lilie.kub@geemail.com	Los Angeles	California	3036887218627952	8c3bcf1bf4444fdc7dccff6e42a38a0b	VISA 16 digit	33.9341154712583872	-118.508662944193176
21038	2020-04-21 17:39:13	2020-04-21	Dereck Shanahan	dereck.shanahan@geemail.com	Pearland	Texas	3009000601909915	80e9b7091cf97b59f99994153a2bf0ec	Diners Club / Carte Blanche	29.6267382237866528	-95.2971776598453459
21039	2020-04-21 17:49:21	2020-04-21	Lashawn Nader	lashawn.nader@geemail.com	Omaha	Nebraska	3024321803218482	b34e296bebdf9321586704f8a3e6e54b	Mastercard	41.2056128610070829	-95.9558827999163526
21040	2020-04-21 17:50:51	2020-04-21	Son Wehner	son.wehner@geemail.com	Houston	Texas	6011370161844160285	3ae45a4dac93b6bc6a86e9efd2a15096	Mastercard	29.7593700311690554	-95.3323229592774055
21041	2020-04-21 18:02:43	2020-04-21	Guilford Little	guilford.little@geemail.com	Milwaukee	Wisconsin	869976860553902772	55726aafc90225fab0066ffc4cfbc010	JCB 16 digit	42.9938595061276061	-87.9278920269206168
21042	2020-04-21 18:07:07	2020-04-21	Mrs. Madaline Rau DVM	mrs.madaline.rau.dvm@warmmail.com	Lakeland	Florida	4445482867118666	a4e6f7e1fb224f933f0d9cfb02bc77db	VISA 16 digit	28.0742848847359419	-81.9232029289822918
21043	2020-04-21 18:46:20	2020-04-21	Brittani Reichel	brittani.reichel@geemail.com	Milwaukee	Wisconsin	4240366623938664	dfbd84f5eba9705b8e0476e485501e9a	VISA 16 digit	42.9874729214321789	-88.019949640297142
21044	2020-04-21 18:50:22	2020-04-21	Dr. Theadore Predovic	dr.theadore.predovic@geemail.com	New York	New York	3017305277774085	36400f039b8c0be15c255e86c913784f	VISA 16 digit	40.6130725585147729	-74.0320597911149179
21045	2020-04-21 19:15:32	2020-04-21	Tiesha Stoltenberg-Anderson	tiesha.stoltenberg.anderson@geemail.com	Columbus	Ohio	4196845661760894	99122ebe50f25b08c2353f0e8ab1ddef	Discover	39.9720696316145379	-82.9774389974076314
21046	2020-04-21 19:19:14	2020-04-21	Ms. Madisyn Smith DVM	ms.madisyn.smith.dvm@warmmail.com	San Francisco	California	3765781516159321	58aeea863a110f987e2f8d645479d7b1	Discover	37.8013901386689639	-122.460028489611119
21047	2020-04-21 19:20:00	2020-04-21	Kaci Watsica	kaci.watsica@geemail.com	Chicago	Illinois	3088926508909481825	3e078f98a3a9188adb9f9515614c5b85	Diners Club / Carte Blanche	41.8443443133331883	-87.7216163088597369
21048	2020-04-21 19:22:50	2020-04-21	Marcy Nitzsche	marcy.nitzsche@geemail.com	Los Angeles	California	869996931512183568	029a0f74ea4b397548f07878ce03217c	JCB 15 digit	33.9641441095020582	-118.461721329064289
21049	2020-04-21 19:28:19	2020-04-21	Daron Waters	daron.waters@woohoo.com	Surprise	Arizona	4471597801836698	d6e76545ae28f7bb8fae72e9f59cd5b1	Discover	33.5756729611422884	-112.4639092338968
21050	2020-04-21 19:53:31	2020-04-21	Hart Crona-White	hart.crona.white@geemail.com	New York	New York	3030365912886550	6a9b8432b4920a4f009e0bbab71b317d	Diners Club / Carte Blanche	40.7225560824144637	-73.9595475363440755
21051	2020-04-21 20:06:01	2020-04-21	Sullivan Hills	sullivan.hills@woohoo.com	Lafayette	Louisiana	3112098897437237664	24da9a2495b3e8e493c54d2f45350fe5	VISA 13 digit	30.1738993775542816	-91.99344759880006
21052	2020-04-21 20:10:03	2020-04-21	Jarvis Wisozk	jarvis.wisozk@geemail.com	San Francisco	California	3787632705785950	fe292969f2063ffd630d5ed7149cb2a9	VISA 16 digit	37.7509477432684903	-122.425628375878247
21053	2020-04-21 20:29:20	2020-04-21	Miss Jena Zemlak	miss.jena.zemlak@woohoo.com	Chattanooga	Tennessee	180013793850951950	a2252c05f8ca14c00f05c5c875ed74c8	VISA 13 digit	34.9956412965748456	-85.2934222343206443
21054	2020-04-21 20:32:36	2020-04-21	Miss Aylin Corkery PhD	miss.aylin.corkery.phd@warmmail.com	Macon	Georgia	4774040752990	0bd1aedcc3a3b11228a8ab6ef0cad9c2	VISA 16 digit	32.8741793641366016	-83.7637617462974049
21055	2020-04-21 20:50:27	2020-04-21	Manerva McKenzie DDS	manerva.mckenzie.dds@geemail.com	Omaha	Nebraska	6011549439461933408	9f30bf3143f1eb5d481052bc1205c46f	Mastercard	41.2081845034059171	-95.9992911946144005
21056	2020-04-21 20:56:45	2020-04-21	Hope Deckow	hope.deckow@geemail.com	Greensboro	North Carolina	6011704715587678287	fe5f2d0d582d6869109dec031fca9af5	VISA 16 digit	36.0897142603177628	-79.7939706264510704
21057	2020-04-21 20:59:38	2020-04-21	Gustaf Walter	gustaf.walter@warmmail.com	San Francisco	California	3719928774957816	9cb834b04fee097cf3de17d7ec1bbe8e	Mastercard	37.7773558881532736	-122.442072542798272
21058	2020-04-21 21:20:34	2020-04-21	Theresa O'Keefe	theresa.o'keefe@woohoo.com	New York	New York	3043207655084224	85c7fa7279894c8ab51cc88129fee710	Discover	40.5743986665494702	-73.851133148780832
21059	2020-04-21 21:30:19	2020-04-21	Lyric Rodriguez	lyric.rodriguez@warmmail.com	Pueblo	Colorado	3528184970127755256	3981d0aee8955177993c493dcc8265b1	Discover	38.2375046326756447	-104.530901621221759
21060	2020-04-21 21:33:23	2020-04-21	Elvin Erdman	elvin.erdman@geemail.com	Oakland	California	3054744667240997	08df52535bd2111995d10c59cbf1542e	VISA 13 digit	37.806768088524521	-122.243541829900295
21061	2020-04-21 21:34:59	2020-04-21	Darren Ledner	darren.ledner@geemail.com	North Charleston	South Carolina	3747951123753344	e0bb2efb4bdda1ffb95069d8eb2a1afc	VISA 16 digit	32.8203525812059667	-80.0299436857551285
21062	2020-04-21 21:37:00	2020-04-21	Daphne Gulgowski MD	daphne.gulgowski.md@warmmail.com	New York	New York	676236235470048	e725deaf0de67518fb15847e84408fa9	JCB 15 digit	40.6545417888313523	-73.8557786997303367
21063	2020-04-21 21:39:56	2020-04-21	Ms. Suzann Kiehn DVM	ms.suzann.kiehn.dvm@geemail.com	Philadelphia	Pennsylvania	4865134521414	05f28da3b15cc7d1986df2b53b1d68f5	VISA 13 digit	39.9179852573625737	-75.0568591254662749
21064	2020-04-21 21:42:10	2020-04-21	Dr. Cas Watsica	dr.cas.watsica@geemail.com	Long Beach	California	3528614450337093772	886309855613cc8b46e174425b4fd8e7	JCB 15 digit	33.8743458624284699	-118.102981236453346
21065	2020-04-21 21:48:27	2020-04-21	Nelda Steuber	nelda.steuber@woohoo.com	Tallahassee	Florida	3096502243206844598	7879fb4a71e836701955e8ba3d9f52d7	JCB 16 digit	30.5372668199263515	-84.2813748280532593
21066	2020-04-21 21:55:02	2020-04-21	Miss Marry Hoeger	miss.marry.hoeger@geemail.com	Hampton	Virginia	3096380949438926279	fbd9a5ecef550132726a700fa720161b	JCB 16 digit	37.0710625904630859	-76.3289247161805662
21067	2020-04-21 22:04:18	2020-04-21	Elon Brown	elon.brown@geemail.com	Milwaukee	Wisconsin	3025244654076503	3dbda3deb297906d1620195c18da87d4	JCB 16 digit	43.1029441912744176	-88.0406286937750906
21068	2020-04-21 22:07:35	2020-04-21	Kaeden Koepp	kaeden.koepp@warmmail.com	New York	New York	869963474236594140	b7156e19a2256cfd46d44c99f4db5517	Voyager	40.6039465570114544	-73.8814837694063726
21069	2020-04-21 22:15:57	2020-04-21	Verlyn Nikolaus	verlyn.nikolaus@geemail.com	Philadelphia	Pennsylvania	3035228724782596	49fc9366f7b0fdc72dfeb86fdee3bcb6	Voyager	39.9242197534494068	-75.1477167841412239
21070	2020-04-21 22:20:08	2020-04-21	Mr. Delma Block	mr.delma.block@geemail.com	Phoenix	Arizona	55129787362544148	40b46efa92759b24a975b1319a1624a1	Diners Club / Carte Blanche	33.571611069136118	-112.001171789171551
21071	2020-04-21 22:26:52	2020-04-21	Maribel Bradtke	maribel.bradtke@geemail.com	New York	New York	869936714445760469	f3330bebb7035aac70d38ad8bc80b6fb	American Express	40.6382939245775319	-73.9833826274506663
21072	2020-04-21 22:37:49	2020-04-21	Raiden Dooley	raiden.dooley@geemail.com	Anchorage	Alaska	3474149020717225	aaf2c2c5fa72898a11431ff74837ece3	VISA 13 digit	61.1046536390420059	-149.256415379665043
21073	2020-04-21 22:41:37	2020-04-21	Codey Schowalter	codey.schowalter@geemail.com	San Francisco	California	676242890367370	910c836892a569f7d9cef08ed9cfcd88	Diners Club / Carte Blanche	37.8211270064795144	-122.398555365863032
21074	2020-04-21 22:46:54	2020-04-21	Dr. Helena Jacobson	dr.helena.jacobson@geemail.com	Phoenix	Arizona	4204907668212	82c06ac8d9bdf9431c4ebfe147192cb9	JCB 15 digit	33.4758365679465228	-112.074457177373034
21075	2020-04-21 22:48:05	2020-04-21	Kia Rowe	kia.rowe@woohoo.com	Mesquite	Texas	3112561602321650032	3ac7eb1897fe3fa4c397188270b6f17b	JCB 16 digit	32.6784394659843329	-96.52753711950146
21076	2020-04-21 22:54:28	2020-04-21	Jeff Carter-Collins	jeff.carter.collins@warmmail.com	San Francisco	California	3451263618904652	1428ea7041babd75cb40c409a33329e9	VISA 16 digit	37.7720759296542923	-122.427292950296462
21077	2020-04-21 22:57:19	2020-04-21	Nola Witting	nola.witting@geemail.com	Wichita	Kansas	54511393617954616	25f9751d5029c841be327ca683dd3e29	Diners Club / Carte Blanche	37.6892681710299087	-97.4314423067230706
21078	2020-04-21 23:02:25	2020-04-21	Ms. Janelle Emmerich	ms.janelle.emmerich@warmmail.com	Chesapeake	Virginia	4314677628705994	d6b78cec5548f30ed0c4b4842012c093	Diners Club / Carte Blanche	36.6396668792009379	-76.2546723052702902
21079	2020-04-21 23:04:32	2020-04-21	Katelynn Johnson	katelynn.johnson@geemail.com	Elizabeth	New Jersey	3036408459230644	2745b2994825042fd945df885e8ca03a	VISA 13 digit	40.7178272584114254	-74.2828166942521904
21080	2020-04-21 23:38:01	2020-04-21	Ms. Richelle Heathcote	ms.richelle.heathcote@geemail.com	Salt Lake City	Utah	4242096317167	637ecc6ebf80996297b9ba3b388b3310	Discover	40.7357005337398448	-111.88843164909072
21081	2020-04-21 23:42:13	2020-04-21	Jakayla Gislason-Pollich	jakayla.gislason.pollich@geemail.com	New York	New York	3528534770365932014	0ceaea7f0dbbe1af43e8d2f2492c85de	JCB 16 digit	40.6643577601984134	-74.024034347607568
21082	2020-04-21 23:49:54	2020-04-21	Linden Kessler-Boehm	linden.kessler.boehm@geemail.com	League City	Texas	3007456732745101	6ec3b970306a5f10cc9fbf72d8de21a5	Diners Club / Carte Blanche	29.5716001423936348	-95.1655262879546768
21083	2020-04-21 23:55:17	2020-04-21	Nikko Cummings-Ernser	nikko.cummings.ernser@geemail.com	Oakland	California	4762670286171630	96fc2f2a41e8cc1008f9a871e83f63a7	Discover	37.8167862062134645	-122.269815096281818
21084	2020-04-21 23:59:24	2020-04-21	Remington Gerlach	remington.gerlach@woohoo.com	Oxnard	California	869996621057678318	3eb2deb51036cec810fb41cd3c70a2b3	Discover	34.2359234022397558	-119.15287032666653
21085	2020-04-22 00:03:15	2020-04-22	Mr. Herschel Swaniawski	mr.herschel.swaniawski@geemail.com	San Diego	California	6011690927167459097	35782af43bf4a7083b40f161b392a42a	VISA 16 digit	32.8339650497373228	-117.041217567482974
21086	2020-04-22 00:06:26	2020-04-22	Forest Romaguera	forest.romaguera@woohoo.com	Olathe	Kansas	060457405504697	ee5b28c69aad8bb94d537eb8edba0f9c	VISA 16 digit	38.9624552853062767	-94.8408015988469231
21087	2020-04-22 00:16:52	2020-04-22	Khiry Krajcik	khiry.krajcik@warmmail.com	San Francisco	California	3011436034871470	6ae17e770ebec6cf074cd674f8bc0998	Mastercard	37.7580651582816387	-122.414383284737269
21088	2020-04-22 00:17:21	2020-04-22	Felicia Kulas	felicia.kulas@woohoo.com	Phoenix	Arizona	4067390504498143	a93c3bc0c621517c42d712401508c34e	Maestro	33.5338521399468235	-112.083394440209872
21089	2020-04-22 00:24:48	2020-04-22	Daisye Daniel	daisye.daniel@warmmail.com	San Diego	California	676200156282576	9388cd22de2a1392622d0cb7397bcd94	VISA 13 digit	32.8989396086029728	-117.198381239399325
21090	2020-04-22 00:28:30	2020-04-22	Evangeline Abshire	evangeline.abshire@geemail.com	New York	New York	53473626323610485	dfc72701da224f63549ba3d3c5353c3c	Diners Club / Carte Blanche	40.710062974248082	-73.9829701427266002
21091	2020-04-22 01:16:38	2020-04-22	Shayna Lind	shayna.lind@warmmail.com	Chicago	Illinois	4005863479670	ff8638b4be0a930d35fcf439182ad2f2	American Express	41.8321224633906041	-87.6705880450580253
21092	2020-04-22 01:26:00	2020-04-22	Tiesha Lindgren	tiesha.lindgren@geemail.com	Roseville	California	3112744556615987395	796b803d19b58e07a4242b9cd5fa1408	JCB 15 digit	38.851910044351591	-121.267825403459
21093	2020-04-22 01:26:36	2020-04-22	Willaim Crist III	willaim.crist.iii@geemail.com	Denver	Colorado	3762320683437005	9e18b2f3c05693033fa337dd36595e55	VISA 16 digit	39.8570122527476371	-104.980541018886868
21094	2020-04-22 01:28:47	2020-04-22	Allena Smith-Grimes	allena.smith.grimes@woohoo.com	New York	New York	561283507295968	0869005a213e63e6cea64aa8b492c411	Mastercard	40.6793465655986211	-73.9746013699926408
21095	2020-04-22 01:34:55	2020-04-22	Mr. Ephriam Schamberger	mr.ephriam.schamberger@geemail.com	San Antonio	Texas	3337981207666938984	37151839eb38005fcb629232628347c0	Discover	29.5391354885954414	-98.5871305269025271
21096	2020-04-22 01:34:58	2020-04-22	Renee Dare	renee.dare@geemail.com	Jackson	Mississippi	4333860069459290	d583211945f69ca46b482530e996d7e9	Discover	32.2265743232976689	-90.1716456373661828
21097	2020-04-22 01:51:11	2020-04-22	Kayleigh Bernhard DVM	kayleigh.bernhard.dvm@woohoo.com	San Antonio	Texas	869965250668823100	9ac8e66ce32bce0b636443efe559d250	Diners Club / Carte Blanche	29.3880675761565584	-98.4385492225944887
21098	2020-04-22 02:15:01	2020-04-22	Zeke Wisozk-Lueilwitz	zeke.wisozk.lueilwitz@woohoo.com	San Francisco	California	3489464668392212	65ba1140e7ccdf009cd80d4bfd9d6d52	JCB 16 digit	37.7539240171836781	-122.44817284216758
21099	2020-04-22 02:47:42	2020-04-22	Geraldine Becker	geraldine.becker@warmmail.com	San Francisco	California	3003884209892334	8e08d8f77423faf17fdd926316471163	Voyager	37.7891458854344151	-122.419333490061277
21100	2020-04-22 02:52:23	2020-04-22	Hanson Zulauf MD	hanson.zulauf.md@geemail.com	Fairfield	California	869942060398962070	a14aeb00cc8f237f47cc279587d4ad07	JCB 16 digit	38.2331376451190579	-122.122540721204501
21101	2020-04-22 03:08:36	2020-04-22	Lindsay Weimann I	lindsay.weimann.i@woohoo.com	Oakland	California	3158479947352756492	44245c1d223036ca365dd7d69554505a	Voyager	37.8392530476120683	-122.263750329314121
21102	2020-04-22 03:14:44	2020-04-22	Bush Mueller DDS	bush.mueller.dds@warmmail.com	Los Angeles	California	6011140628303202492	5c4f6bbeac801aed45f1ad1064e01391	VISA 16 digit	34.0896199437189793	-118.365650604711092
21103	2020-04-22 03:38:03	2020-04-22	Audrianna Bergstrom	audrianna.bergstrom@geemail.com	San Francisco	California	4085324784388417	88281e69ee0f465443691a198f10bd8a	Diners Club / Carte Blanche	37.7918559649772021	-122.407096640254309
21104	2020-04-22 03:45:42	2020-04-22	Wirt Klein	wirt.klein@woohoo.com	San Francisco	California	3717253390122196	3aa90eff5d8252eff67f47aef6f7d112	American Express	37.7674135293793967	-122.430123634577981
21105	2020-04-22 03:47:03	2020-04-22	Ambers Goodwin	ambers.goodwin@geemail.com	Santa Ana	California	6011861550629270481	f8576a637006727967a3c248f24b6311	JCB 16 digit	33.7991259859979181	-117.840649342576043
21106	2020-04-22 03:58:57	2020-04-22	Dallas Kozey	dallas.kozey@woohoo.com	Tyler	Texas	6011831997454395171	408702e4906d8a2bfcd5cbf9abcdfb38	JCB 16 digit	32.2835684628274322	-95.2604863798353705
21107	2020-04-22 03:59:56	2020-04-22	Jaycie Roob	jaycie.roob@geemail.com	San Diego	California	6011566214430837982	d7baee78d0be64cff37a3b1a85f6256a	Diners Club / Carte Blanche	32.8503031442474551	-117.163209639666604
21108	2020-04-22 04:09:06	2020-04-22	Chaka Abbott	chaka.abbott@geemail.com	San Diego	California	3088102684929911467	72f8d98939dc81506e8f869148812c52	Mastercard	32.7704397386938311	-117.208009824752807
21109	2020-04-22 04:21:41	2020-04-22	Aryana Mosciski	aryana.mosciski@geemail.com	San Francisco	California	55436779978633207	8424c80ac18b2dba6564bbfae0954dfb	Maestro	37.7609064231423872	-122.439565255965334
21110	2020-04-22 04:36:32	2020-04-22	Harper Marvin-Nitzsche	harper.marvin.nitzsche@woohoo.com	Lewisville	Texas	3709110435527427	7db637b6be9d0982b542b7348ac7c85e	JCB 16 digit	32.9841874603632803	-96.9800161058113019
21111	2020-04-22 04:59:36	2020-04-22	Harman Schmitt	harman.schmitt@geemail.com	Jacksonville	Florida	6011656953274392064	083cdcfddc21b49155468433f4105f80	Discover	30.256503851763533	-81.7018641049586307
21112	2020-04-22 05:01:27	2020-04-22	Hildegarde Marvin	hildegarde.marvin@geemail.com	San Diego	California	4631557386483024	eb061fc6b437497572756f12ba28853c	JCB 15 digit	32.7844688000690212	-117.042001460064213
21113	2020-04-22 05:12:31	2020-04-22	Isabelle White	isabelle.white@geemail.com	Sparks	Nevada	4136540695106643	1665c85ab20d88151220e8dfde5dfdc7	Mastercard	39.4938439204130347	-119.647744647678365
21114	2020-04-22 05:23:19	2020-04-22	Dr. Khiry Gusikowski DDS	dr.khiry.gusikowski.dds@geemail.com	Berkeley	California	4182489754238629	47b66a634a439aea9582a69f9a67a078	VISA 13 digit	37.8822976001201326	-122.246739768840101
21115	2020-04-22 05:31:05	2020-04-22	Eugene Kling	eugene.kling@warmmail.com	San Francisco	California	3337005740237539057	cae1660337fd0d606bcdcf9b4b796d9f	Mastercard	37.7427907133493576	-122.398919770705277
21116	2020-04-22 05:38:30	2020-04-22	Emely Purdy DDS	emely.purdy.dds@woohoo.com	Rockford	Illinois	3039336236936075	2c1ca60f7f8c8c11465394e2e9d4ce59	Maestro	42.3311810608964407	-89.1185643069263591
21117	2020-04-22 05:43:43	2020-04-22	Miss Iona Oberbrunner MD	miss.iona.oberbrunner.md@warmmail.com	Salt Lake City	Utah	210072844492791995	32efc52e273c9960f94bd2b325e7ff83	Voyager	40.770613383935391	-111.923658587312318
21118	2020-04-22 05:44:39	2020-04-22	Krish O'Reilly V	krish.o'reilly.v@geemail.com	Huntsville	Alabama	4776241810376485	c2e68f4dfbede5dafe23853c65d0ec62	VISA 13 digit	34.7874856975637385	-86.7384276031535109
21119	2020-04-22 06:04:10	2020-04-22	Dr. Camden Swaniawski	dr.camden.swaniawski@geemail.com	Miami	Florida	3112895298113864191	1ac847f3773cc7efbd7eb7b7680b6968	JCB 16 digit	25.782130308043957	-80.1606062585361343
21120	2020-04-22 06:30:16	2020-04-22	Leah Grant	leah.grant@geemail.com	Vallejo	California	54608320122080151	50f4bcb08f1608a8525aed7a56307759	Voyager	38.184704885081949	-122.288791226629158
21121	2020-04-22 07:02:51	2020-04-22	Javon Beahan	javon.beahan@warmmail.com	San Francisco	California	3158506798757943269	2760c285816f6b961c84eb128a272a5b	VISA 13 digit	37.7798509706308252	-122.432498932291466
21122	2020-04-22 07:07:50	2020-04-22	Lular Trantow	lular.trantow@geemail.com	Toledo	Ohio	4959806861027036	d6da6b5aa23046e98ba2a0014076f88a	Voyager	41.5943899311296619	-83.4992976486083194
21123	2020-04-22 07:54:24	2020-04-22	Rosetta Cartwright	rosetta.cartwright@geemail.com	Charlotte	North Carolina	3528218288567714018	222534ea73cceeb6846fe9c2b56a44c7	VISA 16 digit	35.1545611994128677	-80.7978137211352561
21124	2020-04-22 07:56:34	2020-04-22	Baylie Schaden	baylie.schaden@warmmail.com	New York	New York	589320023740432	d023b2b2b724c9fc45141a30ebb10317	Diners Club / Carte Blanche	40.7121636848654589	-73.8516848686512475
21125	2020-04-22 08:00:30	2020-04-22	Mr. Arturo Mosciski	mr.arturo.mosciski@warmmail.com	New York	New York	3088405795838892590	412d1bf8cc146a8bf12277049f01ff23	JCB 15 digit	40.6325718356985561	-73.916399769474566
21126	2020-04-22 08:10:31	2020-04-22	Mrs. Jamie Brakus	mrs.jamie.brakus@geemail.com	San Antonio	Texas	6011514973215861607	ba1df34d793b45daf3155efe991eb2dc	JCB 16 digit	29.3765464496869591	-98.4735284620266356
21127	2020-04-22 08:27:50	2020-04-22	Gerard Hauck	gerard.hauck@geemail.com	Tampa	Florida	6011835309735566396	bb808acce9ca9628e93949e9f19f85c2	Diners Club / Carte Blanche	27.9176131974089863	-82.4115358728196412
21128	2020-04-22 09:05:54	2020-04-22	Bolden Hammes III	bolden.hammes.iii@geemail.com	Dallas	Texas	3014621579123430	b15c26b00af1470f0e0149f67aa03347	VISA 16 digit	32.8607345904029913	-96.73201615106872
21129	2020-04-22 09:27:03	2020-04-22	Coleman Steuber	coleman.steuber@geemail.com	Nashville	Tennessee	53006383286442565	31b99480470f8a460392bae16e9f5b5d	Voyager	36.1012498385395801	-86.7444201975036435
21130	2020-04-22 09:35:34	2020-04-22	Verona Labadie	verona.labadie@warmmail.com	San Francisco	California	3027035143457074	d4b8296b92de689e08d9b742c5376e9a	Maestro	37.7736033869611276	-122.436274952253029
21131	2020-04-22 09:41:21	2020-04-22	Eden Glover	eden.glover@geemail.com	San Francisco	California	869956848577539278	bee1a947429c5fe0ab992caf3593387a	Diners Club / Carte Blanche	37.7602784413764283	-122.440257802957518
21132	2020-04-22 09:54:23	2020-04-22	Mervyn Bernhard DDS	mervyn.bernhard.dds@woohoo.com	Houston	Texas	4128298908023283	43d6739ed3511b1ae54ce33f2bc0b91d	Voyager	29.8218969500701867	-95.4002388446606773
21133	2020-04-22 10:09:45	2020-04-22	Lillis Effertz	lillis.effertz@geemail.com	Newport News	Virginia	4998601718875197	2e893eb545e5d00c42d665e70a26ebf4	Voyager	37.0457646980311708	-76.4529656197205298
21134	2020-04-22 10:26:55	2020-04-22	Oda Kling	oda.kling@warmmail.com	Houston	Texas	3007662333387348	376d0868fb59eb1e48a3268a2c846c50	VISA 16 digit	29.7781002518333509	-95.4549183878131231
21135	2020-04-22 10:31:37	2020-04-22	Arielle Torp	arielle.torp@geemail.com	Vacaville	California	210051407090579439	695710ee6138d1352a4a9d661b2d7e30	VISA 13 digit	38.3747497100044086	-122.042107297514761
21136	2020-04-22 10:35:04	2020-04-22	Lesly McLaughlin	lesly.mclaughlin@geemail.com	Memphis	Tennessee	3052934251070650	de123f7607373faba1ee7ecf6a2e816f	VISA 13 digit	35.0589086948029731	-89.8939990883018822
21137	2020-04-22 10:37:48	2020-04-22	Britny Carroll PhD	britny.carroll.phd@warmmail.com	New York	New York	3337416258000349557	b427109d42fbf9201de29bcb029ecb56	VISA 13 digit	40.6898912162743471	-74.0192577755440055
21138	2020-04-22 10:39:17	2020-04-22	Dr. Manilla Kulas PhD	dr.manilla.kulas.phd@warmmail.com	New York	New York	4861751908364	0ec8f5451e766cb6e3472ff6d81e2344	Mastercard	40.5757037336230297	-73.9191287653882085
21139	2020-04-22 10:39:32	2020-04-22	Ms. Agusta Marks DDS	ms.agusta.marks.dds@geemail.com	Houston	Texas	3337856193588702215	bf06e70d15d9b02aef864b6f5d929d0e	VISA 16 digit	29.8743263208851211	-95.4770515881028103
21140	2020-04-22 10:40:31	2020-04-22	Kolten Doyle	kolten.doyle@warmmail.com	Tallahassee	Florida	869903425538981784	1e647bcf2044685eeeb1ae2303802a97	VISA 13 digit	30.5083691473141343	-84.2249576211456201
21141	2020-04-22 10:44:34	2020-04-22	Davey Reynolds	davey.reynolds@woohoo.com	New Orleans	Louisiana	4634413714443610	9a8e9afd2bc1941ae93fe75567141945	Mastercard	30.0587557359613484	-89.8495035088881906
21142	2020-04-22 11:10:22	2020-04-22	Anabella Spencer	anabella.spencer@woohoo.com	San Jose	California	4574650409478706	0e6dba5cb2394d79661d032290cd099f	JCB 16 digit	37.2991611330591155	-121.892224114922428
21143	2020-04-22 11:11:56	2020-04-22	Mr. Jeremey Anderson DVM	mr.jeremey.anderson.dvm@warmmail.com	San Antonio	Texas	52178989878507987	5e3135016e4d545907046bc28ccaaf37	JCB 16 digit	29.3925842520385991	-98.4504011673223118
21144	2020-04-22 11:12:34	2020-04-22	Neta Connelly	neta.connelly@geemail.com	San Francisco	California	52707427001705574	7110cde9199f4cc2aa58105f65b4501e	JCB 16 digit	37.8014224202650695	-122.44814375637003
21145	2020-04-22 11:39:23	2020-04-22	Lavona Moen-Dach	lavona.moen.dach@geemail.com	Berkeley	California	6011531260664464771	e72a64b16ab3500b0ded959bd63ad426	VISA 16 digit	37.8336945739888506	-122.27840435877664
21146	2020-04-22 11:40:26	2020-04-22	Lillianna Steuber-Hodkiewicz	lillianna.steuber.hodkiewicz@geemail.com	Oakland	California	502069125750062	467b11633017bd9e8dba6c2e23e89190	Discover	37.8152562526873695	-122.243232465208507
21147	2020-04-22 11:43:04	2020-04-22	Duard Bode	duard.bode@geemail.com	Raleigh	North Carolina	4170116398497	12fa3facd7a102abbe2ebc6ce0e16380	JCB 15 digit	35.8059054631873934	-78.710042543796078
21148	2020-04-22 12:07:49	2020-04-22	Mr. Kelly Morar V	mr.kelly.morar.v@geemail.com	Dallas	Texas	210099028518925089	096e270243a32f547b5d247e82589e00	Voyager	32.7382542270042052	-96.811207498280325
21149	2020-04-22 12:32:21	2020-04-22	Powell Bradtke	powell.bradtke@geemail.com	Norwalk	California	869969686420868881	0794693812b5f3409923e0f13f4f7243	VISA 13 digit	33.9775095475487419	-118.04584147381037
21150	2020-04-22 12:59:36	2020-04-22	Kaliyah Senger DVM	kaliyah.senger.dvm@woohoo.com	Atlanta	Georgia	6011968875355251823	df7b95b8a203575c937d6dd1602d95b9	VISA 16 digit	33.8072394183646878	-84.4504072668541284
21151	2020-04-22 13:06:01	2020-04-22	Will Bogan	will.bogan@woohoo.com	Daly City	California	3474253983225877	b88cc994fa649688a0bf6bbb0bda0817	VISA 16 digit	37.6273017773792091	-122.398768320595849
21152	2020-04-22 13:29:10	2020-04-22	Candyce Crona	candyce.crona@geemail.com	Arlington	Texas	3420849090784105	1013270d74f032cde191f259aad7475d	Maestro	32.7894683859560629	-97.2017526495762212
21153	2020-04-22 13:49:39	2020-04-22	Dr. Gaylon Goldner III	dr.gaylon.goldner.iii@warmmail.com	Hartford	Connecticut	676335338206366	c66b8db6d421a83ecac776ee91ff8ba7	JCB 15 digit	41.7152856732733568	-72.6903960211560189
21154	2020-04-22 13:49:53	2020-04-22	Derl Schulist-Blick	derl.schulist.blick@geemail.com	San Diego	California	4401318387982	98ff21b08fc579a3426e90e702518e15	Discover	32.7357827191773794	-117.194372614882894
21155	2020-04-22 13:54:50	2020-04-22	Dr. Gemma Gleichner	dr.gemma.gleichner@woohoo.com	Berkeley	California	4248996531052232	3f8bfbb42b1fb726ad6fdc8529fe6180	VISA 16 digit	37.8507137705393362	-122.291700224003719
21156	2020-04-22 13:56:55	2020-04-22	Reese Schmitt	reese.schmitt@geemail.com	Los Angeles	California	3528157139606648209	140dfcb673fc0874c639ee083dc28ce6	Mastercard	34.0119101703498501	-118.342114892135555
21157	2020-04-22 13:57:44	2020-04-22	Georgie Brekke	georgie.brekke@geemail.com	Dallas	Texas	180035586347403989	9f5f6aa2e13eaa8dee57019715a8168c	Mastercard	32.7083014900602436	-96.745008447203773
21158	2020-04-22 14:03:26	2020-04-22	Lurline Sporer	lurline.sporer@warmmail.com	Billings	Montana	4010564056444832	8c8085c7ea535db623291d8122a966a4	VISA 13 digit	45.8421048099398618	-108.482311130005485
21159	2020-04-22 14:12:55	2020-04-22	Mrs. Audrey Waelchi	mrs.audrey.waelchi@geemail.com	Phoenix	Arizona	3112573259875185695	d7816e1af6b777c0875f95fef2ab275d	VISA 16 digit	33.6192769098028563	-112.101568906933451
21160	2020-04-22 14:25:21	2020-04-22	Dr. Johnathan Cassin	dr.johnathan.cassin@geemail.com	Arlington	Texas	3096030288406078910	88571cb492340af4f6fd25f9167564f4	Mastercard	32.6090775304257861	-97.1623617589499844
21161	2020-04-22 14:28:02	2020-04-22	Ferman Wolf V	ferman.wolf.v@geemail.com	Greensboro	North Carolina	3730246594728506	646586e7f92ee0d91705d24d5714204b	VISA 13 digit	36.1476619078893222	-79.7387391106672538
21162	2020-04-22 14:28:14	2020-04-22	Mikaila Torphy	mikaila.torphy@geemail.com	Hialeah	Florida	180050646529836552	f524e6566ef72a8126a58ac3921a7039	JCB 16 digit	25.929806530659647	-80.3994348536614325
21163	2020-04-22 14:29:10	2020-04-22	Dr. Clem Franecki Sr.	dr.clem.franecki.sr.@woohoo.com	Tucson	Arizona	3528611075537416961	c1e37e3bc67d7468e89d299ff02d8dec	VISA 16 digit	32.2197886657476431	-110.840420172758769
21164	2020-04-22 14:33:26	2020-04-22	Karis Mayert	karis.mayert@geemail.com	Phoenix	Arizona	675921780075087	dc9461b3dfd9cdc7ad5f65478af9e32b	Diners Club / Carte Blanche	33.5109404495384595	-112.044482383497439
21165	2020-04-22 14:33:56	2020-04-22	Dr. Judd Ward MD	dr.judd.ward.md@geemail.com	Seattle	Washington	4985393553776418	5d3ed1725b478e6ada0b0746c75be21e	Voyager	47.5574452161248757	-122.392941041655462
21166	2020-04-22 14:51:01	2020-04-22	Louvenia Hauck PhD	louvenia.hauck.phd@geemail.com	San Diego	California	869922466226821509	4a4f9e0347b595da132842a3670577d2	Mastercard	32.7287110222104971	-117.232788786562168
21167	2020-04-22 14:51:14	2020-04-22	Shamika McCullough	shamika.mccullough@woohoo.com	Miami	Florida	4800275736569864	11f4a15acc3fa03420b2807fcac1db95	Diners Club / Carte Blanche	25.8662576232243353	-80.1644510405477178
21168	2020-04-22 15:11:26	2020-04-22	Ismael Mueller	ismael.mueller@geemail.com	Las Cruces	New Mexico	3439582310879459	2abfde0c8c52f830b928a81e722d9c86	JCB 16 digit	32.3035941469516601	-106.88457446988933
21169	2020-04-22 15:26:20	2020-04-22	Demond Abbott-Welch	demond.abbott.welch@woohoo.com	Seattle	Washington	6011071647736029358	198bc890b876b878b23444005d0a6a25	American Express	47.6133791245911269	-122.375081099422275
21170	2020-04-22 15:41:46	2020-04-22	Ms. Jeanetta Hayes	ms.jeanetta.hayes@woohoo.com	Milwaukee	Wisconsin	501858126695038	512df66da8e59f5e2d1270dc3587b56e	Mastercard	43.0571547436147881	-87.9600203049935487
21171	2020-04-22 15:43:07	2020-04-22	Mr. Hardin Hauck	mr.hardin.hauck@woohoo.com	Stockton	California	3528056928334035032	89cab9084fd7cc96a9c988f77007e62d	American Express	37.9755301856633309	-121.239857269459591
21172	2020-04-22 15:44:58	2020-04-22	Arleth Jerde-Beer	arleth.jerde.beer@geemail.com	Los Angeles	California	210004654843482506	e41a6d661d39712cef592deb9e06db07	JCB 15 digit	34.0049088636744727	-118.483222592481596
21173	2020-04-22 15:48:33	2020-04-22	Bradford Murray	bradford.murray@warmmail.com	Corpus Christi	Texas	589300387657117	a84dfb5d8f79a9de8b1f5be70ac5ae9c	Voyager	27.8487836131297044	-97.2069831617470896
21174	2020-04-22 16:03:19	2020-04-22	Barron Roberts II	barron.roberts.ii@woohoo.com	Stockton	California	3057054582267829	9828b899c8747c7d18792dd8438d87a8	American Express	38.06507797969617	-121.403266849517081
21175	2020-04-22 16:03:26	2020-04-22	Ada Block	ada.block@woohoo.com	Pueblo	Colorado	180001358773983672	be10ea79be9da646b39a5fa9dc9395a5	Diners Club / Carte Blanche	38.2426322974242296	-104.681785610956325
21176	2020-04-22 16:14:14	2020-04-22	Gale Haley	gale.haley@geemail.com	Houston	Texas	210034532783563903	80de7c5ea7832b5a429266e6dbbc8540	JCB 15 digit	29.8318320170588791	-95.4833754159525085
21177	2020-04-22 16:34:20	2020-04-22	Olie Aufderhar II	olie.aufderhar.ii@woohoo.com	Denver	Colorado	4751313194035141	727ce82e434cfdc5cea64e1d6824cd06	American Express	39.7961609768267692	-104.786634593667841
21178	2020-04-22 16:40:11	2020-04-22	Damien Ankunding	damien.ankunding@woohoo.com	Chesapeake	Virginia	3014692712523802	8813931d64f396c03f450aaedf2cc01c	American Express	36.6699164818745089	-76.2927636804368348
21179	2020-04-22 16:44:54	2020-04-22	Saint Hilpert Sr.	saint.hilpert.sr.@woohoo.com	San Francisco	California	869907641802762843	8f9732919b5b8108f5a1e88b700f0437	Maestro	37.754183356526994	-122.415015908378805
21180	2020-04-22 17:09:53	2020-04-22	Tyrell Cartwright-Rutherford	tyrell.cartwright.rutherford@woohoo.com	Los Angeles	California	6011215733626847013	49e0b6b9d4e04e5768cff54b9b3f2b70	JCB 16 digit	33.9448041847772899	-118.413244212511174
21181	2020-04-22 17:15:04	2020-04-22	Efrain Fritsch	efrain.fritsch@warmmail.com	Dallas	Texas	4795117481432921	948ee3ccb320fb22ae9cd672bceab7d3	Maestro	32.8262930521082126	-96.749985229406505
21182	2020-04-22 17:27:04	2020-04-22	Korbin Williamson-Hickle	korbin.williamson.hickle@geemail.com	Minneapolis	Minnesota	869998792402264563	92db9368c81bb2247fa8938a7b73fb6b	Diners Club / Carte Blanche	45.0154383777726395	-93.3466195868600153
21183	2020-04-22 18:02:54	2020-04-22	Reino Tillman	reino.tillman@geemail.com	New York	New York	6011487344007226651	92fc4af73097acdcae66c608611fc3c3	Discover	40.7276860965639358	-73.9481919146969915
21184	2020-04-22 18:04:54	2020-04-22	Oneal White Sr.	oneal.white.sr.@woohoo.com	San Francisco	California	3088173560469452266	31af9838fac9aa3c004f14dc20b7d23c	Maestro	37.7704463147838325	-122.400052935326215
21185	2020-04-22 18:08:57	2020-04-22	Orlena Grady	orlena.grady@geemail.com	Oklahoma City	Oklahoma	3020659632509181	f5bb09b3e0c257c0bd6db15d7ea26ba1	VISA 16 digit	35.4872849309261937	-97.4999002070993157
21186	2020-04-22 18:17:10	2020-04-22	Olen King-Mills	olen.king.mills@warmmail.com	Memphis	Tennessee	676335711510541	6a43f4703b6e0581f7e79a69456ad7de	Voyager	35.2023653445366804	-89.9478222280997812
21187	2020-04-22 18:18:10	2020-04-22	Candido Fahey	candido.fahey@geemail.com	Columbus	Georgia	4383956862061967	ab29fa9201c37f8c462d03f4b4657cbd	Discover	32.5182630494281639	-84.9747017021454809
21188	2020-04-22 18:36:48	2020-04-22	Dr. Will Walker IV	dr.will.walker.iv@geemail.com	Toledo	Ohio	676161126773045	bffca714c07f79b7fa548dcf300f91ac	JCB 16 digit	41.6095319695010772	-83.6713736175891114
21189	2020-04-22 19:05:45	2020-04-22	Dr. Corwin Torp	dr.corwin.torp@geemail.com	San Francisco	California	4134063176074331	c66b7e1d9c5d164c0dc959a30d2af9df	Diners Club / Carte Blanche	37.7287004046370456	-122.415246281849846
21190	2020-04-22 19:08:15	2020-04-22	Mrs. Pamella Becker DDS	mrs.pamella.becker.dds@geemail.com	Berkeley	California	3337905785173758063	a0479fa49f3dac28d1cc5e94dece2a73	VISA 16 digit	37.8320113078180498	-122.256268498669428
21191	2020-04-22 19:08:34	2020-04-22	Cameron Hagenes MD	cameron.hagenes.md@geemail.com	New York	New York	3112639660015569965	ba9b4b441c97193b113ef59dcc63f7bc	Maestro	40.7202376410588585	-73.8409245672997088
21192	2020-04-22 19:12:14	2020-04-22	Chester Koss	chester.koss@warmmail.com	San Francisco	California	3088681152731247362	c013b215c8113fb55bdfccb51f7b7b22	JCB 16 digit	37.7531929741768195	-122.423333571591726
21193	2020-04-22 19:23:57	2020-04-22	Mrs. Leva Orn DDS	mrs.leva.orn.dds@geemail.com	San Francisco	California	4330805207727697	eef02d7c6678cf24fe4e70e0fe6b2bde	Maestro	37.7695464907434229	-122.424436187474697
21194	2020-04-22 20:03:33	2020-04-22	Cedrick Marvin	cedrick.marvin@warmmail.com	Oceanside	California	4595940127096574	85cc1217e2c16a93b9a488b61201d596	Mastercard	33.1720711150094871	-117.239141928179933
21195	2020-04-22 20:15:43	2020-04-22	Kenji Halvorson	kenji.halvorson@geemail.com	Charleston	South Carolina	503847776424146	a78be985779e2a9873fc1d6d4a621dfb	Voyager	32.8271282119207086	-79.8793482606448322
21196	2020-04-22 20:19:36	2020-04-22	Loyal Collins-Hintz	loyal.collins.hintz@geemail.com	New York	New York	180027159697078809	953d989a771d75f6de6d1d6915a7e259	Mastercard	40.6738935732040545	-73.9321493568260166
21197	2020-04-22 20:36:12	2020-04-22	Ms. Kelsi Flatley DVM	ms.kelsi.flatley.dvm@geemail.com	Los Angeles	California	53478418418921786	62d618a1811c8255dd6826c7d54b5268	Mastercard	34.0392064520023752	-118.456431738565854
21198	2020-04-22 21:11:58	2020-04-22	Derald Mante	derald.mante@geemail.com	Los Angeles	California	4985511892947	8877c9955a825722c0e05b26fc1a8678	JCB 16 digit	33.9272941497486045	-118.450016883433975
21199	2020-04-22 21:24:18	2020-04-22	Dr. Rico Barrows	dr.rico.barrows@warmmail.com	Worcester	Massachusetts	3411065874121726	f69aee2e9fd15c8d24d34fbd5837f0d9	JCB 15 digit	42.2051190207414351	-71.781626098535213
21200	2020-04-22 21:29:28	2020-04-22	Sharif Bartell	sharif.bartell@geemail.com	Broken Arrow	Oklahoma	630452640458536	8ea2c17f6b7a752f47b1915c53e8db6e	VISA 16 digit	35.9702586646899576	-95.7356571235638114
21201	2020-04-22 21:38:01	2020-04-22	Nina McLaughlin-Ward	nina.mclaughlin.ward@geemail.com	Richmond	Virginia	3026992825031257	9b9eace0733229a254b9df565e446f2e	VISA 13 digit	37.6202304108753793	-77.4989384356643995
21202	2020-04-22 21:39:56	2020-04-22	Julious Gleichner	julious.gleichner@geemail.com	Los Angeles	California	4323699237157812	4d1e361d4f038d01fa2ac73d78a6bd32	American Express	33.994266294115782	-118.314489373610542
21203	2020-04-22 21:51:26	2020-04-22	Nikolai Kuhn	nikolai.kuhn@geemail.com	San Francisco	California	3452632679900925	615b34800947c0578862fd7bb0ad6daa	Maestro	37.7887995482494574	-122.438999717994733
21204	2020-04-22 22:00:44	2020-04-22	Fenton Koelpin MD	fenton.koelpin.md@geemail.com	New Orleans	Louisiana	3337896849780561160	0fb70559750f0eb0b9442dcd69c8b41c	Voyager	30.1277519640527665	-90.0272095141261843
21205	2020-04-22 22:09:46	2020-04-22	Anthoney Langosh-Larson	anthoney.langosh.larson@geemail.com	Riverside	California	4921783495798305	f97c60a63123efcbd15991168610af91	American Express	34.0373772046010927	-117.312730097628005
21206	2020-04-22 22:27:30	2020-04-22	Reta Ferry	reta.ferry@geemail.com	Washington	District of Columbia	4245721184894	2e3b29445b5890832e66931100a8a33a	Mastercard	38.9061708954427417	-76.9192493152551435
21207	2020-04-22 22:36:27	2020-04-22	Ms. Faith Dickinson	ms.faith.dickinson@warmmail.com	Long Beach	California	3337687091708861165	bfd61a692689c55b311ef011633a91cd	Discover	33.7557064410120233	-118.168652324301377
21208	2020-04-22 22:43:39	2020-04-22	Linwood Haley	linwood.haley@woohoo.com	Fresno	California	3158496773636722228	dc95d7e3c0e0ee0aacee1b516f80627e	VISA 16 digit	36.7757656660269916	-119.733130423688891
21209	2020-04-22 23:27:29	2020-04-22	Goldie Hegmann	goldie.hegmann@geemail.com	Evansville	Indiana	869980798087688034	c1f1ffcd3d7a6e9e5ed4dc0c131f0848	American Express	38.0328584475114937	-87.4487118305105753
21210	2020-04-22 23:42:56	2020-04-22	Dr. French Gibson	dr.french.gibson@geemail.com	Denver	Colorado	4381269104737	87f409a1df3f96f7167d211ad46ef17d	VISA 16 digit	39.6853718730673179	-104.793191437308124
21211	2020-04-23 00:01:39	2020-04-23	Guido Wintheiser	guido.wintheiser@geemail.com	Philadelphia	Pennsylvania	4059954080627688	57aeab6756d0eff19045de28d4fe30e6	JCB 16 digit	39.9795105759013438	-75.072296674912053
21212	2020-04-23 00:03:43	2020-04-23	Mr. Darry O'Reilly III	mr.darry.o'reilly.iii@geemail.com	West Covina	California	4334869328120675	ad713b4f36057c6ca8777552e150a72b	Mastercard	34.1374196453128036	-117.948792768742507
21213	2020-04-23 00:24:15	2020-04-23	Ms. Kimberely Fay	ms.kimberely.fay@geemail.com	Springfield	Missouri	869982660081497192	29846c14e626077e06a10b89287c21c3	Mastercard	37.135708126957347	-93.3793823157727729
21214	2020-04-23 00:42:37	2020-04-23	Kelcie Gislason	kelcie.gislason@woohoo.com	Dallas	Texas	3528309585019714961	d50320db0adfef249565fedb2c5a7ae0	VISA 13 digit	32.7921898763898767	-96.764001553036266
21215	2020-04-23 00:50:39	2020-04-23	Tyree Stiedemann	tyree.stiedemann@warmmail.com	El Paso	Texas	51005719713269033	966650a8d21377dc0a3dcc95229fb984	VISA 13 digit	31.9386825893834256	-106.397148646505556
21216	2020-04-23 01:03:43	2020-04-23	Jere Koch	jere.koch@geemail.com	Salem	Oregon	3708746807312608	5205f4f53844afb984931bb0fd0d434d	Discover	44.996533322780202	-123.03270206159614
21217	2020-04-23 01:11:41	2020-04-23	Owens Fadel	owens.fadel@geemail.com	Nashville	Tennessee	3788924252187238	06110945aab16d9d79f11528a8b8fdad	VISA 16 digit	36.1782377088099665	-86.7724993952456884
21218	2020-04-23 01:29:42	2020-04-23	Mrs. Neta Tillman	mrs.neta.tillman@geemail.com	Jackson	Mississippi	4747394995366684	bf515e18e1a441c1d89fb8817e10e7bd	Maestro	32.3514989526189893	-90.2238399467404975
21219	2020-04-23 01:36:34	2020-04-23	Caiden Goyette	caiden.goyette@geemail.com	Lexington	Kentucky	51657516627204911	94664378960c8dd9951403f772fd01cd	Discover	37.940846193662658	-84.4515442878838627
21220	2020-04-23 02:02:20	2020-04-23	Ms. Vernell Greenholt PhD	ms.vernell.greenholt.phd@warmmail.com	Philadelphia	Pennsylvania	675949603611150	1d5cacaa0a9684bb7a3e28f956b669c3	Maestro	39.9436389492783661	-75.2076579314556
21221	2020-04-23 02:12:47	2020-04-23	Norma Heller	norma.heller@woohoo.com	Arvada	Colorado	3088965041109887585	28296eab13f375dc0050c9cace6d1446	American Express	39.9272497110243876	-105.091785083196314
21222	2020-04-23 02:18:48	2020-04-23	Rudolph Lockman	rudolph.lockman@warmmail.com	Phoenix	Arizona	3419279345722598	98b74bc4b541dc58473a74a6d34d5cda	VISA 16 digit	33.5960849136978439	-112.04851937810183
21223	2020-04-23 02:19:03	2020-04-23	Rosemarie Beatty DVM	rosemarie.beatty.dvm@geemail.com	Las Vegas	Nevada	4553285117430528	fa9ddd4ed8849c44bffa8a1b6abb1395	VISA 16 digit	36.3035624480441186	-115.306027870459843
21224	2020-04-23 02:27:13	2020-04-23	Shenna Aufderhar	shenna.aufderhar@geemail.com	San Diego	California	3337821524682425331	2400cc302564214b16b54bfa6a055e29	VISA 13 digit	32.7327074456561391	-117.073696974096819
21225	2020-04-23 02:32:28	2020-04-23	Mrs. Gerri Wisozk DVM	mrs.gerri.wisozk.dvm@warmmail.com	Tampa	Florida	6011428821749650894	cfcca3b58f11acc09adc6a30a8a26542	Voyager	28.068443134718013	-82.382889726639533
21226	2020-04-23 02:40:40	2020-04-23	Ione Gorczany	ione.gorczany@geemail.com	Fresno	California	869977287590076304	7b5fd1623c504459877af9dff9f3974e	VISA 13 digit	36.742167707100883	-119.822054860937968
21227	2020-04-23 03:19:32	2020-04-23	Mr. Olen Schmidt	mr.olen.schmidt@geemail.com	Louisville	Kentucky	3413599684794635	443b31560381a01c52b1b9b05b023cff	JCB 16 digit	38.2462253823313816	-85.5558569825790869
21228	2020-04-23 03:21:49	2020-04-23	Aubree Mueller	aubree.mueller@geemail.com	Thousand Oaks	California	869940104475018232	fcccd13e883f96ab1a54268b127b1a6e	Mastercard	34.291982069545611	-118.901257774737473
21229	2020-04-23 03:25:56	2020-04-23	Lucy Schaefer MD	lucy.schaefer.md@geemail.com	San Francisco	California	6011893074259910227	a17713aff0fd5fe9d64581eace6842b9	Voyager	37.7611656848997299	-122.426991933042984
21230	2020-04-23 03:30:20	2020-04-23	Tiffany Rutherford-Spencer	tiffany.rutherford.spencer@geemail.com	Jacksonville	Florida	3112516075447155333	0a57de560bce4b43f3a82af3c3be5b25	JCB 16 digit	30.261292137629912	-81.6229857510034122
21231	2020-04-23 03:51:12	2020-04-23	Georgina Gutkowski	georgina.gutkowski@woohoo.com	Memphis	Tennessee	060445175937080	b39a96470664976baf2c74de388aeaae	Discover	35.1401134114779552	-90.0500067843847063
21232	2020-04-23 03:58:48	2020-04-23	Madie Huel	madie.huel@geemail.com	Jackson	Mississippi	3096956075003294226	aca17147a3b1a75d6ab80a47fc817873	Voyager	32.3623544846840261	-90.312553778241579
21233	2020-04-23 04:00:18	2020-04-23	Adriel King DVM	adriel.king.dvm@geemail.com	Mesa	Arizona	869952512166825670	d23e9f13985bc18ee859f6d7441c5212	Voyager	33.428401277275384	-111.712355950323484
21234	2020-04-23 04:03:43	2020-04-23	Marcelino Spencer	marcelino.spencer@geemail.com	Santa Clara	California	4538874556169	d09d8868177031bbe69babc15251451e	JCB 16 digit	37.4482914122570349	-121.868418537452442
21235	2020-04-23 04:04:29	2020-04-23	Easter McCullough	easter.mccullough@woohoo.com	Cary	North Carolina	210092238574288333	6d0da9e3a8c912b8d1b5fb226156f163	Maestro	35.7418202558174727	-78.7444763669829797
21236	2020-04-23 04:06:49	2020-04-23	Marceline Goodwin-Bergnaum	marceline.goodwin.bergnaum@geemail.com	Newark	New Jersey	4999758511706	df822f4117c94fcf14cf40e5399f2038	JCB 16 digit	40.6437487641729476	-74.1824359260242403
21237	2020-04-23 04:20:13	2020-04-23	Smith Aufderhar	smith.aufderhar@geemail.com	Miami Gardens	Florida	180094612005827760	4e4cdbaccb4aabae149f1a6396065e74	JCB 15 digit	26.0179862079616626	-80.2604573555536547
21238	2020-04-23 04:28:34	2020-04-23	Dr. Jamaal Zulauf	dr.jamaal.zulauf@geemail.com	Lancaster	California	6011097994169578067	652e457ca3c63b70b071fbcee6d98bfc	American Express	34.7858290832270001	-118.116922570948674
21239	2020-04-23 04:31:31	2020-04-23	Miss Caydence Mueller	miss.caydence.mueller@woohoo.com	San Francisco	California	3003812331571922	0a1a1dda57378c62bdaa3f682fd38231	Discover	37.7511387774681069	-122.428781085815359
21240	2020-04-23 04:33:55	2020-04-23	Gregorio Pouros	gregorio.pouros@warmmail.com	St. Petersburg	Florida	3044225550193964	f2b3cab22d1bdd2874c84637c0280dbe	JCB 15 digit	27.6936284645348785	-82.7391144838075974
21241	2020-04-23 04:39:10	2020-04-23	Daisy McCullough DVM	daisy.mccullough.dvm@geemail.com	Victorville	California	3052775564222151	0248209176ba6252440d46919db0b318	Maestro	34.4298422658115655	-117.417209781535348
21242	2020-04-23 04:51:09	2020-04-23	Micky Lindgren	micky.lindgren@geemail.com	Denton	Texas	3096445917343641500	35dd30024ba555ddaafcced2559903bb	Diners Club / Carte Blanche	33.3156270502865297	-97.0768391572531328
21243	2020-04-23 04:51:50	2020-04-23	Abdiel Johnston	abdiel.johnston@geemail.com	Phoenix	Arizona	869997004453832178	2bb6e9254c535d22abed27ed02fa219d	Diners Club / Carte Blanche	33.6191508283305964	-112.112454527376599
21244	2020-04-23 05:24:59	2020-04-23	Dr. Lamar Corkery I	dr.lamar.corkery.i@geemail.com	San Francisco	California	869976006762074983	52e5b599c6d8fc12561909d440dd57c8	VISA 13 digit	37.7657482902776493	-122.450425262080842
21245	2020-04-23 05:35:52	2020-04-23	Watson Langosh	watson.langosh@geemail.com	Milwaukee	Wisconsin	3473861786192333	ea96be4c6bcd01dc6eeb5ba4236f5e91	Discover	42.9703279411505861	-88.0405436562009243
21246	2020-04-23 06:09:27	2020-04-23	Darry Medhurst	darry.medhurst@geemail.com	Fort Worth	Texas	869911997412130258	c596d7ccca6dc5a7565590b68b209943	Diners Club / Carte Blanche	32.8622025711983454	-97.3501598335623726
21247	2020-04-23 06:21:35	2020-04-23	Tre Hahn	tre.hahn@geemail.com	Sacramento	California	4532199342876148	a4cdf181b20ed7cb5df8d8e1fafb7978	Voyager	38.5891088487844911	-121.490148403427
21248	2020-04-23 06:22:35	2020-04-23	Marchello Koch	marchello.koch@warmmail.com	Atlanta	Georgia	4370399826657	4c7740a0606560e35cfd8d1c8a85a6fd	VISA 13 digit	33.6805621337421286	-84.356759240669021
21249	2020-04-23 06:29:40	2020-04-23	Tory Rodriguez MD	tory.rodriguez.md@geemail.com	Oakland	California	6011162045445366023	ec9877dc383ff89bf9d42eeda093c618	VISA 13 digit	37.859604252237439	-122.273321415209693
21250	2020-04-23 06:45:14	2020-04-23	Concha O'Reilly	concha.o'reilly@warmmail.com	Orange	California	630456783473152	2ef03790a0c52cadedb687e2844abff3	Maestro	33.7303177676983168	-117.960195765282208
21251	2020-04-23 07:08:36	2020-04-23	Dr. Jonatan Hirthe MD	dr.jonatan.hirthe.md@geemail.com	Memphis	Tennessee	4028675931081134	2a27b16ea29e0b72e8e5462bd7b1f8d0	VISA 16 digit	35.0874835451200653	-90.0390679739672777
21252	2020-04-23 07:31:23	2020-04-23	Jaslene Anderson DVM	jaslene.anderson.dvm@geemail.com	Denver	Colorado	4660529643747933	57a5f1b9aaa99da36b5165c4b8e7bdb0	JCB 16 digit	39.7933258609432698	-104.969673194667706
21253	2020-04-23 07:47:12	2020-04-23	Mr. Lowell Gleichner DDS	mr.lowell.gleichner.dds@geemail.com	Jersey City	New Jersey	4746409325998	cb9fcc294a46975aa02217c6ed38a0ac	JCB 16 digit	40.7590679709274326	-74.0200025707438698
21254	2020-04-23 07:53:00	2020-04-23	Arne Torp	arne.torp@geemail.com	Aurora	Illinois	4998185948234	78e43040cbde7122a65f28987176dfa2	American Express	41.7729772347249124	-88.3742494279913586
21255	2020-04-23 07:55:51	2020-04-23	Donta Johnson	donta.johnson@woohoo.com	San Jose	California	4936572443458028	3b13ef68a323a2ea1ac1839ad222e8bb	Voyager	37.3420166537452474	-121.752769393402716
21256	2020-04-23 08:03:55	2020-04-23	Von Beer	von.beer@warmmail.com	Oakland	California	869946962822271810	f02658d87ab9f36448339ab7204b35f2	American Express	37.7817301640767127	-122.261219644490026
21257	2020-04-23 08:11:42	2020-04-23	Reno Ziemann	reno.ziemann@woohoo.com	Honolulu	Hawaii	3096063693371853017	03846866ae409355d11a4854bb71347d	Diners Club / Carte Blanche	21.3617855877831602	-157.881265564702829
21258	2020-04-23 08:13:21	2020-04-23	Maria Hoeger-Baumbach	maria.hoeger.baumbach@geemail.com	Los Angeles	California	3096011218493000488	4782a2570826905059d54d0eab3ab276	VISA 16 digit	34.1076132401689875	-118.474992855590955
21259	2020-04-23 08:31:54	2020-04-23	Baldwin Boehm	baldwin.boehm@geemail.com	New York	New York	4697253404993	d75d95ac80b39d509b32df6ea1461bf5	JCB 15 digit	40.6675644719731082	-73.9500860536366673
21260	2020-04-23 08:58:52	2020-04-23	Rayne Waelchi DVM	rayne.waelchi.dvm@woohoo.com	Austin	Texas	639004558331874	25e7ea887620288b432cff3efc5a3e13	VISA 16 digit	30.3909725591666984	-97.7475044240482163
21261	2020-04-23 09:08:15	2020-04-23	Beckett Kemmer	beckett.kemmer@geemail.com	Washington	District of Columbia	869914711417999667	c0e5936e44e4f3c7c295ed5156d58a25	American Express	38.9234698707502318	-77.0129701989915247
21262	2020-04-23 09:26:55	2020-04-23	Dr. Tessa Balistreri MD	dr.tessa.balistreri.md@woohoo.com	New York	New York	180081252145300256	bb88287a672afd7587aa9c9e9f8b007d	Discover	40.7265319251678903	-73.967324376980585
21263	2020-04-23 09:32:16	2020-04-23	Ms. Joette Trantow	ms.joette.trantow@geemail.com	Oakland	California	869962576726358538	79c73636bbc48e7193032370f023a8f3	Mastercard	37.8010463268797565	-122.268507476434422
21264	2020-04-23 09:48:53	2020-04-23	Dr. Sasha Smitham	dr.sasha.smitham@geemail.com	Washington	District of Columbia	4306338879083801	c5b8d1481f17a490b1d5ce4750207827	Maestro	38.8902453836783764	-76.9309696453370151
21265	2020-04-23 10:03:47	2020-04-23	Rashida Hickle-Medhurst	rashida.hickle.medhurst@warmmail.com	New York	New York	502037576072765	436f627b257e613c90be225b26e79293	Voyager	40.6460499029830089	-73.8852881558135124
21266	2020-04-23 10:10:16	2020-04-23	Russell Leffler	russell.leffler@warmmail.com	Garden Grove	California	3401114181481589	ddc4158662a824625e45aed29e8607ca	JCB 15 digit	33.8041856670577019	-117.886479044428086
21267	2020-04-23 10:22:56	2020-04-23	Boyd Murazik	boyd.murazik@geemail.com	San Diego	California	51319124851277925	0f65c25979e28330c00d006e26f680f6	VISA 16 digit	32.9062632994793347	-117.159974785512318
21268	2020-04-23 10:34:18	2020-04-23	Doreen Schoen DVM	doreen.schoen.dvm@geemail.com	New York	New York	3413413495940397	21e6acfcd13e1e32b4537874e2006e77	Mastercard	40.5779574642647063	-73.9637666515901628
21269	2020-04-23 10:35:36	2020-04-23	Riley Wintheiser	riley.wintheiser@geemail.com	Jacksonville	Florida	210015945061059548	a39df49e26484e00bb5fdc7b616ef05d	VISA 13 digit	30.2726401805929832	-81.6904809881545617
21270	2020-04-23 11:01:21	2020-04-23	Jovany O'Hara	jovany.o'hara@geemail.com	Berkeley	California	4153469955771144	53921c71e2f7d54c28751b30ad13a5d3	Diners Club / Carte Blanche	37.8871644417857851	-122.230271037841717
21271	2020-04-23 11:02:05	2020-04-23	Maximiliano Kulas Jr.	maximiliano.kulas.jr.@geemail.com	Denver	Colorado	6011007373083721989	1a82a1d0a4b81d9420f5681bd69bf818	JCB 16 digit	39.680222686618194	-104.820639301581679
21272	2020-04-23 11:05:04	2020-04-23	Lita Kuhn	lita.kuhn@geemail.com	Houston	Texas	502011834466044	d362b48f9320dcb9a965fa6bb9ae4bf0	Discover	29.7884600033130482	-95.3101241240758412
21273	2020-04-23 11:40:20	2020-04-23	Canyon Langworth-Kuphal	canyon.langworth.kuphal@geemail.com	San Francisco	California	4943852983797436	a082ff24c8697b539aea43dadfc6d2df	American Express	37.7598786651146412	-122.402517398760793
21274	2020-04-23 11:53:02	2020-04-23	Thad Hettinger	thad.hettinger@geemail.com	San Francisco	California	4419703648867	953e95328ab8823c9a48c26236ccc4b0	American Express	37.7413456289719562	-122.417676759383127
21275	2020-04-23 12:19:15	2020-04-23	Iridian Corwin	iridian.corwin@geemail.com	San Francisco	California	3040347005518175	f6a29b678f4e1917778447e2e0e954d5	Diners Club / Carte Blanche	37.7461583313092319	-122.408925815611042
21276	2020-04-23 12:28:27	2020-04-23	Shay Bogisich	shay.bogisich@geemail.com	Norman	Oklahoma	630499570356834	e227a4e51b29daf73ac276f52ffacc69	VISA 16 digit	35.2274516420014194	-97.3526430916760006
21277	2020-04-23 12:37:19	2020-04-23	Infant Cole	infant.cole@geemail.com	Baltimore	Maryland	4277031599304335	81f3896ba9d247bde2e518d2ee1d59af	Diners Club / Carte Blanche	39.3979666393715888	-76.6704548052530725
21278	2020-04-23 12:39:57	2020-04-23	Ms. Lasonya Marquardt	ms.lasonya.marquardt@geemail.com	Tulsa	Oklahoma	4504591962850185	f8136f0cd6a904f504418fa9ca5b8513	VISA 16 digit	36.0541582633178663	-95.9653809859372586
21279	2020-04-23 12:45:15	2020-04-23	Halley Kuhic	halley.kuhic@geemail.com	Pearland	Texas	639052861130434	d4f49745f6d72c1ae7f94f288b0adb0d	American Express	29.6321392651453621	-95.3203630397416646
21280	2020-04-23 12:50:19	2020-04-23	Margarett Bashirian	margarett.bashirian@geemail.com	Columbia	Missouri	4241346371729209	fff4dc823147a5b5396a2546a46225ec	JCB 16 digit	39.040509637666176	-92.3741750097421033
21281	2020-04-23 12:51:04	2020-04-23	Dr. Bernie Simonis	dr.bernie.simonis@geemail.com	Dallas	Texas	51480201406443609	29806f4f85285a174969b0d64f229c1e	JCB 16 digit	32.7547775251131554	-96.8115113152153697
21282	2020-04-23 12:59:58	2020-04-23	Dr. Eugene Raynor	dr.eugene.raynor@warmmail.com	San Antonio	Texas	502020811634599	3cacc14cc88ba3a88ceba6d93a2a53de	VISA 13 digit	29.4367789361231047	-98.6157175021082111
21283	2020-04-23 13:02:17	2020-04-23	Lloyd Sanford	lloyd.sanford@geemail.com	Los Angeles	California	52164720962126749	aa6c4ae7affb35471f20fedc3a8c2b49	VISA 13 digit	33.9216607556544218	-118.479413192671899
21284	2020-04-23 13:17:25	2020-04-23	Oralia Swaniawski	oralia.swaniawski@geemail.com	Frisco	Texas	3000742649156517	f5eacf23c83c075e7bd0ce40f9d8180c	American Express	33.173034069733319	-96.8738751344125717
21285	2020-04-23 13:38:55	2020-04-23	Mrs. Marilla Rempel DVM	mrs.marilla.rempel.dvm@geemail.com	Fort Lauderdale	Florida	53533174730534731	156278b9f53336eea44177b066a342f1	American Express	26.1499998561095452	-80.1459235525045557
21286	2020-04-23 13:42:57	2020-04-23	Miss Mannie Schowalter DDS	miss.mannie.schowalter.dds@geemail.com	Abilene	Texas	52969539012765554	d27022562c8e6ab34f0158df168216e8	VISA 16 digit	32.3971525220740588	-99.7040408890642311
21287	2020-04-23 14:10:34	2020-04-23	Dawne Wisozk MD	dawne.wisozk.md@geemail.com	Spokane	Washington	3059758830308734	33d638b8a05fcf97e13f07db190e6351	Mastercard	47.5929315588209789	-117.429865795084467
21288	2020-04-23 14:14:35	2020-04-23	Val Padberg	val.padberg@geemail.com	Reno	Nevada	6011422697066949325	e21427c0a8daecdb54cec55babb0a450	JCB 16 digit	39.5889065621964633	-119.916444682625681
21289	2020-04-23 14:19:28	2020-04-23	Barron Schaden-Jones	barron.schaden.jones@woohoo.com	Hayward	California	4540738820591958	e098b5f04e15b816b302baffdc588efc	VISA 16 digit	37.5900117291126392	-122.044953849099201
21290	2020-04-23 14:23:53	2020-04-23	Campbell Skiles IV	campbell.skiles.iv@geemail.com	San Francisco	California	180083090697221076	e52dc9710c8143affe2e06454a894e56	JCB 16 digit	37.7782617222030268	-122.440688217469102
21291	2020-04-23 14:25:14	2020-04-23	Deonta Macejkovic	deonta.macejkovic@geemail.com	Corona	California	4900550213079	73f4a2d37dd66f21608ba601b5ca66d1	JCB 16 digit	33.7891087947767232	-117.533021416116512
21292	2020-04-23 14:37:02	2020-04-23	Dr. Bernardo Jakubowski	dr.bernardo.jakubowski@geemail.com	New York	New York	54930430026439970	1c20a8cf9e6fb3b7f4d691a82bcaaef8	Discover	40.6831568639483265	-73.9918067810952635
21293	2020-04-23 14:52:49	2020-04-23	Marquez Casper III	marquez.casper.iii@geemail.com	San Antonio	Texas	4835574083225	6e8fe5d95069f81fdb9ea6205adbb88e	Mastercard	29.5221252453118552	-98.5910827635157858
21294	2020-04-23 14:54:31	2020-04-23	Dr. Lukas Schowalter	dr.lukas.schowalter@geemail.com	Jacksonville	Florida	3096681034661662093	fb1f42eb3ed6775c1d105a383def0414	Diners Club / Carte Blanche	30.3978712836332612	-81.735742370233325
21295	2020-04-23 14:56:54	2020-04-23	Hermon Abernathy	hermon.abernathy@geemail.com	San Jose	California	180078361722955559	3da4b59a2d50b889d396aa188d1ebea5	Discover	37.2590670561704798	-121.780483071853965
21296	2020-04-23 15:28:41	2020-04-23	Carolee Tillman-Streich	carolee.tillman.streich@geemail.com	San Francisco	California	4673346777141	cf6d0dbd065e2a976cd698a57a1867cc	Maestro	37.7832802970247243	-122.44028786032284
21297	2020-04-23 15:31:37	2020-04-23	Krish Schroeder	krish.schroeder@warmmail.com	Greeley	Colorado	3112412849597155250	4cc91d3047ef9577b3a360b98aa0c3f6	Diners Club / Carte Blanche	40.3814217967979658	-104.711671051320437
21298	2020-04-23 15:31:46	2020-04-23	Anthoney Mitchell Jr.	anthoney.mitchell.jr.@geemail.com	Charlotte	North Carolina	3096920468080546647	7f657ec2e81bd4b177172ef10f90576d	VISA 16 digit	35.1588213552508506	-80.7432450678143709
21299	2020-04-23 16:05:11	2020-04-23	Jorja Douglas-Bayer	jorja.douglas.bayer@woohoo.com	Norfolk	Virginia	210080394337907935	7385b426e8510e71d332732d7494f930	JCB 16 digit	36.841492645118386	-76.1819678702861154
21300	2020-04-23 16:13:20	2020-04-23	Pauline Lehner	pauline.lehner@woohoo.com	Philadelphia	Pennsylvania	4776171493740	a87f4cc54c4206cbadf6a56d97cea542	Diners Club / Carte Blanche	39.9184533577837044	-75.1439003304943469
21301	2020-04-23 16:16:03	2020-04-23	Venus Gaylord	venus.gaylord@geemail.com	Alexandria	Virginia	589325637773091	38130699b6b06451f46c4aba1f306171	JCB 16 digit	38.747279913548752	-77.1800124480374166
21302	2020-04-23 16:22:20	2020-04-23	Dr. Nakia Kuhlman DDS	dr.nakia.kuhlman.dds@geemail.com	New York	New York	3020707334218039	376867a8d9584f0291f1d4c938e0c6bf	Maestro	40.6435349821336587	-74.0319431761641056
21303	2020-04-23 16:32:28	2020-04-23	Micky Franecki I	micky.franecki.i@warmmail.com	Madison	Wisconsin	3088811466986179853	c14b4b97c409dc40e246f6c20d931bae	Voyager	43.1348328810624793	-89.3322144655395363
21304	2020-04-23 16:41:40	2020-04-23	Areli Vandervort	areli.vandervort@woohoo.com	San Francisco	California	55189214166642348	d24bc1821e8019cd72c1a9c99e3d7346	Voyager	37.7391554946315964	-122.456685631213915
21305	2020-04-23 17:10:18	2020-04-23	Deward Lehner	deward.lehner@geemail.com	South Bend	Indiana	869948656819972657	a19b92a9a2279fb6d73035fc1bf9789c	Maestro	41.763455142933509	-86.1776065443698371
21306	2020-04-23 17:19:21	2020-04-23	Mr. Long Von	mr.long.von@geemail.com	Minneapolis	Minnesota	4930941450437	ccf96cfea3e7f2511c8b20d172b4c370	Maestro	44.8702165621418487	-93.3262306756611935
21307	2020-04-23 17:20:40	2020-04-23	Dr. Aditya Williamson	dr.aditya.williamson@geemail.com	New York	New York	3112036796028602655	1cd9bfefecb79a374838fd630023c570	VISA 16 digit	40.6390529819522044	-73.8936765122123091
21308	2020-04-23 17:30:45	2020-04-23	Ruffin Mills MD	ruffin.mills.md@geemail.com	Oakland	California	52590347264428534	67e405a4060d496eedb5c72affc04d8d	Voyager	37.8070668905002805	-122.255430509503952
21309	2020-04-23 17:33:37	2020-04-23	Retta Hand	retta.hand@warmmail.com	Mobile	Alabama	6011615066355816057	e87149064bd01f38e2bac9049c0caee6	Maestro	30.7518863268770275	-88.0442995200537126
21310	2020-04-23 17:50:29	2020-04-23	Gennie Simonis	gennie.simonis@geemail.com	Philadelphia	Pennsylvania	501843964891279	ae566e821325161978757fd82e98419c	VISA 16 digit	40.0706552227452377	-75.1063064998380838
21311	2020-04-23 18:01:31	2020-04-23	Cherrie Roberts	cherrie.roberts@geemail.com	Berkeley	California	676198752430359	841a7ebbc2a0f3964fade45be389131d	VISA 13 digit	37.9219948553151838	-122.245040940979038
21312	2020-04-23 18:07:12	2020-04-23	Damond Prosacco-Gleason	damond.prosacco.gleason@geemail.com	San Francisco	California	502040822141491	4bd0c9d1d203cc6f8ab6e070fa4393a4	American Express	37.7337632507095222	-122.388556515757301
21313	2020-04-23 18:18:19	2020-04-23	Brinley Smitham	brinley.smitham@geemail.com	Phoenix	Arizona	501839826632174	a51f7a5baaf5185bf7947c447fa71036	VISA 13 digit	33.6175924940899051	-112.1747526012756
21314	2020-04-23 19:05:40	2020-04-23	Mahalia Littel	mahalia.littel@geemail.com	Los Angeles	California	3112041315515069063	d63e2654f278112b9f24750edb150598	JCB 15 digit	34.0123764669388535	-118.455108329885817
21315	2020-04-23 19:18:32	2020-04-23	Shardae Bauch-Bednar	shardae.bauch.bednar@geemail.com	Knoxville	Tennessee	869981770643157639	dbcb55c4ff0c4d08ed63aa08ec65ff23	Discover	35.9895296581618496	-83.9113885596144939
21316	2020-04-23 19:22:32	2020-04-23	Dr. Dan Muller	dr.dan.muller@geemail.com	Mesa	Arizona	869993192317735770	319b113c9747710e21f3c61df039e911	JCB 16 digit	33.3828642099309718	-111.74964327610806
21317	2020-04-23 19:26:22	2020-04-23	Ismael Hoeger	ismael.hoeger@geemail.com	Dallas	Texas	3013025543452977	fcfaa36893c618c07e4f789381b61b95	Discover	32.8845185983732335	-96.8645750607326619
21318	2020-04-23 19:42:38	2020-04-23	Kaleigh Macejkovic	kaleigh.macejkovic@warmmail.com	San Francisco	California	210035442915820776	27aee068febfaae59be52ba3cd3ea610	JCB 16 digit	37.7896894530614134	-122.443511456511317
21319	2020-04-23 20:08:03	2020-04-23	Genevra Torphy	genevra.torphy@geemail.com	Kansas City	Missouri	180059094299192628	4b10b217458b07ae6bf64dc2827d3aea	JCB 15 digit	39.0680340679198537	-94.5834272962752749
21320	2020-04-23 20:16:36	2020-04-23	Sheridan Spencer	sheridan.spencer@geemail.com	Fresno	California	4648237052549710	1c8e87ed2a7a1066ccf03ee5dbdaefca	Mastercard	36.805309297550842	-119.890533579663938
21321	2020-04-23 20:17:06	2020-04-23	Anona Borer DDS	anona.borer.dds@geemail.com	Rancho Cucamonga	California	6011574180726318070	ec7bbce01b0ed17ccb26e49413e1ab7e	JCB 16 digit	34.0988936994217369	-117.53739700131193
21322	2020-04-23 20:17:23	2020-04-23	Muriel Fay DDS	muriel.fay.dds@geemail.com	San Francisco	California	4491719503429772	0ca1e2b4e37ba131e2d62598ef50a5f0	VISA 16 digit	37.7588712686406609	-122.441656199983015
21323	2020-04-23 20:47:12	2020-04-23	Mr. Campbell Howell	mr.campbell.howell@warmmail.com	San Francisco	California	4008618972882	0cb76d4abb4d8256b68d6408cac5e657	Discover	37.7464790470171678	-122.449917066143712
21324	2020-04-23 21:13:38	2020-04-23	Lilie Ruecker	lilie.ruecker@geemail.com	Los Angeles	California	3792896964500680	0dbd0ac66b18b165a617ee986c97f1fc	VISA 13 digit	34.0455360188480469	-118.360538808302209
21325	2020-04-23 21:16:29	2020-04-23	Dr. Zion Haag IV	dr.zion.haag.iv@geemail.com	Seattle	Washington	4677342424568051	9728c28579f2246ec1c39c2d1a5d4c50	VISA 16 digit	47.6187003857381654	-122.4428797365088
21326	2020-04-23 21:22:06	2020-04-23	Alvia Quitzon IV	alvia.quitzon.iv@woohoo.com	Winston–Salem	North Carolina	675970502978755	6bbb32ff3f26b7f1d4f722da11186fe2	Diners Club / Carte Blanche	36.1967858507528888	-80.2850891465917158
21327	2020-04-23 21:22:26	2020-04-23	Mr. Stevie Heaney PhD	mr.stevie.heaney.phd@warmmail.com	San Francisco	California	3450524050500931	b5558f7ccd129208c75949c488ce4b3b	VISA 16 digit	37.7599177319549426	-122.450433539899009
21328	2020-04-23 21:38:44	2020-04-23	Jensen Ortiz DVM	jensen.ortiz.dvm@woohoo.com	New York	New York	3425474442595011	55e47ae3ad5830ca5493b74c99c83d39	Maestro	40.6548419189397237	-73.9772324880946428
21329	2020-04-23 21:42:40	2020-04-23	Mrs. Yasmeen Crooks	mrs.yasmeen.crooks@geemail.com	Berkeley	California	4912512905973	6378e1cc13085383c8f60fa1cbd8406c	VISA 16 digit	37.8705868704824695	-122.28528175868712
21330	2020-04-23 21:45:28	2020-04-23	Mr. Tyree Bruen IV	mr.tyree.bruen.iv@geemail.com	San Francisco	California	180079799170267234	e46c27401b5761e7f5615a442ad36538	VISA 16 digit	37.7960406970613647	-122.48453988864452
21331	2020-04-23 21:46:40	2020-04-23	Abelardo Gottlieb-Berge	abelardo.gottlieb.berge@geemail.com	Cary	North Carolina	4372303531316	c412650f516c2b0a5ee91a75b5f4a581	JCB 16 digit	35.7560429655589189	-78.762463332069288
21332	2020-04-23 22:01:58	2020-04-23	Mr. Judson Pouros PhD	mr.judson.pouros.phd@warmmail.com	Orlando	Florida	4694071707646156	c9e3b2c5508dc750994b30bd5cadf043	JCB 16 digit	28.4696822636093927	-81.2451207767207251
21333	2020-04-23 22:12:45	2020-04-23	Landon Reinger	landon.reinger@geemail.com	Philadelphia	Pennsylvania	3528311750929204315	8c2b0cd4de802d7882b45f43890e519e	VISA 16 digit	40.0407879939727493	-75.0532346554000043
21334	2020-04-23 22:28:24	2020-04-23	Mr. River Torp	mr.river.torp@geemail.com	San Francisco	California	4519809102048	aa827dc3c246054e62b5473ba78d6f7e	Diners Club / Carte Blanche	37.7750176710964709	-122.464432287988117
21335	2020-04-23 22:43:08	2020-04-23	Traci Hoppe	traci.hoppe@geemail.com	San Francisco	California	4072907237449	36b7618744c5033f0ba6762bd5798fab	Maestro	37.7841441229050048	-122.454595972163546
21336	2020-04-23 22:45:36	2020-04-23	Elvin Russel	elvin.russel@woohoo.com	Plano	Texas	6011500610723326089	316aeedad3a437c60c6faccd9b6e9e4a	VISA 16 digit	33.0026894923385257	-96.8341720994744435
21337	2020-04-23 22:45:54	2020-04-23	Bernard Douglas	bernard.douglas@geemail.com	Los Angeles	California	869976893468500217	158c7427369aecd7fa0f75e19f9e360d	JCB 15 digit	33.9699375499837046	-118.392869310592488
21338	2020-04-23 22:46:52	2020-04-23	Ms. Stefani Aufderhar DDS	ms.stefani.aufderhar.dds@woohoo.com	Baltimore	Maryland	3727294809020249	8a428f03ac6fa18ac0b417b47a5f74a9	JCB 15 digit	39.3063216480892095	-76.5114379162453133
21339	2020-04-23 22:52:29	2020-04-23	Ms. Love Shanahan	ms.love.shanahan@geemail.com	Stamford	Connecticut	3402289818271717	0128baed9160e5707ccfd550b505fce1	American Express	41.0594169270597433	-73.5326647818125849
21340	2020-04-23 23:25:28	2020-04-23	Edgardo Herman-Osinski	edgardo.herman.osinski@geemail.com	Atlanta	Georgia	4986774987416	05385793da0e8d24f944125874e64a33	Diners Club / Carte Blanche	33.7435447888724553	-84.3342515967831048
21341	2020-04-23 23:40:31	2020-04-23	Kelis Quitzon-Sipes	kelis.quitzon.sipes@geemail.com	Memphis	Tennessee	630470243599183	7ee37c42d856535f2ed94803915e8688	Mastercard	35.0294333068721002	-89.9991856205068501
21342	2020-04-23 23:56:59	2020-04-23	Tyriq Leffler MD	tyriq.leffler.md@woohoo.com	Clinton	Michigan	676300341220812	7476ab3f950815751c4f1be7e2bdbe5b	JCB 16 digit	42.6206878864273406	-82.9469536285456286
21343	2020-04-24 00:03:20	2020-04-24	Mrs. Chastity Lemke	mrs.chastity.lemke@geemail.com	Chicago	Illinois	3088619933832242510	ad46835101d3e1d18c3a61b32be0ab26	Maestro	41.824905141519757	-87.7146364924993378
21344	2020-04-24 00:08:05	2020-04-24	Mr. Talan Rodriguez DVM	mr.talan.rodriguez.dvm@woohoo.com	Denver	Colorado	53140906705600574	599ecc20abfdd3fac46f9c23455f8dfd	Maestro	39.6975249456759514	-104.895740747522936
21345	2020-04-24 00:12:17	2020-04-24	Meghan Stanton	meghan.stanton@geemail.com	Berkeley	California	3005115871480357	594d83d037cc36c30c95f2f6bb23697c	Discover	37.8940230213634379	-122.28746465753899
21346	2020-04-24 00:14:39	2020-04-24	Renae Hilll	renae.hilll@warmmail.com	San Francisco	California	675963746313822	53cb75e19e621c5920b69f87f9818075	Diners Club / Carte Blanche	37.7842095347658358	-122.416182304257973
21347	2020-04-24 00:30:46	2020-04-24	Weldon Effertz DVM	weldon.effertz.dvm@woohoo.com	Anaheim	California	3402682006203247	f5e1354c8974420cd3ef45e3c297a3b5	Discover	33.934444063326346	-117.811319735387713
21348	2020-04-24 00:45:14	2020-04-24	Ellamae Bahringer	ellamae.bahringer@geemail.com	Memphis	Tennessee	4519867694830031	4ed3f148ad8a625a142242922112c674	Mastercard	35.1075632769215886	-89.9774004866160482
21349	2020-04-24 01:02:21	2020-04-24	Jerod Mraz	jerod.mraz@geemail.com	Saint Paul	Minnesota	4994790827560099	9d4ac29744547ab83b6c6ba8bc1ddae6	VISA 16 digit	44.9662103305976828	-93.126908946110305
21350	2020-04-24 01:09:39	2020-04-24	Dr. Dianna Hintz	dr.dianna.hintz@woohoo.com	Berkeley	California	55632160764074306	2f5d675b489cbde1b4eef460c051ce83	JCB 16 digit	37.8847092833815893	-122.305703951273159
21351	2020-04-24 01:12:25	2020-04-24	Ms. Aryana Haag DDS	ms.aryana.haag.dds@warmmail.com	San Diego	California	4578584470491	ce110a2356f6f0d817ac82b410233102	VISA 16 digit	32.8428434756185865	-117.069216569969441
21352	2020-04-24 01:15:28	2020-04-24	Nannette Ruecker	nannette.ruecker@geemail.com	San Francisco	California	210096329201400106	e36fc6e376cae5b991a3bf561c3ecb58	Diners Club / Carte Blanche	37.7737970945447046	-122.425256108850746
21353	2020-04-24 01:35:09	2020-04-24	Caleigh Kuhlman MD	caleigh.kuhlman.md@warmmail.com	Allen	Texas	4422323298422979	6cced63a93b343d8cdb1a74fcf5b8f9e	Discover	33.0052296096019404	-96.6968118824478182
21354	2020-04-24 01:39:58	2020-04-24	Ms. Hanna Dibbert	ms.hanna.dibbert@geemail.com	New York	New York	210085399577065075	ba1ab8a12f3e4208ad5c1ea070f18983	Mastercard	40.5744900424722559	-73.9612255041383122
21355	2020-04-24 01:40:28	2020-04-24	Tiney Skiles-Abshire	tiney.skiles.abshire@warmmail.com	Lexington	Kentucky	869966244342916306	3593b3f6e399f637270734d0711dc3c0	Voyager	38.0341419319964942	-84.3747091809186998
21356	2020-04-24 01:40:49	2020-04-24	Vanesa Crona-Medhurst	vanesa.crona.medhurst@geemail.com	El Paso	Texas	676311462340081	b203d2f1abba988ff428df54ff0f65c3	Voyager	31.9054160201750712	-106.48644087794051
21357	2020-04-24 01:50:57	2020-04-24	Pandora Kautzer	pandora.kautzer@geemail.com	San Francisco	California	4703697093042557	3dd52326df5a0ba1a7050224f46eb4ee	Voyager	37.7845438955129111	-122.418848330190173
21358	2020-04-24 01:51:16	2020-04-24	Conard Stanton Jr.	conard.stanton.jr.@warmmail.com	San Francisco	California	4832592481455368	0e8717f042a85723f7594c39bfe0fe79	Discover	37.8026167738788885	-122.433909568878079
21359	2020-04-24 01:59:58	2020-04-24	Dr. Halbert Schultz	dr.halbert.schultz@woohoo.com	Miramar	Florida	3037964645431941	056728ca2a9b2aef253b829a6e20ebcb	Diners Club / Carte Blanche	25.9202696025818575	-80.3033771983340472
21360	2020-04-24 02:06:26	2020-04-24	Ms. Genevra Dach	ms.genevra.dach@geemail.com	Houston	Texas	4019352238497	e2d9adefbaf3341af64950e530f303a5	Diners Club / Carte Blanche	29.88304130738452	-95.4455654064208261
21361	2020-04-24 02:10:06	2020-04-24	Stetson Veum	stetson.veum@geemail.com	Grand Rapids	Michigan	51238873690131515	08397623ab6c47139f26f4db0c348d2b	JCB 16 digit	42.9685265854269218	-85.7242822726856986
21362	2020-04-24 02:13:18	2020-04-24	Laquan Grady	laquan.grady@geemail.com	Kansas City	Missouri	3033823518014735	4af807f740926341563901b979d4e2ae	Voyager	39.1615717296324704	-94.5152063611652693
21363	2020-04-24 02:15:23	2020-04-24	Dr. Kolton Lubowitz Sr.	dr.kolton.lubowitz.sr.@geemail.com	San Jose	California	502064613631189	e675eabdce005a6d16cd9aca52feb3bc	Mastercard	37.3836868385605499	-121.836968721424782
21364	2020-04-24 02:21:46	2020-04-24	Armand Parker	armand.parker@warmmail.com	Arlington	Texas	869946306061282288	9460790a410e2e694ead092bdc43edf4	American Express	32.6236610471986239	-97.1837673274360583
21365	2020-04-24 02:36:34	2020-04-24	Mr. Genie Hansen	mr.genie.hansen@woohoo.com	Los Angeles	California	3490123690053989	6da9407693ca0067a29332191e8f43e7	JCB 16 digit	33.9568730871058975	-118.327719736377887
21366	2020-04-24 02:38:02	2020-04-24	Miles Bernhard	miles.bernhard@warmmail.com	Fresno	California	3444227214338151	0140dffa0acd4096f622e9747567866f	VISA 13 digit	36.8722999863665564	-119.87233894780428
21367	2020-04-24 02:41:43	2020-04-24	Maleah Hayes	maleah.hayes@geemail.com	Plano	Texas	869911920447731429	4af3378162e4fb9c3920d44f4a86648b	Maestro	33.0570631437089304	-96.6614246390942498
21368	2020-04-24 02:45:32	2020-04-24	Keyshawn Jast	keyshawn.jast@geemail.com	Bridgeport	Connecticut	3790691482971139	e591f6e9da44e5a22e5abdc74abbe43c	Voyager	41.285736253315207	-73.1212828418139367
21369	2020-04-24 02:46:52	2020-04-24	Mr. Willam Zemlak	mr.willam.zemlak@geemail.com	New York	New York	4814777007422	ff87ce9c7c92fa701750feb81f0ddab7	JCB 16 digit	40.7387073156647403	-73.9000503446336836
21370	2020-04-24 02:48:42	2020-04-24	Lucian Lakin	lucian.lakin@woohoo.com	Stamford	Connecticut	4402719305938	dccf2589817871c0d6668ce0350d0e99	Discover	41.1782713967725655	-73.6137009761799135
21371	2020-04-24 02:52:39	2020-04-24	Wesley Bauch	wesley.bauch@geemail.com	New York	New York	3096740195515066143	ba6b3055c1d095f583efd584e4185a63	Mastercard	40.6529028784241504	-73.9234685349639449
21372	2020-04-24 03:18:41	2020-04-24	Ms. Jenni Reinger DVM	ms.jenni.reinger.dvm@geemail.com	Philadelphia	Pennsylvania	55171990400387671	9a22df38175d637f8d1e58c8bb966d79	Discover	40.0514132483355709	-75.2031790042195496
21373	2020-04-24 03:24:14	2020-04-24	Reed Roob	reed.roob@woohoo.com	New York	New York	4333591023459999	5d731049d2b8aa44d68a1441c339811b	JCB 16 digit	40.5637836104016714	-73.9654228481825413
21374	2020-04-24 03:24:54	2020-04-24	Mathew Hoeger	mathew.hoeger@geemail.com	New York	New York	4474987324586	ca7f4271d3194be9470dc3f40ab93abe	VISA 13 digit	40.6616027817353611	-73.8813664430182371
21375	2020-04-24 03:34:36	2020-04-24	Sharman McClure-Kemmer	sharman.mcclure.kemmer@geemail.com	Toledo	Ohio	3488194467001018	2a28e96e6f78877a7cf2655e4dec96b2	VISA 16 digit	41.7185141537044188	-83.6166825490869599
21376	2020-04-24 03:35:41	2020-04-24	Tori Hilpert	tori.hilpert@geemail.com	Sandy Springs	Georgia	51817733063237456	5bacbc264b585c2a51d1ed634f7b45cb	Maestro	33.8429728068001552	-84.3919814774382928
21377	2020-04-24 03:46:42	2020-04-24	Dr. Alek Metz	dr.alek.metz@geemail.com	Houston	Texas	6011731082198499737	9b7d1961bf79f415e96ab1bf20cf2f7f	VISA 13 digit	29.7496144465249017	-95.3125639105696223
21378	2020-04-24 03:53:26	2020-04-24	Rylie Hansen	rylie.hansen@geemail.com	Stockton	California	51027688300736510	231f8cfef06d7d352803ffaa7049426b	Maestro	38.0205616122309138	-121.360399077887834
21379	2020-04-24 04:21:24	2020-04-24	Leland Torphy	leland.torphy@geemail.com	San Francisco	California	4566660170641341	cf231a63b6fc4390a13f6cbfbb55f15b	Diners Club / Carte Blanche	37.7948088127880411	-122.451209080002812
21380	2020-04-24 04:26:30	2020-04-24	Tawnya Dickens	tawnya.dickens@geemail.com	Bakersfield	California	675999072212428	1ecdf4e08dbfc721bca2057dd583e513	Discover	35.3696467362053681	-119.079771795104435
21381	2020-04-24 04:33:41	2020-04-24	Evette Daniel	evette.daniel@geemail.com	West Jordan	Utah	3426638772932171	e5cfdd15b8f4b53d9a920c6df7512c74	Discover	40.5477349323477654	-112.056612062835313
21382	2020-04-24 04:43:52	2020-04-24	Lamonte Gerlach I	lamonte.gerlach.i@geemail.com	Milwaukee	Wisconsin	3088946379462918199	c442a33728cf6671d8e08a8b74d7ffc4	Maestro	43.0571964801374776	-88.046657753513017
21383	2020-04-24 04:56:26	2020-04-24	Marylouise Homenick PhD	marylouise.homenick.phd@geemail.com	Oxnard	California	51821111294178258	abfd42c68656f4fa41390f1339e05e81	Diners Club / Carte Blanche	34.1993015739090751	-119.169436504869168
21384	2020-04-24 04:59:58	2020-04-24	Mr. Wade Gottlieb	mr.wade.gottlieb@woohoo.com	Hampton	Virginia	51475773866775545	ad0ba582a511b75922e8f7fa7cb77331	JCB 16 digit	37.0446922512278007	-76.2180681742358956
21385	2020-04-24 05:08:20	2020-04-24	Katharine Ryan	katharine.ryan@geemail.com	Orange	California	4714729242185818	70d426f2f232df58719b2aed0b828d82	VISA 16 digit	33.7705589714813996	-117.911628725995499
21386	2020-04-24 05:16:54	2020-04-24	Lowell Jakubowski	lowell.jakubowski@geemail.com	Oakland	California	3456575242725525	56a9be8b2d90d6075125e6816d87c28e	Diners Club / Carte Blanche	37.7813671665954729	-122.274455195394708
21387	2020-04-24 05:29:50	2020-04-24	Ransom Parisian	ransom.parisian@geemail.com	Oakland	California	3337426190678211801	e66356c5a5e9c1c573f610c47bb388b9	Mastercard	37.8218099485687986	-122.276281262747403
21388	2020-04-24 05:37:19	2020-04-24	Deidra Hammes	deidra.hammes@geemail.com	Rockford	Illinois	869922173285859830	1e9886146ca1c0c02133fb8fda1203f7	Diners Club / Carte Blanche	42.2852031927101351	-89.1628079186476725
21389	2020-04-24 05:39:14	2020-04-24	Miss Unique Schinner	miss.unique.schinner@geemail.com	Oakland	California	6011261306849130955	395c0ca2b94794e5932a93b6a58db54e	Mastercard	37.8070339164979927	-122.28992256849142
21390	2020-04-24 05:39:59	2020-04-24	Mr. Charle Raynor	mr.charle.raynor@warmmail.com	San Francisco	California	3023895784010563	aa183a34d7e8ac85e170ab7d7b0f55ab	Discover	37.7659707384325216	-122.387340572849638
21391	2020-04-24 05:42:31	2020-04-24	Rella Gaylord	rella.gaylord@geemail.com	Omaha	Nebraska	676108878416729	f5e3426718371a790c13f26b7827a4cb	JCB 15 digit	41.1925431626062846	-95.9790962704572905
21392	2020-04-24 05:43:09	2020-04-24	Randell Murray	randell.murray@geemail.com	Los Angeles	California	6011707952757326010	92c3865684178e91502445d45c94c963	JCB 16 digit	34.0852332429360558	-118.353535050758339
21393	2020-04-24 05:49:09	2020-04-24	Mr. Johathan Sporer	mr.johathan.sporer@geemail.com	Stockton	California	3088461021050953221	5e021c504dd09fc9d299911d95454505	VISA 16 digit	37.9685728284727801	-121.398996801543234
21394	2020-04-24 05:59:24	2020-04-24	Mallorie Marvin-Huels	mallorie.marvin.huels@geemail.com	Providence	Rhode Island	869901020274718789	033f4d246d51d889fad654a700ca4894	JCB 16 digit	41.8926113317575286	-71.5113028984900581
21395	2020-04-24 06:07:45	2020-04-24	Tommie Swaniawski-Schinner	tommie.swaniawski.schinner@geemail.com	Paterson	New Jersey	4319827882607478	09d512e7b5f384a00fb804e0bdf6aee6	American Express	40.828431200045344	-74.1187678406920298
21396	2020-04-24 06:12:16	2020-04-24	Dr. Kelsi Runolfsdottir	dr.kelsi.runolfsdottir@geemail.com	Chicago	Illinois	3096786665808752372	0b5cf0d82585607cd66335428bb833b4	JCB 15 digit	41.8484368731103871	-87.613753852809964
21397	2020-04-24 06:18:53	2020-04-24	Ms. Lurline Abshire	ms.lurline.abshire@geemail.com	Portland	Oregon	639017076558109	b0a3de5b42df49a106264f3f1120069e	JCB 16 digit	45.6018668224457642	-122.607285148976374
21398	2020-04-24 06:30:01	2020-04-24	Pratt Hermiston	pratt.hermiston@warmmail.com	Santa Clara	California	6011826501441851291	01901acdbfb2782c034e5025ff83f059	Voyager	37.2680362077713028	-121.976723029976341
21399	2020-04-24 06:31:40	2020-04-24	Ilona Ritchie	ilona.ritchie@geemail.com	New York	New York	3469791374798975	720f383055e3e71d3c394fa9d5021fb4	JCB 15 digit	40.6235269625429041	-73.883345077502355
21400	2020-04-24 06:35:58	2020-04-24	Christina Nikolaus	christina.nikolaus@geemail.com	New York	New York	3007170554614291	c4d8a9fd3601b4b14d719c4bbb790329	Mastercard	40.6921796803586204	-74.0288926975231618
21401	2020-04-24 06:39:39	2020-04-24	Dr. Glynn Kilback	dr.glynn.kilback@woohoo.com	Tallahassee	Florida	3754562932091311	05dd6c19c22e210bb15973d42f85b3cc	VISA 16 digit	30.5357715164333605	-84.2667366868831209
21402	2020-04-24 06:40:44	2020-04-24	Quinten Gusikowski	quinten.gusikowski@warmmail.com	Cary	North Carolina	4201190957739606	32e3a0de0a787871b1092c4243582c15	Voyager	35.8725386919561799	-78.7696114021904776
21403	2020-04-24 06:41:56	2020-04-24	Joy Rowe	joy.rowe@woohoo.com	Philadelphia	Pennsylvania	6011806915330092490	6d9dd78fc97e406088d3cd83561e0ef7	Mastercard	39.9294357104651638	-75.0968675753466783
21404	2020-04-24 06:49:55	2020-04-24	Collie Rice	collie.rice@geemail.com	Portland	Oregon	3112733246970999887	81c3d691a04cc0593ddf5225d630fc7f	VISA 16 digit	45.4785796607267088	-122.715246286382907
21405	2020-04-24 06:52:50	2020-04-24	Adelbert Little	adelbert.little@woohoo.com	New York	New York	6011356209616500960	48dceb3623ab8516ce87626a3e73dbcf	VISA 13 digit	40.7052948730755588	-73.9862203135050862
21406	2020-04-24 07:04:31	2020-04-24	Amari Reilly	amari.reilly@geemail.com	Raleigh	North Carolina	4750180492696713	ca09178797d360188b13803af1563726	VISA 16 digit	35.7928480834368585	-78.6122468904528802
21407	2020-04-24 07:13:38	2020-04-24	Dr. Maxwell Rogahn	dr.maxwell.rogahn@warmmail.com	Omaha	Nebraska	3112695286112060046	d729685ce58f18b06686242a4ae01b19	American Express	41.1866012244164992	-96.0396278287399667
21408	2020-04-24 07:28:12	2020-04-24	Ms. Emmaline Ryan	ms.emmaline.ryan@geemail.com	Los Angeles	California	4969597986570863	c3cb16a5070b4f1b36dea1d991e3b032	Mastercard	34.0973352970886978	-118.505434259026487
21409	2020-04-24 07:34:31	2020-04-24	Dr. Schuyler Dicki	dr.schuyler.dicki@woohoo.com	Phoenix	Arizona	4926474638380939	acae45117255f21b2c60ccecd3ef55a6	VISA 16 digit	33.543971080931648	-112.036590021375943
21410	2020-04-24 07:37:06	2020-04-24	Ms. Ireland Walter MD	ms.ireland.walter.md@warmmail.com	Mesa	Arizona	4738110637927217	bee5278c1ce756531f3f8f4d39a89c62	Maestro	33.4515557346545123	-111.746915026463199
21411	2020-04-24 08:06:48	2020-04-24	Tavon Denesik	tavon.denesik@woohoo.com	New York	New York	503840133001491	c4bae37121bac2d2d0a0cb00ac4be86d	JCB 16 digit	40.6537254641521741	-73.9376980787504436
21412	2020-04-24 08:12:18	2020-04-24	Madeleine Thiel MD	madeleine.thiel.md@woohoo.com	Los Angeles	California	3053061262549701	d0dc64cb757d5ecdf10a997106add4f1	JCB 16 digit	34.0514627405773851	-118.404868416301156
21413	2020-04-24 08:12:25	2020-04-24	Celia Wiza MD	celia.wiza.md@warmmail.com	Austin	Texas	3112554318219418700	80d37ad57adaa98c6fe713e8b43eb457	VISA 16 digit	30.2760929760649802	-97.8083705860894241
21414	2020-04-24 08:37:39	2020-04-24	Elenor Raynor MD	elenor.raynor.md@geemail.com	New York	New York	3337307919403396717	0a2bf720d2e04fcb8a6061a7a26b0088	American Express	40.6894478096384518	-73.9664098648250103
21415	2020-04-24 08:41:10	2020-04-24	Alex Hamill	alex.hamill@geemail.com	Des Moines	Iowa	4985074339948	72ba070293b1f3672eebb1b1d04b42b9	American Express	41.4729910006489604	-93.5374861641366095
21416	2020-04-24 08:53:50	2020-04-24	Danae Wolf	danae.wolf@geemail.com	Bakersfield	California	3773407587610048	015c2bea50afb158ad427a55799d1ea8	Voyager	35.3097533983353529	-119.009879678980624
21417	2020-04-24 09:03:11	2020-04-24	Ivah Hackett PhD	ivah.hackett.phd@geemail.com	Tampa	Florida	6011817199674798528	fbd4e9ed23a38095d12cd8a51b4fcdb2	Mastercard	27.8730151281341882	-82.4075672419954088
21418	2020-04-24 09:05:02	2020-04-24	Jessee Dooley I	jessee.dooley.i@geemail.com	Los Angeles	California	51918405045515964	6dbec888699896862b40bb9e4df540f4	Discover	34.019747335590047	-118.409310104184968
21419	2020-04-24 09:13:08	2020-04-24	Joretta Zboncak-Kertzmann	joretta.zboncak.kertzmann@geemail.com	Daly City	California	6011187948484436659	3f5df8d9b1b9dab113b878b76b15c888	Diners Club / Carte Blanche	37.7161621677610981	-122.387296552220363
21420	2020-04-24 09:20:29	2020-04-24	Mr. Arno Effertz II	mr.arno.effertz.ii@geemail.com	New York	New York	3088778116463672703	55d7bbde5f01f455e7b39f66ac4468d9	JCB 16 digit	40.6852768249101899	-73.9423757236346546
21421	2020-04-24 09:27:09	2020-04-24	Kalel Rosenbaum	kalel.rosenbaum@geemail.com	New York	New York	210073528475461093	ce17a5e2b7c123571ed773e7bc21cfa9	Diners Club / Carte Blanche	40.6312424536086638	-74.0259647359967232
21422	2020-04-24 09:28:38	2020-04-24	Nancy Howe	nancy.howe@geemail.com	New York	New York	4366158287276319	21f3a8b28394e4fa1171bb4dbad41acd	JCB 15 digit	40.6028180508166514	-73.8479243549879669
21423	2020-04-24 09:55:57	2020-04-24	Lutie Lubowitz	lutie.lubowitz@geemail.com	Tempe	Arizona	3158830889698104918	724653342f1251410b6255dc87d7687f	Maestro	33.4531011152934283	-111.864851582658659
21424	2020-04-24 09:59:23	2020-04-24	Ronna Douglas	ronna.douglas@geemail.com	Chicago	Illinois	3021552553991695	938b1615324dd3b5cd30166c78134338	JCB 16 digit	41.9177522988826041	-87.6002445101302101
21425	2020-04-24 10:01:02	2020-04-24	Ms. Yvonne Farrell	ms.yvonne.farrell@geemail.com	Phoenix	Arizona	869913975771441621	794b60c00ad411a7c04f49c18863853d	JCB 16 digit	33.5938244060546154	-112.094463146470872
21426	2020-04-24 10:12:36	2020-04-24	Adelard Hermiston II	adelard.hermiston.ii@geemail.com	Austin	Texas	3158740876441705942	2f13b9b5cbff49ad0a0545fc1923934a	VISA 16 digit	30.3527864291459295	-97.6902282958157429
21427	2020-04-24 10:16:39	2020-04-24	Ara Bogisich	ara.bogisich@woohoo.com	Lincoln	Nebraska	503869343331521	21c955653aa1f9925b73fedc9ae238e2	Diners Club / Carte Blanche	40.7327192448563835	-96.6569199986916061
21428	2020-04-24 10:16:58	2020-04-24	Westley Rippin	westley.rippin@warmmail.com	Houston	Texas	4004085913570526	a3e30be06085e6a356c6bd5bd58a11ac	Diners Club / Carte Blanche	29.8700521417506053	-95.3226879472393591
21429	2020-04-24 10:23:42	2020-04-24	Celia Rippin	celia.rippin@geemail.com	Anaheim	California	55884791290199111	edf2f2b5515cd06c7fce970e03f50ca9	VISA 16 digit	33.9041242363695048	-117.727865515157944
21430	2020-04-24 10:35:03	2020-04-24	Alfonzo Baumbach	alfonzo.baumbach@warmmail.com	Clovis	California	3459157867348128	41325ccc5861f21c79982d8ab9f2466d	JCB 15 digit	36.7512119043495531	-119.610411700054627
21431	2020-04-24 10:45:35	2020-04-24	Martin Parisian PhD	martin.parisian.phd@geemail.com	Roseville	California	3029542051216044	72a6c1e211bad8eed16acf24a9e543af	Discover	38.8058150028865754	-121.242312590241056
21432	2020-04-24 10:50:17	2020-04-24	Leah Wolf	leah.wolf@geemail.com	Surprise	Arizona	3055893210816750	61920d5a84761c8213b9d990405a1d17	JCB 15 digit	33.707523138052224	-112.399964630580314
21433	2020-04-24 10:55:08	2020-04-24	Hermon Schulist MD	hermon.schulist.md@woohoo.com	Carlsbad	California	6011465654118122599	ca8d4be590fc35cf094a2d357d05ba98	JCB 15 digit	33.1090713689509784	-117.200725895191724
21434	2020-04-24 10:56:29	2020-04-24	Mr. Lula Stracke	mr.lula.stracke@geemail.com	Chattanooga	Tennessee	53077966815556667	7647964d06a46029c162990fb21f1775	Voyager	35.1194963334910568	-85.1975485853213854
21435	2020-04-24 10:57:01	2020-04-24	Dr. Orrie Ullrich	dr.orrie.ullrich@geemail.com	Tulsa	Oklahoma	3466940913903926	f159f45c366667675a70bd303faf6fb2	VISA 16 digit	36.0875811681520133	-95.879051777902248
21436	2020-04-24 11:15:03	2020-04-24	Breonna Buckridge	breonna.buckridge@geemail.com	Chicago	Illinois	501871701293228	c26f12cfaeaae32a0518c00c7e718006	Maestro	41.8980832145851139	-87.6593153823662448
21437	2020-04-24 11:15:21	2020-04-24	Jairo Lebsack-Rolfson	jairo.lebsack.rolfson@geemail.com	New York	New York	4061174396120197	f4924d87e1f9468bdaf6423b4a3d0643	JCB 15 digit	40.7101029960662117	-73.8427387382730842
21438	2020-04-24 11:16:52	2020-04-24	Leonard Kihn	leonard.kihn@geemail.com	Clarksville	Tennessee	210064516502764127	06c2e7ed767b27c229146f3004823e0c	Voyager	36.5315906637474939	-87.2783321522127835
21439	2020-04-24 11:18:38	2020-04-24	Mr. Emett Schneider IV	mr.emett.schneider.iv@geemail.com	Olathe	Kansas	55615875968194193	e3da314b467fa3f05d7e9e68af5befa2	Diners Club / Carte Blanche	38.8091005552683086	-94.7397331461943679
21440	2020-04-24 11:21:17	2020-04-24	Carlotta McGlynn	carlotta.mcglynn@warmmail.com	Knoxville	Tennessee	180009914115683214	153f2a9b38c6a4a89b8790421d7e3610	Voyager	35.8901141726475217	-83.8558211184788433
21441	2020-04-24 11:39:26	2020-04-24	Helma Bednar-Weimann	helma.bednar.weimann@geemail.com	Lancaster	California	675989690942621	7881e1f802b9895e66a9d73bec2d80da	Maestro	34.6298783233169516	-118.22190067223012
21442	2020-04-24 11:57:26	2020-04-24	Dr. Artie O'Reilly	dr.artie.o'reilly@geemail.com	San Francisco	California	3112095276301766210	2aebc81639025317f170dbfb1b3433f5	VISA 16 digit	37.779852367582258	-122.418297288320019
21443	2020-04-24 12:05:51	2020-04-24	Delphine Pfannerstill-Moore	delphine.pfannerstill.moore@geemail.com	New York	New York	3112623353676415524	5f657b346942ea594db2740bd4e2e56d	VISA 13 digit	40.6436688969135247	-73.9823775866895943
21444	2020-04-24 12:13:14	2020-04-24	Shaniya Rath	shaniya.rath@warmmail.com	Kansas City	Missouri	4948938684800	5b4b557db1160b42f518975c8f5ab3be	JCB 16 digit	39.176578576287632	-94.5133438279144542
21445	2020-04-24 12:14:57	2020-04-24	Dr. Cordero Lebsack PhD	dr.cordero.lebsack.phd@geemail.com	Irvine	California	3748696746882397	70404684099152fe0bdb2f708e5aa92b	JCB 15 digit	33.6348927789848346	-117.871178140212962
21446	2020-04-24 12:21:37	2020-04-24	Laurette Kulas-Howell	laurette.kulas.howell@geemail.com	Phoenix	Arizona	3057694593426862	19c8e247a4408db4f1e501b883cd8c0a	American Express	33.6378728445552326	-112.17017941716351
21447	2020-04-24 13:03:54	2020-04-24	Jerrell Wyman	jerrell.wyman@woohoo.com	Lubbock	Texas	869935632695178490	d59b1a64d32f78a1a8ab8532cd90f42d	VISA 13 digit	33.6090722837526386	-101.906852669120582
21448	2020-04-24 13:08:38	2020-04-24	Esta Daugherty	esta.daugherty@geemail.com	Berkeley	California	3753618262523850	f77641c1a4a6fe03acafa80e67703b7c	Mastercard	37.868390709293088	-122.259835065509606
21449	2020-04-24 13:11:41	2020-04-24	Scottie Feil	scottie.feil@geemail.com	Warren	Michigan	3096737875571653745	97f09858e746594b7bc75f0b5b689316	VISA 16 digit	42.5313310433175431	-83.0327630024869023
21450	2020-04-24 13:15:43	2020-04-24	Demarion Harber-Johns	demarion.harber.johns@geemail.com	New York	New York	3485279292466172	1273301cbc6e8f1320c8fa207a01c806	VISA 13 digit	40.5857486431244752	-73.8763904179807724
21451	2020-04-24 13:20:44	2020-04-24	Romeo Torphy	romeo.torphy@geemail.com	Shreveport	Louisiana	4907128298163075	b4b9245a6a624f2028be55979f571fe9	JCB 15 digit	32.4024471064336623	-93.8871035902973148
21452	2020-04-24 13:21:48	2020-04-24	Ellison Conroy-Bernier	ellison.conroy.bernier@woohoo.com	San Angelo	Texas	4672634435290773	d71e61b4724f7b42320428ad93e98660	Maestro	31.3846158628504703	-100.48310455597192
21453	2020-04-24 13:29:26	2020-04-24	Elbert Runte-Lind	elbert.runte.lind@geemail.com	Los Angeles	California	676113671343799	3b75fadfe9dc01d35e4a4e597d595def	JCB 16 digit	33.9831783275917161	-118.337399200395865
21454	2020-04-24 13:31:32	2020-04-24	Pennie Jast	pennie.jast@woohoo.com	San Antonio	Texas	6011565998358135525	05b9f86575bdbf5ad0cd4a9cc3e404b9	JCB 16 digit	29.4642561323545884	-98.5801414029043173
21455	2020-04-24 13:31:46	2020-04-24	Dani Fisher	dani.fisher@geemail.com	Berkeley	California	3030320435120417	97c615fe92dacc94ccd572790f6ef9eb	Discover	37.8876381876181441	-122.266046314302216
21456	2020-04-24 13:37:17	2020-04-24	Cordaro Rosenbaum	cordaro.rosenbaum@geemail.com	San Francisco	California	4665137638942660	fc41d0111e306e1a83d4c6f880b3d45d	Diners Club / Carte Blanche	37.8042592408039724	-122.427227744324611
21457	2020-04-24 13:38:02	2020-04-24	Caydence Towne-Bernier	caydence.towne.bernier@woohoo.com	Wichita	Kansas	4419199598097	8402965e733a930b47cfdf9cab39d35e	Mastercard	37.7196353749249127	-97.4441200172729793
21458	2020-04-24 13:41:42	2020-04-24	Mrs. Samara Dare PhD	mrs.samara.dare.phd@geemail.com	Austin	Texas	869959528880723127	fa593745278da6dc4eecc6448141c615	JCB 16 digit	30.3786829350177179	-97.8180453191284158
21459	2020-04-24 13:43:38	2020-04-24	Mrs. Gladis Thiel	mrs.gladis.thiel@woohoo.com	Chesapeake	Virginia	210020884964489689	44f9303c108ebd0d70fe6c98aec522fb	VISA 16 digit	36.6988766033440825	-76.368667488436401
21460	2020-04-24 13:45:42	2020-04-24	Florine Walker	florine.walker@woohoo.com	San Francisco	California	54748976151255674	e1b80f64c84e1d2e9a4c7c1dded5ee09	Mastercard	37.7579522771220937	-122.416408593396881
21461	2020-04-24 13:53:17	2020-04-24	Miss Lexus Murray	miss.lexus.murray@woohoo.com	Overland Park	Kansas	4099170441100412	daee31de5f1f9e078b9928f37934320d	American Express	38.8008852499406842	-94.7464453496545644
21462	2020-04-24 13:56:12	2020-04-24	Antonetta Barton	antonetta.barton@warmmail.com	Boston	Massachusetts	3027695468871884	9b74f9a2f930b72b746f6be6a564d9e6	JCB 15 digit	42.3998860202897347	-70.9448628219261792
21463	2020-04-24 13:56:59	2020-04-24	Dr. Paisley Dickens	dr.paisley.dickens@geemail.com	New York	New York	3431886730520116	c8e8b4b04b1a7b91e93ca134d45863a8	Diners Club / Carte Blanche	40.7337374165412029	-74.0196682366438239
21464	2020-04-24 13:59:23	2020-04-24	Darlyne Johnson	darlyne.johnson@geemail.com	Modesto	California	869918408418453846	b7a473b98cf1af60958032ab3e39063f	VISA 13 digit	37.7097733189351914	-121.019578301368284
21465	2020-04-24 14:04:04	2020-04-24	Pamela Stroman-Wiza	pamela.stroman.wiza@geemail.com	Tulsa	Oklahoma	4366016329254316	c964744ed5e6d005727a6a80fb358543	Discover	36.1401903852723478	-95.9189121507063476
21466	2020-04-24 14:06:25	2020-04-24	Broderick Walsh	broderick.walsh@geemail.com	New York	New York	6011891530974911545	3b69858f6d065bed8bc46fabfea01c29	Mastercard	40.5824040251076212	-73.8758533525641923
21467	2020-04-24 14:21:43	2020-04-24	Alexis Cole	alexis.cole@geemail.com	Columbus	Ohio	3032863013934129	8f397761c0acd4a3ba013137bb3baf5d	Discover	39.9253912259869281	-83.0354817227695179
21468	2020-04-24 14:32:23	2020-04-24	Dr. Erin Bayer DDS	dr.erin.bayer.dds@warmmail.com	Oceanside	California	3528493362808157471	84697c91737bd949eb9bfe1537233eae	JCB 16 digit	33.3190878195576374	-117.257262531443317
21469	2020-04-24 14:50:55	2020-04-24	Mrs. Charlie Johns	mrs.charlie.johns@geemail.com	Phoenix	Arizona	676329628514498	8e2959c34664532b1f4a24b217ad1a30	Discover	33.5650051805123724	-112.15260478276052
21470	2020-04-24 15:03:00	2020-04-24	Annabella Gerhold	annabella.gerhold@geemail.com	Mesa	Arizona	869959082228711030	7ffcdf2d754a7e2b49fbebaedd18107c	Discover	33.4720961940154424	-111.720117346185816
21471	2020-04-24 15:09:33	2020-04-24	Miss Kimberely Stroman	miss.kimberely.stroman@geemail.com	Oakland	California	4011743371822919	b476d99b2155dcb4505de8daa834572d	VISA 13 digit	37.8075880885059803	-122.296476000949511
21472	2020-04-24 15:18:38	2020-04-24	Vicy Kirlin	vicy.kirlin@geemail.com	San Francisco	California	3462077250933432	4406a798680586c85b82dc51e3fe0372	JCB 15 digit	37.775266913017127	-122.443714892404884
21473	2020-04-24 15:20:21	2020-04-24	Dr. Chip Harris	dr.chip.harris@geemail.com	Louisville	Kentucky	4371371170319475	53ead26e5108b2849147101c58da8909	JCB 15 digit	38.1427618242237685	-85.6047137716855957
21474	2020-04-24 15:23:30	2020-04-24	Dosia Rempel-Hirthe	dosia.rempel.hirthe@warmmail.com	Corona	California	180086354056496811	b94bcf158ec9a84a3741ebe8713bdddf	JCB 16 digit	33.9093560011014361	-117.500182438289741
21475	2020-04-24 15:27:14	2020-04-24	Alphonsus Cummings-Johns	alphonsus.cummings.johns@geemail.com	New York	New York	4241553864741589	69417321db9d0edbfa82afb68ae9a247	JCB 15 digit	40.6972088538799426	-73.9056443554244851
21476	2020-04-24 15:31:38	2020-04-24	Dr. Permelia Walter	dr.permelia.walter@woohoo.com	Denver	Colorado	3337335187022703467	653fe7541b73243cae34c5378ae4bcdd	VISA 16 digit	39.6988487993884789	-104.887600234873972
21477	2020-04-24 15:51:28	2020-04-24	Derick Kuhic PhD	derick.kuhic.phd@geemail.com	Waco	Texas	54600744747999941	ec7ab5c3faddcc10d39b1097603b4198	Diners Club / Carte Blanche	31.5220819553568958	-97.1566499331630808
21478	2020-04-24 15:51:29	2020-04-24	Raina Kassulke	raina.kassulke@geemail.com	Overland Park	Kansas	3096312492601994470	c5927b279207d41637408841bb1ad0ed	VISA 16 digit	38.879091440174733	-94.6954052120488114
21479	2020-04-24 15:52:42	2020-04-24	Mannie Larkin DDS	mannie.larkin.dds@geemail.com	Oakland	California	502048970345129	4c1715f26d413c4d5198af44d30610f9	JCB 16 digit	37.8296983706321441	-122.234964773526201
21480	2020-04-24 15:53:43	2020-04-24	Orval Hayes-Stanton	orval.hayes.stanton@geemail.com	Miami	Florida	6011951023692331342	72c9f03873b995f98e1cc061fbc67c89	JCB 15 digit	25.8423655266545715	-80.1788376894652828
21481	2020-04-24 16:23:38	2020-04-24	Anabella Considine	anabella.considine@geemail.com	San Francisco	California	3480304013707319	4292ddf700bb19202e10d2e5f769e321	Voyager	37.7792519518361587	-122.410948008284649
21482	2020-04-24 16:34:52	2020-04-24	Mr. Stanislaus Feil PhD	mr.stanislaus.feil.phd@geemail.com	Minneapolis	Minnesota	869936372742481790	55cc8d60555e9aaefec3ff32bed34028	JCB 15 digit	44.950297267836703	-93.2788572266038472
21483	2020-04-24 16:44:33	2020-04-24	Mr. Elmer Adams	mr.elmer.adams@warmmail.com	Oakland	California	3112334354541967517	9acdc0c4ebb4d901e01ea608663e61e6	Mastercard	37.8452272821023499	-122.233744277018033
21484	2020-04-24 16:53:51	2020-04-24	Tamekia Oberbrunner	tamekia.oberbrunner@warmmail.com	McKinney	Texas	869927241125841543	0ff05d51aff3d290ccabaefc9c8a65a0	American Express	33.237133842486891	-96.7622182012833747
21485	2020-04-24 17:02:39	2020-04-24	Obie Zemlak-Rath	obie.zemlak.rath@geemail.com	San Francisco	California	869997136418611105	2598a74114e4aae6cbf56e0ae32da4ee	Maestro	37.7774516382838357	-122.44794356558873
21486	2020-04-24 17:05:40	2020-04-24	Bernie Rolfson	bernie.rolfson@geemail.com	Lubbock	Texas	51046859933188679	59b4055ff8cb9e8f1267e9c707ebb383	Mastercard	33.5380977319594535	-101.801518660449247
21487	2020-04-24 17:25:11	2020-04-24	Jerald Satterfield-Oberbrunner	jerald.satterfield.oberbrunner@geemail.com	Jacksonville	Florida	3722845700836309	0ecc3220ebe8ae79e00b62920f0cba69	Voyager	30.3726797755394138	-81.7129969956897213
21488	2020-04-24 17:31:34	2020-04-24	Vernie Kunze	vernie.kunze@warmmail.com	Houston	Texas	180047551012273881	26bf89dce1b6699d3e28e3b8e6be521e	American Express	29.8510049820490195	-95.4651697817273401
21489	2020-04-24 17:32:19	2020-04-24	Erwin Murazik	erwin.murazik@geemail.com	Lancaster	California	561267227686820	073224203ce890f2a54c242b42eff687	JCB 16 digit	34.7772000156588916	-118.25728970421217
21490	2020-04-24 17:32:41	2020-04-24	Cecelia Jaskolski	cecelia.jaskolski@woohoo.com	Charlotte	North Carolina	53274833389638910	21d742abc94888872eb9a5a5b2bb2fce	Diners Club / Carte Blanche	35.1562314788132895	-80.7776588811017575
21491	2020-04-24 17:40:21	2020-04-24	Esperanza Reichel	esperanza.reichel@geemail.com	Fontana	California	3007795561451848	3750c3a798f432f1e07c58f89d677f11	VISA 16 digit	34.0542542256098244	-117.411312159830331
21492	2020-04-24 17:45:27	2020-04-24	Amasa Tremblay	amasa.tremblay@warmmail.com	El Cajon	California	3773945300000732	6ee1ad6c2db12c680e7099e8f6f2c205	JCB 16 digit	32.775870113680881	-117.0143176968392
21493	2020-04-24 17:49:40	2020-04-24	Derl Keeling	derl.keeling@geemail.com	New Orleans	Louisiana	51780944671378805	fea65983f5bd789c4acb5dd70d48c7a7	JCB 15 digit	30.0562876897878937	-89.9344216035474062
21494	2020-04-24 18:18:18	2020-04-24	Mr. Arnett Anderson DDS	mr.arnett.anderson.dds@geemail.com	Peoria	Arizona	180057426392066790	cc2baa86ec1d66a315d0ec4641c4e24c	Diners Club / Carte Blanche	33.8243687058601523	-112.308402988912547
21495	2020-04-24 18:29:02	2020-04-24	Garold Purdy	garold.purdy@geemail.com	Grand Rapids	Michigan	3026761745239088	eba77bed6d202ff004d8cd24128aa158	VISA 16 digit	42.8913934393588434	-85.7157323808543481
21496	2020-04-24 18:31:10	2020-04-24	Genesis Renner	genesis.renner@geemail.com	Garland	Texas	52705652398928016	aea6e1ccd6561adb6e934323cf494f77	American Express	32.9157300801251083	-96.6382687225632395
21497	2020-04-24 18:34:59	2020-04-24	Mrs. Paloma Muller DVM	mrs.paloma.muller.dvm@geemail.com	Chandler	Arizona	3158572179609812029	d9681988b8e012ba0d6deb7108f267d0	JCB 15 digit	33.2413127920214038	-111.850095275777946
21498	2020-04-24 18:35:04	2020-04-24	Jonatan Auer	jonatan.auer@warmmail.com	Meridian	Idaho	4601598842148989	8303304551c33c75f2a725ab5200325d	VISA 16 digit	43.5851625555667965	-116.384299504145602
21499	2020-04-24 18:37:53	2020-04-24	Karis Sporer	karis.sporer@warmmail.com	Irving	Texas	6011161037275876602	88b18966424ad2aee4e52b98683b5a9a	VISA 16 digit	32.8203918808091473	-97.0280488599371154
21500	2020-04-24 18:41:29	2020-04-24	Mrs. Alyce Koelpin	mrs.alyce.koelpin@warmmail.com	Dallas	Texas	4713867570978262	7da9dbdcc21d19fec08a8a8b7ef80ded	JCB 15 digit	32.7618726970434224	-96.7675219701565794
21501	2020-04-24 18:44:40	2020-04-24	Jordi Walter	jordi.walter@woohoo.com	Los Angeles	California	869953524888059735	b6a5efdba3265b52365711a4967aeff7	Mastercard	34.0255233285814498	-118.452815406256533
21502	2020-04-24 18:55:42	2020-04-24	Taja Cole PhD	taja.cole.phd@geemail.com	San Francisco	California	4765770976875180	2614d3628104b6e524073ac26ec95e46	VISA 13 digit	37.7771829882648262	-122.437666500233263
21503	2020-04-24 19:00:01	2020-04-24	Shelby Schiller	shelby.schiller@woohoo.com	San Francisco	California	3045627639130116	22c14ab798308bd5994c6b231dd79e81	JCB 16 digit	37.769850192837751	-122.448393176655443
21504	2020-04-24 19:01:31	2020-04-24	Dr. Olen Wintheiser	dr.olen.wintheiser@warmmail.com	San Francisco	California	3088241011715601239	e9f6b69db5de51b0447f7185f00b0048	Diners Club / Carte Blanche	37.7828697999628176	-122.41719683705972
21505	2020-04-24 19:09:03	2020-04-24	Marcos Herman	marcos.herman@geemail.com	Gresham	Oregon	3088145321217178041	9a2f8ff3443ddb50a359b202ea11002d	Voyager	45.4625287461981173	-122.434829871476069
21506	2020-04-24 19:27:28	2020-04-24	Kristen D'Amore DVM	kristen.d'amore.dvm@warmmail.com	Allentown	Pennsylvania	3158878050371246251	762b5a5c52fe8c70a028a54eec36edcf	Mastercard	40.6308860650531969	-75.5193369070548499
21507	2020-04-24 19:29:31	2020-04-24	Constantine Tremblay	constantine.tremblay@geemail.com	Chicago	Illinois	561247012954831	9684835f258daaa731ba360910d7e1c1	Diners Club / Carte Blanche	41.9012960758361999	-87.7658096329804494
21508	2020-04-24 19:34:24	2020-04-24	Vertie Pouros PhD	vertie.pouros.phd@woohoo.com	San Francisco	California	3158819069993439179	46531cb5f98027e317b1a87dc4bb70b1	American Express	37.7701838592014241	-122.425021255414379
21509	2020-04-24 19:36:59	2020-04-24	Ferne Leannon	ferne.leannon@geemail.com	San Francisco	California	869921304138551412	daba779188d80ab37a09b2e91814af63	Discover	37.7938682597414086	-122.408649259400249
21510	2020-04-24 19:47:09	2020-04-24	Miss Erykah Romaguera	miss.erykah.romaguera@geemail.com	Oakland	California	4396977518226	63006b8e0df85dc444857052db485520	Voyager	37.7882167608607134	-122.301824800888866
21511	2020-04-24 20:06:05	2020-04-24	Goldie Hoeger	goldie.hoeger@woohoo.com	Warren	Michigan	3337887968100318050	bd603001b2c7efab609327a0703297c9	American Express	42.4587650871366264	-83.0399759742431343
21512	2020-04-24 20:14:56	2020-04-24	Ms. Lashawn Mosciski	ms.lashawn.mosciski@geemail.com	Portland	Oregon	3414045949381403	41e7bc78f87a9fdb46896f68b0d01e52	VISA 16 digit	45.6180399550944529	-122.553707634937027
21513	2020-04-24 20:30:59	2020-04-24	Mr. Frank Terry DDS	mr.frank.terry.dds@geemail.com	San Francisco	California	55903033967413039	b88ba104d8bdb3bca5716dcb22c9b11a	Mastercard	37.7713341679934089	-122.41439896515557
21514	2020-04-24 20:31:10	2020-04-24	Waino Schamberger-Stoltenberg	waino.schamberger.stoltenberg@geemail.com	New York	New York	501802560438125	2100aca5c42400889a1bc1b644f2ac6e	Mastercard	40.7197868892680859	-73.9120495398890256
21515	2020-04-24 20:49:13	2020-04-24	Alford Runolfsdottir-Heathcote	alford.runolfsdottir.heathcote@geemail.com	San Francisco	California	4547637854532354	bcd9382ab8c956e8ff53897a39ca288a	American Express	37.7532349888249854	-122.454685940898827
21516	2020-04-24 20:55:28	2020-04-24	Tyesha Ebert	tyesha.ebert@warmmail.com	New York	New York	3059737893358588	0b56d90a8fd0180d672a2f1383be1f8d	VISA 16 digit	40.7556260075643664	-73.9293379861757103
21517	2020-04-24 21:21:25	2020-04-24	Forrest Cummings	forrest.cummings@geemail.com	Oklahoma City	Oklahoma	4728783695283491	75606ff5889ed54c88d4d91317b07306	VISA 16 digit	35.3942215102169655	-97.5100958171661887
21518	2020-04-24 21:49:15	2020-04-24	Fanny Reichert	fanny.reichert@geemail.com	Anchorage	Alaska	6011633900817104850	97a188684dd9fc73317f1a59b39f19c8	VISA 16 digit	61.1013708403084479	-149.247390765429657
21519	2020-04-24 21:53:57	2020-04-24	Mrs. Drew Wolf PhD	mrs.drew.wolf.phd@geemail.com	Oakland	California	4251660540610034	75f753dd208825d00f883073661b771d	VISA 16 digit	37.815849183932869	-122.27777680543322
21520	2020-04-24 21:59:48	2020-04-24	Gustavus Bayer	gustavus.bayer@warmmail.com	Charlotte	North Carolina	869974681194032437	08f2ecec7ebfc6331f1187997c3d8c54	VISA 16 digit	35.1688588128678461	-80.807568500092259
21521	2020-04-24 22:05:03	2020-04-24	Regis Skiles	regis.skiles@geemail.com	Des Moines	Iowa	3484303856892176	07bf938f06c25e64d796b57e441f2018	Diners Club / Carte Blanche	41.561753568632902	-93.5519330062948171
21522	2020-04-24 22:08:13	2020-04-24	Inger Sipes MD	inger.sipes.md@geemail.com	Salt Lake City	Utah	4743970385919507	6b02068f92e3417a6f9d8b6fc79e1982	American Express	40.7813975877273833	-111.950070808822289
21523	2020-04-24 22:33:40	2020-04-24	Carrie Murphy	carrie.murphy@geemail.com	Pasadena	Texas	55722540429420328	284a2c44578bd43603ddacc3e0aaf987	Mastercard	29.6585453388620159	-95.2367165816429946
21524	2020-04-24 22:38:26	2020-04-24	Dr. Kash Bergstrom	dr.kash.bergstrom@geemail.com	Virginia Beach	Virginia	3497297054133851	3670832d3ecd1b3b99e0c2bec67b6544	Mastercard	36.7114797507598993	-76.0219130085453401
21525	2020-04-24 22:45:01	2020-04-24	Antionette Walsh	antionette.walsh@warmmail.com	Centennial	Colorado	3738826943027189	962e5cf75153c061018aefceb9816861	Maestro	39.6616798752959809	-104.962588140683621
21526	2020-04-24 22:56:09	2020-04-24	Jacquez Dickens	jacquez.dickens@warmmail.com	Dallas	Texas	3158963455027475608	2eac245996509e41d4357a2f912e16d0	Mastercard	32.7878628333371154	-96.7718185278549754
21527	2020-04-24 22:59:32	2020-04-24	Elizebeth Stroman	elizebeth.stroman@geemail.com	Nashville	Tennessee	869952400423338036	14dd079cfa50b8c64ec2b5448e344b8c	JCB 16 digit	36.1673312529113105	-86.7614475982636151
21528	2020-04-24 23:06:27	2020-04-24	Uriel Runte	uriel.runte@woohoo.com	Lexington	Kentucky	3792446340855703	11d931cfc5da89d007e201644e2db24c	Maestro	38.0727635080803211	-84.5150538599017978
21529	2020-04-24 23:06:57	2020-04-24	Mrs. Christal Effertz	mrs.christal.effertz@geemail.com	Denton	Texas	3422891288936004	73d3bef438bfc1a185ee0d508f2a4950	JCB 16 digit	33.1652044042743768	-97.1623733450319662
21530	2020-04-24 23:42:25	2020-04-24	Mrs. Marybeth Zieme MD	mrs.marybeth.zieme.md@geemail.com	Seattle	Washington	3112553307082359290	ae9421905ea2d3d0134c991a9aa60761	JCB 16 digit	47.6352994013503164	-122.35513633288592
21531	2020-04-25 00:15:27	2020-04-25	Cailyn Cummings DDS	cailyn.cummings.dds@geemail.com	Frisco	Texas	3784723148759505	b616cda3bec8f817566636f780c9edca	VISA 13 digit	33.1580822560932518	-96.8063649646215083
21532	2020-04-25 00:19:39	2020-04-25	Gael Bosco	gael.bosco@woohoo.com	Clovis	California	3158922572632107200	e3f7f73ffe9ee3232ad1baffb0a5bca8	Mastercard	36.9124851368710409	-119.771800348588826
21533	2020-04-25 00:21:43	2020-04-25	Ms. Ivette Wisozk DDS	ms.ivette.wisozk.dds@woohoo.com	Los Angeles	California	4550301543801	86a309671ce8cae0620fec5e87b0df9e	Diners Club / Carte Blanche	33.9745304992753958	-118.43377588312066
21534	2020-04-25 00:21:54	2020-04-25	Angel Huels	angel.huels@geemail.com	Louisville	Kentucky	4156857399145668	44b29fe0f9f5b62ed59843f0a2ea3c04	Maestro	38.1228736504815515	-85.6434804151836886
21535	2020-04-25 00:26:15	2020-04-25	Dr. Holli Mayert PhD	dr.holli.mayert.phd@geemail.com	Los Angeles	California	3158734458026520877	b5876ca3f91bd582ea90a7641651e252	Voyager	33.9317997226357448	-118.470727960904313
21536	2020-04-25 00:33:05	2020-04-25	Braeden Schamberger PhD	braeden.schamberger.phd@geemail.com	Philadelphia	Pennsylvania	3028097776597906	5f95ec57cfb7cce3f5237fc5bdf654c8	JCB 15 digit	39.9881056574132288	-75.2039990254111643
21537	2020-04-25 01:03:06	2020-04-25	Theresia Yost	theresia.yost@geemail.com	Boston	Massachusetts	52650501472087253	2b72a31f724b664857a3e22174635f92	Mastercard	42.2983441928569235	-71.0001168959725675
21538	2020-04-25 01:09:14	2020-04-25	Norita Pouros	norita.pouros@woohoo.com	Chandler	Arizona	6011275562226362223	80418cd41ccdd80f10f02430176e803f	JCB 16 digit	33.2806496720384786	-111.836414146970583
21539	2020-04-25 01:13:38	2020-04-25	Rolando Marvin	rolando.marvin@woohoo.com	Chicago	Illinois	4429987547651	859dceeadb262d30f4d3057d35a86df4	American Express	41.9319334369920185	-87.7808986586548343
21540	2020-04-25 01:17:29	2020-04-25	Latoria Gislason	latoria.gislason@geemail.com	Gilbert	Arizona	52656909823336200	8e48005d15cd3759468f9b99db9a9181	Voyager	33.3419766852047275	-111.750378573373325
21541	2020-04-25 01:31:45	2020-04-25	Dr. Ayden Durgan	dr.ayden.durgan@geemail.com	Thornton	Colorado	3013105909621199	ab587211b7eed8cfafde4793cefaf2b0	Voyager	39.8887556257989289	-104.99065101390444
21542	2020-04-25 02:26:02	2020-04-25	Miss Helyn Rohan MD	miss.helyn.rohan.md@geemail.com	Toledo	Ohio	3088618099968993275	b66b6c0442cedfd73d9cef00f0b0045a	VISA 13 digit	41.7041157795287631	-83.5164988809131188
21543	2020-04-25 02:32:03	2020-04-25	Dr. Fuller Mosciski	dr.fuller.mosciski@geemail.com	Henderson	Nevada	4261276897442	267eb4360a89b696b69ab5c389e03418	Mastercard	36.0107415680706495	-115.114822961126279
21544	2020-04-25 02:50:57	2020-04-25	Ms. Odalys Leffler DVM	ms.odalys.leffler.dvm@woohoo.com	Fort Worth	Texas	180082869088117774	5316c601d715f4de5f42519de1db6aa6	VISA 13 digit	32.8546011854950351	-97.2910807706236795
21545	2020-04-25 03:00:56	2020-04-25	Deward Feil-Feeney	deward.feil.feeney@warmmail.com	Corona	California	4051911404559	0ede02c40ca28448989ebe4fdab92aa6	VISA 13 digit	33.8854776049386714	-117.501926424607632
21546	2020-04-25 03:04:29	2020-04-25	Devaughn Hyatt	devaughn.hyatt@geemail.com	Torrance	California	3337669387646295306	7cb060bf8eea70057327529b9c8d239d	JCB 16 digit	33.8998823904804922	-118.320625869895878
21547	2020-04-25 03:26:02	2020-04-25	Kathie Nitzsche	kathie.nitzsche@geemail.com	Gilbert	Arizona	4625895663050951	c99223d1e70e68f0318d80860e0fce36	VISA 13 digit	33.3843875709801878	-111.68332971857339
21548	2020-04-25 03:35:31	2020-04-25	Gail Jast	gail.jast@geemail.com	Long Beach	California	3754028805104904	8e47be4bcfcea0b0119c7899aa2f5313	Maestro	33.7440405759781541	-118.129937699127197
21549	2020-04-25 03:42:53	2020-04-25	Alvira Botsford	alvira.botsford@geemail.com	Phoenix	Arizona	6011517524341942683	928d22eb4b5940a07237196706939168	JCB 16 digit	33.5545157986626066	-112.135977376059074
21550	2020-04-25 03:43:38	2020-04-25	Estella Schaefer	estella.schaefer@woohoo.com	Colorado Springs	Colorado	3096083726910762822	f63c159a7bb220816f7616b226eaf2b2	Maestro	38.9316066523596618	-104.770484780489284
21551	2020-04-25 04:08:12	2020-04-25	Joselyn Feeney DDS	joselyn.feeney.dds@geemail.com	Oakland	California	3045225627191719	be88eae4055ebdcdaaaf374b30fbe178	Maestro	37.8391387063587601	-122.300084519752147
21552	2020-04-25 04:10:24	2020-04-25	Jeremey Nienow	jeremey.nienow@geemail.com	San Antonio	Texas	869940980064941599	818c900231fd926f6ba3090ab52ef6b5	Mastercard	29.4718233118835826	-98.5399660570382991
21553	2020-04-25 04:14:25	2020-04-25	Miss Adelyn McGlynn DDS	miss.adelyn.mcglynn.dds@geemail.com	Berkeley	California	4440897920332894	739f3d74c789aa931152fae7a2de69f6	VISA 16 digit	37.8591472543199714	-122.267120613526743
21554	2020-04-25 04:20:19	2020-04-25	Dr. Julisa Jerde	dr.julisa.jerde@geemail.com	Dallas	Texas	3715241732096089	e9bce536a03f3e269db9d6cd8b8f5ea8	VISA 16 digit	32.7162382053483327	-96.7409937215931706
21555	2020-04-25 04:41:41	2020-04-25	Dr. Vinton Bauch	dr.vinton.bauch@geemail.com	New York	New York	55002411583565293	e823277155ee45cdf5d35e399d575c48	Maestro	40.7069608376584924	-74.0227480887796645
21556	2020-04-25 05:09:59	2020-04-25	Elizah Hamill	elizah.hamill@geemail.com	Berkeley	California	4379660483985465	44944a437216d31d746efb0bcbe0c0fc	Mastercard	37.9149000509497611	-122.279353483634083
21557	2020-04-25 05:18:09	2020-04-25	Selmer Johns	selmer.johns@geemail.com	Phoenix	Arizona	869982616796934713	d797f2a04b5371af140e7a2c1feb7550	VISA 16 digit	33.4805269933238634	-112.141236007765315
21558	2020-04-25 05:20:58	2020-04-25	Vernita Feeney-Kemmer	vernita.feeney.kemmer@geemail.com	San Francisco	California	3088800233157574277	f14e9e8264f93d28e07e1d15fa9303d5	VISA 13 digit	37.7720787811114391	-122.422283125801698
21559	2020-04-25 05:24:55	2020-04-25	Mr. Harvie Reichert	mr.harvie.reichert@geemail.com	Inglewood	California	6011324714653586698	7daacf4116cabbeea8317f87b430a6a0	Diners Club / Carte Blanche	33.8719148146700135	-118.270748390539737
21560	2020-04-25 05:25:17	2020-04-25	Tate Hermiston	tate.hermiston@warmmail.com	Fort Worth	Texas	3022786769402498	e54f895213e63307f463d90aab9290d2	VISA 16 digit	32.8561946733444969	-97.2994599613647893
21561	2020-04-25 05:26:17	2020-04-25	Brittanie Schumm-Wehner	brittanie.schumm.wehner@geemail.com	Garden Grove	California	4755387081481	5ef7231d4355a9c7b69944542238029b	VISA 13 digit	33.7338502753350866	-118.017175170548256
21562	2020-04-25 05:33:36	2020-04-25	Dr. Hall Harris V	dr.hall.harris.v@geemail.com	Boston	Massachusetts	52865467382294028	b14e1d27eeab5b33191fca96bfa53a22	Voyager	42.2987144708801068	-71.1090687108643351
21563	2020-04-25 05:43:59	2020-04-25	Hedwig Welch	hedwig.welch@geemail.com	New York	New York	210092507931240009	e5ae452439fba7165dad53f980ad647d	JCB 15 digit	40.7544515311010187	-74.0324108257319722
21564	2020-04-25 05:45:39	2020-04-25	Perla Jast	perla.jast@warmmail.com	Laredo	Texas	3041016881040930	8a812b5c0770cab57ff1650d50a3dff1	Diners Club / Carte Blanche	27.6476725218534476	-99.5194804097533137
21565	2020-04-25 05:47:19	2020-04-25	Myah Ortiz	myah.ortiz@geemail.com	San Francisco	California	3018510822151585	1616c8ca7cd4180a46a9fc061974993e	VISA 16 digit	37.7681540115347048	-122.415196974677613
21566	2020-04-25 05:50:25	2020-04-25	Mr. Eliezer Kozey	mr.eliezer.kozey@woohoo.com	New York	New York	6011156548702368978	fabd5cf5bec2ea93bbfd3a16f4880987	Mastercard	40.7396111387982955	-73.9925880842737769
21567	2020-04-25 05:59:34	2020-04-25	Stacey Hickle	stacey.hickle@warmmail.com	West Valley City	Utah	676213243208769	eb2d523a4d93178f2006d51b50c1afe0	Diners Club / Carte Blanche	40.6690069991853065	-111.937902747954425
21568	2020-04-25 06:08:45	2020-04-25	Genaro Kris	genaro.kris@warmmail.com	Houston	Texas	3783908887935181	2b428a340de8d1d763fa3c23f0801c3e	VISA 16 digit	29.8673528979610658	-95.3487761342912989
21569	2020-04-25 06:09:07	2020-04-25	Gianna Sipes	gianna.sipes@geemail.com	Oakland	California	503897877328506	20aef5747dca3e281a9ae8a6e01ca25c	JCB 16 digit	37.8131450607952289	-122.272106302974535
21570	2020-04-25 06:13:17	2020-04-25	Dr. Gearld Emard DDS	dr.gearld.emard.dds@geemail.com	Pembroke Pines	Florida	55365459028237789	2f71722e86a3ef0d79a870a79102d793	Voyager	26.0411843188144267	-80.399506165636339
21571	2020-04-25 06:29:11	2020-04-25	Oral Eichmann	oral.eichmann@geemail.com	Glendale	California	52368799490305771	5f701deac3a3d7dd119300b124bf584c	VISA 16 digit	34.2579782809350633	-118.282792712039509
21572	2020-04-25 06:38:17	2020-04-25	Latonia Klein	latonia.klein@woohoo.com	Dallas	Texas	4153559682514179	a415d42d4789de0dbf4c9fbd48132039	JCB 15 digit	32.8130984006721533	-96.7274920137096075
21573	2020-04-25 06:38:38	2020-04-25	Ms. Arline Hansen DVM	ms.arline.hansen.dvm@woohoo.com	Dallas	Texas	4672937038738936	79467634f12ca37e8fcf0b0f46f04d29	VISA 16 digit	32.7008467508751934	-96.694318867610761
21574	2020-04-25 06:56:02	2020-04-25	Mr. Freeman Considine	mr.freeman.considine@geemail.com	Los Angeles	California	4489649773471143	c2b30d54684ea91cc416aa5ce6fe1c91	JCB 16 digit	33.9571661821898019	-118.464536137133081
21575	2020-04-25 07:17:09	2020-04-25	Ceylon Williamson V	ceylon.williamson.v@geemail.com	San Francisco	California	210037129668172434	1a76212f6d6823567bf1e8da469eac67	JCB 16 digit	37.737617535018515	-122.435086362574751
21576	2020-04-25 07:19:08	2020-04-25	Mart Dickens IV	mart.dickens.iv@geemail.com	Fort Worth	Texas	4766058689012427	459fe7f480ba8f634a270bbc1aa34e81	Maestro	32.6909915671274049	-97.4455946001511109
21577	2020-04-25 07:24:14	2020-04-25	Verona Armstrong	verona.armstrong@geemail.com	Chicago	Illinois	3096771508781011480	10b28191f89ec45d0ed574b68c6c1d4c	Maestro	41.9285899326041331	-87.6500916177436693
21578	2020-04-25 07:26:52	2020-04-25	Dr. Norita Boyle PhD	dr.norita.boyle.phd@warmmail.com	Charlotte	North Carolina	6011319289029393910	af40c9d8001da19e5d0e3ba49c8393cc	VISA 16 digit	35.1394714633721819	-80.8779572096597406
21579	2020-04-25 07:28:23	2020-04-25	Bird Kerluke	bird.kerluke@geemail.com	Los Angeles	California	4538280756574892	9e2b97eb36e6390278f5abc823423d89	VISA 13 digit	34.1110894489433605	-118.478581075229869
21580	2020-04-25 07:41:01	2020-04-25	Cappie Will	cappie.will@geemail.com	New York	New York	4144817073799193	f4e34f1f04b0e870a0eaa76b41270c46	VISA 13 digit	40.7409558724835534	-73.9276507716055988
21581	2020-04-25 07:54:00	2020-04-25	Delores Ryan	delores.ryan@geemail.com	San Antonio	Texas	4525644314444325	d9647eea7f24300fe15de7b34b9f5ce7	Maestro	29.5692327496200811	-98.5149082864005123
21582	2020-04-25 08:04:56	2020-04-25	Bernardine Emard	bernardine.emard@geemail.com	Berkeley	California	3528315594882664230	c8ab33b2116a9908add8cec72d9709af	VISA 16 digit	37.8512413652926369	-122.258776934748795
21583	2020-04-25 08:05:17	2020-04-25	Elta Torp-Berge	elta.torp.berge@geemail.com	Lexington	Kentucky	4458119700129971	035efe05267aa0e1f7d9c9322dc889e6	Maestro	38.1122045867487813	-84.4743354433581146
21584	2020-04-25 08:33:11	2020-04-25	Xiomara Cassin	xiomara.cassin@woohoo.com	Dallas	Texas	6011826731200660589	40b75d157e0300238557ece2ae75216b	American Express	32.8525688994482152	-96.805346616586661
21585	2020-04-25 08:34:13	2020-04-25	Maryam Eichmann	maryam.eichmann@geemail.com	Des Moines	Iowa	3112456235228478971	2e328a06a1b201e5d382630bfadda9c0	JCB 15 digit	41.626925329093261	-93.682572969379649
21586	2020-04-25 08:36:01	2020-04-25	Elida Reichel	elida.reichel@geemail.com	New York	New York	4295935469360714	896c32975f50876a65dfa73b491ca22e	Diners Club / Carte Blanche	40.6888685469739144	-73.8504013282142608
21587	2020-04-25 08:40:03	2020-04-25	Anibal Wehner	anibal.wehner@geemail.com	Fargo	North Dakota	3158168727694620374	e0b2b6833653332f6b52cb5cca0bd3a7	Diners Club / Carte Blanche	46.8953085609942661	-96.8502243991903953
21588	2020-04-25 08:41:21	2020-04-25	Dr. Zayne Schmeler	dr.zayne.schmeler@geemail.com	Miramar	Florida	639051897331735	d5b444df804b679a3a11baac728ba5d4	JCB 15 digit	25.932315633350985	-80.3686333185520141
21589	2020-04-25 08:55:51	2020-04-25	Jacoby Schmitt Jr.	jacoby.schmitt.jr.@warmmail.com	Norwalk	California	630487121815135	d336d7031851606c3bf6131e3d395a19	VISA 13 digit	33.9577719186082518	-118.068235347796232
21590	2020-04-25 09:02:06	2020-04-25	Dr. Mell Stehr	dr.mell.stehr@woohoo.com	Oxnard	California	4327540008663131	6db0214bcdfd83b5dd8d09b07875b630	VISA 16 digit	34.226318540140241	-119.135507689128076
21591	2020-04-25 09:10:07	2020-04-25	Mr. Arsenio Homenick	mr.arsenio.homenick@geemail.com	Phoenix	Arizona	675978673563124	e05dd1870374dc2418ff73bf57ec4104	JCB 15 digit	33.5676097438137973	-112.145331845658276
21592	2020-04-25 09:19:38	2020-04-25	Gerard O'Reilly	gerard.o'reilly@geemail.com	San Jose	California	6011379634391503983	9da4bae859352f52671f359381a5685c	American Express	37.2921291061032605	-121.742823766426739
21593	2020-04-25 09:20:35	2020-04-25	Mr. Joe Turcotte V	mr.joe.turcotte.v@woohoo.com	Oakland	California	3112787475802181076	2b60f480d0e80aea716b9b21566dcbd1	JCB 15 digit	37.7910052795474343	-122.269149930078385
21594	2020-04-25 09:20:42	2020-04-25	Mr. Gideon Jacobi	mr.gideon.jacobi@geemail.com	Evansville	Indiana	3337595001885145135	148012fd337d89a4bf4cedb61b2c08ab	VISA 13 digit	38.0399278251126347	-87.5076660123586691
21595	2020-04-25 09:50:09	2020-04-25	Oswald Hackett	oswald.hackett@woohoo.com	San Francisco	California	3088481921445850048	34cafb62d45f86c2a76e95170145c6f2	VISA 16 digit	37.7582539175523877	-122.444337851123208
21596	2020-04-25 10:02:43	2020-04-25	Kellen Romaguera	kellen.romaguera@warmmail.com	San Francisco	California	55441254912249158	1f2ffdcc4d47ac5517218baa830030bd	Mastercard	37.7794693725609037	-122.422339977401691
21597	2020-04-25 10:12:02	2020-04-25	Latarsha Hansen	latarsha.hansen@geemail.com	Billings	Montana	4321191733991300	680218867f85f6805edbad32df5fdc5c	VISA 16 digit	45.7899383057598044	-108.483921470509458
21598	2020-04-25 10:31:35	2020-04-25	Mr. Werner Wisoky	mr.werner.wisoky@woohoo.com	San Francisco	California	6011599204257268156	68a46deb49f5ad2f77ea77223581a712	Voyager	37.8010451067926141	-122.430009365101654
21599	2020-04-25 10:34:47	2020-04-25	Bethel Bruen	bethel.bruen@geemail.com	San Francisco	California	3435135958339346	8466d793085200c703a079c6b5c4d44c	JCB 16 digit	37.7549959685268064	-122.422118417550266
21600	2020-04-25 10:43:55	2020-04-25	Sanders Lindgren	sanders.lindgren@geemail.com	San Francisco	California	6011580783027674612	c1a420376e077cfd8f73cdf095636ff5	VISA 13 digit	37.7728865635548345	-122.409423402149628
21601	2020-04-25 10:48:41	2020-04-25	Dr. Teagan Smith	dr.teagan.smith@geemail.com	Berkeley	California	210080690283782713	1de93ff213f7b014295b62152dd84860	VISA 16 digit	37.8535094774004222	-122.250097361295943
21602	2020-04-25 10:58:59	2020-04-25	Anitra Adams DVM	anitra.adams.dvm@geemail.com	Aurora	Illinois	53225059141469952	8449a7ea9981743b375b8870ec89517c	JCB 16 digit	41.8493654780313378	-88.3515428799599363
21603	2020-04-25 11:02:40	2020-04-25	Sing Nikolaus	sing.nikolaus@geemail.com	Austin	Texas	210085498147937506	b47fdf37079c82bf78bc994b731c2dfe	VISA 16 digit	30.3301189609464252	-97.7155468558665348
21604	2020-04-25 11:13:32	2020-04-25	Mr. Lance Mann	mr.lance.mann@geemail.com	Oakland	California	55650072072720404	67cffb78ddbba4d54609f3ab07f59ef9	Mastercard	37.8401893623196699	-122.259313974833105
21605	2020-04-25 11:15:00	2020-04-25	Shaniqua Denesik PhD	shaniqua.denesik.phd@woohoo.com	Kansas City	Missouri	180032390968773629	5d4214ab3e1492a53317415b4ced5c73	VISA 13 digit	39.1256249069072339	-94.46400535444171
21606	2020-04-25 11:15:30	2020-04-25	Mrs. Machelle Rolfson PhD	mrs.machelle.rolfson.phd@geemail.com	San Francisco	California	4626292389871762	4d00c171ced8db02a7014bfbbd4b9751	Maestro	37.760717381261891	-122.46671128084067
21607	2020-04-25 11:29:40	2020-04-25	Mrs. Alleen Nikolaus	mrs.alleen.nikolaus@warmmail.com	San Francisco	California	6011732577961604651	060e755dbfd7b635e5554336460c3a2c	JCB 16 digit	37.7778514770591798	-122.408772637811268
21608	2020-04-25 11:33:25	2020-04-25	Weldon Hackett-Kuvalis	weldon.hackett.kuvalis@woohoo.com	Hayward	California	4952138538023900	d3e10b703a3d0e6b836db0b0c33e6a3b	Mastercard	37.6023512383446104	-122.197258800712973
21609	2020-04-25 11:44:15	2020-04-25	Elida Wisozk	elida.wisozk@geemail.com	West Jordan	Utah	6011382027178748852	923bd526744bb27f5a476d8d8c902c38	Voyager	40.5504810002889542	-112.088088562487812
21610	2020-04-25 11:48:31	2020-04-25	Mrs. Rylan Pouros MD	mrs.rylan.pouros.md@geemail.com	Green Bay	Wisconsin	4672997605979057	d33f6ee8c529c3cf15aaa1e50de77575	JCB 15 digit	44.4473923744697075	-88.00592388457693
21611	2020-04-25 11:57:47	2020-04-25	Derik Medhurst	derik.medhurst@warmmail.com	Fort Lauderdale	Florida	6011690506985715995	abe35ce299149685c69c88d31ea34957	VISA 13 digit	26.0451301476441337	-80.1868424267794921
21612	2020-04-25 12:14:41	2020-04-25	Dallas Rippin	dallas.rippin@geemail.com	Oakland	California	4264585456317834	c63bdaf94268e283d876a0ea3cf2b03e	American Express	37.7624081612281088	-122.293251520808809
21613	2020-04-25 12:21:43	2020-04-25	Les Steuber	les.steuber@geemail.com	Long Beach	California	630470119407719	d3f05bfe31b686f820a772702c4941de	American Express	33.8728069349013268	-118.210901109145212
21614	2020-04-25 12:25:20	2020-04-25	Mr. Joeseph Auer	mr.joeseph.auer@geemail.com	Yonkers	New York	4609911976094279	ed950abb1e0b7af460db47c91537100d	VISA 16 digit	40.9940134718284028	-73.8469174381230005
21615	2020-04-25 12:39:29	2020-04-25	Fielding D'Amore	fielding.d'amore@woohoo.com	Houston	Texas	869924368071549433	8c91f91b5ed1e7295d7e835b5c46687b	Discover	29.8605249978214502	-95.2929064567681365
21616	2020-04-25 12:39:56	2020-04-25	Mr. Vollie Rempel I	mr.vollie.rempel.i@warmmail.com	Phoenix	Arizona	3158894495509837622	5f0c8c38ee9212d9a563e7423deca007	Diners Club / Carte Blanche	33.5193428071148745	-112.104214457229162
21617	2020-04-25 12:42:43	2020-04-25	Mrs. Tayla Will	mrs.tayla.will@geemail.com	San Francisco	California	4475464605140	a7dbc1cfbff5f6991ebed39f5bd5ec53	JCB 16 digit	37.7720158104417223	-122.412899925679724
21618	2020-04-25 12:54:29	2020-04-25	Lonny Considine	lonny.considine@geemail.com	San Francisco	California	4139683805106140	089f75124265e0eaea966f1f79ca243f	Mastercard	37.7619703949465872	-122.442332491129989
21619	2020-04-25 13:02:36	2020-04-25	Mr. Lena Murray DVM	mr.lena.murray.dvm@geemail.com	New York	New York	3051395083353675	7d237f928aa613423fdd361aab0c103f	VISA 16 digit	40.6273282019644952	-73.9700448801171007
21620	2020-04-25 13:06:59	2020-04-25	Guilford Durgan	guilford.durgan@woohoo.com	Minneapolis	Minnesota	180000062817672165	171cbf220ed56ab9943cf8d66287258d	Maestro	45.0476438606709237	-93.3653182521734379
21621	2020-04-25 13:08:39	2020-04-25	Elease Walker	elease.walker@warmmail.com	Murfreesboro	Tennessee	6011949854269276543	317d8781d6c7298bdbaa3a4858f15801	JCB 15 digit	35.8486483774732818	-86.5148886964507398
21622	2020-04-25 13:09:32	2020-04-25	Bert Douglas-Dietrich	bert.douglas.dietrich@woohoo.com	New York	New York	3425034311279590	61d8439cb533eced81f955b3ae39b54c	JCB 15 digit	40.6607264418844139	-73.9604764202039604
21623	2020-04-25 13:14:50	2020-04-25	Christop Luettgen MD	christop.luettgen.md@geemail.com	Lafayette	Louisiana	4628855152656	6688e042035682593fc612a9e1fbbda1	Discover	30.2597390968330195	-92.0558566162213623
21624	2020-04-25 13:18:07	2020-04-25	Sheilah Windler PhD	sheilah.windler.phd@geemail.com	Springfield	Illinois	3096328468251202846	89072ef5747d42a2492f8d5464b9049d	American Express	39.7240368125647336	-89.702416504081711
21625	2020-04-25 13:21:40	2020-04-25	Lamar Rath-Kuphal	lamar.rath.kuphal@warmmail.com	San Francisco	California	6011551943144738162	81e9d2aec87f390edb90ac82428ca91e	Discover	37.7387061866021156	-122.460449126678569
21626	2020-04-25 13:25:47	2020-04-25	Mr. Demond Effertz DVM	mr.demond.effertz.dvm@geemail.com	Miami	Florida	3452640042469379	ad22a8fca3a3d33fbbd2c757d1bf1d7d	JCB 16 digit	25.7480595484513799	-80.1844511857129731
21627	2020-04-25 13:26:40	2020-04-25	Norbert Hane	norbert.hane@geemail.com	Jacksonville	Florida	4720918671184	e473b82fa64f883538669357481e5ed4	Mastercard	30.3965163829322904	-81.7292880522165461
21628	2020-04-25 13:29:17	2020-04-25	Leisa O'Connell	leisa.o'connell@geemail.com	Philadelphia	Pennsylvania	4753869304760	32b17916314c942a7913287ae85bc722	VISA 13 digit	39.9351689770311111	-75.1989790028326297
21629	2020-04-25 13:34:04	2020-04-25	Antony Mills	antony.mills@geemail.com	Chesapeake	Virginia	4189700091604668	a424a7dc82b28b808c819d06df17f41f	JCB 15 digit	36.6061719009425488	-76.2488731828827468
21630	2020-04-25 13:40:13	2020-04-25	Jadyn Green PhD	jadyn.green.phd@geemail.com	Eugene	Oregon	4119668053398	d758857dc092b25e55af670e9c117668	Mastercard	44.0206170031528927	-123.205771872353566
21631	2020-04-25 13:43:51	2020-04-25	Miss Angie Wolf	miss.angie.wolf@geemail.com	Washington	District of Columbia	3026722506034456	259be16a2b98f52851081fbcf0421540	VISA 16 digit	38.8339222044948471	-77.0573604003738666
21632	2020-04-25 13:49:20	2020-04-25	Mr. Shedrick Schmitt	mr.shedrick.schmitt@geemail.com	Oakland	California	4068926914010314	a6808274a62c8735653fb8078950da8e	VISA 13 digit	37.8016228836992809	-122.236751419485216
21633	2020-04-25 14:00:06	2020-04-25	Sterling Cole	sterling.cole@geemail.com	Augusta	Georgia	4689245694846501	24d96b2e3ee2734eb2d52106d9696831	American Express	33.4198261678889352	-82.1516383026555275
21634	2020-04-25 14:05:08	2020-04-25	Ms. Berniece Considine MD	ms.berniece.considine.md@warmmail.com	San Francisco	California	4408000813875570	c37f62d2cff484b523b3137dd70b077d	Mastercard	37.77654674677526	-122.435379978421722
21635	2020-04-25 14:05:11	2020-04-25	Campbell Reynolds	campbell.reynolds@geemail.com	Memphis	Tennessee	3088741909859126738	d42fd2cf96055024d8fe0c14823096a7	Diners Club / Carte Blanche	35.0390602262292106	-89.8822706922680226
21636	2020-04-25 14:25:50	2020-04-25	Marcia Willms	marcia.willms@geemail.com	Richmond	Virginia	3054082260190214	cbd37b304c4c09456f307e6d6848ee4f	JCB 15 digit	37.6022428657147998	-77.5241630870606713
21637	2020-04-25 14:29:32	2020-04-25	Ms. Kathleen Keeling	ms.kathleen.keeling@geemail.com	Seattle	Washington	3112817144213471708	987005b1106a1f7c293e1054a7b80809	VISA 13 digit	47.5564973445534704	-122.347093581307305
21638	2020-04-25 14:35:36	2020-04-25	Naomi Stoltenberg	naomi.stoltenberg@geemail.com	Peoria	Arizona	3337644308421769646	ab9b01fe460dca4e4566fbc57e0d110b	JCB 16 digit	33.8111281001742938	-112.307382362887267
21639	2020-04-25 14:36:46	2020-04-25	Westley Schuppe	westley.schuppe@geemail.com	Newark	New Jersey	180021000965044162	815c81721fa313871312341e09d3e6b0	VISA 13 digit	40.8002361236054512	-74.1897409267000825
21640	2020-04-25 14:42:23	2020-04-25	Emmett Torphy DDS	emmett.torphy.dds@geemail.com	Chicago	Illinois	4364367434443308	98b6e0ea1fe7beb187841f4cec2ca9ee	Mastercard	41.896558199387421	-87.6641096341919166
21641	2020-04-25 14:52:06	2020-04-25	Oren Watsica	oren.watsica@warmmail.com	Irving	Texas	3023591069882475	a1b22dccf2465dd8222235ecb8e34917	Mastercard	32.8099286514751611	-96.8839239339157956
21642	2020-04-25 14:56:28	2020-04-25	Ophelia O'Hara	ophelia.o'hara@geemail.com	Berkeley	California	210096222960421084	91f88d4370f850d28cc69411ab92a916	JCB 16 digit	37.8755048734161619	-122.247592298714281
21643	2020-04-25 15:04:09	2020-04-25	Alyssia Dach	alyssia.dach@geemail.com	Philadelphia	Pennsylvania	6011470158069585807	151392312dee383e68c98269c68fbae3	Mastercard	40.0969805472955088	-75.1847255257789158
21644	2020-04-25 15:17:13	2020-04-25	Mercy Murray-Dickens	mercy.murray.dickens@woohoo.com	San Francisco	California	51467035584263612	71bc8bda8110a69ee4f1d29b3591eeff	JCB 16 digit	37.7590917920680909	-122.420570940913493
21645	2020-04-25 15:25:23	2020-04-25	Miss Mara Schaden	miss.mara.schaden@woohoo.com	Chicago	Illinois	6011475897400129628	4cfce4e9dad1009f614f59ca244e2260	VISA 16 digit	41.7433614151388426	-87.7627184704441561
21646	2020-04-25 15:25:36	2020-04-25	Mr. Atticus Kessler	mr.atticus.kessler@geemail.com	Murfreesboro	Tennessee	3009031411943299	cd318499d734604625b322054e7b0fdf	Diners Club / Carte Blanche	35.7591194636773366	-86.5137013596799136
21647	2020-04-25 15:47:25	2020-04-25	Anabelle Bergnaum	anabelle.bergnaum@geemail.com	Houston	Texas	3096272603006360970	a0783053e2db69001ad01a5776acde9d	JCB 15 digit	29.7447424718722715	-95.4140162001378798
21648	2020-04-25 15:52:24	2020-04-25	Olive Leuschke DDS	olive.leuschke.dds@geemail.com	Fresno	California	676263379992991	c43ec3ed27449933c2ee1eca7b7bb1de	Maestro	36.734293824980405	-119.818367427458625
21649	2020-04-25 16:00:28	2020-04-25	Percy West	percy.west@geemail.com	Irving	Texas	060486449574739	3068c880517db5a845ffe65d17fefae0	JCB 16 digit	32.868097489368914	-97.0550435650907417
21650	2020-04-25 16:01:06	2020-04-25	Ms. Sheilah Windler	ms.sheilah.windler@geemail.com	Dallas	Texas	3088520876495995585	52dec28131b1e281a014f0ef0893bdfc	JCB 16 digit	32.8913251082684894	-96.666548242043703
21651	2020-04-25 16:10:32	2020-04-25	Blaze Jacobs	blaze.jacobs@geemail.com	Fontana	California	869969795316484594	1b9d9832412a0fef4bdc223953137697	VISA 13 digit	34.163056092351674	-117.381738427495222
21652	2020-04-25 16:15:59	2020-04-25	Gorden Zieme	gorden.zieme@geemail.com	San Francisco	California	6011143738923440278	8e2eecdfc7f08fbe3e1fad9a251f34a4	Voyager	37.781608420349464	-122.422930572736917
21653	2020-04-25 16:28:05	2020-04-25	Ms. Mara Glover DVM	ms.mara.glover.dvm@geemail.com	Chicago	Illinois	4612698387325666	fce0e9d384647e1d6ed1b7672bf09ef9	VISA 13 digit	41.8482489229481658	-87.6438686177164215
21654	2020-04-25 16:28:19	2020-04-25	French Borer	french.borer@geemail.com	Dayton	Ohio	869913679535045997	d8810d35e9d3aa89b31ab4a2f5ee82f8	JCB 15 digit	39.6793049864262315	-84.1115440995622521
21655	2020-04-25 16:42:13	2020-04-25	Dr. Merwin Roob	dr.merwin.roob@geemail.com	San Diego	California	3740283074634365	5e3e19bdd84b28ef4ba463d760bd6fd2	American Express	32.8880841128129546	-117.086805318379774
21656	2020-04-25 16:48:00	2020-04-25	Dr. Karis O'Conner	dr.karis.o'conner@warmmail.com	Los Angeles	California	4478449301835	005b532143f502f88e42af16341b1194	Mastercard	34.0875323544587943	-118.38513210462331
21657	2020-04-25 16:50:51	2020-04-25	Dr. Adrain Klocko Sr.	dr.adrain.klocko.sr.@geemail.com	Louisville	Kentucky	503847443498887	dc19c01daaf278a2f0a961820062a388	Maestro	38.2497378817662579	-85.7247789921309788
21658	2020-04-25 17:04:33	2020-04-25	Henri Fay-Ritchie	henri.fay.ritchie@geemail.com	Santa Ana	California	589325809195305	60a387846b31a3a0daad8be8d82cb70a	Diners Club / Carte Blanche	33.7712431369453654	-117.934427856693034
21659	2020-04-25 17:14:44	2020-04-25	Marti Dach	marti.dach@geemail.com	Houston	Texas	6011599544700045499	775cfca5e5b08bd9f4851608f481a3c8	Maestro	29.8537640770509825	-95.3457721637576867
21660	2020-04-25 17:19:52	2020-04-25	Hamilton McDermott	hamilton.mcdermott@geemail.com	Henderson	Nevada	3528357811979708756	e7258fb058f0c6c3b51517b7ca409992	Maestro	36.0804443404942745	-115.113323866545045
21661	2020-04-25 17:35:20	2020-04-25	Monroe Little I	monroe.little.i@geemail.com	Washington	District of Columbia	3158979853607063541	b3750f5ea8c8d06f360296631b56ca6d	Voyager	38.8299123584557293	-77.0323483632624146
21662	2020-04-25 17:39:09	2020-04-25	Darryl Kiehn	darryl.kiehn@geemail.com	Phoenix	Arizona	52500172128854736	58e0e587c80490dcaaf2e6a215025f6a	JCB 16 digit	33.5506230043180338	-112.009413404755676
21663	2020-04-25 17:42:36	2020-04-25	Mr. Winifred Boyer	mr.winifred.boyer@warmmail.com	Omaha	Nebraska	676104068503830	0cfebbee682881f6d3a95b0a96822641	Discover	41.3256320074811612	-96.1073051927726709
21664	2020-04-25 18:04:20	2020-04-25	Torie Padberg DDS	torie.padberg.dds@geemail.com	New York	New York	3112515896749395520	a34a5f9839fd763b538ff4d195dd7abd	VISA 16 digit	40.6167372196670584	-73.8661027292151005
21665	2020-04-25 18:11:26	2020-04-25	Mack White	mack.white@geemail.com	Bakersfield	California	3033598992603100	f807684e293084faa6dc978b4e77347c	JCB 16 digit	35.2629142530437534	-119.055816164919364
21666	2020-04-25 18:15:53	2020-04-25	Mrs. Lossie White	mrs.lossie.white@geemail.com	New York	New York	3027907984854561	4397e2ee5d5dd42288b4c22e61cd708a	Mastercard	40.5635077987089758	-73.9340722549136729
21667	2020-04-25 18:22:57	2020-04-25	Torey Beier PhD	torey.beier.phd@geemail.com	Boston	Massachusetts	3158921894608272516	bfadf118c088864493c3d9c45967a2b0	JCB 15 digit	42.4124786397609839	-70.9225347364738639
21668	2020-04-25 18:35:29	2020-04-25	Courtney Crooks	courtney.crooks@geemail.com	Hialeah	Florida	3337246464530435306	cc07fc337bbf495388184a6a6cb33919	VISA 16 digit	25.8207826252073076	-80.3215095112934705
21669	2020-04-25 18:37:43	2020-04-25	Dr. Esta Kohler MD	dr.esta.kohler.md@woohoo.com	Coral Springs	Florida	3404382869341352	e2696be92447bec90671a8065bb5d8ff	Discover	26.3390265408966719	-80.1642120241310465
21670	2020-04-25 18:38:21	2020-04-25	Mayo Dickinson	mayo.dickinson@geemail.com	Austin	Texas	869924126719384369	fe76084a69382563ac128cdd6e95f8f1	JCB 16 digit	30.3368667574260371	-97.6652936982229392
21671	2020-04-25 18:43:58	2020-04-25	Lilyanna Simonis-Zulauf	lilyanna.simonis.zulauf@woohoo.com	Burbank	California	3096293229810635996	6ab6cf3018067705e3ba629f06338e32	VISA 16 digit	34.2037404493357968	-118.267088730729753
21672	2020-04-25 18:44:24	2020-04-25	Wells Watsica	wells.watsica@geemail.com	San Francisco	California	6011064131317744585	b6705b7ed83740a3a48c44743257da23	VISA 16 digit	37.8041550053741133	-122.438180680117199
21673	2020-04-25 19:37:55	2020-04-25	Dr. Leaner Torp	dr.leaner.torp@warmmail.com	New York	New York	210085649115772958	62766e6642421e68a301b208d17153b7	JCB 15 digit	40.6494441445674752	-74.0245340010978197
21674	2020-04-25 19:40:00	2020-04-25	Dr. Dandre Rowe	dr.dandre.rowe@geemail.com	Cleveland	Ohio	869957153611108886	78d1e66621bb49bd12d5b877029a4e78	Diners Club / Carte Blanche	41.5380085201784937	-81.6610276322584667
21675	2020-04-25 19:43:50	2020-04-25	Billy Hamill	billy.hamill@woohoo.com	Charlotte	North Carolina	4008677026381399	e5b56174d50ec76ccc702a96a8c707cf	JCB 15 digit	35.1318700577851359	-80.8844444986842603
21676	2020-04-25 19:49:03	2020-04-25	Bret Schoen	bret.schoen@geemail.com	New York	New York	3528599891106315343	439063ee75ba3c83471be05692ff7cc9	JCB 16 digit	40.6377921126075066	-73.9397490374173998
21677	2020-04-25 19:55:25	2020-04-25	Leo Jacobi	leo.jacobi@geemail.com	San Francisco	California	3528244807810443378	a6cb4034241cb145dac2d2a035e419e4	JCB 16 digit	37.7674549529193513	-122.417015239302756
21678	2020-04-25 19:58:24	2020-04-25	Joan O'Connell	joan.o'connell@geemail.com	San Francisco	California	4694041923060052	033938a249e359d744f41946c34f27a3	Diners Club / Carte Blanche	37.7486956415744217	-122.430316183933542
21679	2020-04-25 20:13:34	2020-04-25	Dr. Cruz Shanahan	dr.cruz.shanahan@geemail.com	San Francisco	California	4009792103799	ff8c3721cc79a71e58ee595b31a7b63e	Maestro	37.7447005385851213	-122.439304811151814
21680	2020-04-25 20:42:16	2020-04-25	Ember O'Connell	ember.o'connell@warmmail.com	Anaheim	California	3402223738769831	a399d8cc065ccd39d539b8989c91af6e	JCB 15 digit	33.9386180253997409	-117.79448641168176
21681	2020-04-25 20:46:33	2020-04-25	Audie Anderson	audie.anderson@warmmail.com	Tacoma	Washington	6011908285900229873	731578f793d164336ee3d293a876a360	Maestro	47.2082934937093412	-122.544960542838282
21682	2020-04-25 20:48:41	2020-04-25	Dr. Cass Ziemann	dr.cass.ziemann@geemail.com	Costa Mesa	California	3096703975915303500	ea773ba371bbff57e86a4759c514039d	VISA 13 digit	33.6607686505667871	-117.989966940446948
21683	2020-04-25 20:49:56	2020-04-25	Dr. Blaine Bogan	dr.blaine.bogan@geemail.com	Moreno Valley	California	4987145311890081	cbaeb0076cc1c0ee9d5a1ce76030740a	Voyager	33.9729725615579596	-117.264046087252709
21684	2020-04-25 20:56:52	2020-04-25	Miss Myranda Swaniawski DDS	miss.myranda.swaniawski.dds@geemail.com	Green Bay	Wisconsin	4256360835422907	62c8d64c8b64b20e07301b3e4c657e8a	VISA 16 digit	44.5256876853823655	-88.0762253285206924
21685	2020-04-25 21:07:18	2020-04-25	Areli Wisozk-Dickens	areli.wisozk.dickens@woohoo.com	Houston	Texas	4651866484723123	a4b09934427bd4b77e424492354ca820	JCB 15 digit	29.7506468548983349	-95.3785029457431364
21686	2020-04-25 21:07:54	2020-04-25	Akeem Rowe	akeem.rowe@geemail.com	Oakland	California	502097598198436	73638e7d5c93a5852ace5d6993cb8446	American Express	37.7888076232167336	-122.255576245590433
21687	2020-04-25 21:26:29	2020-04-25	Ms. Isamar Hand	ms.isamar.hand@geemail.com	Denver	Colorado	869906889223354481	6fd83c233db16d7417d77e742006b793	American Express	39.6756540478724986	-104.883957536962257
21688	2020-04-25 21:28:47	2020-04-25	Cathern Kuvalis	cathern.kuvalis@geemail.com	Aurora	Colorado	869965975441635567	0fc56c1b8ad2453dd89045a3a4ead400	JCB 16 digit	39.6032503274846874	-104.592499243293702
21689	2020-04-25 21:59:06	2020-04-25	Dr. Champ Goodwin Jr.	dr.champ.goodwin.jr.@geemail.com	New York	New York	4132856623610306	7b6e965a5a2679b69e427f547cdb325a	Maestro	40.6681172274276577	-73.9789616551145883
21690	2020-04-25 21:59:21	2020-04-25	Dr. Delma Nicolas	dr.delma.nicolas@geemail.com	Elk Grove	California	3337555526784196944	17627384da23c61740746c7f2d85dd79	Discover	38.403224906213957	-121.384540873616942
21691	2020-04-25 22:10:26	2020-04-25	Vergil Jacobi	vergil.jacobi@geemail.com	Pueblo	Colorado	210023776206895433	343cfc6ccc302f9def22e08d1f005261	Maestro	38.2808001190401583	-104.538038667603587
21692	2020-04-25 22:12:10	2020-04-25	Tevin Macejkovic	tevin.macejkovic@geemail.com	New York	New York	589376253098503	2d1b1fa5a6d7b1473ca86e2d99eacac6	Discover	40.5988130656760191	-73.8885029993381295
21693	2020-04-25 22:13:53	2020-04-25	Jerrica Swaniawski	jerrica.swaniawski@geemail.com	Hillsboro	Oregon	210062247767860085	2347526eae6fe0b7b67578335e937c5d	Discover	45.5384067821521299	-122.960511064964152
21694	2020-04-25 22:25:28	2020-04-25	Mr. Ammon Boehm Sr.	mr.ammon.boehm.sr.@geemail.com	San Francisco	California	6011108136621314288	44ddaf874e27836779b7510fbca267db	VISA 13 digit	37.7811456349009376	-122.429423403586767
21695	2020-04-25 22:39:54	2020-04-25	Cora Leannon	cora.leannon@woohoo.com	San Francisco	California	869916031827517621	d2529634f1f11a39b237b8d559191f09	Maestro	37.7728282083423252	-122.432144980778645
21696	2020-04-25 22:42:17	2020-04-25	Dr. Tito Thiel IV	dr.tito.thiel.iv@warmmail.com	San Diego	California	4017219377248015	2aa19752d58e794be37a3b37eb011353	Voyager	32.8884696623843169	-117.134212752562021
21697	2020-04-25 23:01:52	2020-04-25	Michael Mertz	michael.mertz@geemail.com	San Bernardino	California	561238563436203	51bef27f786f8b083b779f91877b805f	JCB 16 digit	34.1133827908229037	-117.292094464205576
21698	2020-04-25 23:08:00	2020-04-25	Fredrick Feest	fredrick.feest@geemail.com	Austin	Texas	4557520458899717	ba31e0814967acf351d031adf4593cb9	Maestro	30.3745827601883533	-97.7011500414699299
21699	2020-04-25 23:13:07	2020-04-25	Mr. Arnie Ferry	mr.arnie.ferry@geemail.com	Houston	Texas	561224553534561	50b6b8c43824ff7cdb9082e786c50860	JCB 15 digit	29.8171886812973774	-95.3057585859686185
21700	2020-04-25 23:14:48	2020-04-25	Davie Hammes	davie.hammes@geemail.com	Raleigh	North Carolina	3450268688218405	5b648b82caf2ae92996f63704545af22	American Express	35.7901708542969033	-78.6901076008036711
21701	2020-04-25 23:16:24	2020-04-25	German Nienow	german.nienow@geemail.com	Fort Lauderdale	Florida	3715916256848904	f82e9c3d26fd5bbd6d5a398c5ff88e09	JCB 16 digit	26.1636667329806833	-80.0955020454998987
21702	2020-04-25 23:17:26	2020-04-25	Chester Tromp Sr.	chester.tromp.sr.@geemail.com	Thornton	Colorado	3112651599647945610	1c9df4c4929f5e6fe27bde4997ffb380	VISA 13 digit	40.0167756273277107	-104.992074746607997
21703	2020-04-25 23:25:30	2020-04-25	Anice Torphy	anice.torphy@woohoo.com	Memphis	Tennessee	6011753461775553509	63ae02726386193895e88ea4686b69a6	Maestro	35.1871166182748993	-89.9596090500965744
21704	2020-04-25 23:36:11	2020-04-25	Joni Ebert	joni.ebert@geemail.com	Orlando	Florida	4108622429867874	f37c77a05af9043e8946e7c22227c5c2	Voyager	28.4041597966369217	-81.3591184737127264
21705	2020-04-25 23:42:19	2020-04-25	Rock Huels	rock.huels@geemail.com	Hialeah	Florida	676174313895935	8e03e5243b33fd91adcaa8b40036c2d9	VISA 13 digit	25.8773182314798262	-80.3543371860306621
21706	2020-04-25 23:46:46	2020-04-25	Brionna Wintheiser	brionna.wintheiser@warmmail.com	Seattle	Washington	52295534979247824	6f26d061d41c32e2ce749553519711df	JCB 16 digit	47.5399818255025863	-122.30524157312847
21707	2020-04-26 00:03:32	2020-04-26	Bethann Barrows	bethann.barrows@geemail.com	New York	New York	3407631614013410	4a568eaa6e3db35a53c7750859326d55	Maestro	40.6005304095558799	-73.9372968198161544
21708	2020-04-26 00:07:26	2020-04-26	Helga Collins	helga.collins@geemail.com	Portland	Oregon	4044966988224762	8024e4a82534a0eb1c4522d24af08f97	JCB 16 digit	45.5167565042506865	-122.702018417883664
21709	2020-04-26 00:12:41	2020-04-26	Maudie Haley-Klocko	maudie.haley.klocko@geemail.com	Chicago	Illinois	6011030481202881120	cf306a9664f2b3a10a5935ef4e98985f	JCB 15 digit	41.9082237688194965	-87.7328835314635143
21710	2020-04-26 00:13:59	2020-04-26	Bradford Eichmann	bradford.eichmann@geemail.com	Los Angeles	California	3036431627809032	9bc704285ca831328ebeef459962e611	Maestro	34.0932434344995769	-118.338414799886934
21711	2020-04-26 00:15:50	2020-04-26	Nora Nicolas	nora.nicolas@woohoo.com	San Francisco	California	3732929899504270	3aee29c5b0a7661015f65aa4978a1488	Discover	37.7400172406772256	-122.425295616650615
21712	2020-04-26 00:17:36	2020-04-26	Stormy Champlin-O'Connell	stormy.champlin.o'connell@geemail.com	Chicago	Illinois	3047232223465875	52f5e49da3a9218dc3222fabd9d169f9	Discover	41.8205793092794735	-87.7762558723363924
21713	2020-04-26 00:24:41	2020-04-26	Jordan Murazik III	jordan.murazik.iii@geemail.com	Orange	California	55790119492962958	bb75179653bd0ef3f0245288de47ef2f	Voyager	33.8278191328868232	-117.835840908681234
21714	2020-04-26 00:25:21	2020-04-26	Kristian Adams Sr.	kristian.adams.sr.@woohoo.com	Shreveport	Louisiana	3112597880808982841	0e7ef504cd2d764f3ad40c6782eedf63	JCB 16 digit	32.4416106703463996	-93.8241918184541106
21715	2020-04-26 00:25:22	2020-04-26	Dr. Berniece Keebler MD	dr.berniece.keebler.md@woohoo.com	Houston	Texas	3158371994575683169	9912466beb73982a3b46362059af7b3a	VISA 16 digit	29.825081503585352	-95.2962158311173368
21716	2020-04-26 00:28:52	2020-04-26	Welton Sawayn	welton.sawayn@geemail.com	Toledo	Ohio	6011083540423839401	e514e6ed40b6ef5fb65836d9d64e1d10	Diners Club / Carte Blanche	41.6262690934523931	-83.5656430324405477
21717	2020-04-26 00:47:01	2020-04-26	Dr. Vira Stehr MD	dr.vira.stehr.md@geemail.com	Berkeley	California	54970509472746557	2e551ea41362380ebde406ae40ad95ee	JCB 15 digit	37.8901031664367167	-122.259700038449978
21718	2020-04-26 00:55:20	2020-04-26	Gil Ryan-Schneider	gil.ryan.schneider@woohoo.com	Anaheim	California	3755407479843022	d50050ed627fbcba4827d15f4be1c222	JCB 16 digit	33.8642191919330529	-117.678971360504988
21719	2020-04-26 01:00:31	2020-04-26	Miss Belia Schroeder	miss.belia.schroeder@geemail.com	Denver	Colorado	3528087861417900512	374357f3b7f58cbb86301fa0b42f62f1	Voyager	39.6782831755053209	-104.86565329011195
21720	2020-04-26 01:12:50	2020-04-26	Mr. Ferdinand Howell	mr.ferdinand.howell@geemail.com	North Las Vegas	Nevada	869986840497121653	5f47f04305937bc3fee8288a0eaac619	VISA 16 digit	36.3671690223429351	-115.154815270727127
21721	2020-04-26 01:20:48	2020-04-26	Lulu Lebsack	lulu.lebsack@geemail.com	Gresham	Oregon	3096307602195863041	2d672351ef7cd84cb2351601a362793e	American Express	45.4916604498822252	-122.373799073815718
21722	2020-04-26 01:50:05	2020-04-26	Quintin Blanda	quintin.blanda@geemail.com	San Francisco	California	6011754634452959723	fcc33e74dc81779dc9245a8625cb08d8	American Express	37.7546276733361097	-122.454241892809037
21723	2020-04-26 01:59:12	2020-04-26	Celena Kertzmann	celena.kertzmann@geemail.com	Berkeley	California	4573152553688256	b373f8dbebf0485ca0dca530b40366b6	Voyager	37.8969235294165614	-122.298947551560047
21724	2020-04-26 02:03:15	2020-04-26	Jovita Skiles	jovita.skiles@woohoo.com	New York	New York	3528358915053342470	668d508eac80db4402d64acc68ea7814	JCB 16 digit	40.6839238784965147	-73.8459132150176885
21725	2020-04-26 02:15:18	2020-04-26	Kandi Daniel	kandi.daniel@warmmail.com	Dallas	Texas	54315888326251186	9051e818a0a8cfcc3a6190a6b6e9f979	VISA 16 digit	32.7990736359536683	-96.68730417550168
21726	2020-04-26 02:32:58	2020-04-26	Dr. Bill Wolff	dr.bill.wolff@warmmail.com	Chicago	Illinois	3528341726206196782	c54b0b5c3880d390b089cfb0bb5d2554	Discover	41.8687851178295958	-87.7776637238945767
21727	2020-04-26 02:50:15	2020-04-26	Kristy Howell-O'Keefe	kristy.howell.o'keefe@woohoo.com	San Francisco	California	3158683677147897416	9e903dbd6af0e0fda54c1591fb86bd66	JCB 15 digit	37.770645565692412	-122.433008548965915
21728	2020-04-26 02:52:41	2020-04-26	Hunt Champlin	hunt.champlin@geemail.com	Hampton	Virginia	4037792479842535	cfd645ab3ba95c8b61b1eb22d5539fe7	Mastercard	37.0912067587506016	-76.348988162130496
21729	2020-04-26 03:00:49	2020-04-26	Kirstin Kovacek-Nikolaus	kirstin.kovacek.nikolaus@woohoo.com	Salinas	California	4239894958471061	eb219483a679f0850ddc455709392f49	JCB 16 digit	36.6685674783539	-121.650760983832924
21730	2020-04-26 03:05:17	2020-04-26	Chantal Marquardt	chantal.marquardt@geemail.com	Columbus	Georgia	4653778080289	400e3d97505c8be07e0713985f349c49	Maestro	32.4517632100775799	-84.9387437845278441
21731	2020-04-26 03:09:04	2020-04-26	Mrs. Petra Sipes	mrs.petra.sipes@geemail.com	Jacksonville	Florida	3792250022827919	389aa2149e295adb8a1f844459140ca4	Discover	30.4036515110690146	-81.7029430779241039
21732	2020-04-26 03:14:13	2020-04-26	Casandra Kohler	casandra.kohler@warmmail.com	San Francisco	California	676191179750392	4a2ab529a842df86377b67694b918d40	Voyager	37.781971982504416	-122.43274617088646
21733	2020-04-26 03:21:17	2020-04-26	Karyl Rath-Schuster	karyl.rath.schuster@geemail.com	San Francisco	California	210041810726448569	8576f5dfd89df8c07906b98b8f792394	JCB 15 digit	37.7961451680410789	-122.440209872637425
21734	2020-04-26 03:25:27	2020-04-26	Colvin Gusikowski	colvin.gusikowski@woohoo.com	Rochester	Minnesota	6011003773621061927	9ca4d72fae078fe96488e3a3f34a05ce	Discover	44.0955390054170024	-92.5269869009617736
21735	2020-04-26 03:27:01	2020-04-26	Debrah Lynch-Denesik	debrah.lynch.denesik@geemail.com	West Palm Beach	Florida	502097761511605	4063e096b511103693f1d470fe07892b	Maestro	26.8118140132013707	-80.1480850322008109
21736	2020-04-26 03:28:20	2020-04-26	Yasmin Nienow	yasmin.nienow@geemail.com	Denver	Colorado	3053529462696068	79ddb747a0f57d4b62901a9d6df4c8cc	JCB 16 digit	39.7663837765395627	-104.802647377947721
21737	2020-04-26 03:44:41	2020-04-26	Reyes Bins	reyes.bins@geemail.com	San Francisco	California	6011999220292378467	ee399b0c2f531c0b8ac8901a82847d17	Maestro	37.7641910176391278	-122.420351161488952
21738	2020-04-26 04:04:29	2020-04-26	Mozell Mills	mozell.mills@geemail.com	Buffalo	New York	53378069190089465	b56f6267458ca14d4419a178bdf69c7a	Voyager	42.881025098795071	-78.8819672114148744
21739	2020-04-26 04:08:30	2020-04-26	Elder Adams	elder.adams@woohoo.com	Downey	California	6011981433967578614	8ff78e7f17aef20304fefed3481aa3f4	Mastercard	33.9981428524263194	-118.056393318447846
21740	2020-04-26 04:13:18	2020-04-26	Von Mertz	von.mertz@geemail.com	San Francisco	California	51557748293823135	6f679ab4da276b1ca5f40061848aef6f	VISA 16 digit	37.8041090488640563	-122.409169092807261
21741	2020-04-26 04:13:19	2020-04-26	Jacalyn Lesch	jacalyn.lesch@warmmail.com	San Diego	California	676348975070680	a80aa2c3a925a8f43a7abc997cd3bf34	Voyager	32.7527000058043782	-117.06440589245409
21742	2020-04-26 04:29:25	2020-04-26	Paityn Kassulke-Schinner	paityn.kassulke.schinner@geemail.com	Oklahoma City	Oklahoma	3088313810535608214	c9fe4c1185ddecffacf715eb7f6a3263	VISA 16 digit	35.4682471115984015	-97.5555352038599608
21743	2020-04-26 04:34:49	2020-04-26	Harlon Klocko-Jacobs	harlon.klocko.jacobs@geemail.com	Savannah	Georgia	3046950817535024	bd768a80f08eb79eeb1e48789d2b06c0	VISA 13 digit	32.0385037440899723	-81.0891001409072345
21744	2020-04-26 04:52:40	2020-04-26	Brandt Walsh	brandt.walsh@geemail.com	San Diego	California	869996101983145179	52953f87ce2c90e52ee9cb56c45a4fc3	American Express	32.7649258537285064	-117.056807572757833
21745	2020-04-26 04:59:36	2020-04-26	Trevor Treutel	trevor.treutel@geemail.com	Temecula	California	869948264291096267	917df23c117887a455f541e77b0f92fe	Mastercard	33.5570117730781448	-117.229021596974505
21746	2020-04-26 05:03:45	2020-04-26	Shellie Kautzer PhD	shellie.kautzer.phd@warmmail.com	Louisville	Kentucky	3418514758455505	703f51a36488bb9fbbb3f4c8ad99e211	Mastercard	38.1281561656292496	-85.6594160492137178
21747	2020-04-26 05:08:30	2020-04-26	Miss Kya Wolf DDS	miss.kya.wolf.dds@geemail.com	Vacaville	California	869950125223206818	62b4804150f64466fb01037c372bb618	Maestro	38.4090814670674519	-121.966396118781716
21748	2020-04-26 05:09:39	2020-04-26	Emmalee Bergnaum-Conroy	emmalee.bergnaum.conroy@geemail.com	Nashville	Tennessee	3158478899373494275	6c33eef636a396060e0ccd0a8587efc1	Discover	36.241280611896137	-86.8283217912912306
21749	2020-04-26 05:28:24	2020-04-26	Lorenza Schimmel	lorenza.schimmel@geemail.com	Ontario	California	3337577575282443120	9a3b0d5a621ccb3932d6fc232aa8718a	Diners Club / Carte Blanche	34.0978747354965677	-117.612554893792421
21750	2020-04-26 05:28:44	2020-04-26	Santino Corwin	santino.corwin@geemail.com	Columbus	Ohio	869969407669611217	adcc4c2bdf7e74b469b1b46235aff374	Mastercard	39.9415045673537961	-83.052662962977962
21751	2020-04-26 05:36:49	2020-04-26	Desi Kunze-Hettinger	desi.kunze.hettinger@geemail.com	Mesquite	Texas	4612489622691041	3410dcb80499f8ebbbb1238add4a94c9	JCB 15 digit	32.7245425808519173	-96.5676731309585392
21752	2020-04-26 05:38:44	2020-04-26	Kasen Klein	kasen.klein@geemail.com	Ann Arbor	Michigan	53269029427760744	406cf34614a64b942ffc39e3d06fd5f9	Voyager	42.3473534833233813	-83.8199779289416966
21753	2020-04-26 05:49:39	2020-04-26	William Borer	william.borer@woohoo.com	Atlanta	Georgia	51821394653096671	7547e43da552dd0c905c50dba3ce1693	VISA 13 digit	33.7967290752377352	-84.3238195345781776
21754	2020-04-26 06:05:13	2020-04-26	Mina Hegmann DDS	mina.hegmann.dds@geemail.com	El Paso	Texas	561225417494983	207cb69ddafe032de6bc7d66c4e79b86	JCB 15 digit	31.7976952402215467	-106.335671714644889
21755	2020-04-26 06:24:09	2020-04-26	Clarabelle Kuhlman	clarabelle.kuhlman@warmmail.com	Savannah	Georgia	180015666042258054	0a70bdbdc8a7f539443bb58078ac79b7	VISA 13 digit	32.0107884397823312	-81.1156448816567632
21756	2020-04-26 06:25:51	2020-04-26	Rhett Doyle-Moore	rhett.doyle.moore@geemail.com	Denver	Colorado	210042063169751680	e7f3b637ade2bd00516a0d2120ca3cbe	Discover	39.8522697697445736	-104.905346668117119
21757	2020-04-26 06:35:18	2020-04-26	Nasir O'Conner	nasir.o'conner@geemail.com	Chicago	Illinois	4355876991033	f1340503c7920bf8f6fb21d7e74f4ef8	JCB 16 digit	41.8741719667170216	-87.697044113747026
21758	2020-04-26 06:36:11	2020-04-26	Claudie Feest-Greenholt	claudie.feest.greenholt@woohoo.com	Los Angeles	California	4478711556454	ba05c30c2030001847cfd5d0ee2d019f	JCB 16 digit	34.0769165305752253	-118.330254304035748
21759	2020-04-26 06:43:55	2020-04-26	Margot Mueller	margot.mueller@geemail.com	Los Angeles	California	3337575938828653408	ccca0b5b799b228aa8045324f4875304	JCB 16 digit	33.9451529556285578	-118.375409035803003
21760	2020-04-26 06:48:40	2020-04-26	Eben Tromp	eben.tromp@geemail.com	Surprise	Arizona	3007897308403742	801717514956ede2dfaf666d8b0ef72f	Discover	33.5951803541503864	-112.376978341000893
21761	2020-04-26 06:49:03	2020-04-26	Delta Turcotte	delta.turcotte@woohoo.com	Omaha	Nebraska	54346103455440946	026e7dc3fc0571fc9366dd730d44457a	Maestro	41.1676909412402665	-96.1315224410615912
21762	2020-04-26 06:53:11	2020-04-26	Ruthie Rowe	ruthie.rowe@geemail.com	Ontario	California	3464736803044884	8815c2eff13edc8b0e2fff04e1553429	VISA 13 digit	34.0436131174355765	-117.537454062756908
21763	2020-04-26 06:56:02	2020-04-26	Dr. Ciji Ankunding	dr.ciji.ankunding@geemail.com	San Francisco	California	502037044126029	f6297e65759f75bdc49477a5dcc1c47d	JCB 16 digit	37.7631977658153488	-122.427636244161249
21764	2020-04-26 07:04:41	2020-04-26	Teresa Cormier	teresa.cormier@woohoo.com	Roseville	California	210085887046058002	68b11e8d15491e7ac4bd29e24ca90728	VISA 16 digit	38.8307948599625377	-121.403800358365842
21765	2020-04-26 07:07:25	2020-04-26	Chelsi Schroeder DVM	chelsi.schroeder.dvm@geemail.com	Los Angeles	California	3158908148083439083	220e7a1ef6610bb327c041a45d55b8de	Discover	34.0680866098362927	-118.443659649835155
21766	2020-04-26 07:10:56	2020-04-26	Mrs. Sydni Olson	mrs.sydni.olson@woohoo.com	Fort Worth	Texas	869973989241906185	db7a9c37e1ad9d4bb999eeb8fa392491	Discover	32.7183156638462123	-97.4315585411440566
21767	2020-04-26 07:17:30	2020-04-26	Miss Kimber Haley	miss.kimber.haley@geemail.com	New York	New York	6011615442689541697	cd285a73a1ca7d02587db80d91aabdf0	Diners Club / Carte Blanche	40.7335004907324887	-73.9283054041571859
21768	2020-04-26 07:17:32	2020-04-26	Rettie Haley MD	rettie.haley.md@geemail.com	Modesto	California	55017418857579259	e7211d546b70473cfe5d5d2e8a469568	Voyager	37.607425889372827	-121.042303838694465
21769	2020-04-26 07:25:51	2020-04-26	Mrs. Flora Torphy	mrs.flora.torphy@geemail.com	Salinas	California	4870920382730964	12e53d72c595673e6c543af8d026db96	JCB 16 digit	36.6476470702558714	-121.654549110744895
21770	2020-04-26 07:28:52	2020-04-26	Lafayette Toy V	lafayette.toy.v@woohoo.com	Berkeley	California	4976169813689174	91e4750a4fa9b03f49633f417511a294	Discover	37.880181031890416	-122.243423883170465
21771	2020-04-26 07:41:50	2020-04-26	Mr. Augustine Monahan	mr.augustine.monahan@geemail.com	Denton	Texas	210022406208365406	58639143e4febaa9c8ffe0cf1944e767	VISA 13 digit	33.1768873704396157	-97.084556274361546
21772	2020-04-26 08:10:15	2020-04-26	Mr. Deforest Reinger PhD	mr.deforest.reinger.phd@geemail.com	Hialeah	Florida	180039719260459367	76a4fd408ddc48dc98e78b70e0316b1b	VISA 16 digit	25.9070624376159167	-80.318407012698799
21773	2020-04-26 08:27:40	2020-04-26	Ivana Will	ivana.will@geemail.com	Clarksville	Tennessee	3337212983162098488	80d34119f5191366791d98aa682bc114	Mastercard	36.5440973681990044	-87.3680665485046859
21774	2020-04-26 08:35:37	2020-04-26	Mrs. Etna Daugherty	mrs.etna.daugherty@woohoo.com	Miami Gardens	Florida	6011703835311378722	820cb0261fcb1a2f9c892f0ec7104b13	VISA 16 digit	25.9692077911864949	-80.2447482609901641
21775	2020-04-26 08:57:54	2020-04-26	Kaleigh Champlin-Walker	kaleigh.champlin.walker@geemail.com	Virginia Beach	Virginia	3401484318275588	55a63fe0f3638d8688dcc4e454196535	Discover	36.7637643208913545	-75.9392412940178048
21776	2020-04-26 09:00:00	2020-04-26	Bell Heidenreich	bell.heidenreich@geemail.com	Louisville	Kentucky	3460464893346937	fb8f0f55a1476f326d86248349a0ae1e	JCB 16 digit	38.0684363317113323	-85.6171368619032194
21777	2020-04-26 09:03:40	2020-04-26	Dr. Jaret O'Conner	dr.jaret.o'conner@woohoo.com	Albuquerque	New Mexico	589369169434292	96133bdb3ef64b1c0b2b971f309cc2e5	Maestro	35.1894304069824528	-106.591121342692162
21778	2020-04-26 09:07:52	2020-04-26	Mrs. Siena Lesch MD	mrs.siena.lesch.md@geemail.com	San Francisco	California	55396099196073237	c6819814f6609516ff6841968bb1e903	Voyager	37.754324058754257	-122.432278028299621
21779	2020-04-26 09:41:10	2020-04-26	Luvinia Hyatt	luvinia.hyatt@woohoo.com	Aurora	Colorado	3772705447215200	3fa30a20af45debdf6fd993512ad4777	Diners Club / Carte Blanche	39.7680957892555753	-104.653487104561933
21780	2020-04-26 09:48:44	2020-04-26	Mr. Link Eichmann	mr.link.eichmann@woohoo.com	Houston	Texas	210006829924463173	152601d57fb9faf58e405086913fa4a5	American Express	29.7912126365195959	-95.4638183447081587
21781	2020-04-26 09:52:51	2020-04-26	Tiney Dooley DVM	tiney.dooley.dvm@geemail.com	Los Angeles	California	3337509301925058404	682d4882d459fcc51595ab5553afd785	JCB 16 digit	33.9930409286968356	-118.455622056125847
21782	2020-04-26 10:02:32	2020-04-26	Takisha Tillman	takisha.tillman@warmmail.com	Tulsa	Oklahoma	501876998560056	536924b51e77c2be6ac9add2e13dc654	JCB 16 digit	36.2239317690856737	-95.8814933693923024
21783	2020-04-26 10:05:40	2020-04-26	Garth Grant-Beatty	garth.grant.beatty@geemail.com	New Orleans	Louisiana	869917742491784805	d17540f4545a681603c22bf4085b76f1	VISA 13 digit	29.9844406622011199	-90.03275672227889
21784	2020-04-26 10:08:03	2020-04-26	Kati Schaden-Kris	kati.schaden.kris@geemail.com	Oxnard	California	4930672663831577	6b83724d5b10aea661cd48fbe64d71ca	Maestro	34.1457369217604381	-119.131831716271492
21785	2020-04-26 10:18:46	2020-04-26	Mckenna Hane DDS	mckenna.hane.dds@geemail.com	Berkeley	California	869946395470954223	ddc767170df91b0fb38d6d4bfce6484c	Voyager	37.8695598811571443	-122.24693171007641
21786	2020-04-26 10:29:29	2020-04-26	Tarah Hane	tarah.hane@warmmail.com	San Francisco	California	3020954447994276	82f06e1d93b564d1e48fdf79adc39e80	JCB 16 digit	37.7317384125149289	-122.427078729074069
21787	2020-04-26 10:33:08	2020-04-26	Kaaren Veum	kaaren.veum@geemail.com	Vallejo	California	3049210047762519	ee96404deb648f396cedc2b609033c46	VISA 16 digit	38.1128468206241706	-122.339543252704658
21788	2020-04-26 10:38:53	2020-04-26	Dickie Fay	dickie.fay@geemail.com	Berkeley	California	3112972328365132579	8238f4eecfab62a4f5dbab829f51ab48	JCB 15 digit	37.8891233657824174	-122.305911844734268
21789	2020-04-26 10:43:19	2020-04-26	Ms. Aniya Collier DDS	ms.aniya.collier.dds@woohoo.com	Temecula	California	180074320499464538	2a0539b7d94bbb8eeacfeca358fee9b6	Diners Club / Carte Blanche	33.5228567531000792	-117.173734938512368
21790	2020-04-26 10:43:49	2020-04-26	Shelbie Price	shelbie.price@warmmail.com	Dallas	Texas	3005573295778758	f87753345de7cb9d46529996a2aee333	Mastercard	32.7909820906624248	-96.6786048743370827
21791	2020-04-26 10:44:16	2020-04-26	Aurore Kassulke PhD	aurore.kassulke.phd@warmmail.com	New York	New York	4842297675068666	311bbda97582937530c1c5277cad10cf	Voyager	40.6801611650027297	-73.9953084908321443
21792	2020-04-26 10:47:44	2020-04-26	Jazlyn Marquardt PhD	jazlyn.marquardt.phd@warmmail.com	Phoenix	Arizona	4666308013855665	1c60da7c283a03fb39ab6ff7ea485bf9	Diners Club / Carte Blanche	33.4765107637204267	-112.141411903260661
21793	2020-04-26 10:50:09	2020-04-26	Marcelina Murphy	marcelina.murphy@geemail.com	Phoenix	Arizona	3022516311422565	fd933585c95af6fc397d02270dca79a3	American Express	33.6378196149997422	-111.99916923459844
21794	2020-04-26 11:07:34	2020-04-26	Ms. Joelle Rogahn	ms.joelle.rogahn@geemail.com	Colorado Springs	Colorado	4184494923867	4124ea04511169389f60526f931de9db	American Express	38.9173375130213799	-104.719965254717323
21795	2020-04-26 11:09:46	2020-04-26	Ebenezer Pfeffer	ebenezer.pfeffer@woohoo.com	San Francisco	California	3748832355009747	7429f392348b68ad523a80149a3966bb	Mastercard	37.7702187349788119	-122.446046356079805
21796	2020-04-26 11:20:53	2020-04-26	Mrs. Christin Goodwin DDS	mrs.christin.goodwin.dds@woohoo.com	Aurora	Colorado	3112657791629824335	346c2870b4efcc0a9a9806fba30d351f	JCB 16 digit	39.6731292399689579	-104.700975934148587
21797	2020-04-26 11:32:33	2020-04-26	Dr. Ruthanne Blick PhD	dr.ruthanne.blick.phd@geemail.com	Tulsa	Oklahoma	869915594177569402	1b0769b531bf38a9ec7cff66d5c749f4	JCB 16 digit	36.0542737196568339	-95.905145103014263
21798	2020-04-26 11:45:48	2020-04-26	Hessie Mertz	hessie.mertz@warmmail.com	San Francisco	California	676183920462070	06ae7dbc757b4386b3dadd58ee0b29bc	Voyager	37.7831740482368943	-122.424356738374087
21799	2020-04-26 11:49:24	2020-04-26	Joretta Spencer	joretta.spencer@woohoo.com	Louisville	Kentucky	180051228899276567	9b5ba578ffc9b67aa93a43b49e907d11	VISA 16 digit	38.1497244885094418	-85.7160244635842758
21800	2020-04-26 11:57:59	2020-04-26	Ms. Danielle Stehr DVM	ms.danielle.stehr.dvm@geemail.com	Philadelphia	Pennsylvania	4072690480434506	93894986211a42cb9e157ca8273075e2	Diners Club / Carte Blanche	39.9651858019135915	-75.1877763319660062
21801	2020-04-26 12:08:05	2020-04-26	Aubrey Kunze	aubrey.kunze@geemail.com	Houston	Texas	3337275898598202484	cb6400f037b8fb34128f1e1e8e851089	JCB 16 digit	29.7613669937089078	-95.3719316162183901
21802	2020-04-26 12:09:59	2020-04-26	Butler Jerde	butler.jerde@geemail.com	Chicago	Illinois	4069662397970	afae51033779508f65ed14be3b436b4e	VISA 13 digit	41.8252120150554916	-87.7516149991221681
21803	2020-04-26 12:19:36	2020-04-26	Felisha Brakus	felisha.brakus@geemail.com	Oakland	California	4727358809428729	f4ead3d8975906cfcf0e123552a464de	Diners Club / Carte Blanche	37.7966996882982684	-122.292232351849634
21804	2020-04-26 12:24:46	2020-04-26	Dr. Holly Goldner	dr.holly.goldner@geemail.com	Boston	Massachusetts	3043107051409787	e08d5ed5ca47dedbe782e93f71092cd2	American Express	42.362760191613809	-71.0551566235207019
21805	2020-04-26 12:36:37	2020-04-26	Xzavier Homenick	xzavier.homenick@geemail.com	Fort Worth	Texas	180069066071299373	7990786a75fdb5ff72cfbbce7f083b66	JCB 16 digit	32.8782706406488998	-97.4053142704356389
21806	2020-04-26 12:58:47	2020-04-26	Raymon Koepp	raymon.koepp@geemail.com	San Francisco	California	53365502453965703	05b118ee44833e147247ba4c1eb6679f	Voyager	37.7843462807991273	-122.413426620331506
21807	2020-04-26 13:11:56	2020-04-26	Diego Roberts	diego.roberts@geemail.com	Anchorage	Alaska	4442033722299838	89eddb491d8df372f5f6fe0637b604fd	JCB 16 digit	61.1893673658121386	-149.203972759296363
21808	2020-04-26 13:26:38	2020-04-26	Evans Nitzsche	evans.nitzsche@geemail.com	Oakland	California	6011385289003272261	79b1910cd6c98ff26233527c028e63ab	JCB 15 digit	37.8008110089639899	-122.274646310964641
21809	2020-04-26 13:33:59	2020-04-26	Basil Monahan I	basil.monahan.i@geemail.com	Orlando	Florida	4550039118938697	a04e6ab0b6917c820b37601bf341f84e	JCB 16 digit	28.4255199245907342	-81.2651393021888993
21810	2020-04-26 13:57:51	2020-04-26	Kandy Lesch	kandy.lesch@geemail.com	Philadelphia	Pennsylvania	3112400412607785097	e40e52e9e28f5095afd7a3305010f62b	Maestro	39.9549103337764748	-75.1963875105038397
21811	2020-04-26 14:05:33	2020-04-26	Leonora Gutkowski-Conroy	leonora.gutkowski.conroy@geemail.com	Phoenix	Arizona	6011171031296046913	0d9e78746b63a9b026f16bf92e97e5ac	American Express	33.501593843561416	-112.075086061742539
21812	2020-04-26 14:08:30	2020-04-26	Riley O'Keefe	riley.o'keefe@woohoo.com	Renton	Washington	54468408036149862	3e0f86f220b3d09c6292f4efc7811bba	Mastercard	47.4939836820647159	-122.205108154945066
21813	2020-04-26 14:12:26	2020-04-26	Harley Hamill	harley.hamill@geemail.com	Round Rock	Texas	869929178722802130	0ac3d61be0e28844bc715ac4935b64a8	Mastercard	30.4281283132404106	-97.7362523774001772
21814	2020-04-26 14:18:17	2020-04-26	Ambers Hackett	ambers.hackett@geemail.com	Grand Rapids	Michigan	869998817974112864	c1e9bb456174b94493456ccd0052e2ec	Diners Club / Carte Blanche	43.0045739073574538	-85.7492332812067133
21815	2020-04-26 14:18:41	2020-04-26	Achsah Bailey	achsah.bailey@geemail.com	Richmond	California	3442765468719172	c3a563557707a446438d638b327f2d7b	Voyager	37.9767791151490073	-122.286209086966153
21816	2020-04-26 14:21:50	2020-04-26	Braulio Powlowski	braulio.powlowski@geemail.com	Houston	Texas	3088399801487379141	92dcd165224b153305286e91137fa8b0	JCB 16 digit	29.6879537159655236	-95.4603947976153364
21817	2020-04-26 14:23:01	2020-04-26	Felipe Pouros	felipe.pouros@woohoo.com	Columbia	South Carolina	869968045391749599	2bb4147ff2c5ca4cb38dc4dc09481687	Voyager	33.9466960800610451	-80.8017883370649059
21818	2020-04-26 14:37:33	2020-04-26	Janene Hudson	janene.hudson@geemail.com	Columbus	Ohio	6011523663641616639	6d7eba66b30116e8b97df6c1354287d1	VISA 16 digit	39.9080372286539529	-83.0666095585331448
21819	2020-04-26 14:40:06	2020-04-26	Mr. Brantley Torphy II	mr.brantley.torphy.ii@warmmail.com	Peoria	Illinois	6011378496447039342	cf19e2f9850c4d7cf29fd7ae50aaeb79	Mastercard	40.6653051098678233	-89.6807312904741707
21820	2020-04-26 14:48:45	2020-04-26	Clemie Mitchell	clemie.mitchell@geemail.com	Las Cruces	New Mexico	6011525359940384239	af2e8b5ae09c1cd807d32ca2048c8528	VISA 16 digit	32.3564620559603	-106.760846230213346
21821	2020-04-26 14:51:52	2020-04-26	Rhiannon Quitzon	rhiannon.quitzon@geemail.com	Richmond	Virginia	3423467490880352	5a52ae04c4652cdc61cb2f7038ac85a2	Maestro	37.5115413390319787	-77.4048016931619429
21822	2020-04-26 15:23:04	2020-04-26	Demetra Hamill	demetra.hamill@warmmail.com	San Francisco	California	6011890728915278203	43c04ee7096a7819a258f8a08af14c88	VISA 16 digit	37.7967955472521453	-122.413209114051085
21823	2020-04-26 15:27:01	2020-04-26	Cyril Schiller	cyril.schiller@warmmail.com	Colorado Springs	Colorado	180099796055404938	42c33aecc83b4a12ff140eb5ff5d4990	Discover	38.8368105205289993	-104.722623932656646
21824	2020-04-26 15:35:09	2020-04-26	Brande Schuster DDS	brande.schuster.dds@geemail.com	Long Beach	California	3749834769640298	226075ddc68186f1347c4ebc888ff156	Maestro	33.8954693031784089	-118.239753309141093
21825	2020-04-26 15:45:58	2020-04-26	Buck Bernhard	buck.bernhard@warmmail.com	San Francisco	California	3158326923964975643	6233022efafa6109154a80a534262de9	Diners Club / Carte Blanche	37.7725305606931059	-122.456746183770676
21826	2020-04-26 16:03:28	2020-04-26	Salvatore Hilll DDS	salvatore.hilll.dds@warmmail.com	Antioch	California	180018003932562980	dfed63e40b464a3d5b7b2d259460349e	Discover	38.0310020876381571	-121.751037451502683
21827	2020-04-26 16:04:35	2020-04-26	Elizebeth Beer	elizebeth.beer@warmmail.com	Knoxville	Tennessee	4163249542089202	1b4c84073fd31969cbef7bc0b752c3c9	VISA 16 digit	35.925691344455629	-83.8504458579450755
21828	2020-04-26 16:13:55	2020-04-26	Dr. Jaime Auer DDS	dr.jaime.auer.dds@geemail.com	New York	New York	4978328071836095	7379db11e2586028ed8874c67ed36be5	JCB 16 digit	40.6434681255593873	-73.8490252552449675
21829	2020-04-26 16:32:06	2020-04-26	Dr. Camron Stokes IV	dr.camron.stokes.iv@geemail.com	Vallejo	California	6011717757935423540	1e76cd3668fc8ac80bb74a46b3d1146d	JCB 16 digit	38.1987835351467169	-122.356068739514797
21830	2020-04-26 16:32:09	2020-04-26	Althea Reichert	althea.reichert@geemail.com	San Antonio	Texas	51482282895379825	3080318fb404e86c63013b37f319d1a1	JCB 16 digit	29.4433577829111357	-98.6051389853771667
21831	2020-04-26 16:38:15	2020-04-26	Allyn Schumm	allyn.schumm@geemail.com	Phoenix	Arizona	51208314098330595	bfb5f9723832b3de297d89546452a686	VISA 16 digit	33.6543879332419493	-111.998435410151643
21832	2020-04-26 16:38:44	2020-04-26	Anaya Fay	anaya.fay@geemail.com	Portland	Oregon	869911020835219465	a76c1852b3d0983fddc8e406b57d3e3d	Discover	45.6150229320749645	-122.675701956171551
21833	2020-04-26 16:50:40	2020-04-26	Ester Carter	ester.carter@geemail.com	Ontario	California	3337051392749431440	e9c6a6a8a90cee1ffc456975354853c6	Mastercard	34.1097296994324779	-117.608893206353116
21834	2020-04-26 17:07:31	2020-04-26	Yee Gleichner	yee.gleichner@geemail.com	Syracuse	New York	4875824668148195	444d808a694de19953084b0255a98da6	VISA 13 digit	42.9857750359307929	-76.0546286522191082
21835	2020-04-26 17:12:49	2020-04-26	Britta Lakin	britta.lakin@geemail.com	New York	New York	4352643542927794	7837e77ee35d62ea57c0c49d3ad5f2df	Maestro	40.6357791696898616	-73.9638959041692345
21836	2020-04-26 17:21:46	2020-04-26	Glenn Kuhn	glenn.kuhn@geemail.com	Springfield	Illinois	6011072049715279071	8e28d319ac00e526a3454efcddbca0d4	American Express	39.6921781582444879	-89.5970540902580979
21837	2020-04-26 17:31:30	2020-04-26	Ilo Larkin-DuBuque	ilo.larkin.dubuque@geemail.com	Carrollton	Texas	4288482783819	6348d454da146b3771d40a1b04bca5df	JCB 15 digit	32.9499989184007021	-96.8833332806687793
21838	2020-04-26 17:32:05	2020-04-26	Marlen Strosin	marlen.strosin@warmmail.com	Kansas City	Kansas	630444634694788	a6f366cccb4d3fa697ae5878deeb79b9	JCB 15 digit	39.1958407345600435	-94.7208035966318107
21839	2020-04-26 17:33:16	2020-04-26	Alf Weissnat	alf.weissnat@geemail.com	San Francisco	California	4975244509354135	6d2ace7ea649be3d808285178db1835e	VISA 13 digit	37.7681677547947316	-122.409542264059596
21840	2020-04-26 17:42:11	2020-04-26	Clair Beahan	clair.beahan@geemail.com	Garden Grove	California	55179574642068687	b4406390819e4c5d97af482bde7e9b7d	VISA 13 digit	33.7383837507862552	-117.975226580819111
21841	2020-04-26 18:20:17	2020-04-26	Cherri Botsford	cherri.botsford@geemail.com	San Francisco	California	4748674623584660	07fbe450199cd67edca2b1cc5d65b413	JCB 16 digit	37.7964429389933798	-122.420809204649487
21842	2020-04-26 18:21:11	2020-04-26	Jaxson Heaney	jaxson.heaney@warmmail.com	New York	New York	676103514391345	5e36060bbb174ea19fbe3e801d83a2df	Mastercard	40.7015971762351683	-73.9246028285834882
21843	2020-04-26 18:29:54	2020-04-26	Leala Kuhlman	leala.kuhlman@geemail.com	Eugene	Oregon	3088663265686820710	a1edb4cbe06283aaadd24841cf0d4636	Maestro	43.9744842237986617	-123.201020769587544
21844	2020-04-26 18:33:31	2020-04-26	Estelle Schoen	estelle.schoen@woohoo.com	Dallas	Texas	4612701600167	8f5578124a04274a75d6bdaf0ee769a6	Maestro	32.8896348168879769	-96.6796640623789187
21845	2020-04-26 18:38:36	2020-04-26	Sincere Sporer	sincere.sporer@geemail.com	San Francisco	California	180041515160399828	479057553100fa4174d024fe6545b3d1	Discover	37.7673618106952134	-122.415644284956315
21846	2020-04-26 18:49:57	2020-04-26	Tabetha Stroman	tabetha.stroman@woohoo.com	Sparks	Nevada	4539965409821	2ccd0dec15348b8c667871b5bad28873	JCB 15 digit	39.5247167809639137	-119.725287391091143
21847	2020-04-26 18:54:28	2020-04-26	Malia Marks	malia.marks@geemail.com	Long Beach	California	3528677950048836736	11bfc6a4a682aabc3b722ab75b71a252	VISA 16 digit	33.8498275606714145	-118.061448905912414
21848	2020-04-26 19:01:15	2020-04-26	Mr. Jose Zulauf I	mr.jose.zulauf.i@geemail.com	Raleigh	North Carolina	3158227429669004846	4ae7656ae177e73ed4cd6c3bc51cf97a	JCB 16 digit	35.748589835236217	-78.5482877620432589
21849	2020-04-26 19:10:20	2020-04-26	Destry Cartwright	destry.cartwright@geemail.com	San Francisco	California	3088120447357529682	ec0d01c790762ce04add129abd7a00a3	JCB 16 digit	37.7689416573551284	-122.43993298338448
21850	2020-04-26 19:15:48	2020-04-26	Jannette Crona-Miller	jannette.crona.miller@geemail.com	Columbus	Ohio	51910948172273566	0ef92292dba1c690cec1584833e8c9d7	JCB 16 digit	39.9190621058966926	-83.0269175237745145
21851	2020-04-26 19:20:01	2020-04-26	Phylicia Kunde-Russel	phylicia.kunde.russel@geemail.com	Augusta	Georgia	3484981272604364	ea15a4a795ab1ba2c07a6e6facd37073	Voyager	33.2971334163770081	-82.0693320740774368
21852	2020-04-26 19:22:32	2020-04-26	Trever Hills-Corkery	trever.hills.corkery@woohoo.com	Louisville	Kentucky	6011292350255699767	3be14f55453b73d7ca76e5a6b3dff760	JCB 15 digit	38.2514538939479749	-85.6418926881231357
21853	2020-04-26 19:29:57	2020-04-26	Roel Rutherford Jr.	roel.rutherford.jr.@geemail.com	San Francisco	California	6011315837117020813	88f00073ce602fb1495fac1c34bed050	VISA 13 digit	37.8078887724227144	-122.416789718551811
21854	2020-04-26 19:33:41	2020-04-26	Champ Jakubowski	champ.jakubowski@geemail.com	Buffalo	New York	4588076443674	a287187939375ae93e4d819183cec242	Maestro	42.9375417171232385	-78.8908818409711188
21855	2020-04-26 19:39:51	2020-04-26	Richie Zboncak	richie.zboncak@geemail.com	Des Moines	Iowa	210023749018196134	1d2ec7f6c1fe4652c5feacc2953fcfc5	Maestro	41.6674086724616615	-93.5811483101032735
21856	2020-04-26 19:44:34	2020-04-26	Mr. Reason Gottlieb	mr.reason.gottlieb@warmmail.com	New York	New York	4022024451266	8290884a13f12df36df7f8c57f69e6cf	VISA 16 digit	40.6137669690642511	-73.9400665835373019
21857	2020-04-26 19:50:56	2020-04-26	Mrs. Veva Ryan	mrs.veva.ryan@warmmail.com	San Francisco	California	3459136112278827	fc32d13609585da9245cbce406b2046a	Voyager	37.7829712039496002	-122.403446559914116
21858	2020-04-26 20:08:04	2020-04-26	Jeanna Homenick DVM	jeanna.homenick.dvm@geemail.com	Colorado Springs	Colorado	51482839579321595	de3783a7778acb6396a643d81c87df1b	JCB 15 digit	38.8213255079511583	-104.77149156310297
21859	2020-04-26 20:19:04	2020-04-26	Kelli Pfannerstill	kelli.pfannerstill@geemail.com	Indianapolis	Indiana	4136976786789543	3ff9203c0673992a635a08bef54f06f1	VISA 13 digit	39.7365164838738707	-86.2145171451583536
21860	2020-04-26 20:35:01	2020-04-26	Dr. Kennedi Russel DDS	dr.kennedi.russel.dds@geemail.com	Oakland	California	869944023008363129	9be4700784589348f88c522d5f110178	JCB 16 digit	37.8305720139141997	-122.251774174454241
21861	2020-04-26 20:37:37	2020-04-26	Oda Aufderhar	oda.aufderhar@warmmail.com	Waterbury	Connecticut	52725088622453842	a9a110156a8a6ce383e6cd6d8fd71eb0	Mastercard	41.471792093807835	-72.99791306126005
21862	2020-04-26 20:46:39	2020-04-26	Emiliano Gislason	emiliano.gislason@geemail.com	Denver	Colorado	4260497663901471	17981edf33e75fe7cc4df5025b24d813	Voyager	39.7473627925436901	-104.803873458529267
21863	2020-04-26 20:47:08	2020-04-26	Rose Sipes	rose.sipes@woohoo.com	Jacksonville	Florida	4639721471978874	207c56511e2a3bde196962e358006a39	JCB 15 digit	30.4358813109859838	-81.7590552060011788
21864	2020-04-26 20:55:07	2020-04-26	Doug Vandervort	doug.vandervort@warmmail.com	Chandler	Arizona	3700797327375375	cbb35682b2d736825777c526d7133c54	Discover	33.280496014291046	-111.923109450691939
21865	2020-04-26 21:00:53	2020-04-26	Carmen Walsh	carmen.walsh@geemail.com	Stockton	California	4416470565621	dfa7134b6fecb38f064e5af3309bef12	VISA 16 digit	38.0367573857970527	-121.395782886966316
21866	2020-04-26 21:07:28	2020-04-26	Marie Friesen	marie.friesen@geemail.com	Long Beach	California	4305498063737	450085cdcb3664f2afca30399f76c0fa	JCB 16 digit	33.7812159688498781	-118.203953831472617
21867	2020-04-26 21:09:57	2020-04-26	Angelo Considine	angelo.considine@geemail.com	San Francisco	California	3429849167730073	c74c7af21132fa6a3c36ccdfcc1bdd0f	VISA 16 digit	37.7792457207965739	-122.413739948073257
21868	2020-04-26 21:11:21	2020-04-26	Lular Okuneva	lular.okuneva@geemail.com	San Mateo	California	180062172516576024	c0b60bf6fa036147313cf993f2afc12f	Diners Club / Carte Blanche	37.4922069318007658	-122.380797259029364
21869	2020-04-26 21:14:04	2020-04-26	Amare Crist	amare.crist@geemail.com	Ann Arbor	Michigan	3528766203394071892	154037fcf7d758708ab0a60d3384b0c5	Discover	42.2624112124148752	-83.7957909628857038
21870	2020-04-26 21:14:35	2020-04-26	Dulce Mosciski-Ward	dulce.mosciski.ward@warmmail.com	Albuquerque	New Mexico	3403627740725020	9881df637c55e18b4a1d05b19d176db3	VISA 16 digit	35.0676148679241564	-106.740166914842661
21871	2020-04-26 21:16:25	2020-04-26	Charlize Strosin	charlize.strosin@warmmail.com	Richmond	Virginia	4563270146051600	f69d2e7f92d0625fbbb4b0d4375796b6	VISA 13 digit	37.6229523812640423	-77.4273434370979601
21872	2020-04-26 21:22:15	2020-04-26	Gia Macejkovic	gia.macejkovic@geemail.com	Indianapolis	Indiana	3096060978997141357	558b0886178d5d6317a02843e4463897	Maestro	39.7730354270439577	-86.1008131254199895
21873	2020-04-26 21:28:48	2020-04-26	Jahiem Marquardt	jahiem.marquardt@geemail.com	Antioch	California	675933126637991	6ee66fa241815b30796c5bff6cc63e82	Mastercard	37.9625200251847517	-121.745699205406751
21874	2020-04-26 21:46:41	2020-04-26	Verner Luettgen	verner.luettgen@geemail.com	San Francisco	California	3447241461660545	068689f6a1a061e36eb02e3289585044	VISA 16 digit	37.7889629172003794	-122.404207996737895
21875	2020-04-26 22:02:13	2020-04-26	Miss Gaylene Brekke	miss.gaylene.brekke@geemail.com	Alexandria	Virginia	3088779366873022515	e777427a4082fb7c379061df9442c402	VISA 16 digit	38.8880482728242853	-77.1810008299056562
21876	2020-04-26 22:02:28	2020-04-26	Dr. Wilda Feeney	dr.wilda.feeney@geemail.com	Rancho Cucamonga	California	4453179323077564	5a514744510b04bded03414c04b501e2	American Express	34.147500410302726	-117.491576059582457
21877	2020-04-26 22:15:08	2020-04-26	Zion Osinski	zion.osinski@geemail.com	San Francisco	California	561256302074192	4c3f79d7732ece3583120a5ac6b979da	Mastercard	37.7777098758519543	-122.463398521775005
21878	2020-04-26 22:35:21	2020-04-26	Ronna Veum	ronna.veum@geemail.com	Philadelphia	Pennsylvania	3158290738485138071	bf7d3e9964dea47875998759341939ff	American Express	40.0268443500116433	-75.1733023561436795
21879	2020-04-26 22:37:25	2020-04-26	Chantel Schaefer-O'Connell	chantel.schaefer.o'connell@warmmail.com	Baltimore	Maryland	210082781591220880	8add437e7a8a26dfe87b5e8869cdf852	JCB 16 digit	39.3934832196217002	-76.5898029377702585
21880	2020-04-26 23:04:27	2020-04-26	Ms. Ryleigh Bruen	ms.ryleigh.bruen@warmmail.com	San Bernardino	California	6011270610246343163	35120a5e3469363b1f981e0feec74811	JCB 16 digit	34.2112457717101961	-117.248194068136058
21881	2020-04-26 23:12:35	2020-04-26	Nathalie Morissette	nathalie.morissette@warmmail.com	Phoenix	Arizona	675940594399038	08ae9e324488c21b65ba0e686bb3e0ba	Mastercard	33.5161667354337922	-112.130985738423107
21882	2020-04-26 23:14:23	2020-04-26	Brendon O'Connell	brendon.o'connell@geemail.com	New York	New York	060449782458605	48afb038b717c579672a65a06f423c52	JCB 16 digit	40.6682558289486877	-73.9576200134947896
21883	2020-04-26 23:15:45	2020-04-26	Colonel Gibson-Veum	colonel.gibson.veum@geemail.com	San Francisco	California	4082867806778	96e59a17ca92a1af533194e7427c37cd	Voyager	37.7572026524642936	-122.430905798133921
21884	2020-04-26 23:20:56	2020-04-26	Mr. Cordero Stiedemann	mr.cordero.stiedemann@geemail.com	Fresno	California	4077857496724270	b439e4f9721e3a9928f6c755a44cd9b0	Voyager	36.8701818858146666	-119.763526166520649
21885	2020-04-26 23:24:28	2020-04-26	Magen Witting	magen.witting@geemail.com	Houston	Texas	4268508427037618	95d7d93e6f9f9cc3449ff2bec8d3fd3c	Discover	29.6996752366501831	-95.3460007540896584
21886	2020-04-26 23:36:02	2020-04-26	Tyshawn Monahan	tyshawn.monahan@woohoo.com	Seattle	Washington	4978270692005173	0c9b247583fd72d99500878e6bf8258e	Mastercard	47.6070578726865321	-122.381528413427617
21887	2020-04-26 23:37:22	2020-04-26	Ivy Upton	ivy.upton@geemail.com	Sioux Falls	South Dakota	4244682292192	4533378441ad7c0f501f28a2933db196	American Express	43.4718112500470113	-96.7899858327284477
21888	2020-04-26 23:38:45	2020-04-26	Kenya Bruen	kenya.bruen@geemail.com	Dallas	Texas	6011044830789077516	ebf57ba4080290f162244e93d6a85295	VISA 16 digit	32.8792854560345447	-96.8532088413797254
21889	2020-04-26 23:42:07	2020-04-26	Gayle Hilpert-Beatty	gayle.hilpert.beatty@woohoo.com	Houston	Texas	4062464726493367	8f126bfe539f1b1ccad15494ea594caa	VISA 13 digit	29.8090988092668354	-95.3640965763494393
21890	2020-04-26 23:51:50	2020-04-26	Adriane Stracke	adriane.stracke@geemail.com	Austin	Texas	4818758450772954	5acd6626d5a5b9240a0b25cb95877d60	American Express	30.3818700038023266	-97.7988733548443747
21891	2020-04-26 23:56:59	2020-04-26	Domenico Ernser	domenico.ernser@woohoo.com	Chicago	Illinois	55925827871367981	f926d2883b9458a709b2b4f059a5b6dd	American Express	41.8652598542928729	-87.5916097140435141
21892	2020-04-27 00:15:57	2020-04-27	Arlo Quitzon	arlo.quitzon@geemail.com	Baltimore	Maryland	4039570660562973	2b2005b0c654392e855bbd5e814f6e0f	VISA 16 digit	39.2146698906552018	-76.6494074280392397
21893	2020-04-27 00:36:29	2020-04-27	Alexandre Bashirian-Durgan	alexandre.bashirian.durgan@woohoo.com	Pittsburgh	Pennsylvania	3019356424198270	91f08cafb4f743b7ad96992948d96d9f	JCB 15 digit	40.3606208408672344	-79.9981110797435093
21894	2020-04-27 00:41:52	2020-04-27	Shanika Welch	shanika.welch@geemail.com	New York	New York	4618616132978252	2d6d0eed0f1db31678515172ea529b8d	Discover	40.6706735240053376	-73.9393948959548055
21895	2020-04-27 01:27:18	2020-04-27	Dilan Borer	dilan.borer@geemail.com	Sugar Land	Texas	3730384069195966	a2a0a0ffe35ead5b53c3a54e08952c16	JCB 16 digit	29.5390997840609408	-95.648266009102386
21896	2020-04-27 01:40:54	2020-04-27	German Gusikowski	german.gusikowski@geemail.com	Kenosha	Wisconsin	676169732936229	f6a601b9aeefd854b8b2b3c42fcd2690	Maestro	42.5325892370499687	-87.8574675257079321
21897	2020-04-27 01:44:13	2020-04-27	Mr. Jerimy Lebsack DDS	mr.jerimy.lebsack.dds@geemail.com	Philadelphia	Pennsylvania	4904549628249057	146039715ae6f2314961f4f26e30e49e	JCB 16 digit	40.0263315836392337	-75.1495029844708853
21898	2020-04-27 01:44:20	2020-04-27	Odile Schroeder	odile.schroeder@geemail.com	Berkeley	California	3337982561857271442	bc938df2d32a29af86460649d861c4d9	Diners Club / Carte Blanche	37.8638195464807907	-122.237878119819143
21899	2020-04-27 01:48:40	2020-04-27	Tahj Rau	tahj.rau@geemail.com	Oakland	California	3088842093226683511	f7393e41419f728f1683ea9c3e0395ac	VISA 16 digit	37.7714965200057193	-122.283540335217396
21900	2020-04-27 01:51:35	2020-04-27	Noma Hudson	noma.hudson@geemail.com	Los Angeles	California	676303729039986	ba2c59edca0c34bf4cb25cc321dab68f	VISA 13 digit	33.9244396691076417	-118.363275493215014
21901	2020-04-27 01:57:20	2020-04-27	Madeline McCullough	madeline.mccullough@geemail.com	Berkeley	California	869971094019803706	4ac2b1990d1a696add650ceaa474f098	Diners Club / Carte Blanche	37.8688165476544825	-122.231835012506693
21902	2020-04-27 02:06:06	2020-04-27	Jeanmarie Sawayn	jeanmarie.sawayn@geemail.com	San Antonio	Texas	3490309811478458	a2685c7160d274610d177b239692d1ef	VISA 13 digit	29.4233904881007966	-98.4346373570453324
21903	2020-04-27 02:07:34	2020-04-27	Ms. Tarsha Kuphal	ms.tarsha.kuphal@geemail.com	San Francisco	California	4091671539269	e50c4d136f1d1fe6e6baf11400b4653b	VISA 16 digit	37.7911539648462309	-122.418815241779072
21904	2020-04-27 02:15:42	2020-04-27	Jamar Gutkowski	jamar.gutkowski@geemail.com	San Francisco	California	869934927749693390	5ecd70fcc28ad351a9dd621f96e7bdf5	Mastercard	37.7588516318107068	-122.435434094901623
21905	2020-04-27 02:24:33	2020-04-27	Sariah Kirlin	sariah.kirlin@geemail.com	San Francisco	California	4402275800280	94bf046c9f8c37d5737788e604c683aa	Discover	37.7727120269483052	-122.398688768366185
21906	2020-04-27 02:25:52	2020-04-27	Ashlynn Kovacek DVM	ashlynn.kovacek.dvm@geemail.com	Rancho Cucamonga	California	4213790824410	ffb08bd4902095fd2b58ea5d56cce15b	VISA 16 digit	34.1187161960165923	-117.542077148007976
21907	2020-04-27 02:37:52	2020-04-27	Ancil Donnelly	ancil.donnelly@warmmail.com	Hayward	California	6011923172330660243	2a19adf60cb5affc1e5dd79ad705d219	Voyager	37.5571910256974419	-122.180652705000341
21908	2020-04-27 02:39:07	2020-04-27	Dr. Baxter O'Kon	dr.baxter.o'kon@geemail.com	San Jose	California	4252268148233032	befa91d26772ef7715f39caccb066679	VISA 16 digit	37.2020699734620734	-121.758776542752614
21909	2020-04-27 02:41:08	2020-04-27	Yusuf Schroeder	yusuf.schroeder@woohoo.com	Charlotte	North Carolina	4213885176403134	e243fd510bbb2f7a3efc2b372792466d	Voyager	35.2039745728738609	-80.9300668967366192
21910	2020-04-27 02:43:20	2020-04-27	Maya Nienow	maya.nienow@geemail.com	San Francisco	California	639013119285511	f378bc4a96cde82908a60d80309b6de6	American Express	37.7838457657512095	-122.442559515853134
21911	2020-04-27 02:49:29	2020-04-27	Mrs. Ever Vandervort PhD	mrs.ever.vandervort.phd@geemail.com	Tyler	Texas	210091916641143687	9337bfcea9dfe0feede2b62fe3b4712a	Voyager	32.2722333021510437	-95.2606294840682182
21912	2020-04-27 03:13:51	2020-04-27	Micayla Spencer	micayla.spencer@geemail.com	Modesto	California	3016169250820856	40e95872a4690d5d15f33fd9c561ec4c	JCB 15 digit	37.7221910310909152	-121.102415194336331
21913	2020-04-27 03:16:06	2020-04-27	Gregoria Runte	gregoria.runte@geemail.com	Boise	Idaho	3528971758496744770	5d1cfca720cac34ca3a215b8130115e6	JCB 16 digit	43.6765520307373265	-116.231215367159621
21914	2020-04-27 03:34:06	2020-04-27	Harlie Schaefer	harlie.schaefer@geemail.com	New York	New York	52435701376256226	85fa4691bc0d3588086627596ad7b482	American Express	40.6112325216401331	-73.8547502948332522
21915	2020-04-27 03:41:38	2020-04-27	Mrs. Annika Wisoky	mrs.annika.wisoky@geemail.com	Virginia Beach	Virginia	4324411297539304	f55392a02c24b67067d89313dea9c1cd	American Express	36.749659169996157	-76.071962100048367
21916	2020-04-27 04:16:25	2020-04-27	Dana Zboncak	dana.zboncak@geemail.com	Buffalo	New York	51192885505478836	7702e8cd732212da7f9dd0cc7e71018b	Maestro	42.9646040151081934	-78.9475090744838184
21917	2020-04-27 04:17:30	2020-04-27	Dr. Julian Cummings	dr.julian.cummings@geemail.com	Indianapolis	Indiana	54756577200982737	e0bfdc3124229a39d5ddb70ebabf3595	Diners Club / Carte Blanche	39.8553056318786005	-86.1788018574207939
21918	2020-04-27 04:29:21	2020-04-27	Efrain Christiansen	efrain.christiansen@warmmail.com	Austin	Texas	210063290642236971	1f23696a12c96b06440ad6b411e2d16c	VISA 16 digit	30.3824365053918193	-97.8295139468047807
21919	2020-04-27 04:30:08	2020-04-27	Sylva Kuphal PhD	sylva.kuphal.phd@geemail.com	Denver	Colorado	869920348773548812	82d7e02880f3adaf0e378621a830119b	Maestro	39.7445143192592951	-104.960775052454693
21920	2020-04-27 04:33:13	2020-04-27	Ras Langosh	ras.langosh@geemail.com	San Francisco	California	180067510800404988	55837766c76bc23cb252bb8f9900b360	Diners Club / Carte Blanche	37.7659067676845126	-122.446802741211144
21921	2020-04-27 04:34:22	2020-04-27	Christal Weissnat	christal.weissnat@geemail.com	Torrance	California	869950469379792381	611f39f06d3ac734c759e305610b0f46	JCB 16 digit	33.7676466385740781	-118.423977562145879
21922	2020-04-27 04:40:02	2020-04-27	Etna Ziemann MD	etna.ziemann.md@geemail.com	Portland	Oregon	3096206760035340083	1d7133ea83e51f0f1409b9d4b116bf02	JCB 16 digit	45.4646105846744035	-122.59958065454849
21923	2020-04-27 04:42:31	2020-04-27	Glennis Lebsack	glennis.lebsack@geemail.com	Austin	Texas	54990605013782717	3a02848408b2e082aba03b5018ad29b3	Mastercard	30.2997973584696645	-97.6910696492303146
21924	2020-04-27 05:22:11	2020-04-27	Dr. Miriam Bernier DVM	dr.miriam.bernier.dvm@warmmail.com	San Francisco	California	869945902911463192	6c268c6cb3ab7af24152ae8b30c23b0e	Discover	37.760087971157752	-122.477359731019462
21925	2020-04-27 05:23:44	2020-04-27	Mr. Alphonse Schmitt	mr.alphonse.schmitt@geemail.com	Los Angeles	California	4148984142007	505e965f3fac7a72182dc0032d02ab90	JCB 15 digit	34.0989080240350191	-118.442301093227414
21926	2020-04-27 05:36:28	2020-04-27	Farrah Hilpert-Harber	farrah.hilpert.harber@geemail.com	Tallahassee	Florida	869944012647041899	27cc7de945965fd6bd54b8dc1ae932f0	Mastercard	30.4617452933009716	-84.2198245659019733
21927	2020-04-27 05:40:51	2020-04-27	Chana Kerluke DDS	chana.kerluke.dds@geemail.com	Minneapolis	Minnesota	3337392036636092637	d8890aad9f6f578eb29fb3416357efc1	Maestro	45.0039205664854478	-93.3086607215732329
21928	2020-04-27 05:53:59	2020-04-27	Pate Herman	pate.herman@woohoo.com	Fresno	California	3716993113929242	9e45539b5222bd722af6d887d29b6836	JCB 16 digit	36.7676296316891893	-119.875670331447949
21929	2020-04-27 06:03:50	2020-04-27	Alva Schamberger	alva.schamberger@geemail.com	Oakland	California	54962886463207108	e3525192c511f5ba39689fee582e051c	JCB 15 digit	37.8210032743047577	-122.239632839248543
21930	2020-04-27 06:08:04	2020-04-27	Allena Green	allena.green@warmmail.com	New York	New York	4922259653140	9e033ffcde57d9a4ba8b6049d526e965	VISA 16 digit	40.7582394739836431	-74.0360921082913848
21931	2020-04-27 06:08:31	2020-04-27	Theodore Cartwright	theodore.cartwright@geemail.com	Houston	Texas	180023094174957031	e9522846ccaa532a8bd525af60952a30	American Express	29.8059831544369445	-95.3503496764708274
21932	2020-04-27 06:10:43	2020-04-27	Miss Elianna Bernier DVM	miss.elianna.bernier.dvm@geemail.com	Saint Paul	Minnesota	4974471390323561	177d5a92d835671404273fb80b37b297	Diners Club / Carte Blanche	45.0232765750899944	-93.1855733685925571
21933	2020-04-27 06:19:47	2020-04-27	Pamelia Rodriguez	pamelia.rodriguez@geemail.com	Huntington Beach	California	3489881863689458	131f676f5d513c6c9be5fbbe145dc82a	JCB 16 digit	33.6937620955094701	-118.096849582635983
21934	2020-04-27 06:21:12	2020-04-27	Guido Marks	guido.marks@woohoo.com	Indianapolis	Indiana	869974176025896704	781754dbf44647f63f1e9619f4d79901	Mastercard	39.7364885002847714	-86.1509351037643825
21935	2020-04-27 06:44:10	2020-04-27	Antonetta Deckow	antonetta.deckow@geemail.com	Riverside	California	4397801052531359	16201221870872fae2272d293328ff36	Maestro	33.8586362579785245	-117.403216555292531
21936	2020-04-27 06:47:30	2020-04-27	Evelynn Wilkinson PhD	evelynn.wilkinson.phd@geemail.com	Los Angeles	California	4051648984656755	09e95e5e59369b3fd98ad1daac459fa5	JCB 15 digit	33.9986173697147507	-118.332638041814036
21937	2020-04-27 06:51:20	2020-04-27	Dr. Emilie Blanda	dr.emilie.blanda@geemail.com	Joliet	Illinois	3112941683246837566	5d225220a7a641569698a1e3a14580b1	JCB 16 digit	41.4939318980880074	-88.1812982254300266
21938	2020-04-27 07:28:10	2020-04-27	Keshaun Mayert-Jenkins	keshaun.mayert.jenkins@geemail.com	Bridgeport	Connecticut	55329918658683872	086d800c108a9033a5f3ca23ce386c02	JCB 16 digit	41.2350031170692262	-73.0967210150688942
21939	2020-04-27 07:28:43	2020-04-27	Alois Nikolaus	alois.nikolaus@woohoo.com	Lexington	Kentucky	3158483793233885660	0a43bcb0e8c95849c2b96309c055c2b8	Voyager	38.126948909123243	-84.435598788726324
21940	2020-04-27 07:32:24	2020-04-27	Montel Spinka-Hauck	montel.spinka.hauck@geemail.com	Phoenix	Arizona	3088093196195875269	f616553525514ffdbf1b494994a2235f	JCB 15 digit	33.5444945531364525	-112.00199983082004
21941	2020-04-27 07:41:59	2020-04-27	Ms. Debra Hansen	ms.debra.hansen@geemail.com	Los Angeles	California	6011507271993789572	0a0e8524cfe8cb85023753c084a7046c	Maestro	33.9760274371929469	-118.447376691921789
21942	2020-04-27 07:55:39	2020-04-27	Boris Emmerich	boris.emmerich@geemail.com	Garland	Texas	210073949449019934	bbe22dae1061f6277397b13dd81c6eee	Maestro	32.8184394838057401	-96.6130593717724082
21943	2020-04-27 08:50:27	2020-04-27	Lenon Larkin V	lenon.larkin.v@geemail.com	New Orleans	Louisiana	3528164433618391853	74c9edd9852c06c7355fab52acf6a655	Mastercard	29.9928790554419145	-89.9581251787282525
21944	2020-04-27 08:58:54	2020-04-27	Aryan Hodkiewicz	aryan.hodkiewicz@warmmail.com	New York	New York	6011224635165484851	4a640dd7f55150ebff4e0ddb8d174e25	Discover	40.6672573351990394	-73.8647171320289289
21945	2020-04-27 09:07:17	2020-04-27	Sharyn Klein	sharyn.klein@warmmail.com	Buffalo	New York	4893650712142	714537bbd8d0505b9e5e3d262306e21d	VISA 13 digit	42.9210212781280234	-78.7647756130367611
21946	2020-04-27 09:18:52	2020-04-27	Rhianna Huels	rhianna.huels@geemail.com	Chicago	Illinois	4812357882473772	0b1a3f180b23510ac54340221f331c5f	Discover	41.8543079030536163	-87.7713640243776041
21947	2020-04-27 09:35:53	2020-04-27	Burrell Nienow	burrell.nienow@geemail.com	Berkeley	California	4744795729461497	16f7aa0342d133f0a57cb816745268ff	VISA 13 digit	37.8566181235981816	-122.274618584484287
21948	2020-04-27 09:39:35	2020-04-27	Landon Walsh-O'Hara	landon.walsh.o'hara@geemail.com	San Francisco	California	3528562391840350717	2fe2dfda2e16f03c66ad38f12ee19e27	Voyager	37.7923940620902599	-122.430138166119548
21949	2020-04-27 09:39:40	2020-04-27	Bernardine Gerlach	bernardine.gerlach@geemail.com	Raleigh	North Carolina	561264135410526	1c4b0e79a557407d6cd6fb61cefd8ef5	JCB 15 digit	35.8247207000520049	-78.7132770318008994
21950	2020-04-27 09:45:02	2020-04-27	Jordi Ritchie	jordi.ritchie@geemail.com	Los Angeles	California	210040445960723806	05b1a0b2c75a8fe65e29be644fb41a1c	Maestro	33.9285041659004989	-118.476090877455846
21951	2020-04-27 09:53:07	2020-04-27	Miss Abbie Roob DDS	miss.abbie.roob.dds@geemail.com	Jacksonville	Florida	4123568587504950	b87f452bed10eb3bd87d658ef268839b	Discover	30.2380508644558503	-81.7087481439191947
21952	2020-04-27 10:18:20	2020-04-27	Wayne O'Conner PhD	wayne.o'conner.phd@woohoo.com	Philadelphia	Pennsylvania	4852082654321808	4be1588cf8992bcc905d80d16bc371ca	Maestro	40.0309761140454583	-75.1027241155870371
21953	2020-04-27 10:20:03	2020-04-27	Brionna Haag	brionna.haag@woohoo.com	San Francisco	California	3020168436401272	3123c09351f60dd9132564fe5b441ef5	Mastercard	37.8036230858275957	-122.426177706474277
21954	2020-04-27 10:34:36	2020-04-27	Austin Marquardt	austin.marquardt@geemail.com	Oakland	California	503844893432193	fd3ef972a03c37778055d5bf4b280afd	Discover	37.7971629487838712	-122.265407009352913
21955	2020-04-27 10:41:11	2020-04-27	Adolfo Koelpin	adolfo.koelpin@woohoo.com	New York	New York	3088295773004710196	fc631b3355724ce3db700bb65648cbc1	Diners Club / Carte Blanche	40.7038485259041209	-74.0376483445882769
21956	2020-04-27 10:51:17	2020-04-27	Kael Mohr	kael.mohr@geemail.com	Portland	Oregon	6011627838832067868	9c8c51c419783d825164981ea5242f2b	American Express	45.487631425669413	-122.663702864339584
21957	2020-04-27 10:57:32	2020-04-27	Allyson Stanton	allyson.stanton@geemail.com	New York	New York	3112797855001168073	73f923a2b34817ead6d2408b60e434d5	Maestro	40.641112573420628	-73.9051269397500903
21958	2020-04-27 11:00:22	2020-04-27	Roseann Tromp-Kuhic	roseann.tromp.kuhic@geemail.com	Houston	Texas	3096035895398806739	7c6b7c4eda61bf55b29653ed901cff06	JCB 15 digit	29.872837061582505	-95.348451614288237
21959	2020-04-27 11:07:50	2020-04-27	Lorine Ratke MD	lorine.ratke.md@geemail.com	Los Angeles	California	6011604102856164946	96656ed9ba6b33e0bb0b663abe3a903c	Mastercard	33.9569754436012303	-118.496294127823035
21960	2020-04-27 11:09:31	2020-04-27	Leander Veum	leander.veum@geemail.com	San Francisco	California	53303041358241196	72ba962e3c2f81f8978239af8252723a	Mastercard	37.7810566134809918	-122.417617582868303
21961	2020-04-27 11:38:51	2020-04-27	Mr. Hurley Lesch DVM	mr.hurley.lesch.dvm@geemail.com	Oakland	California	180003407324158553	f44de45780ca3d97c9607bc8f413f69a	JCB 15 digit	37.7825210804693015	-122.252341199612502
21962	2020-04-27 11:39:12	2020-04-27	Abdul Considine	abdul.considine@geemail.com	Madison	Wisconsin	54631853368818232	cfe1cfca9e8b9257dfd084ac9e09b029	Diners Club / Carte Blanche	43.1215990179192303	-89.3825303298305727
21963	2020-04-27 11:52:29	2020-04-27	Vester Schowalter	vester.schowalter@geemail.com	San Francisco	California	6011325141291382273	42a6a8eaed78fc541333a673c515c56a	JCB 16 digit	37.7822494971142788	-122.435407289206097
21964	2020-04-27 12:16:40	2020-04-27	Lisette Goyette MD	lisette.goyette.md@woohoo.com	Nashville	Tennessee	869902541575069514	d1a4c4adfc3b70f8863f05e4aafcfc4c	Discover	36.2592173365067652	-86.7928905343078014
21965	2020-04-27 12:30:22	2020-04-27	Jayda Collier	jayda.collier@warmmail.com	Los Angeles	California	676333213222129	66b5f851ec954918f6c6e7894997e433	American Express	34.049445198556036	-118.488807873333982
21966	2020-04-27 12:37:09	2020-04-27	Addison Kulas	addison.kulas@geemail.com	Chicago	Illinois	3112555881945270942	0503581ea3d44a9b44c9649e7fdcb9a9	VISA 16 digit	41.7922738940291154	-87.6262094251375601
21967	2020-04-27 12:37:56	2020-04-27	Alisha Blanda	alisha.blanda@geemail.com	Carrollton	Texas	4334284997928707	95aeb6e5b825d9cc5ced74af9a3d9b49	VISA 13 digit	33.0210655524782837	-96.9543894390437799
21968	2020-04-27 12:46:54	2020-04-27	Kelly Bartoletti	kelly.bartoletti@geemail.com	Orlando	Florida	51009493949007767	b1adf88094804325df753537751dddb9	Diners Club / Carte Blanche	28.5016493053905648	-81.244794201288741
21969	2020-04-27 12:59:43	2020-04-27	Maymie Streich	maymie.streich@warmmail.com	New York	New York	3022971200349405	21db13b368eba71986ad9f8c7c47473f	VISA 16 digit	40.6186680768839992	-73.9226130251202704
21970	2020-04-27 13:04:06	2020-04-27	Arman Deckow	arman.deckow@geemail.com	Shreveport	Louisiana	4739856329711157	23a7299cad640e4721bb21df378a74bf	Diners Club / Carte Blanche	32.5341113948501643	-93.8515459675554098
21971	2020-04-27 13:26:53	2020-04-27	Evertt Schmitt	evertt.schmitt@geemail.com	New Haven	Connecticut	4903407989073	ed5cac5d297dd0eecb4689b4d83700ce	Diners Club / Carte Blanche	41.2442237140137706	-72.8489713001996222
21972	2020-04-27 14:00:33	2020-04-27	Laurie Zboncak	laurie.zboncak@geemail.com	Los Angeles	California	3528542806133804273	3d969c898e8136f9a43b09eca2862f42	VISA 13 digit	34.1160013470198962	-118.371657453336937
21973	2020-04-27 14:09:06	2020-04-27	Iva Farrell-Reynolds	iva.farrell.reynolds@warmmail.com	Washington	District of Columbia	675920401443427	1db734761c6bd8e86aa727f2eb03936e	Mastercard	38.9347284252554147	-76.9595859348055029
21974	2020-04-27 14:20:26	2020-04-27	Janay Macejkovic	janay.macejkovic@warmmail.com	San Antonio	Texas	3096208956150463886	171a7765f2c326bfcd99153a934f55bc	JCB 16 digit	29.515567988723145	-98.5017658345702927
21975	2020-04-27 14:35:37	2020-04-27	Konnor Gulgowski	konnor.gulgowski@warmmail.com	San Francisco	California	3096097759309653702	7b996d810bf6cebbb160136b491e05a1	VISA 16 digit	37.7652866062741452	-122.421055313552714
21976	2020-04-27 14:35:58	2020-04-27	Evia Donnelly	evia.donnelly@warmmail.com	Cincinnati	Ohio	6011461378220327201	60ae0f3c6fb36fd61de9639b205bb269	JCB 16 digit	39.0877613088347005	-84.4963236962717019
21977	2020-04-27 14:41:15	2020-04-27	Margarite Jakubowski	margarite.jakubowski@geemail.com	Dayton	Ohio	4142325389179128	9946d56c6f05b5f404b2c9c5acf6a014	Mastercard	39.8143882574304939	-84.2851035546701439
21978	2020-04-27 14:47:30	2020-04-27	Miss Gracelyn Brekke PhD	miss.gracelyn.brekke.phd@geemail.com	San Francisco	California	6011473278877718486	3dcefb61cfff39c3ecbe0dbe02c6af39	JCB 16 digit	37.7717607699660576	-122.403887561152814
21979	2020-04-27 15:09:08	2020-04-27	Mateo Schultz PhD	mateo.schultz.phd@warmmail.com	Amarillo	Texas	869951653854723982	8482910f30ef0c9f6c42b4adbb498981	Discover	35.1756009965833272	-101.844612693399938
21980	2020-04-27 15:09:34	2020-04-27	Kim Jast-Hahn	kim.jast.hahn@geemail.com	San Francisco	California	4943134778878	8a5bc5be40a03f215c38901c49285305	American Express	37.7451283628792424	-122.471635428089286
21981	2020-04-27 15:14:29	2020-04-27	Kanisha Block	kanisha.block@geemail.com	Huntington Beach	California	3047658441680616	6b6f20378e2fc2130d005414f715fda0	JCB 15 digit	33.6059684012126212	-118.028953775077312
21982	2020-04-27 15:32:44	2020-04-27	Kadyn Steuber	kadyn.steuber@geemail.com	San Francisco	California	6011064695336834031	229eb598625a59622c7f3b2dd66c36c3	JCB 16 digit	37.790760621238455	-122.394264992002334
21983	2020-04-27 15:40:36	2020-04-27	Karim Gibson	karim.gibson@woohoo.com	San Antonio	Texas	4907774305862355	5f124a3296e93f3806935603811448d7	Discover	29.5030198353413482	-98.4888096847873129
21984	2020-04-27 15:43:53	2020-04-27	Avie Daugherty	avie.daugherty@woohoo.com	Tallahassee	Florida	4719008238528090	1dfff7d46b8e7104a5f7471c3a5c2d05	VISA 13 digit	30.4848541052103066	-84.2991974962424422
21985	2020-04-27 15:50:31	2020-04-27	Dewey Bernier	dewey.bernier@geemail.com	Mesa	Arizona	3041475354346275	f3e5830b2e1833df9ce21df3b9fd6721	Mastercard	33.3289705424249121	-111.647359633760146
21986	2020-04-27 15:54:08	2020-04-27	Miss Maranda Rogahn MD	miss.maranda.rogahn.md@geemail.com	Los Angeles	California	210070203491615048	5155f7843b40d2214c164eaa67d882d4	JCB 15 digit	33.9909781816281367	-118.346630979701132
21987	2020-04-27 15:56:40	2020-04-27	Dr. Ty Waters IV	dr.ty.waters.iv@geemail.com	Chicago	Illinois	4322593064142958	43726ce1272a0ef24c162d8b08caa54c	American Express	41.8033973585650358	-87.7252723977465081
21988	2020-04-27 16:03:32	2020-04-27	Raven Beatty	raven.beatty@warmmail.com	Philadelphia	Pennsylvania	869932656294879193	795e3dc8ed79455fcfb6fc14a1b26189	VISA 16 digit	40.0098588834941395	-75.0810316719014281
21989	2020-04-27 16:12:27	2020-04-27	Zebulon Ratke Sr.	zebulon.ratke.sr.@geemail.com	Costa Mesa	California	4465140177672401	2a4ea783d964be6e6f8ba48d05664e84	Voyager	33.5705842948533615	-117.935295016165085
21990	2020-04-27 16:18:03	2020-04-27	Emile Upton	emile.upton@warmmail.com	Fresno	California	3088742720272264736	54c0cd00f1ab5d286ac65b10f9f31f69	JCB 16 digit	36.7516463629774748	-119.779443607769537
21991	2020-04-27 16:34:17	2020-04-27	Stephon Feeney	stephon.feeney@woohoo.com	Paterson	New Jersey	51558563943609399	7fa43d8a34221ecb02559441218c087a	VISA 16 digit	40.8837551198389377	-74.1832228411894334
21992	2020-04-27 16:44:09	2020-04-27	Anahi O'Conner	anahi.o'conner@geemail.com	Newark	New Jersey	3088631294080789510	ab7cf5feab72a135e484727ff1944e4d	Diners Club / Carte Blanche	40.7891729088414507	-74.2718677074857112
21993	2020-04-27 16:56:30	2020-04-27	Wilton Gleichner	wilton.gleichner@woohoo.com	Oakland	California	4537557556850	e6b1ccb6cc6a0d4ee4479d77a1220239	Discover	37.7849329640656961	-122.251595275879552
21994	2020-04-27 17:00:56	2020-04-27	Brenda Hayes	brenda.hayes@geemail.com	Austin	Texas	54260198078105571	6c6fa84904a1aee7ba36b60bccba7057	Diners Club / Carte Blanche	30.3495870478577885	-97.6756889770511521
21995	2020-04-27 17:21:52	2020-04-27	Kyree Spinka-Herzog	kyree.spinka.herzog@warmmail.com	Edison	New Jersey	3760380344732907	486cbdd262f3d04b160d2f70984066a2	JCB 16 digit	40.4204369048085042	-74.3329294544231232
21996	2020-04-27 17:27:42	2020-04-27	Cathryn DuBuque-Koch	cathryn.dubuque.koch@geemail.com	New York	New York	3773487366495167	84c9b16d7983b76ec36fc6197a814484	VISA 13 digit	40.763459881277754	-73.9094100305706263
21997	2020-04-27 17:36:42	2020-04-27	Violeta Hauck	violeta.hauck@warmmail.com	Nashville	Tennessee	869991227069967239	6da0c73c3ff125599956162b6d61ecb6	JCB 16 digit	36.2007588804822404	-86.8604313119221416
21998	2020-04-27 17:56:01	2020-04-27	Isidro Mertz III	isidro.mertz.iii@warmmail.com	Eugene	Oregon	3449584346193838	280161465969f0f72634be6c501f4935	Voyager	43.9747881368927622	-123.174407979565487
21999	2020-04-27 18:10:40	2020-04-27	Mr. Price Wilderman Sr.	mr.price.wilderman.sr.@geemail.com	San Francisco	California	4377987659911146	6be69d56fa652b0241b8c0195f4a9fd3	JCB 15 digit	37.7857514136972057	-122.427910135252617
22000	2020-04-27 18:25:33	2020-04-27	Dr. Normand Larson PhD	dr.normand.larson.phd@warmmail.com	Charlotte	North Carolina	4556009302482236	6170ddcfd30119b2cfe393a45a7bd94d	JCB 15 digit	35.2557723062366222	-80.7960015562772753
22001	2020-04-27 18:29:57	2020-04-27	Collier Greenholt-Grimes	collier.greenholt.grimes@woohoo.com	Evansville	Indiana	3047156671216649	acdd4bce00a902ea9723122267bfeeb0	American Express	37.9944503650672729	-87.5806834013134221
22002	2020-04-27 18:35:20	2020-04-27	Cami Dicki-Hermiston	cami.dicki.hermiston@geemail.com	San Diego	California	4814875078912756	b109b8a950ac2c745467114cb0e5ef15	Maestro	32.7725147177532321	-117.059747476493939
22003	2020-04-27 18:41:16	2020-04-27	Mr. Yoel Huel	mr.yoel.huel@geemail.com	Chula Vista	California	51296859583058294	a09e5763e7af42d118918b10fe375093	VISA 16 digit	32.6585390570804464	-117.060526911611475
22004	2020-04-27 18:42:08	2020-04-27	Armin Ferry	armin.ferry@geemail.com	Omaha	Nebraska	561237149467500	568f68821f058cd2f467eecec6c5b91f	Maestro	41.2091868074756107	-96.0974541786242327
22005	2020-04-27 19:03:42	2020-04-27	Jule Keeling-Rodriguez	jule.keeling.rodriguez@geemail.com	Miami Gardens	Florida	4864293633763	64985af12b36c1ce3dd56c72e37dc718	Voyager	25.9038178184941401	-80.1626863784868249
22006	2020-04-27 19:05:19	2020-04-27	Mr. Easton Senger DDS	mr.easton.senger.dds@geemail.com	Phoenix	Arizona	3480310957497015	7dd1af5b2098285a1ea08aba93bfe23d	JCB 16 digit	33.5794494984604412	-112.029068503614894
22007	2020-04-27 19:20:19	2020-04-27	Elroy Lockman V	elroy.lockman.v@woohoo.com	Aurora	Colorado	3047122518133231	82ce6936183bdce10dea44c960c9a607	VISA 13 digit	39.7059083882831061	-104.701963533286758
22008	2020-04-27 19:37:51	2020-04-27	Byrd Johns Sr.	byrd.johns.sr.@geemail.com	Los Angeles	California	6011130273199248291	6e3ac2720efbcd3dc4b8a7ed6c43700e	JCB 15 digit	34.0648743683803801	-118.500731561006234
22009	2020-04-27 19:45:15	2020-04-27	Jayvion Hagenes-Sanford	jayvion.hagenes.sanford@geemail.com	El Paso	Texas	4617057371903365	e599d8825ebbe9e0629a1e4b5b571a7e	Discover	31.7929809834171095	-106.352584071688355
22010	2020-04-27 19:45:50	2020-04-27	Ronan Osinski	ronan.osinski@geemail.com	Los Angeles	California	4247463871860618	3ee31d7240778e41919cc96814568dcf	Mastercard	34.0538563012011295	-118.371433386811233
22011	2020-04-27 19:49:45	2020-04-27	Shirl Rosenbaum	shirl.rosenbaum@geemail.com	San Francisco	California	3112275155578611444	b9eaee3eddfb2de9ed51e7b5e2b317b8	VISA 13 digit	37.746227960618441	-122.466717485293913
22012	2020-04-27 20:00:50	2020-04-27	Salina Strosin	salina.strosin@geemail.com	Las Vegas	Nevada	3037701454258621	5670bb0f09451d0e9dafd56f2eb71408	Diners Club / Carte Blanche	36.1716161187373118	-115.267129917277387
22013	2020-04-27 20:03:06	2020-04-27	Kristian Mills-Schuppe	kristian.mills.schuppe@geemail.com	Los Angeles	California	53445804300774229	ee067c794e4ef87f8f1f0927f25b9941	VISA 16 digit	34.110788172190631	-118.448283216589317
22014	2020-04-27 20:13:29	2020-04-27	Palma Stiedemann	palma.stiedemann@geemail.com	Columbus	Georgia	4949692633016652	ed91cda83a3b3316b206f3721f3d6ca8	Diners Club / Carte Blanche	32.5757962095595843	-84.7778522506054486
22015	2020-04-27 20:17:07	2020-04-27	Giovanna Hoppe	giovanna.hoppe@woohoo.com	Oakland	California	3768492986744900	540c051e020042f8c6fa43ad1533be7f	VISA 13 digit	37.7721515154954304	-122.263299926424708
22016	2020-04-27 20:21:10	2020-04-27	Hakim Lockman	hakim.lockman@warmmail.com	Torrance	California	6011721910066862804	86ab9f1254b4c0566bafca50a98213ca	VISA 13 digit	33.9227692706882991	-118.331332017261161
22017	2020-04-27 20:45:21	2020-04-27	Ms. Liana Huel	ms.liana.huel@woohoo.com	Broken Arrow	Oklahoma	4401278092944500	ff608bacd1f00ebacf01dd7f1dd9a305	JCB 15 digit	36.0766106392498997	-95.7822867409270344
22018	2020-04-27 20:50:51	2020-04-27	Erlene Lynch	erlene.lynch@geemail.com	Nashville	Tennessee	3728671598747976	3a77e074f9a2ad42618172af1aa07ac2	Discover	36.0763338864903886	-86.7771700194943634
22019	2020-04-27 21:06:25	2020-04-27	Clarisa Stamm PhD	clarisa.stamm.phd@woohoo.com	San Francisco	California	4730703867269	b9b1dc9835c27c35223426f80240f8af	American Express	37.7934217762517477	-122.445267798504148
22020	2020-04-27 21:16:44	2020-04-27	Dr. Prentiss Klein Jr.	dr.prentiss.klein.jr.@geemail.com	Fort Lauderdale	Florida	6011277455673106862	fcf5c7e71b6d9695f50c5dbc1c911b53	Maestro	26.233543555856496	-80.1514927260398764
22021	2020-04-27 21:53:42	2020-04-27	Jazlene Weimann DVM	jazlene.weimann.dvm@geemail.com	San Francisco	California	3757447388845591	d435152480ab867e67bb9b5ab6ef0107	VISA 16 digit	37.7742664312418768	-122.438409921764958
22022	2020-04-27 22:05:45	2020-04-27	Shepherd Erdman	shepherd.erdman@woohoo.com	Columbus	Ohio	6011059221391364470	d1810658c458a49fef803b582b557dfc	American Express	39.9828387629751134	-82.9169710076183151
22023	2020-04-27 22:10:56	2020-04-27	Columbia Frami DDS	columbia.frami.dds@warmmail.com	Kansas City	Missouri	3337262028673764175	840918cffeb04464c92706be82a64d76	Discover	39.0339319440837969	-94.6158167918436277
22024	2020-04-27 22:42:09	2020-04-27	Madlyn Braun	madlyn.braun@woohoo.com	San Antonio	Texas	210036709778426092	fac9c3a3979f6d4f3eb1e0ff927fee45	Maestro	29.4585709894612435	-98.4830402112401941
22025	2020-04-27 23:10:21	2020-04-27	Miss Colleen Bergnaum PhD	miss.colleen.bergnaum.phd@geemail.com	Vallejo	California	3015659743503722	420e6037ad0a540802085f609f8387db	JCB 15 digit	38.0591760514393442	-122.268866962041699
22026	2020-04-27 23:21:14	2020-04-27	Mike Hamill	mike.hamill@geemail.com	Portland	Oregon	3528368787003839618	7ced6254c5cb38d26db1f09d9009e778	American Express	45.5296829404663299	-122.688765423186126
22027	2020-04-27 23:24:52	2020-04-27	Charlee Heaney	charlee.heaney@geemail.com	Los Angeles	California	3088967821113997258	95f7b33a7cb07335aa21c6e187c46b63	Diners Club / Carte Blanche	34.0689607170741979	-118.381822403985254
22028	2020-04-27 23:27:50	2020-04-27	Ansel O'Hara	ansel.o'hara@geemail.com	New York	New York	3029441342612857	06d5492de8ff1b3dd8c86c977d1c17ff	Discover	40.7595017404519027	-73.8849196702137618
22029	2020-04-27 23:33:15	2020-04-27	Dr. Brantley Kuhic	dr.brantley.kuhic@geemail.com	Memphis	Tennessee	869939094005688112	276434d52664eec93b9c00430b184d86	JCB 16 digit	35.0740515402119613	-90.0628796071071207
22030	2020-04-27 23:41:21	2020-04-27	Price Klocko	price.klocko@geemail.com	Jacksonville	Florida	6011011572472270201	65a8e9c69dc8133a299ffbbe267cd51d	American Express	30.3462224025331437	-81.6223388997916146
22031	2020-04-27 23:45:39	2020-04-27	Timmie Rodriguez	timmie.rodriguez@geemail.com	Little Rock	Arkansas	54272983579738269	153567c9718fc8e7167838bff5ea7458	JCB 15 digit	34.6870738983895635	-92.2814415894322053
22032	2020-04-27 23:56:59	2020-04-27	Louella Nitzsche	louella.nitzsche@geemail.com	New York	New York	4924293940780	a69d468df0e130c91a8a150992d2897e	Voyager	40.6780742496009893	-74.0329917086183968
22033	2020-04-28 00:00:40	2020-04-28	Wade Schmidt	wade.schmidt@geemail.com	Nashville	Tennessee	180078158648397993	dc42036d5d46f53c8a0bc732bab0020e	JCB 16 digit	36.1553980463307312	-86.7081947913765845
22034	2020-04-28 00:01:21	2020-04-28	Giselle Koss	giselle.koss@woohoo.com	Tucson	Arizona	4550785258944800	327901692f00d4dcc542c698cf60537a	JCB 16 digit	32.059846140820909	-110.805924539244174
22035	2020-04-28 00:02:30	2020-04-28	Giovanni Beer-Effertz	giovanni.beer.effertz@geemail.com	Seattle	Washington	869971881964466426	179d69d79b34cbc9c1941d0e64306660	American Express	47.7153195609264102	-122.303126386312385
22036	2020-04-28 00:08:36	2020-04-28	Gloria Streich	gloria.streich@warmmail.com	Chicago	Illinois	53850291393028796	d623c253ea8adbc8bc06b7212ef403d8	JCB 16 digit	41.8624344037681837	-87.7182208194427204
22037	2020-04-28 00:09:55	2020-04-28	Miss Jamila Schultz	miss.jamila.schultz@warmmail.com	New York	New York	869903840740870387	68dff3148f63a334b6ae3e250012dd4e	Voyager	40.6337586521860175	-73.868490296265847
22038	2020-04-28 00:29:32	2020-04-28	Basil Dicki	basil.dicki@warmmail.com	West Covina	California	4832741601550059	c0e5aa70a3af834112e31a97db146d09	VISA 13 digit	34.0705434177644548	-117.959127554025116
22039	2020-04-28 00:35:23	2020-04-28	Dr. Cassidy O'Reilly	dr.cassidy.o'reilly@geemail.com	Milwaukee	Wisconsin	52903537817287856	99f28247c09e8b7f9b50b5837729b13b	VISA 13 digit	42.994355477121843	-87.8766772000685421
22040	2020-04-28 00:43:07	2020-04-28	Ms. Hayden Schimmel	ms.hayden.schimmel@geemail.com	San Antonio	Texas	3096228669197589821	134da02bf573a944999c5373bb4d78f2	Maestro	29.3827030129801479	-98.6097420336049026
22041	2020-04-28 00:53:53	2020-04-28	Winter O'Hara	winter.o'hara@geemail.com	Columbus	Ohio	3786749533911565	9f2c628ca5eedf451cc134bcef6f7021	American Express	39.9452149927660827	-83.0776166224621306
22042	2020-04-28 00:54:23	2020-04-28	Glennie Lemke	glennie.lemke@geemail.com	Toledo	Ohio	4126886764333028	561818a2bd3db4efcf44b30e1a2125cc	American Express	41.6388980375774196	-83.5972995816595841
22043	2020-04-28 00:57:10	2020-04-28	Ruthe Boehm	ruthe.boehm@warmmail.com	San Francisco	California	54468526205543316	0c5a1eb49b3372f4166f3fe7aee314e7	JCB 15 digit	37.7980428866010172	-122.39942667114822
22044	2020-04-28 01:00:12	2020-04-28	Dr. Khalid Lueilwitz DVM	dr.khalid.lueilwitz.dvm@geemail.com	High Point	North Carolina	53589801332929769	73dd4c85826e11c96f9ad7453a46dd42	JCB 15 digit	35.9340866060089326	-80.0564164956305149
22045	2020-04-28 01:04:47	2020-04-28	Erie Metz	erie.metz@geemail.com	San Francisco	California	180092575851772707	d7e588026c83dd7a785efba59142c864	American Express	37.7588225735345588	-122.447275605001266
22046	2020-04-28 01:12:32	2020-04-28	Shantell Stroman	shantell.stroman@geemail.com	Kansas City	Kansas	3158375380799005072	2eb762f386323155ac1af82286339a85	JCB 16 digit	39.0751587319560372	-94.7000551524043033
22047	2020-04-28 01:16:56	2020-04-28	Miss Breann Baumbach MD	miss.breann.baumbach.md@warmmail.com	Los Angeles	California	4522019359765772	918e395bcdf12d0ce24f66b8286cde6e	JCB 15 digit	34.1048195605963471	-118.487835281993441
22048	2020-04-28 01:22:32	2020-04-28	Mr. Starling Harber	mr.starling.harber@woohoo.com	Concord	California	6011068432203710060	8d74ba32ac5379ff9ae54f03d37bdc60	Diners Club / Carte Blanche	37.987769666819645	-122.010060257574906
22049	2020-04-28 01:32:21	2020-04-28	Kellen Bartell Sr.	kellen.bartell.sr.@geemail.com	Chesapeake	Virginia	639084561973227	2f1469c05188c0c27c9deb982c32861f	JCB 15 digit	36.6943205321911705	-76.2827434530325235
22050	2020-04-28 01:33:07	2020-04-28	Anya Marvin	anya.marvin@warmmail.com	New York	New York	54625166599227422	4db00f1e129cf7cfce51e7dd86b520e5	JCB 16 digit	40.6725168215334421	-73.9925464063778549
22051	2020-04-28 01:42:03	2020-04-28	Carnell Cartwright	carnell.cartwright@geemail.com	Joliet	Illinois	6011250602172245490	23e4131a95c76862f52b79315a182c06	Discover	41.4250187741450944	-88.0866458631690534
22052	2020-04-28 01:53:06	2020-04-28	Darrick Satterfield	darrick.satterfield@geemail.com	Chandler	Arizona	676180573429166	86cce1f81ee93c23b97f968475d619b5	Voyager	33.24220230282247	-111.78650916571506
22053	2020-04-28 01:54:49	2020-04-28	Alisson Lowe	alisson.lowe@geemail.com	Oakland	California	869900422602737112	167b623c02d57015f75017898975ee04	Discover	37.7840939190078515	-122.312713790214787
22054	2020-04-28 01:56:55	2020-04-28	Katharina Rempel	katharina.rempel@woohoo.com	Milwaukee	Wisconsin	3414646276390790	83372fdb62d69dc991b873510a644f30	Mastercard	43.0469809816770237	-87.8667672741793098
22055	2020-04-28 02:02:06	2020-04-28	Victorine Sanford	victorine.sanford@geemail.com	Berkeley	California	4498276192290265	65d45f2b31b715c0324cb5703670b9aa	JCB 15 digit	37.8754992956428111	-122.265804804458043
22056	2020-04-28 02:04:08	2020-04-28	Jeannie Gislason MD	jeannie.gislason.md@geemail.com	Oceanside	California	52862232665704405	561624715ca28ee63164f9e3cac52efe	American Express	33.1390938200410474	-117.380364324766035
22057	2020-04-28 02:04:24	2020-04-28	Heath Schuster	heath.schuster@geemail.com	Mesquite	Texas	3112887999725131644	baa65efe4bd0e2566475cbb817e442e5	Maestro	32.7689021164827068	-96.5338892428401891
22058	2020-04-28 02:24:29	2020-04-28	Tula Wiegand DVM	tula.wiegand.dvm@geemail.com	Carrollton	Texas	4766889742535263	df72dd4a06e1683437bf73dec4b3d5ec	JCB 16 digit	32.9134353922601761	-96.8073192666612528
22059	2020-04-28 02:28:28	2020-04-28	Mrs. Bethann Lowe DDS	mrs.bethann.lowe.dds@geemail.com	Houston	Texas	3112048943971409631	e331ef1d32857413d3057c32c916c0af	Voyager	29.8233599926888928	-95.3630752054989301
22060	2020-04-28 02:33:30	2020-04-28	Leilani Swift	leilani.swift@geemail.com	Oxnard	California	561270200760992	2b57ccf988f310403b18b984d75aa66f	Diners Club / Carte Blanche	34.1747074309691783	-119.213208077047398
22061	2020-04-28 02:34:24	2020-04-28	Genesis Rogahn-Bruen	genesis.rogahn.bruen@warmmail.com	New York	New York	6011410306099558962	6a21d9f4723a78b222b984787f5fb60b	Discover	40.6187002158015957	-73.9524861726339822
22062	2020-04-28 02:37:11	2020-04-28	Mr. Nolan Oberbrunner	mr.nolan.oberbrunner@geemail.com	Lubbock	Texas	3498393807295441	14b35548d79f3545c7bbf68f5f8c0718	JCB 16 digit	33.5515047514386495	-101.939283927568056
22063	2020-04-28 02:48:17	2020-04-28	Ulysses Gislason	ulysses.gislason@geemail.com	Gainesville	Florida	3528962911736799291	43c3b482dbe7045ec1a05f22bc4ac106	Voyager	29.6663226594042015	-82.2665794609919203
22064	2020-04-28 02:58:55	2020-04-28	Desi Cassin	desi.cassin@geemail.com	Boston	Massachusetts	6011789587095541309	0e9d722d2b1bde86aa17366587e0822f	VISA 16 digit	42.3781307768244275	-71.1191223235286856
22065	2020-04-28 02:59:21	2020-04-28	Dr. Elsa Kris PhD	dr.elsa.kris.phd@warmmail.com	Brownsville	Texas	180083095952894285	46cc55e667fec47c15a55a3545fff1ee	Diners Club / Carte Blanche	25.9041803626421832	-97.5458797108568234
22066	2020-04-28 03:11:50	2020-04-28	Nayeli Abernathy	nayeli.abernathy@geemail.com	Chicago	Illinois	869956167073439309	eafa92079c5af360eefb8c063effeb66	Discover	41.8050577408935879	-87.618937248367061
22067	2020-04-28 03:39:38	2020-04-28	Darold Feil	darold.feil@geemail.com	El Paso	Texas	869920371966392251	ebe6f4f30823f01daaa730959fa0bcef	Diners Club / Carte Blanche	31.8520662525963054	-106.508858152430506
22068	2020-04-28 03:46:21	2020-04-28	Dr. Aydin Hartmann DVM	dr.aydin.hartmann.dvm@warmmail.com	St. Petersburg	Florida	180046019233143177	790e67a66321738966abce5292b5ca99	American Express	27.7640995162427444	-82.624627194822196
22069	2020-04-28 03:48:07	2020-04-28	Brennen Wolf III	brennen.wolf.iii@geemail.com	San Francisco	California	180028453770512316	35eaead104885b3a7cc00f867ae34818	Voyager	37.7580344521103157	-122.434625468943949
22070	2020-04-28 04:00:23	2020-04-28	Quincy Ernser	quincy.ernser@geemail.com	Anaheim	California	3741627733577416	fc7188d5fe66cec96a9322364f5f8304	JCB 16 digit	33.8766526793427758	-117.667921903191498
22071	2020-04-28 04:11:50	2020-04-28	Mya Reichel PhD	mya.reichel.phd@warmmail.com	Berkeley	California	53745138976531952	a4ba195c71fc0f9f92523b13dbeb8963	VISA 16 digit	37.8931441757879242	-122.268453758000774
22072	2020-04-28 04:25:40	2020-04-28	Elige Mayer	elige.mayer@warmmail.com	Phoenix	Arizona	4937663830797109	f0ef523c4b46c79f53778ba3b33dec5d	Maestro	33.5107549854952893	-112.159244008588047
22073	2020-04-28 04:32:26	2020-04-28	Willam Frami	willam.frami@geemail.com	San Antonio	Texas	639060070016096	b140306ecf8b1ae315a3a5cce8e04f7c	Maestro	29.4334014996025708	-98.4318153156269346
22074	2020-04-28 04:39:03	2020-04-28	Mr. Dedric Pouros MD	mr.dedric.pouros.md@woohoo.com	New York	New York	869945511500408797	993602db37dcdfe05e7971426d7a7514	American Express	40.627241462165486	-73.8544678910531047
22075	2020-04-28 04:51:31	2020-04-28	Ms. Nanci Thompson DDS	ms.nanci.thompson.dds@geemail.com	Centennial	Colorado	3703250412281360	5b80636be2accce71646551e717dff58	JCB 15 digit	39.6585702111985583	-104.86174376601204
22076	2020-04-28 04:53:32	2020-04-28	Ammie Mueller	ammie.mueller@geemail.com	Anaheim	California	676177752908028	1951115f01f406438f1a9a1fee109987	Mastercard	33.862438620097933	-117.729342443563411
22077	2020-04-28 04:59:14	2020-04-28	Miss Joell Brekke	miss.joell.brekke@warmmail.com	Aurora	Illinois	4689060914363686	1c865d5d398f9f3023e296ba911c9c60	Mastercard	41.8438660489153094	-88.3436910254809931
22078	2020-04-28 05:05:52	2020-04-28	Jo Lesch-Von	jo.lesch.von@woohoo.com	Indianapolis	Indiana	54125062294738752	2670efc17308ff0e28e964b6f06f5385	JCB 15 digit	39.7323885636877279	-86.2317887153212013
22079	2020-04-28 05:17:14	2020-04-28	Mimi Dach MD	mimi.dach.md@geemail.com	New York	New York	3112843079039067728	e9ac6724c5d0d53da9e62f831eb51550	VISA 16 digit	40.6673887784816301	-74.0379421566974401
22080	2020-04-28 05:54:24	2020-04-28	Darcy Collier PhD	darcy.collier.phd@woohoo.com	San Diego	California	4550507465133013	915c8ddd4488f29d5e28278b01e42a05	JCB 16 digit	32.8540645130045732	-117.121504394747319
22081	2020-04-28 05:58:58	2020-04-28	Babe Collier	babe.collier@geemail.com	Tempe	Arizona	4067245618862	de02761b1f23a52d83a19182315fe03c	American Express	33.3415414075288865	-111.885429003977393
22082	2020-04-28 06:07:24	2020-04-28	Johana McKenzie	johana.mckenzie@woohoo.com	Bakersfield	California	210046670507505267	473e09a670f2af902145e89c4c086f34	JCB 16 digit	35.2952675680339283	-119.021786337186768
22083	2020-04-28 06:07:24	2020-04-28	Darvin Gislason-Denesik	darvin.gislason.denesik@geemail.com	Albuquerque	New Mexico	3337799655421189602	89f9682fe037d2b198edc317ed4888b2	VISA 16 digit	35.0907827715523553	-106.656810680877044
22084	2020-04-28 06:13:23	2020-04-28	Dr. Perla Casper MD	dr.perla.casper.md@geemail.com	Vallejo	California	53141448253606124	75f3b5d5eaa4d62770cb8d01b7e2404c	American Express	38.0102707819636905	-122.234076602930202
22085	2020-04-28 06:27:49	2020-04-28	Mr. Nathaniel Von	mr.nathaniel.von@geemail.com	Glendale	Arizona	3035681538365273	3d9aa9d6faf2e42fb11659e30d0c2e4f	American Express	33.4838156358566081	-112.284822773959107
22086	2020-04-28 06:31:41	2020-04-28	Juliann Torphy	juliann.torphy@warmmail.com	Huntsville	Alabama	53822361012288348	dc659eecc827ef5e3ede3b9b1b053c10	JCB 16 digit	34.6596939636170873	-86.7627990514524328
22087	2020-04-28 06:33:45	2020-04-28	Jacalyn Marquardt	jacalyn.marquardt@warmmail.com	Escondido	California	180073441616854384	a3edaf8ef2a6dd47b0a5b206187bb3e1	Discover	33.1504266116064059	-116.975432359218601
22088	2020-04-28 07:06:33	2020-04-28	Tamela O'Conner	tamela.o'conner@geemail.com	Fort Worth	Texas	3036594023527316	4d5038af357e27d0f6c54d39290c6601	Mastercard	32.8374079257305738	-97.2812195389352752
22089	2020-04-28 07:13:54	2020-04-28	Lenore Kirlin	lenore.kirlin@geemail.com	Philadelphia	Pennsylvania	6011940630654104659	5b6650c68d268b596c49c180957c2ddb	JCB 15 digit	39.9464952193625251	-75.1834916514244043
22090	2020-04-28 07:15:19	2020-04-28	Terrance Bergstrom	terrance.bergstrom@woohoo.com	Arlington	Texas	4534326990254	1a3bd49b28a4dc9d342bfa279dd4e7ce	Diners Club / Carte Blanche	32.6648287589911348	-97.1156189002122829
22091	2020-04-28 07:19:32	2020-04-28	Chanel Cormier	chanel.cormier@geemail.com	Oklahoma City	Oklahoma	4086429558837389	c4b5559bd621e138884079271180eabf	JCB 16 digit	35.5598386675961322	-97.5414981166262152
22092	2020-04-28 07:20:14	2020-04-28	Violette Dietrich	violette.dietrich@woohoo.com	San Francisco	California	3528484760211723089	28d0a9a3dd53c3fd7cdec453b61d7841	JCB 16 digit	37.767499198694523	-122.472197399918798
22093	2020-04-28 07:40:41	2020-04-28	Kristi Legros-Aufderhar	kristi.legros.aufderhar@geemail.com	New York	New York	4061027760158518	0146843c6f4c61db30ead6d797203166	Maestro	40.6540587285291366	-74.033679003863412
22094	2020-04-28 07:42:29	2020-04-28	Dr. Marilou Blick PhD	dr.marilou.blick.phd@geemail.com	Portland	Oregon	3096029360089128461	4dc13e9f955e2a9c06b3639f5437eb43	Mastercard	45.5738737907614535	-122.647228815453133
22095	2020-04-28 07:46:17	2020-04-28	Aleck Schaden	aleck.schaden@geemail.com	Santa Ana	California	869931526546429249	177c0120e675782b92d5d6a0f69c07f9	VISA 16 digit	33.780865943023187	-117.820306378828363
22096	2020-04-28 08:00:21	2020-04-28	Dr. Jannie Rogahn	dr.jannie.rogahn@woohoo.com	Clarksville	Tennessee	589337108968415	29bc63ae73c7d4304091b57f2e0ce0c3	JCB 16 digit	36.6346794861029821	-87.3648997861377978
22097	2020-04-28 08:11:09	2020-04-28	Boone Botsford	boone.botsford@geemail.com	Chicago	Illinois	3005715302352545	b593efa26f836b17297bedfccec4b87d	JCB 15 digit	41.8979107540868227	-87.7174082917656648
22098	2020-04-28 08:13:40	2020-04-28	Lyn Ortiz-Mueller	lyn.ortiz.mueller@geemail.com	San Diego	California	4401575223682853	830ae7f371385dfe32541b18f8db967d	Maestro	32.772716076166553	-117.181937354141851
22099	2020-04-28 08:25:42	2020-04-28	Hubert Kertzmann	hubert.kertzmann@geemail.com	Kansas City	Missouri	4055339621447	1ef921b0bbd28fb134a0791e253faaec	JCB 15 digit	39.0724919228185001	-94.452306499168273
22100	2020-04-28 08:38:30	2020-04-28	Orlando Gutkowski	orlando.gutkowski@geemail.com	Antioch	California	3486667848718840	4c2617cb7919fc8e0741f6a9b58b1538	American Express	37.9484886429537127	-121.800995440426092
22101	2020-04-28 08:46:44	2020-04-28	Dr. Silver Harvey	dr.silver.harvey@geemail.com	Rancho Cucamonga	California	3029985520123004	3010d94046df0b2fecb951a52c600175	Voyager	34.0414295232847337	-117.547705601901555
22102	2020-04-28 08:47:17	2020-04-28	Caesar Wilkinson	caesar.wilkinson@geemail.com	Chicago	Illinois	3096001411632366041	48203a06412ba337435f59fedd112a95	VISA 13 digit	41.8756730388220433	-87.6849442987732601
22103	2020-04-28 08:58:27	2020-04-28	Tami Wehner	tami.wehner@woohoo.com	Visalia	California	4033718516515465	ea69eb6827ed87e1d556bd94dcb3c70b	VISA 13 digit	36.4042393951166403	-119.383785606747125
22104	2020-04-28 09:04:54	2020-04-28	Mr. Antonio Reynolds	mr.antonio.reynolds@geemail.com	Los Angeles	California	3023098825776561	c6a8989d85c66d728481ab413c8dce23	Mastercard	34.0576799653336408	-118.38454999327584
22105	2020-04-28 09:14:46	2020-04-28	Berniece Emmerich	berniece.emmerich@warmmail.com	Omaha	Nebraska	4578903903544366	3776af7684b1597def0ef4bec16002ad	Discover	41.3470643250882617	-96.1152865895185613
22106	2020-04-28 09:27:31	2020-04-28	Dr. Roxanne Bernhard	dr.roxanne.bernhard@warmmail.com	San Francisco	California	4961498246811	6c0738f9b9917f8823b5482dc6d008ab	Mastercard	37.8168736858603793	-122.432593904545186
22107	2020-04-28 09:39:59	2020-04-28	Mrs. Henriette Leffler	mrs.henriette.leffler@warmmail.com	New York	New York	676101194036370	c9baad7138509e89c761e1586671e417	Mastercard	40.6720724389646193	-73.8643779842544319
22108	2020-04-28 10:12:08	2020-04-28	Sydney Heller	sydney.heller@geemail.com	Boston	Massachusetts	4492450621675703	26dcbf70a170de16a7e1528981731ad2	Discover	42.3135144482068739	-71.0138840860638823
22109	2020-04-28 10:17:44	2020-04-28	Cydney Waelchi	cydney.waelchi@geemail.com	Phoenix	Arizona	6011497190972035405	389af4fa7d6f219bd27f0ee9fa80f5b2	Discover	33.4864115474212909	-112.132741415027908
22110	2020-04-28 10:34:23	2020-04-28	Mr. Brandyn Cartwright	mr.brandyn.cartwright@geemail.com	Berkeley	California	4410668936566718	e1848fb5e54e49131dae254a96f47110	JCB 16 digit	37.8866572801348411	-122.310034991070097
22111	2020-04-28 11:06:33	2020-04-28	Dr. Kristoffer Jacobs	dr.kristoffer.jacobs@geemail.com	Birmingham	Alabama	4996634138993	e19a0dbf9fd0d223482c93e4a8fe98c5	American Express	33.5412980458490537	-86.8275773099865802
22112	2020-04-28 11:08:20	2020-04-28	Mckenzie Hudson	mckenzie.hudson@warmmail.com	Dallas	Texas	180090408736797693	5e6b32c4a79895ddab71434910c18af2	Maestro	32.7072462881721577	-96.7022493858784316
22113	2020-04-28 11:11:12	2020-04-28	Lawanda Greenfelder-Gerhold	lawanda.greenfelder.gerhold@woohoo.com	Tulsa	Oklahoma	4309245771384202	91ad80b2a2861a45c24d2393f63ed5f3	Mastercard	36.2069799005888342	-95.9684561163607981
22114	2020-04-28 11:16:34	2020-04-28	Layla Ankunding	layla.ankunding@geemail.com	Portland	Oregon	4946759021780653	cf2a6d119269273bcb50ce4752567df6	VISA 16 digit	45.5799518153425325	-122.714195260405546
22115	2020-04-28 11:22:17	2020-04-28	Suzan Crona-Kuhlman	suzan.crona.kuhlman@woohoo.com	Overland Park	Kansas	3337003443132723197	e72131806a95208bbc1b9cc09560ddc1	Voyager	38.8952272545415951	-94.6246330257080501
22116	2020-04-28 11:24:32	2020-04-28	Conway Harris-Bailey	conway.harris.bailey@geemail.com	Berkeley	California	6011184699184510367	17bae28b35981a85ae777bc4183b81a3	Discover	37.8827724265115009	-122.257146878133895
22117	2020-04-28 11:42:15	2020-04-28	Jamarion Keebler	jamarion.keebler@warmmail.com	Topeka	Kansas	4255194311500295	9a3fce7ca3f1db725db837c3046b5ed7	Diners Club / Carte Blanche	39.0786598326105619	-95.7609738378029363
22118	2020-04-28 11:48:25	2020-04-28	Miss Patti Russel DDS	miss.patti.russel.dds@geemail.com	Raleigh	North Carolina	561293891588258	a5e8a4b74a325245f4a80a9262c310d5	JCB 15 digit	35.9078812301292984	-78.5700537351362414
22119	2020-04-28 11:50:39	2020-04-28	Dr. Jaimie Effertz	dr.jaimie.effertz@geemail.com	Berkeley	California	869953997021863868	6bce55302ef33a9edded2493deaffafe	Maestro	37.8683512406575176	-122.276128889746317
22120	2020-04-28 11:54:14	2020-04-28	Margeret Barrows	margeret.barrows@geemail.com	Fort Worth	Texas	869977458095736136	1f27ced3f40fc54d4d2192572ec57372	VISA 16 digit	32.79049427663535	-97.4292447414536014
22121	2020-04-28 12:00:43	2020-04-28	Mrs. Luz Corkery	mrs.luz.corkery@warmmail.com	Glendale	California	4515507557672526	f5987992ac6d65b82a2e986730870e29	Mastercard	34.0941504368312636	-118.16748478523381
22122	2020-04-28 12:01:53	2020-04-28	Mr. Callie Denesik	mr.callie.denesik@geemail.com	Lakeland	Florida	869936529714617129	0f4465df2ea59c84018efbde1bf11ba6	Voyager	28.0193195096515097	-81.9024808294024211
22123	2020-04-28 12:04:01	2020-04-28	Alivia Wolff	alivia.wolff@geemail.com	Escondido	California	4436795524518585	bb87398dddcfab757155873f94190e3f	American Express	33.1737054944731256	-117.018940660754211
22124	2020-04-28 12:11:27	2020-04-28	Bertie White	bertie.white@warmmail.com	Atlanta	Georgia	630472364215169	f4d8d02cfc1692ad76925021ed1424c5	Voyager	33.7666405069451798	-84.3227052405986939
22125	2020-04-28 12:12:52	2020-04-28	Mrs. Bobbi Halvorson DVM	mrs.bobbi.halvorson.dvm@geemail.com	Aurora	Illinois	3003380102791251	ed93f26cbea8f7a6097176f2c0237431	Voyager	41.8191321665178961	-88.3875546217825274
22126	2020-04-28 12:15:20	2020-04-28	Hildegarde Armstrong	hildegarde.armstrong@geemail.com	Dallas	Texas	53665624735751821	cea7e54adfd4536ebacf998dce139d39	JCB 16 digit	32.7845480862345582	-96.7657046678904322
22127	2020-04-28 12:18:39	2020-04-28	Marjorie Lebsack	marjorie.lebsack@woohoo.com	Pasadena	Texas	3158149648432569273	bd59312e3e74dbdc02c9630de3e91a79	Diners Club / Carte Blanche	29.7253450861074029	-95.1921628985501798
22128	2020-04-28 12:26:51	2020-04-28	Cletus Collier	cletus.collier@geemail.com	New York	New York	3158086084696822783	678094d1762e5ba65b471a501bb23d7d	Maestro	40.7082461095638592	-73.9291086022637813
22129	2020-04-28 12:35:52	2020-04-28	Dr. Lukas Kautzer DDS	dr.lukas.kautzer.dds@geemail.com	New York	New York	3528779716754537462	5ad9914d621c92a82cd579e999a2ccdc	VISA 16 digit	40.7106434421371688	-73.8902772592276307
22130	2020-04-28 12:45:15	2020-04-28	Vallie Williamson	vallie.williamson@geemail.com	San Francisco	California	210024470633054439	843f3ddcdecd18e0226de4d058e8b696	VISA 13 digit	37.7369908539665815	-122.444803908018017
22131	2020-04-28 12:46:08	2020-04-28	Tabitha Gislason-Dietrich	tabitha.gislason.dietrich@geemail.com	Berkeley	California	55360874428668372	58d63c3a108d8df806b3afd71bbc3239	JCB 16 digit	37.8465676117217527	-122.267909651308514
22132	2020-04-28 13:05:49	2020-04-28	Latoya Huels	latoya.huels@geemail.com	Manchester	New Hampshire	6011628364695040248	a6aff662243abd017327796b70039a4e	American Express	42.9454444276705445	-71.4775774818737091
22133	2020-04-28 13:40:45	2020-04-28	Odelia Osinski-Wiegand	odelia.osinski.wiegand@warmmail.com	Modesto	California	3709316389225450	589f9689ab9ca706495af6b83e8a9ce5	Diners Club / Carte Blanche	37.53830883079209	-121.011946838881826
22134	2020-04-28 13:56:38	2020-04-28	Azalee Huel	azalee.huel@warmmail.com	Surprise	Arizona	3158894696358431314	f241cd1e86a78ad6722fed1a61a7b790	American Express	33.7696534374490369	-112.369405041611557
22135	2020-04-28 14:08:03	2020-04-28	Amos Roob	amos.roob@geemail.com	Tulsa	Oklahoma	3337702781297754745	370e66c12aa35437c752160877db2a81	VISA 13 digit	36.1178611623026384	-95.9209444477178153
22136	2020-04-28 14:13:33	2020-04-28	Miss Kanisha Green DDS	miss.kanisha.green.dds@geemail.com	Overland Park	Kansas	502036295452399	e11e5484f8190608d44e0d7cc3c6c473	Maestro	38.931558643361555	-94.6909342573996611
22137	2020-04-28 14:40:04	2020-04-28	Press Macejkovic	press.macejkovic@geemail.com	West Valley City	Utah	3528308370048812388	a4e452c4081ebf930040da6f8f4ee4bd	Discover	40.6617237713411441	-111.99916798525787
22138	2020-04-28 14:42:09	2020-04-28	Mrs. Monique Welch MD	mrs.monique.welch.md@geemail.com	San Francisco	California	589335412615128	e5c82299d0122a5ac5e2f6c994b9cfe3	Discover	37.7919298534038859	-122.443848273775089
22139	2020-04-28 14:44:53	2020-04-28	Leslie Luettgen	leslie.luettgen@geemail.com	El Paso	Texas	4138686255377849	fd684aafc838386838b171b2b2737d99	JCB 15 digit	31.9359936559867137	-106.350958613444121
22140	2020-04-28 14:44:58	2020-04-28	Mr. Braden Conroy DVM	mr.braden.conroy.dvm@geemail.com	Oakland	California	4297009621748659	8f2baef73a83f3cce6d9f0ee9d96a561	VISA 16 digit	37.7771791934883225	-122.261248532227768
22141	2020-04-28 14:49:29	2020-04-28	Ammon Hamill II	ammon.hamill.ii@geemail.com	Albuquerque	New Mexico	3088853055470263510	5113cddf088688c1177ccd94ed246f6b	VISA 16 digit	35.1357956522278485	-106.672604372545706
22142	2020-04-28 14:51:18	2020-04-28	Daryle Breitenberg-Shields	daryle.breitenberg.shields@woohoo.com	Augusta	Georgia	6011880627926724308	c2b584fffee44ffdfa3bf31fb87db036	JCB 16 digit	33.3268755376543808	-81.9861772352192588
22143	2020-04-28 14:52:01	2020-04-28	Edward Lesch	edward.lesch@geemail.com	High Point	North Carolina	3096277124031155512	631c7fea45a93aeb421132e52e22573e	Maestro	35.9002242481894811	-79.9642332390155559
22144	2020-04-28 15:01:37	2020-04-28	Patrica Cartwright	patrica.cartwright@geemail.com	Houston	Texas	869902638719967858	b1d7202d680ddd2a9f86d4827c6a6009	VISA 13 digit	29.7702962468922152	-95.4236397832647043
22145	2020-04-28 15:13:32	2020-04-28	Lurana Runte	lurana.runte@geemail.com	Chesapeake	Virginia	589336067533939	5d1fae0ab97b4576e558309b0e273a07	Maestro	36.7633492694940429	-76.2551592320512981
22146	2020-04-28 15:26:09	2020-04-28	Cass Lind-Carter	cass.lind.carter@geemail.com	Dallas	Texas	4781555438444	2fa23a9e0dc72929691498f79eed9fd6	JCB 16 digit	32.8575836041748559	-96.7387079354803916
22147	2020-04-28 15:38:20	2020-04-28	Garret Jerde	garret.jerde@woohoo.com	Montgomery	Alabama	4011308540704	2a70e5fffcba7a2a6686230e87d1686e	JCB 16 digit	32.3503719420570874	-86.3210488564021858
22148	2020-04-28 15:41:30	2020-04-28	Wende Stehr	wende.stehr@geemail.com	Oakland	California	54233733109776125	d089811294ff1667dc2a74ea32a19dfc	Mastercard	37.8103280718545065	-122.281491519049382
22149	2020-04-28 15:46:55	2020-04-28	Beecher Heller	beecher.heller@geemail.com	Las Vegas	Nevada	6011869651831125240	9815ad19194c1e75e497c2121879cc6f	American Express	36.1819058819308879	-115.301847961705548
22150	2020-04-28 16:07:35	2020-04-28	Kaylie Hills	kaylie.hills@geemail.com	Coral Springs	Florida	54098036511753144	5050766d4b892365802ac6f3a3289af8	JCB 15 digit	26.1997071858093165	-80.2952043997246676
22151	2020-04-28 16:07:38	2020-04-28	Mr. Elzie Douglas	mr.elzie.douglas@geemail.com	Oakland	California	3096644166190221029	1c26901ecd5e3560ea378ad1ae860310	Diners Club / Carte Blanche	37.8246640962177167	-122.283274123496469
22152	2020-04-28 16:16:31	2020-04-28	Deborrah Funk DDS	deborrah.funk.dds@geemail.com	Atlanta	Georgia	4332444762841509	43b0276ef3ccd855678273e1aebcbfbf	JCB 15 digit	33.6707467476181677	-84.4154124420646639
22153	2020-04-28 16:25:28	2020-04-28	Keifer Metz	keifer.metz@geemail.com	Santa Ana	California	6011516379480928899	9c732c4be01039569ec3636ffa971551	VISA 16 digit	33.6745248509675292	-117.866456355379896
22154	2020-04-28 16:25:43	2020-04-28	Mrs. Rosemary Jacobs	mrs.rosemary.jacobs@geemail.com	Philadelphia	Pennsylvania	4035773349259	fccebb85cf09a36dec3f5e3d35397de4	JCB 15 digit	40.1044553710572416	-75.2108354031473425
22155	2020-04-28 16:27:51	2020-04-28	Almus Casper	almus.casper@geemail.com	Buffalo	New York	869951698678004333	cbe32d64429297d7de536396bef6ff88	JCB 16 digit	42.834987092735247	-78.8584586475908793
22156	2020-04-28 16:49:32	2020-04-28	Colton Rosenbaum	colton.rosenbaum@geemail.com	Palmdale	California	869984441926817763	f427573b9398925fe7d1ffd5710e36fc	VISA 16 digit	34.5942462411560143	-118.035007197316361
22157	2020-04-28 17:13:40	2020-04-28	Lillianna Rolfson-Kling	lillianna.rolfson.kling@geemail.com	New York	New York	3158817036501201450	16ccd7d7fea7f235c041b3a87bef0c47	JCB 16 digit	40.6561319731865041	-73.9352837030205876
22158	2020-04-28 17:17:06	2020-04-28	Jules Schulist	jules.schulist@geemail.com	San Francisco	California	3055010803322365	67b7069f7b4e1a014ab15da7edc0bc17	Discover	37.7687057751930553	-122.40640503652088
22159	2020-04-28 17:35:28	2020-04-28	Georgette Bradtke	georgette.bradtke@warmmail.com	Chesapeake	Virginia	060481636937195	e648be7b5e9faae7b01adb0a4610800e	VISA 16 digit	36.727789546666294	-76.3554950372625143
22160	2020-04-28 17:47:05	2020-04-28	Aylin Schmeler-O'Keefe	aylin.schmeler.o'keefe@geemail.com	Gilbert	Arizona	3528542461660813063	f8798352b026f83a450e5656e39b92a2	JCB 16 digit	33.3786821293525406	-111.675125523530312
22161	2020-04-28 17:48:37	2020-04-28	Ragna Witting	ragna.witting@warmmail.com	Warren	Michigan	3158814389789272310	52f5685a165ffd2d02795406aba4af5a	JCB 16 digit	42.4802936820309611	-83.0518505165819079
22162	2020-04-28 17:49:24	2020-04-28	Reta Batz	reta.batz@geemail.com	Greensboro	North Carolina	4531473010662	e80aaf1d02bd95399ef1baefcac58dd4	Mastercard	36.0693892507929377	-79.9160844664070709
22163	2020-04-28 17:49:56	2020-04-28	Alayna Rowe	alayna.rowe@geemail.com	Orlando	Florida	55186105992019060	617e18bbfac8bb29c7bb719be074e231	VISA 16 digit	28.4681560444444415	-81.2860835564754893
22164	2020-04-28 18:04:32	2020-04-28	Malvina Dare	malvina.dare@geemail.com	Chandler	Arizona	869922044130741020	9217bc7cd22d41cc86c82991644e70ed	JCB 16 digit	33.2170174727771439	-111.896537992300097
22165	2020-04-28 18:21:49	2020-04-28	Leatrice Kirlin-O'Kon	leatrice.kirlin.o'kon@geemail.com	Austin	Texas	3042984685300975	0f5ebb37e703a7b4fecf94f57ac5cade	Maestro	30.2947010113984341	-97.8103297284577025
22166	2020-04-28 18:36:16	2020-04-28	Palmer King	palmer.king@geemail.com	Virginia Beach	Virginia	3008936678421212	aeaa39b475cd214037f5ed6c112c760e	JCB 15 digit	36.6872929640300569	-75.9662029082559087
22167	2020-04-28 18:40:59	2020-04-28	Hillary Dare MD	hillary.dare.md@geemail.com	San Antonio	Texas	6011493170809063972	aa77fb7fb864a53b4898710904ffeae3	VISA 13 digit	29.4637717728108157	-98.427444446349881
22168	2020-04-28 18:41:40	2020-04-28	Deacon Schmidt PhD	deacon.schmidt.phd@woohoo.com	Green Bay	Wisconsin	4786061984161	f6190b8b6449a5f70429e3feb29e0659	VISA 16 digit	44.5241879307728254	-88.0421715490806918
22169	2020-04-28 18:47:17	2020-04-28	Edward Feest-Wuckert	edward.feest.wuckert@geemail.com	El Paso	Texas	4642724547222793	4d46fe501c3669df8e8351f6b89fb60b	JCB 16 digit	31.7547542228657775	-106.391517360739414
22170	2020-04-28 19:00:58	2020-04-28	Reatha Rutherford DVM	reatha.rutherford.dvm@woohoo.com	New York	New York	3337702432254162114	2e882df18ecb9b07de8e2f800726316c	Diners Club / Carte Blanche	40.7136812254544367	-73.9022372145101372
22171	2020-04-28 19:13:40	2020-04-28	Betty Trantow-Stiedemann	betty.trantow.stiedemann@woohoo.com	Phoenix	Arizona	3112152334770833977	7cd88cf4e745e7cc15d9f1c665f2c272	VISA 16 digit	33.5902044294334985	-112.095885025423399
22172	2020-04-28 19:15:00	2020-04-28	Kaitlynn Beatty	kaitlynn.beatty@geemail.com	Atlanta	Georgia	6011078428882108475	3da039a4142f4b3fa935169ef9fbe68e	Discover	33.6744867342799949	-84.4172598542224648
22173	2020-04-28 19:19:35	2020-04-28	Fed Prosacco	fed.prosacco@warmmail.com	Philadelphia	Pennsylvania	4068443046166147	4de2b519732511e48ccae1ca68eb9dea	JCB 15 digit	40.0437666855711498	-75.1138267239920907
22174	2020-04-28 19:20:38	2020-04-28	Dr. Rowland Gusikowski II	dr.rowland.gusikowski.ii@geemail.com	Los Angeles	California	4013493969486770	450b35e62b6ba9ca0605cba7054e7b3a	Mastercard	34.1133763586968186	-118.436338885500277
22175	2020-04-28 19:24:31	2020-04-28	Lydell Durgan-Feeney	lydell.durgan.feeney@woohoo.com	New York	New York	060447193182335	926f71a2718223e1da669fbddb4f6a82	Diners Club / Carte Blanche	40.6133994166962822	-73.9877059618838047
22176	2020-04-28 19:40:34	2020-04-28	Patience Lang	patience.lang@geemail.com	San Francisco	California	869940522888490799	257174aff9ab8cd1753146e857fcc0ff	American Express	37.8027872397958333	-122.428923964616402
22177	2020-04-28 20:19:31	2020-04-28	Adria Wehner	adria.wehner@geemail.com	Kansas City	Missouri	4466458812560	9e5cb66985dd9f5142b8d7fff133b123	JCB 16 digit	39.0357782788410788	-94.6433842051066421
22178	2020-04-28 20:21:03	2020-04-28	Mariana Schiller	mariana.schiller@geemail.com	Corpus Christi	Texas	869942547685822611	32491abc5126ee767f7f682d7d2acdba	JCB 16 digit	27.7118486540794393	-97.2415010455358839
22179	2020-04-28 20:23:51	2020-04-28	Odie Zulauf	odie.zulauf@warmmail.com	Chicago	Illinois	180056954068474999	47a0c7fb90a82109fa886ebb5c3426cb	JCB 15 digit	41.9293888090945828	-87.7813479612611189
22180	2020-04-28 20:26:59	2020-04-28	Dianna Feil	dianna.feil@geemail.com	Oakland	California	869965201785716883	11c8e0ed0644b94e883a8f2f9171a449	Maestro	37.7989493429534846	-122.238409986144987
22181	2020-04-28 20:30:23	2020-04-28	Nichol Dooley	nichol.dooley@geemail.com	Port St. Lucie	Florida	4064171619928148	bd64b54be6add16761e9f69cf75206dc	VISA 13 digit	27.3444157716020939	-80.4356592912778297
22182	2020-04-28 20:33:00	2020-04-28	Emmaline Turner	emmaline.turner@geemail.com	San Francisco	California	4269702821704	254774728a0c4787ebd5f348082115af	JCB 16 digit	37.7807612138771063	-122.440456859810155
22183	2020-04-28 20:50:31	2020-04-28	Dr. Giovani Brakus DDS	dr.giovani.brakus.dds@woohoo.com	Charlotte	North Carolina	4435137104277	940826f6e79bcd6beb53c890a9c63d1a	JCB 16 digit	35.219957917022704	-80.8740141280870972
22184	2020-04-28 21:00:07	2020-04-28	Leland Eichmann-Williamson	leland.eichmann.williamson@geemail.com	Aurora	Illinois	3158381345320623562	28cd6c42c63105c451da0abc29898ce9	JCB 16 digit	41.7623504620734636	-88.2476893207918778
22185	2020-04-28 21:00:57	2020-04-28	Linus Cole	linus.cole@geemail.com	Plano	Texas	3444429485638802	af0c9f289d134458c4302ebb6a3a6419	VISA 16 digit	33.0329015957277292	-96.7510718759331922
22186	2020-04-28 21:08:21	2020-04-28	Stuart Marquardt	stuart.marquardt@woohoo.com	Sandy Springs	Georgia	4991198439981278	8ed002a9c16759790a55652a0a633df7	Mastercard	33.9419203980416029	-84.2953933870036138
22187	2020-04-28 21:12:42	2020-04-28	Norman Jakubowski MD	norman.jakubowski.md@geemail.com	Houston	Texas	3528487067423202176	ff64e6075c70f27b29d16272bb26b040	Mastercard	29.847279526487366	-95.4427067799042987
22188	2020-04-28 21:16:14	2020-04-28	Zayne Barrows	zayne.barrows@geemail.com	San Francisco	California	52730162988287772	b703a08358bed7fc009650c3d314e9cb	Voyager	37.7475246053015638	-122.427764868248744
22189	2020-04-28 21:18:59	2020-04-28	Marcell Kohler	marcell.kohler@geemail.com	Oakland	California	3337874132174113112	f8d91596398900b65e60fe5144a7f95f	JCB 16 digit	37.8348832584557684	-122.243627596327059
22190	2020-04-28 21:20:54	2020-04-28	Liza Bernier	liza.bernier@geemail.com	Nashville	Tennessee	4319088324821439	cd231fc51043aa19014e7c4863ea9a7e	VISA 13 digit	36.2626583119977255	-86.7289806041773375
22191	2020-04-28 21:38:23	2020-04-28	Reilly Koss	reilly.koss@woohoo.com	Aurora	Colorado	3008092059333087	0af61eec27e11744b35c3bdc251c3b03	VISA 16 digit	39.6379482199549713	-104.597305236163365
22192	2020-04-28 21:45:57	2020-04-28	Shannen Rau	shannen.rau@geemail.com	Tyler	Texas	3700397985022417	b70045e2a726e465d4b095643110e39f	JCB 16 digit	32.286338057792932	-95.2798476056303798
22193	2020-04-28 21:46:56	2020-04-28	Roddy Schinner	roddy.schinner@geemail.com	Gilbert	Arizona	3722514445898251	d87381ec0da7a085c8d0c859629f1e9c	VISA 16 digit	33.3346405224289697	-111.79347314104848
22194	2020-04-28 22:18:29	2020-04-28	Nels Heathcote-Block	nels.heathcote.block@geemail.com	Berkeley	California	502072309963154	1eb14701672351fdd3c36ba77477231e	JCB 16 digit	37.8708696369803164	-122.271872044213993
22195	2020-04-28 22:23:30	2020-04-28	Derl Torp	derl.torp@geemail.com	Springfield	Massachusetts	3088898092871479533	e6a6ec0a981877c7fe656e7954686746	Diners Club / Carte Blanche	42.2125092868432361	-72.5228272460959857
22196	2020-04-28 22:25:46	2020-04-28	Regan Grimes	regan.grimes@warmmail.com	San Diego	California	180035399383659989	a5f63559082131710026d143021eaf92	VISA 16 digit	32.8092496196340804	-117.156201643859973
22197	2020-04-28 22:28:18	2020-04-28	Brantley Carter	brantley.carter@geemail.com	Nashville	Tennessee	4272086371205	93be5457d067c276b5be51f444e46e6c	Maestro	36.1077678547363732	-86.8158356296736713
22198	2020-04-28 22:39:33	2020-04-28	Tillman Rippin	tillman.rippin@geemail.com	Gresham	Oregon	180060475384928223	0cd4467e18cbe0f374f7cee323850ca1	VISA 16 digit	45.572536129406835	-122.412118352231005
22199	2020-04-28 22:47:06	2020-04-28	Ellyn Dibbert	ellyn.dibbert@geemail.com	Reno	Nevada	630403362627493	a55186df177be2d82072bc8f3c5816a5	JCB 16 digit	39.6180586868044031	-119.944293898965796
22200	2020-04-28 22:47:23	2020-04-28	Susann Beer	susann.beer@geemail.com	Midland	Texas	210086472434268189	2b5c9e9e706a22916818d561737685c5	American Express	32.0573364237979064	-102.205243093403055
22201	2020-04-28 22:53:51	2020-04-28	Makai Metz	makai.metz@geemail.com	New York	New York	4825452773904871	aaa6349f6baabb97e0ca1f0e6e57c213	Voyager	40.6159217078927881	-73.9941671284742597
22202	2020-04-28 23:12:22	2020-04-28	Treyton Nader	treyton.nader@geemail.com	Garland	Texas	6011574302117759080	79ac4f017b5052165e67eb3b495ab79c	JCB 15 digit	32.9406581878431126	-96.6148438223797825
22203	2020-04-28 23:23:48	2020-04-28	Yandel Robel	yandel.robel@geemail.com	San Francisco	California	4041003370180270	4a6b6dc0ab8490d03a08a23aa9b33050	JCB 16 digit	37.7656053600556874	-122.43130646556375
22204	2020-04-28 23:26:10	2020-04-28	Ula Sanford	ula.sanford@geemail.com	Rockford	Illinois	060480782847695	44be7ab62a52217580c39f78a1aacf46	Voyager	42.2598305163916237	-89.0834025139272256
22205	2020-04-28 23:29:03	2020-04-28	Freeda Hahn	freeda.hahn@geemail.com	San Francisco	California	3472720092623392	c6581d86252a114b4224f16f284469b3	Voyager	37.7814948740367456	-122.42368031128396
22206	2020-04-28 23:29:22	2020-04-28	Thomas Murphy	thomas.murphy@geemail.com	Waterbury	Connecticut	502045130355287	6dc36b6bd13109d8fc61ade0e9cb2f13	JCB 16 digit	41.5686459167432076	-73.0021176033101966
22207	2020-04-28 23:43:08	2020-04-28	Aretha Boehm	aretha.boehm@geemail.com	Berkeley	California	4151943317009510	d1608ee95581adb4c46c98a9e3c5b9c8	Maestro	37.9005727443329548	-122.268158588198787
22208	2020-04-28 23:45:40	2020-04-28	Tre Schuster	tre.schuster@woohoo.com	Fremont	California	869907562166036550	61436ea674904eb85bc0e56432ce1750	JCB 15 digit	37.5278215682301663	-121.861357655188812
22209	2020-04-29 00:02:49	2020-04-29	Miss Kalyn Eichmann DDS	miss.kalyn.eichmann.dds@geemail.com	San Francisco	California	630446652332324	4462c1bf392546b041089619e3ae3118	VISA 13 digit	37.7613812090722831	-122.451249972327531
22210	2020-04-29 00:03:31	2020-04-29	Jasper Rogahn	jasper.rogahn@woohoo.com	Kansas City	Missouri	4334505386741	9da85c4bdf171b5e68ac9e591532f280	JCB 16 digit	39.1285970508422736	-94.464059760257598
22211	2020-04-29 00:32:56	2020-04-29	Clark Schumm	clark.schumm@woohoo.com	San Jose	California	4834143621284082	15c9418140e48647e4710acb144b9823	American Express	37.3863017209161086	-121.849195463604858
22212	2020-04-29 00:38:27	2020-04-29	Gasper Rogahn	gasper.rogahn@geemail.com	Sterling Heights	Michigan	4895665358498	876456173f58a82d31fab1458e42fc34	American Express	42.6535800501320566	-83.0582778938274799
22213	2020-04-29 00:40:01	2020-04-29	Vinson Ryan II	vinson.ryan.ii@geemail.com	Eugene	Oregon	3712965354000713	26c3f38c686d9b8db3789d24b178de20	JCB 16 digit	44.0747426696781091	-123.100605003255239
22214	2020-04-29 00:41:58	2020-04-29	Dr. Westley Rowe II	dr.westley.rowe.ii@geemail.com	San Francisco	California	4593768158714985	479bef91c185b840a6c56c8c1108d29e	Voyager	37.7396820812590832	-122.464439493131621
22215	2020-04-29 00:57:58	2020-04-29	Landin McDermott	landin.mcdermott@geemail.com	Saint Paul	Minnesota	3046819156556786	eed3fe6e165e3cbcea6dc65e84dcb016	JCB 16 digit	44.8555017529927227	-93.1954835851475565
22216	2020-04-29 01:04:22	2020-04-29	German Romaguera	german.romaguera@geemail.com	Minneapolis	Minnesota	3001489968921712	eff326659842e89f381ebf202986fa4e	Voyager	45.0262393188748504	-93.3644662237532401
22217	2020-04-29 01:04:26	2020-04-29	Ms. Eliza Mueller	ms.eliza.mueller@geemail.com	Peoria	Arizona	869960137858298539	3910e768d0b1ed73af795b5dbabe8b62	American Express	33.7779327663395534	-112.325762639746074
22218	2020-04-29 01:24:20	2020-04-29	Jedediah Schmidt	jedediah.schmidt@geemail.com	Miramar	Florida	3112684935345057970	5348e5cd312a8e49bd553c582d0d3a4a	JCB 16 digit	26.0153152636233713	-80.4355651723679159
22219	2020-04-29 01:25:11	2020-04-29	Julien Padberg	julien.padberg@woohoo.com	Milwaukee	Wisconsin	180049260060860296	e405679ed2527370ca80a602ecd315af	VISA 13 digit	43.0858459042936559	-87.920962035479775
22220	2020-04-29 01:37:17	2020-04-29	Nona O'Kon	nona.o'kon@geemail.com	New York	New York	3158021898738416694	0065edef1bc0044ef3f42eee8eb11996	Diners Club / Carte Blanche	40.5930489841606459	-74.011105594913289
22221	2020-04-29 01:46:41	2020-04-29	Dustan Hane	dustan.hane@woohoo.com	Seattle	Washington	55876996151306446	01b24b8479ef9fe85ebcc0887c844469	Discover	47.5364045856911659	-122.432408542736994
22222	2020-04-29 01:57:22	2020-04-29	Elgie Dooley	elgie.dooley@geemail.com	Portland	Oregon	4027743779769631	e4fe3b59e2307d90c1a947b847fc9993	Discover	45.5217670157439969	-122.623901282064622
22223	2020-04-29 01:57:47	2020-04-29	Mrs. Elza Homenick PhD	mrs.elza.homenick.phd@geemail.com	San Antonio	Texas	4481244524764299	aebfa3a9da9fefe3f3f4e9f74f00f91b	VISA 13 digit	29.3810342195048939	-98.5248880744282047
22224	2020-04-29 01:59:40	2020-04-29	Gaines Donnelly-Bergstrom	gaines.donnelly.bergstrom@geemail.com	Torrance	California	3726744605835084	fc7acd513e8ed3455432d2da1ca83d24	JCB 15 digit	33.7374851529393354	-118.397085957381492
22225	2020-04-29 02:02:51	2020-04-29	Laci Kling-Schuppe	laci.kling.schuppe@geemail.com	Des Moines	Iowa	6011400821747503170	be4eb1c544d90a767e13fc6ef8220924	VISA 13 digit	41.4950572784733041	-93.6172834538433705
22226	2020-04-29 02:15:00	2020-04-29	Octave Daniel-Hackett	octave.daniel.hackett@warmmail.com	Oakland	California	6011642189438686623	3915342ec729e585b97bd2d0333d2d26	Discover	37.8139099423972809	-122.262954938045311
22227	2020-04-29 02:20:05	2020-04-29	Artelia Tremblay PhD	artelia.tremblay.phd@geemail.com	Berkeley	California	3088270687616647225	58c10fa535ebd8fff4b047374c23b251	Voyager	37.855414304640334	-122.32885531476127
22228	2020-04-29 02:48:49	2020-04-29	Seth Dare	seth.dare@warmmail.com	San Francisco	California	502075838278952	0ae51eaa80156b039360d34afc69038a	VISA 13 digit	37.7698152878737261	-122.404279562990325
22229	2020-04-29 02:49:49	2020-04-29	Miss Regena Leuschke	miss.regena.leuschke@geemail.com	New York	New York	869971653799624846	121c3798d4279cb5493026de9e64a225	Maestro	40.5810728882662914	-73.9885215297702672
22230	2020-04-29 02:55:39	2020-04-29	Lon Weber DDS	lon.weber.dds@geemail.com	Renton	Washington	4576831759260	8c9d0daf19f6b19b46dbb62cd2e7cdd5	JCB 15 digit	47.3793194325234737	-122.266049312155687
22231	2020-04-29 03:07:16	2020-04-29	Mrs. Blanch Stamm PhD	mrs.blanch.stamm.phd@warmmail.com	Everett	Washington	3758316663564350	cedc06155113295f1e289f1ea36f1354	VISA 13 digit	47.8974256149385127	-122.125966225390883
22232	2020-04-29 03:13:22	2020-04-29	Godfrey Reinger	godfrey.reinger@woohoo.com	Chicago	Illinois	3528559005709479988	61363e904726652eb77eec286a5110a7	JCB 16 digit	41.8719074573203969	-87.7327204423520612
22233	2020-04-29 03:16:57	2020-04-29	Isham Sauer-Okuneva	isham.sauer.okuneva@geemail.com	Houston	Texas	3028447517803545	53d2ef9df8b46af62be48ba42569cd61	VISA 13 digit	29.768583908498659	-95.4003373153988292
22234	2020-04-29 03:19:53	2020-04-29	Lacy Gerlach	lacy.gerlach@geemail.com	Houston	Texas	869939591360506862	a9be7927d0e23984849cdc4052aa4bbd	Maestro	29.7653390647456035	-95.3911689925953823
22235	2020-04-29 03:21:49	2020-04-29	Jimmie D'Amore	jimmie.d'amore@woohoo.com	Los Angeles	California	503806849895419	bbc64b24d68bc17f89a3029cf96ec66b	Discover	33.9265697758045022	-118.386399297648296
22236	2020-04-29 03:32:19	2020-04-29	Russ Donnelly	russ.donnelly@warmmail.com	Port St. Lucie	Florida	4427734548634	eeee594c680c8a8e4fee196383966c71	VISA 16 digit	27.3256311726424848	-80.4833426214374583
22237	2020-04-29 03:33:16	2020-04-29	Selina Adams	selina.adams@geemail.com	Little Rock	Arkansas	4695927271854337	440a637e655c487ba7b195a33c5cf6ba	Diners Club / Carte Blanche	34.7076585482615982	-92.2708328494675385
22238	2020-04-29 03:38:19	2020-04-29	Angelina Hilll	angelina.hilll@geemail.com	Frisco	Texas	6011736314266269659	4f9faf30c1d267a5aaf4bae82348f23d	Mastercard	33.2425238853782403	-96.7531513980332676
22239	2020-04-29 03:40:43	2020-04-29	Roby Jast-Kilback	roby.jast.kilback@geemail.com	Greensboro	North Carolina	4598741213173583	165c384515cf9f50e0c48819aa674210	Discover	36.0888891080044232	-79.8067558785881772
22240	2020-04-29 03:45:11	2020-04-29	Marci Bogisich	marci.bogisich@geemail.com	Fresno	California	3528120892277307141	4784b9c478fc4910991696c547c721c6	Mastercard	36.8575878741558611	-119.705248136875781
22241	2020-04-29 03:45:12	2020-04-29	Orren Bergstrom	orren.bergstrom@woohoo.com	Cleveland	Ohio	180006567650977103	75039daf2f905a3f491f8ddf88c9a703	Voyager	41.4058714064620403	-81.5939583858713462
22242	2020-04-29 03:54:07	2020-04-29	Mr. Manly Ruecker	mr.manly.ruecker@geemail.com	Oakland	California	3112547927249708060	27b4250a8430bc14dbc68c5b60d9eb96	VISA 16 digit	37.8317492489540399	-122.272695760839142
22243	2020-04-29 04:05:18	2020-04-29	Ms. Iyana Veum DDS	ms.iyana.veum.dds@geemail.com	El Paso	Texas	4565743724751	a0cd9bcaf08f03a07a0288402401e74b	Maestro	31.7743443234186635	-106.464369426572702
22244	2020-04-29 04:34:08	2020-04-29	River Emard-Blick	river.emard.blick@geemail.com	San Diego	California	869921185950461321	c6d79e44ec0e35ac5ba1ff23297cd2c3	VISA 16 digit	32.7161640640415285	-117.220570751223718
22245	2020-04-29 04:43:14	2020-04-29	Burl Schumm Jr.	burl.schumm.jr.@geemail.com	Philadelphia	Pennsylvania	51314023079606045	eae060356feff0a5368ce7023039ef04	American Express	40.0854856162291	-75.1412653153661694
22246	2020-04-29 04:48:39	2020-04-29	Virgie Conroy	virgie.conroy@geemail.com	Fort Wayne	Indiana	6011041288244787224	4deb6e1ec4ea85e82addaad2e1812ff2	JCB 16 digit	41.0401836517982161	-85.2367681295365145
22247	2020-04-29 04:59:36	2020-04-29	Amari Gleichner	amari.gleichner@geemail.com	Cincinnati	Ohio	060428062113601	ce02c6d5292924bb2af145c93da719a2	VISA 13 digit	39.0409694636005895	-84.4820358176521893
22248	2020-04-29 05:23:14	2020-04-29	Rollin Howe	rollin.howe@geemail.com	San Francisco	California	4296801623938481	3531326a8c81c09cd61f80431a10b12b	JCB 15 digit	37.7672595416878565	-122.438592264640633
22249	2020-04-29 05:46:26	2020-04-29	Sheryl Hermann	sheryl.hermann@geemail.com	Springfield	Illinois	6011731714292148378	072c0e7aa37e2bc3da4613ae6b6c133e	Voyager	39.7592335193570676	-89.5492309702564029
22250	2020-04-29 05:53:14	2020-04-29	Ronin Block-Dare	ronin.block.dare@geemail.com	Madison	Wisconsin	503831770287667	d777654e93d6c963f60a9c10cedd3887	Diners Club / Carte Blanche	43.0652014383554445	-89.3649706923287397
22251	2020-04-29 05:53:48	2020-04-29	Aubree Jenkins PhD	aubree.jenkins.phd@woohoo.com	Waterbury	Connecticut	51219042370624800	bc14011a2bb789bfe17106f991ddd54b	JCB 16 digit	41.5987205433696516	-73.1342426077377041
22252	2020-04-29 06:29:30	2020-04-29	Tracey Kilback-Wisoky	tracey.kilback.wisoky@woohoo.com	Cedar Rapids	Iowa	6011468827580674191	84c703a2c16cd9c550e9768100d66b5d	JCB 16 digit	42.0345401950720685	-91.7137115690458558
22253	2020-04-29 06:41:53	2020-04-29	Hermon Muller	hermon.muller@geemail.com	San Francisco	California	210089305630931399	e0deb3235f6e2ce95a108b79c57775c1	VISA 16 digit	37.7733736453354183	-122.419228505019873
22254	2020-04-29 06:46:28	2020-04-29	Deandre Renner DVM	deandre.renner.dvm@woohoo.com	Tulsa	Oklahoma	4624136118019197	c1c3c2b8dca9387c2108c05c05036a91	Discover	36.1166383615132389	-95.9865988334596096
22255	2020-04-29 06:51:07	2020-04-29	Misti Muller	misti.muller@woohoo.com	San Diego	California	180083279776906380	0bc7ced99630fd2eba1c5fb13c7d8a6d	JCB 16 digit	32.8187627547487608	-117.218745225751775
22256	2020-04-29 07:02:02	2020-04-29	Izayah Homenick	izayah.homenick@warmmail.com	Fontana	California	4828548819253	01bb5fae89976efd610823bbdab83696	VISA 13 digit	34.08880998391286	-117.454866981999587
22257	2020-04-29 07:16:49	2020-04-29	Levern Konopelski	levern.konopelski@geemail.com	Denver	Colorado	180058309844071510	a92cb7e57a85110ea2963ae6ffb24866	JCB 16 digit	39.7492972185421678	-104.810276491033292
22258	2020-04-29 07:17:10	2020-04-29	Audrianna Gleichner	audrianna.gleichner@geemail.com	San Francisco	California	3004565697435111	8ee3634ede696bc964dc91a433cd3154	Discover	37.7905111979666799	-122.436198374251973
22259	2020-04-29 07:34:04	2020-04-29	Ms. Paris Batz	ms.paris.batz@warmmail.com	Washington	District of Columbia	3022302496543438	2f6b2bee7e865eac597f17c0ec0f7556	Voyager	38.8174167284075153	-76.921953228323531
22260	2020-04-29 07:36:36	2020-04-29	Hayden Wiza	hayden.wiza@geemail.com	New York	New York	3703934858644195	a9acbe2395641a853e457a50ac584a0e	Voyager	40.7275380648896075	-73.8429778652161275
22261	2020-04-29 07:37:58	2020-04-29	Hilliard Upton-Jacobs	hilliard.upton.jacobs@geemail.com	Richmond	Virginia	3782063665501945	6d0db5f91355380f1efae2f53916fe48	VISA 13 digit	37.5883707649759913	-77.573469115769484
22262	2020-04-29 07:41:03	2020-04-29	Mathilda Osinski	mathilda.osinski@woohoo.com	Burbank	California	210042772579354253	d80cb35022d3aca220c6786f7c864ac9	Mastercard	34.2093371650133307	-118.336740484650818
22263	2020-04-29 07:44:23	2020-04-29	Susana Koepp	susana.koepp@geemail.com	Los Angeles	California	4440285685472958	59f1430830161cb507449d15aa61b677	Discover	34.0714560473669295	-118.399550121928741
22264	2020-04-29 07:54:16	2020-04-29	Jacky Emard	jacky.emard@geemail.com	Victorville	California	869955933386782441	cb48a1f0f1feb191fdcedcec0dca145f	JCB 15 digit	34.4482646241083756	-117.303132594671467
22265	2020-04-29 08:01:36	2020-04-29	Matteo Zemlak-Kiehn	matteo.zemlak.kiehn@geemail.com	Reno	Nevada	4605279059774	27973b8140502525c59ecc44a4fc8f31	Voyager	39.4844097356390265	-119.923661821119126
22266	2020-04-29 08:25:05	2020-04-29	Tonda Bosco	tonda.bosco@geemail.com	Wilmington	North Carolina	55092248936456007	7e957f859021acf8aca41dcd7ec663c0	VISA 13 digit	34.2885018102180226	-77.9484596914138734
22267	2020-04-29 08:33:04	2020-04-29	Nobie Emard	nobie.emard@geemail.com	Cincinnati	Ohio	3112205264743068889	947733f6ec68bae34a607531c95f1230	Discover	39.2343286250948893	-84.516812274399399
22268	2020-04-29 08:33:07	2020-04-29	Myrta Haley	myrta.haley@geemail.com	Hollywood	Florida	3096518540965686421	35d0a899dc31ce9d680098603104ea47	JCB 16 digit	26.0928406414054308	-80.1627402839068282
22269	2020-04-29 08:42:59	2020-04-29	Rachael Koepp-Mosciski	rachael.koepp.mosciski@geemail.com	Boston	Massachusetts	180072824287772319	2d416bd6db4a1d939b39983f1783a7df	Mastercard	42.427493843546138	-70.9876306191969633
22270	2020-04-29 08:57:16	2020-04-29	Ofelia Schoen	ofelia.schoen@geemail.com	Chicago	Illinois	4042126460488730	90205d4ee1ecaca2816de22599ebc1d9	Maestro	41.8230578158818176	-87.7789558959223228
22271	2020-04-29 09:07:52	2020-04-29	Myrta Flatley	myrta.flatley@woohoo.com	San Francisco	California	3042146680213062	1999f6afffd65ab12dd00ced1e4985e0	VISA 13 digit	37.7693622765728492	-122.427462271830478
22272	2020-04-29 09:27:46	2020-04-29	Evander Russel IV	evander.russel.iv@geemail.com	Springfield	Illinois	4823401329071448	31e81615f7f66143bf40ee93eb2a6e2e	VISA 16 digit	39.7296689903050648	-89.7123252914756506
22273	2020-04-29 09:41:25	2020-04-29	Electa Mayer	electa.mayer@woohoo.com	Philadelphia	Pennsylvania	3528652726357099101	c31c9351dd1cc82315afb62d370ac3ff	VISA 13 digit	40.0518828071612845	-75.0879370097901671
22274	2020-04-29 10:03:32	2020-04-29	Ms. Yazmin Hintz DDS	ms.yazmin.hintz.dds@warmmail.com	Chula Vista	California	3096534785253361654	f16dd1fc7e41b7ebb4e422d297a2932a	Voyager	32.6127313618779127	-116.939663379243385
22275	2020-04-29 10:06:24	2020-04-29	Mr. Thos Kautzer	mr.thos.kautzer@geemail.com	Columbus	Ohio	3096721666016753986	00068a93f07ec25b179cbe2728313bbb	VISA 13 digit	40.0705618160821473	-82.9646626264091651
22276	2020-04-29 10:11:09	2020-04-29	Opha Daniel	opha.daniel@geemail.com	Louisville	Kentucky	4268163991462006	f359ee49c4de50612f5c2bdfd8c82029	JCB 16 digit	38.1654546059105542	-85.5942580391723737
22277	2020-04-29 10:11:31	2020-04-29	Jakayla Rosenbaum	jakayla.rosenbaum@geemail.com	Los Angeles	California	3528337118544603594	232d97ee6ea5d3810285b4c260581be6	Mastercard	34.0974593935400208	-118.46418043216616
22278	2020-04-29 10:21:08	2020-04-29	Mrs. Anahi Gerlach	mrs.anahi.gerlach@warmmail.com	San Francisco	California	3020002517047557	a532f4af1efe35ffbdde60628db59fc3	Discover	37.7587310922943615	-122.414844739804352
22279	2020-04-29 10:26:58	2020-04-29	Parthenia Abernathy	parthenia.abernathy@geemail.com	Seattle	Washington	3528744793929890607	c97993b6c810ac79eeccb6ba68a00e7c	VISA 13 digit	47.5780791545212267	-122.409471024006223
22280	2020-04-29 10:46:35	2020-04-29	Quiana Dickinson-Runolfsson	quiana.dickinson.runolfsson@geemail.com	Pittsburgh	Pennsylvania	180011306157635580	3dc82111c24704729b193ab06e507229	JCB 16 digit	40.516066905199736	-80.0192884634420381
22281	2020-04-29 10:47:05	2020-04-29	Harman Upton	harman.upton@geemail.com	Lexington	Kentucky	4084824803294	ca4d3f2b4352ff19a0769d87ad05f2f4	JCB 16 digit	38.0591057915117617	-84.5515271406985818
22282	2020-04-29 10:55:29	2020-04-29	Seaborn Beer	seaborn.beer@geemail.com	Oxnard	California	3158861923313367915	1e10811164ea9fccf7ed6c7e4953edac	Mastercard	34.192514671613651	-119.238886693809548
22283	2020-04-29 11:07:54	2020-04-29	Conley Lehner I	conley.lehner.i@warmmail.com	Oakland	California	869926533498113893	f92f1ec9aca9dac277899b112b20ca45	Mastercard	37.8137307023155742	-122.283366449250693
22284	2020-04-29 11:08:43	2020-04-29	Lorenza Johnson	lorenza.johnson@geemail.com	San Francisco	California	4462255517655404	a4522fbdf42e78e6dd2fb4cf20deef6a	JCB 16 digit	37.7606660850857239	-122.416979346425606
22285	2020-04-29 11:12:11	2020-04-29	Brogan Frami MD	brogan.frami.md@warmmail.com	Tempe	Arizona	3096177375530866493	da6e20f723f1bc76bc4cce56e5aff6fc	VISA 16 digit	33.3710698936521979	-111.947547134899722
22286	2020-04-29 11:14:33	2020-04-29	Ms. Ivah Medhurst	ms.ivah.medhurst@geemail.com	Tallahassee	Florida	869940463673561991	0980861f5b4109264208ed7b0ca60993	Maestro	30.3586278075374665	-84.2421563728261731
22287	2020-04-29 11:18:12	2020-04-29	Dirk Gutkowski	dirk.gutkowski@woohoo.com	San Francisco	California	3158795500221491135	67b8ced0c558569d1e237bd9cb3cd531	JCB 15 digit	37.7632358948915936	-122.447815480392833
22288	2020-04-29 11:53:25	2020-04-29	Thyra Yundt	thyra.yundt@geemail.com	Indianapolis	Indiana	3158331014191203323	1b46899fb9cd1e8749b44d0e0eb780d5	Diners Club / Carte Blanche	39.7353701168213007	-86.1267445599395813
22289	2020-04-29 12:07:50	2020-04-29	Travis Jacobi-Macejkovic	travis.jacobi.macejkovic@geemail.com	Allen	Texas	4729146887037613	da648145fe8dda3dce3dafbeb48e9582	Discover	33.1617899909175904	-96.597755349794781
22290	2020-04-29 12:31:46	2020-04-29	Mrs. Rosy Gibson PhD	mrs.rosy.gibson.phd@geemail.com	San Antonio	Texas	3041016398353230	2c9cccb95704301759f63e314970c18e	VISA 13 digit	29.5219562157128017	-98.4276079532526325
22291	2020-04-29 12:32:41	2020-04-29	Arianna Zulauf	arianna.zulauf@geemail.com	Paterson	New Jersey	4994048223022	155bf6b62100afeb3caa5b0f64ada232	Voyager	40.9264120244842005	-74.0851060316871894
22292	2020-04-29 12:34:19	2020-04-29	Misty Mohr	misty.mohr@geemail.com	New York	New York	180045528670242707	d12d983109a041a661d760fd128b7b42	Discover	40.6316317764334372	-73.9242970721691819
22293	2020-04-29 12:36:49	2020-04-29	Jarvis Monahan	jarvis.monahan@geemail.com	New York	New York	869907249619476746	ebcb4601a0bd86f4a68a056d1172e3a1	VISA 13 digit	40.5841327876076079	-73.9668038808170678
22294	2020-04-29 12:37:44	2020-04-29	Mistie Hoppe-Cummings	mistie.hoppe.cummings@geemail.com	San Francisco	California	3461996073569019	afaf52c6c77b19ada9cf7713451cf215	VISA 16 digit	37.7490538981244086	-122.452663974313779
22295	2020-04-29 12:49:38	2020-04-29	Mr. Kaiden Bernier	mr.kaiden.bernier@geemail.com	Baton Rouge	Louisiana	4073653974402222	4e9adc7f36ebac0bb9c6cf40809ef3e9	Discover	30.3713195676662018	-91.1805376816649016
22296	2020-04-29 13:07:20	2020-04-29	Fatima Oberbrunner	fatima.oberbrunner@woohoo.com	Oakland	California	52833530710898445	2fed6b1260ffc47912c34f7ed9f54915	VISA 13 digit	37.8220894676839094	-122.249887402425088
22297	2020-04-29 13:14:01	2020-04-29	Ms. Cristen Torphy	ms.cristen.torphy@woohoo.com	Miami	Florida	3337002357394888129	f5617876db40b5744735392e93f0dd18	Maestro	25.726683566081153	-80.2514296450991225
22298	2020-04-29 13:20:14	2020-04-29	Shirley Green	shirley.green@geemail.com	Chicago	Illinois	3717296534639906	4db7a16978a8ac22df5bc1ce33f78205	VISA 13 digit	41.8841802516788277	-87.7478286719445038
22299	2020-04-29 13:24:34	2020-04-29	Leona Gerlach-Nolan	leona.gerlach.nolan@geemail.com	Fort Wayne	Indiana	55030095285174029	ad1aedad8db3ca0a4c72cb4ebe3fc6d3	Mastercard	41.0218358122993294	-85.1777133129756976
22300	2020-04-29 13:27:20	2020-04-29	Dr. Art Hettinger IV	dr.art.hettinger.iv@geemail.com	Berkeley	California	180081800652212445	e1fa5da628c8834e471bccc6ba668fed	Discover	37.8790360364977943	-122.254119792513862
22301	2020-04-29 13:27:27	2020-04-29	Buena Kshlerin MD	buena.kshlerin.md@geemail.com	Kansas City	Kansas	53033749412396056	d31e9db551533012825663a154eb2d16	VISA 16 digit	39.1078184726554952	-94.6461867603409956
22302	2020-04-29 13:29:05	2020-04-29	Lainey Dickinson	lainey.dickinson@geemail.com	Allentown	Pennsylvania	4903944664726	aec4c9298f144ec072d24c1af05712ca	VISA 16 digit	40.5465218232259161	-75.4708024678300973
22303	2020-04-29 13:49:01	2020-04-29	Kinte Lueilwitz-Funk	kinte.lueilwitz.funk@geemail.com	New York	New York	869947589808909250	54a45278b448cecfb7ce1a9a25f4c191	Mastercard	40.6478589114025226	-74.018590555795285
22304	2020-04-29 13:54:06	2020-04-29	Brent Bernhard	brent.bernhard@geemail.com	West Valley City	Utah	54795250981047228	f3d0385e1a8ad4a524ba3e642f3f75ea	JCB 16 digit	40.7617205423526414	-111.998848221519211
22305	2020-04-29 13:59:15	2020-04-29	Laurine Hoppe	laurine.hoppe@geemail.com	Los Angeles	California	4850840736771932	a9aa5aba120a6cc2cab7facd7811147f	VISA 16 digit	34.0017262573219838	-118.34409218714498
22306	2020-04-29 14:06:33	2020-04-29	Dr. Eleonora Kassulke PhD	dr.eleonora.kassulke.phd@geemail.com	Philadelphia	Pennsylvania	6011765460840980115	f82eb4cf6c53b55534b01af58a27dc23	Diners Club / Carte Blanche	40.0289358736906209	-75.0740856865786128
22307	2020-04-29 14:07:09	2020-04-29	Mrs. Freeda Kutch	mrs.freeda.kutch@warmmail.com	Athens	Georgia	4474788392441892	e60e8be208be5e8400484306a9e716d1	VISA 13 digit	33.9673430057432455	-83.3754979991003751
22308	2020-04-29 14:07:41	2020-04-29	Matthew Medhurst	matthew.medhurst@geemail.com	Houston	Texas	6011435191778022378	d9d9910f3860ab688ae85674f2319185	Maestro	29.8635032155629254	-95.3522122641574583
22309	2020-04-29 14:21:31	2020-04-29	Trent Schmeler	trent.schmeler@woohoo.com	San Francisco	California	3474299680210191	5f0f37f8fb7da659357774912d4c142f	Discover	37.7635083638557489	-122.445511710459684
22310	2020-04-29 14:29:59	2020-04-29	Irvin Tillman DVM	irvin.tillman.dvm@geemail.com	McAllen	Texas	4371397818027	68caf51649220303d8051bb65f482530	Mastercard	26.2739252745013658	-98.2833657596573147
22311	2020-04-29 14:44:10	2020-04-29	Gilford Hammes	gilford.hammes@geemail.com	Fort Wayne	Indiana	6011237750530878771	60700e249b271b65b2dc518015c7bc3e	Mastercard	41.1861927887674426	-85.0717609071858192
22312	2020-04-29 14:46:21	2020-04-29	Merna Klein	merna.klein@geemail.com	Sunnyvale	California	4252592622846518	4f2114380b27703c515b632485604ac9	Discover	37.3237573983140294	-122.080924002287176
22313	2020-04-29 14:51:28	2020-04-29	Dolphus Balistreri-Gerlach	dolphus.balistreri.gerlach@woohoo.com	San Francisco	California	869947628127631607	d6eb47245c8ef5b452d4006b9fe44733	Discover	37.7654113863546428	-122.42557708183918
22314	2020-04-29 14:55:42	2020-04-29	Henri Reinger	henri.reinger@geemail.com	San Diego	California	6011139243971306485	9d5591836eb527237c46a6f62fe56034	Maestro	32.8917309200923924	-117.040163381807517
22315	2020-04-29 15:07:18	2020-04-29	Neola Rodriguez-Metz	neola.rodriguez.metz@geemail.com	Henderson	Nevada	589366345773338	d8d373e3a5709cf1c1e0ed9728ad04f1	Maestro	36.0845946038074814	-115.046223060662683
22316	2020-04-29 15:10:30	2020-04-29	Denis Goldner	denis.goldner@geemail.com	Peoria	Illinois	3528467201461296972	92492a850229415fac1d02d711f61afa	Maestro	40.6597893645390869	-89.53790925525837
22317	2020-04-29 15:18:11	2020-04-29	Loretto Sanford-Littel	loretto.sanford.littel@geemail.com	Denver	Colorado	6011606650397708876	4872000a1eec2448ace1030958051938	VISA 16 digit	39.787739621014893	-104.968677786669133
22318	2020-04-29 15:50:38	2020-04-29	Dr. Lou Hudson	dr.lou.hudson@geemail.com	New Orleans	Louisiana	4093167808557248	c3301fd9ef6971e0656464994c605851	Maestro	30.0223787996467202	-89.8540983736775871
22319	2020-04-29 15:51:04	2020-04-29	Dr. Mardell Ankunding PhD	dr.mardell.ankunding.phd@geemail.com	Anchorage	Alaska	4223848826582986	1cedac7b19573f44e03a16eb7063d797	JCB 16 digit	61.2704954193655453	-149.37308400912508
22320	2020-04-29 15:54:13	2020-04-29	Stacey Ortiz MD	stacey.ortiz.md@geemail.com	San Francisco	California	3026217093320830	a1f25fb5e74d1229a9c4d1704ad2c003	Discover	37.7582639439714711	-122.440866010773973
22321	2020-04-29 15:58:17	2020-04-29	Marinda Spencer-Hoppe	marinda.spencer.hoppe@geemail.com	San Diego	California	3424416715662086	0524b43b4216036b617d168259ef9dc7	VISA 13 digit	32.7351998177424051	-117.067405689638107
22322	2020-04-29 16:04:27	2020-04-29	Mia Toy	mia.toy@geemail.com	New York	New York	869973057586962690	16688ee665c464e90324fb5a6a6b560c	VISA 16 digit	40.6186543775945879	-73.9573617404222432
22323	2020-04-29 16:04:37	2020-04-29	Semaj Jerde-Boyle	semaj.jerde.boyle@geemail.com	Fort Wayne	Indiana	55024365078711180	b22e65e0b9a7e3e0b335ad9a4b2d4400	Maestro	41.0546518558420246	-85.1337044967092567
22324	2020-04-29 16:10:19	2020-04-29	Mr. Jared Stiedemann MD	mr.jared.stiedemann.md@geemail.com	Chicago	Illinois	869966309430329504	1694ee9a5c9fe9aac6ecdc3b80d17065	Voyager	41.8979663194924612	-87.5834178822610454
22325	2020-04-29 16:19:07	2020-04-29	Dr. Derrick Hudson	dr.derrick.hudson@geemail.com	Tucson	Arizona	4820236177989199	2258411f98a6caf211c86c3eee81d0f8	Voyager	32.131470307991286	-110.889454670040308
22326	2020-04-29 16:19:19	2020-04-29	Susannah Hermann	susannah.hermann@geemail.com	Lansing	Michigan	4509694490624	951f7fec1b0a41c9e6e56834c7e849f8	American Express	42.6742849573336542	-84.6199660458259189
22327	2020-04-29 16:42:48	2020-04-29	Miss Jaylen Reinger DDS	miss.jaylen.reinger.dds@woohoo.com	Lincoln	Nebraska	3409874736000430	27fba92a24fba45c93b537ab103f4e1b	Mastercard	40.730741765305396	-96.7769082001104977
22328	2020-04-29 16:54:34	2020-04-29	Kittie Sporer DDS	kittie.sporer.dds@geemail.com	Palm Bay	Florida	3337185109442718066	579270ea0f7be4df7c93e9651f5023d8	American Express	28.0462676384340988	-80.7288555936258234
22329	2020-04-29 17:06:19	2020-04-29	Clement Hegmann	clement.hegmann@geemail.com	San Francisco	California	6011292910727616481	b078c77c2a0f451a99c500daad1f010f	VISA 13 digit	37.7429069596270779	-122.432084575879429
22330	2020-04-29 17:11:51	2020-04-29	Gaylen Kemmer	gaylen.kemmer@geemail.com	Knoxville	Tennessee	3788878620321426	9c043e355ffd5959fb2794b1053b22fd	VISA 16 digit	35.8761906547069529	-83.8573761576537038
22331	2020-04-29 17:12:52	2020-04-29	Janiya Breitenberg	janiya.breitenberg@geemail.com	Charlotte	North Carolina	676189034187982	d77d63c6cdffb00ba0e3b5bee46144d5	Discover	35.1243105010848495	-80.7658074218723954
22332	2020-04-29 17:19:36	2020-04-29	Precious Kreiger	precious.kreiger@geemail.com	New York	New York	4974043912862333	1fd2c3c6e2f3912070cbda128ff66c13	VISA 13 digit	40.6469011533297575	-73.8755598258588435
22333	2020-04-29 17:20:48	2020-04-29	Kassidy Lindgren	kassidy.lindgren@woohoo.com	Thornton	Colorado	4340272915836	f020febfd4da9df128d78f6b9674fd76	VISA 13 digit	39.8650159438472258	-104.955186253476143
22334	2020-04-29 17:33:13	2020-04-29	Dr. Heber Kshlerin	dr.heber.kshlerin@geemail.com	Miami	Florida	6011674996002392813	5e6e99bffc63a32a13db5c5c3c233baa	American Express	25.866167303281653	-80.1749398619741243
22335	2020-04-29 17:50:10	2020-04-29	Dr. Carlyle Hessel IV	dr.carlyle.hessel.iv@geemail.com	Baltimore	Maryland	3453860294299022	b1f4905faf3dfe261f4a7545b6ff43fa	VISA 13 digit	39.2990015805698931	-76.5905029768608472
22336	2020-04-29 17:53:07	2020-04-29	Dr. Yoshio Hills III	dr.yoshio.hills.iii@geemail.com	Buffalo	New York	3030848706578301	dbc5190708b7aca1ba1a3e5ba5d76e39	Discover	42.9802107891254082	-78.8699406888734558
22337	2020-04-29 17:58:32	2020-04-29	Kamora Casper	kamora.casper@geemail.com	Oakland	California	53083167850460715	0955ad8e0d7a585e195d5e9dc894fde2	VISA 16 digit	37.8028977902054422	-122.245549622242507
22338	2020-04-29 18:01:01	2020-04-29	Gail Bode	gail.bode@geemail.com	San Francisco	California	3421974998321484	43b866637f205f1f86836c7ece7214e0	Maestro	37.7773518557498988	-122.407521730805271
22339	2020-04-29 18:02:13	2020-04-29	Pansy Okuneva-Upton	pansy.okuneva.upton@geemail.com	Des Moines	Iowa	3088830144953168434	21844f2e2cc72394d37aa663ba3bc1c7	American Express	41.534009065267071	-93.6976305927194772
22340	2020-04-29 18:11:40	2020-04-29	Jarad Prohaska II	jarad.prohaska.ii@woohoo.com	Jackson	Mississippi	6011791318699468939	ab8f6991fc9d61435f74109fa220d8b3	Mastercard	32.4062860366135865	-90.1823546161383405
22341	2020-04-29 18:18:13	2020-04-29	Jada Waelchi	jada.waelchi@warmmail.com	Boston	Massachusetts	3088503213867555675	21cf5de8cc72a3542a928bb7bdfd7310	VISA 16 digit	42.3529336583968288	-71.1169884099111016
22342	2020-04-29 18:34:16	2020-04-29	Damond Jerde	damond.jerde@woohoo.com	Memphis	Tennessee	4201793669195387	72f5c8f10a7cf0d75573216f76d20ebe	Mastercard	35.1804789139490595	-90.0654842742044508
22343	2020-04-29 18:44:17	2020-04-29	Ewald Huel	ewald.huel@geemail.com	Philadelphia	Pennsylvania	4203606010589595	3f1651f328e55223efa7e86a01abedcc	Discover	40.085291515007242	-75.0948266352426259
22344	2020-04-29 19:03:32	2020-04-29	Dr. Chalmer Bruen V	dr.chalmer.bruen.v@geemail.com	Los Angeles	California	3337620901454532523	3451478e6f5cb51b556d2dbcf759c1ec	Diners Club / Carte Blanche	34.0119388725008776	-118.439705949695025
22345	2020-04-29 19:08:08	2020-04-29	Ezzard Fritsch	ezzard.fritsch@geemail.com	Roseville	California	4900654912951592	ac29ddb9de1d52a9c17d20add4155986	Discover	38.7183448380380852	-121.337214657174044
22346	2020-04-29 19:10:07	2020-04-29	Dr. Kasie Johnson	dr.kasie.johnson@geemail.com	Clearwater	Florida	3337526603344404161	7db65f55fca3c6764291a3dca8b29563	JCB 15 digit	28.0768758477769786	-82.7166231093261359
22347	2020-04-29 19:12:34	2020-04-29	Adria Lind	adria.lind@geemail.com	Oakland	California	3337121459023302708	d7690cffa2c62d335641da5db73665fc	Maestro	37.7954808205080326	-122.312080470068935
22348	2020-04-29 19:38:57	2020-04-29	Dr. Raymundo Mante DVM	dr.raymundo.mante.dvm@geemail.com	Madison	Wisconsin	4593158941057191	865343e1278b1ea24e09fe5c79dfa957	JCB 15 digit	43.1810217413559556	-89.5211878561299272
22349	2020-04-29 19:44:47	2020-04-29	Mr. Kristin Swaniawski IV	mr.kristin.swaniawski.iv@woohoo.com	Rockford	Illinois	639064214365070	ba123b7b9461269852de6cf6230d6cc2	Maestro	42.2434707425545923	-89.132043938925861
22350	2020-04-29 19:46:19	2020-04-29	Kraig Hoppe-Mohr	kraig.hoppe.mohr@geemail.com	Milwaukee	Wisconsin	4139039244880	2d302562ee3d2029e2ffd7db3e937bcf	VISA 13 digit	43.0311752905223486	-87.8976224451426447
22351	2020-04-29 19:47:39	2020-04-29	Dr. Charlotta Daugherty PhD	dr.charlotta.daugherty.phd@warmmail.com	San Francisco	California	53177784999592930	c1424fe5eb882c9afbaa4fd555d1aa02	VISA 16 digit	37.7723511658115925	-122.405674322785543
22352	2020-04-29 19:59:29	2020-04-29	Mrs. Angella Bergstrom	mrs.angella.bergstrom@geemail.com	Memphis	Tennessee	3748765802619389	3461748e2b53b0180d1d5b48ddaa0365	Voyager	35.0704567533053506	-89.949468830765781
22353	2020-04-29 20:07:44	2020-04-29	Mr. Rollin Howe III	mr.rollin.howe.iii@woohoo.com	Rockford	Illinois	630412103141359	25664f41a3e049013d8211b97152572f	Voyager	42.1765523282356583	-88.9738327948194012
22354	2020-04-29 20:40:41	2020-04-29	Simpson Mayer	simpson.mayer@geemail.com	Los Angeles	California	4936317455950516	1342244860c3c64975243b7e26bd9fcd	Voyager	33.9271826370019411	-118.464920876127849
22355	2020-04-29 20:41:15	2020-04-29	Leafy Schinner	leafy.schinner@geemail.com	Irvine	California	4744179683661980	9fb9585b89a46e08fb264611402650dc	American Express	33.7688712120536749	-117.726783497679236
22356	2020-04-29 21:02:28	2020-04-29	Abbie Cassin	abbie.cassin@geemail.com	Santa Rosa	California	6011768418423337233	ee0ce19e442172e27fd927f80e6a0792	Voyager	38.3903139541048617	-122.750814201986799
22357	2020-04-29 21:13:38	2020-04-29	Rillie Kautzer	rillie.kautzer@woohoo.com	Frisco	Texas	3528266445814904112	0a44479acaf2b0e4c6d6031168731bdb	JCB 15 digit	33.1914879767220441	-96.7269253589887086
22358	2020-04-29 21:25:55	2020-04-29	Shelley Doyle	shelley.doyle@geemail.com	Killeen	Texas	52119219512015300	fdee10040379fbfecd1d15d036f718a5	American Express	31.1172984244998538	-97.6475888490844568
22359	2020-04-29 21:43:16	2020-04-29	Marguerite Doyle	marguerite.doyle@woohoo.com	San Francisco	California	676303361423027	d15aaa0ac2acfef612df31e7f8165bd8	JCB 16 digit	37.7948282897951842	-122.447111501798659
22360	2020-04-29 21:49:35	2020-04-29	Rollin Botsford	rollin.botsford@geemail.com	Chicago	Illinois	180087008731890769	0ce765e88abf85037d5fefd98642cab8	VISA 16 digit	41.9165849351625894	-87.5942966403935088
22361	2020-04-29 22:00:53	2020-04-29	Aubrey Hermiston	aubrey.hermiston@geemail.com	Miami	Florida	4426379747512659	ee8ab69c636c8398285abea3b1519d4b	JCB 16 digit	25.7869415644694122	-80.2332785438153877
22362	2020-04-29 22:06:15	2020-04-29	Arline Runte-Cummerata	arline.runte.cummerata@geemail.com	Buffalo	New York	4175374846142048	00e8d6c1a9eec3dd95540959ba7c4514	JCB 16 digit	42.8349823815468653	-78.8896012688919939
22363	2020-04-29 22:26:51	2020-04-29	Danita O'Kon	danita.o'kon@geemail.com	Tempe	Arizona	6011315358605123688	23e4f5cbe36866a8e79fc2a9285e3d4e	VISA 13 digit	33.4477023337423773	-111.949374158916243
22364	2020-04-29 22:27:31	2020-04-29	Ford Witting	ford.witting@woohoo.com	Alexandria	Virginia	53114916573585783	877132307ae47dbd4c5a32c3ebf847d5	American Express	38.8153526940964113	-76.9960878016877928
22365	2020-04-29 22:43:08	2020-04-29	Zoie Larson	zoie.larson@geemail.com	Richmond	Virginia	3467889302353434	e7dfde2c1dac256d4fa84c0f8308fe6c	VISA 16 digit	37.4709402855239802	-77.4575588828176222
22366	2020-04-29 22:50:23	2020-04-29	Clemmie Hermann	clemmie.hermann@warmmail.com	Madison	Wisconsin	6011535395697883013	a7145658288d08159b59b632dc6367d1	JCB 16 digit	43.0678575869623614	-89.5044114681776648
22367	2020-04-29 22:54:22	2020-04-29	Myranda Miller	myranda.miller@warmmail.com	Philadelphia	Pennsylvania	3158930868436744531	314f0d2f6239edf3808bc1407f363d8a	VISA 13 digit	40.0020314998883748	-75.2061878524154537
22368	2020-04-29 22:55:26	2020-04-29	Emmit Hermann	emmit.hermann@geemail.com	Philadelphia	Pennsylvania	4655084469166856	2c42010eb532b015597a62a3963ee123	Voyager	40.0707934302236879	-75.0449184205748168
22369	2020-04-29 23:02:14	2020-04-29	Misael Deckow	misael.deckow@geemail.com	San Antonio	Texas	3337283312769973733	b7b946189aa6cf642bb3ed2e085b6e5a	JCB 16 digit	29.4895059298794706	-98.4402395818218565
22370	2020-04-29 23:07:34	2020-04-29	Mr. Darell McDermott I	mr.darell.mcdermott.i@warmmail.com	Chesapeake	Virginia	54203505837741076	491f4935ee2538c53e7df5ba68336c7d	Discover	36.6274082937050594	-76.2289154730580805
22371	2020-04-29 23:15:18	2020-04-29	Ilda Rempel	ilda.rempel@geemail.com	Newark	New Jersey	4488043100483	a88f66d64ef75b485042f10ef5f9b351	JCB 15 digit	40.7675087269775602	-74.1432589847337482
22372	2020-04-29 23:22:37	2020-04-29	Mckinley Kulas PhD	mckinley.kulas.phd@geemail.com	Denver	Colorado	3058753776180966	ebf72dd6da2d5eca3eee81bc6ebdbd26	VISA 16 digit	39.7082950377423316	-104.832472588984672
22373	2020-04-29 23:23:49	2020-04-29	Elder Boyle	elder.boyle@geemail.com	Los Angeles	California	3479455946511096	4451f8f4a8f90a60305d28645cc75db9	JCB 15 digit	33.9359641293860932	-118.335783613751829
22374	2020-04-29 23:25:19	2020-04-29	Lige Weber	lige.weber@geemail.com	Frisco	Texas	4755182102414938	6803f86d15081d8722eb056360d87e6e	Discover	33.1561875548675644	-96.9219135430384426
22375	2020-04-29 23:26:59	2020-04-29	Johnathan Conroy	johnathan.conroy@warmmail.com	Tampa	Florida	630442940600259	a9067acea7f478009ab48e8009692d34	Maestro	28.0384353873901055	-82.437328100737929
22376	2020-04-29 23:28:55	2020-04-29	Diya Gutmann MD	diya.gutmann.md@geemail.com	San Francisco	California	501856727328967	99a71e53bec9a30143b97d1e480a4cf0	American Express	37.7887459778344308	-122.453732927639152
22377	2020-04-29 23:33:58	2020-04-29	Devan Powlowski	devan.powlowski@geemail.com	Yonkers	New York	3763950453751604	c9b5ec4915b7c7e69ca88c5dfd0c7505	Discover	40.879072615477817	-73.850729569920901
22378	2020-04-29 23:40:18	2020-04-29	Ishmael Dare-Conn	ishmael.dare.conn@woohoo.com	Simi Valley	California	869938971942166768	5a485a377d51217d884a548b0cd5d61c	JCB 16 digit	34.2352381486218391	-118.78226475661063
22379	2020-04-29 23:58:48	2020-04-29	Brady Brown	brady.brown@geemail.com	Joliet	Illinois	4172460069910980	ef46472632206e37cb960039d6897ff4	American Express	41.5787830809455343	-88.2336854290321355
22380	2020-04-30 00:17:17	2020-04-30	Dr. Loren Daugherty	dr.loren.daugherty@woohoo.com	Columbus	Ohio	54359052244349674	1807c17b5d7e35df895ef17f1d41a78d	Diners Club / Carte Blanche	39.9226091924633835	-82.9303262754112609
22381	2020-04-30 00:20:29	2020-04-30	Dr. Dilan VonRueden	dr.dilan.vonrueden@warmmail.com	San Francisco	California	6011646001476683972	db56bb70e70ee907d226e3874d3bf10a	Mastercard	37.7443744630950633	-122.43951467163761
22382	2020-04-30 00:35:17	2020-04-30	Miss Caro Smitham MD	miss.caro.smitham.md@geemail.com	Rochester	New York	3088132250058488281	087bf5bd6ade10d28c77aa5b9c8dfc14	Maestro	43.1267107455037504	-77.5879031782742601
22383	2020-04-30 00:39:36	2020-04-30	Bart Raynor	bart.raynor@geemail.com	Berkeley	California	3158812612168295566	bc96a687392b0cbfae5d221bf7dbc7e4	Diners Club / Carte Blanche	37.8730058363914566	-122.250536291109569
22384	2020-04-30 00:57:43	2020-04-30	Marci Gorczany	marci.gorczany@geemail.com	Tampa	Florida	53098973168925171	6d061026ccf6df0d4508c27d205131a0	Mastercard	28.0175190140143009	-82.484088302471477
22385	2020-04-30 00:59:51	2020-04-30	Jamie Hintz	jamie.hintz@geemail.com	Lowell	Massachusetts	4862380891029061	b64ba38d70280fe47c47e36fd38d3778	American Express	42.59726679077	-71.3015609852377281
22386	2020-04-30 01:01:43	2020-04-30	Cuba Heller-DuBuque	cuba.heller.dubuque@geemail.com	Dallas	Texas	4445818178920	5d145dedcbd29eb4c3272c3aeb48e81c	Maestro	32.8330917654365351	-96.7289218874145291
22387	2020-04-30 01:07:53	2020-04-30	Vidal Cummings	vidal.cummings@geemail.com	Greeley	Colorado	6011327275116592613	153aa78777cd34ff894e7eb9308c9318	American Express	40.3304679631322642	-104.718316230115292
22388	2020-04-30 01:42:49	2020-04-30	Mrs. Caroline Donnelly DDS	mrs.caroline.donnelly.dds@geemail.com	Seattle	Washington	3096018623033065193	716175a6b482969b34b1ec3f4ba71c49	American Express	47.5543460126426041	-122.28110696002058
22389	2020-04-30 02:11:22	2020-04-30	Cayla Williamson	cayla.williamson@geemail.com	Torrance	California	3088405423779253025	831d1f682108b261b8f23a7c0378cb8f	Voyager	33.9281271733250449	-118.32288722550831
22390	2020-04-30 02:20:15	2020-04-30	Alexis Denesik-Kihn	alexis.denesik.kihn@warmmail.com	New York	New York	6011702494444450023	799506f0a3b4a77411ae3fae368f3047	Mastercard	40.7376916551254666	-73.8568037094444065
22391	2020-04-30 02:26:01	2020-04-30	Dolphus Bosco	dolphus.bosco@warmmail.com	Lowell	Massachusetts	6011148527799571000	a638bbea36f3814ad7483aedfac94de1	Voyager	42.5918358913026793	-71.2671732997860801
22392	2020-04-30 02:38:05	2020-04-30	Letty Ruecker	letty.ruecker@geemail.com	Norfolk	Virginia	869923168432301693	1dcdb089c33677a16a55c3cd70984aaa	JCB 16 digit	36.9721128662601117	-76.2988729964014141
22393	2020-04-30 03:10:59	2020-04-30	Minnie Pfannerstill-Williamson	minnie.pfannerstill.williamson@geemail.com	Miami	Florida	55155988260296669	b636c7c18ea37663ff03634a4e72c9ed	American Express	25.7494068025283518	-80.1274239559996886
22394	2020-04-30 03:20:20	2020-04-30	Alina Jakubowski	alina.jakubowski@geemail.com	Cleveland	Ohio	4926806361787931	52bb76df6ef010c58c9a0fbc666422c6	Voyager	41.5416158935837387	-81.7720559643819911
22395	2020-04-30 04:00:45	2020-04-30	Dr. Devyn Kunde	dr.devyn.kunde@geemail.com	Lincoln	Nebraska	210013776451286298	7dc80759633b9901c44c495e8d587893	JCB 16 digit	40.8859849515389655	-96.6174403236873474
22396	2020-04-30 04:07:22	2020-04-30	Fleming Crooks	fleming.crooks@woohoo.com	Tucson	Arizona	6011611779950953554	a78aee2e4cb29e5449debfdfc90ca8b2	Mastercard	32.112164508602028	-110.926070860609784
22397	2020-04-30 04:21:21	2020-04-30	Barry Wilderman	barry.wilderman@geemail.com	New York	New York	4586211857691	18cbfc71cb86d436e91abe5f374aa8fd	Maestro	40.6168299133181563	-73.865244909691441
22398	2020-04-30 04:25:44	2020-04-30	Brooklynn Murphy	brooklynn.murphy@geemail.com	Birmingham	Alabama	3499624893859420	61901690c9a0dc1cb584904e8f9e4430	Mastercard	33.5486648730725037	-86.7539264298286383
22399	2020-04-30 04:34:23	2020-04-30	Mrs. Jaclyn Crist MD	mrs.jaclyn.crist.md@warmmail.com	Riverside	California	3713283933360874	8cf98ac072d7f1385118c07fb414403e	Voyager	33.9329781908024088	-117.407704743879648
22400	2020-04-30 04:52:14	2020-04-30	Winton Heathcote	winton.heathcote@geemail.com	Oklahoma City	Oklahoma	3096274787443889275	2e4c53a1eb6bd76eaff3c323059b5661	JCB 16 digit	35.4146416205823442	-97.5345580946084141
22401	2020-04-30 05:02:24	2020-04-30	Gladis Leuschke-Kuhic	gladis.leuschke.kuhic@geemail.com	Philadelphia	Pennsylvania	869930436919512665	9bbd31363a355b8a2affea3091e00ca6	VISA 16 digit	39.9461764243390434	-75.0516338883798682
22402	2020-04-30 05:12:42	2020-04-30	Mrs. Earline Hettinger DDS	mrs.earline.hettinger.dds@warmmail.com	Greensboro	North Carolina	4659743326542015	4ee0f7010f1ec9d4e34376c9a0e98b5e	Mastercard	36.0947614085044748	-79.8124348783846926
22403	2020-04-30 05:16:25	2020-04-30	Travon Hudson	travon.hudson@geemail.com	Toledo	Ohio	3012103581653441	c2bac724041ac35d591a892969e7bc2c	Maestro	41.6474353579975656	-83.5619003376789493
22404	2020-04-30 05:19:17	2020-04-30	Mr. Tyrese Schiller	mr.tyrese.schiller@geemail.com	Greensboro	North Carolina	55988311018343878	ad371b15794ed9f42dee414442b0ea73	Voyager	36.0438016813829591	-79.8369922195542614
22405	2020-04-30 05:24:50	2020-04-30	Adelard Barrows	adelard.barrows@woohoo.com	Houston	Texas	3528876884761413408	756346b25e6cf5c7a61a405ab7136ec6	VISA 16 digit	29.7867077699009322	-95.3909829113647305
22406	2020-04-30 05:26:40	2020-04-30	Mrs. Echo Padberg DVM	mrs.echo.padberg.dvm@geemail.com	Savannah	Georgia	53047805081583004	b6d2a891a3ceb8f67e861e358325a5b4	JCB 16 digit	31.959712796015662	-81.2512228586398066
22407	2020-04-30 05:51:20	2020-04-30	Bell Rodriguez DDS	bell.rodriguez.dds@geemail.com	Tampa	Florida	4553105178917595	6d864c8e03d7c6bd1f920ba4d067736d	Mastercard	28.0113501566577696	-82.4485673502299932
22408	2020-04-30 05:51:34	2020-04-30	Julianne Runolfsson	julianne.runolfsson@warmmail.com	Los Angeles	California	6011729949573989868	e4d30afd5285c7378700ba056b454898	Voyager	34.0991291671391537	-118.418573931045074
22409	2020-04-30 05:51:37	2020-04-30	Jerold Kuhn	jerold.kuhn@warmmail.com	Greensboro	North Carolina	4745046811518045	c1de36973c13bd681776561984e52246	Discover	36.0907252146046602	-79.79890272849984
22410	2020-04-30 05:52:16	2020-04-30	Alexia Lebsack	alexia.lebsack@geemail.com	New York	New York	4570104920773421	177343407169644828f0f631ee756999	JCB 15 digit	40.6478392984010242	-73.8945364786207648
22411	2020-04-30 05:54:19	2020-04-30	Almer Gleason-Towne	almer.gleason.towne@geemail.com	Chicago	Illinois	4323766261107	7fb05b7bb141d1a1b7addd4777b86f5e	VISA 13 digit	41.8961697451140722	-87.5936834298103975
22412	2020-04-30 06:01:15	2020-04-30	Gaither Ullrich	gaither.ullrich@geemail.com	Chesapeake	Virginia	53764969500201365	99b1bd2332bc01a793f2d628cef5168e	Mastercard	36.6945274573523577	-76.3342916779995022
22413	2020-04-30 06:04:31	2020-04-30	Antoine Price	antoine.price@geemail.com	Philadelphia	Pennsylvania	55153792962834732	73137d2b92031ec8b3846f7cbbb249fb	VISA 13 digit	39.9984083994716428	-75.1495587127182745
22414	2020-04-30 06:10:34	2020-04-30	Willa Keeling	willa.keeling@geemail.com	Washington	District of Columbia	4662329272128127	fc90ed7b8aea2f5dec05aada598da401	Voyager	38.879994566206264	-77.0291137010071481
22415	2020-04-30 06:12:44	2020-04-30	Gwen Lesch-Wuckert	gwen.lesch.wuckert@geemail.com	New York	New York	4425096599770182	1b7f48f012d16e0c8d5cd6c94d350a5c	Discover	40.7105584467984727	-73.9116107452556435
22416	2020-04-30 06:15:13	2020-04-30	Kordell Weber	kordell.weber@woohoo.com	New York	New York	4674774389722963	5c12eeba5b07fa7bc1f7d90ca15d622d	JCB 15 digit	40.7448771550543611	-73.9391898504353975
22417	2020-04-30 06:19:28	2020-04-30	Walton Luettgen	walton.luettgen@geemail.com	Berkeley	California	3112404859693956600	f2fed2306e0cc4501b63ea9f5341dd89	Discover	37.8815090908843786	-122.245321820784511
22418	2020-04-30 06:55:11	2020-04-30	Mrs. Kaylen Konopelski	mrs.kaylen.konopelski@geemail.com	San Francisco	California	3096151351024709796	e3115455c48a306687ade8311a88674b	Mastercard	37.7710010816186923	-122.440025227684373
22419	2020-04-30 07:04:16	2020-04-30	Braylen VonRueden	braylen.vonrueden@geemail.com	San Francisco	California	3088646686300054653	8acef0575d91ac51d680d730427910e4	JCB 16 digit	37.7801706688821994	-122.390225004408251
22420	2020-04-30 07:11:43	2020-04-30	Yvonne Bahringer	yvonne.bahringer@geemail.com	Sacramento	California	4364795084581	ddde49432b464974bd6835335186d245	JCB 15 digit	38.5309485472537574	-121.492613262288643
22421	2020-04-30 07:34:39	2020-04-30	Fleta Friesen	fleta.friesen@geemail.com	San Francisco	California	869901902613162748	7cd0161096a0fcd1a11a06dfb8ac9726	Discover	37.7550691938634628	-122.428759225135423
22422	2020-04-30 07:35:24	2020-04-30	Ladarius Goodwin	ladarius.goodwin@geemail.com	San Francisco	California	869923590557806851	af8f7ff7dd811e7892c5adc36ba4cf53	Voyager	37.7853570470179463	-122.415564646841048
22423	2020-04-30 07:49:41	2020-04-30	Miss Keila Schamberger DDS	miss.keila.schamberger.dds@geemail.com	San Francisco	California	4906728111736360	c5be0c8c23c886649dfd0df9f567200e	VISA 16 digit	37.7656267408696564	-122.462483196311652
22424	2020-04-30 07:56:51	2020-04-30	Dr. Orpha Ziemann	dr.orpha.ziemann@geemail.com	Los Angeles	California	3096414443945379529	edf4d660c29cab9f977d6f41a025c919	Discover	34.0688743016082753	-118.410487650566921
22425	2020-04-30 08:02:49	2020-04-30	Denisse Ward-Hessel	denisse.ward.hessel@geemail.com	Laredo	Texas	3096137121546214669	587286ec46dd89f0d23cc6beede7c852	JCB 16 digit	27.6379332362391068	-99.4768621203962624
22426	2020-04-30 08:10:56	2020-04-30	Manly Mayer I	manly.mayer.i@geemail.com	Mobile	Alabama	4106859464075672	ff2c339b2029ea1977b7bc16894cdbfc	Voyager	30.6258430753942577	-88.0347426967367568
22427	2020-04-30 08:14:42	2020-04-30	Novella Stokes	novella.stokes@geemail.com	San Francisco	California	3158385955078106986	7c6a82bf21fb34556c71a4765b9b97ef	Mastercard	37.7452250028617371	-122.440653747504399
22428	2020-04-30 08:15:13	2020-04-30	Naoma Homenick	naoma.homenick@warmmail.com	Houston	Texas	4332488214807	91d07ec6f9081eef5a79676d65882ee5	Maestro	29.8378739553581909	-95.3447524707779337
22429	2020-04-30 08:16:39	2020-04-30	Mamie Nienow	mamie.nienow@geemail.com	New York	New York	210053161712240510	4381c2a033827c8c411ccb0d3f1ad7cb	Discover	40.6705165136363362	-73.9181778872281257
22430	2020-04-30 08:57:26	2020-04-30	Velvet Kuvalis DVM	velvet.kuvalis.dvm@woohoo.com	Kent	Washington	869977932113909636	a4035b06debb3b4c2924bfe790d35511	JCB 15 digit	47.452079504087564	-122.195208776383467
22431	2020-04-30 08:58:48	2020-04-30	Robert Treutel	robert.treutel@geemail.com	Sacramento	California	4659317385722782	b730f683f0f8b61cf88944224e9ca4d0	Discover	38.6052889936402437	-121.40259121016264
22432	2020-04-30 09:07:54	2020-04-30	Colbert Lockman	colbert.lockman@geemail.com	San Francisco	California	3337022270968459472	ba0447ecc3d7b8835cc8082a27d4fed8	VISA 16 digit	37.7739108164462891	-122.438482744382924
22433	2020-04-30 09:34:36	2020-04-30	Lucille Hickle PhD	lucille.hickle.phd@geemail.com	Atlanta	Georgia	3096444747386893275	f5e841fed7b60ce5d925a22e57992b24	JCB 16 digit	33.6690775041744104	-84.357009911122546
22434	2020-04-30 09:54:38	2020-04-30	Ms. Sebrina Torp	ms.sebrina.torp@geemail.com	Rochester	Minnesota	3022534530194030	87d8c73cefa94319380f58d70abee740	Voyager	44.040052092438188	-92.4577852248333301
22435	2020-04-30 09:55:41	2020-04-30	Dedra Douglas	dedra.douglas@woohoo.com	San Francisco	California	3096107787960786980	b60662faee9758f5721755aea8a3e341	VISA 16 digit	37.7565163611130643	-122.411403285913764
22436	2020-04-30 09:58:42	2020-04-30	Tom Bergstrom V	tom.bergstrom.v@geemail.com	Austin	Texas	6011742090864800150	89d082ef6c5549dc3ddf0498738c1606	JCB 15 digit	30.3052208410702626	-97.7962891381472446
22437	2020-04-30 10:00:45	2020-04-30	Tristen Bosco	tristen.bosco@warmmail.com	Hampton	Virginia	675917394366508	13e07d41036299a649eef2fcaf6db796	Discover	37.0885199366156044	-76.2158816838268223
22438	2020-04-30 10:11:42	2020-04-30	Alva Hansen	alva.hansen@geemail.com	Los Angeles	California	502012568921204	8a9cef1f6bbbb5f3970a4f59636aae67	Voyager	34.0691415102552568	-118.351165829411883
22439	2020-04-30 10:29:53	2020-04-30	Tiffany Dare	tiffany.dare@geemail.com	St. Petersburg	Florida	4516119324197727	4a9ca143d4c0c9e955032c0ed4735e40	Mastercard	27.6940200054440666	-82.6348349055167262
22440	2020-04-30 10:43:06	2020-04-30	Dr. Torrance Stamm I	dr.torrance.stamm.i@geemail.com	Omaha	Nebraska	3730407949641360	cd7b56433f7adbd21ee25ab9a5cdaa18	JCB 16 digit	41.2928516138490309	-95.9553279933635253
22441	2020-04-30 11:02:31	2020-04-30	Glenda Kohler	glenda.kohler@geemail.com	Houston	Texas	210082628435278527	c050f3e1ba7107c69b769976518931fa	Discover	29.7796278676096335	-95.3457652569763354
22442	2020-04-30 11:05:04	2020-04-30	Mr. Oley Bauch IV	mr.oley.bauch.iv@geemail.com	Cary	North Carolina	4668223348320145	74af60b4196c006009ee4fc43115dd0b	Voyager	35.8410476761046795	-78.7835185691799893
22443	2020-04-30 11:19:27	2020-04-30	Danelle Renner	danelle.renner@geemail.com	Kansas City	Missouri	869972190536416680	cb877330d61661bbce3281c8b05adf39	VISA 16 digit	39.0424828532919292	-94.5306364637091718
22444	2020-04-30 11:26:40	2020-04-30	Lucius Graham	lucius.graham@geemail.com	San Francisco	California	3494008000131862	18a184943563d001813605fcbce41b60	JCB 16 digit	37.7508398733146464	-122.380970596437209
22486	2020-04-30 19:55:50	2020-04-30	Tatia Schinner	tatia.schinner@geemail.com	Charlotte	North Carolina	54167595731792675	5cf432357e23eecd3af8c7194f630a3a	VISA 13 digit	35.1405360634691988	-80.8346948637571217
22445	2020-04-30 11:51:36	2020-04-30	Miss Cherie Harris DVM	miss.cherie.harris.dvm@warmmail.com	Berkeley	California	3785648141128227	c4fe4978dc479aeec9bd6e4f87e3c29f	JCB 15 digit	37.868602157149347	-122.251821834604286
22446	2020-04-30 12:25:26	2020-04-30	Miss Tiffanie Cummerata MD	miss.tiffanie.cummerata.md@geemail.com	McAllen	Texas	3096272043573114155	65a5484cff61f19e13745747e53ad650	JCB 16 digit	26.1818458224486541	-98.2154817115362704
22447	2020-04-30 12:44:35	2020-04-30	Kayleen Gusikowski	kayleen.gusikowski@geemail.com	Buffalo	New York	869970630010046331	ee81b19ed01e3ed5e1cc6d397a7692cc	American Express	42.8931224698852702	-78.8644555265482552
22448	2020-04-30 12:54:21	2020-04-30	Mr. Fate Bogan	mr.fate.bogan@geemail.com	Durham	North Carolina	4967953580974	07f65fa6d9130cbc9ec2fdbc55000920	American Express	35.9690359257407479	-78.8233392485786197
22449	2020-04-30 12:59:26	2020-04-30	Vincenzo Muller	vincenzo.muller@geemail.com	Berkeley	California	3096197490467579229	bb1f45ee847f2c58637739261bacd694	Maestro	37.8521558153346263	-122.283735781823268
22450	2020-04-30 13:02:39	2020-04-30	Dr. Elliana Gutkowski	dr.elliana.gutkowski@geemail.com	Los Angeles	California	4667640389132	bc827ed12bfee0b606ecaf5ea9f7c338	Diners Club / Carte Blanche	34.0572592616878396	-118.396772594935442
22451	2020-04-30 13:41:02	2020-04-30	Mrs. Queenie Maggio DVM	mrs.queenie.maggio.dvm@geemail.com	Buffalo	New York	639080678746449	ca09248e1188edd715351ac7e215d999	American Express	42.945364127326755	-78.8399850781939904
22452	2020-04-30 13:42:05	2020-04-30	Jame Tremblay	jame.tremblay@geemail.com	Philadelphia	Pennsylvania	3528385957859431310	d5ed7557c811db5e03d732fc22ce1400	VISA 16 digit	40.0967271142598207	-75.1091144132327315
22453	2020-04-30 13:43:24	2020-04-30	Woodrow Harber	woodrow.harber@geemail.com	Miami	Florida	3037128121433850	f4f1d57e35e22ad203dd8d0fd291ddb8	VISA 16 digit	25.6965182644452916	-80.2391530683603236
22454	2020-04-30 14:02:26	2020-04-30	Ms. Kortney Gerlach	ms.kortney.gerlach@geemail.com	San Antonio	Texas	676229192221579	133e4717475905f7a1208074fbd9d7c9	VISA 13 digit	29.5471026481665682	-98.5013361633591273
22455	2020-04-30 14:37:24	2020-04-30	Mr. Noble Sauer MD	mr.noble.sauer.md@geemail.com	Baton Rouge	Louisiana	4586471895437080	3dbe0e5c0da08445b9daabe77702fe36	Diners Club / Carte Blanche	30.3830199803903689	-91.1948816910028484
22456	2020-04-30 14:57:57	2020-04-30	Adriana Wintheiser	adriana.wintheiser@woohoo.com	Savannah	Georgia	4135282555136961	f697c476fc69faf2ecafcd67d9efdf70	VISA 13 digit	31.9836073976568862	-81.1566208636075288
22457	2020-04-30 15:32:07	2020-04-30	Vester Stokes	vester.stokes@geemail.com	Inglewood	California	210038880294971594	dd919d85615e31496d4e962630b324e4	VISA 16 digit	33.8762263176742948	-118.327058409902463
22458	2020-04-30 16:28:08	2020-04-30	Joseluis Schimmel III	joseluis.schimmel.iii@geemail.com	Washington	District of Columbia	3005183434390042	ff616a3b1b2e1876d73129a939a7a1e0	JCB 16 digit	38.9929828328810615	-77.0513061307583058
22459	2020-04-30 17:00:42	2020-04-30	Hallie Klein-Kulas	hallie.klein.kulas@geemail.com	San Francisco	California	4731395636293	6fb3420512c0a189b510cef9eb104b85	JCB 15 digit	37.7823081063629687	-122.402446707475775
22460	2020-04-30 17:05:37	2020-04-30	Latonya Howe	latonya.howe@geemail.com	Phoenix	Arizona	639011087818248	2bb01905e8ea3be9f8f9063ed2b091a9	Maestro	33.5495656278382981	-112.122102669898794
22461	2020-04-30 17:08:09	2020-04-30	Jude Grimes	jude.grimes@geemail.com	Scottsdale	Arizona	4832421648112458	73b4c453dc307eebe67a061c9aaffd5d	JCB 16 digit	33.7128743148066121	-111.902884314485263
22462	2020-04-30 17:13:57	2020-04-30	Dr. Milo Dare	dr.milo.dare@geemail.com	Carrollton	Texas	4245809423991537	abb98810c679295b81e212fb4862b229	VISA 13 digit	33.0210631158590289	-96.8479510741636176
22463	2020-04-30 17:32:26	2020-04-30	Dennis Collier	dennis.collier@geemail.com	Temecula	California	180030880362210063	be8fcdbff09b34a5aa32c73f5903fafb	VISA 16 digit	33.5599809927999928	-117.065046050884575
22464	2020-04-30 17:39:01	2020-04-30	Laney Howell	laney.howell@geemail.com	San Francisco	California	4354424405602925	08c57450a16cfe86a66a6f42fe52e6c2	Mastercard	37.7529029250371764	-122.433006305557583
22465	2020-04-30 17:46:14	2020-04-30	Bjorn Murray	bjorn.murray@geemail.com	New York	New York	51733635665276025	ce3015df0e01ac9a924a16db4dc9b033	VISA 13 digit	40.5693507970068623	-73.9456272266235146
22466	2020-04-30 17:59:42	2020-04-30	Keith Beier-Balistreri	keith.beier.balistreri@geemail.com	San Francisco	California	3785266308953228	fa3e9f5d689fc5852cb69054992bd09a	American Express	37.7875660088474206	-122.463976182001915
22467	2020-04-30 18:07:34	2020-04-30	Margot Zieme-Raynor	margot.zieme.raynor@geemail.com	Minneapolis	Minnesota	3096190449785495614	2b5b5cbcb17c1992a5b8a96493c385d1	Mastercard	45.0343480194538799	-93.3431600061517202
22468	2020-04-30 18:13:24	2020-04-30	Maleah Willms	maleah.willms@geemail.com	Mesa	Arizona	3747096681597772	c9d65a8d849137d95eb272ec08d23030	Mastercard	33.4374704119428969	-111.770753761788455
22469	2020-04-30 18:33:57	2020-04-30	Evan Kemmer	evan.kemmer@geemail.com	Palmdale	California	869902087960732514	cd9afb6c33601ff2b115555c86a4b0e8	JCB 15 digit	34.5168978656958814	-118.063857280788568
22470	2020-04-30 18:34:52	2020-04-30	Simmie Fadel	simmie.fadel@geemail.com	Burbank	California	4644136403490638	27dcb02edc1ce8a4d512bcf7b8a335f0	JCB 16 digit	34.140510482101142	-118.400330094484247
22471	2020-04-30 18:37:54	2020-04-30	Dr. Dewey Barton PhD	dr.dewey.barton.phd@geemail.com	Rancho Cucamonga	California	4045955199992	32831826b5fbfe052f706a3c8cd02b5e	VISA 16 digit	34.0650279009241643	-117.547777012037855
22472	2020-04-30 18:38:25	2020-04-30	Mr. Cicero Hansen	mr.cicero.hansen@geemail.com	New York	New York	52878972655542982	8d31893db2a40a4eee8f34134778cfca	Maestro	40.6306194344293345	-73.8462484093744251
22473	2020-04-30 18:42:49	2020-04-30	Iverson Crist	iverson.crist@geemail.com	Berkeley	California	6011824514553337738	1a3fd7b53e486ff99c97e99050d0e22a	American Express	37.8983586344265149	-122.273381513724757
22474	2020-04-30 18:48:26	2020-04-30	Rosaline Marvin	rosaline.marvin@geemail.com	Frisco	Texas	6011185939713595227	4ede9dc345ee107681a909e4df7e1986	VISA 16 digit	33.2289044210683571	-96.9037599747743457
22475	2020-04-30 18:55:55	2020-04-30	Doc Wehner	doc.wehner@woohoo.com	Hampton	Virginia	3035422735476468	90feca30ac471cd31d5cf02a9d5cf7e1	VISA 16 digit	37.0349060104712891	-76.2094215755447806
22476	2020-04-30 19:02:18	2020-04-30	Pearlene Moen	pearlene.moen@geemail.com	San Francisco	California	3112332641307221887	b5f5b8c25d276bfed4b73f578740e187	VISA 16 digit	37.7822891994033156	-122.415690181384562
22477	2020-04-30 19:25:35	2020-04-30	Evans Welch-Trantow	evans.welch.trantow@geemail.com	San Francisco	California	6011851916861842125	14edc91537993536236ecae8df2ccc24	VISA 16 digit	37.7762977022814752	-122.439098477967093
22478	2020-04-30 19:25:48	2020-04-30	Shirl Renner PhD	shirl.renner.phd@woohoo.com	San Francisco	California	869906132899990670	114e3253e7ae226941a80a30411187bd	VISA 16 digit	37.8180272032905194	-122.47638936421194
22479	2020-04-30 19:28:49	2020-04-30	Dr. Dow Bauch Sr.	dr.dow.bauch.sr.@geemail.com	New York	New York	869917548580447588	c21912d444c4a34fe343e4fe34e0a785	Voyager	40.5799213302079593	-74.0214089676167788
22480	2020-04-30 19:29:58	2020-04-30	Betty Purdy	betty.purdy@geemail.com	New York	New York	6011733386331935368	0e0e819b97d23e4519e870805e60e0da	Diners Club / Carte Blanche	40.6058518352210527	-74.0149573693878864
22481	2020-04-30 19:37:03	2020-04-30	Harlie Dickinson III	harlie.dickinson.iii@geemail.com	Scottsdale	Arizona	3337816457720785134	d804c118d4281dfc4bee2cca5de63d6b	Mastercard	33.6032944324083616	-111.924935922162973
22482	2020-04-30 19:39:29	2020-04-30	Miss Jesse Kemmer DDS	miss.jesse.kemmer.dds@geemail.com	Seattle	Washington	3337656162788820137	2e289e0b5afbc1b980f82215c449b22c	JCB 16 digit	47.5985494053382396	-122.387585352725907
22483	2020-04-30 19:41:13	2020-04-30	Ouida Morissette	ouida.morissette@woohoo.com	San Diego	California	6011009648790466244	9ed79ce405dab1a5217e2c1f12f69372	JCB 15 digit	32.8777321872368447	-117.179560338370507
22484	2020-04-30 19:44:41	2020-04-30	Tevin Funk	tevin.funk@geemail.com	Columbia	South Carolina	180010620291900952	f593234b6072f88d5bf7dcd2e1973452	American Express	34.1192800001505745	-80.903535756889724
22485	2020-04-30 19:54:04	2020-04-30	Lainey VonRueden	lainey.vonrueden@geemail.com	Miami	Florida	3753335876570157	7cae0390626b59678745463fd22766db	Voyager	25.8091012971613587	-80.3058794880159184
22487	2020-04-30 19:56:35	2020-04-30	Dolly Klein	dolly.klein@geemail.com	New York	New York	4102806746107	ff0fd7c2f501d3c3c6f7fbb92656f28b	Maestro	40.6818080504182689	-73.9111777529016081
22488	2020-04-30 20:19:05	2020-04-30	Candido Collins-Gulgowski	candido.collins.gulgowski@geemail.com	Irving	Texas	6011949848906255837	77dfdbfb1b3f690d5848fd70c13535e8	VISA 13 digit	32.9306547622613621	-96.8753169111721206
22489	2020-04-30 20:25:06	2020-04-30	Janiya Dibbert	janiya.dibbert@geemail.com	Provo	Utah	180007457916607026	dfc20dc60c13e48c9f1c1e6f44e6615e	Diners Club / Carte Blanche	40.307558814787491	-111.644309642273186
22490	2020-04-30 20:26:28	2020-04-30	Burl Doyle	burl.doyle@geemail.com	San Francisco	California	3112489053640690623	fed54d32d20dad7372400c34de1811b0	JCB 16 digit	37.8072426431649973	-122.422454693663866
22491	2020-04-30 20:29:16	2020-04-30	Mrs. Dawna Parker PhD	mrs.dawna.parker.phd@geemail.com	League City	Texas	6011798072278988766	c83ca4213aff109f113962b4d38c0deb	JCB 16 digit	29.455569997888432	-95.0167245961245186
22492	2020-04-30 20:48:06	2020-04-30	Jaheim Kerluke	jaheim.kerluke@geemail.com	Jacksonville	Florida	3337851743908543684	8c80bf6627547a98c596f0d4ae2c5d60	VISA 13 digit	30.35555136078559	-81.6835549099914857
22493	2020-04-30 20:54:08	2020-04-30	Kaci Spencer-Wolf	kaci.spencer.wolf@geemail.com	Berkeley	California	3528357044745387255	72225a53880779889fb398219578c393	Maestro	37.8766582331098505	-122.289443305123228
22494	2020-04-30 21:07:32	2020-04-30	Paulette Anderson MD	paulette.anderson.md@geemail.com	Los Angeles	California	3158068342949732916	8def87ae2a1bdfa6e9c797262d69488b	VISA 16 digit	34.0151230320200284	-118.450895826704055
22495	2020-04-30 21:10:14	2020-04-30	Venie Lehner	venie.lehner@geemail.com	Las Vegas	Nevada	3158299546703131948	95a7481a8d35561343a63081f84047f0	Mastercard	36.1856162715803791	-115.200759681847316
22496	2020-04-30 21:21:51	2020-04-30	Daneen Rippin	daneen.rippin@geemail.com	Vancouver	Washington	4265989997748441	6ecc2e5d60df93ba8cf43ac889d931ec	JCB 15 digit	45.7203471410159068	-122.575000401732325
22497	2020-04-30 21:45:25	2020-04-30	Kathrine Ortiz	kathrine.ortiz@warmmail.com	Plano	Texas	3059796542457852	5977dd40409af014099cb4175b32df86	American Express	33.0010831748686755	-96.6645723347268984
22498	2020-04-30 21:54:14	2020-04-30	Dr. Baron Kulas	dr.baron.kulas@woohoo.com	Atlanta	Georgia	54409697163744089	357699fe05c5e9ac5852c12ff314d208	VISA 13 digit	33.7853209014792029	-84.4145478669133098
22499	2020-04-30 22:02:31	2020-04-30	Jax Hettinger-Schmidt	jax.hettinger.schmidt@geemail.com	San Francisco	California	3528583801139435099	d3571067b1d92d06a22698b452d3b549	Diners Club / Carte Blanche	37.7619999234988768	-122.451684187904647
22500	2020-04-30 22:13:47	2020-04-30	Dasia Macejkovic	dasia.macejkovic@woohoo.com	Atlanta	Georgia	3799237788799500	e4a76a92285c6110e01485fb67004b58	Discover	33.746725045172127	-84.4405938570432397
22501	2020-04-30 22:15:18	2020-04-30	Aurthur Kutch	aurthur.kutch@geemail.com	Fort Worth	Texas	3025657708310620	9ff7f04d185d80becc16419390c87428	Maestro	32.7985848127454531	-97.379664533194898
22502	2020-04-30 22:16:49	2020-04-30	Nestor Gerhold-Kirlin	nestor.gerhold.kirlin@geemail.com	Buffalo	New York	210054723166326464	f3c716f0c3da1cbe6aba6a52591b3c0f	Diners Club / Carte Blanche	42.9770127890352143	-78.9445122867755629
22503	2020-04-30 22:17:30	2020-04-30	Ms. Nona Larson DVM	ms.nona.larson.dvm@warmmail.com	Dallas	Texas	53453691090814276	24405f3da0d0a7dd1122373ee62b5d85	American Express	32.7716576213289059	-96.6851856901738671
22504	2020-04-30 22:18:25	2020-04-30	Paola Casper	paola.casper@geemail.com	Costa Mesa	California	502076088062476	be2e1041dc1821d09b3bd0a8e6c85ff0	JCB 15 digit	33.606017460768669	-117.968303005011009
22505	2020-04-30 22:21:27	2020-04-30	Mrs. Evelynn DuBuque DVM	mrs.evelynn.dubuque.dvm@geemail.com	Columbus	Ohio	4397200813880165	8180edafabda14e76ecc9ab2e478c750	JCB 15 digit	40.0110028917014589	-82.9410018949538568
22506	2020-04-30 22:27:20	2020-04-30	Dr. Burnell Tillman	dr.burnell.tillman@warmmail.com	West Jordan	Utah	6011146209770012773	20fcbdddaf1e9979614f66a4bdd6b53a	American Express	40.5867363649677486	-112.048064265874402
22507	2020-04-30 22:38:21	2020-04-30	Rigoberto Pfeffer	rigoberto.pfeffer@geemail.com	Indianapolis	Indiana	676113609763035	b469a76036acc4f4e1e836b43f2f590e	Mastercard	39.7169306444942904	-86.1802341906089282
22508	2020-04-30 22:44:13	2020-04-30	Gary Gottlieb	gary.gottlieb@geemail.com	San Francisco	California	4670425279801680	8df8eb4dd07d6140b06269a39dc3cf38	JCB 16 digit	37.7408962357711815	-122.426057681768853
22509	2020-04-30 23:00:56	2020-04-30	Mr. Ali O'Reilly	mr.ali.o'reilly@warmmail.com	Saint Paul	Minnesota	6011200206030602180	8f271aa22a359a24c3b9ed3f18aa66de	VISA 16 digit	44.9570216592807341	-93.1166805791467453
22510	2020-04-30 23:18:23	2020-04-30	Adelard Fisher	adelard.fisher@geemail.com	El Paso	Texas	4619034062266376	e09316ea39b0064738766642871dab09	Discover	31.8893850020427259	-106.336267279226334
22511	2020-04-30 23:21:43	2020-04-30	Edwina Klein DDS	edwina.klein.dds@geemail.com	San Antonio	Texas	3043086342905292	059014c20dcf5dbd4130afbebde22a21	VISA 16 digit	29.5416050809506316	-98.5533747228164145
22512	2020-04-30 23:28:01	2020-04-30	Dr. Booker McDermott PhD	dr.booker.mcdermott.phd@geemail.com	Long Beach	California	6011921155458866538	0302b08f04424ddb7086e4081d3a6150	American Express	33.9088955432929069	-118.168223901900646
22513	2020-04-30 23:54:30	2020-04-30	Dawne Kihn	dawne.kihn@geemail.com	San Francisco	California	54615567129010190	2fa61cc50c2b056dd42fddc969eb3206	Maestro	37.7460717027459225	-122.441609235393244
22514	2020-04-30 23:58:28	2020-04-30	Mr. Leland Kutch MD	mr.leland.kutch.md@geemail.com	San Francisco	California	4155555276734	bd5d712d0a3f0aefdf77490cd967205f	Mastercard	37.7491714791774413	-122.432763597410769
22515	2020-05-01 00:09:02	2020-05-01	Ms. Ragna Gusikowski	ms.ragna.gusikowski@geemail.com	San Francisco	California	4051753681428027	82d2a2a76cb6dc8251df8d756b9dcbe2	Maestro	37.7760945619913926	-122.481996259019468
22516	2020-05-01 00:18:32	2020-05-01	Miss Noretta Krajcik	miss.noretta.krajcik@geemail.com	San Francisco	California	180025555377922665	21609fbbe8cb11d8cdf7e397830ae98c	Maestro	37.7836381736372857	-122.445678382238583
22517	2020-05-01 00:23:50	2020-05-01	Kamryn Lind-Leannon	kamryn.lind.leannon@geemail.com	Indianapolis	Indiana	6011822783606144076	390ca113f2b6fd91c1cb69acfce9d551	JCB 16 digit	39.8147942217074302	-86.1752614624068087
22518	2020-05-01 00:35:29	2020-05-01	Eugenie Stehr	eugenie.stehr@geemail.com	San Francisco	California	869939028570204749	d8c51d7bbd98675dfd8897335b267dc6	Diners Club / Carte Blanche	37.7625704240584454	-122.441058506205849
22519	2020-05-01 00:57:01	2020-05-01	Aleena Mann	aleena.mann@geemail.com	San Francisco	California	4146478525628163	4cfff0e4ef313120b017d0df3bb4006f	VISA 16 digit	37.7524023946142933	-122.419580665388281
22520	2020-05-01 01:09:08	2020-05-01	Shanelle Hand	shanelle.hand@geemail.com	Cincinnati	Ohio	3528491756744449987	afe768ffa0f7b95ebc672cf059f308a2	Discover	39.1191457237813651	-84.50657989841811
22521	2020-05-01 01:19:26	2020-05-01	Corliss Koch	corliss.koch@geemail.com	Tyler	Texas	3793758314173338	4ff80de6512d8cf1308b8a3f7a2d5fc3	Diners Club / Carte Blanche	32.3701227943927066	-95.2076744750250015
22522	2020-05-01 01:19:45	2020-05-01	Jesse Koelpin-Orn	jesse.koelpin.orn@woohoo.com	Austin	Texas	4537270414775040	b988fcb9c7da93978f0445419774ef0b	JCB 15 digit	30.219500610058752	-97.7783467735868044
22523	2020-05-01 01:23:16	2020-05-01	Juanita Jacobson	juanita.jacobson@geemail.com	Santa Ana	California	3022696564934217	f1185c78fe535e5ab0462d5a70bd429f	American Express	33.7315881229575751	-117.935814529696472
22524	2020-05-01 01:29:44	2020-05-01	Mr. Odus Aufderhar I	mr.odus.aufderhar.i@geemail.com	League City	Texas	3033191877710198	5844d84bbe20c8805b92281829b6a7aa	Discover	29.5494012434430431	-95.1537711807511783
22525	2020-05-01 01:36:11	2020-05-01	Clayton Strosin	clayton.strosin@geemail.com	El Paso	Texas	3528745845909019877	48035613571e0976700a862541e4b878	JCB 16 digit	31.8742123560342954	-106.339738517252741
22526	2020-05-01 01:42:33	2020-05-01	Dr. Cassie Funk DDS	dr.cassie.funk.dds@geemail.com	Eugene	Oregon	3793083038553545	b4fca3a7a185327d57033e2c4bd64a6c	JCB 15 digit	44.0978248303018532	-123.132243010773138
22527	2020-05-01 01:51:57	2020-05-01	Dirk Conn-Prohaska	dirk.conn.prohaska@geemail.com	Roseville	California	3008908811222336	0c55a55d6c8f36516bc92b7138ed73f4	Maestro	38.7657457816936031	-121.269163643963267
22528	2020-05-01 01:58:19	2020-05-01	Evalena Watsica	evalena.watsica@geemail.com	Renton	Washington	561274239199347	a28e7225d4c8f331693afc8f157f8af2	VISA 16 digit	47.5353802109196835	-122.190078958550458
22529	2020-05-01 02:16:46	2020-05-01	Oley Kris	oley.kris@woohoo.com	Houston	Texas	4737356968104923	4a85136f535d3babcfa9fee8ad7b4c34	JCB 15 digit	29.7969669210802763	-95.4081359688673132
22530	2020-05-01 02:19:32	2020-05-01	David Huels III	david.huels.iii@warmmail.com	New Haven	Connecticut	4332173228005	7091e80b281c69a339b37f877381b80e	Maestro	41.2307305627960687	-72.9589353408664465
22531	2020-05-01 02:21:51	2020-05-01	Mrs. Ara Sipes	mrs.ara.sipes@geemail.com	Stockton	California	3008154314366193	a586bf994e0100f21ef95de8b26322a2	JCB 16 digit	38.0560672612126965	-121.301793849616502
22532	2020-05-01 02:37:26	2020-05-01	Octavia Kirlin	octavia.kirlin@geemail.com	Philadelphia	Pennsylvania	3528829351536958719	4223d6e7d28ad71fe2d8cf507dd71e8b	Maestro	39.9414806797593798	-75.1270456597574139
22533	2020-05-01 02:46:10	2020-05-01	Dominick Ernser	dominick.ernser@geemail.com	San Jose	California	4827128090186	81bd6ce1098f0e9bb644a8d380ae0947	American Express	37.2038324808523058	-121.831390370543673
22534	2020-05-01 02:49:20	2020-05-01	Hobart Haag	hobart.haag@warmmail.com	Anchorage	Alaska	869979673279439327	c22f9831510850e181781cec9a5a2201	American Express	61.2638234744064505	-149.374508865422769
22535	2020-05-01 02:50:45	2020-05-01	Deidra Glover	deidra.glover@geemail.com	Cambridge	Massachusetts	3096848781450407672	667214a37369b714f512964a99bd0d74	American Express	42.3175083973668507	-71.1354776385322225
22536	2020-05-01 03:15:17	2020-05-01	Zayden McClure MD	zayden.mcclure.md@geemail.com	Augusta	Georgia	869910553018202347	767134322109f7a5368d3049ce26bd34	JCB 15 digit	33.4119889724273236	-82.0916526329997964
22537	2020-05-01 03:24:04	2020-05-01	Derrek Hammes	derrek.hammes@geemail.com	New York	New York	4977067395094	c13d518967c70ccd0d9c9bda91beb97c	Discover	40.6321345970258108	-73.9105458754010414
22538	2020-05-01 03:33:54	2020-05-01	Dr. Madaline Bosco PhD	dr.madaline.bosco.phd@warmmail.com	San Francisco	California	4163382809916815	5c2c0f6a9fb3455823df7ad996ff78b4	JCB 16 digit	37.8075484882921202	-122.430785290128341
22539	2020-05-01 03:38:09	2020-05-01	Mr. Jeramy Legros	mr.jeramy.legros@geemail.com	Berkeley	California	3158281447910470031	1e46aff1bd9961a6a62c09ca3beb6389	Discover	37.8433879874760919	-122.262441243120577
22540	2020-05-01 03:47:21	2020-05-01	Mal Rutherford	mal.rutherford@geemail.com	Clearwater	Florida	3337151826810323217	92b595edabdafdc52ca46c7136723845	Maestro	27.8866422140631833	-82.7546390101112337
22541	2020-05-01 03:52:43	2020-05-01	Mr. Mearl Kunze	mr.mearl.kunze@geemail.com	Columbus	Ohio	180047850045494260	5e9c08bd2f8717291d4cf558a5a8a60c	VISA 16 digit	39.9234681556511646	-83.028256768011687
22542	2020-05-01 03:53:09	2020-05-01	Teela Dibbert	teela.dibbert@geemail.com	Phoenix	Arizona	210024563326925871	15c8fc42027d6be731fd310413435ff2	VISA 13 digit	33.580364175320419	-112.022865693590049
22543	2020-05-01 04:09:00	2020-05-01	Dr. Clarissa Monahan DDS	dr.clarissa.monahan.dds@warmmail.com	Detroit	Michigan	3096712072133292027	65436fcef66477502540ce71d1ca48b8	Maestro	42.3352184872534139	-83.0585193229027112
22544	2020-05-01 04:14:09	2020-05-01	Santiago Crist	santiago.crist@geemail.com	San Francisco	California	3013597693773634	99a815243b15ec22e73c0019d9a06691	JCB 16 digit	37.7784066124679185	-122.413364206186671
22545	2020-05-01 04:21:29	2020-05-01	Concetta Moore-Kuphal	concetta.moore.kuphal@woohoo.com	Winston–Salem	North Carolina	180091395069682098	6d8122bb1dc86fdc0ebe2f877767ac9f	Discover	36.0557296976212385	-80.2952806620988895
22546	2020-05-01 04:23:37	2020-05-01	Dr. Murl Becker	dr.murl.becker@woohoo.com	Riverside	California	4632795798321	170f43a3bd577b675bae4fd17a71c22d	Voyager	33.8626333118829876	-117.343112956636389
22547	2020-05-01 04:26:16	2020-05-01	Jeffry Hodkiewicz	jeffry.hodkiewicz@geemail.com	Houston	Texas	869930330434769753	705e0b605a82a5289b001f08cd3086e4	VISA 16 digit	29.6961331263262771	-95.4235363523025057
22548	2020-05-01 04:27:41	2020-05-01	Agustus Murazik	agustus.murazik@geemail.com	San Diego	California	3112681203084521299	0741791f7d860d3deed8afaa94f624cd	American Express	32.775467590668427	-117.214537018528219
22549	2020-05-01 04:31:01	2020-05-01	Mr. Clive Goldner	mr.clive.goldner@woohoo.com	Chesapeake	Virginia	6011915409252173262	8ab5980851118ebb7f512da5b8917543	JCB 16 digit	36.7477743270579751	-76.2623984427500545
22550	2020-05-01 04:32:42	2020-05-01	Dr. Lena Bernhard DDS	dr.lena.bernhard.dds@geemail.com	Los Angeles	California	3008475861469712	74976b604235cb5b342b046658e7530d	JCB 16 digit	34.0335888174694006	-118.331735330213974
22551	2020-05-01 04:44:20	2020-05-01	Rosa Keeling	rosa.keeling@woohoo.com	Worcester	Massachusetts	4337424666540782	c3f2c3079ad056c9374f6243a920614a	Mastercard	42.2028612186368548	-71.7372348196592213
22552	2020-05-01 04:54:42	2020-05-01	Brisa Watsica	brisa.watsica@geemail.com	Eugene	Oregon	6011725568755594272	ca1f4e4a7ac1642c0ceea7d2562454e2	Maestro	44.0689419745661297	-123.054510765847567
22553	2020-05-01 04:54:44	2020-05-01	Miss Jolette Carroll DVM	miss.jolette.carroll.dvm@geemail.com	Tucson	Arizona	53634679405338281	e03df2beb8eb75fd1f6964fa064bfb97	JCB 16 digit	32.0717800453346271	-110.879124807449429
22554	2020-05-01 05:03:06	2020-05-01	Tara Stracke	tara.stracke@woohoo.com	Los Angeles	California	675904457318212	9f2e9e1de73bc28c1bd21be6a240afd1	JCB 15 digit	33.9657339599315051	-118.466790005843336
22555	2020-05-01 05:04:05	2020-05-01	Roxann Yundt	roxann.yundt@geemail.com	Chicago	Illinois	6011968681980546508	f89ac83ef48aea01bf9ebfeeed8e09d3	JCB 15 digit	41.7456970420967792	-87.757461164801569
22556	2020-05-01 05:25:36	2020-05-01	Dr. Katelyn Hirthe	dr.katelyn.hirthe@geemail.com	Chandler	Arizona	3053841028410094	bc1dab7da0c571f410bb5be06a5d21e9	JCB 16 digit	33.3445589741315658	-111.810270336957274
22557	2020-05-01 05:26:21	2020-05-01	Theadore Jacobs	theadore.jacobs@geemail.com	Austin	Texas	503880707101699	32e93916b979012a3561b161eb6f24db	VISA 16 digit	30.3808453094340862	-97.7775863063760085
22558	2020-05-01 05:41:07	2020-05-01	Benjaman Baumbach	benjaman.baumbach@geemail.com	Colorado Springs	Colorado	3158284235769339200	49d00333a0c9d7546523ad5b679b0700	VISA 13 digit	38.9476446903824822	-104.73241777761541
22559	2020-05-01 05:45:20	2020-05-01	Acey Luettgen PhD	acey.luettgen.phd@woohoo.com	Fort Worth	Texas	4227027769636	6a41e23ce16de1df77ec27ad4a30a4ae	Voyager	32.7253918204512431	-97.3475472312707382
22560	2020-05-01 05:59:09	2020-05-01	Miss Rhiannon Wunsch	miss.rhiannon.wunsch@geemail.com	Washington	District of Columbia	4729894199292	6cf7e319bc762db0c4b25b3a2fc941c7	American Express	38.8550829937946034	-77.0241893186446305
22561	2020-05-01 06:15:10	2020-05-01	Delma Howell DVM	delma.howell.dvm@woohoo.com	New York	New York	54173205664941958	7e18018d900bd9edca873db8202b82a5	Mastercard	40.5980612224657094	-73.9178763431858243
22562	2020-05-01 06:19:18	2020-05-01	Judi Prosacco	judi.prosacco@geemail.com	Phoenix	Arizona	3112775587396403924	351ec94f727ab7bcdc5ddf43f6a0c0bc	Maestro	33.5234333320453786	-112.03786533772238
22563	2020-05-01 06:24:29	2020-05-01	Daja Balistreri	daja.balistreri@geemail.com	Washington	District of Columbia	4680925915197789	457a062d2723f122be257fe307ab57ca	JCB 16 digit	38.9176222797282065	-77.0485508444931355
22564	2020-05-01 06:26:26	2020-05-01	Kloe Wisozk	kloe.wisozk@geemail.com	Fayetteville	North Carolina	6011015714730843082	8deae01011074ddad47482952dbfe149	VISA 16 digit	35.1089749248486029	-78.8910184209831016
22565	2020-05-01 06:29:28	2020-05-01	Corry Wehner	corry.wehner@geemail.com	San Francisco	California	3096249416838441219	d476b7a0d87112a8a56e80aa17b0e682	VISA 13 digit	37.7693803423419965	-122.449370814560112
22566	2020-05-01 06:31:12	2020-05-01	Holden Weissnat	holden.weissnat@geemail.com	Charlotte	North Carolina	4222607109967814	b196c8adae636911ddf6967241570de1	VISA 16 digit	35.2026302768636512	-80.8777141401488393
22567	2020-05-01 06:48:35	2020-05-01	Raekwon Pfannerstill-Stracke	raekwon.pfannerstill.stracke@geemail.com	New York	New York	4622949462111739	460ded44fcedfd43271a491d0b27d090	Mastercard	40.738938693305478	-74.0276786855783229
22568	2020-05-01 06:55:56	2020-05-01	Rhea Lemke	rhea.lemke@geemail.com	San Francisco	California	4063176280268287	890b4871ec78fbb68ce1e23174e37ea6	Discover	37.809632635500968	-122.479668227258784
22569	2020-05-01 06:56:07	2020-05-01	Britany Schinner	britany.schinner@geemail.com	Clarksville	Tennessee	4257469164962	ef5f14db3911e4a89dfb659adb073dc7	Maestro	36.6331011006735281	-87.3003679461263147
22570	2020-05-01 06:57:29	2020-05-01	Danny Konopelski	danny.konopelski@woohoo.com	Detroit	Michigan	6011728664777713763	7162b7f48607d63bed3424c5d901df67	JCB 16 digit	42.3780624395627541	-83.0202775460321476
22571	2020-05-01 07:00:27	2020-05-01	Elvia White	elvia.white@geemail.com	Scottsdale	Arizona	3112383786962893641	7665beb6b4481a75fd52e614e2584b37	American Express	33.7167134200811418	-111.824718971360838
22572	2020-05-01 07:02:50	2020-05-01	Dr. Dontae Reichert Sr.	dr.dontae.reichert.sr.@woohoo.com	Modesto	California	3472096078865012	c6c514dc179984bcd765e356de3960aa	American Express	37.5930314382538242	-121.054730876183143
22573	2020-05-01 07:18:12	2020-05-01	Cornelia Walsh	cornelia.walsh@warmmail.com	Ventura	California	676130781440661	5704fa8158bac53f651ccdee53401760	Discover	34.3081374833986175	-119.319535466433308
22574	2020-05-01 07:23:41	2020-05-01	Juli Bergstrom	juli.bergstrom@geemail.com	Fort Worth	Texas	4976555560552310	43ce1342b1de79de83d7373f99c36acf	Voyager	32.7914144499283324	-97.4156741149079011
22575	2020-05-01 07:35:19	2020-05-01	Shawnda O'Reilly	shawnda.o'reilly@warmmail.com	San Francisco	California	3021859321963140	1707ecf4230bf3161f98c8bdc825a863	JCB 16 digit	37.8002842607577421	-122.461270174757274
22576	2020-05-01 07:48:14	2020-05-01	Leah Kutch	leah.kutch@woohoo.com	Miami	Florida	3528466799297351292	0951bfa0121b3e3676718fc24741ab4d	Mastercard	25.7382732615012699	-80.2084048576526385
22577	2020-05-01 07:48:25	2020-05-01	Penny Ebert	penny.ebert@woohoo.com	Washington	District of Columbia	3406773266195714	a8d49f53b42ea03d7c25dc29330d6c22	JCB 15 digit	38.9716954573787717	-77.074454891330376
22578	2020-05-01 07:50:06	2020-05-01	Bettylou Carter DDS	bettylou.carter.dds@geemail.com	Los Angeles	California	3474160875232491	39213606fbd8a9038a57db19c7c16e6c	Maestro	33.9528417538717378	-118.500777027801789
22579	2020-05-01 07:53:22	2020-05-01	Averi Runolfsson-Williamson	averi.runolfsson.williamson@geemail.com	San Francisco	California	869954939788570509	17472afa2642fe504a68d39d473cda03	JCB 16 digit	37.7998052616450053	-122.44028868746274
22580	2020-05-01 07:58:58	2020-05-01	Nehemiah Toy	nehemiah.toy@geemail.com	Rialto	California	53168692962657039	51ac348a7d5211c75431b61b45756538	JCB 15 digit	34.0907677924010954	-117.350430199791859
22581	2020-05-01 08:05:03	2020-05-01	Ms. Keanna Toy MD	ms.keanna.toy.md@geemail.com	Houston	Texas	4429765657011103	2bae2353287b856514feb44b217574cd	JCB 16 digit	29.8345390450753278	-95.3984658740475737
22582	2020-05-01 08:09:53	2020-05-01	Mrs. Lourdes Cronin	mrs.lourdes.cronin@geemail.com	Chicago	Illinois	4861954838171169	3064e6e087b710c0e088c489e7e1d01e	JCB 15 digit	41.8421526515226816	-87.6240842306084886
22583	2020-05-01 08:15:15	2020-05-01	Ewart Erdman	ewart.erdman@warmmail.com	Winston–Salem	North Carolina	6011180708097967889	2e756e0b7ca292e7dc05a039a6e67d54	VISA 16 digit	36.079090707632524	-80.2381870540920659
22584	2020-05-01 08:23:15	2020-05-01	Sarrah Bogisich DDS	sarrah.bogisich.dds@geemail.com	Louisville	Kentucky	3088010253060739938	e69a6cc501d57a001251811ab3e6f9a2	JCB 16 digit	38.1309904144048701	-85.5592766427040203
22585	2020-05-01 08:27:07	2020-05-01	Clyda Auer-Padberg	clyda.auer.padberg@geemail.com	Bridgeport	Connecticut	4642577807447850	dff2e2d5b4b05132b6ed6d94cee8fc00	VISA 13 digit	41.1824963876675767	-73.2492393764566714
22586	2020-05-01 08:31:15	2020-05-01	Jahiem Gulgowski	jahiem.gulgowski@warmmail.com	Saint Paul	Minnesota	3035920700167756	6d40f496e6445f3f7769f553fdc23720	VISA 13 digit	45.024317257566004	-93.1654764768000661
22587	2020-05-01 08:35:28	2020-05-01	Keyshawn Hahn	keyshawn.hahn@geemail.com	Albuquerque	New Mexico	869995634064044342	c126bd6c5f25025e594f359265ed872c	VISA 16 digit	35.186376755558328	-106.626265691786642
22588	2020-05-01 08:40:54	2020-05-01	Ellen Nienow-Leffler	ellen.nienow.leffler@geemail.com	Columbus	Ohio	180002976405622001	a7d1fb5441f70dd7fc188e5141fd7a9b	VISA 16 digit	39.9329707054465999	-82.9704939524412168
22589	2020-05-01 08:48:36	2020-05-01	Lenna Gutkowski	lenna.gutkowski@geemail.com	San Antonio	Texas	589363233016169	36a068bb2dd677a5244befd96f1f179d	JCB 16 digit	29.5325509226486105	-98.5805982188623346
22590	2020-05-01 09:44:24	2020-05-01	Lilliana Gaylord-Beahan	lilliana.gaylord.beahan@woohoo.com	Tempe	Arizona	6011575717421763032	87fb40be563389677b310e9351e60509	Maestro	33.4482823917564005	-111.965855563155557
22591	2020-05-01 09:50:55	2020-05-01	Dr. Layla Kilback	dr.layla.kilback@woohoo.com	Midland	Texas	4639936915557	cefd38a188ac591aad6082034d03afe3	Maestro	31.9676750550702202	-102.09324366745912
22592	2020-05-01 10:00:57	2020-05-01	Diallo Durgan II	diallo.durgan.ii@geemail.com	Tulsa	Oklahoma	3025298591449454	bbf9887bfa9b67f58dd066553b2f385a	VISA 13 digit	36.1969297039691327	-95.8617892850145665
22593	2020-05-01 10:01:44	2020-05-01	Dell Jakubowski	dell.jakubowski@warmmail.com	Sandy Springs	Georgia	3088785314767823731	6d5275b7910c95273570d4898333673a	VISA 16 digit	33.9819994477611047	-84.281445388131587
22594	2020-05-01 10:06:35	2020-05-01	Lutie Schroeder	lutie.schroeder@geemail.com	Bellevue	Washington	3337725341986389692	ec315dbbcbba412743f34a7efeae92d6	American Express	47.6648580997433555	-122.209580265177408
22595	2020-05-01 10:44:48	2020-05-01	Florida Dietrich	florida.dietrich@geemail.com	Overland Park	Kansas	676183619118132	9c4de2e6298d73a518479adc82ed23bc	Discover	38.8221628933083309	-94.7854916639667096
22596	2020-05-01 10:46:22	2020-05-01	Caesar Johns	caesar.johns@geemail.com	Fort Worth	Texas	3112573710222197098	8d2ba46540d6537c0b789078f8d159de	JCB 16 digit	32.8355159975178523	-97.3325462212141588
22597	2020-05-01 10:48:53	2020-05-01	Miracle Kautzer	miracle.kautzer@geemail.com	Aurora	Colorado	180088559427024799	87eaabaa68b5467e6f71cb41cc978173	VISA 16 digit	39.6274112641457492	-104.641589093872156
22598	2020-05-01 11:03:58	2020-05-01	Simmie Renner-Howell	simmie.renner.howell@warmmail.com	San Francisco	California	869992638466407141	c8a7ca996ab221ea89faddd1ecfa993d	VISA 16 digit	37.7902339196854555	-122.438704958997775
22599	2020-05-01 11:05:48	2020-05-01	Phoebe Romaguera	phoebe.romaguera@warmmail.com	Frisco	Texas	52568402487730345	0a7a21e01fd6d5264942bcedc1451b78	Mastercard	33.0697355733249339	-96.7990995970297519
22600	2020-05-01 11:07:18	2020-05-01	Jake Daugherty	jake.daugherty@geemail.com	Allentown	Pennsylvania	3337227196095418904	cb70a7494a25a84ea02b133638dc80fd	JCB 16 digit	40.5789961484972395	-75.3893800561796752
22601	2020-05-01 11:10:40	2020-05-01	Tobie Bartell	tobie.bartell@geemail.com	Los Angeles	California	3337842039961631850	d01285c4d0a1f483b23c0dec95cb1e09	Discover	33.9768852918740336	-118.358376068900526
22602	2020-05-01 11:12:45	2020-05-01	Dr. Norval Prosacco DVM	dr.norval.prosacco.dvm@geemail.com	Palm Bay	Florida	4825332961610011	12af89113ea8cf8671baa41a6e3072ed	Voyager	27.9926328864734622	-80.7002617880072393
22603	2020-05-01 11:20:47	2020-05-01	Alessandra Jerde	alessandra.jerde@warmmail.com	San Francisco	California	3002265604712171	7a9220facc97cc7961604ff695bcc05e	JCB 15 digit	37.7898124250553664	-122.426742971335941
22604	2020-05-01 11:24:00	2020-05-01	Ms. Ally Sporer DVM	ms.ally.sporer.dvm@geemail.com	Scottsdale	Arizona	3043108348314335	76c3b87c766e6ff41392556ff343e6e8	Voyager	33.644594450772928	-111.777728501983347
22605	2020-05-01 11:26:28	2020-05-01	Chelsie Armstrong	chelsie.armstrong@warmmail.com	San Francisco	California	676178087789299	d9cd4b18d1e023b99a9b431a1009c769	Voyager	37.7424089379332841	-122.38755980051738
22606	2020-05-01 11:35:48	2020-05-01	Jayleen Leuschke DVM	jayleen.leuschke.dvm@geemail.com	Tyler	Texas	180069211382885367	1454ed181b8b059c608a98c655b36c72	Diners Club / Carte Blanche	32.3013436317492335	-95.2529129232853649
22607	2020-05-01 11:39:12	2020-05-01	Ms. Ilo Dach DVM	ms.ilo.dach.dvm@geemail.com	Phoenix	Arizona	4582354089671	25b88b3d2544def18065ac5374579410	JCB 16 digit	33.5999235910296434	-112.148947699128101
22608	2020-05-01 11:40:29	2020-05-01	Nasir Koepp	nasir.koepp@geemail.com	San Francisco	California	54117235124505753	b7a1fd43b7ffa0d13bfac3da4de1a83e	American Express	37.789260816592666	-122.415046754493929
22609	2020-05-01 11:47:52	2020-05-01	Faron Dooley	faron.dooley@geemail.com	Brownsville	Texas	869925628515013729	ea9d625e2f00ebdc579de59418bdb633	VISA 16 digit	26.0093138141635798	-97.5529693919420282
22610	2020-05-01 11:52:53	2020-05-01	Yair Dooley	yair.dooley@geemail.com	San Francisco	California	54097605198858805	f1834f3aecd467dc13191e7d74f8819e	VISA 13 digit	37.8075198135152064	-122.428604320184846
22611	2020-05-01 12:01:27	2020-05-01	Mrs. Rikki Bradtke	mrs.rikki.bradtke@geemail.com	Minneapolis	Minnesota	3426731192922193	e10878e6e1ddee3783af9a1fac7d7c56	JCB 15 digit	44.9456615759145421	-93.3416190498314791
22612	2020-05-01 12:04:58	2020-05-01	Norwood Beahan	norwood.beahan@geemail.com	Scottsdale	Arizona	869955741177227926	ec8d6a447168a844f32ecd6e7c70d768	Voyager	33.5850157468237001	-111.864007740045338
22613	2020-05-01 12:11:17	2020-05-01	Fredie Carroll-Zulauf	fredie.carroll.zulauf@geemail.com	San Diego	California	4614009267312147	cc914bc13a7c58bd050cf66489db280f	Discover	32.7507664648883079	-117.202003345070409
22614	2020-05-01 12:12:27	2020-05-01	King Funk-Braun	king.funk.braun@geemail.com	San Francisco	California	6011588810859846539	974bdda70404c9d658cd0f05a0059d6d	VISA 16 digit	37.7810153064229439	-122.457778180533523
22615	2020-05-01 12:19:05	2020-05-01	Lowell Jacobi PhD	lowell.jacobi.phd@geemail.com	Indianapolis	Indiana	3004766949279360	fabb3bfd198b22adc90bcfd4a8baa518	JCB 16 digit	39.6955312604557733	-86.1831904555872086
22616	2020-05-01 12:25:46	2020-05-01	Mrs. Mckayla Huels	mrs.mckayla.huels@geemail.com	Pearland	Texas	6011708391438770917	517a9fdf231b09ce3293b1244468d253	VISA 16 digit	29.5393812834557146	-95.2537081308983176
22617	2020-05-01 12:29:57	2020-05-01	Jayvion Runolfsson	jayvion.runolfsson@geemail.com	Jacksonville	Florida	3497072791061214	1ee35ab94fbcc535f085d24ee0f966fa	VISA 16 digit	30.2516349973209202	-81.6381604586340615
22618	2020-05-01 12:33:29	2020-05-01	Haywood Hamill	haywood.hamill@geemail.com	Omaha	Nebraska	3096990210123564145	96ed24db426dee43972d424529a707df	VISA 13 digit	41.1938141593854894	-96.1380406697861929
22619	2020-05-01 12:33:59	2020-05-01	Miss Laurel Okuneva	miss.laurel.okuneva@geemail.com	Gilbert	Arizona	869951269240832302	00da2a4620a4fa22304314306343e1d3	Maestro	33.3585489093206817	-111.709390678828953
22620	2020-05-01 12:35:59	2020-05-01	Ean Prohaska	ean.prohaska@geemail.com	Columbus	Ohio	4815914040119	c41f65cdab3f39d24758af5b7ee804ac	JCB 16 digit	39.9892391555987317	-83.055008965474741
22621	2020-05-01 12:38:31	2020-05-01	Elenora Smitham	elenora.smitham@geemail.com	San Francisco	California	869942017557113481	b5d60623a26200059b0d3202fe50677e	JCB 16 digit	37.7735421809919956	-122.417224562689313
22622	2020-05-01 12:43:49	2020-05-01	Hartwell Boyer	hartwell.boyer@woohoo.com	Cleveland	Ohio	3096789078019803694	ec561010762c18a3329e14daf9a2f11b	JCB 16 digit	41.404623908301815	-81.6700782844569488
22623	2020-05-01 12:44:39	2020-05-01	Mr. Linton Raynor	mr.linton.raynor@geemail.com	San Francisco	California	3088796956715501889	fd147004e30ee3103179d388a91b80bc	Diners Club / Carte Blanche	37.7506442002745004	-122.485068234923261
22624	2020-05-01 12:45:45	2020-05-01	Essie Russel	essie.russel@geemail.com	New York	New York	6011149367070078147	dd84509aadf68c4f39d37be7a980a163	JCB 15 digit	40.702457537245003	-74.0270870457298997
22625	2020-05-01 12:50:44	2020-05-01	Breanna Wilderman	breanna.wilderman@geemail.com	Durham	North Carolina	3732431885828391	63f768bf956b24bf7dba9ae0306a6bea	Maestro	35.8899002168107728	-78.9351527024895034
22626	2020-05-01 12:54:44	2020-05-01	Carole Kreiger-Satterfield	carole.kreiger.satterfield@geemail.com	San Francisco	California	4169491351261	a881cae5934efe1e8b27630a63f9e4c8	Mastercard	37.818631655536997	-122.453034724625041
22627	2020-05-01 13:00:05	2020-05-01	Whit Gorczany	whit.gorczany@woohoo.com	West Covina	California	3337780768590251243	2ec95d684cca058990f2e602e9d3579b	JCB 15 digit	34.0720006855778408	-117.940264556657141
22628	2020-05-01 13:40:35	2020-05-01	Godfrey Bradtke	godfrey.bradtke@geemail.com	Chandler	Arizona	3096578384708369772	9b2dacfe6796cedf889d25561a1e2b44	Mastercard	33.1980013511233025	-111.896735302719847
22629	2020-05-01 13:41:12	2020-05-01	Adams Stoltenberg I	adams.stoltenberg.i@geemail.com	Clinton	Michigan	3009096312638991	59aab8421defea19d0ff2641859aa54a	Mastercard	42.6272080184958853	-82.9808981773518042
22630	2020-05-01 13:44:42	2020-05-01	Davonte Bradtke	davonte.bradtke@geemail.com	Columbus	Ohio	180022763380578978	7c76d5cee9f7dd0234bdf5135bb1c259	VISA 16 digit	39.9442672919992319	-83.0647580684863129
22631	2020-05-01 14:12:44	2020-05-01	Arlena Lubowitz	arlena.lubowitz@woohoo.com	Fresno	California	3112076439273928266	1679ead72a0dd510c92bd864d1ece724	Mastercard	36.7658108772583319	-119.806118664761641
22632	2020-05-01 14:16:37	2020-05-01	Mr. Maceo Schiller DDS	mr.maceo.schiller.dds@geemail.com	New York	New York	3048371548559613	03671184788a331ff9eb61417b41a50a	VISA 16 digit	40.6931970735304063	-73.9320009763713841
22633	2020-05-01 14:31:04	2020-05-01	Jaylin Mills	jaylin.mills@geemail.com	Fort Lauderdale	Florida	503804696134115	ae94ade68a6423cdd190b6386716d006	JCB 16 digit	26.209494797418639	-80.0507031388401913
22634	2020-05-01 14:40:26	2020-05-01	George Smith	george.smith@geemail.com	Oceanside	California	3096471985328594819	1a00b29d97cee22c760765394e65143b	Discover	33.1318620427865511	-117.264163957497857
22635	2020-05-01 14:43:59	2020-05-01	Abdullah Sawayn DDS	abdullah.sawayn.dds@geemail.com	Fort Worth	Texas	3088308567939877970	6f8e99a0607e4f7aae3b971a195bddf5	Maestro	32.7990873429514451	-97.3402265295207485
22636	2020-05-01 14:49:03	2020-05-01	Lucio Breitenberg-Douglas	lucio.breitenberg.douglas@geemail.com	Mesquite	Texas	3048953128528363	423e36d03a0fd572aba52d7db91ef724	JCB 16 digit	32.7711434058189397	-96.6363062548182938
22637	2020-05-01 14:50:01	2020-05-01	Sedrick Sawayn	sedrick.sawayn@geemail.com	San Francisco	California	6011362766115846220	7dd63ac32916c257d2bb22909ff6ec97	Diners Club / Carte Blanche	37.7581193896107195	-122.395987222399768
22638	2020-05-01 14:50:29	2020-05-01	Mr. Matt Schimmel Sr.	mr.matt.schimmel.sr.@geemail.com	Vista	California	3096963347084902121	116af82899bff2bd6e67c40e20794776	American Express	33.2644992309603893	-117.214499596698587
22639	2020-05-01 15:20:56	2020-05-01	Bristol Murphy	bristol.murphy@geemail.com	San Antonio	Texas	4994778781033	0513c9784518a5d0e13c97d158bde23f	VISA 13 digit	29.3782182285167295	-98.5469991248402692
22640	2020-05-01 15:25:10	2020-05-01	Dr. Lizabeth Sanford DVM	dr.lizabeth.sanford.dvm@geemail.com	Nashville	Tennessee	869926032050720211	1196a05c72e233e9608705b7381dfcf8	Diners Club / Carte Blanche	36.1253166727844572	-86.8595499483309652
22641	2020-05-01 15:30:58	2020-05-01	Dr. Henri Cremin	dr.henri.cremin@geemail.com	San Francisco	California	54087042200481487	2a5ca84a03c870aabc09160b52083e6e	Diners Club / Carte Blanche	37.7528242865946737	-122.44629813980184
22642	2020-05-01 15:39:12	2020-05-01	Hershell Gottlieb-Okuneva	hershell.gottlieb.okuneva@geemail.com	Lincoln	Nebraska	4509450065623517	7cb7e8cef5cc18d57e3d3cbb9c5e2487	JCB 15 digit	40.7222004144471086	-96.7187650109335806
22643	2020-05-01 15:48:11	2020-05-01	Litha Krajcik	litha.krajcik@geemail.com	San Francisco	California	53124241443661856	26d3773095024762f5640b8c5a0a1ecf	JCB 15 digit	37.7732748229353632	-122.428271443382599
22644	2020-05-01 15:50:15	2020-05-01	Dr. Gee Schamberger DDS	dr.gee.schamberger.dds@geemail.com	Atlanta	Georgia	4737790820198964	5d061811a52ea5d78ba0a3a2c3ef71be	JCB 15 digit	33.7057944540210102	-84.3685322627935648
22645	2020-05-01 15:54:16	2020-05-01	Whitney Watsica III	whitney.watsica.iii@woohoo.com	Raleigh	North Carolina	4203923449225935	ac75624d2861a8f17a13936d95df991b	Discover	35.8916729856882242	-78.5836017442803865
22646	2020-05-01 16:03:38	2020-05-01	Sheridan Mayer DVM	sheridan.mayer.dvm@woohoo.com	Fresno	California	3761456308209386	a88a2b259e5585c441fe60c50cd45d34	Diners Club / Carte Blanche	36.8484918232414884	-119.794005211453523
22647	2020-05-01 16:27:53	2020-05-01	Dillan Huels	dillan.huels@geemail.com	Athens	Georgia	676136945370827	d455065aac30db8856844a8b065509f6	VISA 16 digit	33.9967644268836793	-83.4593276057507722
22648	2020-05-01 16:48:29	2020-05-01	Ephram Gerhold	ephram.gerhold@geemail.com	Los Angeles	California	3088575457910243200	8b4c48b3ec1a3d1b54d7d8dccadddf64	Discover	34.1063296733755621	-118.346784377283598
22649	2020-05-01 16:48:42	2020-05-01	Gilberto Watsica Jr.	gilberto.watsica.jr.@geemail.com	Tyler	Texas	3431702004825489	0a57f1d069ee872e324fe67af3ca9dd0	VISA 13 digit	32.3788693384315849	-95.2501514172755179
22650	2020-05-01 16:50:14	2020-05-01	Zoey Kovacek	zoey.kovacek@warmmail.com	Yonkers	New York	6011720033197874894	189917ad41e2fa12a6d009b5724cd26b	Diners Club / Carte Blanche	40.9208322407878953	-73.8182721798192745
22651	2020-05-01 16:51:30	2020-05-01	Liston Cronin	liston.cronin@warmmail.com	Santa Maria	California	3053268711114538	d0f8f52192a04b7cb831f5f32cac061d	VISA 16 digit	34.9826181767571711	-120.346899512541668
22652	2020-05-01 16:57:13	2020-05-01	Stephania Schuppe	stephania.schuppe@warmmail.com	Nashville	Tennessee	4537509521655	6ab0faad7a08fc4bd1eacf557da35cfc	American Express	36.1541064360767592	-86.8813162455707726
22653	2020-05-01 17:12:07	2020-05-01	Jerrold Stark	jerrold.stark@geemail.com	El Paso	Texas	3337450979444746820	5a27cbcdce6bcdf3ec2a1bc104385566	Mastercard	31.8069916445590586	-106.478654087379581
22654	2020-05-01 17:17:28	2020-05-01	Ms. Cherish White MD	ms.cherish.white.md@warmmail.com	Los Angeles	California	4609476493455	70da28a6259e76fd24a13d3aefd4d6b7	Mastercard	33.9465275987848614	-118.373300117206938
22655	2020-05-01 17:23:24	2020-05-01	Judy Ziemann	judy.ziemann@geemail.com	Baltimore	Maryland	54705906068457775	538b4e211017a9691d676ff683d6179a	JCB 16 digit	39.3332017041277098	-76.6541244240496269
22656	2020-05-01 17:32:16	2020-05-01	Maria Breitenberg	maria.breitenberg@warmmail.com	Knoxville	Tennessee	6011514591303560509	8bd18605d0d4561d1f10b1dc826dd8b8	Discover	35.9503264834701994	-83.9794868358161182
22657	2020-05-01 17:39:25	2020-05-01	Nylah Hyatt DDS	nylah.hyatt.dds@geemail.com	Hayward	California	6011623113580130258	a7801064b7051475156ed10932d63707	American Express	37.7108018184535254	-122.201376072994989
22658	2020-05-01 18:02:33	2020-05-01	Della O'Kon	della.o'kon@geemail.com	Allen	Texas	3798703954479715	38e3efd447829b8adba090ec29630cd3	JCB 16 digit	33.0721983439780729	-96.7255274606350781
22659	2020-05-01 18:07:23	2020-05-01	Ms. Sonji Barrows	ms.sonji.barrows@woohoo.com	Oakland	California	6011566895411266256	e30564a9c65ae8737366f79d4bc72b65	VISA 16 digit	37.7763810461476908	-122.259018219988775
22660	2020-05-01 18:17:47	2020-05-01	Dr. Mittie Lesch	dr.mittie.lesch@geemail.com	San Francisco	California	3704947213773995	03b2567f8606d5b9ccf22ffe346422e6	JCB 15 digit	37.7477915849786925	-122.420451312760562
22661	2020-05-01 18:23:02	2020-05-01	Hill Stehr	hill.stehr@geemail.com	Charleston	South Carolina	3797187311706807	abdc7e8f2028c8b3f9d0b2a445cdd2c9	VISA 16 digit	32.9007192584682286	-79.9536320691611593
22662	2020-05-01 18:23:45	2020-05-01	Lisha Hoppe	lisha.hoppe@warmmail.com	Davenport	Iowa	3032790488434261	749509ab74fb14ab31547276deb9f225	Voyager	41.6445078617691991	-90.6434151847343941
22663	2020-05-01 18:24:50	2020-05-01	Dr. Fisher DuBuque	dr.fisher.dubuque@geemail.com	Milwaukee	Wisconsin	4490123682166	d63d8c2dfcbb01cad0c93cac504d5ad1	JCB 16 digit	42.9988863238684829	-87.9840343164380698
22664	2020-05-01 18:25:45	2020-05-01	Najee Stamm	najee.stamm@warmmail.com	Berkeley	California	3112065527071367720	36b5087c03f690a4fc45f8ec4018e025	JCB 16 digit	37.8480486417492372	-122.230177217910821
22665	2020-05-01 19:01:46	2020-05-01	Kameron Schmitt-Gulgowski	kameron.schmitt.gulgowski@warmmail.com	Columbus	Ohio	502078775771047	7200051c85ee73228d3b07454c3f8534	Voyager	39.9561371837787291	-82.9530727169245523
22666	2020-05-01 19:14:46	2020-05-01	Dola Conroy	dola.conroy@geemail.com	Columbus	Ohio	060476087656443	1885b4f39b487855cd2418967c2259d5	VISA 16 digit	39.9782892808828478	-82.8990193613574036
22667	2020-05-01 19:56:46	2020-05-01	Shannon Schuppe-Keebler	shannon.schuppe.keebler@geemail.com	San Francisco	California	3714176801121205	b49958d31f93876ccaca8d38c2e4a271	JCB 16 digit	37.7465676622937494	-122.44558521567879
22668	2020-05-01 20:07:48	2020-05-01	Nery Lind	nery.lind@geemail.com	Olathe	Kansas	4069079240456048	8194b31987c421aa06e777277f7ae0f3	VISA 16 digit	38.8241025949019942	-94.8548051200509121
22669	2020-05-01 20:36:50	2020-05-01	Benjamen Bartoletti-Runolfsson	benjamen.bartoletti.runolfsson@geemail.com	Grand Prairie	Texas	3096141989503453106	9767b103c80ac732eec31249b23f9c34	JCB 16 digit	32.6708590473100529	-96.921265162142376
22670	2020-05-01 20:38:39	2020-05-01	Lailah McCullough-Rowe	lailah.mccullough.rowe@geemail.com	Oakland	California	3013626676049298	89eda87ad01a1293eda7f5b9b6e80b08	JCB 16 digit	37.8008060115029778	-122.263021961275825
22671	2020-05-01 20:47:47	2020-05-01	Miss Jerilynn Shanahan MD	miss.jerilynn.shanahan.md@woohoo.com	Miramar	Florida	6011351224175183582	cfb4f92e90d39976b9d85aa1ceafedc1	VISA 16 digit	25.9768307690490055	-80.2783472871400505
22672	2020-05-01 20:49:38	2020-05-01	Demi Dach	demi.dach@geemail.com	Davie	Florida	6011148597315108579	901af64d8bcec634f74aa634ee14f6c3	Maestro	26.0300747911710282	-80.329302936363959
22673	2020-05-01 20:53:34	2020-05-01	Ms. Tenisha Haley MD	ms.tenisha.haley.md@geemail.com	Oklahoma City	Oklahoma	3750331460482860	6bec3a4d542262dbbafc7b3665c767ee	JCB 15 digit	35.4864396991118838	-97.5490388835676043
22674	2020-05-01 21:10:32	2020-05-01	Selah Stamm	selah.stamm@geemail.com	Fontana	California	6011461769897152551	911dd21bdf95d8c4d86898187d332ffe	Diners Club / Carte Blanche	34.2081086092311892	-117.465463940780239
22675	2020-05-01 21:13:33	2020-05-01	Senora Krajcik	senora.krajcik@woohoo.com	Lowell	Massachusetts	3088469921152884640	e581715ec160d0644ab806f0e85fa0aa	Voyager	42.6835655238349005	-71.2822253599636326
22676	2020-05-01 21:25:23	2020-05-01	Erie Kilback	erie.kilback@warmmail.com	Portland	Oregon	676179937967739	6f96be5b4c2ab90151db413979b46bd7	Discover	45.6299940017871535	-122.58458950724453
22677	2020-05-01 21:41:24	2020-05-01	Salome Jerde	salome.jerde@warmmail.com	Sacramento	California	4171587041461137	5b903886746113b50b20c8714efdaa38	Voyager	38.6312205841097978	-121.411030349346248
22678	2020-05-01 22:00:00	2020-05-01	Virginia Pollich	virginia.pollich@geemail.com	Houston	Texas	3337716932426365739	bbb6354803ccdae87a51cfb57314634f	American Express	29.695346915729715	-95.4712720466326914
22679	2020-05-01 22:04:21	2020-05-01	Xzavier Waelchi	xzavier.waelchi@warmmail.com	Kenosha	Wisconsin	180063110088159752	3e60f5186988014a96598eaea36353bf	VISA 16 digit	42.6137440422389631	-87.797111907251562
22680	2020-05-01 22:13:24	2020-05-01	Dawn Little	dawn.little@woohoo.com	Los Angeles	California	869941345213003460	0a7ba441d45cddb939bf01c0932f8db3	JCB 15 digit	34.0825351624149775	-118.379933576750744
22681	2020-05-01 22:19:59	2020-05-01	Fulton Bauch	fulton.bauch@geemail.com	Milwaukee	Wisconsin	3056418440664280	02b4669006f0987f38186f48056d4de2	Diners Club / Carte Blanche	43.0916936940133581	-87.8752541366133926
22682	2020-05-01 22:22:16	2020-05-01	Federico Feeney V	federico.feeney.v@geemail.com	Fort Worth	Texas	3088406313158287505	e882145665349872c49dd199ab69bc4b	Mastercard	32.7501576736625282	-97.373383513633911
22683	2020-05-01 22:32:17	2020-05-01	Kacy Bayer	kacy.bayer@geemail.com	El Paso	Texas	4090315562514243	6c9c4ad4d8e14bd09c5810c66797cc4c	VISA 16 digit	31.8294646857600689	-106.458164542585621
22684	2020-05-01 22:35:40	2020-05-01	Leilani King DVM	leilani.king.dvm@warmmail.com	Austin	Texas	4339372050452	6b628729b976a8364334204cefb1ef0c	Discover	30.2428506268315012	-97.6994760323088656
22685	2020-05-01 22:35:53	2020-05-01	Elonzo Feest	elonzo.feest@geemail.com	Miami	Florida	51675939407913444	cefe4f599f5b1f2a901788c4cdb10f7b	JCB 15 digit	25.785342270242797	-80.1290428018536431
22686	2020-05-01 22:39:34	2020-05-01	Sie Nolan	sie.nolan@geemail.com	Indianapolis	Indiana	180040915541667169	5165e57d89128388ff89c20f0d41caf6	JCB 15 digit	39.7359243716120716	-86.2040902430392748
22687	2020-05-01 22:58:23	2020-05-01	Rena Maggio	rena.maggio@geemail.com	Carrollton	Texas	561201338085812	7b4307eac7b79cbaa59ad1c4ae7fe47c	VISA 16 digit	32.8977693226575809	-96.9496033909592825
22688	2020-05-01 23:03:45	2020-05-01	Shanon Bauch-Zulauf	shanon.bauch.zulauf@warmmail.com	New York	New York	4921695977801219	f51f0c3a37a78f029bd699ed77954430	JCB 16 digit	40.6849347945060558	-74.0112126434583217
22689	2020-05-01 23:07:05	2020-05-01	Dylan Lockman	dylan.lockman@woohoo.com	Los Angeles	California	4893817887436225	8800a401db2ee5929e348cfa94998c88	Discover	34.0777321787416909	-118.499788708145914
22690	2020-05-01 23:13:04	2020-05-01	Mr. Ora Franecki	mr.ora.franecki@geemail.com	Wichita	Kansas	3424490653613666	225bfd6defe8d8f51d24d928447c479e	JCB 15 digit	37.7394010240089131	-97.4108512200616303
22691	2020-05-01 23:14:09	2020-05-01	Signe Kovacek	signe.kovacek@geemail.com	Berkeley	California	3112116530172064815	53a038980c8b1a32edb6504093504f61	JCB 16 digit	37.8829380043100272	-122.296848257209916
22692	2020-05-01 23:20:06	2020-05-01	Rice Mueller-Kihn	rice.mueller.kihn@woohoo.com	Kent	Washington	3733500163704018	424ec85be526855e767aff8eb373ea50	Maestro	47.4162700371928523	-122.162770449151097
22693	2020-05-01 23:22:15	2020-05-01	Philomena Luettgen	philomena.luettgen@geemail.com	Albuquerque	New Mexico	503854458205298	344e58ef11ee063befdf5b91b1dafc79	Diners Club / Carte Blanche	35.2006503447558785	-106.5918861846976
22694	2020-05-01 23:22:30	2020-05-01	Edmon White	edmon.white@geemail.com	Murrieta	California	3440677202012289	9d09ede7b187b05c56393fa1128b8868	JCB 15 digit	33.5096382337719163	-117.172294966727122
22695	2020-05-01 23:23:19	2020-05-01	Ruel Dietrich-Jerde	ruel.dietrich.jerde@geemail.com	Sterling Heights	Michigan	6011018752344192998	9b9a0198b475b5bdcf76aa5b02057ef9	Voyager	42.624844642829899	-83.1302054430518211
22696	2020-05-01 23:25:26	2020-05-01	Jarret Halvorson	jarret.halvorson@geemail.com	Des Moines	Iowa	3774175890592901	412af6c9fef3ebe1c83bebb44c81e7e3	JCB 16 digit	41.5089132282625926	-93.5171183057174176
22697	2020-05-01 23:28:07	2020-05-01	Irvin McKenzie	irvin.mckenzie@geemail.com	San Francisco	California	503814072567606	959750b5486ae7a2ba58af3ce86562fb	Mastercard	37.7784746201837436	-122.397942969688671
22698	2020-05-01 23:32:03	2020-05-01	Greta Armstrong-Ankunding	greta.armstrong.ankunding@warmmail.com	Cape Coral	Florida	51776279111713741	8e48e3a765003d599f8bbc1b65b4322c	VISA 13 digit	26.7308777109690006	-82.0931260993309309
22699	2020-05-01 23:32:37	2020-05-01	Wilkie Mohr	wilkie.mohr@geemail.com	Olathe	Kansas	54709449120688828	96549592ef0b55769eaa0d282b38eacc	JCB 16 digit	38.9208789645351487	-94.7220748995598427
22700	2020-05-01 23:45:44	2020-05-01	Miss Kalene Wunsch DVM	miss.kalene.wunsch.dvm@geemail.com	Los Angeles	California	4713991635671	8da79c3847a5bfc97ee9eeb32fab8a44	Discover	34.0047770462796066	-118.406254430999226
22701	2020-05-02 00:02:07	2020-05-02	Mrs. Nola Marks	mrs.nola.marks@geemail.com	Los Angeles	California	3741148595551993	37d503e6f01e20c1bdd495a4f1825b59	VISA 16 digit	34.1183057056605819	-118.404718309267608
22702	2020-05-02 00:02:44	2020-05-02	Belinda Haag	belinda.haag@geemail.com	Miami	Florida	3088366856025558902	1d93299cba518f94e8edfd3077358453	Discover	25.7154213039342316	-80.1701917233284576
22703	2020-05-02 00:16:36	2020-05-02	Primus Bailey	primus.bailey@warmmail.com	Norfolk	Virginia	4639457070469	861cdf64fffc959bd1db92a192be3809	VISA 16 digit	36.9762415107358251	-76.185026764590674
22704	2020-05-02 00:19:53	2020-05-02	Abby Jacobs-Tromp	abby.jacobs.tromp@geemail.com	Pittsburgh	Pennsylvania	3096081808159636925	035304c95adcfea1ce1692234dc1369e	VISA 16 digit	40.4388542969666389	-80.048029621474825
22705	2020-05-02 00:20:25	2020-05-02	Mr. Elie Christiansen DVM	mr.elie.christiansen.dvm@geemail.com	Chicago	Illinois	4276975605151	ac715be28d995ba2f154c06077264a76	Mastercard	41.7648037040442262	-87.7079001175735158
22706	2020-05-02 00:21:45	2020-05-02	Mrs. Georgette Hilll	mrs.georgette.hilll@geemail.com	New York	New York	55526669500047847	24ff6bd4f188e114feefa2222bbbdd6b	VISA 16 digit	40.6994534103423362	-73.9247453085508113
22707	2020-05-02 00:25:18	2020-05-02	Abe Marvin PhD	abe.marvin.phd@woohoo.com	Orlando	Florida	3096533005939997560	cc116881f231a016fb3855cbd2cb777a	American Express	28.4722657390668985	-81.3292058442220167
22708	2020-05-02 00:39:36	2020-05-02	Less Towne	less.towne@geemail.com	San Francisco	California	3096493394066185837	3aff2db198c2c7f5a550b4c837777f05	JCB 16 digit	37.7745080456264546	-122.398000810585302
22709	2020-05-02 00:51:53	2020-05-02	Miss Torie Konopelski DVM	miss.torie.konopelski.dvm@geemail.com	Lowell	Massachusetts	4548459081848	854b86003a945358e280ccbaa2ccc79a	Voyager	42.6606157414950431	-71.3287352956704837
22710	2020-05-02 00:56:55	2020-05-02	Dr. Kaiden Stoltenberg	dr.kaiden.stoltenberg@geemail.com	El Paso	Texas	3337687416266270576	89a47298540d0d5e7c7855afb39aa729	American Express	31.8140356687657544	-106.336691662294797
22711	2020-05-02 01:17:12	2020-05-02	Maureen Crist	maureen.crist@geemail.com	Denver	Colorado	210012547842166429	81c95166d5ca916e4052edb7ba73cde8	VISA 13 digit	39.6953654700011001	-104.969551173948133
22712	2020-05-02 01:17:49	2020-05-02	Clabe Hartmann	clabe.hartmann@geemail.com	Chicago	Illinois	4272990800331376	2d72041e7710550d73167560c8ca466f	Voyager	41.8693123155575293	-87.6918445722229762
22713	2020-05-02 01:23:16	2020-05-02	Dr. Yvonne Becker	dr.yvonne.becker@woohoo.com	New York	New York	4932079293787	b0ccff8e2c95a160eb94e036bd10a565	Discover	40.6749384532440459	-73.8812663944799368
22714	2020-05-02 01:26:34	2020-05-02	Delmar Adams-Rohan	delmar.adams.rohan@warmmail.com	Seattle	Washington	4296414466296	621544f01282c982366d5fafec70dc4a	Discover	47.7132793362643568	-122.306416216112297
22715	2020-05-02 01:33:28	2020-05-02	Tera Hand	tera.hand@geemail.com	Houston	Texas	180095577619782330	a8dfe4ea733de87c209b3de402866bdb	VISA 13 digit	29.8637723131649189	-95.3905187816373967
22716	2020-05-02 01:34:12	2020-05-02	Dr. Mickey Strosin V	dr.mickey.strosin.v@woohoo.com	Dallas	Texas	3096038061261233678	cd855d0ddfa6abe30b9b8f4a67578885	American Express	32.8630523742914207	-96.7645534728150807
22717	2020-05-02 01:51:01	2020-05-02	Ignatz Weissnat	ignatz.weissnat@warmmail.com	Berkeley	California	4763104422564135	b30fad2d755e50deaa660f1daf4d09ae	JCB 16 digit	37.8426339831648306	-122.289734466265472
22718	2020-05-02 01:51:08	2020-05-02	Ms. Crystal Huel	ms.crystal.huel@geemail.com	San Francisco	California	54109744006811809	8150d5b5a1a6b799a244b18e29cf8a07	American Express	37.7519552327321364	-122.416199551711841
22719	2020-05-02 01:55:29	2020-05-02	Miss Mira Hackett	miss.mira.hackett@woohoo.com	Peoria	Illinois	4259680870165955	7519b673f71a5edf52bd32f768cf0164	JCB 16 digit	40.6962020585183026	-89.6757189067430858
22720	2020-05-02 02:05:48	2020-05-02	Jim Durgan	jim.durgan@geemail.com	San Francisco	California	3337973214534011119	8da6a0b7c1892bd7c5460d07b51c8c22	Discover	37.7578676125928254	-122.444908566482752
22721	2020-05-02 02:18:37	2020-05-02	Fred Jacobson	fred.jacobson@warmmail.com	Louisville	Kentucky	4560078056144874	eb09c8ddaa396ea5240c089d3d91f35c	Mastercard	38.2229912730302672	-85.5768001828879221
22722	2020-05-02 02:32:43	2020-05-02	Sampson Koepp	sampson.koepp@woohoo.com	Chula Vista	California	4238484112178	cc360a8325abcec35c8cd8fcbdbafafa	JCB 16 digit	32.619916350324452	-116.925451597501336
22723	2020-05-02 02:36:16	2020-05-02	Mr. Clayton Kuhic	mr.clayton.kuhic@geemail.com	Garland	Texas	55393572512577605	afd3822fb8cc90877f0572a59970e1ec	VISA 13 digit	32.8840397306952568	-96.5489506401747519
22724	2020-05-02 02:47:07	2020-05-02	Demetria Jacobi	demetria.jacobi@geemail.com	San Francisco	California	3337773126478520503	36d786cfb532f3d6fcda20325c70218d	Discover	37.7816740101728286	-122.421490244391052
22725	2020-05-02 03:25:24	2020-05-02	Mrs. Elnora Johns MD	mrs.elnora.johns.md@warmmail.com	Jacksonville	Florida	4271145171707115	d2bf9018b9f2f529e45540e09adbe4cd	VISA 16 digit	30.288420673232153	-81.6193187522314503
22726	2020-05-02 03:35:16	2020-05-02	Belle Harris	belle.harris@woohoo.com	New Haven	Connecticut	869912663071603337	85bd493a48ce12caeaa999eaa58a59fa	JCB 16 digit	41.3574583132743854	-72.982692597759879
22727	2020-05-02 03:50:17	2020-05-02	Garrett Moore-Jerde	garrett.moore.jerde@warmmail.com	Coral Springs	Florida	4483616435135	3c4c6e8f4abca82d63313657efc1b074	JCB 16 digit	26.2394888665590464	-80.2480726477347304
22728	2020-05-02 03:58:17	2020-05-02	Angele Hintz	angele.hintz@geemail.com	San Bernardino	California	3112548841393324690	c7481071c5e9146abb257868ebaf40eb	JCB 15 digit	34.1373970237359359	-117.291787717236573
22729	2020-05-02 03:59:31	2020-05-02	Lonnie Beahan	lonnie.beahan@woohoo.com	Fort Worth	Texas	503844951184397	b641ea777e8c7a9c2c244a1280d8bd15	Discover	32.7950669041890635	-97.4114735812235608
22730	2020-05-02 04:17:41	2020-05-02	Odelia Waters	odelia.waters@geemail.com	Arlington	Texas	54873257596594127	6b481fdbbf4ed48c5f034b3b802517dd	VISA 16 digit	32.6052912256464325	-97.0257647426359426
22731	2020-05-02 04:19:30	2020-05-02	Mr. Johnny Pagac Sr.	mr.johnny.pagac.sr.@geemail.com	Anchorage	Alaska	3483020959118355	adf644ae213525b622289ddc14b7fecc	Diners Club / Carte Blanche	61.2240609220445151	-149.270103416371342
22732	2020-05-02 04:20:42	2020-05-02	Garey Carter	garey.carter@geemail.com	San Francisco	California	3438785059266033	c4f6406f9711ad92b689f08d1e6d2f3d	JCB 16 digit	37.7618974520157096	-122.444764437442302
22733	2020-05-02 04:27:26	2020-05-02	Zadie Carter DVM	zadie.carter.dvm@geemail.com	Philadelphia	Pennsylvania	4918786150304454	5cfdf0a085e09e45b28ab5ef7cebcd91	JCB 16 digit	40.09298361860737	-75.1050674233485012
22734	2020-05-02 04:28:23	2020-05-02	Dr. Ricci Grant II	dr.ricci.grant.ii@geemail.com	Anchorage	Alaska	589369960651318	97315f0bac19969dab6b60884f922d68	Discover	61.1074803477834934	-149.381170489651339
22735	2020-05-02 04:37:17	2020-05-02	William Bayer MD	william.bayer.md@geemail.com	Oklahoma City	Oklahoma	3700203035123397	b4d4378f3904061a0684c240543c9757	VISA 16 digit	35.5377376840360455	-97.4377236912853988
22736	2020-05-02 04:45:17	2020-05-02	Pamela Breitenberg DVM	pamela.breitenberg.dvm@geemail.com	San Diego	California	3046956745573789	9ce4b82fd10c67d347403726b0b4452d	Diners Club / Carte Blanche	32.7479800213661036	-117.173573695952072
22737	2020-05-02 05:10:06	2020-05-02	Lakeisha Hills DVM	lakeisha.hills.dvm@woohoo.com	Milwaukee	Wisconsin	55797330082323732	0c0c3eefcb8eff5f8c0df28ffcb0a8cc	VISA 13 digit	43.0715898047752646	-87.8770256018832328
22738	2020-05-02 05:24:57	2020-05-02	Jase Ullrich Jr.	jase.ullrich.jr.@geemail.com	Oklahoma City	Oklahoma	6011291987465778054	44246b0b58dc4d8b640fdc95ca459e3c	JCB 15 digit	35.3735878702163689	-97.4352774927288294
22739	2020-05-02 05:43:39	2020-05-02	Blaze Miller	blaze.miller@geemail.com	Ontario	California	4820586793455524	69d5aaa06d17588aea45300f9293b425	JCB 16 digit	34.0351636903971411	-117.667797240904349
22740	2020-05-02 05:47:38	2020-05-02	Willodean Dicki	willodean.dicki@geemail.com	New York	New York	4064212978577	5230549f99b5d760ec221ceb95f420df	Maestro	40.607651317561043	-73.850068793807921
22741	2020-05-02 05:50:23	2020-05-02	Miss Gale Rice MD	miss.gale.rice.md@geemail.com	Little Rock	Arkansas	3096822705889066858	9b2410eecc90eb542b1035716e791fc8	JCB 16 digit	34.6381719400450621	-92.387525739927213
22742	2020-05-02 05:51:31	2020-05-02	Trina Jerde DVM	trina.jerde.dvm@geemail.com	Philadelphia	Pennsylvania	4005668950939438	556420a136185848c786ba3c0ee7f886	American Express	40.0949402268469299	-75.1569925666686203
22743	2020-05-02 05:52:37	2020-05-02	Sarah King	sarah.king@geemail.com	Berkeley	California	676150650167948	a58f0d7612022e8d5739470d471afe8a	VISA 13 digit	37.8759972289252929	-122.254134841474453
22744	2020-05-02 05:59:51	2020-05-02	Dr. Derick Harvey IV	dr.derick.harvey.iv@geemail.com	Wilmington	North Carolina	3337600169466387575	527d18f12c55e094884f2ab72d3621a1	Diners Club / Carte Blanche	34.2784868102807607	-77.9386577315621167
22745	2020-05-02 06:05:54	2020-05-02	Mr. Greggory Nicolas PhD	mr.greggory.nicolas.phd@woohoo.com	Albuquerque	New Mexico	3088987519756596413	9932d908b8b13fd8faf450e1569d7c96	JCB 15 digit	35.0096712071582701	-106.714198777971419
22746	2020-05-02 06:17:56	2020-05-02	Sabina Crooks-Sauer	sabina.crooks.sauer@woohoo.com	Chicago	Illinois	4109565138914231	012c382916d0d49355d27be29331b75f	Maestro	41.8336305632557739	-87.7474761812046182
22747	2020-05-02 06:29:43	2020-05-02	Volney Beahan	volney.beahan@geemail.com	New York	New York	3096096843297530824	c8e66e9dd502e294ca983a06a2bef777	VISA 13 digit	40.6577642187234005	-73.9804099634185377
22748	2020-05-02 06:32:46	2020-05-02	Phoenix O'Hara	phoenix.o'hara@geemail.com	Pomona	California	180025575210032126	22d86e31acfac67b827a6e9eba1d10c9	Diners Club / Carte Blanche	34.0867432688400172	-117.799964724198361
22749	2020-05-02 06:57:24	2020-05-02	Elmo Beahan-Dicki	elmo.beahan.dicki@warmmail.com	Houston	Texas	3096038623668888022	7d70fb0c8b39fd1dcabf9652b35a039d	VISA 13 digit	29.8406927885100259	-95.3239434892326614
22750	2020-05-02 07:15:10	2020-05-02	Lota Farrell PhD	lota.farrell.phd@woohoo.com	San Francisco	California	3017662216296392	3eefe26fd0735bf2bb390720bc4ef118	Diners Club / Carte Blanche	37.7169241192795823	-122.427296538448275
22751	2020-05-02 07:16:36	2020-05-02	Miss Cydney Bartoletti DVM	miss.cydney.bartoletti.dvm@geemail.com	Macon	Georgia	3743741682470149	558341e8fbdf54fe0ae6901320089fb2	JCB 15 digit	32.8279295830067213	-83.7242709824077735
22752	2020-05-02 07:19:46	2020-05-02	Clifton Wintheiser	clifton.wintheiser@warmmail.com	Buffalo	New York	3112455168421915823	74c2dc4406967e9ef13bb493b8d933a8	Diners Club / Carte Blanche	42.8151887515746026	-78.8348298396848151
22753	2020-05-02 07:42:39	2020-05-02	Clare Hamill-Stoltenberg	clare.hamill.stoltenberg@geemail.com	Warren	Michigan	561237106620646	cf7be476c865cd67148b34e05232c7d8	JCB 15 digit	42.5635437107641224	-83.0508738708682444
22754	2020-05-02 07:49:13	2020-05-02	Kale Gerhold-Wintheiser	kale.gerhold.wintheiser@woohoo.com	Chicago	Illinois	54616131310941439	1fbebee6d62a16512733cb1bd0334108	VISA 13 digit	41.8679122818935667	-87.7256364935573174
22755	2020-05-02 07:53:16	2020-05-02	Harriette Pfannerstill	harriette.pfannerstill@geemail.com	Orange	California	4931628794873	6ad609b69c7c0e8d8da77923c6c16960	JCB 16 digit	33.792512903397899	-117.846415526895967
22756	2020-05-02 08:02:43	2020-05-02	Dr. Sheridan Strosin	dr.sheridan.strosin@geemail.com	McKinney	Texas	6011577300578553908	9387439e2b7e313fc726c3a0b2ef2590	VISA 16 digit	33.1365589249543859	-96.6098025829829368
22757	2020-05-02 08:06:40	2020-05-02	Blaine Crona	blaine.crona@geemail.com	Birmingham	Alabama	676311352149733	16cd28f0ca5a9c1d829bcf6b084df6b4	JCB 15 digit	33.5882591421507328	-86.8511023254375942
22758	2020-05-02 08:12:46	2020-05-02	Council Klocko	council.klocko@woohoo.com	San Francisco	California	3096228660112216822	eda6919296dc00fdb51c8bbf4490c478	Mastercard	37.7576928184118188	-122.440163792174502
22759	2020-05-02 08:15:31	2020-05-02	Kami Hickle	kami.hickle@geemail.com	Port St. Lucie	Florida	676261103099646	8ee76540cf16fd63ae76b7fd78f86176	VISA 16 digit	27.330510982651635	-80.4715412185613133
22760	2020-05-02 08:22:16	2020-05-02	Israel Huel III	israel.huel.iii@geemail.com	Anaheim	California	3337024463557106228	2c1ef4b365bd123074733852416b6dd8	Diners Club / Carte Blanche	33.8298934357538812	-117.807971265187859
22761	2020-05-02 08:38:41	2020-05-02	Bjorn Volkman	bjorn.volkman@geemail.com	Fullerton	California	4663746880778242	0a820dcdabfdcdfea96edc21522e0172	VISA 13 digit	33.8727305564720211	-117.87634870798513
22762	2020-05-02 09:00:35	2020-05-02	Candice Swift	candice.swift@geemail.com	Garland	Texas	4064585001817	5f966abff4066d152f71532706c0e209	Voyager	32.9641631124775856	-96.6737236177709036
22763	2020-05-02 09:18:01	2020-05-02	Garret Bins	garret.bins@woohoo.com	Saint Paul	Minnesota	52830154748146132	38f4818baa594e14827b561201de0b5f	VISA 16 digit	44.9001671362143	-93.1562034215576915
22764	2020-05-02 09:18:54	2020-05-02	Elinor Ruecker	elinor.ruecker@woohoo.com	Chicago	Illinois	4088466878266	ed2ae02849fce48a71b2fdbd385b0df5	Mastercard	41.8530557488858719	-87.6989201767399891
22765	2020-05-02 09:19:24	2020-05-02	Mr. Hughie Parker MD	mr.hughie.parker.md@geemail.com	San Francisco	California	3480819428481044	53b4a2979f741403ec4c2222f3ed03d0	VISA 16 digit	37.7589344877770188	-122.467472251641269
22766	2020-05-02 09:20:50	2020-05-02	Cherish Dickens-Hane	cherish.dickens.hane@geemail.com	Houston	Texas	210006153408806116	6be0e8f005ccd55f8945ae2c1f5e2b2b	VISA 13 digit	29.8007005288343869	-95.3948464236702733
22767	2020-05-02 09:36:50	2020-05-02	Bena Veum	bena.veum@geemail.com	Los Angeles	California	6011825292981770999	b71ac61e583741d9a3abf28761917bf4	VISA 16 digit	33.9732216112647194	-118.433494518975905
22768	2020-05-02 09:45:42	2020-05-02	Dr. Andrea Gutkowski	dr.andrea.gutkowski@geemail.com	San Francisco	California	210004647301630657	5334eebab076c1c71f993ef32f055129	JCB 16 digit	37.7888639627933998	-122.435396726592401
22769	2020-05-02 09:49:58	2020-05-02	Jenny Sipes	jenny.sipes@geemail.com	Atlanta	Georgia	4764422069371153	e8f01ab04846d335aa33635e7a5d0476	JCB 15 digit	33.7587586967084547	-84.4536958027210147
22770	2020-05-02 10:01:42	2020-05-02	Lawrence Fahey MD	lawrence.fahey.md@geemail.com	New York	New York	6011069849611925106	f8eafe1ed752795668d7caa0e38dcaf8	Discover	40.625519257992508	-73.9203326264292002
22771	2020-05-02 10:53:34	2020-05-02	Denzil Murray-Schmidt	denzil.murray.schmidt@geemail.com	San Francisco	California	3158773816018561427	13739b04dce632772f77e9e6d1f23bca	JCB 16 digit	37.7680086487506372	-122.446175041968147
22772	2020-05-02 10:54:05	2020-05-02	Jean Murazik V	jean.murazik.v@geemail.com	Sacramento	California	53509919834135755	6781847fa09f946b0cedbf489098395a	Mastercard	38.5462250152867298	-121.415418720595909
22773	2020-05-02 11:08:38	2020-05-02	Emilio Kling	emilio.kling@woohoo.com	Berkeley	California	869999306430463540	330ef53240764e992f99bf9fac2ab5d8	Mastercard	37.8947788827404466	-122.251268154822313
22774	2020-05-02 11:13:32	2020-05-02	Dr. Ebba Fritsch DVM	dr.ebba.fritsch.dvm@geemail.com	Chicago	Illinois	869903592155353140	6283c0bf0f917daf89b2b7b4b196ea82	Maestro	41.8856685211718087	-87.6961104108981715
22775	2020-05-02 11:15:19	2020-05-02	Odalys Lubowitz	odalys.lubowitz@geemail.com	West Valley City	Utah	4383486680728068	387478e4b33c5146d0e501d0813a7ebf	VISA 16 digit	40.7748809670787296	-112.081961178382102
22776	2020-05-02 11:19:25	2020-05-02	Johnnie Pollich-Watsica	johnnie.pollich.watsica@geemail.com	New York	New York	4068901402799	6cf39a7fea21845b860c6af7e7bf5119	Maestro	40.7239865366592966	-73.9400458987697959
22777	2020-05-02 11:25:38	2020-05-02	Gilbert Lind	gilbert.lind@geemail.com	Rochester	Minnesota	4306751019519296	62b945980a4a1f1b54dc7c77785cf179	Voyager	43.9419375941991817	-92.418517152837282
22778	2020-05-02 11:32:20	2020-05-02	Amiya O'Keefe	amiya.o'keefe@warmmail.com	Long Beach	California	54122954383609907	fca5f5e8cf6f3e88a31dd762bd7c2577	Diners Club / Carte Blanche	33.78477366499677	-118.125975732148802
22779	2020-05-02 11:33:38	2020-05-02	Franklyn Bernier	franklyn.bernier@geemail.com	Frisco	Texas	3528462055860161111	956e097fd65692bf74fbae491e21b453	JCB 16 digit	33.128243362111597	-96.8876216541252973
22780	2020-05-02 11:33:44	2020-05-02	Twyla Green	twyla.green@geemail.com	Arlington	Texas	3528170981957912012	2a4c3316876dee1d74aff771e91501fc	Voyager	32.7980515400662966	-97.0525573813382607
22781	2020-05-02 11:33:50	2020-05-02	Eben Crist	eben.crist@geemail.com	Houston	Texas	3158640515917796495	c6a6c7f0a53b723b7882e5b97a80df4f	VISA 16 digit	29.7840519944284097	-95.3261949160616808
22782	2020-05-02 11:33:52	2020-05-02	Adelia Rempel	adelia.rempel@geemail.com	Charlotte	North Carolina	3096836775379959007	e6baed93d55c7fa208205d2bbf41aa5d	VISA 13 digit	35.1459802828051124	-80.7961702309493006
22783	2020-05-02 11:38:47	2020-05-02	Dr. Aydin Jacobson II	dr.aydin.jacobson.ii@geemail.com	San Francisco	California	54253327241042028	8de0e8da5955579c6588362c4cd81b29	VISA 16 digit	37.778065865192751	-122.406996387460978
22784	2020-05-02 11:46:24	2020-05-02	Angel Simonis	angel.simonis@geemail.com	San Francisco	California	3045037380304706	ef37dd0a4f4b803953b55ebc2b10d32b	Discover	37.7792746582923868	-122.413675013991522
22785	2020-05-02 11:48:38	2020-05-02	Vivien Tillman-Nienow	vivien.tillman.nienow@geemail.com	Denver	Colorado	4255978954510987	4e7a506c048e82a0eea0e6b6c15fa54a	JCB 15 digit	39.8106419571727486	-104.940518459562583
22786	2020-05-02 12:00:21	2020-05-02	Belle Welch	belle.welch@geemail.com	Irving	Texas	4884939091820	9754330df63d7403584ca71a0aa85ba9	VISA 16 digit	32.8256148094262912	-97.0278402998391556
22787	2020-05-02 12:04:03	2020-05-02	Emilee Hagenes	emilee.hagenes@geemail.com	Visalia	California	3337817813784290461	36670eea0ef108a72a783d3bd535cdf7	JCB 15 digit	36.4178344412196466	-119.40233534110115
22788	2020-05-02 12:05:25	2020-05-02	Hermann Hintz	hermann.hintz@woohoo.com	Peoria	Illinois	4634786165767748	425dd8ce4a7129a5626050ce98512baa	VISA 13 digit	40.6904834925532342	-89.6910155679915135
22789	2020-05-02 12:18:27	2020-05-02	Audy Bogisich-Steuber	audy.bogisich.steuber@warmmail.com	Mesquite	Texas	4956831187771	9c8a9c2f29cbda125cb7f427b4daffd8	VISA 13 digit	32.6742406339660292	-96.6117098402429377
22790	2020-05-02 12:29:12	2020-05-02	Dr. Cornell Armstrong IV	dr.cornell.armstrong.iv@geemail.com	Las Vegas	Nevada	869979914274146818	b49bf5dd722d9334b05e06e0c2198cbe	Mastercard	36.1531964521024349	-115.256166295262418
22791	2020-05-02 12:34:30	2020-05-02	Damaris Lesch	damaris.lesch@woohoo.com	San Francisco	California	3337416002156524450	4ee72b5835281aba817c7f543140a22b	JCB 15 digit	37.7826759593468324	-122.43723554410164
22792	2020-05-02 12:53:03	2020-05-02	Mr. Harvie Walter II	mr.harvie.walter.ii@geemail.com	New York	New York	3006511351167259	e42473ca8bf081fa853e677f3e8cf4f9	Discover	40.5652800551373502	-73.9200409663271074
22793	2020-05-02 12:55:26	2020-05-02	Aleta Steuber	aleta.steuber@warmmail.com	Kansas City	Missouri	3337541486457173851	8a1d71508908678bb4ce88242ed56449	Discover	39.0546015058480265	-94.4904038097932926
22794	2020-05-02 12:57:18	2020-05-02	Isadore Donnelly	isadore.donnelly@warmmail.com	New York	New York	3054399515525071	00b03f4197ec7996a0e07091b6ddfefc	Mastercard	40.7237802590467055	-73.8533355688571902
22795	2020-05-02 13:04:54	2020-05-02	Jorge Kassulke	jorge.kassulke@geemail.com	Los Angeles	California	3485665456902186	16441c569ce723a64776ff1ee2da8c29	Discover	33.9249014947429259	-118.347068390202892
22796	2020-05-02 13:05:52	2020-05-02	Leopold Schuppe Sr.	leopold.schuppe.sr.@geemail.com	Chattanooga	Tennessee	180092881763823483	32afa86c148dc517bd11ad45a9866d12	Maestro	35.1369412637632337	-85.2248528891071686
22797	2020-05-02 13:13:48	2020-05-02	Kipp Larson	kipp.larson@geemail.com	Kansas City	Missouri	3441839341345108	a97c96de68ce0102130f980ec20fd10e	Voyager	39.1160393621143001	-94.4923751800078975
22798	2020-05-02 13:13:53	2020-05-02	Daulton Roberts	daulton.roberts@woohoo.com	San Diego	California	3112292163680763508	121558852dcf62198d57a803280d6fd1	JCB 16 digit	32.7799853108890389	-117.179246359774851
22799	2020-05-02 13:44:20	2020-05-02	Dr. Lemon Schiller	dr.lemon.schiller@woohoo.com	Joliet	Illinois	3008500334211787	54d534251be46cad16850300d3d86b55	Discover	41.4530154192212947	-88.0909442606020718
22800	2020-05-02 13:44:26	2020-05-02	Dr. Vidal Hamill II	dr.vidal.hamill.ii@geemail.com	Mesa	Arizona	869914811964988384	2b18c4a5345dc3ff3219386792c04f7d	Diners Club / Carte Blanche	33.4496251885924494	-111.746137753955651
22801	2020-05-02 13:48:11	2020-05-02	Mrs. Irva Schoen PhD	mrs.irva.schoen.phd@woohoo.com	New York	New York	3096189216704306757	d9afa073e7f15da8edf63b2327f6ff69	Maestro	40.6726526741161933	-74.0269619440089883
22802	2020-05-02 13:55:27	2020-05-02	Sammie Bosco MD	sammie.bosco.md@geemail.com	Fort Worth	Texas	3015965352153786	85758923418e2be835b1619b95865448	Discover	32.8712902486380187	-97.3668043573673856
22803	2020-05-02 13:59:37	2020-05-02	Bliss Miller	bliss.miller@warmmail.com	Los Angeles	California	3158300673879039304	b573e084c380226008724e5bd4f7fd70	JCB 15 digit	34.0038521850347522	-118.406979664554072
22804	2020-05-02 14:02:46	2020-05-02	Jaelynn Dickens	jaelynn.dickens@geemail.com	San Francisco	California	4855455408093	fddf77b2d5f9ba93dbeaf79ace8a2d1a	Voyager	37.7788143371959109	-122.408959789112387
22805	2020-05-02 14:03:29	2020-05-02	Paris Gislason	paris.gislason@warmmail.com	Peoria	Arizona	4766131745354	c8531a4c49ca9f15b6697d5ffbe5e3d7	Discover	33.8546750828426326	-112.367781002299864
22806	2020-05-02 14:13:12	2020-05-02	Karyl Stiedemann	karyl.stiedemann@geemail.com	Roseville	California	4937432630795873	305bbebe37f9443f1d23a72fe17b3d1f	JCB 15 digit	38.6828920398429048	-121.29249277289361
22807	2020-05-02 14:19:12	2020-05-02	Joline Rutherford DDS	joline.rutherford.dds@geemail.com	San Francisco	California	3760441356332547	79216ead030bfb1be1afabc0d6be4286	Diners Club / Carte Blanche	37.7396622593425306	-122.421560386838465
22808	2020-05-02 14:33:00	2020-05-02	Dr. Immanuel Corwin I	dr.immanuel.corwin.i@warmmail.com	Las Vegas	Nevada	3056538692039210	f3a5aa9cf81e0c82f42099cb0ecdfaff	VISA 16 digit	36.2384792412266137	-115.245952234251789
22809	2020-05-02 14:37:10	2020-05-02	Dayna Brown	dayna.brown@warmmail.com	Carlsbad	California	3337483119991521752	41e73baed275d4caaa990b2ccf058955	JCB 16 digit	33.082182773895191	-117.339472872230402
22810	2020-05-02 14:44:08	2020-05-02	Mr. Hoyt Blanda MD	mr.hoyt.blanda.md@geemail.com	Shreveport	Louisiana	4106476320340586	95331a7bca3c5514515d36f3c42aa47a	Mastercard	32.4124349282361592	-93.7834729354109555
22811	2020-05-02 14:49:46	2020-05-02	Caro Schaefer	caro.schaefer@geemail.com	Houston	Texas	4576015615159771	ef9b65d3bd324e7318b1bf3b796ad2b5	American Express	29.8577469143163405	-95.3004787071622985
22812	2020-05-02 14:54:33	2020-05-02	Ivy Yost	ivy.yost@geemail.com	San Francisco	California	51729401643841307	a9f6df3194fac8ce6c0e7739fb5213ea	Voyager	37.7823292804117585	-122.409247658592449
22813	2020-05-02 15:01:26	2020-05-02	Brigid Walsh	brigid.walsh@geemail.com	Chicago	Illinois	869940556440396490	55638ba88670db4f2880e54e1a5c8d82	VISA 13 digit	41.9269512899987404	-87.6557806487690669
22814	2020-05-02 15:08:15	2020-05-02	Ramiro Shields	ramiro.shields@geemail.com	Edison	New Jersey	3158710872439183164	02f62c4f21150736d222a338996a5592	Voyager	40.5277445166334473	-74.3516652907762676
22815	2020-05-02 15:31:14	2020-05-02	Dr. Alcide Ondricka II	dr.alcide.ondricka.ii@geemail.com	Waco	Texas	180057631660087416	58e7d5b3dc06f668ba3d9a54dcbcaa13	Discover	31.5370723862409577	-97.1701230134479772
22816	2020-05-02 15:35:25	2020-05-02	Jackeline Gorczany DVM	jackeline.gorczany.dvm@warmmail.com	Springfield	Illinois	3781095286197332	03d6a097159efbcb76bb10bf7c1dc94f	Diners Club / Carte Blanche	39.8631903551206008	-89.7433397510092732
22817	2020-05-02 15:45:14	2020-05-02	Dr. Diamond Schultz MD	dr.diamond.schultz.md@geemail.com	Tampa	Florida	51189571245861870	ec3852d0fa25282dbd611cb27e9f1b66	Discover	27.9361589493811131	-82.4485670375849935
22818	2020-05-02 15:55:47	2020-05-02	Jonatan Eichmann	jonatan.eichmann@geemail.com	Berkeley	California	4845784978802674	728a2ffe0dbf97ce5deaba33c6436fe0	JCB 16 digit	37.8565413744025108	-122.287368509550021
22819	2020-05-02 16:05:32	2020-05-02	Janay Langosh	janay.langosh@warmmail.com	Anaheim	California	3528887706313436529	b2da918af885adcf5366f871eda5e9d7	Maestro	33.8447868628259769	-117.822972773595154
22820	2020-05-02 16:26:15	2020-05-02	Dr. Tyrek Lynch	dr.tyrek.lynch@woohoo.com	Huntington Beach	California	3096367556957123118	5005bde29b772678f913a75ffd670169	VISA 16 digit	33.7149643273133819	-118.10423218441494
22821	2020-05-02 16:29:49	2020-05-02	Tanja Tromp	tanja.tromp@geemail.com	League City	Texas	060419099687006	e2d4752388670967756a921a3b273c78	Voyager	29.4717825910937066	-95.0533724857479285
22822	2020-05-02 16:30:09	2020-05-02	Adan Frami-Dach	adan.frami.dach@warmmail.com	Berkeley	California	4768038622460659	f324fe21a57aa19f1a38a14d9e4b0cd0	VISA 16 digit	37.8840541634139569	-122.271746079113584
22823	2020-05-02 16:34:01	2020-05-02	Dr. Grayce Johnston PhD	dr.grayce.johnston.phd@geemail.com	Oakland	California	180083867060634682	a0c1ad173c3e20f574d385237e83a315	JCB 16 digit	37.8367067008764906	-122.259882781021687
22824	2020-05-02 16:36:27	2020-05-02	Mr. Jonathan Gulgowski IV	mr.jonathan.gulgowski.iv@geemail.com	Oakland	California	180064493529153207	cd6e74baecdb61738cb959d1b68c96df	JCB 16 digit	37.7561408548266968	-122.251553692014681
22825	2020-05-02 16:38:50	2020-05-02	Bryson Mertz	bryson.mertz@warmmail.com	Bakersfield	California	210030120822454286	aabbb473de186d132adb95f08734fed9	Mastercard	35.2830915086146391	-119.096942214322453
22826	2020-05-02 16:42:56	2020-05-02	Mr. Neely Swaniawski Sr.	mr.neely.swaniawski.sr.@warmmail.com	Orlando	Florida	4230536734892636	2d302b43d28c05d1234a3e3271ac426a	VISA 16 digit	28.4160497073814255	-81.2286024255178916
22827	2020-05-02 17:07:29	2020-05-02	Sigrid Purdy	sigrid.purdy@geemail.com	Chicago	Illinois	210055745947708594	366ed869e101888a0c757f9fe66f64c6	Diners Club / Carte Blanche	41.7963454900611211	-87.6563405388995989
22828	2020-05-02 17:11:30	2020-05-02	Skylar Buckridge	skylar.buckridge@geemail.com	Pembroke Pines	Florida	869958897636277410	63c704171b000db5a49477482ef3d14d	JCB 16 digit	25.9447640562932946	-80.2964004600323733
22829	2020-05-02 17:23:26	2020-05-02	Valentin Goodwin DVM	valentin.goodwin.dvm@geemail.com	Baltimore	Maryland	3158735603367593053	68fd6923463043ae0bcd137bfb248634	Mastercard	39.2597746781073482	-76.6543577317632696
22830	2020-05-02 17:27:16	2020-05-02	Mrs. Marnie McKenzie PhD	mrs.marnie.mckenzie.phd@geemail.com	Lakewood	New Jersey	4654113984313312	24a24a86e87d52dca2a376050ea43d13	VISA 16 digit	40.0431137841477991	-74.1950169910021202
22831	2020-05-02 17:28:41	2020-05-02	Mr. Jack Olson III	mr.jack.olson.iii@geemail.com	Raleigh	North Carolina	4990414639906978	6436cb94ba69382b335a8843da8c0506	Mastercard	35.7589503279089911	-78.6563061321090942
22832	2020-05-02 17:31:23	2020-05-02	Mr. Cleveland Wisoky	mr.cleveland.wisoky@geemail.com	Hollywood	Florida	4579910627071278	3c4166bd07f10311b1eb8ff92b28baca	JCB 16 digit	25.9972056532688427	-80.0975173938371228
22833	2020-05-02 17:32:23	2020-05-02	Kaylah Lebsack DVM	kaylah.lebsack.dvm@warmmail.com	Phoenix	Arizona	3019836544619917	2f9839c3d094195f95a4dccd5e5d88f7	JCB 16 digit	33.6486613416045941	-112.065295550732316
22834	2020-05-02 17:33:13	2020-05-02	Leyla Hudson-Metz	leyla.hudson.metz@geemail.com	Columbus	Georgia	3337141248838823040	90bc04e3a7ba1977051e8e9e6ba8b178	VISA 16 digit	32.5542416708122886	-84.9246027425095349
22835	2020-05-02 17:43:29	2020-05-02	Bentley Prohaska	bentley.prohaska@geemail.com	San Francisco	California	3112226398894569827	fcacc3f3a51d2d3e9f581836ae2695db	JCB 15 digit	37.830291534771618	-122.4029751498244
22836	2020-05-02 17:48:13	2020-05-02	Carolyne Gaylord-Sipes	carolyne.gaylord.sipes@geemail.com	Centennial	Colorado	6011847619362428496	d1fc3c1e4c09cb0da7a7c8835cf8aefb	Maestro	39.5595411932602516	-104.923771953432265
22837	2020-05-02 18:21:04	2020-05-02	Burrel Lynch	burrel.lynch@geemail.com	Columbia	Missouri	4373430816867541	2b9f717004501d9df20fbc95f9ed62ba	Diners Club / Carte Blanche	39.0279127090119431	-92.2620053008251944
22838	2020-05-02 18:25:25	2020-05-02	Kianna Sanford	kianna.sanford@geemail.com	Indianapolis	Indiana	3049275346747339	39a32ca207057e46912c66903d56cb07	VISA 13 digit	39.8646397246520934	-86.2434139681249832
22839	2020-05-02 18:25:41	2020-05-02	Dr. Agnes Aufderhar DDS	dr.agnes.aufderhar.dds@woohoo.com	Jacksonville	Florida	180082468845681410	6204da1326f7b08b4399a5af1a8dea81	JCB 16 digit	30.3217249904811368	-81.6678643243465672
22840	2020-05-02 18:34:57	2020-05-02	Bryn Schaden	bryn.schaden@woohoo.com	Fremont	California	3112221999341219588	38903967ce03a8b31731b9ccfddb3d91	JCB 15 digit	37.5434820323418847	-121.87460658396482
22841	2020-05-02 18:35:32	2020-05-02	Mr. Micheal Funk III	mr.micheal.funk.iii@geemail.com	New York	New York	4623056773525844	cfdd8ff3aba16191c0bb293d9da3a3cb	American Express	40.6007134375851564	-73.9090020256012679
22842	2020-05-02 18:46:17	2020-05-02	Mrs. Loriann Kshlerin	mrs.loriann.kshlerin@geemail.com	Seattle	Washington	54713283753643352	614ef8a088304b5831560292c9602d11	VISA 16 digit	47.5620142605546832	-122.450523288167631
22843	2020-05-02 18:58:56	2020-05-02	Julien Dickens-Nikolaus	julien.dickens.nikolaus@warmmail.com	Atlanta	Georgia	3713439654821078	83a771041ae1cdd7cb79bd436a209634	VISA 16 digit	33.7540807260941733	-84.4391956874214173
22844	2020-05-02 19:05:21	2020-05-02	Ms. Lesa Christiansen	ms.lesa.christiansen@geemail.com	San Francisco	California	3027945192053824	1c63696224062d05f614885c93422973	JCB 16 digit	37.8012962279885159	-122.445232795123445
22845	2020-05-02 19:10:40	2020-05-02	Joel Bednar-Goyette	joel.bednar.goyette@woohoo.com	Boston	Massachusetts	3096377596710096738	47bd5f41a1868f1e6e96592890175005	JCB 15 digit	42.3658169172406218	-70.9999223988454844
22846	2020-05-02 19:13:36	2020-05-02	Kegan Kautzer	kegan.kautzer@woohoo.com	San Francisco	California	676354479405091	b4135a4fcf3f370770f59c4c5e77de83	American Express	37.7895220441814672	-122.431361302195697
22847	2020-05-02 19:24:22	2020-05-02	Mr. Steve Klein III	mr.steve.klein.iii@geemail.com	Berkeley	California	3158495176781052717	8ef66d1459ee61789708a5e8593c844d	JCB 16 digit	37.8442777233978447	-122.289009758281082
22848	2020-05-02 19:26:28	2020-05-02	Corene Lubowitz	corene.lubowitz@geemail.com	Mesa	Arizona	4273719765243	6783c4d0f68630ddad31828e6d9dd15c	Discover	33.3230413348559296	-111.812791675317655
22849	2020-05-02 19:30:54	2020-05-02	Miss Kari Goodwin	miss.kari.goodwin@geemail.com	Plano	Texas	53582889829680323	4fc21aec529987d5e51e9d7e39aaa44a	JCB 15 digit	32.9754849119663263	-96.6807258427325706
22850	2020-05-02 19:41:59	2020-05-02	Kaelyn Kuphal-Conroy	kaelyn.kuphal.conroy@geemail.com	Wilmington	North Carolina	54201393628699957	c9b46cdf25d7a8fbc625d7908d1f368f	American Express	34.2012805720146744	-77.8461366894181879
22851	2020-05-02 20:03:11	2020-05-02	Dr. Armani Toy	dr.armani.toy@geemail.com	Milwaukee	Wisconsin	3003882697279261	fad772c3f505471e35b6b7c4d041ab20	American Express	43.000939149837194	-87.9880046670891431
22852	2020-05-02 20:05:04	2020-05-02	Valinda Cummerata	valinda.cummerata@geemail.com	Denver	Colorado	869981689512525090	6da42c1faf1580ef8392b4feb77400c7	Mastercard	39.7502847929071592	-104.865576925292984
22853	2020-05-02 20:13:59	2020-05-02	Everet Zboncak	everet.zboncak@geemail.com	Murfreesboro	Tennessee	3112475786667142871	28ff2d122350a6a35111d50dc1de511a	VISA 13 digit	35.9335674517441603	-86.3311663170661774
22854	2020-05-02 20:17:21	2020-05-02	Denver Runte I	denver.runte.i@geemail.com	Memphis	Tennessee	3112285085057496108	f01e7c5bdc586a6f69ebfea039ccc331	Discover	35.0076545429948709	-89.9968801508449019
22855	2020-05-02 20:23:29	2020-05-02	Soledad Lang	soledad.lang@geemail.com	New York	New York	52972189025487278	3c5974c6808be4edbe73b0f1ddd0062e	American Express	40.6868047020621617	-73.911606378982583
22856	2020-05-02 20:26:44	2020-05-02	Nelly Bosco	nelly.bosco@geemail.com	San Francisco	California	51514159388940267	6cff1f3d4ddb8ab91f35af60170e78d9	Maestro	37.7856567743639431	-122.401972076366988
22857	2020-05-02 20:32:22	2020-05-02	Miss Kandi Douglas PhD	miss.kandi.douglas.phd@geemail.com	Lancaster	California	3528507027833305544	d7d83b51339c009dadb56308adfa3baf	VISA 16 digit	34.6963264872100225	-118.267107303344829
22858	2020-05-02 20:46:38	2020-05-02	Ginger Ondricka-Botsford	ginger.ondricka.botsford@geemail.com	Berkeley	California	3528894469693080869	c655320b13ea05e41b6ca455c38d97ea	Mastercard	37.8923167941519452	-122.261999238942778
22859	2020-05-02 20:49:17	2020-05-02	Nyah Kirlin	nyah.kirlin@warmmail.com	Rochester	Minnesota	3049509229321709	a047a1d26f3f205ebbff9cecd68b6bee	Discover	44.0544254110097881	-92.5530201469201614
22860	2020-05-02 20:49:41	2020-05-02	Zachary Brown	zachary.brown@geemail.com	New York	New York	4754109371643	f305a1cb89ea557a49f95715891d0b3e	VISA 16 digit	40.5987290434762826	-73.8494978003099476
22861	2020-05-02 20:56:50	2020-05-02	Dino Harber	dino.harber@geemail.com	Austin	Texas	4482578576293833	2064c8d8fcbffc83d149cdb8edbd3b4e	VISA 16 digit	30.2621884585484864	-97.762785268226267
22862	2020-05-02 21:21:54	2020-05-02	Kendall Zemlak-Lebsack	kendall.zemlak.lebsack@geemail.com	Boston	Massachusetts	6011850206247670601	db0a5e22e545f4fc030869e3f2d606c5	Discover	42.3092195117548115	-70.9426709973670597
22863	2020-05-02 21:25:53	2020-05-02	Ana McLaughlin	ana.mclaughlin@warmmail.com	Gilbert	Arizona	4151050277910164	bdb17ef74dda35969f53889a2dbedba6	Maestro	33.246871231856943	-111.772340130214019
22864	2020-05-02 21:31:13	2020-05-02	Earlie Rohan MD	earlie.rohan.md@geemail.com	El Paso	Texas	3337648901267780325	d7cb180ed687dc7fa3c623e546579c8c	Discover	31.775172119058297	-106.484089506275964
22865	2020-05-02 21:33:16	2020-05-02	Johnie Conn MD	johnie.conn.md@geemail.com	Santa Clarita	California	3037235352274232	d74d6e5e040fd3cc5075062201d52a2e	JCB 16 digit	34.4625435934141251	-118.446776872091732
22866	2020-05-02 21:33:52	2020-05-02	Tristan Zemlak-Schuster	tristan.zemlak.schuster@warmmail.com	Elizabeth	New Jersey	3057528586079793	494146c82839561790dc399658692f53	VISA 16 digit	40.6921802346255674	-74.1229949544593723
22867	2020-05-02 22:10:52	2020-05-02	Marisela Abshire	marisela.abshire@warmmail.com	Tulsa	Oklahoma	6011555162405188514	9f7c93ca0090a8d237e126f9674cfc6e	Discover	36.0990882086005058	-95.9669136221475867
22868	2020-05-02 22:11:59	2020-05-02	Mr. Artis Hermiston	mr.artis.hermiston@geemail.com	Los Angeles	California	869907410856261346	28bc249d78c4f0cd28c7cd93a018a806	VISA 16 digit	34.064296430615336	-118.354226279909909
22869	2020-05-02 22:23:38	2020-05-02	Maxim Schimmel	maxim.schimmel@geemail.com	New York	New York	4265335322508	e92d92d2016ab24a121b09fed1a48c51	Maestro	40.6236987563073626	-74.0040234467376052
22870	2020-05-02 22:29:24	2020-05-02	Hubert Franecki DDS	hubert.franecki.dds@geemail.com	San Francisco	California	4548223529098	9b95e208e6a3ac9cf13c215bbcbd4b70	VISA 16 digit	37.8067354832688949	-122.424279595036211
22871	2020-05-02 22:39:03	2020-05-02	Rosina Bayer	rosina.bayer@warmmail.com	El Paso	Texas	4265172565872683	697483a5bca84e9a2861e8e5127d917e	Diners Club / Carte Blanche	31.9294138958040641	-106.403645616255702
22872	2020-05-02 22:39:32	2020-05-02	Mohamed Ebert-Bahringer	mohamed.ebert.bahringer@woohoo.com	Glendale	California	3088891456352888826	5f6c7d26ebbebcad898c54bb47e2ee8b	Diners Club / Carte Blanche	34.1220918352469766	-118.243891897508135
22873	2020-05-02 22:53:46	2020-05-02	Neta Gutmann	neta.gutmann@warmmail.com	Pittsburgh	Pennsylvania	3779339741445686	f19f53a13b0a8a371c0890b6f270ae54	VISA 16 digit	40.5287845411293191	-80.0473619302906201
22874	2020-05-02 23:00:51	2020-05-02	Albertha Bode	albertha.bode@woohoo.com	Coral Springs	Florida	210083400956119004	1e37d218b621b8cce0bbd3c0529c552f	American Express	26.2145915580045461	-80.2729325759347461
22875	2020-05-02 23:01:28	2020-05-02	Shelvie Dooley DVM	shelvie.dooley.dvm@geemail.com	San Francisco	California	55523207179865216	7f843d2b1dbd1a5381eb051e90ac8b83	JCB 16 digit	37.7488821295305712	-122.412971234523269
22876	2020-05-02 23:15:29	2020-05-02	Media Cassin DVM	media.cassin.dvm@geemail.com	Murfreesboro	Tennessee	3158422745173889593	de37e1f6940d12e30f9b5b16e99db304	Mastercard	35.9481632631856982	-86.4340973303504256
22877	2020-05-02 23:44:35	2020-05-02	Leonie Windler	leonie.windler@geemail.com	New Orleans	Louisiana	3158187068758282430	06d43ff4aec9a1d7b9ee151ff7c6a643	Discover	30.0910886664889752	-90.0307011816445737
22878	2020-05-02 23:51:26	2020-05-02	Valentine Koelpin-Harber	valentine.koelpin.harber@geemail.com	Bakersfield	California	3158302088340433135	b1002ecff9212a8abe338617855b07b4	VISA 13 digit	35.3034003522887829	-118.970423401081192
22879	2020-05-02 23:56:09	2020-05-02	Renee Koelpin	renee.koelpin@woohoo.com	Indianapolis	Indiana	3036257220941173	3acf5ac1ab8f91bd9f7e62b162471ca4	Voyager	39.8731456851128456	-86.231236474515498
22880	2020-05-02 23:58:10	2020-05-02	Dr. Ashlie Zieme MD	dr.ashlie.zieme.md@warmmail.com	Greensboro	North Carolina	675941505751036	6069fac8501bbd434d68009f31938fe2	American Express	36.112391342699901	-79.8186416482068637
22881	2020-05-03 00:14:22	2020-05-03	Ms. Ida Hand	ms.ida.hand@geemail.com	Las Vegas	Nevada	589379272159793	267a359c3b929fc6f966267868505ccd	VISA 16 digit	36.2236984823930968	-115.200949827509362
22882	2020-05-03 00:16:04	2020-05-03	Dr. Gunner Farrell IV	dr.gunner.farrell.iv@warmmail.com	Boise	Idaho	3017939378837605	747f059b4946a230f4f17b84f8599fa6	VISA 13 digit	43.504440454640239	-116.207916216012833
22883	2020-05-03 00:23:41	2020-05-03	Mr. Casen Baumbach	mr.casen.baumbach@geemail.com	Worcester	Massachusetts	869998006640883112	abd6eda55a9a5f92274fe1bfdd340c66	VISA 16 digit	42.1719388363119236	-71.8570801330517952
22884	2020-05-03 00:37:55	2020-05-03	Butch Wilderman	butch.wilderman@geemail.com	Frisco	Texas	3158796629689822553	082aefda4f112dcc09676f5fb07e0ecb	Maestro	33.0721725303210334	-96.8507725503504275
22885	2020-05-03 00:39:19	2020-05-03	Kay Bayer	kay.bayer@woohoo.com	Chicago	Illinois	3043807632749144	13c6f9a633ddcd767af37ae25dae1395	JCB 16 digit	41.9279440009802613	-87.5908280075091881
22886	2020-05-03 00:50:25	2020-05-03	Lula Kovacek-Walter	lula.kovacek.walter@geemail.com	Sacramento	California	4654387023314	6d118c681c14c959b56909d18929e5eb	Mastercard	38.5815356937501619	-121.472361262865732
22887	2020-05-03 01:08:38	2020-05-03	Genaro Pollich	genaro.pollich@geemail.com	Virginia Beach	Virginia	180079967926711694	e15920bc81e790053e4eff7d05d7bcac	VISA 13 digit	36.8253142204321904	-75.9423298994682767
22888	2020-05-03 01:15:34	2020-05-03	Heath Hermiston	heath.hermiston@geemail.com	San Jose	California	3015614719642467	44e0c0ce2b6e9a9d10233f86295d5f87	Diners Club / Carte Blanche	37.3026717224445221	-121.813602333677565
22889	2020-05-03 01:18:58	2020-05-03	Aleena Franecki PhD	aleena.franecki.phd@warmmail.com	Warren	Michigan	3722166750360078	ebdf99c3260817f83221087cd65774bd	Discover	42.5621059388849901	-83.0938975556753689
22890	2020-05-03 01:32:30	2020-05-03	Burnice O'Conner	burnice.o'conner@geemail.com	Concord	California	55936359317459484	fa4bea3cf6c35e2f7d85305ac8b8b4e1	VISA 16 digit	38.0046446575716175	-121.94191376810744
22891	2020-05-03 01:37:12	2020-05-03	Leonore Durgan	leonore.durgan@woohoo.com	Roseville	California	3112612179877422172	ae1f161ed31da1b348860351cd467a7a	VISA 16 digit	38.8199802696760727	-121.339789291632925
22892	2020-05-03 01:47:32	2020-05-03	January Macejkovic MD	january.macejkovic.md@geemail.com	San Antonio	Texas	210069582745067301	e868d0caf2a01aef17b6e377c10a5168	American Express	29.5667271930795152	-98.4467043611988402
22893	2020-05-03 01:47:45	2020-05-03	Gus Tillman	gus.tillman@geemail.com	Los Angeles	California	3112587739808667442	3f6f95136e4310c8993937c6995c2faf	American Express	34.0091653597872678	-118.477612253138048
22894	2020-05-03 01:53:11	2020-05-03	Mrs. Shona Murphy	mrs.shona.murphy@geemail.com	Cleveland	Ohio	55671840564057047	ab77959abae81e19b0089026bbbb8571	JCB 16 digit	41.5635644070189443	-81.689477165486295
22895	2020-05-03 01:55:16	2020-05-03	Tinnie Rogahn	tinnie.rogahn@woohoo.com	West Palm Beach	Florida	6011458602794513218	c028792e54137b8e400ba53fbb61eb92	Maestro	26.6786065673768533	-80.1519910819664574
22896	2020-05-03 02:02:58	2020-05-03	Woody Bechtelar	woody.bechtelar@geemail.com	San Francisco	California	4428327016811763	9849b7e07e9d36125ed8ec7a49c60654	JCB 15 digit	37.7724454420049653	-122.382733279483205
22897	2020-05-03 02:06:26	2020-05-03	Dr. Jameel Murray	dr.jameel.murray@geemail.com	Orlando	Florida	4061994614301539	bb60f2bc8e32a25f6ea16ed6c96f3b12	JCB 16 digit	28.3960755180831974	-81.3012216321624805
22898	2020-05-03 02:08:53	2020-05-03	Ms. Cannie Crist MD	ms.cannie.crist.md@warmmail.com	Los Angeles	California	3012392101882040	8aba18bc9c8c2fcd4707d54de3ce99f9	American Express	34.0320798507291826	-118.332658618315307
22899	2020-05-03 02:13:29	2020-05-03	Ms. Kailyn Heller DVM	ms.kailyn.heller.dvm@geemail.com	Glendale	Arizona	3036800695435708	17a69113501697b2a1b4bb074f67bd6b	JCB 16 digit	33.6310966744314825	-112.213415523085359
22900	2020-05-03 02:26:54	2020-05-03	Samara Brown-Gutmann	samara.brown.gutmann@woohoo.com	San Francisco	California	6011034729658570852	45c983c06b4d1c26cf707d7a269ff674	VISA 16 digit	37.8022736067830536	-122.426537680760703
22901	2020-05-03 02:41:39	2020-05-03	Brandon Sanford	brandon.sanford@geemail.com	Houston	Texas	55741961571541470	4cd1a59d289f74b28b6d806d550fe942	Voyager	29.7189640626389533	-95.3744242497734689
22902	2020-05-03 02:54:55	2020-05-03	Mr. Jaren O'Hara DVM	mr.jaren.o'hara.dvm@geemail.com	Little Rock	Arkansas	6011152555070447783	3869acfe506bf724d28110608fa0f0fe	Diners Club / Carte Blanche	34.631316787171734	-92.3109770454339582
22903	2020-05-03 03:13:13	2020-05-03	Onie Buckridge	onie.buckridge@geemail.com	New York	New York	4172315927333496	dc69ffbb6c15c9e8abba0a13ef0851ed	Mastercard	40.7552936265934278	-73.8869098856940809
22904	2020-05-03 03:13:26	2020-05-03	Jenniffer McLaughlin	jenniffer.mclaughlin@geemail.com	Miami	Florida	4505164543822575	061212e33dad1acee33e8444e7f94a9e	VISA 13 digit	25.7095441624194407	-80.2531688944309991
22905	2020-05-03 03:15:55	2020-05-03	Audrey Bogisich DDS	audrey.bogisich.dds@geemail.com	Denver	Colorado	869915153966721698	780f6c043eb85718b2e7c1f806818d1c	VISA 16 digit	39.7276902650535106	-104.937097981596736
22906	2020-05-03 03:16:09	2020-05-03	Ms. Deena Brakus DVM	ms.deena.brakus.dvm@geemail.com	Jurupa Valley	California	503889789836833	61089d7f30c71b77f66e64531856857f	JCB 15 digit	33.9865463351760084	-117.396094945121931
22907	2020-05-03 03:20:30	2020-05-03	Yesenia Larson	yesenia.larson@warmmail.com	Phoenix	Arizona	4064844049887981	0cf5d97f5dfccc5806da7a10b4807bdc	Diners Club / Carte Blanche	33.6648962903235116	-112.125716707522429
22908	2020-05-03 03:29:07	2020-05-03	Rob Jacobi	rob.jacobi@geemail.com	Chicago	Illinois	180082330770991190	99a1e2a0d3abd5aac1ce5522f02dbc6d	Diners Club / Carte Blanche	41.8233142319437121	-87.6761290359340535
22909	2020-05-03 03:32:13	2020-05-03	Olin Turcotte	olin.turcotte@woohoo.com	Plano	Texas	3429756851802185	3e156e0c58d5b337d889fc3cf7583f3f	JCB 16 digit	32.9820792433425822	-96.6691720411829607
22910	2020-05-03 03:53:46	2020-05-03	Sharman Buckridge	sharman.buckridge@warmmail.com	Concord	California	4426894823037017	b4293cdf964b1c4a9542ae9e97c38e76	American Express	38.0096369559809588	-121.916458008222648
22911	2020-05-03 03:55:08	2020-05-03	Gillie Kulas	gillie.kulas@geemail.com	Mesquite	Texas	6011885093752589932	a5cc3b1083b1afe4c30601ec25a0c71d	Diners Club / Carte Blanche	32.7870163530387018	-96.6334567847393515
22912	2020-05-03 03:56:54	2020-05-03	Neta Von	neta.von@geemail.com	San Francisco	California	3112264011266950862	19cfc5d5cbabddabd4243b78c953cf36	Discover	37.7851740343211162	-122.430848461550696
22913	2020-05-03 04:03:03	2020-05-03	Miss Erlene Ziemann	miss.erlene.ziemann@geemail.com	Rochester	New York	4038524068319	a1be07f711d99b26780804bf1486b9fe	JCB 15 digit	43.0778750073608023	-77.6674905080121079
22914	2020-05-03 04:15:59	2020-05-03	Mrs. Kailee Fritsch PhD	mrs.kailee.fritsch.phd@geemail.com	Fontana	California	869962542498806724	352c98644748f2ecb40ff61f6bbfc6f8	Voyager	34.0892891852799806	-117.383245301553615
22915	2020-05-03 04:17:24	2020-05-03	Hilbert Schiller	hilbert.schiller@geemail.com	Fontana	California	6011879033782467582	802043ae8cdebf3369b6cccb2e0895f4	Diners Club / Carte Blanche	34.0334236503262062	-117.401912624928727
22916	2020-05-03 04:21:39	2020-05-03	Shemar Osinski	shemar.osinski@woohoo.com	Pearland	Texas	869907917576396004	1c8a25210f432064163263cb5aff79e4	Diners Club / Carte Blanche	29.5479702029183535	-95.3778382632270478
22917	2020-05-03 04:38:47	2020-05-03	Leonia Mueller	leonia.mueller@geemail.com	Dayton	Ohio	55462261266110914	0cb4a0d54e5da783c64587c3093ca4ef	VISA 16 digit	39.7620089614089594	-84.1270572831112986
22918	2020-05-03 04:56:44	2020-05-03	Dr. Mohammad Luettgen	dr.mohammad.luettgen@geemail.com	Rancho Cucamonga	California	51820531752892366	319717bd38d8bef76a6d38356cd2964d	American Express	34.1217422979410756	-117.616700466676434
22919	2020-05-03 05:02:35	2020-05-03	Mont Durgan	mont.durgan@woohoo.com	Los Angeles	California	4745105366348	16bae90f4d1f4ff34554713597c3b59c	VISA 16 digit	33.9194976041890683	-118.315908548840497
22920	2020-05-03 05:03:25	2020-05-03	Shelli Shanahan-Spinka	shelli.shanahan.spinka@geemail.com	Austin	Texas	3448658553533877	ae6a5c48324c790d4e30a9c34381008a	Discover	30.3465172188483159	-97.7576698573079028
22921	2020-05-03 05:04:03	2020-05-03	Glennis Barton	glennis.barton@geemail.com	Washington	District of Columbia	4261466026562	434d0508bccf41d0540acef698bb7dbd	JCB 16 digit	38.8270332440532755	-76.944140798759463
22922	2020-05-03 05:21:46	2020-05-03	Ladonna Douglas	ladonna.douglas@warmmail.com	New Orleans	Louisiana	869967947080623996	1a96631fbbb5b1eda9141d5aa1acd79a	Diners Club / Carte Blanche	30.040916815541312	-89.9245238486472545
22923	2020-05-03 05:26:31	2020-05-03	Mathews Greenholt	mathews.greenholt@warmmail.com	Jacksonville	Florida	4123094006300292	d3d7869779aa141dccceaa59f7799b84	JCB 15 digit	30.3585113998088971	-81.6288973441425725
22924	2020-05-03 05:38:27	2020-05-03	Merlin Keebler	merlin.keebler@geemail.com	Columbus	Georgia	3050987181948918	939a61f9e98f28ac2b87f29f2a10ee2b	Diners Club / Carte Blanche	32.4911057001024446	-84.7837986385613647
22925	2020-05-03 05:45:50	2020-05-03	Rosia Fay	rosia.fay@geemail.com	Austin	Texas	210087106128420883	3ab7ff106c8fba7108b09e8f739a5be8	Voyager	30.3511724200692008	-97.7563172251690276
22926	2020-05-03 05:54:50	2020-05-03	Thelma Parisian	thelma.parisian@warmmail.com	Dallas	Texas	869952384479092491	74f8f7f896a72f91ffbe4fd7b5b669c7	VISA 13 digit	32.8772047066401711	-96.8266220286451187
22927	2020-05-03 05:56:51	2020-05-03	Lem Hegmann	lem.hegmann@geemail.com	Lowell	Massachusetts	4749120211422	fbce7af7d56a47144aa82f3f6ed96b6c	American Express	42.5555852425154342	-71.4010435053952079
22928	2020-05-03 06:03:03	2020-05-03	Kenisha Larson	kenisha.larson@geemail.com	Dallas	Texas	4861100755896038	c866ec7786b25877147a1a0565825fd0	Mastercard	32.8610823771256975	-96.738110806789237
22929	2020-05-03 06:23:37	2020-05-03	Arnett Bayer	arnett.bayer@warmmail.com	Grand Prairie	Texas	4657666613887	6ff76b27882d05a1bffc1c9b5b0bd61c	Maestro	32.7019729718618137	-97.0695361111652204
22930	2020-05-03 06:24:17	2020-05-03	Isom Haag	isom.haag@geemail.com	Buffalo	New York	869950687023318812	84834a0cabd8a85b60c36bfcee83c044	American Express	42.9906588827911733	-78.7628783238519077
22931	2020-05-03 06:27:54	2020-05-03	Ivey Miller	ivey.miller@geemail.com	Overland Park	Kansas	676263192613741	267a87a37610b2f825de5b0aac51c730	Mastercard	38.8185748976059273	-94.767944285463912
22932	2020-05-03 06:32:09	2020-05-03	Miss Montie Langworth DDS	miss.montie.langworth.dds@geemail.com	San Jose	California	3096597739817761556	3083f44358d0a2fb6da35362972da791	VISA 13 digit	37.3186892551191178	-121.824339112242313
22933	2020-05-03 06:35:30	2020-05-03	Gerry Herzog	gerry.herzog@warmmail.com	San Francisco	California	4895513743588311	a9a0bc8fe3e7e1bca87dc4de19946a4c	Mastercard	37.7861486981145873	-122.37600580759306
22934	2020-05-03 06:44:29	2020-05-03	Zollie Mosciski	zollie.mosciski@geemail.com	Cleveland	Ohio	4138861194440749	8725f533ffb91badc8bcc107df0fe8f5	Discover	41.5334140863586185	-81.7344986997317591
22935	2020-05-03 06:44:54	2020-05-03	Ms. Dot Kuhlman	ms.dot.kuhlman@geemail.com	Chula Vista	California	180088640594576785	ce647fcaa2f5431e9a3dc03ae8da34a2	Maestro	32.5750894368391428	-116.97665241800695
22936	2020-05-03 07:09:28	2020-05-03	Dell Strosin	dell.strosin@geemail.com	North Las Vegas	Nevada	180005428084148673	9747bf8b9328d453b6205a9eb21be2db	JCB 16 digit	36.2157790950190233	-115.145850794458397
22937	2020-05-03 07:13:32	2020-05-03	Amelia Mertz	amelia.mertz@woohoo.com	Berkeley	California	501866493825260	9fd88bdefe4157fef35d6e44d86b7a33	Voyager	37.8902163611248355	-122.271332671613649
22938	2020-05-03 07:14:44	2020-05-03	Arra Schimmel	arra.schimmel@warmmail.com	San Francisco	California	4066741737435289	ed058ce6aeef12909ce5b2b275c669de	VISA 16 digit	37.7850505400015848	-122.44278722486861
22939	2020-05-03 07:20:54	2020-05-03	Mrs. Shirlene Renner	mrs.shirlene.renner@geemail.com	Glendale	Arizona	3158984561266266965	1f2eacdaa3e80f9acefa2e636d25452c	JCB 15 digit	33.4652038037072828	-112.123210123626137
22940	2020-05-03 07:22:00	2020-05-03	Mr. Rashaan Bruen	mr.rashaan.bruen@geemail.com	San Francisco	California	3034922346436430	9452b0888b63a2369f5a45ca6043e9d8	VISA 16 digit	37.7677749409874224	-122.403464480967571
22941	2020-05-03 07:22:50	2020-05-03	Miss Racheal Schiller	miss.racheal.schiller@warmmail.com	New York	New York	4475910850369774	f53970225daefaed49b0d61a99fe069e	Voyager	40.6507623387258477	-73.9015727161325486
22942	2020-05-03 07:26:12	2020-05-03	Darcie Braun	darcie.braun@geemail.com	Greeley	Colorado	4525066690205601	171f0250f449416fa9b1fbb10258ad2d	American Express	40.3756537523187689	-104.685542836117378
22943	2020-05-03 07:35:12	2020-05-03	Miss Santina Batz MD	miss.santina.batz.md@geemail.com	Palm Bay	Florida	4651155846178014	180730157dc706548c25b66fa324783d	Voyager	28.030935366809743	-80.7015444553293264
22944	2020-05-03 07:38:56	2020-05-03	Xiomara Bashirian	xiomara.bashirian@geemail.com	San Diego	California	3096428007171466526	bc1abe54ee908b3744ad3326aa10c57d	VISA 16 digit	32.9080354290150083	-117.203772113835441
22945	2020-05-03 07:48:26	2020-05-03	Miss Giovanna Schroeder	miss.giovanna.schroeder@geemail.com	Oakland	California	4524787283555521	0f7b97856863597495e35b0a734244c5	Discover	37.8073834307010657	-122.269723899099944
22946	2020-05-03 07:48:34	2020-05-03	Theadore Botsford-Murray	theadore.botsford.murray@geemail.com	Port St. Lucie	Florida	676383257321469	f7a9be9723c0b25ef5f82d454225a967	VISA 13 digit	27.3013959539256987	-80.3779325626410497
22947	2020-05-03 08:06:32	2020-05-03	Mrs. Mariah Wisoky PhD	mrs.mariah.wisoky.phd@geemail.com	Clinton	Michigan	210049452247246131	101ce04f9cc6dc14215ded34077e303a	Diners Club / Carte Blanche	42.6032647688008836	-82.9357452198006229
22948	2020-05-03 08:13:03	2020-05-03	Claudie Wisoky	claudie.wisoky@geemail.com	Saint Paul	Minnesota	3024310907010382	ae5ac3cdec7828bb44879ecba05354f3	VISA 13 digit	45.0088551850929903	-93.1780685029722804
22949	2020-05-03 08:20:48	2020-05-03	Chessie Conroy-Welch	chessie.conroy.welch@geemail.com	New York	New York	180069596613769186	ab059be6ac02736bb31fd0948864cb30	Voyager	40.7231355023328234	-73.9367198949109792
22950	2020-05-03 08:21:32	2020-05-03	Mr. Linnie Ferry DDS	mr.linnie.ferry.dds@woohoo.com	Los Angeles	California	4532532864135628	ea7bc424f0e92e746e2cb40250e18cdc	JCB 15 digit	33.9765041268296528	-118.394560235458613
22951	2020-05-03 08:40:03	2020-05-03	Antwon Herman	antwon.herman@geemail.com	New York	New York	180072169506456744	e310b9d20645fa6c1485a19b39a1ab68	VISA 16 digit	40.7371050644889436	-74.0371455403871863
22952	2020-05-03 08:40:15	2020-05-03	Luanne Rice	luanne.rice@geemail.com	San Francisco	California	4113261589439936	d41a58d9c5a1401d6b60da69b247f11d	Voyager	37.7362698076659626	-122.44870359772969
22953	2020-05-03 08:40:55	2020-05-03	Neta Cummings	neta.cummings@warmmail.com	Boise	Idaho	4253362493009045	4a449dc4cfc0bc937c753093393be5ae	American Express	43.6481209216311612	-116.206927599311626
22954	2020-05-03 08:41:51	2020-05-03	Ollie Beer-Gleason	ollie.beer.gleason@geemail.com	Riverside	California	3015193575609720	32f2a4ce84072966fec8251462e6ae61	JCB 15 digit	33.8666665503703044	-117.404411957363408
22955	2020-05-03 08:50:08	2020-05-03	Micheal Smith	micheal.smith@geemail.com	Garland	Texas	3112488246635893829	e8a3cbb780d54392734dc4b6a071d4ef	VISA 13 digit	32.8150118069957912	-96.698992772556096
22956	2020-05-03 08:51:14	2020-05-03	Reilly Witting	reilly.witting@geemail.com	Hayward	California	54078569635143697	6a2a10c9018c686e2eab1401a5531d76	JCB 16 digit	37.6090652127273373	-122.049562009496242
22957	2020-05-03 08:55:45	2020-05-03	Jalynn Anderson	jalynn.anderson@warmmail.com	El Cajon	California	4293859121726	9f00081cca2b74ab8d046ea82ef06729	JCB 15 digit	32.7991568392615704	-117.000584819092978
22958	2020-05-03 09:04:39	2020-05-03	Sydney Purdy	sydney.purdy@geemail.com	Long Beach	California	4660042235300	f973979e4f2975fc8b740a0072b2d65d	JCB 16 digit	33.8937807968638793	-118.148212560189137
22959	2020-05-03 09:10:38	2020-05-03	Miss Beckie Beatty MD	miss.beckie.beatty.md@warmmail.com	Albuquerque	New Mexico	180081626155613007	1099045751ef95284a0936584c8afea2	Mastercard	35.1500390817545352	-106.555679311470698
22960	2020-05-03 09:17:22	2020-05-03	Jereme Hayes	jereme.hayes@geemail.com	Berkeley	California	6011768837076680500	863238b6545f2bc4e740d1e5112e8b2d	Diners Club / Carte Blanche	37.8985447202379504	-122.263064797837544
22961	2020-05-03 09:30:37	2020-05-03	Tea Ritchie DDS	tea.ritchie.dds@geemail.com	Los Angeles	California	6011294812710776660	5843d5c55cb7a548a27074f0a3ec659f	Mastercard	33.9718251839611654	-118.495975784584132
22962	2020-05-03 09:36:05	2020-05-03	Adan Orn-Dooley	adan.orn.dooley@geemail.com	Sunnyvale	California	639005076797249	e314053c58c1646a582f9e97470ab85c	Diners Club / Carte Blanche	37.3442052973426897	-121.933415233317021
22963	2020-05-03 09:41:51	2020-05-03	Shea Gerlach	shea.gerlach@geemail.com	Elk Grove	California	4443643422175	ce9f8f307b72af7f1f99792ff712ad39	Maestro	38.3632996170133325	-121.454674217188739
22964	2020-05-03 09:41:56	2020-05-03	Mr. Darnell Runolfsson	mr.darnell.runolfsson@geemail.com	Fontana	California	4881796847377	245946b3b94d48a6792f93a487716662	JCB 15 digit	34.1946756171677251	-117.508727565761291
22965	2020-05-03 09:46:02	2020-05-03	Clemence Stracke-Mueller	clemence.stracke.mueller@geemail.com	Berkeley	California	4815299584558	b36e600375084e36a4cae1a1d0351029	Maestro	37.8427876593837453	-122.27472484521266
22966	2020-05-03 09:47:40	2020-05-03	Trent Aufderhar-Feil	trent.aufderhar.feil@warmmail.com	Victorville	California	180024910136724228	012e9231ba9456ab1a0eeccd08855876	Voyager	34.4308930454075366	-117.325589465458322
22967	2020-05-03 10:02:24	2020-05-03	Rowan McKenzie	rowan.mckenzie@geemail.com	Portland	Oregon	3429134185752064	28ee6a8e4668b0300019060a03b10ddc	VISA 16 digit	45.4381900733225024	-122.677835583919659
22968	2020-05-03 10:11:41	2020-05-03	Dozier Schamberger	dozier.schamberger@geemail.com	Springfield	Missouri	6011325713449412457	2295276b1a3f5139216eb9216dd74798	JCB 16 digit	37.2603601311527228	-93.3604315560136087
22969	2020-05-03 10:13:25	2020-05-03	Charlie Borer	charlie.borer@geemail.com	San Francisco	California	3054987017474994	4c2c936ea7f91a91a21c32536674a963	JCB 15 digit	37.7678491266853555	-122.401213269936832
22970	2020-05-03 10:14:01	2020-05-03	Phoenix Bernhard	phoenix.bernhard@warmmail.com	New York	New York	4779719539330443	3787eab704aec0253c205923eea8e825	Mastercard	40.6222775338441124	-73.8799677459418689
22971	2020-05-03 10:18:13	2020-05-03	Alwina Jakubowski MD	alwina.jakubowski.md@geemail.com	Tampa	Florida	51642845811699760	f5168af07bb84b14f2e8bee6f69e2402	VISA 16 digit	27.8820625742081525	-82.5643264434046955
22972	2020-05-03 10:27:08	2020-05-03	Joseline Feeney	joseline.feeney@geemail.com	San Francisco	California	3055727828680374	c1c2d629059741e418b0d8c1e08f80f5	Discover	37.776385197208775	-122.42743347960446
22973	2020-05-03 10:55:26	2020-05-03	Jude Brown	jude.brown@warmmail.com	Detroit	Michigan	210048577422416371	c442ddcc44b1c0588fa9bde72c5221d4	Voyager	42.4810026340112117	-83.1943653639990828
22974	2020-05-03 11:02:02	2020-05-03	Fredric Rohan IV	fredric.rohan.iv@geemail.com	Athens	Georgia	3006936453700550	902da747581cb7531f5d314c45f76a2c	American Express	33.8903975318841617	-83.3909301217295109
22975	2020-05-03 11:06:47	2020-05-03	Lauryn Zieme	lauryn.zieme@geemail.com	Baton Rouge	Louisiana	3112747046780946902	6e0a9b31ce7df2a51a4b7fd778641b39	Maestro	30.3822366616901007	-91.0395765052750647
22976	2020-05-03 11:07:57	2020-05-03	Kamya Mraz	kamya.mraz@geemail.com	Berkeley	California	4639751644928803	32e9fdc5b2442526b2ebebfb79f6686d	JCB 16 digit	37.8898042308484548	-122.279921216065702
22977	2020-05-03 11:17:22	2020-05-03	Penny Kuvalis	penny.kuvalis@geemail.com	Fort Worth	Texas	51389782061996827	629bb4e9f73838cf7ecd6151eb646d9f	Maestro	32.780401830567051	-97.3902040694195819
22978	2020-05-03 11:31:44	2020-05-03	Lawyer Mohr DDS	lawyer.mohr.dds@warmmail.com	Chattanooga	Tennessee	3337652813653161890	1c78a39d4349a495aed8e052be6434f7	VISA 16 digit	35.0803440878484452	-85.265201685187975
22979	2020-05-03 11:37:08	2020-05-03	Lou Lubowitz	lou.lubowitz@geemail.com	San Francisco	California	3038842391489686	1e60307561d2ff19305ccd4db79688b4	VISA 16 digit	37.7771679629819346	-122.41943278627636
22980	2020-05-03 11:41:38	2020-05-03	Debera Stamm	debera.stamm@woohoo.com	Chicago	Illinois	3337636858481458936	cf79b46bd0cb925cd2253cf4f3a5eef8	Maestro	41.7991743722766671	-87.5931677686545953
22981	2020-05-03 11:44:40	2020-05-03	Jaidyn Thiel	jaidyn.thiel@geemail.com	San Bernardino	California	210014882481246465	81a94aecce053b4f5518dad6714ccb4d	American Express	34.1962732733026087	-117.27025741522796
22982	2020-05-03 11:45:15	2020-05-03	Ashtyn Schumm	ashtyn.schumm@geemail.com	San Francisco	California	180043425659749996	05b47ddef6b2c5b227c27bd635d800c2	Discover	37.7005090532518565	-122.432764802453761
22983	2020-05-03 11:49:04	2020-05-03	Karren Mitchell DDS	karren.mitchell.dds@geemail.com	Oakland	California	210055876055565060	caa3cb3873a0fbfadb7e7db607a1e55e	Discover	37.7729476880517225	-122.294782534617184
22984	2020-05-03 11:54:12	2020-05-03	Scot Ward	scot.ward@geemail.com	Fort Worth	Texas	3337689216324210517	8c6efa14d3dfa4464c8d53eef3818c4a	Discover	32.7119349272977544	-97.3514068050596819
22985	2020-05-03 11:56:49	2020-05-03	Bethann Cummings	bethann.cummings@geemail.com	Oakland	California	4846598494629	0fe25c40fb3c98b9d2411b4fe11b280c	VISA 13 digit	37.7680411871163813	-122.305857261947068
22986	2020-05-03 12:14:21	2020-05-03	Byrdie Rice	byrdie.rice@geemail.com	Oakland	California	869908319921172421	182327087d2d2e4aa13fe25310439822	Discover	37.7991141554492316	-122.263996882262944
22987	2020-05-03 12:20:06	2020-05-03	Kareen Fadel-Raynor	kareen.fadel.raynor@geemail.com	San Francisco	California	3754162837230351	5c1b872986c34d8f39064df3900543ae	JCB 16 digit	37.7875072228546145	-122.416671029850519
22988	2020-05-03 12:21:59	2020-05-03	Reggie Mills-Reinger	reggie.mills.reinger@warmmail.com	Paterson	New Jersey	3709528482696904	caaa0d4c96a708d5caeab317e3fb6ffa	Discover	40.8895022713534502	-74.09060923000537
22989	2020-05-03 12:25:13	2020-05-03	Miss Jeffie Stroman	miss.jeffie.stroman@geemail.com	Virginia Beach	Virginia	4098395847506	45b8351239482f10e1774dd73983f025	VISA 16 digit	36.8001656536664825	-76.0304929558325568
22990	2020-05-03 12:28:32	2020-05-03	Smith Schuster	smith.schuster@geemail.com	San Francisco	California	060448464705697	a4a8df41f12e500b5113a36f38486efe	Discover	37.7403516353935586	-122.436959684907578
22991	2020-05-03 12:32:45	2020-05-03	Selmer Bergnaum	selmer.bergnaum@geemail.com	Lakewood	Colorado	3030199733474712	d60b51db606e3398e9cb09f7d00778e2	JCB 15 digit	39.7679373761579384	-105.038075685643022
22992	2020-05-03 12:36:17	2020-05-03	Madyson Sporer DVM	madyson.sporer.dvm@geemail.com	Denton	Texas	4703895798037910	55a5599e6a7ce4837d97e3ab4e24857e	JCB 16 digit	33.25697727504037	-97.2055670492943449
22993	2020-05-03 12:37:23	2020-05-03	Dr. Malachi Walter DDS	dr.malachi.walter.dds@warmmail.com	Columbus	Georgia	3528687504206032352	ae80ce22082cf3dec966c67691ced39e	Maestro	32.519609982198844	-84.8871121165972227
22994	2020-05-03 12:47:18	2020-05-03	Minta Gusikowski	minta.gusikowski@geemail.com	Indianapolis	Indiana	639099525791002	8cff98542919b20fdce19f812c0d66c4	JCB 16 digit	39.8137660502463575	-86.1499058022830582
22995	2020-05-03 12:59:48	2020-05-03	Antony Kuhic	antony.kuhic@geemail.com	Amarillo	Texas	4770775500190	5ca1509aa6ec783c55acff9c7a3cfd47	American Express	35.1841102970927935	-101.731007353621351
22996	2020-05-03 13:10:28	2020-05-03	Mrs. Sophronia Howell	mrs.sophronia.howell@geemail.com	Virginia Beach	Virginia	3783023074168990	16e1fbcd64a3ed55450e7daa84ef34a3	Maestro	36.8276189139299106	-75.9946182935170782
22997	2020-05-03 13:13:03	2020-05-03	Harrie Kling	harrie.kling@geemail.com	San Francisco	California	3028810765070028	12175fd4c3abcf86affa64aa9366824d	Maestro	37.7883198764847847	-122.457830263812625
22998	2020-05-03 13:13:29	2020-05-03	Buffy Boyle	buffy.boyle@warmmail.com	San Francisco	California	4826799979438255	b2b8aad500c5bdc1c71943c674ea3260	JCB 16 digit	37.7802836983946406	-122.441513510763741
22999	2020-05-03 13:17:03	2020-05-03	Ressie Olson	ressie.olson@warmmail.com	Aurora	Colorado	3025912237278628	4f56ca92e9b172eee46fa5eb5e150bfb	VISA 16 digit	39.6225174000132867	-104.67487948202789
23000	2020-05-03 13:20:18	2020-05-03	Mr. Amarion Murphy	mr.amarion.murphy@warmmail.com	Laredo	Texas	6011143409011142685	770cde8e087d289699723fc848c3d81e	Maestro	27.5353387812335058	-99.4008408063564417
23001	2020-05-03 13:21:24	2020-05-03	Beryl Morissette	beryl.morissette@geemail.com	Louisville	Kentucky	4887170323103647	538e8ebaf806642a5aad4d4e5ca6a624	JCB 15 digit	38.1393134534262117	-85.7210115021165535
23002	2020-05-03 13:25:32	2020-05-03	Sandi Tromp	sandi.tromp@geemail.com	New York	New York	210011120862631705	563e6b936a30ea58d10015b551fac74a	American Express	40.7318780656196182	-74.0039937012724494
23003	2020-05-03 13:43:58	2020-05-03	Kiley Larkin	kiley.larkin@geemail.com	Fort Worth	Texas	3747231884181831	af20e5ce55994bf92f14fd915bfd0b0c	VISA 16 digit	32.824830668983985	-97.4354083935085669
23004	2020-05-03 13:54:29	2020-05-03	Theta Trantow	theta.trantow@geemail.com	New York	New York	869973257690179518	a296f7f7105e8c665effa6ced172a10d	JCB 15 digit	40.5698573827967053	-73.8925712488021702
23005	2020-05-03 14:09:49	2020-05-03	Danyel Rippin PhD	danyel.rippin.phd@woohoo.com	Davie	Florida	3112370480986661862	11f4da4908b7aa429615374a80f4296d	Voyager	26.0420477791022513	-80.3095684220455581
23006	2020-05-03 14:12:19	2020-05-03	Vella Rau	vella.rau@geemail.com	Pompano Beach	Florida	54869627708551908	50fdfc83b0f62f1b12518d39290a08d6	JCB 16 digit	26.3114835120536377	-80.0527476583454671
23007	2020-05-03 14:15:05	2020-05-03	Beryl Vandervort	beryl.vandervort@geemail.com	San Francisco	California	869958711095997162	31b1bb3dd26c4eaf87c3094acec57b3e	VISA 13 digit	37.737414898195766	-122.420490719260172
23008	2020-05-03 14:27:08	2020-05-03	Thor Kshlerin-Schumm	thor.kshlerin.schumm@geemail.com	Fort Worth	Texas	6011935736441737557	3ae5efae3790bc11af1503be7ad22c3b	JCB 16 digit	32.8275182627663042	-97.3851761201217698
23009	2020-05-03 14:33:45	2020-05-03	Quintin Schoen	quintin.schoen@geemail.com	Gainesville	Florida	3052601094523696	704ff5f6057260364a3fe8ba2c776fc0	VISA 13 digit	29.7091712794557203	-82.2939916336316628
23010	2020-05-03 15:00:26	2020-05-03	Donavon Wuckert	donavon.wuckert@geemail.com	New York	New York	3158873984941198474	23f943fbd8b2ef853f8872760e0623e1	Diners Club / Carte Blanche	40.57056730298698	-73.9379980196140707
23011	2020-05-03 15:00:54	2020-05-03	Daija Douglas	daija.douglas@geemail.com	Vacaville	California	210094707015522425	f1f67cf20a278616eb6469f8dc230995	Diners Club / Carte Blanche	38.3387815930541649	-121.873243255715082
23012	2020-05-03 15:09:24	2020-05-03	Ason O'Keefe	ason.o'keefe@woohoo.com	Cincinnati	Ohio	55030178526823008	e51df3dfc75d183086d870b1c2899142	VISA 16 digit	39.1866431181550041	-84.4350506097815838
23013	2020-05-03 15:13:22	2020-05-03	Joette Greenfelder PhD	joette.greenfelder.phd@geemail.com	New York	New York	4857179283745	3c5e1bbb8f89d9903f18c8753367fd3e	Voyager	40.6016912437733239	-73.8653221879050079
23014	2020-05-03 15:16:04	2020-05-03	Clotilde Greenholt	clotilde.greenholt@warmmail.com	Los Angeles	California	4990720599872988	d0b26489bd389e4a776950647a56efcc	VISA 16 digit	34.08059578820653	-118.401084109115601
23015	2020-05-03 15:32:00	2020-05-03	Leroy Hilll	leroy.hilll@woohoo.com	Arlington	Texas	4021212035535	9ef18c3d081fa8806c714e659a253c8d	VISA 16 digit	32.7430362930305279	-97.0371362299218845
23016	2020-05-03 15:36:42	2020-05-03	Zavier Hagenes	zavier.hagenes@woohoo.com	Corpus Christi	Texas	54819800765085380	eb617a1be3868fe1c5ae35c73b7a35ea	American Express	27.7157972338080398	-97.1222961703609684
23017	2020-05-03 15:37:00	2020-05-03	Ashli Herzog	ashli.herzog@warmmail.com	Aurora	Colorado	3112250989410138144	381e9225cefe8189d3e6a01be6ede09f	VISA 16 digit	39.6434550880566263	-104.77364893244841
23018	2020-05-03 15:51:37	2020-05-03	Rolanda Rohan	rolanda.rohan@geemail.com	Fort Wayne	Indiana	3434430380715127	7d751a0f7c1b925f258e96a189a35198	Discover	41.1335933743294362	-85.1562269021045495
23019	2020-05-03 15:52:03	2020-05-03	Luverne Franecki	luverne.franecki@geemail.com	Fullerton	California	869932474415167419	004cd0a7d97b159ac0cf8a1c2719667e	JCB 15 digit	33.8471751981105626	-118.020475475324318
23020	2020-05-03 16:14:56	2020-05-03	Dr. Baron Volkman MD	dr.baron.volkman.md@warmmail.com	Evansville	Indiana	4249103989537967	e0ef8c837f7ac2c851828ffb25948a68	JCB 16 digit	37.9582732154659865	-87.5740507424741992
23021	2020-05-03 16:29:13	2020-05-03	Carleen Reichel	carleen.reichel@woohoo.com	New York	New York	869975135161554088	807a5e177528a28e80d0d8e910f98a1d	Diners Club / Carte Blanche	40.7143231823332599	-73.9953109736450045
23022	2020-05-03 16:33:54	2020-05-03	Miss Gladys Walsh DVM	miss.gladys.walsh.dvm@geemail.com	Phoenix	Arizona	4281071491313145	d42d31ba311015d5b2363c1b0ea2119d	Mastercard	33.5647849433988341	-112.104910706675057
23023	2020-05-03 16:36:24	2020-05-03	Mr. Alonza Bruen	mr.alonza.bruen@geemail.com	Chicago	Illinois	869933536258311962	86743d6f80aaaadb502a45df0729b5f3	Mastercard	41.8371044370181906	-87.6710325424589172
23024	2020-05-03 16:36:40	2020-05-03	Syble Jenkins	syble.jenkins@warmmail.com	Kansas City	Missouri	3337389644733052795	ae03507719b4fd4af15c7dd768c2e7d1	VISA 16 digit	39.0465944433420944	-94.5219912554360917
23025	2020-05-03 16:43:12	2020-05-03	Miss Ilona Bahringer MD	miss.ilona.bahringer.md@woohoo.com	Scottsdale	Arizona	4329489654205	67e8c3d2b336fbec28b0606afbcffe0d	Voyager	33.7507677767083081	-111.937352121897405
23026	2020-05-03 16:43:58	2020-05-03	Bryana Williamson	bryana.williamson@geemail.com	El Monte	California	3096731484847646439	f749c353643cf6a4cf219aadc28c24ec	Maestro	34.1657329381167827	-117.982898114461818
23027	2020-05-03 17:07:40	2020-05-03	Katy Kunde	katy.kunde@geemail.com	Clovis	California	4100830286504021	acfe95ab775ca2d6a1fef20f6c225473	VISA 16 digit	36.7513506570242399	-119.644574657229327
23028	2020-05-03 17:11:17	2020-05-03	Dolphus Heidenreich-Walker	dolphus.heidenreich.walker@geemail.com	Honolulu	Hawaii	869986764034343655	3e2617448756923c36d48244ea599114	Diners Club / Carte Blanche	21.3197987246077503	-157.898691460511088
23029	2020-05-03 17:17:08	2020-05-03	Dr. Elon Beahan	dr.elon.beahan@geemail.com	El Cajon	California	4745243023744	8ba4c8bc64175561ec113d406a810042	Discover	32.7929178923375844	-116.86941282927954
23030	2020-05-03 17:27:52	2020-05-03	Dr. Terrie Senger	dr.terrie.senger@geemail.com	Phoenix	Arizona	210064251576952669	bc6b6eebcf53803cf5ecaaef5915beca	Voyager	33.487189270269873	-112.183113481190432
23031	2020-05-03 17:31:57	2020-05-03	Edrie Berge-Howell	edrie.berge.howell@geemail.com	Cleveland	Ohio	675940299675435	e7ad93dc9dcb2f62786ff2a7b424ab91	Maestro	41.4730171737577749	-81.6170884089317212
23032	2020-05-03 17:37:11	2020-05-03	Harley Pouros-Hirthe	harley.pouros.hirthe@geemail.com	Tulsa	Oklahoma	3034617915099763	32588671c66b7463111be6c06a5dbb5d	VISA 16 digit	36.0733015629831684	-95.8933243443678975
23033	2020-05-03 17:39:11	2020-05-03	Ernestina Mitchell	ernestina.mitchell@geemail.com	Aurora	Colorado	3759564122530152	3305d262889e34e09bf9ce31fd68f43c	Maestro	39.6887657234557025	-104.758909695886828
23034	2020-05-03 17:56:02	2020-05-03	Dr. Wing Gutmann	dr.wing.gutmann@geemail.com	Charlotte	North Carolina	4280908759698512	53aa4ee9e7b1e1a5ad937119301ac4de	JCB 16 digit	35.1856193274047229	-80.7849645459037333
23035	2020-05-03 18:07:25	2020-05-03	Idella Kub	idella.kub@geemail.com	Philadelphia	Pennsylvania	180063059225925361	14ff75f1cf29bcf3797804e5ca7384ae	JCB 16 digit	39.9969796255655581	-75.0488475370120369
23036	2020-05-03 18:10:29	2020-05-03	Carolynn Breitenberg	carolynn.breitenberg@woohoo.com	Detroit	Michigan	4159170766422604	5152f404762d6d552cbff88c90d82c7c	JCB 15 digit	42.393441180132335	-83.1648902747433567
23037	2020-05-03 18:22:38	2020-05-03	Brock Schumm I	brock.schumm.i@geemail.com	Los Angeles	California	561288861936560	c9a36570452ab37a22731c0193cb182b	Voyager	34.0472728671837572	-118.372178754535682
23038	2020-05-03 18:26:52	2020-05-03	Milissa Considine-Schoen	milissa.considine.schoen@geemail.com	Oakland	California	4227567799167	08a9ee328f6e57a1caae8aafc59ffeb9	VISA 16 digit	37.7979306536787121	-122.292545603014887
23039	2020-05-03 18:36:27	2020-05-03	Natalee Streich-Howe	natalee.streich.howe@woohoo.com	San Antonio	Texas	3337046616475528203	d8897116a83901f3a18f25d11f7f3ddb	JCB 16 digit	29.4327835503105071	-98.6145499470014073
23040	2020-05-03 18:51:54	2020-05-03	Ashlie Fay	ashlie.fay@geemail.com	San Francisco	California	4768406109985	572cf04c606cfa2e54be2adb156e9b5e	VISA 13 digit	37.7686664019828839	-122.448240811607874
23041	2020-05-03 18:58:20	2020-05-03	Lyric Rippin	lyric.rippin@geemail.com	New York	New York	3415567576285903	805a5f3ec81f413bdb2645c936825292	JCB 16 digit	40.5965432073213179	-73.925289292250568
23042	2020-05-03 18:58:27	2020-05-03	Dante Kuhn	dante.kuhn@woohoo.com	Houston	Texas	4364372118034	85907aca91b4604d6b8d768a5697b6b1	VISA 16 digit	29.8541311363302171	-95.2931476366255481
23043	2020-05-03 19:00:47	2020-05-03	Mrs. Jaylene Crooks MD	mrs.jaylene.crooks.md@geemail.com	Norfolk	Virginia	676120763647680	8808e2f4a88eb178a5a3c1cc1c96d2b8	VISA 13 digit	36.9405661815330433	-76.2804689363580195
23044	2020-05-03 19:13:41	2020-05-03	Mr. Cleave Collier MD	mr.cleave.collier.md@woohoo.com	Oklahoma City	Oklahoma	3337516537795444171	b0eee1ba2d8dc964c54aac7ded7b18e6	Mastercard	35.501529129073397	-97.4652596631448773
23045	2020-05-03 19:15:56	2020-05-03	Joesph Stehr	joesph.stehr@geemail.com	San Francisco	California	869919177786536040	324ffe7288db460ed7f3bf5bbe91274e	JCB 16 digit	37.7755640975624729	-122.429704713605062
23046	2020-05-03 19:18:58	2020-05-03	Mr. Elie Kohler	mr.elie.kohler@geemail.com	Oakland	California	4328025667682498	bd16432d7b9f2229913b1c6bea10315f	VISA 16 digit	37.8072929594573708	-122.242787781006783
23047	2020-05-03 19:24:37	2020-05-03	Lilie Wolff	lilie.wolff@geemail.com	Jacksonville	Florida	55251174219999702	4d7873110274f3d54a85bbf8abd23605	Mastercard	30.3997670508973314	-81.658120170895387
23048	2020-05-03 19:43:27	2020-05-03	Christina Mueller	christina.mueller@geemail.com	Montgomery	Alabama	501888723502527	a1f25575097ee6a0cfbc45a3622cb20b	VISA 13 digit	32.3906316960163423	-86.2911818912871098
23049	2020-05-03 19:59:57	2020-05-03	Erasmus Davis	erasmus.davis@geemail.com	Saint Paul	Minnesota	3476836466969686	db8bdee90b004c003afb4d0ac581e910	American Express	44.9559753720123325	-93.1289881943058191
23050	2020-05-03 20:03:12	2020-05-03	Dr. Tasia Gibson PhD	dr.tasia.gibson.phd@warmmail.com	New York	New York	4154464391026962	6d20b1220cda260c915274df80eee3c4	JCB 15 digit	40.6556165931038578	-73.8743092607602421
23051	2020-05-03 20:08:39	2020-05-03	Jeb Roberts	jeb.roberts@geemail.com	Memphis	Tennessee	4470200220635210	8787553c67cb73d90ec50d06ba6ce291	Voyager	35.0909431466899804	-89.8983573495667514
23052	2020-05-03 20:22:20	2020-05-03	Miss Sara Buckridge	miss.sara.buckridge@geemail.com	Montgomery	Alabama	4827142332759035	8621274b647e2674e6534b138e42b671	JCB 16 digit	32.2487075742732756	-86.173410835551465
23053	2020-05-03 20:25:43	2020-05-03	Demetric Leffler	demetric.leffler@geemail.com	San Bernardino	California	4775197160424	d0f402448ae6fce7b2ffbb989404cae0	VISA 16 digit	34.2084785791844084	-117.339285779210172
23054	2020-05-03 20:27:58	2020-05-03	Mr. Evan Herzog Sr.	mr.evan.herzog.sr.@woohoo.com	Phoenix	Arizona	3718060270199742	3cf1193094c362095bdb45a02c103894	Maestro	33.4866196974579253	-112.115539155986539
23055	2020-05-03 20:29:34	2020-05-03	Ms. Ethelene Reilly PhD	ms.ethelene.reilly.phd@geemail.com	Austin	Texas	3012341550361865	1a6de5cf857f82fd14ff34c565bf1442	Discover	30.2224784639790656	-97.7121140661422203
23056	2020-05-03 20:42:59	2020-05-03	Cael Muller	cael.muller@geemail.com	Hayward	California	4330734987201386	19ce04412f792ac16d1547285f8a115b	Discover	37.6877280246920918	-122.197707582197708
23057	2020-05-03 20:46:22	2020-05-03	Darrin Feil	darrin.feil@geemail.com	Indianapolis	Indiana	3112066223888508164	d7d2b99fdc3e7e473adc2b4ba1fc39bc	JCB 16 digit	39.6845838377725286	-86.0885656664814718
23058	2020-05-03 20:49:42	2020-05-03	Curt Kuvalis	curt.kuvalis@geemail.com	Orlando	Florida	869961225810474972	b2f132fbbaee02b0cf294eff3aea3a71	JCB 16 digit	28.3858105837166299	-81.2313388305217075
23059	2020-05-03 20:58:56	2020-05-03	Diandra Bergstrom	diandra.bergstrom@geemail.com	San Francisco	California	630493406681283	4900db9bdb73e1787b6d574e60483855	Voyager	37.7687600753046766	-122.435472008822529
23060	2020-05-03 21:15:34	2020-05-03	Litzy Sanford	litzy.sanford@geemail.com	Dallas	Texas	4277072982413424	ea54a03a1ef1ca34128f1d190eb677a7	Maestro	32.8738729854851996	-96.7613762534651869
23061	2020-05-03 21:18:02	2020-05-03	Ashanti Kassulke-Torphy	ashanti.kassulke.torphy@geemail.com	Los Angeles	California	6011983062387546212	bc6dd03cea00e1d3620ac573e5f4d342	Voyager	33.9516580267209562	-118.380330538376413
23062	2020-05-03 21:18:31	2020-05-03	Yasmine Considine-Hilpert	yasmine.considine.hilpert@woohoo.com	Portland	Oregon	4775616429209386	b1d14bdea9cef49cf6f470b28e294af7	JCB 15 digit	45.5693159864172301	-122.63291042139754
23063	2020-05-03 21:37:00	2020-05-03	Hasan Haley	hasan.haley@geemail.com	San Francisco	California	4734141046045337	240ebbc11b6f7f337b981cfc63f45272	Voyager	37.7351045270447543	-122.431795665211553
23064	2020-05-03 21:41:50	2020-05-03	Raiden Mueller	raiden.mueller@geemail.com	Washington	District of Columbia	4367213942947215	bb1367eb8e4f4e740277c9cf93f263af	JCB 15 digit	38.8302702279094589	-77.1094756135929345
23065	2020-05-03 21:45:48	2020-05-03	Elzie Hilpert-Daniel	elzie.hilpert.daniel@geemail.com	New York	New York	6011733670669314902	3b9124aa6f6b8a4e1fdc9a96559ea9e7	Voyager	40.708095286576075	-73.9144896000985057
23066	2020-05-03 21:48:31	2020-05-03	Kallie Gleason-Conroy	kallie.gleason.conroy@woohoo.com	Dallas	Texas	4176199628547984	94867743f0688b6c7ca14347f0f50181	Diners Club / Carte Blanche	32.7335580881025692	-96.7077632472347375
23067	2020-05-03 21:57:33	2020-05-03	Alston Berge	alston.berge@warmmail.com	Baltimore	Maryland	3158835129059637163	6c6e7ff59799698dfc1bd2a93303484d	VISA 16 digit	39.3831699265632764	-76.6043610462937465
23068	2020-05-03 22:05:43	2020-05-03	Mr. Daryn Lesch I	mr.daryn.lesch.i@warmmail.com	Los Angeles	California	869933762634609065	c7417df5128508132621d817070df7f0	Voyager	34.0255575175262948	-118.334680435712627
23069	2020-05-03 22:07:43	2020-05-03	Ms. Albina Nienow DVM	ms.albina.nienow.dvm@woohoo.com	New Haven	Connecticut	4589202081254717	a377cf8c067d26856dae881dab06d153	American Express	41.3833646276026954	-72.925584317557508
23070	2020-05-03 22:14:32	2020-05-03	Tami Yundt DDS	tami.yundt.dds@warmmail.com	Newark	New Jersey	869987489973059802	828c4ddd78efa7dacb9168580cb453dd	Mastercard	40.6484773879319476	-74.1726190762802986
23071	2020-05-03 22:20:40	2020-05-03	Yulisa Nitzsche	yulisa.nitzsche@geemail.com	New York	New York	4536036498429	26326e023cc41dd9ef5c1b7f9c01d58e	JCB 15 digit	40.6927305164970434	-73.9597659528151183
23072	2020-05-03 22:28:23	2020-05-03	Mr. Arch Satterfield Sr.	mr.arch.satterfield.sr.@geemail.com	Arlington	Texas	4472723191180278	e799daa3e12be07cb08578069bddcf33	VISA 16 digit	32.7023566975973523	-97.2076593769740356
23073	2020-05-03 22:28:29	2020-05-03	Nathalie Kuhlman	nathalie.kuhlman@woohoo.com	San Bernardino	California	4763780768548	608654f85df2305071f42a4e8111f400	American Express	34.0845879679810224	-117.325726272935412
23074	2020-05-03 22:30:07	2020-05-03	Windell Bailey	windell.bailey@geemail.com	New York	New York	3088511473584699384	61cbe6c5ff2fac59429d6684a13da2ae	Voyager	40.607995785888285	-73.9358783156041
23075	2020-05-03 22:35:04	2020-05-03	Austin Kutch	austin.kutch@geemail.com	Louisville	Kentucky	675957698439676	49a7a04390f9f8d906f6ac6bd30b023e	Discover	38.0791913703452778	-85.6079541869998053
23076	2020-05-03 22:37:11	2020-05-03	Kristi Maggio	kristi.maggio@geemail.com	Los Angeles	California	501899021430220	744ac777ba911ba5f5c2a8ed8c7ea11d	JCB 16 digit	33.9816339498251665	-118.416332538564873
23077	2020-05-03 22:49:14	2020-05-03	Miss Candi Boehm	miss.candi.boehm@geemail.com	Austin	Texas	676298567501451	d98bc8b70dbd2a67a84c0f3c53a771c1	American Express	30.2953517273195061	-97.75123008356951
23078	2020-05-03 22:53:14	2020-05-03	Sabina Vandervort	sabina.vandervort@geemail.com	Victorville	California	54268896999692088	cd9080947c70e8bc3118399df44ab8d4	Mastercard	34.4990302653748557	-117.369828010831398
23079	2020-05-03 22:56:06	2020-05-03	Ms. Ossie Littel DVM	ms.ossie.littel.dvm@woohoo.com	New York	New York	630498536985983	9a56b40606d91aebbc8d31725c1e44ba	Voyager	40.58786855416745	-73.9991548127856049
23080	2020-05-03 22:56:40	2020-05-03	Phoebe Daugherty	phoebe.daugherty@geemail.com	Visalia	California	4589762017421607	eda6d4999b9bc393e6051987b158f5e0	American Express	36.3492367570243786	-119.310852194264157
23081	2020-05-03 23:06:10	2020-05-03	Malcolm Hegmann	malcolm.hegmann@geemail.com	Houston	Texas	51870245247292327	df376e38f82476bdcd7b7a0c7fe2c219	VISA 16 digit	29.8163484935261316	-95.3461595457062145
23082	2020-05-03 23:21:44	2020-05-03	Quinn Runolfsdottir	quinn.runolfsdottir@geemail.com	Long Beach	California	4470045961658	2558250178043695a6ca2a6a95d7e438	VISA 13 digit	33.7666881007894872	-118.186156294604018
23083	2020-05-03 23:29:16	2020-05-03	Orlin Kozey	orlin.kozey@geemail.com	Miramar	Florida	180074294825996002	f8029e747959925d130f54f70dd47941	American Express	26.0169770762771364	-80.2471688827958047
23084	2020-05-03 23:31:37	2020-05-03	Elma Bailey	elma.bailey@geemail.com	Oakland	California	3741951953372773	1bd55fe613be6cb1a154bf1f62eb65a1	Discover	37.7944432641360564	-122.242466649653878
23085	2020-05-04 00:00:24	2020-05-04	York Sawayn IV	york.sawayn.iv@geemail.com	Virginia Beach	Virginia	4482657246759801	59595ea351369de773bfc0d86046037b	VISA 16 digit	36.7169871731381861	-76.0233877048499807
23086	2020-05-04 00:00:46	2020-05-04	Doshia Bergnaum	doshia.bergnaum@warmmail.com	Chicago	Illinois	4678035152506	f433fc90e05bca87e076bca841ff0d4f	JCB 16 digit	41.8925705060664555	-87.7605993983831212
23087	2020-05-04 00:16:46	2020-05-04	Tyrell Roob	tyrell.roob@warmmail.com	San Francisco	California	4435855069033	648c5494a77d02550a9f44c586f45577	VISA 13 digit	37.750646978517473	-122.43694769784571
23088	2020-05-04 00:38:04	2020-05-04	Mr. Jeb Johnston IV	mr.jeb.johnston.iv@geemail.com	Washington	District of Columbia	4767574127247119	ae9802d1981b7a4047eae24a6499ae51	Diners Club / Carte Blanche	38.9509539625871923	-76.9387937878470893
23089	2020-05-04 00:55:58	2020-05-04	Miller Kovacek	miller.kovacek@geemail.com	Olathe	Kansas	3528052428100108356	a0f94bef5849ea41c84b3b0d34933b80	VISA 16 digit	38.8137167620595562	-94.8263136915098954
23090	2020-05-04 01:03:05	2020-05-04	Mrs. Trisha Simonis	mrs.trisha.simonis@geemail.com	Los Angeles	California	4014146707030	b499390abba1e638254e6fc55d2a94ff	VISA 13 digit	33.9966667583078106	-118.461009523132063
23091	2020-05-04 01:17:16	2020-05-04	Teagan Durgan	teagan.durgan@warmmail.com	Cambridge	Massachusetts	3043123854556351	a3366785bdd46c0959f20eb268dbfa3c	Discover	42.4559037950113378	-71.1633981288492663
23092	2020-05-04 01:17:44	2020-05-04	Braden Quigley	braden.quigley@geemail.com	Augusta	Georgia	3436364416168126	a74c917373fe33f5ebe129e077773b93	Discover	33.2920304662752855	-82.0847596242852546
23093	2020-05-04 01:18:19	2020-05-04	Cassie Lind	cassie.lind@geemail.com	Chicago	Illinois	3059198059822141	4eda478fe307075cfb6af7f83c73a4cf	VISA 13 digit	41.9284083694987046	-87.7455265185359821
23094	2020-05-04 01:23:22	2020-05-04	Mrs. Biddie Friesen MD	mrs.biddie.friesen.md@geemail.com	Knoxville	Tennessee	3158851416021365729	ecd9e8135e12b0176a259fcd57861dbf	VISA 16 digit	36.0603048484370134	-83.9045480534184662
23095	2020-05-04 01:23:52	2020-05-04	Bedford Moen-Corwin	bedford.moen.corwin@woohoo.com	Pomona	California	51342074483675452	67d79622078b023bc83ab6e3a4f8a4d5	JCB 16 digit	34.056537533741448	-117.756706313319881
23096	2020-05-04 01:39:05	2020-05-04	Rylee Donnelly	rylee.donnelly@geemail.com	Arlington	Texas	180066729444661081	cc4d93bd6828e2c8dfbc6a75b25a43ea	VISA 13 digit	32.7249647818755349	-97.1294525594942257
23097	2020-05-04 01:40:05	2020-05-04	Konnor Crist DVM	konnor.crist.dvm@warmmail.com	Macon	Georgia	3706444400949545	14a6eead34d035644782382770fab079	JCB 16 digit	32.7453788470953668	-83.6008872793715341
23098	2020-05-04 02:02:20	2020-05-04	Ms. Reina Senger DVM	ms.reina.senger.dvm@geemail.com	New York	New York	3112633888177883181	aa59051c3c77c3f1dc123d1b19a4af62	Discover	40.5814128575604371	-73.8817403624195634
23099	2020-05-04 02:07:06	2020-05-04	Yvette Gaylord	yvette.gaylord@warmmail.com	Indianapolis	Indiana	4342579052330305	6e20bb575682897a94b0fd708fa5cb8a	Voyager	39.8449573033496733	-86.1996342679221215
23100	2020-05-04 02:11:34	2020-05-04	Raelynn West	raelynn.west@geemail.com	Oakland	California	676278634017079	8a61892e7e9a6b63e3c4408e76f3356f	VISA 13 digit	37.7702449466511467	-122.295531235873014
23101	2020-05-04 02:19:27	2020-05-04	Max Mante	max.mante@geemail.com	Philadelphia	Pennsylvania	869938503048783939	c5bb14456d2f08ccd22a9fcc2e1a843f	JCB 16 digit	40.0949461947619881	-75.1795093511596377
23102	2020-05-04 02:25:06	2020-05-04	Lynda Baumbach PhD	lynda.baumbach.phd@geemail.com	New York	New York	210025958981536667	92e3424e0e6467472b24b5c4aa1f1aaa	Voyager	40.613539536785332	-73.9774275598943234
23103	2020-05-04 02:28:53	2020-05-04	Mildred Olson	mildred.olson@geemail.com	Los Angeles	California	6011665388546422424	982ff3e924243a31fb063d480582eea3	VISA 16 digit	34.0536627697158565	-118.326595062901447
23104	2020-05-04 02:37:17	2020-05-04	Urban Will II	urban.will.ii@woohoo.com	Glendale	California	3088675788182336291	9e59e2160c49980d1dac97f96338a8cd	VISA 16 digit	34.278785662049053	-118.188889290708303
23105	2020-05-04 02:38:53	2020-05-04	Mr. Trent McDermott MD	mr.trent.mcdermott.md@warmmail.com	Inglewood	California	3047438407822993	c173a30223c78be7a8fe9a6742e1a126	JCB 16 digit	34.0033855955827988	-118.407715238074957
23106	2020-05-04 02:48:36	2020-05-04	Maddison Stroman-Walker	maddison.stroman.walker@geemail.com	Las Cruces	New Mexico	4194561028100565	a2d581c65361a2261e75429d5799fdb7	Diners Club / Carte Blanche	32.2694689856410051	-106.88305642489604
23107	2020-05-04 02:54:26	2020-05-04	Tamisha Steuber-Johnston	tamisha.steuber.johnston@warmmail.com	Austin	Texas	675918314257249	df152dc53f0e69e3b54ba99d7cf1a984	American Express	30.2863393026065069	-97.8102519097045047
23108	2020-05-04 03:08:39	2020-05-04	Delos Breitenberg	delos.breitenberg@geemail.com	San Francisco	California	54082510103117874	2c2ffed5f6ccc502bd45ad8b96fa9de2	JCB 16 digit	37.7958935740331015	-122.440902764388639
23109	2020-05-04 03:13:19	2020-05-04	Aleena Powlowski	aleena.powlowski@warmmail.com	Cleveland	Ohio	3158108988055007964	c217f07b5b4f8d1351a76bf51ef28fd6	Diners Club / Carte Blanche	41.4310105603970555	-81.7521970398962452
23110	2020-05-04 03:16:10	2020-05-04	Mr. Manson Goyette	mr.manson.goyette@geemail.com	Lafayette	Louisiana	3088896885533629573	00116ef9c6e071ebf03c69025b6319c2	Voyager	30.1611487579509614	-91.9776533974651187
23111	2020-05-04 03:52:42	2020-05-04	Destin Glover	destin.glover@geemail.com	Oakland	California	3528917333659903923	aeb2428cd556c1a61d8523f8a2d58989	VISA 16 digit	37.8306736355676279	-122.273209160166971
23112	2020-05-04 04:10:51	2020-05-04	Mal Schuster-Mitchell	mal.schuster.mitchell@geemail.com	Honolulu	Hawaii	3029135599303463	653945a7d527ea753e1367cfccf6cbbf	JCB 16 digit	21.2753517938528205	-157.918023548622045
23113	2020-05-04 04:10:54	2020-05-04	Shaneka Hodkiewicz	shaneka.hodkiewicz@geemail.com	Boise	Idaho	3337971908913416607	7ee59ecbe9d44d007c679d9d5f70c484	Mastercard	43.6404365307789277	-116.253162154481558
23114	2020-05-04 04:15:46	2020-05-04	Haylie Towne	haylie.towne@warmmail.com	Orlando	Florida	3001403767483683	b3de9d75efcb0ea5357fb547efab0147	VISA 16 digit	28.4532389798931753	-81.3081213465858212
23115	2020-05-04 04:18:05	2020-05-04	Angus Nader DVM	angus.nader.dvm@geemail.com	Sunnyvale	California	4304160350969	41010777f2c19ade3c7aea580dd96314	VISA 16 digit	37.3604072757523511	-122.093455281687156
23116	2020-05-04 04:26:24	2020-05-04	Khloe Boehm-Hettinger	khloe.boehm.hettinger@geemail.com	Salem	Oregon	4703898694897	f9bf79c364c5f849480e729f5b2702c9	VISA 16 digit	44.9032474395621506	-123.072900209079307
23117	2020-05-04 04:38:27	2020-05-04	Izetta King	izetta.king@geemail.com	Jacksonville	Florida	210088892294606855	0f1b5fac5f55306ba112f1b195a920d3	VISA 16 digit	30.3313270549342029	-81.7560547629915249
23118	2020-05-04 04:50:48	2020-05-04	Cullen Kozey	cullen.kozey@geemail.com	Houston	Texas	4824508671330674	9922599529b8c94a295caae8ce453f43	Mastercard	29.8256611961018301	-95.324512709958114
23119	2020-05-04 04:56:26	2020-05-04	Ms. Audie Strosin MD	ms.audie.strosin.md@woohoo.com	Durham	North Carolina	3112370116975430675	b9ff286ffb6a617bd9a1104a1531d19e	American Express	35.9910482947960446	-78.9064681942012243
23120	2020-05-04 05:13:27	2020-05-04	Mr. Garrett Kovacek	mr.garrett.kovacek@woohoo.com	San Francisco	California	3112809009138035641	911efc32fef969329f5cbf736ff96767	JCB 16 digit	37.7508693214483273	-122.423210963091321
23121	2020-05-04 05:18:21	2020-05-04	Mr. Otto Gusikowski V	mr.otto.gusikowski.v@geemail.com	Phoenix	Arizona	210089018316044458	d52687488b45ef0f1e47bd31e86ab762	American Express	33.554840135940168	-112.005163887741418
23122	2020-05-04 05:32:28	2020-05-04	Charlie Harris	charlie.harris@geemail.com	New York	New York	3746854737373940	3da52bcdd3610bfd09e1928d81178865	JCB 16 digit	40.7515875973496549	-73.9150461268506973
23123	2020-05-04 05:33:19	2020-05-04	Jordon Denesik	jordon.denesik@geemail.com	McAllen	Texas	4015301226103468	eb5e043ae43100af1e9cf693d28f48be	JCB 16 digit	26.2854835282385331	-98.2991072373777541
23124	2020-05-04 05:41:43	2020-05-04	Lora Gislason	lora.gislason@warmmail.com	Chicago	Illinois	180082035903785100	fa2d53bf8d689bc46ec693b6493909bc	JCB 16 digit	41.8339279005140057	-87.7364218185685587
23125	2020-05-04 05:56:20	2020-05-04	Tyrese Walter Sr.	tyrese.walter.sr.@geemail.com	St. Louis	Missouri	52014828313467969	8f06d5e2d6327afd92ad5f6bdf0106e2	VISA 16 digit	38.6022908340364665	-90.2691136406272676
23126	2020-05-04 06:00:01	2020-05-04	Angus Wiegand	angus.wiegand@woohoo.com	San Francisco	California	4447828807465633	6f921ed540aade1bfd982ee88cb39fa2	VISA 16 digit	37.7704994420912357	-122.430982779595709
23127	2020-05-04 06:10:00	2020-05-04	Soren Lakin	soren.lakin@geemail.com	Columbus	Ohio	4577261201419	dd9b263958869ae10a3dd3cc69173ce0	VISA 16 digit	39.9724383725363737	-82.9069726872958341
23128	2020-05-04 06:25:52	2020-05-04	Jazlynn Wehner	jazlynn.wehner@geemail.com	San Francisco	California	4508838237655261	f9cff05960e0f49024f831240848061e	VISA 13 digit	37.7812217112631217	-122.462350782596104
23129	2020-05-04 06:33:22	2020-05-04	Bentley Jaskolski IV	bentley.jaskolski.iv@warmmail.com	Montgomery	Alabama	3462689952346869	83a9320679199e99f7a95fe5b2aaafdc	JCB 15 digit	32.2552340406391806	-86.1877698866337454
23130	2020-05-04 06:53:01	2020-05-04	Lorelei Ritchie	lorelei.ritchie@geemail.com	Sacramento	California	210099541226235336	006a4c649d31e0c1dcb1b8dcb8f6dab1	VISA 16 digit	38.5269542822413129	-121.506673507696391
23131	2020-05-04 07:02:34	2020-05-04	Jaxen Ryan-Terry	jaxen.ryan.terry@geemail.com	San Francisco	California	4749376235844	2ba36aea1fb2f796173cbacd2e4f4eef	JCB 16 digit	37.7526705178444146	-122.427122761299401
23132	2020-05-04 07:13:18	2020-05-04	Mrs. Kay O'Reilly MD	mrs.kay.o'reilly.md@warmmail.com	Austin	Texas	54534212809380443	fd51f95328a911b4fed4567247fa0e5a	Mastercard	30.267932442029565	-97.8213792601838747
23133	2020-05-04 07:21:59	2020-05-04	Bryton Schroeder	bryton.schroeder@geemail.com	San Francisco	California	6011383770746322838	206cd9650f8650ee7e12d632b70ab309	JCB 16 digit	37.7557114606308133	-122.427492133894859
23134	2020-05-04 07:41:56	2020-05-04	Dr. Delisa Murray	dr.delisa.murray@geemail.com	Garden Grove	California	4516411273006110	84b258cd586b6807aede625688dbe2b7	Diners Club / Carte Blanche	33.748659893806277	-117.91362568922527
23135	2020-05-04 07:44:42	2020-05-04	Sariah Monahan	sariah.monahan@geemail.com	Oakland	California	3112303928180876597	d7885c296cdc286afb370b6ef86dab01	Voyager	37.7893897513407779	-122.270244028934286
23136	2020-05-04 07:48:47	2020-05-04	Jaylin Bergstrom	jaylin.bergstrom@woohoo.com	New York	New York	4077574591846	189ef5439610a424e3cccc85ca82cf38	VISA 13 digit	40.6820459450352914	-73.8616870561975958
23137	2020-05-04 07:50:44	2020-05-04	Tristan Lockman-Collier	tristan.lockman.collier@geemail.com	Berkeley	California	4040346388778663	1548c3fe2146afaa573212d7bafb6eb9	JCB 16 digit	37.8848695675588729	-122.283180767635031
23138	2020-05-04 08:06:38	2020-05-04	Ms. Ilona Ondricka MD	ms.ilona.ondricka.md@geemail.com	Houston	Texas	3024901212035666	f758fe52720f76ee772474eeb55e6e3c	VISA 16 digit	29.8656345725137733	-95.3632399525042587
23139	2020-05-04 08:09:44	2020-05-04	Tyrin Legros	tyrin.legros@geemail.com	Las Vegas	Nevada	3337328727088595957	93ac709076dbe2a1e2fe913bb29891df	VISA 16 digit	36.324552276926859	-115.205368563413984
23140	2020-05-04 08:09:59	2020-05-04	Denton Schumm	denton.schumm@geemail.com	Dallas	Texas	51257449575630263	d129dea5dbe48852707220a29d99a568	Maestro	32.8102686642475447	-96.7429805854763742
23141	2020-05-04 08:12:08	2020-05-04	Mrs. Cathrine Hammes	mrs.cathrine.hammes@geemail.com	West Jordan	Utah	51704023632402534	d1e84cdff8408a37d08851cb39e178ed	Diners Club / Carte Blanche	40.6142589990772365	-112.054945266255359
23142	2020-05-04 08:13:19	2020-05-04	Hazel Schultz	hazel.schultz@geemail.com	Chicago	Illinois	180013291969864404	fcf18d4ea402747ff2a5f3d46b1b777f	Diners Club / Carte Blanche	41.8668064488865426	-87.7445469066530421
23143	2020-05-04 08:15:03	2020-05-04	Crista Larson	crista.larson@geemail.com	Olathe	Kansas	6011185876704012764	4338dab73b8b78bda892c08410c2cb40	Mastercard	38.8203915863420832	-94.7779918249864153
23144	2020-05-04 08:15:34	2020-05-04	Jaxen Ryan	jaxen.ryan@geemail.com	El Paso	Texas	4001740616329	d808c8feeb2b1414ef2df0a51057679e	Discover	31.7791987414300472	-106.381188439669089
23145	2020-05-04 08:24:29	2020-05-04	Dessie Rau-Breitenberg	dessie.rau.breitenberg@geemail.com	Los Angeles	California	4568765006826517	87b3a0d350149e41bac9cac240738550	Discover	33.9547059079032394	-118.393286583385617
23146	2020-05-04 08:44:51	2020-05-04	Lelar Tremblay	lelar.tremblay@geemail.com	Dallas	Texas	210048768220074542	6400a694c27c157031e932a6d59164d9	Maestro	32.7877013780448578	-96.7238965005110884
23147	2020-05-04 08:53:58	2020-05-04	Dr. Pamella Fritsch	dr.pamella.fritsch@geemail.com	San Francisco	California	4641016473911	d6f82408640bfcde7ed526bde4ebad18	VISA 16 digit	37.7630786008657466	-122.430929699215923
23148	2020-05-04 08:55:35	2020-05-04	Domenick Jacobs III	domenick.jacobs.iii@geemail.com	Austin	Texas	3412811103064651	0bc862219769ac83d02e173bb005840e	Maestro	30.2858844855461271	-97.6835628182865747
23149	2020-05-04 09:13:52	2020-05-04	Dr. Jaycob Runolfsdottir DVM	dr.jaycob.runolfsdottir.dvm@geemail.com	Oklahoma City	Oklahoma	501866775911192	4fbdad79691cef57e6495c6570f9b098	JCB 16 digit	35.5091608753804167	-97.582686909976232
23150	2020-05-04 09:15:47	2020-05-04	Dr. Deante Doyle IV	dr.deante.doyle.iv@geemail.com	San Diego	California	676367262892853	62ba972b3564184b88ebc99558a4655f	Maestro	32.8174884573623515	-117.053565102154394
23151	2020-05-04 09:19:36	2020-05-04	Lucien Kuhic	lucien.kuhic@warmmail.com	Portland	Oregon	4547118216708081	02835092a9b76df9b7b66c5742d69551	JCB 16 digit	45.4683727944157994	-122.68796970252879
23152	2020-05-04 09:22:30	2020-05-04	Zaria Rowe	zaria.rowe@geemail.com	Kansas City	Kansas	4753315108476	ed89fc662ae459de2f6c881f2fb7620f	American Express	39.174965624222537	-94.7316873764090275
23153	2020-05-04 09:25:17	2020-05-04	Mrs. Syreeta Moen PhD	mrs.syreeta.moen.phd@woohoo.com	Shreveport	Louisiana	869948898643853691	9a81b5c8ee7b41f03e038ed619ce2e3b	JCB 16 digit	32.3827909856807494	-93.8446319589603632
23154	2020-05-04 09:34:56	2020-05-04	Kate Mueller-Bergnaum	kate.mueller.bergnaum@geemail.com	Montgomery	Alabama	55650823952600698	d4ed3071e9fc64148bb474357dd1e260	American Express	32.3044341975756026	-86.3407984561439577
23155	2020-05-04 09:53:55	2020-05-04	Giovani Kohler-Graham	giovani.kohler.graham@geemail.com	San Jose	California	869991154755294159	8941c5451ef81b69c163b3d5d998137e	Diners Club / Carte Blanche	37.3015358238767831	-121.878017180015888
23156	2020-05-04 09:56:59	2020-05-04	Mr. Andra Herzog V	mr.andra.herzog.v@geemail.com	San Francisco	California	4837550825937744	8f6cd680e46a2a16cd291187d240021c	JCB 16 digit	37.8147791171595316	-122.460089613482751
23157	2020-05-04 10:11:59	2020-05-04	Mrs. Janelle Spencer	mrs.janelle.spencer@geemail.com	Columbus	Ohio	869940836064261448	cfee5934dc339461f23128dad65d9d9b	Discover	40.0844467941250642	-82.9413613212064007
23158	2020-05-04 10:18:27	2020-05-04	Risa Durgan	risa.durgan@geemail.com	Pasadena	California	3031278976443698	59da605285963de43c7ddd44f12e2b78	Diners Club / Carte Blanche	34.2264688569441446	-118.117467945237081
23159	2020-05-04 10:18:27	2020-05-04	Allie Smitham	allie.smitham@geemail.com	Aurora	Colorado	4565011307842884	3305cbdb7d0fabafc96eee13632321f8	VISA 16 digit	39.6892321876827623	-104.777930066094555
23160	2020-05-04 10:43:36	2020-05-04	Miss Aida O'Conner DDS	miss.aida.o'conner.dds@geemail.com	Savannah	Georgia	4933088476603	8415b20a2b256dc9240b87a61cec7dad	Maestro	32.0486557799950234	-81.2264724225424146
23161	2020-05-04 10:44:20	2020-05-04	Cruz O'Conner	cruz.o'conner@woohoo.com	Boston	Massachusetts	3706223125212029	a86151b4ea84d5578beb2c37b6d634a1	VISA 16 digit	42.3771661491766594	-71.0805132325690323
23162	2020-05-04 10:49:29	2020-05-04	Dr. Trumaine Johnson DDS	dr.trumaine.johnson.dds@geemail.com	Albuquerque	New Mexico	4447314439038	e3dbca2a5cc1784fdee18081f365bb6d	Mastercard	35.1412068466790046	-106.689616689325874
23163	2020-05-04 10:52:50	2020-05-04	Foster Braun	foster.braun@geemail.com	Las Vegas	Nevada	210058867748452912	09b3d045dc986ae6bd50bcfd6dd85426	VISA 16 digit	36.3276008641447845	-115.238858444311091
23164	2020-05-04 11:09:07	2020-05-04	Ibrahim Goyette	ibrahim.goyette@geemail.com	Jacksonville	Florida	6011920644415611401	afa2078b47531f93eb91c486553bcf81	Voyager	30.3200303986720741	-81.7223869300525649
23165	2020-05-04 11:20:36	2020-05-04	Dr. Darrell Keeling	dr.darrell.keeling@geemail.com	Los Angeles	California	3042607043565902	afe2d02130a8ad8bac0e980322199745	Diners Club / Carte Blanche	33.9425199232395727	-118.452755862008033
23166	2020-05-04 11:20:55	2020-05-04	Edsel Considine	edsel.considine@geemail.com	Houston	Texas	4035476370354	27675b0a745ee44ae89eb6097a2d7af5	Diners Club / Carte Blanche	29.8100335941262529	-95.3423426289126326
23167	2020-05-04 11:27:54	2020-05-04	Delinda Hermiston-Rodriguez	delinda.hermiston.rodriguez@geemail.com	San Francisco	California	676358531393559	8eaa3cd7432563788f948546a84406b1	Voyager	37.7676725105196311	-122.393695044434722
23168	2020-05-04 11:28:50	2020-05-04	Tamisha Crist	tamisha.crist@warmmail.com	San Diego	California	3774660381648817	ca95edc5a87529bdf9ac99efe9d561aa	Maestro	32.7322520257972158	-117.188511575050654
23169	2020-05-04 11:33:30	2020-05-04	Deidra Miller	deidra.miller@warmmail.com	Tucson	Arizona	4313491548704	19a8afa534e4bc9e926108889236558c	Maestro	32.1751530957449248	-110.774784114560475
23170	2020-05-04 11:35:12	2020-05-04	Kane Robel	kane.robel@warmmail.com	Ontario	California	6011188980708484974	5ac5a0088964587a226505fc11b3545c	Maestro	34.009762436212597	-117.67025407143943
23171	2020-05-04 11:41:56	2020-05-04	Joleen Lubowitz DDS	joleen.lubowitz.dds@geemail.com	Oakland	California	3528654199625857825	52695dbacf97538ec17e9d2cbdf7161f	Maestro	37.8179336383281139	-122.254129292084869
23172	2020-05-04 11:43:25	2020-05-04	Aryanna Homenick DVM	aryanna.homenick.dvm@warmmail.com	Kansas City	Kansas	869946545757108733	c1c7e8173187c26ea51b0bbb18fdfa6c	Maestro	39.1424278797954344	-94.7324931972131168
23173	2020-05-04 11:48:07	2020-05-04	Melonie Tromp DDS	melonie.tromp.dds@woohoo.com	Lexington	Kentucky	4661595545251	6b4b14a3d79bb7baebb720c04c569b41	Mastercard	38.0761438048787397	-84.426926656988627
23174	2020-05-04 11:54:21	2020-05-04	Gay Mann-Fritsch	gay.mann.fritsch@geemail.com	Oceanside	California	3337267495680504073	aa0f86d815c825a1be414dabc64d9cd4	VISA 16 digit	33.2598740429040021	-117.389762701335187
23175	2020-05-04 11:59:02	2020-05-04	Miss Karrie Bernier MD	miss.karrie.bernier.md@geemail.com	Chicago	Illinois	3712761714264937	5cc28f9b0a5136eb90ffd22d4d0be9ad	JCB 16 digit	41.8818780071869483	-87.6839170889027315
23176	2020-05-04 12:12:17	2020-05-04	Mr. Hoover Hamill DVM	mr.hoover.hamill.dvm@geemail.com	Glendale	California	869913029386320901	0d402b0adabf36f0c6bf8dad32bae52d	JCB 15 digit	34.2037161697387688	-118.183717595496404
23177	2020-05-04 12:14:07	2020-05-04	Dr. Leon Rohan	dr.leon.rohan@woohoo.com	Carrollton	Texas	3528552847660229259	8d83d6d04bbe77378064c02b9e17a134	VISA 13 digit	33.0553342727866024	-96.9903187620315634
23178	2020-05-04 12:25:29	2020-05-04	Mr. Rayford Ziemann	mr.rayford.ziemann@geemail.com	Allentown	Pennsylvania	210008507470298015	65770a291d6d7ede161a6dbe52b27100	American Express	40.5966965746380382	-75.5660979573164013
23179	2020-05-04 12:34:19	2020-05-04	Jacques Auer Jr.	jacques.auer.jr.@woohoo.com	San Angelo	Texas	4583313744612	6940ac7105ccf63812cfaae36fd955c8	VISA 16 digit	31.3554834099639201	-100.372132614498966
23180	2020-05-04 12:39:33	2020-05-04	Andrae Cruickshank	andrae.cruickshank@geemail.com	Worcester	Massachusetts	4017204946108692	c6d46f535cbc2a809185670946624a59	VISA 16 digit	42.2945002592336365	-71.7859073313206437
23181	2020-05-04 12:48:29	2020-05-04	Loretto Walter-Mills	loretto.walter.mills@woohoo.com	Dallas	Texas	3033724096908498	81d3e6258d6506e9a26f167a14917600	VISA 16 digit	32.7514132582388839	-96.8471405931245499
23182	2020-05-04 12:55:16	2020-05-04	Rhona Bashirian	rhona.bashirian@warmmail.com	Chicago	Illinois	3006025935389784	50bd3e57a65fab2e47d60498465c175d	VISA 16 digit	41.8087844457313409	-87.7663877251587792
23183	2020-05-04 12:56:14	2020-05-04	Kristian Bednar-Moore	kristian.bednar.moore@geemail.com	San Francisco	California	180026059941251205	4c2cc9f24a54818a3d568ef2ceaa7501	VISA 16 digit	37.8009314384521744	-122.395857966708533
23184	2020-05-04 13:20:47	2020-05-04	Dr. Elon Romaguera DDS	dr.elon.romaguera.dds@geemail.com	Los Angeles	California	869918887371904194	6966a661d5e1cb090867e9103df24f57	VISA 13 digit	33.9605522750277018	-118.372161010279498
23185	2020-05-04 13:22:48	2020-05-04	Mrs. Marcie D'Amore DVM	mrs.marcie.d'amore.dvm@geemail.com	Berkeley	California	6011086293630498614	2b4d88dbadb382be85665d96c2a5f5c2	JCB 16 digit	37.8722804839884759	-122.292718068137034
23186	2020-05-04 13:37:00	2020-05-04	Nehemiah Toy	nehemiah.toy@geemail.com	Pittsburgh	Pennsylvania	3411832812487794	8bb7dc39a95688d38b63f2c6a1bb1a85	Mastercard	40.3499367187220557	-79.928888420125844
23187	2020-05-04 13:42:58	2020-05-04	Deanna Glover PhD	deanna.glover.phd@woohoo.com	Irving	Texas	3776262205756336	f8b12ff2e0628a4dd33c3aa99f1e4689	JCB 16 digit	32.7651855855666128	-96.9000653740297935
23188	2020-05-04 13:53:40	2020-05-04	Terrell Gerhold	terrell.gerhold@geemail.com	Oklahoma City	Oklahoma	3467288866054548	8111600090eafd6131ffa55c5846468b	VISA 16 digit	35.493003483992446	-97.5195740270324052
23189	2020-05-04 14:08:12	2020-05-04	Marget Mayert PhD	marget.mayert.phd@woohoo.com	Winston–Salem	North Carolina	52148609234500503	87eecfb3dd057dbb79d89ed721095538	JCB 15 digit	36.1690543927483219	-80.2021551227793026
23190	2020-05-04 14:16:03	2020-05-04	Myah Klein	myah.klein@geemail.com	Los Angeles	California	3158690636307137527	05693174f51f251de00170bbc8c49bcc	VISA 13 digit	34.0954348813608235	-118.370598215469343
23191	2020-05-04 14:16:39	2020-05-04	Kylie Mueller-Senger	kylie.mueller.senger@geemail.com	El Paso	Texas	869930840132505515	3928c9bddeccba7732cd6187630250a0	Voyager	31.8178835620466636	-106.456166457476101
23192	2020-05-04 14:19:19	2020-05-04	Coral Dietrich-Wolf	coral.dietrich.wolf@warmmail.com	Los Angeles	California	3096157747229282790	a11c8fe5aea7a74ec1d494c29867be73	Voyager	34.0022027244191563	-118.335900116711102
23193	2020-05-04 14:30:12	2020-05-04	Herma Kautzer	herma.kautzer@geemail.com	Washington	District of Columbia	6011635599151918905	79ea8e411fc948d348e337d803536946	Maestro	38.8180933567959841	-77.1101785300511864
23194	2020-05-04 14:41:08	2020-05-04	Mrs. Trish Heller MD	mrs.trish.heller.md@warmmail.com	Chicago	Illinois	869956974685820804	a6aef727d61e042af297fe6c93b34515	Mastercard	41.9119177774827918	-87.6579886126827432
23195	2020-05-04 14:42:51	2020-05-04	Geary Stamm MD	geary.stamm.md@geemail.com	Houston	Texas	4098708322247	2047bfb68546e22935a24b1047019422	Mastercard	29.7003249684426933	-95.3883027822259777
23196	2020-05-04 14:49:46	2020-05-04	Ned Mertz	ned.mertz@woohoo.com	Minneapolis	Minnesota	3096191459662217139	9a09f0b1a1d9dfc95d2114f2333297ef	VISA 13 digit	45.0298876249317033	-93.3600346701957307
23197	2020-05-04 14:56:55	2020-05-04	Corda Ryan	corda.ryan@warmmail.com	Cincinnati	Ohio	3458290383098017	84361f68316e249d2050dac34c800307	VISA 16 digit	39.1196900367036449	-84.4493384198557493
23198	2020-05-04 15:02:42	2020-05-04	Bob Casper	bob.casper@woohoo.com	Irvine	California	3039530019959565	f3be14645072970f1727aabcd141a3e3	JCB 15 digit	33.5885610689424041	-117.682627008949595
23199	2020-05-04 15:09:17	2020-05-04	Miss Katy Kuhn	miss.katy.kuhn@warmmail.com	Pomona	California	6011646058559336258	347511be25968aca8848eb26870aa37b	VISA 13 digit	33.9902330204881764	-117.838739252878725
23200	2020-05-04 15:19:39	2020-05-04	Mr. Homer Beer	mr.homer.beer@geemail.com	New York	New York	3049161763056273	c2e17497a6ab6e12540d813b4a95071c	VISA 16 digit	40.5970023784078649	-74.0377221756510409
23201	2020-05-04 15:22:19	2020-05-04	Jessee Rogahn	jessee.rogahn@geemail.com	San Diego	California	3158731497934747126	660244af81cb9c2b79e3157f2d4e29fc	JCB 16 digit	32.7345667315714053	-117.178210435472437
23202	2020-05-04 15:28:09	2020-05-04	Garvin Blanda	garvin.blanda@geemail.com	New York	New York	6011111148848005826	1598f048449aab9cb2616c69a7a5ada7	JCB 15 digit	40.641227991668508	-73.9834541227564131
23203	2020-05-04 15:31:40	2020-05-04	Miss Alvira Runolfsson PhD	miss.alvira.runolfsson.phd@geemail.com	Sacramento	California	4183707483040	231562a3e6314bef7e945192059e1251	VISA 16 digit	38.6332536089498575	-121.548340212671448
23204	2020-05-04 15:40:53	2020-05-04	Reino Lakin	reino.lakin@warmmail.com	Virginia Beach	Virginia	3041116643975496	b07ea0b8718872e1f779c16d10c31c8c	VISA 16 digit	36.6863077775295849	-76.0540751521613458
23205	2020-05-04 15:43:03	2020-05-04	Mr. Erich Monahan PhD	mr.erich.monahan.phd@woohoo.com	Chicago	Illinois	3018049610104704	77e778cb64e8092e5c270b58d49e6d4e	VISA 16 digit	41.856404317759349	-87.6902064316004441
23206	2020-05-04 15:44:13	2020-05-04	Herminia Lockman-Barrows	herminia.lockman.barrows@geemail.com	Victorville	California	3015989640305065	2744346a14a7e8ef14315b5122d7f810	JCB 16 digit	34.4277498135108502	-117.346871448323498
23207	2020-05-04 15:47:03	2020-05-04	Jewel Braun	jewel.braun@woohoo.com	New York	New York	3480656817837661	cec45a937a036252279646934a663434	JCB 16 digit	40.6427867130599907	-73.8569371491566216
23208	2020-05-04 15:51:39	2020-05-04	Lucero Hirthe	lucero.hirthe@geemail.com	Rochester	Minnesota	6011370062426826071	9d88e0158e837262d9804cf937b31062	American Express	43.9347607533350555	-92.4968630998048837
23209	2020-05-04 16:07:37	2020-05-04	Zeno Beatty	zeno.beatty@geemail.com	Scottsdale	Arizona	210034797861014851	333914b5f5c30869748119f8de83eec2	American Express	33.7230629849836205	-111.795415711259835
23210	2020-05-04 16:11:43	2020-05-04	Ali Weissnat-Rodriguez	ali.weissnat.rodriguez@woohoo.com	Lexington	Kentucky	4417906029750705	bcdb74888ac804601b00633e5be08642	JCB 16 digit	38.0436280492104615	-84.4689804234906916
23211	2020-05-04 16:15:07	2020-05-04	Dr. Wes Barton III	dr.wes.barton.iii@geemail.com	San Francisco	California	4952547430506293	97b7ab5eafc6b6db19de024192d2fde3	Diners Club / Carte Blanche	37.7940500472642924	-122.449156933009974
23212	2020-05-04 16:15:55	2020-05-04	Oneida McGlynn MD	oneida.mcglynn.md@geemail.com	Phoenix	Arizona	55826182481059002	6f98aed4d1e03f5a29962024a2e6dc46	VISA 16 digit	33.6153005818769373	-112.089833450030909
23213	2020-05-04 16:39:15	2020-05-04	Mr. Murdock Stoltenberg III	mr.murdock.stoltenberg.iii@warmmail.com	Jersey City	New Jersey	6011149322400123113	17b18363660a3975fe03a9d52f1d8cb1	Discover	40.7201487372104083	-74.1205953214738571
23214	2020-05-04 16:43:11	2020-05-04	Aloysius Fay	aloysius.fay@geemail.com	Long Beach	California	180047752503292550	96e6cb8ce9cf09bf58a5351daa0a3a94	JCB 15 digit	33.8004632878869771	-118.078869323495027
23215	2020-05-04 16:50:33	2020-05-04	Mrs. Myrl Donnelly	mrs.myrl.donnelly@warmmail.com	Paterson	New Jersey	869977510911600696	e9fa27149863b97b919d865946bf88c6	Diners Club / Carte Blanche	40.8937570318069277	-74.1076360323440326
23216	2020-05-04 16:58:14	2020-05-04	Aidyn Wiegand	aidyn.wiegand@geemail.com	West Jordan	Utah	4364279399423284	25c9dcbdf8dd3f46d70e61c9c2a1db0b	VISA 16 digit	40.5879520567856744	-111.986763136330239
23217	2020-05-04 17:05:34	2020-05-04	Cheryll Dibbert	cheryll.dibbert@geemail.com	San Francisco	California	6011472178256388888	2cb776ba9a7f2e24831fde55b90582f7	JCB 16 digit	37.791433772273237	-122.471924665081659
23218	2020-05-04 17:06:03	2020-05-04	Zayne Hills	zayne.hills@geemail.com	Jacksonville	Florida	3742912038638751	8e0e8887b6ac36655136ce5fcda6703d	Mastercard	30.362402012483777	-81.6900253743011575
23219	2020-05-04 17:06:34	2020-05-04	Cornelia Fisher	cornelia.fisher@geemail.com	Evansville	Indiana	4701245792695	2a88c15996783db9bad724e237fdc409	Voyager	38.0181354588035489	-87.6194287153825115
23220	2020-05-04 17:08:39	2020-05-04	Bradley Jones PhD	bradley.jones.phd@geemail.com	Washington	District of Columbia	6011743492228308491	9e7f671ed66ae0178fd6332688372491	JCB 16 digit	38.9668001708839071	-77.0575668235521789
23221	2020-05-04 17:10:52	2020-05-04	Millard Ruecker	millard.ruecker@geemail.com	Berkeley	California	3158927143919604262	cca4f33aae6f8f5c2a61530025560990	Diners Club / Carte Blanche	37.8654685000035656	-122.278214551501463
23222	2020-05-04 17:19:23	2020-05-04	Marrion Bruen	marrion.bruen@warmmail.com	Lafayette	Louisiana	3027910943210040	434e4c1b6d59c407ae45950e910f93f3	Mastercard	30.1532086952567084	-91.9964663478862406
23223	2020-05-04 17:32:54	2020-05-04	Mrs. Kimberli Hartmann PhD	mrs.kimberli.hartmann.phd@geemail.com	Ventura	California	4992950137281644	a99ba8227bc7955996736ea0f92413ff	VISA 16 digit	34.2970209554929326	-119.279417716163024
23224	2020-05-04 17:43:52	2020-05-04	Atlas Ryan	atlas.ryan@geemail.com	Chicago	Illinois	676241721839896	491576275a0d6c6bef280852529764db	Voyager	41.8459614100236479	-87.7471340451885027
23225	2020-05-04 17:54:58	2020-05-04	Cornell Jenkins	cornell.jenkins@geemail.com	San Francisco	California	503897614543300	31f1dee26251272cdcf89fb094601f9f	Discover	37.7899456944527969	-122.424452311996703
23226	2020-05-04 18:06:39	2020-05-04	Erin Hahn	erin.hahn@woohoo.com	San Francisco	California	4581814830351	1453dcbbee22add91b6a349151c36bb1	VISA 16 digit	37.7723570873041794	-122.431602233493152
23227	2020-05-04 18:08:41	2020-05-04	Brandon Crist	brandon.crist@geemail.com	New York	New York	675952325084326	b41a18fff03fa6e1508a35ec294da7ad	JCB 16 digit	40.6302035243008248	-74.0042532345175772
23228	2020-05-04 18:39:36	2020-05-04	Chasity Crist	chasity.crist@geemail.com	San Francisco	California	3158223984448405429	5911f599613a6847aec1d0b0fb1ba763	Maestro	37.778910294409016	-122.443667549934261
23229	2020-05-04 18:42:43	2020-05-04	Eliezer Walsh	eliezer.walsh@geemail.com	Memphis	Tennessee	4754657957033	54406b6c77b1c15da642341ffbb14ff0	VISA 13 digit	35.09221179011017	-90.0727619038686242
23230	2020-05-04 18:42:55	2020-05-04	Aylin Kub	aylin.kub@geemail.com	Virginia Beach	Virginia	55761459719092907	3c7900a34b7905ec0648c452ea142ad1	Mastercard	36.6824392590858039	-76.1116598367828914
23231	2020-05-04 19:09:48	2020-05-04	Mrs. Nadine Huels MD	mrs.nadine.huels.md@geemail.com	Warren	Michigan	869984198332973388	c1af520eb5195daa9f047729cb32453b	JCB 16 digit	42.4248739927072052	-83.0404145756270822
23232	2020-05-04 19:25:29	2020-05-04	Rollin Sanford	rollin.sanford@geemail.com	Sacramento	California	869981653473604013	1607cd77174fc8c6c780a5dcf08d0b54	American Express	38.5679603942468745	-121.453989862256122
23233	2020-05-04 19:29:27	2020-05-04	Jazlynn Upton	jazlynn.upton@geemail.com	Dallas	Texas	6011619651473649716	2ab67e4176af792fc2444b02e711a5ab	JCB 16 digit	32.822121464162322	-96.7419413385409825
23234	2020-05-04 19:53:33	2020-05-04	Peyton Paucek	peyton.paucek@geemail.com	Boise	Idaho	3112863348490662052	040ef40e9ec1dfdfc453d96d66664eb8	Voyager	43.5251720098450789	-116.133205688810719
23235	2020-05-04 19:54:29	2020-05-04	Dorris Hodkiewicz	dorris.hodkiewicz@warmmail.com	West Covina	California	4697368958271	6a67243f1108cddf23e320eca6a4372f	Voyager	34.1319810460429665	-117.94940610538012
23236	2020-05-04 19:56:33	2020-05-04	Dr. Tyrique Kulas III	dr.tyrique.kulas.iii@geemail.com	Alexandria	Virginia	561220093071189	a1ee54106947ccdc59fd5c5483de7856	Mastercard	38.8995897949323037	-77.1749782608807209
23237	2020-05-04 20:20:26	2020-05-04	Sawyer Pagac	sawyer.pagac@geemail.com	San Francisco	California	6011314175154146204	526d4ef2bf9fbe514e0b0dad523f77cc	JCB 15 digit	37.7722620511680347	-122.43031600986221
23238	2020-05-04 20:20:43	2020-05-04	Sarah Ward	sarah.ward@geemail.com	Charlotte	North Carolina	4169864515385	f739b98e2dd37146d30b4e6912b361df	Diners Club / Carte Blanche	35.2761355224318791	-80.8278839049804958
23239	2020-05-04 20:34:02	2020-05-04	Marion Fadel	marion.fadel@geemail.com	Indianapolis	Indiana	180057987909336331	e9dd5863e543fd87c885597e03a357f9	Mastercard	39.7180189425133179	-86.1622943561259689
23240	2020-05-04 20:37:04	2020-05-04	Jinnie Olson	jinnie.olson@geemail.com	Little Rock	Arkansas	180021825166283882	7e832f8867328ad8a36d7b62eeec952d	Maestro	34.732646237760413	-92.3138626844495462
23241	2020-05-04 20:42:49	2020-05-04	Mr. Darrin Bradtke DDS	mr.darrin.bradtke.dds@geemail.com	Oakland	California	4684426570116	81a599d12c1b43bce934e3a5f34445cc	VISA 13 digit	37.8322372137723519	-122.273633550463884
23242	2020-05-04 20:55:22	2020-05-04	Mr. Eldon Kuhic	mr.eldon.kuhic@geemail.com	Seattle	Washington	3028610262165242	80bfc5e9f6dcc397b60620883309e6ee	VISA 16 digit	47.5751225591097011	-122.352814518326511
23243	2020-05-04 21:01:24	2020-05-04	Georgine Bosco	georgine.bosco@geemail.com	Glendale	California	3528085134413855011	31fee15ed7c175645ba3ddcb48f82f61	JCB 16 digit	34.2357465222697641	-118.163123314212271
23244	2020-05-04 21:04:28	2020-05-04	Dr. Darrion Gutmann	dr.darrion.gutmann@geemail.com	Denver	Colorado	4974249509254	edabb2a57ee4b0be7656884e8d8243ad	Discover	39.7845973484270274	-104.919932884188739
23245	2020-05-04 21:26:34	2020-05-04	Dr. Jones Koss	dr.jones.koss@geemail.com	Pittsburgh	Pennsylvania	869916091349782483	96d14546031e3c42fa6aecc8ebe2b180	JCB 16 digit	40.5142693823158737	-80.0136926399715236
23246	2020-05-04 21:48:42	2020-05-04	Esperanza Corkery	esperanza.corkery@geemail.com	Killeen	Texas	589340142807342	3106317d803071dc07217d806e223bfa	Diners Club / Carte Blanche	31.1282736713763342	-97.78207804636844
23247	2020-05-04 21:54:04	2020-05-04	Miriam Armstrong	miriam.armstrong@warmmail.com	San Francisco	California	3096350232773023770	55ac8eca77f7c4445db8cd2a4f4c4226	Voyager	37.7967170406102468	-122.422881029639868
23248	2020-05-04 21:55:07	2020-05-04	Mr. Young Lubowitz	mr.young.lubowitz@geemail.com	Elgin	Illinois	639085250540979	612a9f67a7f5e59e177fb5eaeed7228f	VISA 16 digit	42.0812477988474072	-88.2717962230842659
23249	2020-05-04 22:03:17	2020-05-04	Sarai Lind	sarai.lind@geemail.com	Los Angeles	California	210014415505356604	78739539ce39c19cca6e6bbae525dbdf	VISA 16 digit	34.0986324131820311	-118.330734762176121
23250	2020-05-04 22:09:16	2020-05-04	Harlan Keeling	harlan.keeling@geemail.com	Dallas	Texas	3158802671766512600	bb208a60825030e1988974ac3fdd2563	VISA 13 digit	32.8634442311517887	-96.6989940129183196
23251	2020-05-04 22:14:33	2020-05-04	Ninnie Brakus	ninnie.brakus@geemail.com	Nashville	Tennessee	676201604993889	d696fc9b3eec6681e5d37504e268c996	Mastercard	36.1483521952882398	-86.7684872960113012
23252	2020-05-04 22:19:07	2020-05-04	Felicity Muller	felicity.muller@warmmail.com	Fort Worth	Texas	3088756335794689345	b0ff93f8193fb16a0728d93b496f9c48	Voyager	32.8291600666064767	-97.2689250604070708
23253	2020-05-04 22:19:16	2020-05-04	Jaimie Kassulke	jaimie.kassulke@warmmail.com	Berkeley	California	180041072114913148	55a091819eefd155b3eec174f354325b	Discover	37.837324076136845	-122.245377548259611
23254	2020-05-04 22:19:51	2020-05-04	Helene Morar	helene.morar@woohoo.com	Elk Grove	California	180079620528558217	5b0f0502b66b6894c24d8853d0a5ea43	American Express	38.5138068101186306	-121.387306702360519
23255	2020-05-04 22:27:42	2020-05-04	Aleah Konopelski	aleah.konopelski@woohoo.com	El Paso	Texas	4325426615820	655bc8fb8203495a407758dc890182d8	VISA 16 digit	31.8276269655503334	-106.382762518709526
23256	2020-05-04 23:03:01	2020-05-04	Roberta Oberbrunner	roberta.oberbrunner@geemail.com	Nashville	Tennessee	4842029687493	05b00ec94da5f15677ecd120a5ee3788	VISA 16 digit	36.1530078420538459	-86.7566854580212379
23257	2020-05-04 23:05:06	2020-05-04	Ivy Jenkins	ivy.jenkins@woohoo.com	Milwaukee	Wisconsin	4189733768999	f49de02ce4068f161fc40554ac21a03c	JCB 15 digit	43.1312762403480718	-87.9733324852407037
23258	2020-05-04 23:22:19	2020-05-04	Amiyah Schumm	amiyah.schumm@geemail.com	New Orleans	Louisiana	3781657718694119	29c24dd7fc0b94eaed25922077467f03	VISA 16 digit	30.0367584615029379	-89.9070903728976845
23259	2020-05-04 23:22:38	2020-05-04	Randle Ryan	randle.ryan@geemail.com	Springfield	Missouri	3054735005159295	1562626236f21c463d7bdadd19b9d834	American Express	37.2590547804448775	-93.2243370399635296
23260	2020-05-04 23:37:47	2020-05-04	Maud Considine PhD	maud.considine.phd@geemail.com	College Station	Texas	060463219375126	38957b3e2b43b49d9c4acbd3584fd931	American Express	30.5842785886999238	-96.3613967538658613
23261	2020-05-04 23:45:33	2020-05-04	Arturo Wolff DDS	arturo.wolff.dds@geemail.com	Seattle	Washington	589360902564677	c35384ced966a0da51dc7422211c958b	JCB 15 digit	47.6971195171978337	-122.252692260492211
23262	2020-05-04 23:47:23	2020-05-04	Mrs. Danna Bins MD	mrs.danna.bins.md@geemail.com	Pomona	California	3723736884026552	d82eebb08619583338e853d7b911cdb4	Voyager	34.0172842798791848	-117.741282684492319
23263	2020-05-05 00:17:20	2020-05-05	Marnie Kerluke	marnie.kerluke@woohoo.com	Salt Lake City	Utah	3031436285580184	c827a825534cb872e488ac035f0f3c83	VISA 16 digit	40.8759259841084486	-112.008636062959212
23264	2020-05-05 00:27:20	2020-05-05	Jonatan Barrows	jonatan.barrows@geemail.com	Philadelphia	Pennsylvania	3011289782292625	85cc86110a86000408e227e5be0f29ac	JCB 16 digit	40.0970882816199179	-75.0345053946033147
23265	2020-05-05 00:31:17	2020-05-05	Dr. Lucas Wunsch Sr.	dr.lucas.wunsch.sr.@geemail.com	San Francisco	California	3044563504182208	1ede8e18f96eaed276b3a50f2aa81aa2	Diners Club / Carte Blanche	37.7590913012856291	-122.438682770707558
23266	2020-05-05 00:34:18	2020-05-05	Elissa Cartwright	elissa.cartwright@woohoo.com	San Francisco	California	3022814167246638	e3300d270353048da27f9a7e96fecf3a	VISA 13 digit	37.7601072476198354	-122.421764654276146
23267	2020-05-05 00:35:03	2020-05-05	Mitchel Erdman-Franecki	mitchel.erdman.franecki@geemail.com	Columbus	Ohio	869987791017044686	ed8397731509553bb1808b52d92e99bd	Mastercard	39.8969311847861832	-83.0111080991804613
23268	2020-05-05 00:37:13	2020-05-05	Debbi Kerluke-Hilpert	debbi.kerluke.hilpert@woohoo.com	Memphis	Tennessee	6011161962590066987	77846b181309718cd2c11fea8c2ca62f	VISA 16 digit	35.0697544302858404	-89.8935726613994746
23269	2020-05-05 00:46:16	2020-05-05	Everet Satterfield	everet.satterfield@woohoo.com	Bakersfield	California	3045061545319094	d0ce05026765dab115730e6dfc31885b	American Express	35.4006825940858576	-119.042774225053563
23270	2020-05-05 00:47:21	2020-05-05	Zaire Runolfsdottir-Erdman	zaire.runolfsdottir.erdman@woohoo.com	Evansville	Indiana	869926762824410109	b15bf8c860867cb87a15f587b41d26a2	Diners Club / Carte Blanche	37.9652426942855072	-87.5623683261618027
23271	2020-05-05 00:47:50	2020-05-05	Veronica Cremin-Boyer	veronica.cremin.boyer@warmmail.com	New Orleans	Louisiana	52383999563542513	05847438a16ac5e8d40bbdec8c19834f	Discover	30.061256382802128	-89.964654742486772
23272	2020-05-05 00:56:37	2020-05-05	Ellen Swaniawski	ellen.swaniawski@geemail.com	San Francisco	California	210048603189121374	58dfe6d2f895f8f3783e0b39418c1de5	JCB 16 digit	37.7816612671981673	-122.417005512515104
23273	2020-05-05 00:56:41	2020-05-05	Palmer Wolf	palmer.wolf@geemail.com	Las Vegas	Nevada	3404289356635925	b2abd3a9da7842b21c2f03b0f53b5297	American Express	36.2053305414140212	-115.34925837313979
23274	2020-05-05 01:09:27	2020-05-05	Tamisha Gaylord	tamisha.gaylord@geemail.com	Virginia Beach	Virginia	4487802720200	2bf274cb244f7cff0fca79d3b181b347	Discover	36.7901382368244256	-76.1250479547444741
23275	2020-05-05 01:22:12	2020-05-05	Kayleigh Emmerich-Feeney	kayleigh.emmerich.feeney@warmmail.com	Birmingham	Alabama	4615373766169252	47ac8326ece59caf6c162898149eb3b7	American Express	33.5928184937011451	-86.8640057468563356
23276	2020-05-05 01:47:41	2020-05-05	Citlali Wilderman	citlali.wilderman@geemail.com	San Diego	California	51737727733718595	51c6b7a53dbdf7254428370f55ce2aae	Diners Club / Carte Blanche	32.8404435162499553	-117.163099728096284
23277	2020-05-05 01:51:16	2020-05-05	Abdullah Klocko-Beer	abdullah.klocko.beer@geemail.com	Los Angeles	California	52707964113476140	68734223d85d5452bdb7617c2c63f0ad	Mastercard	33.9524712263472352	-118.452132778753707
23278	2020-05-05 01:57:28	2020-05-05	Aubree Gusikowski	aubree.gusikowski@woohoo.com	Fort Lauderdale	Florida	3475247402006602	403981ba28f99c7186d4274bce0ddfe9	Diners Club / Carte Blanche	26.0818512673944234	-80.1953598698887902
23279	2020-05-05 02:08:55	2020-05-05	Miss Alison Grady DVM	miss.alison.grady.dvm@geemail.com	San Diego	California	4275038572598884	5e66e5ff2c7edd97c168345170125066	VISA 16 digit	32.8963116731096079	-117.073283570017665
23280	2020-05-05 02:10:16	2020-05-05	Jaquelin Durgan	jaquelin.durgan@geemail.com	New York	New York	3158802291000287651	fdc189116fe22e25d679d0b81c411dea	VISA 16 digit	40.6921118675023337	-74.0025473591767167
23281	2020-05-05 02:20:37	2020-05-05	Kaye Gulgowski	kaye.gulgowski@geemail.com	San Jose	California	6011092183060101451	cf571c60aa9c84e81e8ae1b005a98809	JCB 16 digit	37.2224495986297725	-121.781136893456434
23282	2020-05-05 02:35:18	2020-05-05	Tristin Pagac	tristin.pagac@geemail.com	Jersey City	New Jersey	6011918538450972690	0a01bc0c17e7358c1b3932ae356759fa	Mastercard	40.8064887335464306	-74.096492948425194
23283	2020-05-05 02:40:47	2020-05-05	Mr. Lavern McCullough	mr.lavern.mccullough@geemail.com	San Angelo	Texas	6011703903922014779	39f19180dbc889766387aa593896a3ca	Discover	31.3821913578234586	-100.536735694400974
23284	2020-05-05 02:42:50	2020-05-05	Diandra Dickinson	diandra.dickinson@geemail.com	Seattle	Washington	676198713141970	7dae70acd7ebe6065dfadb3c3bd8a3bf	Diners Club / Carte Blanche	47.5221891457140444	-122.349885433299093
23285	2020-05-05 02:46:58	2020-05-05	Leaner Conroy	leaner.conroy@warmmail.com	San Francisco	California	180008351268797577	c03a91730eac752571afc7f65a180c0c	JCB 16 digit	37.7949850177189504	-122.476171495454366
23286	2020-05-05 02:57:57	2020-05-05	Verlyn Quitzon	verlyn.quitzon@geemail.com	Phoenix	Arizona	6011234550673051597	374b4ed21d7aed9f48d413a351d9722b	JCB 16 digit	33.6093739180292985	-112.000620756524057
23287	2020-05-05 02:58:22	2020-05-05	Junior Farrell	junior.farrell@geemail.com	Oakland	California	52444964573048346	ce1159414ddb1e54c056036588b1fa8b	American Express	37.8353122308200724	-122.246678526671829
23288	2020-05-05 02:59:28	2020-05-05	Tristin Herzog	tristin.herzog@warmmail.com	Denver	Colorado	869967724907229020	6303a19ceecc807543e04d7382f449b1	JCB 15 digit	39.708819725229958	-104.784811485257379
23289	2020-05-05 03:09:37	2020-05-05	Dr. Dell Hilll Sr.	dr.dell.hilll.sr.@woohoo.com	New York	New York	630406784843820	39ad28b8ac15fb1af7546580d5b5b087	JCB 16 digit	40.6954356183987116	-74.0324341348733697
23290	2020-05-05 03:28:43	2020-05-05	Seward Bode	seward.bode@geemail.com	Fayetteville	North Carolina	3088327047220108077	1c65052df9514c65ea103ceab882f0b9	JCB 15 digit	35.0005253491245227	-78.9503421086017028
23291	2020-05-05 03:42:53	2020-05-05	Josiah Ruecker	josiah.ruecker@geemail.com	San Francisco	California	4343012794501578	91967a8ef611f26e05fc2878171bef13	Mastercard	37.7574187285744003	-122.410985927426225
23292	2020-05-05 03:46:24	2020-05-05	Ned Blanda	ned.blanda@geemail.com	Irvine	California	52187206814475834	730375c993fbb6b6efe85fd7520a845a	American Express	33.7712579246159663	-117.778627907532453
23293	2020-05-05 03:54:03	2020-05-05	Judi Schiller	judi.schiller@geemail.com	Sandy Springs	Georgia	561217742193943	66aa9010a50c07ecabd164a180720c9c	Discover	33.8815379643402963	-84.3619973158545804
23294	2020-05-05 04:14:40	2020-05-05	Frankie Bailey I	frankie.bailey.i@geemail.com	San Francisco	California	4472591306676443	d7e82df1f852806a2fb8b0ce48b2e502	Discover	37.7926637671966574	-122.424141533069914
23295	2020-05-05 04:19:20	2020-05-05	Dr. Cleola Boyer	dr.cleola.boyer@geemail.com	Rochester	New York	3783260472607159	0c88cde8baeb2490809bd9112fe0d6c4	American Express	43.1118844421092433	-77.7028112402424256
23296	2020-05-05 04:19:51	2020-05-05	Merri Kulas	merri.kulas@geemail.com	San Mateo	California	51604036415087786	6ba655b9116c9be44ad86e1e6afe1a13	VISA 16 digit	37.568487214704227	-122.255138579788053
23297	2020-05-05 04:32:49	2020-05-05	North Hills	north.hills@geemail.com	Plano	Texas	4603880883363802	95ef739bc479c682fb87cab82b83a243	JCB 15 digit	33.0237598949663393	-96.7039540802311137
23298	2020-05-05 04:41:18	2020-05-05	Aurthur Skiles	aurthur.skiles@geemail.com	Milwaukee	Wisconsin	180026370185826689	513285e473226a172cfeac85d16c7d94	VISA 13 digit	42.9968657462943327	-87.9529488821614507
23299	2020-05-05 04:47:42	2020-05-05	Adalberto Gerlach	adalberto.gerlach@geemail.com	Santa Clarita	California	3158475234654746305	a30e62d8dcf0851818f76b8999b8c440	JCB 16 digit	34.4615728597827271	-118.553688977016876
23300	2020-05-05 04:47:44	2020-05-05	Tremaine Mueller	tremaine.mueller@warmmail.com	San Francisco	California	3088664610815913432	177cc3708f02cb0dd619bfaad6229e8c	American Express	37.7624942679917623	-122.411710044884757
23301	2020-05-05 05:03:15	2020-05-05	Joseph Rowe	joseph.rowe@warmmail.com	Costa Mesa	California	3528023973440643238	7fc44061b8c7177b380394d6296a3e9a	Mastercard	33.7413409782588474	-117.969777202313026
23302	2020-05-05 05:08:37	2020-05-05	Aurelio Stoltenberg	aurelio.stoltenberg@geemail.com	Anchorage	Alaska	6011309876050724880	06e0e74cb63f3c60715ba9202a57c988	JCB 16 digit	61.0898890392139577	-149.30853766357825
23303	2020-05-05 05:17:27	2020-05-05	Edra Hane	edra.hane@geemail.com	Los Angeles	California	869951649395450127	4a8793470eafaf62e5029ceb996c4e27	American Express	33.9388233560468962	-118.344473128299413
23304	2020-05-05 05:29:21	2020-05-05	Hertha Daniel	hertha.daniel@geemail.com	Chicago	Illinois	3042947991535162	9f4bdb65b1ec8046898badd718c0de92	American Express	41.8076083415955324	-87.6171412302210939
23305	2020-05-05 05:29:26	2020-05-05	Braden Hintz	braden.hintz@geemail.com	Baltimore	Maryland	3716638167307817	0e9c90a95d67c99264e8e53b221041cc	VISA 16 digit	39.3404407922644168	-76.6113194775786326
23306	2020-05-05 05:35:39	2020-05-05	Elizebeth Labadie	elizebeth.labadie@woohoo.com	Vista	California	4069785083408	9f4efafba9ec571017c54649873dccb0	American Express	33.1481793845519448	-117.27858937667348
23307	2020-05-05 05:49:34	2020-05-05	Carolann Carroll	carolann.carroll@geemail.com	Chandler	Arizona	55018775115601624	94f2dc3357ca1c859646388a84b376cd	Diners Club / Carte Blanche	33.3803908004049177	-111.939741090580455
23308	2020-05-05 05:53:34	2020-05-05	Tyrik Mraz	tyrik.mraz@geemail.com	Baltimore	Maryland	639084259630436	d3a3a50d7f06b00bc96c0434a27c6b6a	American Express	39.376531472522764	-76.5678556867428171
23309	2020-05-05 06:02:17	2020-05-05	Lynsey Oberbrunner	lynsey.oberbrunner@woohoo.com	Seattle	Washington	4681912686249469	4dcd5a385d48818100b81da140cfabc5	JCB 16 digit	47.6609267522506386	-122.326712911661332
23310	2020-05-05 06:06:16	2020-05-05	Earlie DuBuque	earlie.dubuque@geemail.com	Westminster	Colorado	3038907230591644	eabd381b96fef82f29d471024fce3752	American Express	39.8126978761821988	-105.056798596648136
23311	2020-05-05 06:14:00	2020-05-05	Velva Block	velva.block@geemail.com	Temecula	California	3040393809873739	48cc75ee348d85f5c1b7e27f5c06d8bb	JCB 15 digit	33.4909885410353496	-117.130866367761783
23312	2020-05-05 06:19:17	2020-05-05	Francisquita Mertz	francisquita.mertz@geemail.com	Berkeley	California	4916451830670	4fa0ac31ddafa4c8984e0b2f271f953a	VISA 16 digit	37.8744816285897059	-122.283910398107821
23313	2020-05-05 06:26:00	2020-05-05	Mrs. Ione Dooley MD	mrs.ione.dooley.md@geemail.com	Cary	North Carolina	6011727518000064611	d43ca11f0efc2b950317bd06dd868531	VISA 16 digit	35.7203787169061613	-78.8642791797958296
23314	2020-05-05 06:26:01	2020-05-05	Dr. Chin Kovacek II	dr.chin.kovacek.ii@geemail.com	San Antonio	Texas	869925429259468637	d329ea623e8e3599e7be963a927e4754	Discover	29.3793995201192786	-98.6154714955318639
23315	2020-05-05 06:46:12	2020-05-05	Benjamen Hickle	benjamen.hickle@geemail.com	Des Moines	Iowa	3112877560681404797	c344ebdb854564ebacd956704406e093	Diners Club / Carte Blanche	41.6032889148429064	-93.5860917524013729
23316	2020-05-05 06:46:56	2020-05-05	Reece Harvey	reece.harvey@geemail.com	Rancho Cucamonga	California	180034425128907325	15d6bd71b4e3a051fefb150189e6c706	VISA 16 digit	34.1914231117807361	-117.65807735561468
23317	2020-05-05 07:15:33	2020-05-05	Aliya Price	aliya.price@woohoo.com	Phoenix	Arizona	3337843507319877846	24ecd4f5f5244925fe3fb2ea89e309f5	JCB 15 digit	33.627577846164634	-112.154339935157822
23318	2020-05-05 07:16:45	2020-05-05	Steve Doyle	steve.doyle@geemail.com	Plano	Texas	3096094607916989576	fcda2ab3a5be66b268f6f5c7d8ecab0f	Mastercard	33.0899246295534084	-96.7984319911986546
23319	2020-05-05 07:17:53	2020-05-05	Mr. Wheeler O'Reilly III	mr.wheeler.o'reilly.iii@woohoo.com	Boston	Massachusetts	51235199258080099	90801a22e73739168cf62616c32cfc17	VISA 16 digit	42.3861164611000589	-71.107502058981737
23320	2020-05-05 07:28:13	2020-05-05	Kaitlynn Carroll	kaitlynn.carroll@geemail.com	New York	New York	3337800205864550758	fe3548e3b52c09635dea5a4f80c770ba	JCB 15 digit	40.6173382900413102	-74.0262688880216331
23321	2020-05-05 07:29:35	2020-05-05	Kimberely Abernathy DVM	kimberely.abernathy.dvm@geemail.com	Dallas	Texas	6011094954442676578	d30d80f08721a8ca3e27ed264fdce0b5	VISA 16 digit	32.8064134835537544	-96.7997232537213677
23322	2020-05-05 07:42:46	2020-05-05	Ina Gutmann	ina.gutmann@geemail.com	Los Angeles	California	3158486447090255536	a642c65139e0c6c2b709f130a4d0616f	VISA 16 digit	34.0666830990795049	-118.486922501865024
23323	2020-05-05 07:44:19	2020-05-05	Neha Hermiston	neha.hermiston@geemail.com	Sunnyvale	California	3492664271971832	c428589f955b037a1f79a07b8ccc22e5	Discover	37.4564520526669966	-121.99045157569573
23324	2020-05-05 07:58:50	2020-05-05	Verl Nolan	verl.nolan@woohoo.com	West Covina	California	3112902589518735874	0084b1e730a821c4e889789e50c02b0f	VISA 16 digit	34.0424674996748564	-117.857205535245683
23325	2020-05-05 08:06:14	2020-05-05	Mrs. Peggy Quitzon DVM	mrs.peggy.quitzon.dvm@geemail.com	Dallas	Texas	6011114593137198831	5335ce2df0320189b5f0b5b575dae9d2	Mastercard	32.8580314518224483	-96.8002836003396538
23326	2020-05-05 08:13:34	2020-05-05	Shirl Hudson	shirl.hudson@warmmail.com	New York	New York	55243221445561896	a71054353c6663c0ee3ce4e98106b6bb	JCB 16 digit	40.7097712566833962	-73.9843959934905087
23327	2020-05-05 08:15:44	2020-05-05	Esco Keeling	esco.keeling@geemail.com	Memphis	Tennessee	3047603862605163	0ec48709965017d97850409998591014	American Express	35.1639461266409654	-90.0246161453217297
23328	2020-05-05 08:35:03	2020-05-05	Mace Dicki	mace.dicki@warmmail.com	South Bend	Indiana	3046568807989579	16be7bcac9863f469dcf5647aa617d4a	American Express	41.7517092935420635	-86.2902589987088078
23329	2020-05-05 08:35:39	2020-05-05	Mr. Brian Hintz	mr.brian.hintz@woohoo.com	Detroit	Michigan	4200628966687	b5c407007b12f386ec7e049d7a7823f6	American Express	42.4377604111488935	-83.0733377299856386
23330	2020-05-05 08:40:39	2020-05-05	Sherrill Hilll	sherrill.hilll@geemail.com	New York	New York	503899409020106	149c09e7e2500e672d7bc3f27e39b212	JCB 16 digit	40.5720107001010319	-74.0090131146263275
23331	2020-05-05 08:57:35	2020-05-05	Dr. Bertie Cormier	dr.bertie.cormier@geemail.com	Dallas	Texas	3088888194408401303	c0b02f4f8a5d35909d88c6bef1638c4c	Diners Club / Carte Blanche	32.7755214062791325	-96.7723319886215023
23332	2020-05-05 09:00:21	2020-05-05	Ayleen Erdman	ayleen.erdman@geemail.com	Los Angeles	California	501846706235614	d4080fe905ef772eab71e50fbf866beb	VISA 16 digit	34.0011060879897329	-118.374077676701546
23333	2020-05-05 09:01:26	2020-05-05	Ms. Fallon Schamberger	ms.fallon.schamberger@warmmail.com	Berkeley	California	869965163448344893	a4788dd0b6dbfe0e0aa36607fe9d1426	VISA 16 digit	37.8540573644081775	-122.280374561029106
23334	2020-05-05 09:03:06	2020-05-05	Mr. Ernie Moore MD	mr.ernie.moore.md@geemail.com	Denton	Texas	3014972422299368	815f555b7d79b29a41df1eb520b87814	Discover	33.1808747350037123	-97.0991911569736885
23335	2020-05-05 09:36:16	2020-05-05	Harry Grant	harry.grant@geemail.com	New York	New York	4857330807515684	86e2d0adcbb4e9ff8e53e58f8a110892	American Express	40.680779404681175	-73.9213959291938636
23336	2020-05-05 09:37:09	2020-05-05	Senora Crooks	senora.crooks@woohoo.com	Joliet	Illinois	6011640417643342506	09d83c984f2b36e42d29024e0e641615	VISA 16 digit	41.5691304349664605	-88.0657856728520159
23337	2020-05-05 09:38:41	2020-05-05	Lovie Huels	lovie.huels@geemail.com	Raleigh	North Carolina	4181213147312433	10e302b1b99947684a6d0d24b4f319f4	JCB 16 digit	35.7428811018489299	-78.7024171685736604
23338	2020-05-05 09:41:50	2020-05-05	Kamryn Langworth	kamryn.langworth@warmmail.com	Sparks	Nevada	51267738939284447	91e926f625aeab29b547475c7de9c82e	American Express	39.5015309850458038	-119.727039604340121
23339	2020-05-05 09:46:33	2020-05-05	Maggie Swift	maggie.swift@geemail.com	Kansas City	Missouri	210026232840261357	bb7b579873f382aea1d027bca3c3b072	Diners Club / Carte Blanche	39.1461687596816574	-94.5953493000231731
23340	2020-05-05 10:03:41	2020-05-05	Dr. Uriah Ernser II	dr.uriah.ernser.ii@geemail.com	New York	New York	3158927304203924648	03eb951a8dc5e11916291c23854b3091	VISA 16 digit	40.5829290246348791	-73.8751028775133136
23341	2020-05-05 10:07:29	2020-05-05	Ryker Connelly	ryker.connelly@geemail.com	Las Cruces	New Mexico	3015665707298373	7780c6398e30637d644a72cc7039f10f	JCB 16 digit	32.4244983254499743	-106.852557902375978
23342	2020-05-05 10:25:42	2020-05-05	Lindsay Metz-Bruen	lindsay.metz.bruen@geemail.com	Chula Vista	California	869989562526879823	4024bd6626882c969581c3c7e9612259	Mastercard	32.5664548945844174	-117.081339891697084
23343	2020-05-05 10:53:20	2020-05-05	Rowan Hagenes	rowan.hagenes@geemail.com	San Antonio	Texas	4280572223130203	d63fd9bef9c3f25a03c97bb74e3aee25	VISA 16 digit	29.4051092996798467	-98.5536458201076755
23344	2020-05-05 10:53:53	2020-05-05	Tammy Lockman	tammy.lockman@warmmail.com	Meridian	Idaho	869930265718358693	b048f99d825d389fc424f16ed28c10b5	VISA 16 digit	43.6144553203143133	-116.434943227650223
23345	2020-05-05 11:01:05	2020-05-05	Stevie Gutmann	stevie.gutmann@geemail.com	Philadelphia	Pennsylvania	503845835847422	9d59cfc177872813c151184a4b25b97f	JCB 16 digit	40.0602866583462784	-75.1623827566292135
23346	2020-05-05 11:16:24	2020-05-05	Christoper Haley MD	christoper.haley.md@geemail.com	Indianapolis	Indiana	180066507414640602	ae360d7f1936972f8c00dd5534768ef8	VISA 13 digit	39.7775509608916948	-86.117250424364201
23347	2020-05-05 11:36:50	2020-05-05	Dominick Shields	dominick.shields@geemail.com	Chicago	Illinois	3416738102453849	5f013692551b52855f0d2ddf50109ede	JCB 15 digit	41.8589769963011165	-87.6012559846539034
23348	2020-05-05 11:37:14	2020-05-05	Hortense Gaylord MD	hortense.gaylord.md@geemail.com	Omaha	Nebraska	3528366514296582024	b7d80090ceab8d72b75c63c3c7980837	Maestro	41.3318205583054592	-96.1441730365272633
23349	2020-05-05 11:45:39	2020-05-05	Cleve Friesen	cleve.friesen@geemail.com	San Francisco	California	180057810516209412	22bdece81252c991745c71de7889e844	JCB 16 digit	37.7691683801560742	-122.411042281311452
23350	2020-05-05 11:51:54	2020-05-05	Audie Dooley	audie.dooley@geemail.com	San Francisco	California	3112075225343814649	017ff7fa125a968e7324ddc229a9d34a	JCB 15 digit	37.75968970631574	-122.446636194701838
23351	2020-05-05 12:26:34	2020-05-05	Alyvia Hudson-Hansen	alyvia.hudson.hansen@geemail.com	Carrollton	Texas	4831760541353920	bbffa7b5601ea292f81ee8fe88223a4b	Voyager	32.9724680626686677	-96.8726170007467289
23352	2020-05-05 12:30:02	2020-05-05	Danyell Reinger PhD	danyell.reinger.phd@woohoo.com	San Francisco	California	4639650922631107	78571fac59e80ed392c9ce3350171287	JCB 15 digit	37.7657089935554851	-122.438255035260823
23353	2020-05-05 12:33:37	2020-05-05	Macel Hudson	macel.hudson@geemail.com	Spokane	Washington	6011279134807670592	c1965089b72f2cc260c26e1ae5dc4075	American Express	47.5826819835934742	-117.507448034676912
23354	2020-05-05 12:37:41	2020-05-05	Sienna Fahey	sienna.fahey@warmmail.com	Frisco	Texas	869937698837703568	a5313e9666907339163ec517d9cf6111	VISA 16 digit	33.2433547371994678	-96.9017055127046945
23355	2020-05-05 12:39:43	2020-05-05	Dr. Pairlee Abbott	dr.pairlee.abbott@geemail.com	Baton Rouge	Louisiana	4694501489051951	b1af3b287d623cc98ef0dd1f5b1c3c1b	Diners Club / Carte Blanche	30.3645488064482798	-91.1546156187649785
23356	2020-05-05 12:54:42	2020-05-05	Erich Armstrong	erich.armstrong@geemail.com	Fort Worth	Texas	51595571026264086	57799c584eb0d21d76c733b3bdc70f17	Discover	32.8410818825531763	-97.3985129035364849
23357	2020-05-05 12:59:13	2020-05-05	Antone Thiel Jr.	antone.thiel.jr.@geemail.com	Rialto	California	3096745791950519623	3e0f10a1cf5262c57a3d32c9a7a4df2b	Voyager	34.0894665115263322	-117.43553600237631
23358	2020-05-05 13:00:19	2020-05-05	Debbi Reichert	debbi.reichert@geemail.com	Milwaukee	Wisconsin	3096435930027239287	4cee34958af36541808480deefec4fe8	Voyager	43.0916010582439597	-87.9129026396766307
23359	2020-05-05 13:01:19	2020-05-05	Zona Gutmann	zona.gutmann@warmmail.com	San Antonio	Texas	54473431695929872	efca6778aecefdd187649cc35f08be61	Voyager	29.4957630685135719	-98.4636386348236243
23360	2020-05-05 13:22:55	2020-05-05	Dr. Reilly Zemlak DVM	dr.reilly.zemlak.dvm@geemail.com	Berkeley	California	55605197210786581	d64d7028f2fd7f31b4ef5983dd645fbd	American Express	37.849133856134813	-122.273566879635624
23361	2020-05-05 13:34:48	2020-05-05	Luella Klocko	luella.klocko@geemail.com	Dallas	Texas	180077707138359870	7b2558eeefe30500fb78162ecd8ad3dd	VISA 16 digit	32.7077408101681613	-96.7257041424009856
23362	2020-05-05 13:58:04	2020-05-05	Jaycee Morissette	jaycee.morissette@geemail.com	Corpus Christi	Texas	3088971499737382043	4002e1dc5e2984545942882f0ce94329	American Express	27.8066475788999341	-97.2374292564407057
23363	2020-05-05 14:03:12	2020-05-05	Ala Erdman	ala.erdman@geemail.com	Miami	Florida	3337008907118141678	7d5d642ee66799e215e52b99307d7ce8	American Express	25.8325586475569757	-80.2389942607715767
23364	2020-05-05 14:06:11	2020-05-05	Mr. Elza Robel	mr.elza.robel@woohoo.com	Pembroke Pines	Florida	3045901078175571	3135f85f24c49478cd84bef3b1821f5c	JCB 16 digit	26.0669670342039339	-80.2656942507620954
23365	2020-05-05 14:06:39	2020-05-05	Ginny Cassin	ginny.cassin@geemail.com	Edison	New Jersey	869929324331024555	cf545c0c0be1dc440791d3a7438cf2c8	VISA 13 digit	40.5914848961364427	-74.3745694824546604
23366	2020-05-05 14:07:52	2020-05-05	Astrid Okuneva-Cremin	astrid.okuneva.cremin@geemail.com	San Diego	California	3337607194830893929	ef6eecf9be3b1b51ee3485b4599a36a0	VISA 16 digit	32.8697900267384924	-117.116405525747695
23367	2020-05-05 14:07:53	2020-05-05	Zena Bernhard	zena.bernhard@geemail.com	Colorado Springs	Colorado	3777744993408435	f73d73c6ad7ff5a39ed3063a2e59afbf	Maestro	38.958136372086777	-104.696048406294366
23368	2020-05-05 14:11:59	2020-05-05	Londyn Deckow MD	londyn.deckow.md@woohoo.com	Stockton	California	4702628143604097	66ccc402600edca2d2dd224971d91631	Maestro	38.0551866353686918	-121.384988069356609
23369	2020-05-05 14:28:08	2020-05-05	Porsha Hayes	porsha.hayes@geemail.com	Thousand Oaks	California	676221817396191	dbcd58a331728d1bc977608211273cbd	VISA 16 digit	34.2427412855710855	-118.807008264205237
23370	2020-05-05 14:42:46	2020-05-05	Mr. Nehemiah Koelpin	mr.nehemiah.koelpin@warmmail.com	Laredo	Texas	4433959728742465	c08939702f757f8ea9cd1708e30e3412	JCB 16 digit	27.4974242021046607	-99.5346368900973317
23371	2020-05-05 14:48:24	2020-05-05	Trumaine Bernier	trumaine.bernier@geemail.com	Berkeley	California	51246257706765674	7da5f92f4da7a49bcc41e8b101699027	Discover	37.8806022252499304	-122.269642322769272
23372	2020-05-05 14:52:30	2020-05-05	Henri Effertz	henri.effertz@geemail.com	San Francisco	California	4360859035147	f360366e76815722515917486178a09a	Voyager	37.7923226426588457	-122.36909300964119
23373	2020-05-05 14:56:56	2020-05-05	Alberta Zieme MD	alberta.zieme.md@woohoo.com	Virginia Beach	Virginia	676264572458467	be088fcfbaf2a32198751306b425a1fe	VISA 16 digit	36.8133634350448844	-76.0827771914795079
23374	2020-05-05 15:02:27	2020-05-05	Ambrose Okuneva	ambrose.okuneva@geemail.com	Santa Maria	California	210093673531971143	9421f5da351c7998a1b33d679c56f161	VISA 13 digit	35.0164438175566488	-120.519864788829537
23375	2020-05-05 15:02:31	2020-05-05	Hardy Leffler	hardy.leffler@geemail.com	Arlington	Texas	4671254747613132	56af078229712455b3af40508dbef48b	American Express	32.6107622773170434	-97.1881939266834394
23376	2020-05-05 15:07:01	2020-05-05	Dr. Bridgette Marks DVM	dr.bridgette.marks.dvm@geemail.com	Long Beach	California	561268350352321	57a05deb82f457dff79a7266885e05d4	Voyager	33.7276076521545605	-118.255032705904171
23377	2020-05-05 15:11:32	2020-05-05	Zakary Emmerich-Gerhold	zakary.emmerich.gerhold@geemail.com	Garland	Texas	180010034731070428	9ff0fb09da6926ed065938cdf5c45a3d	Maestro	32.8639103051509665	-96.6028221552886066
23378	2020-05-05 15:16:42	2020-05-05	Mr. Rod Weissnat	mr.rod.weissnat@geemail.com	Fayetteville	North Carolina	3112623756211591171	635f1a63c042cb3e39e4db478b8970a0	American Express	35.1360495876774195	-78.8899471138734327
23379	2020-05-05 15:19:23	2020-05-05	Harman Frami	harman.frami@geemail.com	New York	New York	6011971534811081952	cdbc8cfadb6d8f24e732f812d00dcdfd	VISA 13 digit	40.6628592219427247	-74.0268611540913497
23380	2020-05-05 15:22:43	2020-05-05	Ms. Casandra Hammes DDS	ms.casandra.hammes.dds@geemail.com	Honolulu	Hawaii	4663782031366256	9f05b1b16e2e0e5ce48f5632321d7ca2	VISA 16 digit	21.3313944325067126	-157.846788906047493
23381	2020-05-05 15:32:51	2020-05-05	Taja Turcotte	taja.turcotte@geemail.com	San Francisco	California	51560358967347786	004b9b06b5dc73c97be48c283ed6a894	Maestro	37.7872247069769713	-122.450100347889844
23382	2020-05-05 15:54:28	2020-05-05	Bobbie Upton	bobbie.upton@geemail.com	Glendale	Arizona	3112825083592057045	f266ca27fa9d98d33536e2b8319e27bd	Mastercard	33.6236845822766384	-112.137066493907568
23383	2020-05-05 15:55:20	2020-05-05	Dangelo Lockman	dangelo.lockman@geemail.com	San Francisco	California	3158607774492042202	45c5c4dd51bdc4301781b3cccf43d424	Diners Club / Carte Blanche	37.738708512716272	-122.41343600930584
23384	2020-05-05 16:07:12	2020-05-05	Monna Cassin	monna.cassin@geemail.com	Oxnard	California	3018842575365587	108b2209b7684851845bd65cf3e3f248	VISA 13 digit	34.2149470351591702	-119.132543993313234
23385	2020-05-05 16:08:09	2020-05-05	Fulton Ullrich	fulton.ullrich@geemail.com	Palmdale	California	4473942930199766	ae24f3eca3137e20b057d3efe46d419c	VISA 13 digit	34.5888272502310556	-118.133633926696703
23386	2020-05-05 16:14:39	2020-05-05	Dr. Russel Rempel	dr.russel.rempel@warmmail.com	St. Petersburg	Florida	3051964733466391	ffa7f513531a7a408a0a97aeb68aa8cd	JCB 15 digit	27.8299596398491431	-82.6136473936851985
23387	2020-05-05 16:20:12	2020-05-05	Raelynn Bernhard PhD	raelynn.bernhard.phd@geemail.com	Los Angeles	California	210026384846260337	9ddba474df98a15b475982fa72980bbe	Mastercard	34.1190838070452216	-118.466216624806819
23388	2020-05-05 16:45:06	2020-05-05	Amalie Weissnat	amalie.weissnat@geemail.com	New York	New York	55402773567410432	03b19f5c6eb15e0fe886e6e7733f69c8	JCB 15 digit	40.5719261086303717	-73.8524411782517944
23389	2020-05-05 17:02:37	2020-05-05	Mrs. Diann Block DDS	mrs.diann.block.dds@geemail.com	Santa Ana	California	869936151506371714	55a7c9eab37ad99637ad29c3627fd3c6	VISA 16 digit	33.8099352976877228	-117.793435326071446
23390	2020-05-05 17:22:28	2020-05-05	Torrance Brekke	torrance.brekke@geemail.com	St. Petersburg	Florida	869983993467673550	230e6d29a43f2f109b5ad48b65225d35	Diners Club / Carte Blanche	27.6855808989033108	-82.6839039210587714
23391	2020-05-05 17:26:54	2020-05-05	Mr. Tegan Upton II	mr.tegan.upton.ii@geemail.com	Boston	Massachusetts	4703267208638705	59fc298d29edccac84b0fa552262a124	Mastercard	42.4196270792447052	-71.0242434161201146
23392	2020-05-05 17:38:11	2020-05-05	Kaila Reynolds PhD	kaila.reynolds.phd@warmmail.com	Buffalo	New York	4379317102146389	23da46ea34a966942f3d677478d1127a	American Express	42.9351022371742843	-78.934736425143484
23393	2020-05-05 17:41:57	2020-05-05	Keisha Hermann-Bernhard	keisha.hermann.bernhard@geemail.com	Naperville	Illinois	3713721388186526	eb1df562b4cce464325733d3f6be39a2	Diners Club / Carte Blanche	41.6788391313429969	-88.261680815450859
23394	2020-05-05 17:49:28	2020-05-05	Ryann Rolfson-Legros	ryann.rolfson.legros@geemail.com	Gilbert	Arizona	869929335560298439	f512c2088eb6d0e7570fc58f097a3821	VISA 13 digit	33.286303326009957	-111.68545177319497
23395	2020-05-05 17:55:10	2020-05-05	Rosalee Bartell MD	rosalee.bartell.md@geemail.com	Houston	Texas	4386850689723	74bdf456485a5e0c0ef5282311cb69e0	Voyager	29.8580242837857455	-95.3903429530575835
23396	2020-05-05 17:58:46	2020-05-05	Dorothy Jones MD	dorothy.jones.md@geemail.com	Houston	Texas	3746760499738750	2ae5f0b7dc5ed03da7a66246c95a4b04	VISA 16 digit	29.692497248070687	-95.4640462761759778
23397	2020-05-05 17:59:37	2020-05-05	Alf Erdman	alf.erdman@geemail.com	Worcester	Massachusetts	3528852266521971859	ade1608a306ba94972d8b3e47ca4b5a6	Voyager	42.3656639336310334	-71.7499584313269736
23398	2020-05-05 18:08:53	2020-05-05	August Hermiston	august.hermiston@geemail.com	New York	New York	3337545024650602289	82b4524235f06c62e99562f5426a485f	VISA 16 digit	40.6800962899569427	-74.0139647540997743
23399	2020-05-05 18:13:55	2020-05-05	Sandy Lindgren	sandy.lindgren@geemail.com	San Francisco	California	6011266259085194380	d07751ae82653beaa506158e39997e0f	VISA 13 digit	37.787805673447707	-122.419382898868577
23400	2020-05-05 18:16:43	2020-05-05	Shalon Rath	shalon.rath@geemail.com	Oakland	California	6011550070902702999	6ec8d5586dfbdb9fe73f0cb9754e70bf	Voyager	37.8216450080829176	-122.288711006238174
23401	2020-05-05 18:19:34	2020-05-05	Solon Kris-Waelchi	solon.kris.waelchi@warmmail.com	Irvine	California	3021841597464789	b6354d2485dbb76cbbf6981d01a3f998	VISA 16 digit	33.7565575283966979	-117.779146880983561
23402	2020-05-05 18:32:00	2020-05-05	Miguelangel Barton	miguelangel.barton@warmmail.com	San Francisco	California	6011260258141896703	d84b17b208aff36a110310b58bf75bbe	JCB 16 digit	37.7460823326684292	-122.430715068059939
23403	2020-05-05 18:51:48	2020-05-05	Dr. Kayden McClure	dr.kayden.mcclure@geemail.com	Philadelphia	Pennsylvania	6011817966930721126	492f0f4a686e79b7063b181008d1ac32	Discover	39.9267141776118422	-75.167442533876013
23404	2020-05-05 18:53:30	2020-05-05	Jakobe Schmeler	jakobe.schmeler@geemail.com	Los Angeles	California	3158335107559267082	41826bdbb1df6373abb35a92f48568a3	VISA 16 digit	34.0736884859722053	-118.506811024899775
23405	2020-05-05 19:01:33	2020-05-05	Destin Lemke	destin.lemke@geemail.com	New York	New York	4035008412823	da794e05d08fc4084d8f340b267e64f2	VISA 13 digit	40.573893949644642	-73.9373217799130771
23406	2020-05-05 19:27:19	2020-05-05	Presley Lehner	presley.lehner@warmmail.com	Los Angeles	California	3023110101555765	ae4c784a973d171f042f727a08be244b	VISA 13 digit	33.921773206755141	-118.333357462472463
23407	2020-05-05 19:54:42	2020-05-05	Luvinia Roob-Stehr	luvinia.roob.stehr@geemail.com	Sacramento	California	4233334685243554	ffe5e38a4586b763cac4e23edd8d4512	JCB 16 digit	38.5759924893531974	-121.377314219368984
23408	2020-05-05 19:59:39	2020-05-05	Arvilla Roob	arvilla.roob@geemail.com	Oakland	California	3047707193241695	53ab0f37f410fdefd8647d488a106e8a	VISA 13 digit	37.7985493136443083	-122.25675403570294
23409	2020-05-05 20:02:40	2020-05-05	Jan Collier	jan.collier@warmmail.com	Corpus Christi	Texas	4590178273918	f7a79d18cb9ecad070ca1835bec54e9d	VISA 16 digit	27.7493004482176175	-97.272838858125354
23410	2020-05-05 20:09:24	2020-05-05	Mr. Deondre Rogahn PhD	mr.deondre.rogahn.phd@geemail.com	Norfolk	Virginia	3337332095204422066	f3e1e90946ed4e3dc88dfae91e0f9ca8	JCB 15 digit	36.8989114555548881	-76.1836118008945249
23411	2020-05-05 20:13:43	2020-05-05	Roxane Terry	roxane.terry@warmmail.com	San Francisco	California	502048155219073	24c563a45d24bc4bccf446a1be96f40c	American Express	37.7689067905770059	-122.433358682642563
23412	2020-05-05 20:19:26	2020-05-05	Infant Baumbach	infant.baumbach@geemail.com	Round Rock	Texas	503865932833943	16500e7f5a2a22711fd32f32e65ee4ee	VISA 13 digit	30.6013172475758957	-97.6483353024665206
23413	2020-05-05 20:32:06	2020-05-05	Brigitte O'Keefe DVM	brigitte.o'keefe.dvm@woohoo.com	Jacksonville	Florida	3037719845412772	fa3cbb989f1bb31411b44ed6d830c9a2	Diners Club / Carte Blanche	30.4301120615616441	-81.7059306185770851
23414	2020-05-05 20:37:44	2020-05-05	Tricia Powlowski MD	tricia.powlowski.md@geemail.com	Chicago	Illinois	6011028742408281694	f14e0c066dd584b858a00c42c3c17397	Discover	41.8288766038905848	-87.7699967809982553
23415	2020-05-05 21:28:42	2020-05-05	Camryn Smitham	camryn.smitham@geemail.com	Henderson	Nevada	4502013386834390	d8eb4558ef600fecb141c1b3c6fbe251	Diners Club / Carte Blanche	36.0094358651831783	-115.053305084553372
23416	2020-05-05 21:43:31	2020-05-05	Hazel Lakin	hazel.lakin@geemail.com	Fremont	California	502014414514597	b586a6eaf040b793629731967b4bba4f	JCB 15 digit	37.4405003046318896	-121.871058253430576
23417	2020-05-05 21:53:51	2020-05-05	Sylas White-Kuvalis	sylas.white.kuvalis@geemail.com	Houston	Texas	3112560703847590909	2cf39d97a4c3b77c404fea4e2edf65a0	JCB 16 digit	29.8656938145481057	-95.3304413734950202
23418	2020-05-05 21:59:01	2020-05-05	Dr. Omer Bergstrom III	dr.omer.bergstrom.iii@geemail.com	El Cajon	California	4229929519439967	3fe66de6a5bbe41e70dcd395a148d2d0	Diners Club / Carte Blanche	32.8072276460479912	-116.956905455393354
23419	2020-05-05 22:12:28	2020-05-05	Little Rolfson-Krajcik	little.rolfson.krajcik@geemail.com	Memphis	Tennessee	676119893375055	8290fbb234012164afb9488657990493	VISA 16 digit	35.0819852966416619	-90.0576870857529315
23420	2020-05-05 22:15:54	2020-05-05	Mrs. Shanell Hintz	mrs.shanell.hintz@geemail.com	Houston	Texas	4319327048645	2a3ec78e4a8323be2e173f59c09df8ad	VISA 16 digit	29.8083363005504012	-95.4754926192589153
23421	2020-05-05 22:19:52	2020-05-05	Kelby Howell	kelby.howell@geemail.com	Oakland	California	4596475035901960	326132c692d4b15adf6d2a704228747a	JCB 16 digit	37.8067029489549142	-122.270666683003341
23422	2020-05-05 22:23:20	2020-05-05	Trever Breitenberg	trever.breitenberg@geemail.com	New York	New York	55860454280767797	69bde78375f20a69c2e00785166f1c34	Discover	40.6182946343198381	-73.872032401327786
23423	2020-05-05 22:42:46	2020-05-05	Amit Wolf	amit.wolf@geemail.com	El Paso	Texas	4588167908313544	299260d3292fe80b0335d288e3d532f3	Mastercard	31.8702691592104763	-106.479945018094043
23424	2020-05-05 22:56:10	2020-05-05	Bernadette Larkin MD	bernadette.larkin.md@geemail.com	San Francisco	California	180060742274894736	321f4ccb4d51a8292f2e1125f15f6693	Discover	37.8008397214859571	-122.440872072474477
23425	2020-05-05 23:21:19	2020-05-05	Tavon Hand	tavon.hand@geemail.com	Colorado Springs	Colorado	4225538980425571	67bfe73a45d59e474d2e245639d56e9c	Maestro	38.8229004886515412	-104.736694646688917
23426	2020-05-05 23:25:19	2020-05-05	Mr. Ed Kirlin	mr.ed.kirlin@geemail.com	New York	New York	3528459543091689773	b145d74142b568ed58c1c0eb7466c9b9	JCB 16 digit	40.5689417261853791	-74.0083341299451831
23427	2020-05-05 23:30:32	2020-05-05	Finnegan Jast DVM	finnegan.jast.dvm@geemail.com	Sugar Land	Texas	3158017469409428743	648acebbe300e1c13fa432189c89798e	Mastercard	29.5504425265878439	-95.5972209922976788
23428	2020-05-05 23:41:52	2020-05-05	Candido Feil	candido.feil@geemail.com	New York	New York	180029635110904810	433131f13b8852c5c19656de4988320c	Diners Club / Carte Blanche	40.6434875167198442	-74.0107858281012625
23429	2020-05-05 23:48:56	2020-05-05	Jalen Stark	jalen.stark@geemail.com	Elgin	Illinois	210091531054561471	2162c9fa6c62f8311b7f8625d33f8ddd	Diners Club / Carte Blanche	41.9737718096751706	-88.2710692171294369
23430	2020-05-05 23:52:36	2020-05-05	Mamie Hermann IV	mamie.hermann.iv@geemail.com	Fort Worth	Texas	3528110665184953831	436e31f59c8430f1a8907c4553e9398f	Discover	32.7609372618198407	-97.3984479964997547
23431	2020-05-06 00:09:01	2020-05-06	Vina Herman MD	vina.herman.md@geemail.com	Stamford	Connecticut	3029522172586186	be643b2e82e944828f763c9c3933dd6c	VISA 16 digit	41.0666882419377615	-73.5349259976800624
23432	2020-05-06 00:16:12	2020-05-06	Dr. Tisha Pfannerstill PhD	dr.tisha.pfannerstill.phd@geemail.com	San Francisco	California	3006204189084231	2ce47d7886639893b7c32f8014c5ed7a	Discover	37.7776780018929301	-122.386569824897464
23433	2020-05-06 00:19:07	2020-05-06	Oneida Swaniawski	oneida.swaniawski@geemail.com	Green Bay	Wisconsin	210051135133742512	7414d3c32403596ce24f44a118b85c5b	Voyager	44.6078896368451367	-87.998423089721058
23434	2020-05-06 00:20:30	2020-05-06	Aiden Kshlerin-Gislason	aiden.kshlerin.gislason@geemail.com	Oceanside	California	4125407313001	fcdc4404b2c133b6a705265ab9cfc67c	VISA 16 digit	33.1326638695206483	-117.377902662436298
23435	2020-05-06 00:22:55	2020-05-06	Ednah Koch	ednah.koch@woohoo.com	Des Moines	Iowa	869984181751078715	3aac9138a1ea1bdf47ec04718124e586	Diners Club / Carte Blanche	41.4809367309067412	-93.5773517200302365
23436	2020-05-06 00:26:40	2020-05-06	Buster Emmerich	buster.emmerich@geemail.com	Louisville	Kentucky	6011744759460461868	3f54c6630476d0693303f55407e1d316	Maestro	38.154150922353935	-85.6377162977192654
23437	2020-05-06 00:29:22	2020-05-06	Josefita O'Kon	josefita.o'kon@woohoo.com	El Monte	California	3337924396720359004	2e5c0a36fe492e9e1d30781cf099c237	JCB 15 digit	34.14135629992969	-118.097792367523908
23438	2020-05-06 00:37:11	2020-05-06	Cristofer Gerhold	cristofer.gerhold@woohoo.com	Memphis	Tennessee	6011580951205493697	5b1e7f558f605bce687e59ad45ee8771	American Express	35.037397969567408	-90.0331092110626372
23439	2020-05-06 00:39:31	2020-05-06	Ms. Rhianna Heidenreich DDS	ms.rhianna.heidenreich.dds@geemail.com	Las Vegas	Nevada	180074670579579336	81dd07ffd9c9211a65242d1f1b74b7d3	Diners Club / Carte Blanche	36.2548992106791559	-115.17187597818895
23440	2020-05-06 00:46:16	2020-05-06	Kayleen Nicolas	kayleen.nicolas@geemail.com	San Francisco	California	3088046918467946884	b483347444d420c0c1c4d1b3fa9bcc4d	Discover	37.7486548671490567	-122.434283643506333
23441	2020-05-06 01:02:12	2020-05-06	Destinee Funk DDS	destinee.funk.dds@woohoo.com	Detroit	Michigan	3731625724391591	1365009c465188570ec0b8a5605657ff	Discover	42.385574551897129	-83.1360893845211706
23442	2020-05-06 01:04:27	2020-05-06	Barton Reilly	barton.reilly@warmmail.com	Lewisville	Texas	3337020789371928023	f163914b78b3106be82b5291eef40d6e	JCB 16 digit	32.9745440328013117	-97.0143980183202785
23443	2020-05-06 01:19:43	2020-05-06	Hermine Robel	hermine.robel@geemail.com	Savannah	Georgia	4348443162194214	44d1f1e01408b2e955ea23701275950b	VISA 16 digit	32.0571419323887667	-81.1675373065438066
23444	2020-05-06 01:19:52	2020-05-06	Ingrid Schamberger	ingrid.schamberger@geemail.com	Nashville	Tennessee	4746691630426430	5a555bdbcc261771e61edc50129244bb	VISA 16 digit	36.1340311015613338	-86.6940062160510507
23445	2020-05-06 01:44:24	2020-05-06	Betha Gorczany	betha.gorczany@geemail.com	Eugene	Oregon	6011931424319737322	41e9ec45f4e1c7a8e1a412c08d08df28	Mastercard	44.0002671736020616	-123.185888593596232
23446	2020-05-06 01:54:16	2020-05-06	Mr. Kenyatta Brown	mr.kenyatta.brown@woohoo.com	Shreveport	Louisiana	210077301773670377	1608ce4d9a4710acc87c94f2f8fb9ad7	American Express	32.472886272869637	-93.7231534914791524
23447	2020-05-06 01:59:06	2020-05-06	Caleb Kutch-Orn	caleb.kutch.orn@warmmail.com	New York	New York	501887277592314	37329d3e523fc3e03b8e2df33410cb15	JCB 16 digit	40.7371781851388519	-73.8891582976456647
23448	2020-05-06 02:21:50	2020-05-06	Zona Schimmel	zona.schimmel@geemail.com	Phoenix	Arizona	3088162022401658677	4a06511a2c31e0d0de227089c88347d5	Voyager	33.5050053507022554	-112.026782289978499
23449	2020-05-06 02:30:52	2020-05-06	Harlow Littel-Bailey	harlow.littel.bailey@warmmail.com	Chicago	Illinois	3408972552933758	eecfa6e021164e7cc0c49fcae9d53e11	American Express	41.8759955245837574	-87.7470119709644365
23450	2020-05-06 02:31:41	2020-05-06	Toriano Prosacco	toriano.prosacco@geemail.com	Austin	Texas	4467030684576	46b5479fe54b0dd35db88834490b9bdf	Maestro	30.2589893478561187	-97.7765694753505272
23451	2020-05-06 02:32:27	2020-05-06	Dr. Saige Ryan DDS	dr.saige.ryan.dds@warmmail.com	West Valley City	Utah	3112019637774874802	85028baf701a9f7a479768b22b028648	Discover	40.6875428885910608	-112.039238296051693
23452	2020-05-06 02:40:03	2020-05-06	Dr. Spurgeon Johns	dr.spurgeon.johns@woohoo.com	West Covina	California	561258386760399	c33cca57186d0daf7ab6e1fd4288f692	VISA 13 digit	34.114251605571809	-117.907268848277255
23453	2020-05-06 02:43:52	2020-05-06	Luka McDermott	luka.mcdermott@geemail.com	Abilene	Texas	4761218806695323	b0ce1d1a6d91d218717933b2583e4e75	JCB 16 digit	32.3984467082265795	-99.833653129073241
23454	2020-05-06 02:49:09	2020-05-06	Mrs. Francies VonRueden DVM	mrs.francies.vonrueden.dvm@geemail.com	Ontario	California	676333609379194	afdea1e66a68347c7634e6e593a4935a	Diners Club / Carte Blanche	34.0060192186996346	-117.632336943792936
23455	2020-05-06 03:03:42	2020-05-06	Joe Hilll	joe.hilll@warmmail.com	Glendale	Arizona	4539050368973	f0240fd6545b649100fb7139e4e267c1	JCB 15 digit	33.5540702324122151	-112.182392801649485
23456	2020-05-06 03:29:55	2020-05-06	Dr. Carlos Abbott III	dr.carlos.abbott.iii@geemail.com	Denton	Texas	3088876603851885105	2454ebd5df8e3b7b070f227e9c45492a	VISA 16 digit	33.2126098579060312	-97.1389055736955243
23457	2020-05-06 03:42:56	2020-05-06	Curtis O'Keefe	curtis.o'keefe@geemail.com	Tucson	Arizona	6011250968922462861	3ea20849929882c11b4d895bc5fe9fe1	Discover	32.0945630426559632	-110.776963632855939
23458	2020-05-06 03:47:52	2020-05-06	Newell Prohaska	newell.prohaska@geemail.com	Virginia Beach	Virginia	676103390608572	6aaed422357ce8e4df414b48aed00d14	VISA 13 digit	36.6840074763819572	-75.9359969642616761
23459	2020-05-06 03:57:35	2020-05-06	Clay Schmeler-Koch	clay.schmeler.koch@geemail.com	Dayton	Ohio	210095737775142394	bb6b90a80a1735e44647a16194990760	Discover	39.7389974513348179	-84.1256468119755425
23460	2020-05-06 03:59:22	2020-05-06	Dr. Chandler Schinner PhD	dr.chandler.schinner.phd@geemail.com	Boise	Idaho	676386707775846	2f070284484c28e9c1940adeeddbe580	JCB 16 digit	43.619445221605524	-116.245861881105981
23461	2020-05-06 04:12:16	2020-05-06	Georgie Cronin	georgie.cronin@warmmail.com	San Francisco	California	3459632317612265	01a753ccff4c9f0760b4135b8aecb53c	JCB 15 digit	37.7481324634671935	-122.457456300003429
23462	2020-05-06 04:15:11	2020-05-06	Ms. Lala Corkery	ms.lala.corkery@geemail.com	Overland Park	Kansas	55209044990297530	47bc6b12836fc43a7f77ab043608ceb4	VISA 13 digit	38.9075769365634798	-94.7210677098989464
23463	2020-05-06 04:32:16	2020-05-06	Tristen Cruickshank	tristen.cruickshank@woohoo.com	New York	New York	4711368513541368	0b2118cef78b0219dc44b4a2215e581b	JCB 16 digit	40.6694735232032798	-73.9113832680869791
23464	2020-05-06 04:47:07	2020-05-06	Cornie Murazik	cornie.murazik@geemail.com	New York	New York	3056499467894711	a7a0b31d7c7d7734f8fb1e1a693b6157	Maestro	40.6080168740581726	-73.9492471932794899
23465	2020-05-06 04:47:50	2020-05-06	Ollie Schuster DDS	ollie.schuster.dds@woohoo.com	Phoenix	Arizona	4182983744892396	0b0b36fdf583e00a7b25e9bc1696cccc	VISA 13 digit	33.5171282998219127	-112.058687353453053
23466	2020-05-06 04:50:46	2020-05-06	Ms. Luna Zboncak MD	ms.luna.zboncak.md@warmmail.com	Virginia Beach	Virginia	4760789386356321	dc5d19600551b2fd1133707be393f4fe	Diners Club / Carte Blanche	36.7990035360865306	-76.0894742214724431
23467	2020-05-06 04:52:34	2020-05-06	Dorcas Conn	dorcas.conn@warmmail.com	New York	New York	3337669884866706897	0374ecaf9e0d7924a378d8388668aba8	Discover	40.6873331712782402	-74.0270073871955248
23468	2020-05-06 04:53:30	2020-05-06	Devan Schmitt	devan.schmitt@geemail.com	Boise	Idaho	54297712795356213	94e550facd3e1638242281dd5726f50e	Maestro	43.6606495817795377	-116.279042704795302
23469	2020-05-06 05:03:18	2020-05-06	Ms. Heather Cremin DVM	ms.heather.cremin.dvm@geemail.com	Chicago	Illinois	6011315438128437318	3bc230092e76ef400d00b8fb328878ac	Maestro	41.8622376692317459	-87.7723694100540115
23470	2020-05-06 05:21:30	2020-05-06	Albert Tremblay II	albert.tremblay.ii@geemail.com	Arlington	Texas	52846482648420212	cba84f32e80f676b85d90406e901afc5	VISA 13 digit	32.6680339980188705	-97.040753725918762
23471	2020-05-06 05:55:41	2020-05-06	Karren Rippin	karren.rippin@geemail.com	Austin	Texas	3423986902731036	708b8fbfe54c2a87e7f8ba7859c8244c	Maestro	30.2437606036789717	-97.842596509052072
23472	2020-05-06 06:08:26	2020-05-06	Dr. Martell Kunde PhD	dr.martell.kunde.phd@geemail.com	Sacramento	California	3337437137956652989	74691ca10f9fa2e96782666ecb30589c	VISA 16 digit	38.4894141025640053	-121.517032585038237
23473	2020-05-06 06:24:43	2020-05-06	Lakeisha White	lakeisha.white@geemail.com	Dallas	Texas	55757725047668303	b11f5fa8681f7df400c9a6c6568c9cea	American Express	32.8675484292015483	-96.7540088208820634
23474	2020-05-06 06:46:31	2020-05-06	Beatrice Sporer-Fahey	beatrice.sporer.fahey@geemail.com	Cape Coral	Florida	3112591732517405539	e482cf0328f53e3504d8767d39f60976	JCB 15 digit	26.6278823893953103	-81.9059822950582941
23475	2020-05-06 07:26:49	2020-05-06	Laron Witting	laron.witting@geemail.com	San Francisco	California	869923536261265488	2142d75e17cb06e04e4ab23fa9020694	JCB 15 digit	37.7690190593031261	-122.441041763601035
23476	2020-05-06 07:33:30	2020-05-06	Elias Gottlieb	elias.gottlieb@geemail.com	San Francisco	California	3088414220116371216	3abef2485cec63300b421e31a46782e4	Voyager	37.7325107768606216	-122.3859036417563
23477	2020-05-06 07:35:13	2020-05-06	Jaret Abernathy	jaret.abernathy@geemail.com	Gresham	Oregon	3740404192658983	d7bdcc2bc7292aeff26a67bef6fb51fe	Diners Club / Carte Blanche	45.5088524792298657	-122.464192077450818
23478	2020-05-06 07:35:55	2020-05-06	Ms. Tracie Crist	ms.tracie.crist@geemail.com	Oakland	California	6011306911221291148	136693ad767947b9983f0c47dd3ae853	Voyager	37.8139441049875771	-122.257898434976482
23479	2020-05-06 07:40:58	2020-05-06	Earnest Hauck	earnest.hauck@geemail.com	New York	New York	3011532090998577	d23794efc571ea3c90c871525f93b7bc	Voyager	40.5984886212963616	-73.9202019325353206
23480	2020-05-06 07:53:08	2020-05-06	Grant Kirlin Jr.	grant.kirlin.jr.@woohoo.com	Omaha	Nebraska	4480067699458	3505c58c8c2f8409d5b141e908a91200	Discover	41.3341446574922671	-96.119337072886907
23481	2020-05-06 08:00:28	2020-05-06	Vernal Hodkiewicz	vernal.hodkiewicz@geemail.com	Fresno	California	6011862985840105810	23a249fda0b9617af5245c774696dd88	Voyager	36.7288104418072834	-119.745354744989058
23482	2020-05-06 08:50:36	2020-05-06	Mila Rice-Walsh	mila.rice.walsh@geemail.com	Corpus Christi	Texas	4584553065422356	6363dad8e6034c8fa49ce832a966bb00	American Express	27.7411425460997982	-97.1039284919217209
23483	2020-05-06 08:56:36	2020-05-06	Annie Torp	annie.torp@warmmail.com	Amarillo	Texas	3528948763443881592	a6af47d90bfdbd14bbd7055ccff5e4af	VISA 13 digit	35.1400044704485666	-101.839105371185397
23484	2020-05-06 08:56:53	2020-05-06	Kallie Lindgren	kallie.lindgren@geemail.com	Waco	Texas	639039231562032	7b577f7392fe469236b12016c7523e15	Discover	31.5949998493514954	-97.1617604751270392
23485	2020-05-06 08:58:53	2020-05-06	Vergil Kreiger	vergil.kreiger@geemail.com	Portland	Oregon	561271186361854	0297e2f2577b7cc7de5260c04ef838c4	JCB 15 digit	45.4398095087967775	-122.584402824146679
23486	2020-05-06 08:59:35	2020-05-06	Ferman Hirthe	ferman.hirthe@geemail.com	Visalia	California	4961095776798	f2e439fc0d9d545fa1b215bde95d9081	American Express	36.2893386870112309	-119.283812653658543
23487	2020-05-06 09:03:59	2020-05-06	Xzavier Marks	xzavier.marks@geemail.com	New York	New York	4364229795047542	f6a28dd6428c677042f305e8aa8ec53e	VISA 13 digit	40.6835931593775726	-73.9033071909461086
23488	2020-05-06 09:05:49	2020-05-06	Dr. Gladstone Stehr	dr.gladstone.stehr@woohoo.com	San Francisco	California	54639976424363869	6348b88ed24569370da39484991c46eb	JCB 15 digit	37.7857385477277248	-122.448503269828109
23489	2020-05-06 09:15:38	2020-05-06	Yee Waters-Kertzmann	yee.waters.kertzmann@geemail.com	Santa Clara	California	3046677729920735	cac2f4c18e760e2c43eba1b6c928b83e	Voyager	37.2954216653298616	-121.914407739601657
23490	2020-05-06 09:19:57	2020-05-06	Treva Mosciski PhD	treva.mosciski.phd@woohoo.com	St. Petersburg	Florida	630436771317934	eddd35db233fa8ed82f26b06de4767d3	Maestro	27.814695681620389	-82.6124042450807963
23491	2020-05-06 09:25:22	2020-05-06	Ms. Carissa Feest DDS	ms.carissa.feest.dds@geemail.com	Pomona	California	4799642386131845	07de12934f19b1b505b112a44d8cd85a	VISA 16 digit	34.1221149748694188	-117.78693053596318
23492	2020-05-06 09:28:59	2020-05-06	Anthony Casper	anthony.casper@geemail.com	Cape Coral	Florida	4549341634466813	a171b939c73d1463ed46cd9fd1cb071a	VISA 16 digit	26.6299538579739625	-82.0092968148250065
23493	2020-05-06 09:34:11	2020-05-06	Mr. Ennis Goldner DVM	mr.ennis.goldner.dvm@geemail.com	Virginia Beach	Virginia	3088623623049201698	f5bcf135442b7cff79746e4f2436384b	VISA 16 digit	36.8698180034477261	-76.0860479794114752
23494	2020-05-06 09:57:28	2020-05-06	Miguel Strosin	miguel.strosin@woohoo.com	San Francisco	California	3002620298071658	db3e236a05eb717f26816fcfba38dcca	VISA 13 digit	37.7933860826515442	-122.399417297822353
23495	2020-05-06 09:58:21	2020-05-06	Dr. Lloyd Dach III	dr.lloyd.dach.iii@geemail.com	Austin	Texas	3528532059157186175	e79790cbf09fffce99ef03769798dece	Maestro	30.3429186313074055	-97.6844311398226779
23496	2020-05-06 10:15:53	2020-05-06	Ferris Macejkovic DVM	ferris.macejkovic.dvm@woohoo.com	Fort Worth	Texas	3112673637585772150	08244f52afa674d2156464e455b6a827	Maestro	32.8764997787363811	-97.4163563103701904
23497	2020-05-06 10:42:29	2020-05-06	Willene Bayer MD	willene.bayer.md@geemail.com	Columbus	Ohio	869995038864280512	26bf297f2733063c070e2935b450fa93	VISA 16 digit	40.0459677344232787	-82.9613300186350955
23498	2020-05-06 10:57:01	2020-05-06	Lissette Grimes	lissette.grimes@geemail.com	Murrieta	California	3112329791101605598	d37561ae1c850d3cf09462bb72367357	American Express	33.5388926622554635	-117.256451388438791
23499	2020-05-06 11:00:41	2020-05-06	Berkley D'Amore	berkley.d'amore@woohoo.com	Houston	Texas	52134883414461077	d3f82fc0b5b0b559a94e31c5cb0a1dca	Diners Club / Carte Blanche	29.7813458215523497	-95.3677174848053681
23500	2020-05-06 11:05:36	2020-05-06	Mara Haag	mara.haag@geemail.com	Berkeley	California	3096423226646729301	441d1987c1f00f7f29a80dc9c24f11f8	Maestro	37.8624805628801937	-122.274200764052623
23501	2020-05-06 11:32:21	2020-05-06	Mrs. Zettie Osinski DDS	mrs.zettie.osinski.dds@geemail.com	Springfield	Illinois	6011960633624782641	8f28c075857f666bf2483a221f6cb2e8	JCB 15 digit	39.7523890772521469	-89.739489755453917
23502	2020-05-06 11:45:13	2020-05-06	Marge Brakus	marge.brakus@woohoo.com	Baltimore	Maryland	3112996139224775694	2a67c275ae535a6cb0b8ad5bae12b8e7	VISA 16 digit	39.3327347866725177	-76.5573680677469781
23503	2020-05-06 11:52:31	2020-05-06	Ms. Kristin Lubowitz DVM	ms.kristin.lubowitz.dvm@geemail.com	Anchorage	Alaska	4039861967606518	949870beeb095734b07ce48924f9081e	Maestro	61.1954414586752691	-149.214879072516425
23504	2020-05-06 11:54:34	2020-05-06	Armida Nolan	armida.nolan@geemail.com	Everett	Washington	4954306661660685	13ea80323ba5ff7d079dd109903bd515	JCB 16 digit	47.8690238670337962	-122.204647696030889
23505	2020-05-06 11:57:00	2020-05-06	Permelia Crooks-Jacobi	permelia.crooks.jacobi@warmmail.com	St. Louis	Missouri	4073270087106	79e82af8cb22f2953147a938b27149e6	VISA 16 digit	38.6073392269823685	-90.2386644477494144
23506	2020-05-06 12:00:06	2020-05-06	Sadye Nicolas	sadye.nicolas@geemail.com	Charlotte	North Carolina	869921783361898691	75ed6152573574db3c985c07a17cf5c1	JCB 16 digit	35.1814314946785558	-80.9128494627252195
23507	2020-05-06 12:07:19	2020-05-06	Mr. Hymen Aufderhar MD	mr.hymen.aufderhar.md@warmmail.com	Raleigh	North Carolina	3045996343674663	e706f0e4c15148472c1ae8c8d27463d7	VISA 16 digit	35.7716407070070446	-78.571658822701508
23508	2020-05-06 12:35:23	2020-05-06	Jadiel Koss-Thompson	jadiel.koss.thompson@warmmail.com	Jacksonville	Florida	6011073442837402995	fd0019210ee57f1780701cedbaa4fd31	Maestro	30.3444227326247855	-81.6462371989697289
23509	2020-05-06 12:41:09	2020-05-06	Codey Bogisich-Ernser	codey.bogisich.ernser@warmmail.com	San Francisco	California	639061467577567	1cf17c610042db22aa7d19a2c8b40ff2	VISA 13 digit	37.7679152874243584	-122.44324133736319
23510	2020-05-06 12:47:56	2020-05-06	Anna Pollich-Bauch	anna.pollich.bauch@geemail.com	New York	New York	501876330504085	d92df6e1c00fe5ee1c2618d4225382a5	VISA 16 digit	40.7490063740629722	-73.9139622721251044
23511	2020-05-06 12:48:35	2020-05-06	Isidro Aufderhar Sr.	isidro.aufderhar.sr.@geemail.com	Los Angeles	California	180097152206023429	76650a90cbf0c9eae04e51f826e10426	Discover	33.9976148912548979	-118.477789863337946
23512	2020-05-06 12:56:09	2020-05-06	Margarito Nolan	margarito.nolan@geemail.com	Hampton	Virginia	3459587516327554	d865f3c02c04301513ae9f4ccb1bab9c	JCB 15 digit	37.0364908064734237	-76.2271776000134622
23513	2020-05-06 13:04:30	2020-05-06	Mylee Roberts	mylee.roberts@woohoo.com	Austin	Texas	4650903256244433	83559f6b4899bc5affbe6c7e6b1ec952	Maestro	30.2335742605045432	-97.7043095847364498
23514	2020-05-06 13:05:02	2020-05-06	Clide Hoppe-McCullough	clide.hoppe.mccullough@woohoo.com	Bridgeport	Connecticut	675954184707708	9130a7afaba6e60a887b5b06fa9c7196	Voyager	41.1413915378671078	-73.2793019906517173
23515	2020-05-06 13:11:19	2020-05-06	Mr. Burr Streich Jr.	mr.burr.streich.jr.@geemail.com	Denver	Colorado	4229936474506912	cc59832e67c6aa79301e840f8191cb9e	Discover	39.6620494444906697	-104.799171832461283
23516	2020-05-06 13:21:11	2020-05-06	Corda Osinski-Zboncak	corda.osinski.zboncak@geemail.com	San Francisco	California	180054398960922857	fbfbdd678d12ccc9b7c7e20a9b639aca	JCB 16 digit	37.783348538537652	-122.443474309738932
23517	2020-05-06 13:21:23	2020-05-06	Juluis Corkery	juluis.corkery@geemail.com	Los Angeles	California	54151688350444914	6926672e47190b8c13c399acc0d5d24f	Mastercard	34.076905131233481	-118.406087284720684
23518	2020-05-06 13:22:37	2020-05-06	Rodney Roberts	rodney.roberts@geemail.com	Durham	North Carolina	3337228223537953428	03ee3ede83bb6eb59aec159560604ebb	Maestro	35.9269354604430475	-78.8852494160547906
23519	2020-05-06 13:24:58	2020-05-06	Mrs. Marquita Fay	mrs.marquita.fay@geemail.com	Raleigh	North Carolina	4796202893772012	9456658057c150c89b4c6b335b5ef353	JCB 16 digit	35.9109075157571525	-78.5941988238535885
23520	2020-05-06 13:31:36	2020-05-06	Judith Swift	judith.swift@geemail.com	Salem	Oregon	869997902784339914	0dc7f75292bcd954560c7303fcf4721d	Voyager	44.9475701282534743	-122.944425377731022
23521	2020-05-06 13:35:14	2020-05-06	Lisandro Schaden	lisandro.schaden@warmmail.com	Berkeley	California	3158884085268257518	76b7c050fffe9ac5be331aa42af6137c	JCB 16 digit	37.8653544320418121	-122.250440154560764
23522	2020-05-06 13:48:21	2020-05-06	Myla Mayer	myla.mayer@warmmail.com	Pompano Beach	Florida	3435872596616442	3d8e48a22ff5cb25364f7cd7f3b55c19	JCB 16 digit	26.2286425576344122	-80.1259338833704504
23523	2020-05-06 13:49:33	2020-05-06	Amy Cummerata-Parker	amy.cummerata.parker@warmmail.com	Berkeley	California	4786128863473	f510ed53250d3859109e8beefb464093	Voyager	37.8533096796652231	-122.282634034425087
23524	2020-05-06 14:09:18	2020-05-06	Dana Lemke	dana.lemke@geemail.com	Miami	Florida	51426755916314185	d1eb6114466c81d31a281ab275a7ffe3	Discover	25.8426947082065048	-80.1704632778525337
23525	2020-05-06 14:24:25	2020-05-06	Evita Champlin	evita.champlin@woohoo.com	Bakersfield	California	4665512290842	ff6c6c589dc7386eb3e7518f207ef23f	JCB 16 digit	35.3471244011715058	-118.981083277733248
23526	2020-05-06 14:32:42	2020-05-06	Dr. Jaimie Batz V	dr.jaimie.batz.v@geemail.com	Austin	Texas	3725546387703831	55490a707b8adcd0d74d63a98ba10698	JCB 16 digit	30.2491551592607024	-97.6869833817478366
23527	2020-05-06 14:36:56	2020-05-06	Dr. Rihanna Kshlerin	dr.rihanna.kshlerin@geemail.com	Columbus	Ohio	4900193104000926	30c8f846f6a017f65d3166b7b9d7b3a7	VISA 13 digit	40.0005461042325905	-83.0314379522811663
23528	2020-05-06 14:38:27	2020-05-06	Stefani Rath	stefani.rath@geemail.com	San Francisco	California	3429708535987866	1733d9c54a44ebf7f8bfbd0386ab580d	VISA 16 digit	37.7545658380427653	-122.417470649673049
23529	2020-05-06 15:08:08	2020-05-06	Charlene Schimmel	charlene.schimmel@woohoo.com	Renton	Washington	4429229008660787	88a2c329ae760b967430759c197d2271	Mastercard	47.4985459542892912	-122.168018810970707
23530	2020-05-06 15:10:18	2020-05-06	Dr. Luciano Koss	dr.luciano.koss@geemail.com	Waco	Texas	4753776830739623	ec124b411bf077fee98e398bd1f33429	Voyager	31.6039707239925853	-97.2169214922599565
23531	2020-05-06 15:11:49	2020-05-06	Alexandr Jacobs	alexandr.jacobs@geemail.com	San Francisco	California	869929810864720890	e1cb56c2d92aa588cad24c0d31d23274	American Express	37.772759023042866	-122.428407946744784
23532	2020-05-06 15:16:23	2020-05-06	Dr. Dale Koelpin II	dr.dale.koelpin.ii@warmmail.com	San Francisco	California	3088470794022933625	a6222e3db00eb7cdda8a1b6a79d568ab	Diners Club / Carte Blanche	37.7967304140813809	-122.422954370773823
23533	2020-05-06 15:27:47	2020-05-06	Marguerite Hand	marguerite.hand@geemail.com	Detroit	Michigan	639033315090390	a57b132dd625310d03e948d7d3dedadf	JCB 15 digit	42.3073148787878495	-83.040968153404819
23534	2020-05-06 16:02:03	2020-05-06	Ms. Jayda Stanton	ms.jayda.stanton@woohoo.com	Spokane	Washington	4139218986624	fd1369613f38c5ce561e5d66a2f9cb25	VISA 16 digit	47.7658146960899188	-117.4090048746571
23535	2020-05-06 16:02:30	2020-05-06	Dr. Almon Swaniawski Sr.	dr.almon.swaniawski.sr.@woohoo.com	Topeka	Kansas	4308644212092443	a9f5e3dcd9e47276eddc5fbb57943471	Mastercard	39.123793559887261	-95.60550313030258
23536	2020-05-06 16:15:36	2020-05-06	Ms. Hallie Parisian	ms.hallie.parisian@geemail.com	San Antonio	Texas	4929390084821290	6ad01b089ddc4b2e6418ab96f8d15941	American Express	29.4799081422459324	-98.597748703539736
23537	2020-05-06 16:25:37	2020-05-06	King Kovacek	king.kovacek@geemail.com	New Orleans	Louisiana	3004115878492828	bbb27e759ffa3cdd7c52d2b3a130c26f	American Express	29.9782993289656936	-90.0278875697199226
23538	2020-05-06 16:35:19	2020-05-06	Pat Grimes	pat.grimes@geemail.com	Memphis	Tennessee	060470225606527	4e8b5c9585939cc5f6b030cecbe56796	Mastercard	35.1567537095464786	-89.878600876571241
23539	2020-05-06 16:36:16	2020-05-06	Melva Goodwin DDS	melva.goodwin.dds@warmmail.com	New York	New York	6011840890582882443	59fb3b7212e4bb95bd07cd6a7d372688	JCB 16 digit	40.6356239762846343	-74.0353315684374422
23540	2020-05-06 16:43:19	2020-05-06	Sharleen Kihn	sharleen.kihn@warmmail.com	Henderson	Nevada	6011784383026651267	6b8178ed36609eff222334a7a9af8c4e	Mastercard	36.0599724595833564	-115.104956695639345
23541	2020-05-06 17:15:48	2020-05-06	Alessandra Kling-Cummerata	alessandra.kling.cummerata@woohoo.com	San Jose	California	3017320823278895	bceb3bbfdeafb90505a3fc84a1669d24	Diners Club / Carte Blanche	37.2084732475511757	-121.836650588664781
23542	2020-05-06 17:19:25	2020-05-06	Jory Kirlin	jory.kirlin@geemail.com	Dallas	Texas	3112934814840676261	39cbab1f5d37511d07af0d32ed004696	Mastercard	32.8028671898685431	-96.8570370231252156
23543	2020-05-06 17:34:51	2020-05-06	Quiana Pfannerstill	quiana.pfannerstill@geemail.com	Chula Vista	California	3096144122228580253	0c595426686fda20cdfdc96ff5fba0b1	VISA 13 digit	32.5473336728520692	-117.07438447328731
23544	2020-05-06 17:45:25	2020-05-06	Theodora Schoen	theodora.schoen@geemail.com	Irvine	California	4915710943993	033242378f01c8a4a7ecf02cdd4e6c3d	VISA 16 digit	33.6774814239252365	-117.746453038371357
23545	2020-05-06 17:49:03	2020-05-06	Jerica Runolfsson	jerica.runolfsson@geemail.com	New Orleans	Louisiana	3435541488273832	fa32902ba13e117c89281943b83792f7	JCB 16 digit	29.9567600477967417	-89.9418677004315015
23546	2020-05-06 17:56:00	2020-05-06	Joselin Pollich	joselin.pollich@warmmail.com	Grand Rapids	Michigan	869935880712480593	53dcdb95d29f0dd4958a6f8ad11d9083	JCB 16 digit	43.0060243212420446	-85.5652088742371717
23547	2020-05-06 18:14:44	2020-05-06	Yahir Nicolas	yahir.nicolas@geemail.com	Lexington	Kentucky	4913095134222468	a1a4f4b192bb11a30353c8f815d811b8	JCB 16 digit	38.0590038725052011	-84.3978906722638698
23548	2020-05-06 18:15:34	2020-05-06	Blake Renner-Veum	blake.renner.veum@geemail.com	Las Vegas	Nevada	3057853295168236	8fdf20c49fc10565ea9e8b3b9fdfcd7b	VISA 13 digit	36.2926359394200162	-115.203170935271672
23549	2020-05-06 18:23:24	2020-05-06	Reinhold Legros-Gusikowski	reinhold.legros.gusikowski@geemail.com	Greensboro	North Carolina	3088976462191738808	8afc63de062c32accb2a0537d5f9b8ac	Discover	36.1709680507540696	-79.775064587498079
23550	2020-05-06 18:35:42	2020-05-06	Thad Kuphal V	thad.kuphal.v@geemail.com	Lowell	Massachusetts	630430063321605	5cbf9ceb7a9737bc5f63ec875d6dd44f	JCB 16 digit	42.6574356913901909	-71.2829025760166388
23551	2020-05-06 18:58:31	2020-05-06	Ken Emard	ken.emard@warmmail.com	Buffalo	New York	3088574148172819412	29a56ee32206766996a7f9e19d822d47	Discover	42.83182642173022	-78.9515260218109916
23552	2020-05-06 19:15:28	2020-05-06	Bettyjane Pollich	bettyjane.pollich@geemail.com	New York	New York	3158695037993052382	372aaac81980408bdeb1913cc59a996c	VISA 13 digit	40.7142074997294685	-73.9923477952264221
23553	2020-05-06 19:16:21	2020-05-06	Buren Runte	buren.runte@geemail.com	Montgomery	Alabama	4131285852118495	5bcad8777f71ca2085cb51c41e464f31	VISA 16 digit	32.3964643980309361	-86.1738426903881134
23554	2020-05-06 19:16:48	2020-05-06	Brittny Hickle	brittny.hickle@warmmail.com	Chicago	Illinois	589345329106723	1716a331b885e2b037f04871939a4b12	Diners Club / Carte Blanche	41.9099751616198617	-87.6579152645573032
23555	2020-05-06 19:17:32	2020-05-06	Madge Zboncak PhD	madge.zboncak.phd@geemail.com	San Francisco	California	060420004800551	78cfe32ba901bd5c078f396a54b1e90b	Mastercard	37.7698706961494324	-122.450403776367324
23556	2020-05-06 19:22:18	2020-05-06	Sharyn Dach	sharyn.dach@geemail.com	Hollywood	Florida	3096973695266238880	30f7add5ad5fe40b4eb4c7745761f11b	VISA 16 digit	26.0940182009190309	-80.1785001416973699
23557	2020-05-06 19:26:13	2020-05-06	Winston Feest	winston.feest@geemail.com	Minneapolis	Minnesota	4034330011494086	aa2bd6a712df6afba0e97e28d6dfe602	JCB 16 digit	44.9137663371015279	-93.2646730889838125
23558	2020-05-06 20:05:02	2020-05-06	Randell Boyer	randell.boyer@geemail.com	San Diego	California	3027953475452895	6428fd80e8bd38c66c828b41bb088ff9	Voyager	32.739516254753994	-117.107216408699756
23559	2020-05-06 20:09:42	2020-05-06	Olen Hettinger	olen.hettinger@geemail.com	New York	New York	4731348704636	7bece5c1d651dc52ecaf7c7eaa6606d9	JCB 16 digit	40.6699400752074993	-73.9974801587302267
23560	2020-05-06 20:16:02	2020-05-06	Arnold Zieme	arnold.zieme@woohoo.com	Stockton	California	4573305079648	882d56999da13ad4be1584e5d8a82f11	VISA 16 digit	38.0104444297228028	-121.373480172370748
23561	2020-05-06 20:25:10	2020-05-06	Jeptha Wilderman DDS	jeptha.wilderman.dds@warmmail.com	San Francisco	California	3004696328205803	ddb687af058e076fb2a9c3e53a6ed0ef	VISA 13 digit	37.7627429678784878	-122.420292383614779
23562	2020-05-06 20:26:37	2020-05-06	Hardie Hessel	hardie.hessel@geemail.com	Chattanooga	Tennessee	869990194533846533	13c4ba6f16dd7377192b852fff5e01ae	Discover	35.1224130017999556	-85.1841240244746274
23563	2020-05-06 20:34:18	2020-05-06	Demetrius Frami-Pfannerstill	demetrius.frami.pfannerstill@geemail.com	Providence	Rhode Island	3009145096853621	676f3fea7d5ae211384603c507c7881b	JCB 15 digit	41.8631281045585837	-71.3431056424427794
23564	2020-05-06 20:36:05	2020-05-06	Ms. Teresa Hagenes	ms.teresa.hagenes@warmmail.com	San Francisco	California	6011938168796946103	f9f933ff3c93b18174310a9daaf12c7d	Maestro	37.7779110907790354	-122.454259530820522
23565	2020-05-06 20:36:30	2020-05-06	Dr. Arthur Gaylord PhD	dr.arthur.gaylord.phd@geemail.com	San Francisco	California	3158776139330085331	7dd040e4881949fc5e7af6fbaa12b5cc	Mastercard	37.7965116362285514	-122.426088309748536
23566	2020-05-06 20:46:58	2020-05-06	Chasity Torp	chasity.torp@geemail.com	Wichita	Kansas	210045824112303060	bab9bbbb9cda2fce1de842fc04818597	JCB 15 digit	37.6461009378887681	-97.3731752177901626
23567	2020-05-06 20:50:39	2020-05-06	Fielding Bins	fielding.bins@geemail.com	San Francisco	California	4875330038432020	a0009ad448f805b56e0f977d80f8be5a	Mastercard	37.7506887108135487	-122.399236310401832
23568	2020-05-06 20:56:33	2020-05-06	Kailyn Friesen	kailyn.friesen@geemail.com	Murfreesboro	Tennessee	3011649084948069	02c5d0d709630bfc845de79801097c0f	VISA 13 digit	35.8187307629387846	-86.3575222611278264
23569	2020-05-06 21:06:44	2020-05-06	Adelina Kunze	adelina.kunze@warmmail.com	Rochester	Minnesota	3459488239033605	e4b7cc8a7e2056365fc92d41e95f5de3	Voyager	44.0412648165501679	-92.4900026238642567
23570	2020-05-06 21:24:01	2020-05-06	Colon Durgan	colon.durgan@warmmail.com	Independence	Missouri	639095606062370	772ccd5b1a13d529652dc9803bd15836	American Express	39.1254777422193456	-94.2730593632258405
23571	2020-05-06 21:24:13	2020-05-06	Mr. Davion Jones	mr.davion.jones@geemail.com	Berkeley	California	3112950528259421337	289647dfad0fdba178eaaa5f79bc303a	JCB 16 digit	37.865842135277731	-122.278265923673686
23572	2020-05-06 21:24:54	2020-05-06	Leala Farrell	leala.farrell@geemail.com	Rockford	Illinois	3044361597081712	183c50b9fdb42957f6aac792e39f3019	JCB 15 digit	42.2503493691340068	-89.1367826765220599
23573	2020-05-06 21:33:57	2020-05-06	Burl Runolfsdottir	burl.runolfsdottir@geemail.com	Roseville	California	869947812248817903	57e0fe7a361332cacd8249ad6977b99b	Discover	38.7975072319209531	-121.251995577964564
23574	2020-05-06 21:34:54	2020-05-06	Elenore Koepp	elenore.koepp@geemail.com	Winston–Salem	North Carolina	6011884135301071044	ade8c18a5c04ff705d6ec9f93bcb6d92	VISA 16 digit	36.1933668222043678	-80.1886520228013353
23575	2020-05-06 21:53:54	2020-05-06	Devonta Hayes	devonta.hayes@geemail.com	Los Angeles	California	3112340614974223346	5600c00ccf0978008b1a227747b9de61	VISA 16 digit	34.0532313642423574	-118.501521755288536
23576	2020-05-06 22:11:28	2020-05-06	Dr. Karren Metz	dr.karren.metz@geemail.com	Amarillo	Texas	52659602611687101	889a34433b6bf9537da1923099b80234	Voyager	35.1375789402216654	-101.79366156843939
23577	2020-05-06 22:12:09	2020-05-06	Dr. Orvis Murray Sr.	dr.orvis.murray.sr.@warmmail.com	Stockton	California	4487645781402684	86ab3fb340d5a41a3675ddc2a2cef4b0	VISA 16 digit	38.0467162685666267	-121.278463224004213
23578	2020-05-06 22:21:41	2020-05-06	Agustus Kemmer	agustus.kemmer@warmmail.com	Oakland	California	4908033336375	31398c353307e4de80125437313d2970	VISA 13 digit	37.8344188997116504	-122.282362978651051
23579	2020-05-06 22:27:18	2020-05-06	Dorian Renner	dorian.renner@geemail.com	Ontario	California	4040041257243	42a4e44ec3b72aec31d5474a3686e8ce	Maestro	34.0727185751456787	-117.63408401115872
23580	2020-05-06 22:36:14	2020-05-06	Kasandra Jakubowski-Mraz	kasandra.jakubowski.mraz@geemail.com	Fort Worth	Texas	4112244598747	b3d058459b9afa7dd7b3b8af582ba9d4	JCB 16 digit	32.8560805538259473	-97.4096577557090626
23581	2020-05-06 22:51:19	2020-05-06	Waverly Cummings	waverly.cummings@woohoo.com	San Francisco	California	6011651476038678870	df8b3335101641cccb5650367954d151	Diners Club / Carte Blanche	37.7635725699012923	-122.460227531694642
23582	2020-05-06 22:56:21	2020-05-06	Shane Tromp-Schuster	shane.tromp.schuster@geemail.com	San Francisco	California	55010097788922080	bd12686ec968f4970dbeeac419b3850e	Discover	37.7902548106852336	-122.408804672324308
23583	2020-05-06 23:11:37	2020-05-06	Ms. Magdalena Zemlak	ms.magdalena.zemlak@woohoo.com	Los Angeles	California	869954094178505036	d34f627b5b3e77422237887d6f7b9fc4	Voyager	33.9331138354126338	-118.468728540930144
23584	2020-05-06 23:26:42	2020-05-06	Dr. Zenas Koss	dr.zenas.koss@geemail.com	New York	New York	4633372387691106	e2be0cc51dcd2f3f25ea570a09969cb5	Discover	40.6857152092959709	-73.9114656939066919
23585	2020-05-06 23:34:50	2020-05-06	Erline Schultz	erline.schultz@geemail.com	San Francisco	California	3023264197454159	a904e16a4f2749bc61dba48150cbb8c6	American Express	37.7802873589687849	-122.436561988405202
23586	2020-05-06 23:38:29	2020-05-06	Mr. Alford Schaefer	mr.alford.schaefer@geemail.com	Overland Park	Kansas	53116032223716238	b244847be225f3fd16b8a49487ee307f	Voyager	38.8482674125451624	-94.7151005062315647
23587	2020-05-07 00:33:06	2020-05-07	Stefan Padberg-Spinka	stefan.padberg.spinka@geemail.com	Stockton	California	4889528899695312	1d1e3060271aa42539354368a0a032c9	Maestro	38.0068154148954918	-121.374602463104949
23588	2020-05-07 00:46:21	2020-05-07	Lucretia Ratke-Marks	lucretia.ratke.marks@warmmail.com	San Francisco	California	3088854206877881177	be9805c01ff5cbed302cb99867141fdb	JCB 16 digit	37.7742049920738907	-122.417547554501155
23589	2020-05-07 00:46:24	2020-05-07	Broderick Tillman	broderick.tillman@geemail.com	San Francisco	California	6011948500164714127	352a5bdd432816297feb946c8e44e81a	VISA 16 digit	37.7666695683654652	-122.405074374303453
23590	2020-05-07 00:56:21	2020-05-07	Edrie Boehm	edrie.boehm@geemail.com	Rancho Cucamonga	California	3778917467030252	95b365ceb5741f3a3ffd35da808c4e00	JCB 16 digit	34.0880990710102054	-117.617787399143722
23591	2020-05-07 01:03:35	2020-05-07	Sarina Roberts	sarina.roberts@geemail.com	Philadelphia	Pennsylvania	676327692320461	77a8075fdb96246913bce319318f9a88	Maestro	39.9827945609536002	-75.1650580701783326
23592	2020-05-07 01:06:16	2020-05-07	Mychal Champlin	mychal.champlin@warmmail.com	San Francisco	California	3047771928363414	98fd6fd62349e625245a3d6a37af8483	VISA 13 digit	37.7286394752074301	-122.414771617581636
23593	2020-05-07 01:12:08	2020-05-07	Maryam Rau-Turner	maryam.rau.turner@geemail.com	Joliet	Illinois	54316601878747009	bfd47685eae1ae5f6c4bfb79b0d6a9d7	VISA 16 digit	41.4409288197148555	-88.1295214123196899
23594	2020-05-07 01:15:17	2020-05-07	Lawanda Schaden	lawanda.schaden@geemail.com	Corona	California	4681834672351549	29470d1d5f5f3546c4f5c614dd23e3c6	JCB 16 digit	33.9329546856116551	-117.593642246557394
23595	2020-05-07 02:07:38	2020-05-07	Marion Pfannerstill	marion.pfannerstill@warmmail.com	Woodbridge	New Jersey	4242259570768	1fc55ab9be1f930baca1fa4a2e0e690d	VISA 13 digit	40.5654105176374316	-74.3092193529799516
23596	2020-05-07 02:31:34	2020-05-07	Raphael Kovacek	raphael.kovacek@geemail.com	Jersey City	New Jersey	53324192616263079	837dedc31db6c465d9e6afb51421b0dc	Voyager	40.7543892923682876	-73.9918003883633872
23597	2020-05-07 02:32:30	2020-05-07	Harlan Heaney	harlan.heaney@warmmail.com	El Paso	Texas	210038765275007239	7bb69ebc7b52ffe775d28eedefce71a0	Diners Club / Carte Blanche	31.7973671948831544	-106.507125945946214
23598	2020-05-07 02:50:29	2020-05-07	Rome Waters	rome.waters@woohoo.com	Los Angeles	California	4759133433525	f27117d3ea64632c3a675ad648e6d23a	JCB 16 digit	33.9441789348941256	-118.487914977873857
23599	2020-05-07 02:52:37	2020-05-07	Yadira O'Conner	yadira.o'conner@geemail.com	Allen	Texas	3337088245082802964	a943933c4d5e8ea11e4275762e237daf	Discover	33.1555715730439857	-96.591234034667167
23600	2020-05-07 02:57:22	2020-05-07	Maximilian Kemmer	maximilian.kemmer@geemail.com	Lubbock	Texas	3034180459947673	78e12eb64d77dedc527b24556dc7151b	JCB 16 digit	33.4795701254665872	-101.877785318662234
23601	2020-05-07 03:11:31	2020-05-07	Dr. Orval Littel III	dr.orval.littel.iii@geemail.com	Memphis	Tennessee	869976054603409026	c2d4762fe4189976acb5432629f4b79c	American Express	35.1810075311057275	-90.0665496601048829
23602	2020-05-07 03:15:45	2020-05-07	Mr. Lon Wisozk	mr.lon.wisozk@geemail.com	San Francisco	California	4915302937784704	640fa1c16b77b7cc6b6d0627d6838c66	Maestro	37.7651582162507182	-122.44765834769332
23603	2020-05-07 03:34:05	2020-05-07	Itzel Bradtke	itzel.bradtke@geemail.com	Jersey City	New Jersey	869951508886424936	3987d8c3494fc2907939a3efeb024665	JCB 16 digit	40.6365233822666099	-74.0230132250536315
23604	2020-05-07 03:44:46	2020-05-07	Mrs. Jocelyn Pagac MD	mrs.jocelyn.pagac.md@geemail.com	Garland	Texas	180076027532100619	a960f2099a26d17558ed53c15978e472	Mastercard	32.9792457885343566	-96.6716904401008037
23605	2020-05-07 03:47:58	2020-05-07	Luverne Legros	luverne.legros@warmmail.com	San Diego	California	3112387589766679489	500902149a2694b10e490cbf9e10554a	JCB 16 digit	32.7702274843186174	-117.135166475679725
23606	2020-05-07 04:01:12	2020-05-07	Mr. Dijon Yundt I	mr.dijon.yundt.i@geemail.com	New York	New York	869914032499402433	11808d26fcbbfd71537e7cb1462be9df	Diners Club / Carte Blanche	40.6280291270688139	-74.0249989110872093
23607	2020-05-07 04:02:15	2020-05-07	Jarad Witting	jarad.witting@geemail.com	San Francisco	California	869946000119467955	7dc1e3eb030d18669f63af9d798ffb6d	Diners Club / Carte Blanche	37.7705234865504806	-122.405098638383365
23608	2020-05-07 04:07:49	2020-05-07	Dr. Nelly O'Keefe DVM	dr.nelly.o'keefe.dvm@geemail.com	San Francisco	California	869999717963013926	a9f9e9a48e5c13d400aaa4ba6b49ccff	VISA 16 digit	37.792978788074393	-122.469900314394053
23609	2020-05-07 04:12:10	2020-05-07	Ashli Will	ashli.will@warmmail.com	El Paso	Texas	3421944671917833	36ccc1776b770a2391c40a03f911d619	Diners Club / Carte Blanche	31.7840497271452129	-106.487644527338446
23610	2020-05-07 04:16:32	2020-05-07	Mark Kunde	mark.kunde@geemail.com	Dallas	Texas	6011602247959031856	fc88793b7f2127a4051912b550c73eaa	JCB 16 digit	32.8329317909006022	-96.8433645926378546
23611	2020-05-07 04:22:36	2020-05-07	Fed Strosin	fed.strosin@geemail.com	Thousand Oaks	California	4348541908680	d3a25ae81ed40423e112d04074e19adb	JCB 15 digit	34.1215176020555191	-118.889741874989866
23612	2020-05-07 04:33:23	2020-05-07	Mr. Clide Auer I	mr.clide.auer.i@geemail.com	Raleigh	North Carolina	675962547338921	ffcaf037cca00457ac6f6904ab7fe6d6	VISA 13 digit	35.8020620050974188	-78.6706492804858897
23613	2020-05-07 04:39:02	2020-05-07	Meggan Gutkowski	meggan.gutkowski@woohoo.com	St. Petersburg	Florida	869921417367264539	fbe3fc940039536330a415dc4c838d4c	VISA 16 digit	27.7322989595942211	-82.6933037792690016
23614	2020-05-07 04:41:05	2020-05-07	Zane Koelpin DDS	zane.koelpin.dds@warmmail.com	Columbus	Ohio	4472294655973	7f142e68b39aa06d27237682e34371fb	VISA 16 digit	40.0611377767797521	-82.9187164135512091
23615	2020-05-07 04:41:44	2020-05-07	Virgil Harber	virgil.harber@geemail.com	Greensboro	North Carolina	869985255403111360	eadd9f51a8f16a88c009261850904dbe	VISA 13 digit	36.1115837042801076	-79.7866033405512525
23616	2020-05-07 04:50:54	2020-05-07	Elex Turcotte-Sipes	elex.turcotte.sipes@geemail.com	Houston	Texas	869901943732045216	0ef9e262e6d165f17bc6fffdf0bceacb	Diners Club / Carte Blanche	29.8454963201735168	-95.3788650555551101
23617	2020-05-07 04:52:28	2020-05-07	Rocco Maggio	rocco.maggio@geemail.com	Los Angeles	California	561278277119141	50faed36b476aee99d99f1a7e48c113f	Maestro	33.9581816363945563	-118.37779952953494
23618	2020-05-07 04:53:32	2020-05-07	Nile Hamill	nile.hamill@geemail.com	Buffalo	New York	676345286994954	7ea8378f618816c2b8ebb968e712ece2	Voyager	42.9398183281253978	-78.7992406835712558
23619	2020-05-07 04:58:15	2020-05-07	Boone Greenholt	boone.greenholt@woohoo.com	Rockford	Illinois	210065992672510385	b87233e4966809d72fa4628b441627e3	Mastercard	42.2195719469815529	-89.0797404628995793
23620	2020-05-07 05:00:13	2020-05-07	Krystina Lubowitz	krystina.lubowitz@geemail.com	Scottsdale	Arizona	4921100493578995	66164362dd4c1580af46979787e69674	Discover	33.6504649131216098	-111.829037968438485
23621	2020-05-07 05:04:45	2020-05-07	Andre Nader	andre.nader@woohoo.com	San Francisco	California	869975260620502823	0200ff9ca8409938e6d65843284bccb5	JCB 15 digit	37.765211853298041	-122.473879300854364
23622	2020-05-07 05:25:06	2020-05-07	Capitola Boehm	capitola.boehm@geemail.com	San Francisco	California	4379074016915389	51eb45bc5ffb0d8ca305763685ae6f38	VISA 16 digit	37.7736139667311051	-122.463427293647513
23623	2020-05-07 05:27:41	2020-05-07	Roderick Schamberger	roderick.schamberger@warmmail.com	Houston	Texas	869930728363340977	797fb30b22ea0a19e257ce585a0d16c9	VISA 13 digit	29.8335209882430732	-95.4823839769713629
23624	2020-05-07 05:31:38	2020-05-07	Devaughn Ferry	devaughn.ferry@woohoo.com	New York	New York	51274514988406426	ae3645678579ad619c238ce9b6502253	Discover	40.5797853692658208	-73.8691855637717936
23625	2020-05-07 05:43:59	2020-05-07	Dr. Rowland Howell MD	dr.rowland.howell.md@woohoo.com	Chicago	Illinois	52608099824418592	e743838af0d9460cd59b9a5dc86b4492	Mastercard	41.7661297253169153	-87.6794063891779558
23626	2020-05-07 05:57:20	2020-05-07	Garland Waters	garland.waters@geemail.com	Akron	Ohio	869907713663115682	44c5f274da220e53f7a702f8127e2b76	JCB 16 digit	41.1255913500040791	-81.5440927399169624
23627	2020-05-07 06:01:03	2020-05-07	Kacie Ziemann	kacie.ziemann@geemail.com	Philadelphia	Pennsylvania	52657414294538706	2fd048c63e2fdbae34921b8d53d779aa	American Express	39.924146808959172	-75.1316786576893207
23628	2020-05-07 06:02:20	2020-05-07	Mrs. Grecia Bergnaum	mrs.grecia.bergnaum@warmmail.com	San Francisco	California	4968478019349248	d8ee04b6ae7b1fc532279e80cc708f24	Discover	37.7993548950909783	-122.410763723481637
23629	2020-05-07 06:14:54	2020-05-07	Joanie Zulauf	joanie.zulauf@geemail.com	Waco	Texas	52491539363080857	39e2073e95f8a8c3a9fe10c6a0c300ee	Voyager	31.5345135104585417	-97.170133841376753
23630	2020-05-07 06:38:03	2020-05-07	Mr. Pratt Baumbach	mr.pratt.baumbach@geemail.com	Victorville	California	4596173919371	1279cb4bad04320c729d52ed2c0137dd	VISA 13 digit	34.6131328996036203	-117.433267836753657
23631	2020-05-07 06:39:16	2020-05-07	Maribeth Grant-Howell	maribeth.grant.howell@geemail.com	Dallas	Texas	3024333341003185	90dd661c5a91d4df9854959851cdcbe1	Maestro	32.8473989731904155	-96.8305890861395682
23632	2020-05-07 06:43:06	2020-05-07	Dr. Foster Prohaska	dr.foster.prohaska@geemail.com	Port St. Lucie	Florida	3726513291407981	2e7cf931ff6c2dd5d0db1c43484c6f50	Mastercard	27.3554655048199002	-80.4744255609896015
23633	2020-05-07 06:50:52	2020-05-07	Dr. Leandro Romaguera	dr.leandro.romaguera@geemail.com	Houston	Texas	210065620221360818	8131b639d125dfd4870c225ebaf38d66	American Express	29.8393508109342314	-95.4013420770425427
23634	2020-05-07 06:54:03	2020-05-07	Kermit Moore-Beier	kermit.moore.beier@geemail.com	San Francisco	California	3528913803305845276	9b2251b952c1f24d76510ab715408c19	JCB 15 digit	37.7702013485406809	-122.438492005911982
23635	2020-05-07 06:56:24	2020-05-07	Dr. Gwyn Turner	dr.gwyn.turner@warmmail.com	St. Petersburg	Florida	869967247439655629	99902c5d7904e18fd640d3b933568f5d	JCB 16 digit	27.7845696054752906	-82.6967571534573977
23636	2020-05-07 07:07:00	2020-05-07	Hattie Wilderman	hattie.wilderman@geemail.com	Jacksonville	Florida	3158085866145481422	3b4344bd470085f10dfe827b6d106920	VISA 16 digit	30.3970140207611017	-81.641222187279169
23637	2020-05-07 07:11:21	2020-05-07	Deondre Gerhold-Mann	deondre.gerhold.mann@warmmail.com	New York	New York	561201929410254	489520a53308b31267a3dee53d9c8b78	Mastercard	40.6099780660346141	-73.9362224387831901
23638	2020-05-07 07:20:12	2020-05-07	Sergio Armstrong IV	sergio.armstrong.iv@geemail.com	New York	New York	3088699843966819475	ff8aa5bc9a48d2e25050684249982a2e	JCB 15 digit	40.6535736294221124	-73.9347799812339161
23639	2020-05-07 07:35:47	2020-05-07	Dakota Marquardt-McCullough	dakota.marquardt.mccullough@geemail.com	Detroit	Michigan	180090052470886047	fd0a3d883121d1d28731bbfc0f68cb5b	VISA 16 digit	42.2988148538786959	-83.0982500743240138
23640	2020-05-07 07:36:02	2020-05-07	Bethel Strosin	bethel.strosin@woohoo.com	Macon	Georgia	4306513276210104	78d8db94ad3dd59487c92a803ceb0272	JCB 16 digit	32.7869747587025131	-83.64826712330877
23641	2020-05-07 07:40:03	2020-05-07	Darlene Williamson	darlene.williamson@warmmail.com	Nashville	Tennessee	4578671460428741	e6a10fa6ab48c911f7e9903d3d84910a	VISA 16 digit	36.1075818858232296	-86.7685434535518283
23642	2020-05-07 08:04:36	2020-05-07	Scottie Ryan	scottie.ryan@geemail.com	Los Angeles	California	6011011050771366533	02ed40c257242c51b3a52a83f9567814	Maestro	34.0578982487652411	-118.33668580623268
23643	2020-05-07 08:06:36	2020-05-07	Yamilex Bernhard	yamilex.bernhard@warmmail.com	Las Vegas	Nevada	3799703581804698	47e7a1f81f48830ea9ef062dffc2d189	VISA 16 digit	36.175811759252845	-115.16257153071686
23644	2020-05-07 08:12:36	2020-05-07	Miss Leota Dietrich	miss.leota.dietrich@geemail.com	New York	New York	676332621623241	0013b141efac7034889c5c8e6f960d61	Maestro	40.7250596884395932	-73.9715230203594984
23645	2020-05-07 08:14:50	2020-05-07	Dr. Maxine Stoltenberg MD	dr.maxine.stoltenberg.md@geemail.com	Milwaukee	Wisconsin	4742408388099432	24cec45c094d77550298e3ce40de2c7e	JCB 15 digit	43.1152303764216569	-88.0249865085918515
23646	2020-05-07 08:18:18	2020-05-07	Dr. Newell Bartoletti III	dr.newell.bartoletti.iii@geemail.com	North Las Vegas	Nevada	869912953506458856	a38ea77726417515a318c83c38ef7f58	Maestro	36.1909753661759197	-114.999386961919825
23647	2020-05-07 08:26:01	2020-05-07	Dr. Madden Watsica DVM	dr.madden.watsica.dvm@geemail.com	Simi Valley	California	3528177162840577683	1cf001dd2b573c7a7ac820aa5ff83495	Maestro	34.2655225652974096	-118.847322338413449
23648	2020-05-07 08:31:35	2020-05-07	Kenyon Daugherty	kenyon.daugherty@geemail.com	Lansing	Michigan	6011849876462032507	751bb7bf65027ed8453773d4f883a5a9	VISA 16 digit	42.6430269897758976	-84.617736078950756
23649	2020-05-07 08:35:45	2020-05-07	Ms. Nolia Ryan	ms.nolia.ryan@warmmail.com	Phoenix	Arizona	4704605893709829	8303a3bae2247f8665c6cb05a162e035	JCB 15 digit	33.528479644323518	-112.169785353441171
23650	2020-05-07 08:37:46	2020-05-07	Kaitlynn Bode DVM	kaitlynn.bode.dvm@geemail.com	Long Beach	California	3013915963567314	ac82bdaa783ef7320fe911ac2675e60c	VISA 16 digit	33.7144156858146147	-118.062330428294089
23651	2020-05-07 08:38:04	2020-05-07	Pam Ritchie	pam.ritchie@geemail.com	Garland	Texas	52777976148556352	9c0a0abd1325727fc1285c8706b79e6d	Diners Club / Carte Blanche	32.9137356414228677	-96.7143816370677314
23652	2020-05-07 08:46:24	2020-05-07	Theodis O'Kon	theodis.o'kon@geemail.com	Antioch	California	3706302999779675	a0589c8dba0d236fbe97e616317c93db	Discover	37.9293298347186294	-121.740156857267763
23653	2020-05-07 08:50:45	2020-05-07	Carson Kulas	carson.kulas@warmmail.com	New York	New York	3528901179671718056	af9cf2aae971704f05e5e1136679de54	VISA 16 digit	40.5986721152197561	-73.9055448336888077
23654	2020-05-07 08:51:06	2020-05-07	Dr. Marcelo Hackett II	dr.marcelo.hackett.ii@geemail.com	New York	New York	3337406722216141647	d562621c5c69b037c4d3c0b7c2513d4d	Discover	40.7079069571327423	-73.8445332624379489
23655	2020-05-07 09:40:39	2020-05-07	Etna Kuhlman DDS	etna.kuhlman.dds@geemail.com	Philadelphia	Pennsylvania	3096876996011297074	fcd541682e1979d1288caf2df0dc0463	Voyager	40.1049791269894698	-75.1065605931349154
23656	2020-05-07 09:41:30	2020-05-07	Cam Wisozk	cam.wisozk@woohoo.com	Pompano Beach	Florida	4687905813445830	7da67612a6eb4a539e28c27e5dfe1654	VISA 16 digit	26.2423063603494313	-80.0484366702228698
23657	2020-05-07 09:43:11	2020-05-07	Corbett Gutkowski	corbett.gutkowski@warmmail.com	Abilene	Texas	4263705433286	a5b91b04e11907006a134993bdd5d3e0	JCB 15 digit	32.3681171001009673	-99.7878328469529805
23658	2020-05-07 09:46:02	2020-05-07	Forrest Predovic	forrest.predovic@geemail.com	Denver	Colorado	51875038101445619	d0c708866aa411c464b95616524cfc05	VISA 16 digit	39.7179425374656887	-104.855037570955602
23659	2020-05-07 09:53:14	2020-05-07	Cas Parisian-Rempel	cas.parisian.rempel@geemail.com	San Francisco	California	4691917727238	a0bb98ffc7676a47bf323d730d99d3b9	American Express	37.8017155318738176	-122.45772056904282
23660	2020-05-07 10:00:46	2020-05-07	Macarthur Gutmann PhD	macarthur.gutmann.phd@woohoo.com	Fort Worth	Texas	4236234568738034	7f3f6ea6524367e1f8810f3daaef7ca7	Voyager	32.729081756161527	-97.4193837351452601
23661	2020-05-07 10:38:12	2020-05-07	Domenick Douglas-Greenholt	domenick.douglas.greenholt@geemail.com	San Francisco	California	869961467452111054	3f7fc38bbcb37372755a9d882e9cc00f	Voyager	37.8207632338224329	-122.406684307659461
23662	2020-05-07 10:44:46	2020-05-07	Miss Eris Brekke	miss.eris.brekke@geemail.com	Norfolk	Virginia	6011438851159271251	a700a812803413a66b13122756bf2f00	Diners Club / Carte Blanche	36.9798114779889602	-76.3064171838577892
23663	2020-05-07 10:44:50	2020-05-07	Dink Pollich	dink.pollich@geemail.com	Fort Wayne	Indiana	4302525448452	19dbca522be889960b5fed7f07f19063	Diners Club / Carte Blanche	41.0501511442258931	-85.2138951957911246
23664	2020-05-07 11:03:31	2020-05-07	Adelle Stamm	adelle.stamm@geemail.com	San Francisco	California	3088462219631061931	df4cef0120e35d4e930f7f2823c5b71f	VISA 16 digit	37.7843227270779067	-122.444630101400264
23665	2020-05-07 11:13:10	2020-05-07	Edith Predovic	edith.predovic@warmmail.com	New York	New York	3096737296752444806	8f3429b7a21ea61f10912ba43d113f22	VISA 16 digit	40.6550602552238871	-73.9124210308667244
23666	2020-05-07 11:32:47	2020-05-07	Gael Hermann	gael.hermann@geemail.com	Moreno Valley	California	3112365908975816748	f277125b7fe99e6bbeb57b10b0f6a278	American Express	33.9716211386948785	-117.229735390419876
23667	2020-05-07 11:34:03	2020-05-07	Florie Deckow	florie.deckow@geemail.com	Fargo	North Dakota	210091129656482962	15013cc46f15bd72c6d6da4abe8df1f3	VISA 16 digit	46.9067374466218041	-96.8569664446599745
23668	2020-05-07 11:34:13	2020-05-07	Aretha Ledner	aretha.ledner@geemail.com	New York	New York	54408940425797227	094f1dfe4798aaba6c32b4e186b86660	Voyager	40.7507683098074054	-73.9226053596369894
23669	2020-05-07 11:48:24	2020-05-07	Tylor Kertzmann	tylor.kertzmann@woohoo.com	Newark	New Jersey	4163828887735899	6b272847b9bb56dcda6cacd917c4c12a	JCB 16 digit	40.7707086196083637	-74.1986948707349683
23670	2020-05-07 11:54:29	2020-05-07	Kamren Bednar	kamren.bednar@woohoo.com	Rochester	Minnesota	3005520223562325	b827a4bb9410c38918ef30a286d7362b	Maestro	43.9311557313330496	-92.4880722526114454
23671	2020-05-07 12:05:55	2020-05-07	Herman Lebsack MD	herman.lebsack.md@woohoo.com	Los Angeles	California	869939787984591328	36462aaaeef3b99774192d538f174da5	VISA 16 digit	34.0090407606545782	-118.335685360011823
23672	2020-05-07 12:21:45	2020-05-07	Vick Emard	vick.emard@geemail.com	San Francisco	California	210075726645140971	3b3e28b13b577033b8854a9d521e8bb5	VISA 16 digit	37.7409914011563856	-122.390345513574786
23673	2020-05-07 12:25:49	2020-05-07	Lera Becker MD	lera.becker.md@geemail.com	Scottsdale	Arizona	180067854245134127	6627e473ff4a0b922ea3e2a1de5bec1a	JCB 16 digit	33.5974327053997683	-111.907682555770862
23674	2020-05-07 12:42:26	2020-05-07	Tatyana Hand	tatyana.hand@geemail.com	San Francisco	California	869981481729073100	d99baafbfc4eda5bfe6d1f99b7e1689c	VISA 16 digit	37.7818224097830111	-122.458789750564364
23675	2020-05-07 12:54:49	2020-05-07	Mae Murazik	mae.murazik@geemail.com	Lafayette	Louisiana	3158180789613904887	3ddcd760dff58ef3849cb2f75b42ac15	VISA 13 digit	30.151241730616988	-92.0189424796812148
23676	2020-05-07 12:58:18	2020-05-07	Ms. Rilla Strosin	ms.rilla.strosin@woohoo.com	Lubbock	Texas	561236863780437	c99f42159650dbd018d4205628aca9f6	VISA 13 digit	33.5672909849830035	-101.929544365956261
23677	2020-05-07 13:12:58	2020-05-07	Dr. Mason Greenholt I	dr.mason.greenholt.i@geemail.com	Berkeley	California	210090994808161413	ec384e644adac71e3bcf0dffb00476d4	VISA 16 digit	37.8830082498120504	-122.299405484730144
23678	2020-05-07 13:15:40	2020-05-07	Karlee Dach-Schaden	karlee.dach.schaden@geemail.com	Bakersfield	California	3031359050286060	e7b9734995fda1813e536679db515cb7	VISA 13 digit	35.2969178502622967	-119.056379535728311
23679	2020-05-07 13:18:44	2020-05-07	Shep Grimes III	shep.grimes.iii@warmmail.com	San Francisco	California	3427813247945418	c865761d43e9571a1a0876108361e366	VISA 13 digit	37.7647927684107074	-122.433865844635832
23680	2020-05-07 13:40:49	2020-05-07	Danniel Hermann	danniel.hermann@woohoo.com	El Paso	Texas	6011613457487957327	02191df58724fe91e9041ec9a227e99a	VISA 16 digit	31.9279647009741545	-106.34446428157203
23681	2020-05-07 13:57:39	2020-05-07	Keshaun Waelchi	keshaun.waelchi@woohoo.com	Vista	California	4207374709366835	77aab9d801697a2552316e552c72c17a	JCB 16 digit	33.1294299439974154	-117.193176188838109
23682	2020-05-07 13:58:36	2020-05-07	Clifford Carroll-Sawayn	clifford.carroll.sawayn@warmmail.com	Santa Clarita	California	4755200497323025	9e94a75de2073f4964bccbc4ee964b6e	VISA 13 digit	34.3507874364703909	-118.466299650036547
23683	2020-05-07 14:03:51	2020-05-07	Raheem Cronin	raheem.cronin@warmmail.com	San Francisco	California	3158362351329333644	2c6b7091c14536c99339bd81320159ab	Diners Club / Carte Blanche	37.7782626711790854	-122.388276614546257
23684	2020-05-07 14:23:31	2020-05-07	Dr. Audrina Aufderhar PhD	dr.audrina.aufderhar.phd@warmmail.com	Tempe	Arizona	4073454482980571	774aa625b4c75f31dd174c79680fce68	Discover	33.3079848053786876	-111.852908777262272
23685	2020-05-07 14:29:00	2020-05-07	Esco Heller	esco.heller@geemail.com	Riverside	California	3009824138825348	009f9a29df9c8bcb69154fca353d4c4f	Maestro	34.0088225473597632	-117.35104951401874
23686	2020-05-07 14:30:49	2020-05-07	Seamus Veum	seamus.veum@warmmail.com	Charleston	South Carolina	180068234633296987	fa34bb54f44dfa4f598558a514d32884	Diners Club / Carte Blanche	32.7239759986750798	-80.0179397251606019
23687	2020-05-07 14:31:35	2020-05-07	Denis Bogisich-Rolfson	denis.bogisich.rolfson@geemail.com	Honolulu	Hawaii	676212859422565	8ec1900d734f011294fdf5cf805f636f	JCB 16 digit	21.2403538292489955	-157.752831720395392
23688	2020-05-07 15:17:16	2020-05-07	Cleveland Lehner	cleveland.lehner@geemail.com	San Antonio	Texas	3050773938846955	672fc16cb943af3b397d9db33eb7d903	Mastercard	29.5624558507069963	-98.5028012306265452
23689	2020-05-07 15:24:41	2020-05-07	Viola Mills	viola.mills@geemail.com	New York	New York	676109302116257	df47b94731cab9c8f7aaaf769db0aa8a	Diners Club / Carte Blanche	40.7427825161479404	-73.911403233594072
23690	2020-05-07 16:01:49	2020-05-07	Dr. Dakota Ebert DDS	dr.dakota.ebert.dds@warmmail.com	Los Angeles	California	51361986338763199	04e4305cdcf9b0b2fd0b6ae07d3ef16b	VISA 16 digit	34.1189472655631576	-118.387898173322156
23691	2020-05-07 16:08:54	2020-05-07	Corine Osinski PhD	corine.osinski.phd@warmmail.com	New York	New York	4759397675886	d9ee6a0fe0cad783a54ed39374bdbd9a	VISA 13 digit	40.7481866463310993	-73.970887380501992
23692	2020-05-07 16:13:32	2020-05-07	Alonza Blick	alonza.blick@woohoo.com	North Las Vegas	Nevada	869902241016242685	fec362993a28b52af83f526a8dd0ba00	Discover	36.2875439505249275	-115.147397004555543
23693	2020-05-07 16:29:33	2020-05-07	Gibson Hessel	gibson.hessel@geemail.com	Los Angeles	California	55972923741676776	40cf63a9de643ab578861548da64815b	VISA 16 digit	33.9290073793247302	-118.408824448705829
23694	2020-05-07 16:37:11	2020-05-07	Gifford Roberts	gifford.roberts@geemail.com	Phoenix	Arizona	3046140171205667	28b449c4356b1ace658b735df80b92f3	Voyager	33.5259892342079482	-112.043729227541391
23695	2020-05-07 16:57:43	2020-05-07	Mrs. Karen Kuhn	mrs.karen.kuhn@geemail.com	San Francisco	California	3040994715027003	9af0cdc4512043b93307901c4019acf9	JCB 15 digit	37.7452903422243793	-122.431653074016864
23696	2020-05-07 17:12:47	2020-05-07	Demetra Johnson PhD	demetra.johnson.phd@woohoo.com	San Francisco	California	4751241749819	5dc00ee58559d204e7b5caa2fa8ddd9f	VISA 13 digit	37.8113652983472974	-122.440087936916697
23697	2020-05-07 17:26:25	2020-05-07	Glinda Ankunding	glinda.ankunding@geemail.com	Little Rock	Arkansas	6011246541087556731	172830c4edfe5d97d7cb74b7fc36f8e9	Diners Club / Carte Blanche	34.7550890489291433	-92.2851493408776804
23698	2020-05-07 17:27:23	2020-05-07	Pricilla Osinski	pricilla.osinski@geemail.com	Stamford	Connecticut	180076373836074229	81b2bdcc45eb18437b1d89a287f21663	VISA 16 digit	41.0605459701154416	-73.4845677284561134
23699	2020-05-07 17:35:40	2020-05-07	Barrett Mante	barrett.mante@geemail.com	Indianapolis	Indiana	589367572138757	35423af5c1145d44f4549dfc41b3c51a	Voyager	39.7679657142151157	-86.1476080273479141
23700	2020-05-07 17:43:05	2020-05-07	Mellie Friesen	mellie.friesen@geemail.com	Lubbock	Texas	3008415599563311	b0073b388b4ec4b4b1414ae2eb59969f	Maestro	33.6263213631272322	-101.98453659363166
23701	2020-05-07 17:55:50	2020-05-07	Ms. Zara Fay PhD	ms.zara.fay.phd@geemail.com	Philadelphia	Pennsylvania	3088401760955736834	ee4f62aa29c553046d75664b1260d9e0	American Express	40.0435208178084352	-75.0519881233472432
23702	2020-05-07 18:01:39	2020-05-07	Mrs. Yadira Larson PhD	mrs.yadira.larson.phd@geemail.com	New York	New York	4991314513409	2780993a613a0dfccf20540e88ec30e0	American Express	40.6070482626780844	-73.9704900164518477
23703	2020-05-07 18:06:28	2020-05-07	Ema Ullrich	ema.ullrich@geemail.com	New York	New York	3429917925537591	575630bec69ada41133e825b447a6fb8	Mastercard	40.7036100332848747	-73.9837777568854307
23704	2020-05-07 18:25:39	2020-05-07	Damion Jerde	damion.jerde@geemail.com	Wichita	Kansas	3528874348178090813	48facbd7059caec6135ffcf5b708840b	JCB 15 digit	37.6508426488254244	-97.4056544004674976
23705	2020-05-07 18:51:22	2020-05-07	Shanequa Yost	shanequa.yost@warmmail.com	Akron	Ohio	3088995427558274355	dfc7e51f1e5d74838201fc195886be8f	Maestro	41.0566122492607661	-81.4289433063786419
23706	2020-05-07 19:03:46	2020-05-07	Wood Huel	wood.huel@geemail.com	Fresno	California	3020348517742899	c6f0ba35c50ae76221bab0d053f3bcb9	Discover	36.8193391498517215	-119.811417861060804
23707	2020-05-07 19:10:42	2020-05-07	Carmel Huel IV	carmel.huel.iv@geemail.com	Fargo	North Dakota	53505660339413305	7dd342a54556ec7715be24700089ddcf	Voyager	46.9495616659753026	-96.8965217037554822
23708	2020-05-07 19:29:25	2020-05-07	Lynsey Mitchell	lynsey.mitchell@warmmail.com	San Francisco	California	6011828323122924372	67067fcfbbe6c5c4581f4f60c7c86edc	VISA 16 digit	37.7408106338364249	-122.428170243963052
23709	2020-05-07 19:34:33	2020-05-07	Johnie Kovacek	johnie.kovacek@geemail.com	San Francisco	California	3088420280566708657	a2453999a8dcd2273adffe14df700c6c	Diners Club / Carte Blanche	37.7696158834053008	-122.410861940663651
23710	2020-05-07 20:15:40	2020-05-07	Lenord Labadie-Stoltenberg	lenord.labadie.stoltenberg@geemail.com	Chicago	Illinois	589364495775039	9b2ab538f5bda4fa70f3811833d52d3a	Voyager	41.8410250274766256	-87.7479749319173408
23711	2020-05-07 20:20:27	2020-05-07	Zachariah Spencer-Olson	zachariah.spencer.olson@geemail.com	San Francisco	California	676231447447736	436b7e66ec7fed44135834ba66a05f02	Diners Club / Carte Blanche	37.7973691777894771	-122.455558817552117
23712	2020-05-07 20:22:32	2020-05-07	Dylan Towne	dylan.towne@geemail.com	Las Vegas	Nevada	54299324948638709	19ef8d1d7840753f3932c9febd2a2f2f	VISA 16 digit	36.2179122772634017	-115.321329343712321
23713	2020-05-07 20:25:28	2020-05-07	Hakim Braun	hakim.braun@geemail.com	San Francisco	California	4348607172906714	947794ddf68561ee782dd75734fa536f	Maestro	37.7497027402223324	-122.473130472249622
23714	2020-05-07 20:29:52	2020-05-07	Versie Hilll	versie.hilll@geemail.com	Orange	California	51295554699947768	f4773343869c51145471269f6f0d2f21	Maestro	33.8145671438779658	-117.927956073415658
23715	2020-05-07 20:34:23	2020-05-07	Danyelle Weimann-Cartwright	danyelle.weimann.cartwright@warmmail.com	Fremont	California	3037436464689776	2a6c4a5818dfa2da4fd9334f1f74667f	Voyager	37.4193661406338265	-121.901580663676185
23716	2020-05-07 20:36:45	2020-05-07	Dr. Leland Mohr MD	dr.leland.mohr.md@geemail.com	Oklahoma City	Oklahoma	4686084996445412	3247369e2f6014fe72ea757466f4470a	VISA 13 digit	35.546101095052812	-97.416509661393988
23717	2020-05-07 20:51:09	2020-05-07	Ovid Graham	ovid.graham@geemail.com	Baton Rouge	Louisiana	501800486383730	f40092b703cfbac0459adaef3b67bfcc	VISA 13 digit	30.4134085732724522	-91.0392275457378446
23718	2020-05-07 20:53:56	2020-05-07	Maeve Jacobson-Gerlach	maeve.jacobson.gerlach@geemail.com	Plano	Texas	210059697246680501	48fdc7e1805d93a6f21b1f0a153f5bdb	Maestro	33.0003364869944775	-96.7501774678654982
23719	2020-05-07 20:59:26	2020-05-07	Waymon Muller	waymon.muller@geemail.com	Hollywood	Florida	869925453585998489	3625dd2f4fe1f0a8dca1b5f974163f9a	Discover	26.1082406821604813	-80.1139584612384397
23720	2020-05-07 21:08:22	2020-05-07	Mickie Kris	mickie.kris@geemail.com	Philadelphia	Pennsylvania	6011811885354404330	f5c258b7f724b875e5a2cb0b6346bc48	Discover	39.9315297241747373	-75.0508592700019506
23721	2020-05-07 21:13:47	2020-05-07	Dr. Rudolph Johns	dr.rudolph.johns@woohoo.com	Dallas	Texas	3096454378444563259	5e88aa50f003322a21ffaad565e8650e	Diners Club / Carte Blanche	32.7978993172563662	-96.725211761608719
23722	2020-05-07 21:18:57	2020-05-07	Foster Friesen-Toy	foster.friesen.toy@geemail.com	San Antonio	Texas	3088821545438937188	5dc1c1ad3dff912080c2f0b0b52673b3	VISA 13 digit	29.5316896579764787	-98.6183164721656595
23723	2020-05-07 21:29:52	2020-05-07	Herminia Spencer	herminia.spencer@woohoo.com	New York	New York	4258730824242680	d3aaf8ad4520df185f6b9c513864a5c9	JCB 16 digit	40.5664121205676338	-73.8857689893234522
23724	2020-05-07 21:31:43	2020-05-07	Judyth Cummings-Langosh	judyth.cummings.langosh@woohoo.com	San Francisco	California	3096509667236957405	262e89d8d03d0e5a903aa3b8c30cb9cd	Maestro	37.7435170580018067	-122.398538348767005
23725	2020-05-07 21:37:47	2020-05-07	Isidore O'Hara	isidore.o'hara@warmmail.com	San Francisco	California	6011576295054113675	93fe09f2340f3eba0be199c3530c65a9	VISA 13 digit	37.7742663814317012	-122.440050504806067
23726	2020-05-07 22:08:36	2020-05-07	Juelz Jast	juelz.jast@geemail.com	Phoenix	Arizona	210025886675757929	dde175aae23095e5386178d25eb04342	Diners Club / Carte Blanche	33.6072684871897138	-112.124112537123636
23727	2020-05-07 22:38:22	2020-05-07	Forest D'Amore	forest.d'amore@geemail.com	Columbus	Ohio	869913223577374492	ef7f107a5f1406f06edc5a0b3433f510	Mastercard	39.9736915226604808	-83.0645049019020121
23728	2020-05-07 23:09:50	2020-05-07	Tiesha Kozey	tiesha.kozey@geemail.com	Rancho Cucamonga	California	4728689608502564	c3870f07b61aae12b567a1c1c025f126	American Express	34.1590366884592953	-117.580703436444324
23729	2020-05-07 23:20:44	2020-05-07	Eulalia Kunze	eulalia.kunze@warmmail.com	San Francisco	California	4775029380073801	a5c930e18dc08a13edf8845e68fe3a72	JCB 16 digit	37.7612172965512372	-122.421464643414566
23730	2020-05-07 23:33:38	2020-05-07	Anya Gutmann DVM	anya.gutmann.dvm@geemail.com	New York	New York	3404027964494024	bcfe1a75f1f0f9c29107182f6f5bd8c0	Mastercard	40.7569434059541678	-73.843628505467251
23731	2020-05-07 23:51:51	2020-05-07	Caro Larkin DDS	caro.larkin.dds@geemail.com	Los Angeles	California	210067419369640992	96794242f8517e1e1c4888dab2e842f5	American Express	34.002226705742622	-118.32300986312255
23732	2020-05-07 23:58:50	2020-05-07	Kimberly O'Keefe	kimberly.o'keefe@geemail.com	Atlanta	Georgia	3438455555806985	5b3b38d1bd3fb8881a0712258e8b3fc3	JCB 16 digit	33.6718467610232537	-84.3453423982996497
23733	2020-05-07 23:59:58	2020-05-07	Yesenia Fahey-O'Reilly	yesenia.fahey.o'reilly@woohoo.com	Oakland	California	3158871778990318336	d43eeac5835a26db3a0a6752ba571248	VISA 16 digit	37.786782072431123	-122.284171540187927
23734	2020-05-08 00:13:59	2020-05-08	Dr. Jamarcus Lehner	dr.jamarcus.lehner@geemail.com	San Francisco	California	3528817588453538321	0832a7e0562aa98d50109d7ed1bc5e4b	Voyager	37.7554128170199021	-122.409263043107686
23735	2020-05-08 00:27:18	2020-05-08	Mrs. Caydence Yost PhD	mrs.caydence.yost.phd@woohoo.com	Oakland	California	3112749061034052785	e431a2f14db2384e999d6679802c675a	Diners Club / Carte Blanche	37.8000760116028403	-122.262485985906849
23736	2020-05-08 00:28:12	2020-05-08	Mr. Kenny Walsh Sr.	mr.kenny.walsh.sr.@geemail.com	Chicago	Illinois	3158158978257530060	11d4d4337a443479e3f6f1d69550bb37	VISA 16 digit	41.7861683168284586	-87.6542583887029423
23737	2020-05-08 00:38:42	2020-05-08	Miley Koelpin	miley.koelpin@geemail.com	Arlington	Texas	630403150568925	234566e9c6f5372074ebae2df60df1ee	Diners Club / Carte Blanche	32.6044765386048709	-97.2151484546743347
23738	2020-05-08 00:39:26	2020-05-08	Miss Roxann Altenwerth	miss.roxann.altenwerth@geemail.com	San Francisco	California	3475919636006281	da621452a6c3a1c98792af1251df47e3	VISA 13 digit	37.7658171096943889	-122.419657167734655
23739	2020-05-08 00:40:50	2020-05-08	Dennie Bechtelar	dennie.bechtelar@geemail.com	Clearwater	Florida	6011546446055264614	30fec8420875c86ce46a66708314525a	JCB 15 digit	27.893947682262958	-82.7263904433496293
23740	2020-05-08 00:43:48	2020-05-08	Rex Terry V	rex.terry.v@geemail.com	Newport News	Virginia	4250121440403229	3e5bd887bb1ef03ee1985dfabee47a29	JCB 16 digit	36.976824463101849	-76.5392642437741273
23741	2020-05-08 00:47:42	2020-05-08	Zain Ondricka Sr.	zain.ondricka.sr.@geemail.com	St. Louis	Missouri	3337293604371256616	c0b4618b5569675224a14967fc379e16	VISA 16 digit	38.5515905263058869	-90.2376204129777904
23742	2020-05-08 00:48:30	2020-05-08	Ms. Kay Konopelski	ms.kay.konopelski@warmmail.com	Honolulu	Hawaii	3029440666578348	a713ee2bdaaf44df70921f6087511cde	VISA 13 digit	21.3514397863514738	-157.803856344867881
23743	2020-05-08 00:52:10	2020-05-08	Adella Schinner	adella.schinner@geemail.com	New York	New York	869994579791322399	8729abd9594287e463213874772405ea	American Express	40.6558431396950013	-73.9656799263682245
23744	2020-05-08 00:53:59	2020-05-08	Mr. Coley Lebsack IV	mr.coley.lebsack.iv@geemail.com	Columbus	Ohio	676388113303163	9bf2f4cd5c001e6a49f8c8f3ff878cd0	JCB 15 digit	39.9017574478916828	-83.0137315745700164
23745	2020-05-08 01:08:26	2020-05-08	Mr. Orrie Koepp III	mr.orrie.koepp.iii@geemail.com	Indianapolis	Indiana	869969071368861653	8ba8f183916fcac83f01f9ed11272304	VISA 16 digit	39.6946691106080962	-86.0513992528166654
23746	2020-05-08 01:14:09	2020-05-08	Georgie Goldner	georgie.goldner@geemail.com	Charleston	South Carolina	3337722379787753636	edba8bb6bf8e8c5ff437266cfc8d02f1	JCB 16 digit	32.7361933733798551	-79.905141272457314
23747	2020-05-08 01:25:21	2020-05-08	Ofelia West	ofelia.west@geemail.com	Vallejo	California	6011589426635176783	bcb90f3d0a29ed1423eaf724b358d8bb	Maestro	38.1781385948970922	-122.232940911954259
23748	2020-05-08 01:26:40	2020-05-08	Reagan Ondricka	reagan.ondricka@geemail.com	Jacksonville	Florida	4246217431685035	94332e85d6f51f7227fb760978ac78d5	VISA 16 digit	30.2516581134922795	-81.7578531888391922
23749	2020-05-08 01:28:22	2020-05-08	Osbaldo O'Keefe	osbaldo.o'keefe@geemail.com	Downey	California	3088555962137672903	e8cd3b891f03c941de82c5485ad6ca49	Diners Club / Carte Blanche	34.0273182864550492	-118.076431706558537
23750	2020-05-08 01:43:40	2020-05-08	Dr. Matt Runolfsdottir	dr.matt.runolfsdottir@warmmail.com	Omaha	Nebraska	3445712894434015	26a3859dcf7baa23b9d0d4c26859c980	VISA 16 digit	41.2883328511059275	-95.988345406029751
23751	2020-05-08 01:53:29	2020-05-08	Bryana Parisian DVM	bryana.parisian.dvm@geemail.com	Frisco	Texas	676363260895337	8610f883775b0c36c1a14d04629b2530	JCB 16 digit	33.2242547973521027	-96.894508566076297
23752	2020-05-08 01:57:59	2020-05-08	Dr. Judah Corkery DVM	dr.judah.corkery.dvm@geemail.com	Springfield	Missouri	4051162569076	0c9c770b1312d6605416bfc5aae312b2	VISA 13 digit	37.2451530813898941	-93.2075599235307521
23753	2020-05-08 02:26:16	2020-05-08	Dr. Krissy White MD	dr.krissy.white.md@geemail.com	Los Angeles	California	4886050908723681	73587fabfcaa2fa8ce51d3011c0582c9	JCB 16 digit	33.9546066312450918	-118.387918460368354
23754	2020-05-08 02:28:52	2020-05-08	Starling Gulgowski	starling.gulgowski@geemail.com	New York	New York	180085421157375649	68906de7be4a351cb26cabb43879018d	VISA 13 digit	40.6017598163094391	-73.9916230237938493
23755	2020-05-08 02:30:39	2020-05-08	Leia Leannon	leia.leannon@woohoo.com	San Diego	California	3413822674318847	abc1b6bed5fe4d38ae67329d2a662036	JCB 15 digit	32.8275374450322275	-117.156318802889444
23756	2020-05-08 02:49:08	2020-05-08	Alisa Torp	alisa.torp@geemail.com	Jacksonville	Florida	6011464872600139290	d4422b641bb9555ad6299535533a106c	Voyager	30.389797961623966	-81.5898722789794277
23757	2020-05-08 02:50:40	2020-05-08	Cordero Johns	cordero.johns@geemail.com	Syracuse	New York	3430957500991752	16d592c0afc27f3a01a8cb4c7cb44719	Voyager	43.0202641273234008	-76.0464806002810718
23758	2020-05-08 03:01:08	2020-05-08	Alonza Padberg	alonza.padberg@geemail.com	Houston	Texas	3017356311769862	b23598d7e103e3dc131f85cbc8aadbcc	JCB 16 digit	29.8732139500401921	-95.3843111841488707
23759	2020-05-08 03:01:18	2020-05-08	Shirley Gerlach	shirley.gerlach@geemail.com	Hartford	Connecticut	6011776276028243598	1b4261ed238a0d409ef98c4d45b17a96	JCB 16 digit	41.700267433097217	-72.6243895663306205
23760	2020-05-08 03:16:23	2020-05-08	Giada Emard	giada.emard@geemail.com	San Francisco	California	52825521345616088	3734b5ed76d8a86157117d2a1e3eb7d2	JCB 16 digit	37.7688256487066738	-122.409000221114439
23761	2020-05-08 03:29:47	2020-05-08	Bret Jenkins	bret.jenkins@geemail.com	Palmdale	California	6011758600737174087	e92e8be21690f3eda0273d203d980413	JCB 16 digit	34.5984296806938971	-118.142022904846442
23762	2020-05-08 03:36:58	2020-05-08	Denisha Bahringer	denisha.bahringer@geemail.com	New York	New York	180012143635017936	9c3ec9de492fb1af5a3602af403cb9e8	Voyager	40.6634021485447903	-74.036679874908927
23763	2020-05-08 03:37:58	2020-05-08	Macey Wolf	macey.wolf@geemail.com	San Angelo	Texas	3158019512487539283	9ba23410963c010bb7e2d7669c3ac93a	Voyager	31.5114431223519134	-100.438604010839015
23764	2020-05-08 03:38:08	2020-05-08	Precious Fritsch	precious.fritsch@warmmail.com	Washington	District of Columbia	3005037478078766	723d462b4357158bc894f88b2c015efe	VISA 16 digit	39.0007630171053137	-77.1066555371254765
23765	2020-05-08 03:38:51	2020-05-08	Lewis Marquardt-Moore	lewis.marquardt.moore@geemail.com	Honolulu	Hawaii	6011435578556360873	9efe06a7421cd1de788275aa0f248087	JCB 16 digit	21.2995379441168176	-157.822436945114646
23766	2020-05-08 03:43:06	2020-05-08	Destiney Graham	destiney.graham@geemail.com	Orlando	Florida	52337939386941622	15c12349d3c819fa88bd1b4b1cf58895	VISA 16 digit	28.3286032635517415	-81.2349838240504312
23767	2020-05-08 03:45:23	2020-05-08	Dr. Kaela Altenwerth	dr.kaela.altenwerth@geemail.com	North Las Vegas	Nevada	3016906533710564	6eac304b59b407d08a282e6627d66ba8	JCB 15 digit	36.3158594933960543	-115.018245977092164
23768	2020-05-08 03:51:20	2020-05-08	Mr. Ola Volkman V	mr.ola.volkman.v@woohoo.com	New York	New York	3017587468977276	daef56bd2263f2cd3af706b296bba18c	JCB 15 digit	40.7615333137325919	-74.0107707772765337
23769	2020-05-08 03:51:24	2020-05-08	Kinsey McCullough-Bergnaum	kinsey.mccullough.bergnaum@geemail.com	El Paso	Texas	3158526945797575942	29c8e9b0f3f9c3a774aef1167fd431a5	VISA 16 digit	31.8084947908125848	-106.379133162552492
23770	2020-05-08 04:05:05	2020-05-08	Dr. Chantelle Welch	dr.chantelle.welch@geemail.com	San Francisco	California	3096734676167095371	83fb16aba2fd7b00d74f0e700bde3172	JCB 16 digit	37.7823901118919636	-122.419657025685737
23771	2020-05-08 04:08:12	2020-05-08	Amelia Crist	amelia.crist@warmmail.com	Concord	California	3494118905519119	28b3a7fe2805a0a90820a947b434c966	JCB 16 digit	37.9041395826663816	-122.061051138647272
23772	2020-05-08 04:14:23	2020-05-08	Ima Pollich-Connelly	ima.pollich.connelly@woohoo.com	El Paso	Texas	3096930181604353105	6626d86c74c7ce3f4f1d6a48066e0c85	Mastercard	31.8183776380322882	-106.467647751744849
23773	2020-05-08 04:15:46	2020-05-08	Mr. Jeffie Armstrong Jr.	mr.jeffie.armstrong.jr.@geemail.com	Plano	Texas	210033605497630662	be4c539635e269eea4325feb011179e9	Mastercard	33.132875229519982	-96.8212870634809093
23774	2020-05-08 04:21:35	2020-05-08	Dr. Torry Prosacco I	dr.torry.prosacco.i@geemail.com	Oklahoma City	Oklahoma	4679418329968	f01837c98d460380eca13e3da3df6d57	VISA 16 digit	35.3694846030700987	-97.5430803340289714
23775	2020-05-08 04:35:15	2020-05-08	Dr. Kanesha McCullough	dr.kanesha.mccullough@geemail.com	Aurora	Colorado	6011005852909962374	b54df5cd5c8b10644f498ab95657cd60	VISA 13 digit	39.6584065771307834	-104.723893903952842
23776	2020-05-08 04:40:14	2020-05-08	Ishaan Schiller DDS	ishaan.schiller.dds@geemail.com	San Francisco	California	4679103426210201	a48b4dbed462b49a32e980b1e06e81ce	Maestro	37.76923859189111	-122.416331448281809
23777	2020-05-08 04:40:33	2020-05-08	Keila Von-Hansen	keila.von.hansen@warmmail.com	Round Rock	Texas	54081714637564129	94734a22ad7f37a0af907f8f2a770e90	JCB 16 digit	30.4507265592131766	-97.7407103605419394
23778	2020-05-08 04:51:24	2020-05-08	Thor Lesch	thor.lesch@woohoo.com	Baltimore	Maryland	3158297461221515774	f12cfad7eab90181a3e70304f5851e70	American Express	39.3898081919178367	-76.5666813971027693
23779	2020-05-08 04:56:16	2020-05-08	Myer Kilback	myer.kilback@warmmail.com	New York	New York	3055886215133809	d7273f9d6b022936f4f2a53785dc4937	Diners Club / Carte Blanche	40.5721989658884681	-74.0305418549466907
23780	2020-05-08 05:04:55	2020-05-08	Jessie Deckow-Kiehn	jessie.deckow.kiehn@geemail.com	Stamford	Connecticut	6011495545090304854	0374d8b8db69ff8414a11ffbbece4c14	JCB 16 digit	41.1729947622284342	-73.5674970272500133
23781	2020-05-08 05:16:26	2020-05-08	Teagan Hane	teagan.hane@geemail.com	Springfield	Illinois	869919869520655777	30e74394005c88f5af0521a25196a9d9	Voyager	39.8320278411883848	-89.5644947770986732
23782	2020-05-08 05:23:12	2020-05-08	Camron Pouros	camron.pouros@geemail.com	San Francisco	California	6011689902429974442	2a1e964d0f43f87f8b0b52bfda3d7428	VISA 16 digit	37.7881391521213033	-122.42396396985454
23783	2020-05-08 05:24:22	2020-05-08	Thad Littel	thad.littel@geemail.com	San Antonio	Texas	4939631695084937	c0745220d9b7d17374465397725d7f54	VISA 13 digit	29.4833148862306018	-98.5265885858632515
23784	2020-05-08 05:24:37	2020-05-08	Stacy Johnston	stacy.johnston@geemail.com	Berkeley	California	3112376699350739129	c5bb7ca756fcb7a78742b9884db8aebd	VISA 16 digit	37.8708554650588312	-122.254263490971653
23785	2020-05-08 05:33:47	2020-05-08	Aiyana Bernhard-Senger	aiyana.bernhard.senger@geemail.com	Tucson	Arizona	4696043898166201	834ffd305f688944dda0e6906ef65174	American Express	32.1945066199213272	-110.829068685299148
23786	2020-05-08 05:46:45	2020-05-08	Miss Karie Kuhlman PhD	miss.karie.kuhlman.phd@geemail.com	Pittsburgh	Pennsylvania	3337992224855634313	61cf4baa7aa8611e9da15295897ca676	Voyager	40.4259287156585572	-79.9712827693842456
23787	2020-05-08 05:48:12	2020-05-08	Mamie Hagenes-Spencer	mamie.hagenes.spencer@geemail.com	Eugene	Oregon	4993016412229929	a14410226884d97c88b440822ea2ce7c	Diners Club / Carte Blanche	44.0836393621943898	-123.103272505289695
23788	2020-05-08 05:53:52	2020-05-08	Rudolfo Borer V	rudolfo.borer.v@woohoo.com	Charlotte	North Carolina	4196085893150271	cb2c4cf108cf9a88e9e2f6c3e7dc7617	Mastercard	35.2901518557008345	-80.7530457153394821
23789	2020-05-08 05:58:17	2020-05-08	Monna Lesch	monna.lesch@geemail.com	Pembroke Pines	Florida	503849635166140	7c4cc33afe3d662b0b322d6e845e4b8f	Maestro	26.0542906837109491	-80.2881144090458747
23790	2020-05-08 06:03:36	2020-05-08	Jessie Swaniawski	jessie.swaniawski@geemail.com	Los Angeles	California	4872157801575542	604d03ba0fd4a711861368c34390146e	American Express	34.043888595500583	-118.361852431715647
23791	2020-05-08 06:13:34	2020-05-08	Dr. Robbin West	dr.robbin.west@warmmail.com	Midland	Texas	3337782240416232128	bd8cff156c178132b60162b8ecbc2e3d	JCB 16 digit	31.9928938066776851	-102.088935582268988
23792	2020-05-08 06:24:16	2020-05-08	Valentin Heathcote	valentin.heathcote@geemail.com	Beaumont	Texas	4473959096735	61603705cd329c59d4473fdbc317f1fd	VISA 16 digit	30.093775120338055	-94.0506437974303964
23793	2020-05-08 06:28:13	2020-05-08	Teela Nikolaus	teela.nikolaus@woohoo.com	Round Rock	Texas	3464997848506119	232f3d142f44896cc6bd811a7f1c17ed	Voyager	30.5917828692726808	-97.7653172126822199
23794	2020-05-08 06:33:43	2020-05-08	Jenifer Lubowitz	jenifer.lubowitz@geemail.com	Daly City	California	3022393313406859	aca32bf5393647a467b3ecf8de4f2ed4	VISA 16 digit	37.6200082423552828	-122.556079686069864
23795	2020-05-08 06:41:07	2020-05-08	Shaniqua Schiller	shaniqua.schiller@warmmail.com	New York	New York	3112238191961630986	c8596cbb3d40d7ed0cbe2c471021285a	JCB 16 digit	40.6745683154780409	-73.892143397162485
23796	2020-05-08 06:45:04	2020-05-08	Meryl Walter PhD	meryl.walter.phd@geemail.com	New York	New York	3112329016733299499	66aefd9e274343826966424a3ce2f6eb	VISA 16 digit	40.5940135313421493	-73.954071928410599
23797	2020-05-08 07:12:44	2020-05-08	Mr. Berlin Gibson Sr.	mr.berlin.gibson.sr.@warmmail.com	San Francisco	California	3469507325216374	bf5a9b8240f75afbb5655cb60bbef67e	Diners Club / Carte Blanche	37.801280551757678	-122.413947957656092
23798	2020-05-08 07:19:38	2020-05-08	Dejuan Goodwin-Bosco	dejuan.goodwin.bosco@geemail.com	Chicago	Illinois	4768367387940583	e8be1cf31754379fd9b75bedf581d980	JCB 16 digit	41.8208578569650697	-87.6749670295540255
23799	2020-05-08 07:24:19	2020-05-08	Dilan Lang	dilan.lang@woohoo.com	Fresno	California	51921431879469461	ca452e224953447f59db5a569ef27121	Mastercard	36.8093701417431234	-119.848289559838932
23800	2020-05-08 07:30:53	2020-05-08	Orville Altenwerth	orville.altenwerth@warmmail.com	San Francisco	California	180017476933646054	4de7aff90b84b62766ba3ace82098be0	JCB 16 digit	37.7291560050641195	-122.462185364150614
23801	2020-05-08 07:38:15	2020-05-08	Miss Keesha Koepp	miss.keesha.koepp@geemail.com	Fort Worth	Texas	4613212879746345	62a51f150de543d7352c9ee13147e667	Diners Club / Carte Blanche	32.7925301984939708	-97.4452187989659535
23802	2020-05-08 07:38:16	2020-05-08	Garrett West-Kuhic	garrett.west.kuhic@geemail.com	Waco	Texas	4132804267889	d541aaeb5fa9e0b7b02eb5eaad630fe1	Diners Club / Carte Blanche	31.48637926240675	-97.1223529481459451
23803	2020-05-08 07:45:04	2020-05-08	Emerson Smith-Pouros	emerson.smith.pouros@woohoo.com	Phoenix	Arizona	6011564131589972844	de98efaa93ce6a7946b2adf2e7c4e810	Maestro	33.4744920606192196	-112.057381029466541
23804	2020-05-08 07:58:13	2020-05-08	Dr. Luvenia Keeling PhD	dr.luvenia.keeling.phd@geemail.com	Houston	Texas	4725375186368049	f2e979aa882cc383bc52c90ea87a4ceb	JCB 16 digit	29.7946879996065057	-95.2984421020854313
23805	2020-05-08 07:59:19	2020-05-08	Alberta Schultz	alberta.schultz@geemail.com	Mobile	Alabama	869952936002310292	d5a9c59db7138038a426d23920e8c5d8	Voyager	30.6345368660163118	-88.0193415221430371
23806	2020-05-08 08:07:13	2020-05-08	Saniyah Rohan DDS	saniyah.rohan.dds@geemail.com	Mobile	Alabama	180002053727701234	cc381c891672b21078d8bfdc1ebfad69	American Express	30.5699955668874068	-88.1797761568471827
23807	2020-05-08 08:09:14	2020-05-08	Eathel Turcotte	eathel.turcotte@geemail.com	Fontana	California	869988566608004516	c9f9c675a73d60af06f06de340c54736	VISA 16 digit	34.0201482708249259	-117.54677588914484
23808	2020-05-08 08:10:14	2020-05-08	Jerome Cartwright	jerome.cartwright@woohoo.com	Berkeley	California	3158812343459479582	704709a5fe155b643c68b054c255201d	VISA 16 digit	37.8441776341137839	-122.258051064466372
23809	2020-05-08 08:19:02	2020-05-08	Dr. Bea Green	dr.bea.green@woohoo.com	Pembroke Pines	Florida	3020245253757331	b64fbe8ee111b67be87fb100887fcce7	Discover	25.9642945113163464	-80.3984841370858305
23810	2020-05-08 08:25:38	2020-05-08	Lizzie Bechtelar	lizzie.bechtelar@geemail.com	Sparks	Nevada	676372023072076	98badbd735e18d2f58c955f9fd491a60	Discover	39.5100024630554003	-119.729823025254916
23811	2020-05-08 08:41:16	2020-05-08	Mr. Olie Nikolaus III	mr.olie.nikolaus.iii@geemail.com	Fort Worth	Texas	3158038420353143361	1ac5d70efc10c22b6711b2cac6364644	VISA 16 digit	32.696989667840306	-97.3242490591302527
23812	2020-05-08 08:50:52	2020-05-08	Willis Beier MD	willis.beier.md@geemail.com	Odessa	Texas	869997842220270523	042b6a02ce299a17f7a650d5d66a6f1b	Maestro	31.9115082798071228	-102.419704351496321
23813	2020-05-08 09:04:59	2020-05-08	Allyn Cormier PhD	allyn.cormier.phd@woohoo.com	Portland	Oregon	3158847334432504405	b502bd5eaa3f1b2d57fa149f80c7f9aa	VISA 13 digit	45.61888315741718	-122.679867771267894
23814	2020-05-08 09:10:59	2020-05-08	Mr. Carnell Schmeler IV	mr.carnell.schmeler.iv@geemail.com	Mesa	Arizona	639008412120738	1d8166bda826d9a11cef878e443e237e	Maestro	33.4157777261134186	-111.795630046713725
23815	2020-05-08 09:18:54	2020-05-08	Lonnie Hamill	lonnie.hamill@geemail.com	San Francisco	California	55996219253614731	c1540d73ce1986f1307d5b7191a041c5	Mastercard	37.7859908063857972	-122.450908467039426
23816	2020-05-08 09:21:28	2020-05-08	Lannie Schoen	lannie.schoen@woohoo.com	Los Angeles	California	4267901559018	88d1004c2566a953dc7f727d9dfea539	Mastercard	33.9687904151953717	-118.452554306107757
23817	2020-05-08 09:26:55	2020-05-08	Celestino Bogisich	celestino.bogisich@woohoo.com	Los Angeles	California	4874302882442	37b0b5c43b94a705f0fc05eb5a647b41	JCB 16 digit	34.0419008340086791	-118.395281113729993
23818	2020-05-08 09:45:20	2020-05-08	Eugenio Renner	eugenio.renner@geemail.com	San Francisco	California	3088226683678427916	6b2a7bd0af95919831295ac0ef51b2cc	Discover	37.7634143677939988	-122.425477556214304
23819	2020-05-08 09:48:23	2020-05-08	Sydnie Reichel	sydnie.reichel@woohoo.com	Phoenix	Arizona	3096474916804316812	c32682cf17728016ade6e44d8591d445	JCB 16 digit	33.558317000039672	-112.161803805308793
23820	2020-05-08 10:05:37	2020-05-08	Camryn Reynolds PhD	camryn.reynolds.phd@warmmail.com	Tempe	Arizona	3112993080007883565	b67e2f633588f2711b4a53ec8b5b6fa5	Voyager	33.3793268579445765	-111.852960311717538
23821	2020-05-08 10:11:11	2020-05-08	Jayda Weber	jayda.weber@geemail.com	San Diego	California	3337107374719793870	53fb0a6f930aea1d861be23ff5236b61	JCB 16 digit	32.8468443268045789	-117.10759133788757
23822	2020-05-08 10:13:26	2020-05-08	Bertina Herman-Lind	bertina.herman.lind@geemail.com	Vista	California	4003304632723527	b31c67f77af58dc4c560a31cf2ae7c1c	VISA 16 digit	33.1547888443321028	-117.196589312801521
23823	2020-05-08 10:26:18	2020-05-08	Shyheim Hoeger	shyheim.hoeger@geemail.com	Alexandria	Virginia	6011000587916413145	14eae201cc1b1dbc92961489608200cb	JCB 16 digit	38.9044199633061822	-77.0647087410543179
23824	2020-05-08 10:39:57	2020-05-08	Tyreek Abernathy-Mante	tyreek.abernathy.mante@warmmail.com	Springfield	Illinois	210042922854015901	a33b5b8b10744004ec948e358761a2cf	Mastercard	39.7471663887299584	-89.5835251312706617
23825	2020-05-08 10:53:35	2020-05-08	Lottie Shanahan	lottie.shanahan@woohoo.com	Berkeley	California	6011509145597594026	2828e88e834b79bd3c6ca5e1bbae70c9	Maestro	37.863742038628331	-122.294696299458266
23826	2020-05-08 10:54:02	2020-05-08	Carra Sauer	carra.sauer@warmmail.com	San Francisco	California	4724101098943831	107fb1f3b573f492a04713a2a67c1874	JCB 16 digit	37.7608880536800839	-122.415197282616489
23827	2020-05-08 10:56:25	2020-05-08	Arbie Hagenes	arbie.hagenes@geemail.com	Arlington	Texas	6011934077733491848	aab191a4a140b3f6645d5c91858bfa9f	American Express	32.629524139898642	-97.114841799906273
23828	2020-05-08 11:05:35	2020-05-08	Jule Davis	jule.davis@woohoo.com	Phoenix	Arizona	210069506847074733	b84b6eee9b390160e1d229d51ea04747	American Express	33.5303929542124308	-112.071156021992124
23829	2020-05-08 11:11:51	2020-05-08	Arnetta Cole	arnetta.cole@warmmail.com	Rochester	New York	676345808350818	a8e4736ba6adc827df0acb3f298f81a7	Mastercard	43.0829626129452095	-77.5694060811545683
23830	2020-05-08 11:29:27	2020-05-08	Treyvon Turcotte	treyvon.turcotte@geemail.com	San Francisco	California	54503967034470197	5ee3321857580cd89b2e07d639602af1	VISA 16 digit	37.7817940132240295	-122.470017104318913
23831	2020-05-08 11:34:17	2020-05-08	Aiyanna Jacobs MD	aiyanna.jacobs.md@geemail.com	San Francisco	California	3037218290608117	1e07ba343e4fb4616318f6c82fca300a	Diners Club / Carte Blanche	37.7593330159253426	-122.416746407632147
23832	2020-05-08 11:36:57	2020-05-08	Maverick Swift-Jast	maverick.swift.jast@geemail.com	Peoria	Illinois	6011181208058649484	48a29ebf527164037af5f488f95f5997	VISA 13 digit	40.6802563701625886	-89.6615144769545651
23833	2020-05-08 11:42:22	2020-05-08	Cappie Tillman	cappie.tillman@geemail.com	San Francisco	California	3112501814501539447	ae425a94b9bf8fe0833b91344375242f	American Express	37.7600751049906407	-122.416090094430061
23834	2020-05-08 11:43:47	2020-05-08	Daisie Grimes	daisie.grimes@geemail.com	Chicago	Illinois	3528052077444224716	d50851c44b2233adad8bdae1312f41df	Maestro	41.7841028434991841	-87.710885411783309
23835	2020-05-08 11:44:13	2020-05-08	Ayden Hayes IV	ayden.hayes.iv@geemail.com	New York	New York	676104264090111	91f3038cfa7669fb2e92488f99390723	Voyager	40.6675155316703041	-74.0373087277997257
23836	2020-05-08 12:04:52	2020-05-08	Leroy Jacobs	leroy.jacobs@geemail.com	Houston	Texas	4027838684633219	5df804e062eb9c5fe20fd91fec42a054	VISA 16 digit	29.7228237696070217	-95.3598223755151082
23837	2020-05-08 12:17:51	2020-05-08	Reginal Labadie PhD	reginal.labadie.phd@geemail.com	Saint Paul	Minnesota	4334240404677915	29b70845a0722fcbd0e84b6f8eecc8a5	JCB 16 digit	45.0016444686274966	-93.0813196784149852
23838	2020-05-08 12:34:31	2020-05-08	Abbie Lind	abbie.lind@woohoo.com	Phoenix	Arizona	869963967118662802	8339144148570ec04e347e98fbdc6954	Voyager	33.5184883931119018	-112.147438499417532
23839	2020-05-08 12:35:51	2020-05-08	Mrs. Meghan Konopelski PhD	mrs.meghan.konopelski.phd@geemail.com	Houston	Texas	4088186806605	3f75567fd6e344c31d770415a44d801b	Diners Club / Carte Blanche	29.7514185058031231	-95.4206883481252959
23840	2020-05-08 12:38:48	2020-05-08	Rinda Fadel	rinda.fadel@woohoo.com	Milwaukee	Wisconsin	52520405973021365	dd9fa09565c118d3320e1dbc0f75a4f0	Diners Club / Carte Blanche	43.1372293047226947	-87.9156094241056678
23841	2020-05-08 12:39:08	2020-05-08	Kendall Kshlerin	kendall.kshlerin@woohoo.com	Oakland	California	4609656500116888	5d719e149d76f6ac4e969aacbb9febae	Maestro	37.7944556242632501	-122.304856415817724
23842	2020-05-08 13:08:42	2020-05-08	Clinton Gislason Jr.	clinton.gislason.jr.@warmmail.com	Phoenix	Arizona	3528133255954802328	04fa6c8d275a002f5a40f90f342bd16d	VISA 16 digit	33.5701473071638503	-112.132343889719252
23843	2020-05-08 13:09:51	2020-05-08	Dr. Elvin Wyman II	dr.elvin.wyman.ii@geemail.com	Cincinnati	Ohio	4189705792555	196ad560fa0f409b4fbf9f2109dcf166	Diners Club / Carte Blanche	39.1517476372186124	-84.5751601054139428
23844	2020-05-08 13:17:13	2020-05-08	Collins Kovacek I	collins.kovacek.i@woohoo.com	Springfield	Missouri	4880149065504649	7a3d7046466cdf62fab945f2a06698e2	Discover	37.1232399805177025	-93.2134415922045747
23845	2020-05-08 13:19:17	2020-05-08	Simone Torp	simone.torp@geemail.com	Lubbock	Texas	3096223502149984482	e66b24487628d76251586c26178acf00	JCB 16 digit	33.5727575964801019	-101.801982151987787
23846	2020-05-08 13:32:55	2020-05-08	Darnell Gottlieb	darnell.gottlieb@geemail.com	San Antonio	Texas	676367221449761	44d0e5f5af022e42e7d0cde051ab2e74	Voyager	29.4913793155062933	-98.5859162048272708
23847	2020-05-08 13:43:41	2020-05-08	Keli Lehner-Altenwerth	keli.lehner.altenwerth@woohoo.com	Phoenix	Arizona	4835421715502307	c46fcbc44e27542b4a9665063b12a04a	Diners Club / Carte Blanche	33.5075345078881881	-112.018603899183134
23848	2020-05-08 13:55:59	2020-05-08	Charley O'Kon	charley.o'kon@woohoo.com	Louisville	Kentucky	180017469123907196	17025d05dba2caf6f2e4b168c71c6528	JCB 15 digit	38.1441124337628494	-85.6981148267701371
23849	2020-05-08 14:08:51	2020-05-08	Aurthur Stoltenberg	aurthur.stoltenberg@warmmail.com	San Francisco	California	3439782733715385	eb636e0b8967f1d637de125ba0f911b1	JCB 16 digit	37.746410598585399	-122.408456476806194
23850	2020-05-08 14:09:36	2020-05-08	Tomeka DuBuque	tomeka.dubuque@geemail.com	Worcester	Massachusetts	6011624971191775897	7827669d49c94064d42a3ccc6f6c91b4	JCB 15 digit	42.2959283367898351	-71.8587408147074314
23851	2020-05-08 14:15:37	2020-05-08	Keyon Rippin	keyon.rippin@geemail.com	Santa Maria	California	3528986250482437224	2b5c5651bcd019df46e269252059e4b2	Mastercard	34.9408672935392701	-120.44834414170235
23852	2020-05-08 14:17:31	2020-05-08	Mr. Wyatt Beier II	mr.wyatt.beier.ii@woohoo.com	San Diego	California	869966910613860585	3406558de7e5d89bef59b8ef90671638	VISA 16 digit	32.9143785591769955	-117.213642478492119
23853	2020-05-08 14:20:56	2020-05-08	Drucilla Fritsch MD	drucilla.fritsch.md@woohoo.com	Columbus	Ohio	6011317643638816400	f25f6f18b9560110d4af1066797ab172	VISA 16 digit	39.9322223459880803	-83.0474885654870434
23854	2020-05-08 14:23:15	2020-05-08	Dr. Jessica Nader DDS	dr.jessica.nader.dds@geemail.com	Buffalo	New York	3017014604914303	354fd180ca5ae823d0fc35091bdc79ce	Maestro	42.9082692527398422	-78.8783253865715182
23855	2020-05-08 14:36:56	2020-05-08	Augustus Bins	augustus.bins@geemail.com	Plano	Texas	589396679434959	af0e02a4969dbe7a4f73e27b677c4baa	VISA 16 digit	32.9760137171570236	-96.8357764891065642
23856	2020-05-08 14:44:12	2020-05-08	Alexandrea Kohler PhD	alexandrea.kohler.phd@geemail.com	New York	New York	6011555824065751119	6a07c64bb4584ef71d0954c40e4b2760	Diners Club / Carte Blanche	40.7024141655061413	-74.003124113556737
23857	2020-05-08 14:52:42	2020-05-08	Nunzio Johnson	nunzio.johnson@geemail.com	Gresham	Oregon	3023099737206945	a42553ed561bdcb0e1d2f45311580a0f	Mastercard	45.5347959751218525	-122.375541197860983
23858	2020-05-08 15:13:22	2020-05-08	Stephan Willms	stephan.willms@geemail.com	Houston	Texas	4308457609300	2909b6eeb8bd63b9f6f90c3a4f2d24e2	VISA 16 digit	29.8776009263083324	-95.4891386874966344
23859	2020-05-08 15:16:52	2020-05-08	Lisbeth Lebsack	lisbeth.lebsack@woohoo.com	Escondido	California	6011463035528225531	4267fb59cf0d307719f798194b6dfa1e	Discover	33.1699253202177573	-117.039097290836267
23860	2020-05-08 15:24:33	2020-05-08	Mrs. Daniela Leffler	mrs.daniela.leffler@geemail.com	Pompano Beach	Florida	3700981828488081	530f56519cbaeba1895ea8bfcfb47c91	Maestro	26.3143851842530054	-80.1612421220481366
23861	2020-05-08 15:27:09	2020-05-08	Campbell Strosin-Emard	campbell.strosin.emard@geemail.com	Vancouver	Washington	4202166905077	338b42efe5257d2f17cc7f1656233de8	Discover	45.6525703386940052	-122.520918423735338
23862	2020-05-08 15:43:07	2020-05-08	Acy Stoltenberg	acy.stoltenberg@woohoo.com	San Diego	California	3112263268643991206	e0ada4529a90e07aed959798c440e8d3	American Express	32.8971049564491977	-117.150758254332473
23863	2020-05-08 15:43:35	2020-05-08	Thresa Emmerich	thresa.emmerich@geemail.com	San Antonio	Texas	4437914647445	587e5c01f61ec689820d7e7811579cdf	JCB 15 digit	29.3769302096288669	-98.4584412680774932
23864	2020-05-08 16:02:58	2020-05-08	Hillary Pollich	hillary.pollich@geemail.com	Oklahoma City	Oklahoma	6011739692590440253	5b5dfd470a59069c8eee930b041d9391	JCB 15 digit	35.4439639446701875	-97.5892709643475769
23865	2020-05-08 16:17:58	2020-05-08	Cleon Bernhard DDS	cleon.bernhard.dds@woohoo.com	Mesa	Arizona	4663545103578763	0a4302042e11bae6541e37062851d1f1	Mastercard	33.3211066473886319	-111.678870266990359
23866	2020-05-08 16:43:57	2020-05-08	Darci Cummings	darci.cummings@geemail.com	San Antonio	Texas	3158287511230832172	5d06f51c9712a8b3a98a0cfef0158745	Diners Club / Carte Blanche	29.4920583650540564	-98.5892881579067506
23867	2020-05-08 16:49:20	2020-05-08	Rae Heaney	rae.heaney@geemail.com	Mesa	Arizona	3475909079961852	337aa274f3e8f7dd7088f18b8861141e	VISA 13 digit	33.3434185817051656	-111.756200200819961
23868	2020-05-08 16:55:17	2020-05-08	Samir Grady	samir.grady@woohoo.com	Amarillo	Texas	3112762216432342715	ad153bf28957fa43b33495476e88cfb7	Diners Club / Carte Blanche	35.2255002156529571	-101.918214105847113
23869	2020-05-08 16:55:45	2020-05-08	Tylor Heidenreich	tylor.heidenreich@geemail.com	San Francisco	California	3112750326402422001	4fb9c6fc8ff8670e60227e1c47e18931	VISA 16 digit	37.8032438822745362	-122.434253566561964
23870	2020-05-08 17:01:15	2020-05-08	Fronnie Moen	fronnie.moen@geemail.com	Los Angeles	California	3020615813245706	3867a02c421f6ddcd1c58057dc04890a	Discover	34.002602680852263	-118.350761267588652
23871	2020-05-08 17:03:58	2020-05-08	Mr. Arlyn Bednar III	mr.arlyn.bednar.iii@warmmail.com	Fort Worth	Texas	6011800719464639399	85c675a58341871fd8cd11f1f4ad872e	JCB 16 digit	32.6846666644848867	-97.4422136542674195
23872	2020-05-08 17:08:36	2020-05-08	Gerry Abshire	gerry.abshire@warmmail.com	Austin	Texas	4651509082825052	31a5f065f53e2eb27786adf0b19795f5	Diners Club / Carte Blanche	30.2969587236303823	-97.7357126685563458
23873	2020-05-08 17:12:11	2020-05-08	Braelyn Walker	braelyn.walker@warmmail.com	Milwaukee	Wisconsin	6011073376233495114	3f7741a2ea5f22e50432beca119f7a2d	VISA 16 digit	43.0256363248538207	-87.9362609391201318
23874	2020-05-08 17:15:02	2020-05-08	Darell Koch	darell.koch@geemail.com	Laredo	Texas	502034045467783	c7db884b8ed9a0e7fd056202b7c23a01	JCB 16 digit	27.4647082105461529	-99.543343928596741
23875	2020-05-08 17:17:50	2020-05-08	Mr. Ulysses Lueilwitz	mr.ulysses.lueilwitz@geemail.com	San Antonio	Texas	3112156535647793568	95fd281b6c7274042acb4aa428236729	JCB 16 digit	29.4251386100031453	-98.5841682157780923
23876	2020-05-08 17:29:22	2020-05-08	Miss Judy Shanahan PhD	miss.judy.shanahan.phd@warmmail.com	Fort Worth	Texas	6011239922970294193	d0cc3a60718bbac896afda5039e22091	JCB 16 digit	32.6988755351454046	-97.2989021696437106
23877	2020-05-08 17:29:43	2020-05-08	Christion Shields	christion.shields@geemail.com	Los Angeles	California	4019514851195387	d5cb10af81b76a22b09255cd77a1fa35	VISA 16 digit	34.079798849286135	-118.498332166903836
23878	2020-05-08 17:37:14	2020-05-08	Ethie Bailey	ethie.bailey@geemail.com	Anchorage	Alaska	210047915689957714	a041af385119948071c1542fbdd2db53	JCB 15 digit	61.1933219156909729	-149.374578559178104
23879	2020-05-08 17:46:50	2020-05-08	Kianna Smitham	kianna.smitham@geemail.com	Jacksonville	Florida	55478100828119215	0864d37017c644a0752dbdc237cae0b5	Mastercard	30.2941017951868474	-81.6222335020158454
23880	2020-05-08 17:50:46	2020-05-08	Littleton Powlowski	littleton.powlowski@warmmail.com	San Francisco	California	3041148751288917	308d410dfb98efebea4e5d73f23ab984	JCB 16 digit	37.7819394103921766	-122.396808024415819
23881	2020-05-08 17:51:08	2020-05-08	Antwan Waelchi	antwan.waelchi@geemail.com	San Francisco	California	3700133366160645	7b6da6457037b78ead2d6495584eb3c0	Voyager	37.8142439440311406	-122.41987149952601
23882	2020-05-08 17:51:40	2020-05-08	Danelle Huel	danelle.huel@woohoo.com	Hartford	Connecticut	3787736351831362	681d3b041f02909e7857991c498c9a14	Maestro	41.7425981503460548	-72.7633648723255817
23883	2020-05-08 18:10:57	2020-05-08	Miss Starla Rice MD	miss.starla.rice.md@geemail.com	Baltimore	Maryland	51987333037658749	b9ff329b6988b3516b4be338aeb25d6b	JCB 16 digit	39.2851436249446095	-76.6069373363181967
23884	2020-05-08 18:14:56	2020-05-08	Adlai Rosenbaum	adlai.rosenbaum@warmmail.com	Chicago	Illinois	3726308351353781	3a70936456e64554166c62309c3beb52	VISA 13 digit	41.7562103268060838	-87.5947405954852627
23885	2020-05-08 18:14:58	2020-05-08	Phylicia Romaguera	phylicia.romaguera@geemail.com	New York	New York	3112195452015809872	62448de12cac1032308c882c352edc66	JCB 16 digit	40.6137495586872106	-73.9447235936660263
23886	2020-05-08 18:27:29	2020-05-08	Besse Bailey	besse.bailey@geemail.com	San Francisco	California	3528431472398302364	0f878575b9bea8c231025cfb39f968bd	Maestro	37.7578037581752852	-122.446996099319065
23887	2020-05-08 18:30:00	2020-05-08	Brittnay Muller	brittnay.muller@woohoo.com	Salt Lake City	Utah	4673298835211463	1ca7d50d291a8f9f24bac063eb7024cc	Maestro	40.6915536292042574	-112.000347615726284
23888	2020-05-08 18:56:00	2020-05-08	Brandon Wuckert	brandon.wuckert@geemail.com	Toledo	Ohio	4356978933028661	c9595effd782aabc34ca4e725991d493	Mastercard	41.5751752615611991	-83.5958668405056073
23889	2020-05-08 19:01:50	2020-05-08	Ben Streich	ben.streich@woohoo.com	Lexington	Kentucky	869957400606958050	78bea46479579796ba6bd3cb52f2c0e0	JCB 16 digit	38.0429612826898733	-84.3696168740645049
23890	2020-05-08 19:05:58	2020-05-08	Bose Hirthe-Braun	bose.hirthe.braun@geemail.com	San Francisco	California	55183158776062866	cb7751774ea8de0430b6a6276d0f9e38	American Express	37.7636477195507894	-122.428501912158296
23891	2020-05-08 19:06:32	2020-05-08	Miss Kiara Doyle	miss.kiara.doyle@woohoo.com	Wichita	Kansas	639060942681804	bb3846f634794ac04e6b3ffb284921c7	JCB 16 digit	37.7363412703730177	-97.3219574033018233
23892	2020-05-08 19:11:15	2020-05-08	Mr. Silver Cruickshank	mr.silver.cruickshank@geemail.com	Detroit	Michigan	3011270005434038	00990dc7caec4f68a2e5e542fb22a60b	JCB 16 digit	42.3905298093259333	-83.0033540250387034
23893	2020-05-08 19:22:49	2020-05-08	Miss Philomena Nikolaus MD	miss.philomena.nikolaus.md@geemail.com	Austin	Texas	869908179345758654	cf90e4d6d1003897e66e06fe11cbf210	VISA 16 digit	30.224081585894897	-97.6585076410561896
23894	2020-05-08 19:38:44	2020-05-08	Cloyd Herzog	cloyd.herzog@geemail.com	Akron	Ohio	6011664856129789188	f58fb3182a5b58fd7c4a3b4bca5c3cb3	Maestro	41.1520846654027679	-81.6007865916319162
23895	2020-05-08 20:05:31	2020-05-08	Mr. Maurice Ruecker DVM	mr.maurice.ruecker.dvm@geemail.com	Overland Park	Kansas	180052021132980825	b1fbd3c5e87b00febe405e5496306b1f	JCB 15 digit	38.7903634393923014	-94.7866145547986036
23896	2020-05-08 20:10:27	2020-05-08	Jace Beatty-Lynch	jace.beatty.lynch@geemail.com	San Francisco	California	4646441663421549	220bb9e32d4a24c1f2a5d00373fd7da3	Discover	37.7198104088193986	-122.411714288386307
23897	2020-05-08 20:17:15	2020-05-08	Miss Gaylene Haley PhD	miss.gaylene.haley.phd@geemail.com	Richardson	Texas	869901582484574021	c364799c89c68ce12191f5ea7b7bd073	Discover	32.9427695113468886	-96.7985727804474578
23898	2020-05-08 20:17:28	2020-05-08	Sal Lockman-Kuphal	sal.lockman.kuphal@geemail.com	Washington	District of Columbia	4818130154698	330db69bd0f6561e8345b5cab342102c	JCB 16 digit	38.988660401504859	-77.1049870612777823
23899	2020-05-08 20:30:04	2020-05-08	Darci Farrell PhD	darci.farrell.phd@woohoo.com	Chula Vista	California	3337226118582825988	a48fef049453eda0ccd0fb62759a0e05	Discover	32.6853307274866793	-117.085110888234141
23900	2020-05-08 20:51:45	2020-05-08	Killian Oberbrunner	killian.oberbrunner@warmmail.com	San Angelo	Texas	3784486023502156	626e3eee7ba3c2f45afc0146972d08fa	JCB 15 digit	31.5366452424939716	-100.538865196436646
23901	2020-05-08 20:54:52	2020-05-08	Myles Gislason	myles.gislason@geemail.com	Fort Collins	Colorado	3096575147292033630	dea10aea8d950a4571ca89289aef236a	VISA 16 digit	40.5011377689119456	-105.126127745392921
23902	2020-05-08 21:10:10	2020-05-08	Loney Jones IV	loney.jones.iv@geemail.com	Mesa	Arizona	4665469885174683	b5e48d1e824be12cfaf48af2d4a11af8	Diners Club / Carte Blanche	33.404705611165241	-111.658925245737279
23903	2020-05-08 21:10:18	2020-05-08	Shannen Prohaska	shannen.prohaska@warmmail.com	Berkeley	California	3528719222399876046	1c6e6285a4dd8ea5a0f5eda5690b8549	Mastercard	37.8805336034120899	-122.281347578257495
23904	2020-05-08 21:24:45	2020-05-08	Theodocia Schaefer	theodocia.schaefer@woohoo.com	Nashville	Tennessee	3158965759429530052	2a2d8a15586336a1975491b583a44bed	Mastercard	36.2518751850474601	-86.7016957196779572
23905	2020-05-08 21:28:50	2020-05-08	Ras Armstrong	ras.armstrong@woohoo.com	Baltimore	Maryland	4056789816083498	6ca2e8feb694d4e32c77ae294761b1e9	VISA 13 digit	39.3058963038027258	-76.6726645487379272
23906	2020-05-08 21:48:41	2020-05-08	Brandon Wiegand	brandon.wiegand@geemail.com	San Francisco	California	54596827926086345	d4562e170e6f1288e8d7a8c955fdbe4e	Voyager	37.7555575678150745	-122.428809920091084
23907	2020-05-08 21:50:43	2020-05-08	Latonya Beier	latonya.beier@geemail.com	New York	New York	869920998090669848	08719935dedd86adf570aac2a6ba44ec	JCB 16 digit	40.6298808037061221	-73.9420461338374793
23908	2020-05-08 22:35:04	2020-05-08	Mr. Matt Hessel DDS	mr.matt.hessel.dds@warmmail.com	Riverside	California	4224568498866108	4b64786567b2f6d8f387646db4426d37	Maestro	34.0101463490113574	-117.349204902580752
23909	2020-05-08 22:51:54	2020-05-08	Skylar Conn	skylar.conn@woohoo.com	New York	New York	869934356583700113	5e4ca2f92314bdb646bfd1ba521c4130	VISA 16 digit	40.5668965243957942	-73.8534181006148458
23910	2020-05-08 23:08:35	2020-05-08	Semaj Bartell	semaj.bartell@woohoo.com	New York	New York	4806396862401	eeba93aa5323eaee0f44b370efb731d0	VISA 16 digit	40.7340871605314305	-73.8668908283941477
23911	2020-05-08 23:10:58	2020-05-08	Sannie Stiedemann	sannie.stiedemann@woohoo.com	Fort Worth	Texas	51857995341094113	8188e2acfd3fcf078a5e56ff44344808	Mastercard	32.7147063030451548	-97.3606139090664726
23912	2020-05-08 23:19:37	2020-05-08	Luella Ryan	luella.ryan@warmmail.com	Aurora	Colorado	4085067761164	988a48e448c4d8217d6752fc26342d63	JCB 15 digit	39.7236273802928679	-104.663176805072283
23913	2020-05-08 23:25:47	2020-05-08	Dr. Bethany Lesch	dr.bethany.lesch@geemail.com	New Orleans	Louisiana	53299997637604262	494170cdf969c5218bb22dd9b0ce9eeb	American Express	29.9620610946338637	-89.9151414098478909
23914	2020-05-08 23:31:45	2020-05-08	Dianna Herzog	dianna.herzog@geemail.com	Huntsville	Alabama	630427152685130	2022fc0ff874a2e3e8f0765ce6594bb2	VISA 16 digit	34.603281432973219	-86.6505409888941784
23915	2020-05-08 23:44:24	2020-05-08	Blair Leuschke	blair.leuschke@geemail.com	Lowell	Massachusetts	4256231037894	a8531a78dd75d74996cb639814c5bb9d	JCB 16 digit	42.6409475678447691	-71.3570528514556628
23916	2020-05-08 23:48:08	2020-05-08	Winifred Barton	winifred.barton@geemail.com	San Francisco	California	6011539473119317708	0e61739567514ca3348f8bca8a8ae38f	VISA 16 digit	37.7554610251416349	-122.438654217352109
23917	2020-05-08 23:59:53	2020-05-08	Argie Boehm	argie.boehm@geemail.com	Oakland	California	3088902571204439524	9a97de736f80ac2954f4be0276403665	VISA 16 digit	37.8198256981484136	-122.252024513372703
23918	2020-05-09 00:10:15	2020-05-09	Caesar Ortiz	caesar.ortiz@geemail.com	Berkeley	California	210008958683828876	5c006983c83fd6d64585c10136fbeef5	American Express	37.8598934898161446	-122.27478134900943
23919	2020-05-09 00:34:25	2020-05-09	Wyatt Bernier	wyatt.bernier@geemail.com	Albuquerque	New Mexico	6011157440000787985	b1a246dd811f49e3d44a5c53675b785c	American Express	35.1636229832790832	-106.601831641427808
23920	2020-05-09 00:36:18	2020-05-09	Jake Crooks	jake.crooks@geemail.com	Arlington	Texas	54471850649125307	01856930661d76f79fc44f5793a85de4	Voyager	32.7366205116052171	-97.0385576867058859
23921	2020-05-09 00:42:43	2020-05-09	Jemal Farrell-Ullrich	jemal.farrell.ullrich@woohoo.com	Fayetteville	North Carolina	3013672309493594	d8094d501291439127fc10f9e3a3a795	VISA 16 digit	35.1745091413866717	-78.9812334241941585
23922	2020-05-09 00:44:16	2020-05-09	Shelly Kling	shelly.kling@geemail.com	Fort Wayne	Indiana	3429939901582458	7e7751712bcc4befb35c200ed0922fd0	VISA 16 digit	41.0009799501642576	-85.1109124407391988
23923	2020-05-09 01:10:07	2020-05-09	Ishmael Wisoky	ishmael.wisoky@warmmail.com	Oklahoma City	Oklahoma	869943640844853897	9ba64a1336b8749995ca99388df0b138	VISA 16 digit	35.4217753877308255	-97.5221391899872572
23924	2020-05-09 01:47:18	2020-05-09	Celestia Rosenbaum	celestia.rosenbaum@geemail.com	Tacoma	Washington	180055209653447541	c8ce6a4200b2988ed37732a045373ac5	VISA 13 digit	47.1864817054130157	-122.481684060930462
23925	2020-05-09 01:56:01	2020-05-09	Sonya Yost	sonya.yost@woohoo.com	Philadelphia	Pennsylvania	4308102066872	8dad5f599ba71dcbef8b9441fde4c51f	Discover	40.0564256040804096	-75.1236871481772539
23926	2020-05-09 01:58:50	2020-05-09	Shaneka Kshlerin DDS	shaneka.kshlerin.dds@geemail.com	San Antonio	Texas	4858250399427578	d85a4f70ecc11c2c2045377e022a8c71	JCB 16 digit	29.4535701816972342	-98.4810940646402457
23927	2020-05-09 02:03:27	2020-05-09	Maribeth McDermott	maribeth.mcdermott@warmmail.com	Vallejo	California	180073148152547294	38b003bfa8466e63ad2bc830eb377a99	JCB 15 digit	38.1435270786374829	-122.241536266390227
23928	2020-05-09 02:08:51	2020-05-09	Mr. Grant Brakus	mr.grant.brakus@geemail.com	Chicago	Illinois	55591516365331172	c75ae8c74ff9ed5f1b52ec8ff585f4aa	Diners Club / Carte Blanche	41.9215744785334934	-87.7244028858404619
23929	2020-05-09 02:12:32	2020-05-09	Mr. Talen Mitchell III	mr.talen.mitchell.iii@geemail.com	Toledo	Ohio	4607220235602	1342ce8b29d024fb09e682a62776f3bb	American Express	41.7412240673027881	-83.6612584194965763
23930	2020-05-09 02:14:57	2020-05-09	Alyse Ferry	alyse.ferry@geemail.com	Oakland	California	3005722274918691	443e7b3e19ecaf4eef67dc8e0f355618	Diners Club / Carte Blanche	37.7860291005627147	-122.247933335503447
23931	2020-05-09 02:16:17	2020-05-09	Yandel Ortiz-Sauer	yandel.ortiz.sauer@warmmail.com	San Francisco	California	3158545886878934862	17ea862ed2648b1410a5c0a2ae729377	JCB 16 digit	37.772401254265759	-122.428839097393649
23932	2020-05-09 02:23:46	2020-05-09	Tyreke Emmerich	tyreke.emmerich@woohoo.com	Chicago	Illinois	3088769723988470611	fd5cce0f0ca7d7bfd0b3281cd1b8f035	JCB 16 digit	41.8509618942927588	-87.7790642511129278
23933	2020-05-09 02:25:42	2020-05-09	Orrie Prosacco	orrie.prosacco@woohoo.com	Charlotte	North Carolina	3096769578809360874	cf5c592bf813b5de75da801c64a004cc	Diners Club / Carte Blanche	35.2201965382575963	-80.7431927579399229
23934	2020-05-09 02:30:04	2020-05-09	Brian Rolfson	brian.rolfson@geemail.com	Montgomery	Alabama	4841263185991038	a7eea16b022250a6a3a5d4362d9b179b	Discover	32.357616697943584	-86.1880729095697404
23935	2020-05-09 02:34:16	2020-05-09	Franc Willms	franc.willms@geemail.com	Knoxville	Tennessee	51338682435520745	535a4c4d09b3a4ca78534d9584a97dca	JCB 15 digit	35.9737310713686043	-83.8495620758954345
23936	2020-05-09 02:37:24	2020-05-09	Myrtis Schowalter	myrtis.schowalter@warmmail.com	Clarksville	Tennessee	4339505827237462	f4fcb6c9d6ea5a614cdcf3e4617ab5bb	Discover	36.6589315119791763	-87.3990381491322097
23937	2020-05-09 02:42:38	2020-05-09	Domenick Sanford	domenick.sanford@geemail.com	New York	New York	060442119092072	ddcb7818be32435ad10e6acd040e5b57	JCB 16 digit	40.7244413192141792	-73.9829201325204195
23938	2020-05-09 02:46:22	2020-05-09	Kenan Leffler-Heidenreich	kenan.leffler.heidenreich@geemail.com	San Jose	California	561229274427672	e5764af2da34525852fda3bc708843d1	Diners Club / Carte Blanche	37.2105788128271726	-121.824426993889361
23939	2020-05-09 02:46:53	2020-05-09	Joshua Lindgren	joshua.lindgren@geemail.com	San Francisco	California	6011607436476044816	9731c2642e86a3c32560c7271b651312	VISA 16 digit	37.8170285101843149	-122.412403891073566
23940	2020-05-09 02:53:08	2020-05-09	Clarissa Grimes	clarissa.grimes@warmmail.com	Lexington	Kentucky	54404214157631044	313fcc478edf7f0f9844a0d6f881da51	Maestro	37.942057539044697	-84.4045587716989161
23941	2020-05-09 02:56:39	2020-05-09	Josiephine Veum-Rath	josiephine.veum.rath@warmmail.com	New York	New York	4061343877334318	9d6980796ef7d324d06f3ea6b5696172	VISA 16 digit	40.7335926748104384	-73.9876877167157829
23942	2020-05-09 02:58:25	2020-05-09	Shay Bahringer-Connelly	shay.bahringer.connelly@geemail.com	Paterson	New Jersey	52955494047548946	d4d40e61885a24a39a058ed092c93265	VISA 13 digit	40.8928415482353387	-74.1485088670134616
23943	2020-05-09 02:59:41	2020-05-09	Almon Gislason	almon.gislason@woohoo.com	Phoenix	Arizona	3088487622120341295	3a0847946325bdc22f30c5b27f5320ed	JCB 16 digit	33.5472363466329924	-112.057369742535428
23944	2020-05-09 03:24:46	2020-05-09	Ms. Emery Hintz PhD	ms.emery.hintz.phd@geemail.com	San Francisco	California	502011558688427	955439939e603f6c5477a2fa8c592b4c	Maestro	37.7786325715473552	-122.434115351147597
23945	2020-05-09 03:33:18	2020-05-09	Dr. Myrtle West DVM	dr.myrtle.west.dvm@woohoo.com	San Antonio	Texas	180009868573276723	79a47a42ae0e0cd63ef17a125e557417	VISA 16 digit	29.4944995809882897	-98.59257641353868
23946	2020-05-09 03:35:30	2020-05-09	Laura Renner	laura.renner@geemail.com	San Francisco	California	3158381215089048295	8e2a2bf9b47c4407eb4a1a33601e83ce	Maestro	37.7764420774296354	-122.420971553430334
23947	2020-05-09 03:43:31	2020-05-09	Doctor VonRueden-Blick	doctor.vonrueden.blick@geemail.com	San Francisco	California	53317323082165741	844082b466505c6ccd6119a894dd32d7	Mastercard	37.7728478711915869	-122.413137805666295
23948	2020-05-09 03:43:58	2020-05-09	Emilee Larkin	emilee.larkin@geemail.com	Columbus	Ohio	180056997545436594	a726af3881a15974a101b0bf6cbd019f	Voyager	39.9815429195806402	-83.0206269928488894
23949	2020-05-09 03:48:48	2020-05-09	Cheryle Wolf	cheryle.wolf@geemail.com	Everett	Washington	3337933439719136089	a924b333ea6fbb74f9a2d07f7ed72de4	Maestro	48.0316725035555692	-122.198357632442935
23950	2020-05-09 04:01:30	2020-05-09	Mossie Kuhic	mossie.kuhic@geemail.com	Charleston	South Carolina	3112164603464747073	ede84323178350c11d582e82dea27158	JCB 15 digit	32.8742911770470485	-79.8776097206082198
23951	2020-05-09 04:05:55	2020-05-09	Dr. Dotty Schiller PhD	dr.dotty.schiller.phd@geemail.com	Baltimore	Maryland	4305596599537320	1c19f78a554d7a9d5a250dff1ebc3241	American Express	39.3758509334642426	-76.5530454071257225
23952	2020-05-09 04:28:07	2020-05-09	Dorcas Keebler	dorcas.keebler@geemail.com	Sioux Falls	South Dakota	4582785276890789	a0d2f3146ac1452b7e497ebf058256ea	Discover	43.5698116526093315	-96.6460552875585819
23953	2020-05-09 04:51:39	2020-05-09	Markita Bashirian-Franecki	markita.bashirian.franecki@warmmail.com	Virginia Beach	Virginia	3096155337272814194	c55e5f024017b9c9dc25a949d18a8f36	JCB 16 digit	36.6953398989699764	-76.0043952501516742
23954	2020-05-09 04:51:50	2020-05-09	Dr. Chesley Glover V	dr.chesley.glover.v@geemail.com	Berkeley	California	51511701194695487	1105ae22539475d9cf8c927818f67623	Mastercard	37.8420141693704295	-122.297762012439264
23955	2020-05-09 05:15:58	2020-05-09	Jeffery Mertz V	jeffery.mertz.v@warmmail.com	Los Angeles	California	3337177190504519469	e081b679ce5f5dcff9ff705778d255f4	VISA 16 digit	34.04464662739597	-118.424384045926104
23956	2020-05-09 05:20:06	2020-05-09	Shani Gusikowski	shani.gusikowski@woohoo.com	Omaha	Nebraska	54106411588892283	b751db704bbf9b591e2e4ffe17401d7b	JCB 16 digit	41.290826484016705	-95.9453936271019359
23957	2020-05-09 05:33:02	2020-05-09	Dr. Hans Kerluke	dr.hans.kerluke@geemail.com	Santa Clara	California	3032149990117601	733d77119ad211277b823d2dfeac316e	JCB 16 digit	37.3469072906117887	-121.926496371766177
23958	2020-05-09 05:37:33	2020-05-09	Santos Hodkiewicz	santos.hodkiewicz@woohoo.com	Pasadena	Texas	3403952743183476	fec1fd2bad66ad99203e3c2f0450dc71	Diners Club / Carte Blanche	29.7544909275475895	-95.1535082788154511
23959	2020-05-09 05:42:22	2020-05-09	Inell Ferry	inell.ferry@warmmail.com	Oakland	California	4434299046534768	0cfed5b08ca9b455c1b61b0996d11f41	Maestro	37.8065461256460864	-122.262389810085011
23960	2020-05-09 05:52:19	2020-05-09	Dr. Aydan Wolf V	dr.aydan.wolf.v@geemail.com	Berkeley	California	180050629387355022	c2f6d59e6456743a4e942abd2a00c663	Voyager	37.8841977319827308	-122.293852057492842
23961	2020-05-09 06:08:05	2020-05-09	Mikalah Kuvalis	mikalah.kuvalis@warmmail.com	Wichita	Kansas	180034166393750830	93c4df0df1bd60473db2cae4b5747d37	American Express	37.7642226034186805	-97.2846951123993904
23962	2020-05-09 06:22:23	2020-05-09	Hollie Effertz	hollie.effertz@woohoo.com	North Las Vegas	Nevada	6011503480241848445	6e190c06fb5d0d7f026ce8c93c139566	VISA 13 digit	36.2803295231580734	-115.082307774362718
23963	2020-05-09 06:28:29	2020-05-09	Emerald Bednar	emerald.bednar@geemail.com	San Francisco	California	55844446771851669	aa89274a9d423cbc6a934510cbbd901c	JCB 16 digit	37.7860765598079809	-122.439270156838347
23964	2020-05-09 06:31:49	2020-05-09	Hobson Will-VonRueden	hobson.will.vonrueden@geemail.com	Murfreesboro	Tennessee	210093555996521606	d09c697ef2701fe95402b382c36404af	Mastercard	35.7537556687023539	-86.5035199384056028
23965	2020-05-09 06:32:16	2020-05-09	Maximiliano Bergnaum	maximiliano.bergnaum@warmmail.com	San Francisco	California	869939173298067448	7f3a5df5a9ea4094f429ec15f883532d	Maestro	37.8148924089928826	-122.453084462784773
23966	2020-05-09 06:34:04	2020-05-09	Miss Bernita Ruecker PhD	miss.bernita.ruecker.phd@geemail.com	Newark	New Jersey	639060238154821	85fa047710d07c8d64b3fdf8094a4208	Maestro	40.6396229972511591	-74.2066708458330453
23967	2020-05-09 06:34:34	2020-05-09	Miss Imo Russel	miss.imo.russel@geemail.com	Berkeley	California	869912844322190718	f736d5027f6a9b771dbe88dfd11163b2	VISA 16 digit	37.8709613441114143	-122.292070394731539
23968	2020-05-09 06:35:11	2020-05-09	Michell Will MD	michell.will.md@woohoo.com	Orlando	Florida	589338105514590	e089e87d9a9fa249b7c9a363fb1d77be	JCB 15 digit	28.4583022354435151	-81.3341932367034275
23969	2020-05-09 06:40:33	2020-05-09	Elna Kertzmann-Heathcote	elna.kertzmann.heathcote@geemail.com	Greeley	Colorado	4917018710124	8e67c2d949f53a4a48267856791536d0	JCB 16 digit	40.4685113904133473	-104.670157718130199
23970	2020-05-09 06:47:55	2020-05-09	Almus Moore-Nolan	almus.moore.nolan@geemail.com	New York	New York	630406381744801	8821beb7d040ff97201793f32bab570c	American Express	40.7548171700667581	-73.9229103959526839
23971	2020-05-09 07:02:41	2020-05-09	Rickie Mayert	rickie.mayert@warmmail.com	Hillsboro	Oregon	869951267434295278	db9033a918396a5fa15caefbcd1f35b6	Discover	45.6267541669048384	-123.035017961558694
23972	2020-05-09 07:04:04	2020-05-09	Mrs. Cheryl Carter DVM	mrs.cheryl.carter.dvm@warmmail.com	Lowell	Massachusetts	4921102157507799	90287ee955d7e0f11b288be18139b2ea	VISA 13 digit	42.6572051159441514	-71.251705350248514
23973	2020-05-09 07:08:33	2020-05-09	Helen Lind MD	helen.lind.md@warmmail.com	Omaha	Nebraska	3112275081135502274	330ce68e954c7c52833fe9a59c5417ab	Diners Club / Carte Blanche	41.2623465718381155	-96.0262235880944957
23974	2020-05-09 07:20:06	2020-05-09	Lesa Rowe	lesa.rowe@geemail.com	Topeka	Kansas	4613246981624552	20fc7db7c81af68be4306249801fc184	JCB 15 digit	38.9487107359737195	-95.7697872312448908
23975	2020-05-09 07:37:18	2020-05-09	Mr. Luster Hermiston MD	mr.luster.hermiston.md@warmmail.com	North Charleston	South Carolina	180012881293601893	4730b81c0bbc9eca347e62c67a883aad	JCB 16 digit	33.0014938888300193	-80.0955000395048415
23976	2020-05-09 07:51:43	2020-05-09	Ms. Elia Rolfson DVM	ms.elia.rolfson.dvm@warmmail.com	North Las Vegas	Nevada	3528606352872211530	1807dc6258e3e18528a5d7cbb2783532	Maestro	36.3218876341048613	-115.085731308789562
23977	2020-05-09 07:55:41	2020-05-09	Alethea Doyle	alethea.doyle@geemail.com	Sioux Falls	South Dakota	3158739308090508123	45f4d259da19ccf2b5b19dec6bc7e792	VISA 16 digit	43.6097365560095724	-96.7050749726761154
23978	2020-05-09 07:57:23	2020-05-09	Rosia Kovacek-Bradtke	rosia.kovacek.bradtke@geemail.com	Norman	Oklahoma	4091915134764728	a5123d9d7ac55db7db27b3bfbaa0e8d2	Maestro	35.3392915870569624	-97.4428275919772631
23979	2020-05-09 07:59:28	2020-05-09	Alberta Jast	alberta.jast@geemail.com	San Francisco	California	180029550880477675	a209305cbece872178af76c85e38236a	Mastercard	37.7695979259489931	-122.385741868276554
23980	2020-05-09 07:59:33	2020-05-09	Ardelia Ritchie PhD	ardelia.ritchie.phd@geemail.com	McAllen	Texas	180015333348898410	aa0e0339d84eb30d3acd2073328136ed	VISA 16 digit	26.2961854992739852	-98.3219092955660017
23981	2020-05-09 08:15:10	2020-05-09	Lucio Harris	lucio.harris@warmmail.com	San Francisco	California	3096979246972068643	577ad599618f5a0cda206c7909072398	Maestro	37.8021757239283858	-122.444909500468526
23982	2020-05-09 08:20:56	2020-05-09	Wilbert Terry	wilbert.terry@geemail.com	Oklahoma City	Oklahoma	3528824878263185616	b44c3350d613c33333ff655ede0006f2	VISA 16 digit	35.5148992665488308	-97.4295167378976998
23983	2020-05-09 08:21:49	2020-05-09	Dr. Stone Considine DDS	dr.stone.considine.dds@woohoo.com	Woodbridge	New Jersey	51308247615562549	6246c04fe0489585767bc6ba7e10297b	Maestro	40.4648073025669888	-74.1954703321538886
23984	2020-05-09 08:25:35	2020-05-09	Ms. Gilda Simonis	ms.gilda.simonis@geemail.com	Dallas	Texas	210004287414413897	f851694d3453f8d4cf3d16d419eac4b6	JCB 15 digit	32.874835145919775	-96.6735608927402552
23985	2020-05-09 08:42:26	2020-05-09	Aydan Morissette	aydan.morissette@warmmail.com	Los Angeles	California	4424241817446824	b1ccc1b8ed4b3c43b8fd1460a12c53b5	VISA 16 digit	34.0467837329819787	-118.436878438060347
23986	2020-05-09 08:45:15	2020-05-09	Worley Mueller	worley.mueller@geemail.com	Fremont	California	869949381610117316	d08b22407cd16e94e3186f125f971710	Voyager	37.4408101060595371	-122.033634002878145
23987	2020-05-09 09:02:29	2020-05-09	Dedrick Watsica	dedrick.watsica@geemail.com	Atlanta	Georgia	4146334313419	731f476fee805dc683178ad3cb23972a	Discover	33.6781090489398736	-84.5125705504834741
23988	2020-05-09 09:04:00	2020-05-09	Karri Feil	karri.feil@geemail.com	New York	New York	52700715980739037	31cd275b9da106847cdd7c16a0151019	VISA 13 digit	40.5842315891049807	-73.8429895986232907
23989	2020-05-09 09:06:50	2020-05-09	Tristan Beatty	tristan.beatty@warmmail.com	Miramar	Florida	3702452758048475	84d3c89acc64b060eea3c0297e49521a	American Express	25.8851658435054119	-80.3024188809555142
23990	2020-05-09 09:09:14	2020-05-09	Libby Marks	libby.marks@geemail.com	New York	New York	4676440727623	5a789d17bc4c57141c0ce7baea0828b2	Diners Club / Carte Blanche	40.6067867786381385	-73.8506699234142872
23991	2020-05-09 09:10:18	2020-05-09	Miss Meadow Dietrich	miss.meadow.dietrich@geemail.com	San Francisco	California	3432466721519226	735118783a6b20518faa64d312bd82cb	JCB 16 digit	37.7648853833737874	-122.458855230997884
23992	2020-05-09 09:21:37	2020-05-09	Alfonse Boyle	alfonse.boyle@warmmail.com	Ontario	California	6011131328297172477	076822026baaa3aacc9aa2a75764e02b	VISA 16 digit	33.9972297342173775	-117.676970409658551
23993	2020-05-09 09:31:09	2020-05-09	Kaela Walter-Kessler	kaela.walter.kessler@geemail.com	San Antonio	Texas	6011054516536317407	f4ed2682b59dc6fa6732d4e06fe16ccf	American Express	29.5575440569851544	-98.4784650496043241
23994	2020-05-09 09:49:07	2020-05-09	Jaylen Turcotte-Eichmann	jaylen.turcotte.eichmann@geemail.com	Salt Lake City	Utah	180020238414348468	00e501ca30cb9eae45352eadfc5c1f6d	Diners Club / Carte Blanche	40.8077273807167984	-111.871793449431649
23995	2020-05-09 09:49:35	2020-05-09	Ms. Leone Greenholt	ms.leone.greenholt@geemail.com	Pembroke Pines	Florida	6011380980428745981	29a7c32012fa6a70350f18968b84b4cd	Discover	25.9685021637976163	-80.2691409450858799
23996	2020-05-09 09:51:45	2020-05-09	Roxy Feest	roxy.feest@geemail.com	Plano	Texas	3088165688081427760	a7994a54182d447457c22f97b42af19d	VISA 16 digit	33.1227272464513831	-96.7919040687099113
23997	2020-05-09 09:54:31	2020-05-09	Leonore Champlin	leonore.champlin@woohoo.com	San Francisco	California	3088746963000778058	d006e79aa979ee5dc8db7c43d0d5db05	Discover	37.8101561697308526	-122.44905902705284
23998	2020-05-09 10:05:13	2020-05-09	Luverne Auer	luverne.auer@woohoo.com	Gilbert	Arizona	3456904628731842	9a38369bda458a4c313b36f8b3396e27	VISA 16 digit	33.4093704706404324	-111.710246947886787
23999	2020-05-09 10:07:35	2020-05-09	Hilario Ryan	hilario.ryan@geemail.com	New York	New York	3011498464951198	e7dc29b6afe5c9f867a1995f238e10e9	Voyager	40.6985108430255167	-74.0287986971799228
24000	2020-05-09 10:26:58	2020-05-09	Oline Carter	oline.carter@geemail.com	Berkeley	California	4031738180288001	47d66dd58530d4ccbc4f20391e849197	JCB 16 digit	37.8913542354001365	-122.27024582250128
24001	2020-05-09 10:28:33	2020-05-09	Miss Agatha Davis	miss.agatha.davis@warmmail.com	Philadelphia	Pennsylvania	3088051167649785446	5ef0f9cfacd410331888479034bb91d8	VISA 13 digit	40.0587206224404255	-75.1592136572014624
24002	2020-05-09 10:32:00	2020-05-09	Rudolph Kulas	rudolph.kulas@geemail.com	Los Angeles	California	3088946112404766214	9502a56c9fc9db22593671e03818c738	JCB 16 digit	33.9436577077820871	-118.479364200913523
24003	2020-05-09 11:11:10	2020-05-09	Davin Lockman-Johnson	davin.lockman.johnson@geemail.com	Thousand Oaks	California	180097682512550590	21a13d4fe8f71705b5c193dd5ee6b575	Diners Club / Carte Blanche	34.1700586043104551	-118.951245446261765
24004	2020-05-09 11:14:54	2020-05-09	Jaye Wuckert	jaye.wuckert@geemail.com	Winston–Salem	North Carolina	3455998794613827	f35e01dff70111013828e311fb44f1c3	Discover	36.0500290248308346	-80.2912839814685242
24005	2020-05-09 11:20:00	2020-05-09	Ramona Dach	ramona.dach@woohoo.com	Columbia	Missouri	55424020067389961	f155181fa52209f199e3cfd5bfd34979	American Express	38.9253209724903684	-92.2541764096410049
24006	2020-05-09 11:23:10	2020-05-09	Sammie Dicki	sammie.dicki@warmmail.com	Jackson	Mississippi	4582704232319403	c066ef65e0ca1508761489298c17b323	JCB 15 digit	32.2999414274182186	-90.1276274261504398
24007	2020-05-09 11:24:38	2020-05-09	Daryl Boyer MD	daryl.boyer.md@warmmail.com	El Paso	Texas	639057613239177	b49e70ea513fd55dbb1b9010430c53af	Diners Club / Carte Blanche	31.8780667133923643	-106.525389011854315
24008	2020-05-09 11:29:36	2020-05-09	Levin Kirlin Jr.	levin.kirlin.jr.@warmmail.com	Los Angeles	California	4172987443010715	6e623d9744c34603ebd31a19c2c8815c	JCB 16 digit	34.0024462753307049	-118.44239958003088
24009	2020-05-09 11:34:29	2020-05-09	Aleck Cole	aleck.cole@geemail.com	Fresno	California	3158908585250907667	fdf5a998e6dfeceed42dde699f8bba44	American Express	36.8641904452688962	-119.821414671616267
24010	2020-05-09 11:35:03	2020-05-09	Deegan Brown PhD	deegan.brown.phd@geemail.com	New York	New York	54580351765766675	eb717e06df3194fd1a2e029aa5f41211	JCB 16 digit	40.5876552934516184	-74.0006664671365115
24011	2020-05-09 11:55:08	2020-05-09	Eulalie Hudson	eulalie.hudson@geemail.com	San Francisco	California	210011092593922325	480ce389e18a070a9760f5e61b1cbab4	JCB 16 digit	37.7766483948844609	-122.447805001995889
24012	2020-05-09 11:57:46	2020-05-09	Omar Rempel	omar.rempel@geemail.com	Houston	Texas	3046301346871219	b0f1c2d86549fc58ab79cd227fe214c7	JCB 16 digit	29.8660016879983239	-95.4203147372711413
24013	2020-05-09 12:07:13	2020-05-09	Kaleigh Aufderhar	kaleigh.aufderhar@woohoo.com	New York	New York	869993208239683268	6e78c7eae99957e517cf49e1e03d8206	Discover	40.5958661208152733	-73.8776409613329861
24014	2020-05-09 12:14:07	2020-05-09	Riley Kuhic PhD	riley.kuhic.phd@warmmail.com	Tucson	Arizona	210078696723149896	5ff8aa730362aed0d8d42cdd843223d6	VISA 16 digit	32.2246695627965067	-110.955718984244754
24015	2020-05-09 12:55:22	2020-05-09	Thomasina Strosin	thomasina.strosin@woohoo.com	Kansas City	Missouri	6011286831235772871	e188fd5cd6f0d53dcae51af9793726a8	Maestro	39.0264043103739624	-94.6259992808327155
24016	2020-05-09 12:57:19	2020-05-09	Kamryn Christiansen I	kamryn.christiansen.i@geemail.com	Chicago	Illinois	180019404833296562	99bb2449c459fe90184b0432390ab223	JCB 15 digit	41.880396648107471	-87.7745550437394542
24017	2020-05-09 13:08:14	2020-05-09	Hunter Wuckert	hunter.wuckert@warmmail.com	Dayton	Ohio	3088067601222511797	f047035abba0371282158be08ef9683f	Voyager	39.7939836214087919	-84.2236804816596276
24018	2020-05-09 13:08:51	2020-05-09	Verena Mosciski	verena.mosciski@geemail.com	San Francisco	California	3096143179706477643	527c51e8286cd34427bff5e2e4456847	American Express	37.7858225185372021	-122.44996567282476
24019	2020-05-09 13:13:50	2020-05-09	Miss Bethann Heller MD	miss.bethann.heller.md@geemail.com	New York	New York	3739059638027335	a6b0d7aa271583e58ff028f4de9f2984	VISA 16 digit	40.7616956643983741	-73.9477991467237388
24020	2020-05-09 13:19:41	2020-05-09	Deryl Stamm	deryl.stamm@geemail.com	Tucson	Arizona	6011025012153316910	39e71e1cf599ee4631d21872eb99d00b	Diners Club / Carte Blanche	32.1561707541853181	-110.869909430690484
24021	2020-05-09 13:22:10	2020-05-09	Pearline Thompson	pearline.thompson@woohoo.com	McAllen	Texas	4154289078776526	7bcc344e1aee5dc2d243e5fef1332799	VISA 16 digit	26.1852692886561158	-98.3458657912291585
24022	2020-05-09 13:30:51	2020-05-09	Lonnie Friesen-Harvey	lonnie.friesen.harvey@geemail.com	Stamford	Connecticut	180033736284312428	ad3ce4d2667fde1b7f97bcea6a6a812b	Maestro	41.1308831652510918	-73.6136304307300691
24023	2020-05-09 13:33:37	2020-05-09	Dedric Dickens	dedric.dickens@woohoo.com	San Francisco	California	3088735939317290089	a912e2fe2c9701092747b3cb5b9e0d24	JCB 16 digit	37.789254432526306	-122.423330211610448
24024	2020-05-09 13:40:34	2020-05-09	Dr. Jamey Boyer I	dr.jamey.boyer.i@warmmail.com	McAllen	Texas	6011166829476355468	e61db1f194008f22fac65edf22d8c06a	JCB 16 digit	26.2080677235338833	-98.3420677651498352
24025	2020-05-09 13:42:22	2020-05-09	Sim Kilback-Mraz	sim.kilback.mraz@warmmail.com	Salinas	California	54060618193481716	714c8dea5461c5f8e67f7d8ada978d2d	JCB 15 digit	36.7383305075809332	-121.587433002953233
24026	2020-05-09 13:44:00	2020-05-09	Bethann Grady	bethann.grady@geemail.com	Independence	Missouri	869978776672212372	d7708e522c2e8ef548d189b633319b03	JCB 16 digit	39.0767960337009299	-94.3687983452159784
24027	2020-05-09 13:59:54	2020-05-09	Maebelle Sipes	maebelle.sipes@geemail.com	High Point	North Carolina	3112545574264507852	a30577a4b18ef30b477dfab1c6d807a8	VISA 13 digit	36.0314951590821195	-79.8927061111405408
24028	2020-05-09 14:08:22	2020-05-09	Kenneth Hintz	kenneth.hintz@geemail.com	Oakland	California	3112269530947877447	0a7d8b0e2603fe5faf53c84f8e90091e	JCB 16 digit	37.7894507122540873	-122.298531581171176
24029	2020-05-09 14:18:04	2020-05-09	Dolly Witting	dolly.witting@warmmail.com	Brownsville	Texas	3088144237469668029	085e73c1fd24fa64594ccca1e0dfe588	JCB 15 digit	25.9811699858013512	-97.4324899898562506
24030	2020-05-09 14:22:37	2020-05-09	Karsyn Casper	karsyn.casper@geemail.com	San Francisco	California	4025457807068518	6c63f93d8d12f7c63c40d6057705ed41	Voyager	37.771503858584957	-122.470770969086857
24031	2020-05-09 14:32:53	2020-05-09	Jalisa Wiza	jalisa.wiza@geemail.com	Indianapolis	Indiana	3025305085994968	ef3682d1f9cdbec075ef0494bd8eada6	JCB 16 digit	39.7369348622400267	-86.0623785636123273
24032	2020-05-09 14:39:11	2020-05-09	Lulu Bashirian	lulu.bashirian@geemail.com	Denton	Texas	3088796675252539249	59e7443ca0dfc58d1777f96d4a7203aa	Diners Club / Carte Blanche	33.2272349855661417	-97.1775670013051496
24033	2020-05-09 15:04:40	2020-05-09	Connie Lesch	connie.lesch@geemail.com	New York	New York	630407567362574	78caf9d5f263686195ff4e29f891307a	VISA 16 digit	40.7604828433357156	-73.8919629199791643
24034	2020-05-09 15:05:55	2020-05-09	Rosalee Kuphal	rosalee.kuphal@geemail.com	Oakland	California	4356154301275	42e4677bba18849212719fa95c314edc	Maestro	37.8092839522907056	-122.291513524854764
24035	2020-05-09 15:14:38	2020-05-09	Mrs. Prudence Collier PhD	mrs.prudence.collier.phd@geemail.com	Davenport	Iowa	869940580085819418	cac09a59af11a60004bfb590c39aa7ba	JCB 16 digit	41.6515585528951107	-90.6777263689748878
24036	2020-05-09 15:19:09	2020-05-09	Alwine Daugherty-Goldner	alwine.daugherty.goldner@geemail.com	Philadelphia	Pennsylvania	180049237234934520	946ce585d5b8b997efda8e4abdf99809	Maestro	40.0924439980607445	-75.0884334084477274
24037	2020-05-09 15:31:03	2020-05-09	Jaren Renner-Heller	jaren.renner.heller@geemail.com	Montgomery	Alabama	869989059673011615	04c6a16ea4f05d9ae7b97be8fea83eb3	VISA 16 digit	32.2555550243638436	-86.2610786057230001
24038	2020-05-09 15:33:25	2020-05-09	Adriel Wiegand	adriel.wiegand@warmmail.com	Denver	Colorado	3337887781551470076	71d0936421ec4351c921d84e7798e04a	JCB 16 digit	39.6703951673168689	-104.905845996808637
24039	2020-05-09 15:34:16	2020-05-09	Darvin Schneider	darvin.schneider@geemail.com	Palmdale	California	180072843595332160	1cd8f31e7c84942c41aff24109bf9467	VISA 16 digit	34.517646063104273	-118.055032511986425
24040	2020-05-09 16:14:36	2020-05-09	Cherelle Kunze	cherelle.kunze@warmmail.com	Pasadena	California	4214063139916	1e263e85a6377efc4f06cc5da1458ea6	JCB 16 digit	34.2196576714370408	-118.095057487236716
24041	2020-05-09 16:22:53	2020-05-09	Mr. Estel Pacocha	mr.estel.pacocha@geemail.com	San Francisco	California	3158859581254875132	ca6f1bb7b4af49521ecd1fa18b150fea	JCB 16 digit	37.7458891554761777	-122.447781193198338
24042	2020-05-09 16:25:44	2020-05-09	Clarisa Reichel	clarisa.reichel@warmmail.com	Baltimore	Maryland	4650304918429233	900e8433d89ab9dff4a177be49b2894b	VISA 16 digit	39.2403749377932343	-76.567796509854503
24043	2020-05-09 16:27:14	2020-05-09	Ms. Georgeann Collins DDS	ms.georgeann.collins.dds@geemail.com	Irving	Texas	3798345108017510	e4aeb85c73e303a4d6861c6de9a2cc2f	Discover	32.8803038634311449	-96.8905117996782081
24044	2020-05-09 16:36:10	2020-05-09	Ms. Cornelia Parisian DVM	ms.cornelia.parisian.dvm@woohoo.com	Chicago	Illinois	52672649062413027	45fc206437b7963f799ccec305076a23	Discover	41.8551428262911784	-87.6419179736200675
24045	2020-05-09 16:37:15	2020-05-09	Dola Pacocha-Mitchell	dola.pacocha.mitchell@geemail.com	Jacksonville	Florida	4814252756387158	684e9c55057429ab46ada8503db5288a	VISA 16 digit	30.2490179370675243	-81.5879442864641646
24046	2020-05-09 16:41:56	2020-05-09	Bryan Fay I	bryan.fay.i@geemail.com	El Cajon	California	6011936565080431381	671db410965397cd26e3556fbdc4046b	Discover	32.7977146445315313	-117.000912805571787
24047	2020-05-09 16:43:57	2020-05-09	Dr. Dorian Frami	dr.dorian.frami@geemail.com	Columbus	Ohio	3044137434499121	1c5e7635b82c9ae23fa5135071c9a616	VISA 13 digit	39.9019249048128728	-82.9678573148559906
24048	2020-05-09 16:48:50	2020-05-09	Karter Homenick	karter.homenick@geemail.com	Corona	California	6011784226140932321	63e82f2876d335b70017132426365c0f	JCB 16 digit	33.795286474784838	-117.596072041729471
24049	2020-05-09 17:19:23	2020-05-09	Ava Miller PhD	ava.miller.phd@geemail.com	Baltimore	Maryland	4413455384548241	343daa0a6c3524801a20de8a94ebeb08	VISA 16 digit	39.3368285714182946	-76.6861281875073928
24050	2020-05-09 17:30:11	2020-05-09	Miss Mahalia Windler	miss.mahalia.windler@woohoo.com	Norwalk	California	3158151046100673524	00617a595fb1af66f8f045f6be1e5103	JCB 15 digit	33.9335952265769265	-118.097550224144015
24051	2020-05-09 17:40:35	2020-05-09	Gabrielle Tromp	gabrielle.tromp@warmmail.com	San Jose	California	869914310140279016	3341494f0e940b9560c4d0a30f215dc0	VISA 13 digit	37.3698315346900358	-121.753031268179043
24052	2020-05-09 17:43:35	2020-05-09	Cassius Swaniawski	cassius.swaniawski@geemail.com	Daly City	California	6011229017146962765	3d6c0c3453d4b19ea03f49acfec8b3f4	VISA 13 digit	37.7725528172604683	-122.517667065616706
24053	2020-05-09 17:48:34	2020-05-09	Alfonse Braun DVM	alfonse.braun.dvm@geemail.com	Cleveland	Ohio	4751352224982	97ad2c0a3d209f0b8d1b71dbb372928f	Mastercard	41.577509909993033	-81.7155783274915137
24054	2020-05-09 18:03:06	2020-05-09	Bernardine Deckow MD	bernardine.deckow.md@geemail.com	Anchorage	Alaska	3772019076353245	95f4187c85a3b58225146620992539f1	JCB 16 digit	61.1309290481481753	-149.196432215732699
24055	2020-05-09 18:03:57	2020-05-09	Rustin Mills II	rustin.mills.ii@warmmail.com	Stockton	California	3528095494190325069	3749fc45927a607e9f576ae6a9441859	Mastercard	38.0393127592012306	-121.301530193592612
24056	2020-05-09 18:23:12	2020-05-09	Matie Glover	matie.glover@geemail.com	Minneapolis	Minnesota	3043176072998086	1ac408c6d3a1eb8bd1ed8634cea09377	VISA 13 digit	44.9728318506006133	-93.2973299754589789
24057	2020-05-09 18:29:21	2020-05-09	Miss Juliette Veum	miss.juliette.veum@woohoo.com	Lubbock	Texas	3776673130283289	2e8764d3a8063099a9524285de0a9ccc	VISA 13 digit	33.6003876273095656	-101.878164561130859
24058	2020-05-09 18:33:51	2020-05-09	Loni Lockman	loni.lockman@woohoo.com	Glendale	Arizona	54281072809701674	fffc19e5b25d49eac2f689a0c31f2ae2	Voyager	33.5891841564089049	-112.127825730040286
24059	2020-05-09 18:36:34	2020-05-09	Murl Wiza	murl.wiza@geemail.com	Charlotte	North Carolina	6011779530396207073	50bf3fdb5025e9937a686d3a36521f77	VISA 16 digit	35.2493869632270176	-80.747559091024101
24060	2020-05-09 18:48:35	2020-05-09	Miss Magen Ondricka DDS	miss.magen.ondricka.dds@woohoo.com	Aurora	Colorado	6011949515469522693	733e0841d6bc8fe55e6ac8da346f7300	Diners Club / Carte Blanche	39.6113178616035739	-104.771065342065697
24061	2020-05-09 19:03:00	2020-05-09	Tabetha Kuphal	tabetha.kuphal@geemail.com	Jacksonville	Florida	3004590493877019	30bfaa017a7d97a3e779a7a70023eafb	JCB 16 digit	30.3767666655179127	-81.6576211028344972
24062	2020-05-09 19:26:02	2020-05-09	Simona Tillman	simona.tillman@geemail.com	Los Angeles	California	6011879713455199287	1d18c22971490b59e84728e8ac9813fd	American Express	34.0228387588035304	-118.423551271855075
24063	2020-05-09 19:46:20	2020-05-09	Dian Block	dian.block@geemail.com	Augusta	Georgia	4289316634248407	f3029da9977953cc90d9efd082183312	VISA 13 digit	33.3868648895733031	-82.1496515766546196
24064	2020-05-09 19:55:05	2020-05-09	Zenas Heaney	zenas.heaney@warmmail.com	New York	New York	210074243089406042	c6e9348f3192e9ca463f44ea46cc0039	Maestro	40.6248485316280252	-73.9800343219552161
24065	2020-05-09 19:55:50	2020-05-09	Leesa Schamberger	leesa.schamberger@geemail.com	San Francisco	California	4516155984791581	85a653dfd806b60bf854623cfbfd97a4	VISA 16 digit	37.7953566110070796	-122.426084493122048
24066	2020-05-09 19:56:26	2020-05-09	Jamila Pouros-Deckow	jamila.pouros.deckow@geemail.com	Tempe	Arizona	630451602001938	ef746ba319fb99dc8a0bb5ffbf31f259	JCB 16 digit	33.433848361663145	-111.839023651930688
24067	2020-05-09 20:04:08	2020-05-09	Alois Connelly-Kuvalis	alois.connelly.kuvalis@geemail.com	Los Angeles	California	3337995389206397113	c0fee491de6b08ab43ebf6ca7bb1ba8f	JCB 16 digit	34.043863690491392	-118.497765019116173
24068	2020-05-09 20:11:08	2020-05-09	Markel Padberg	markel.padberg@geemail.com	San Francisco	California	4026953957582851	d3b3bd1db2783b876665da93fb23d57f	JCB 15 digit	37.7955920233625307	-122.423333649348677
24069	2020-05-09 20:13:42	2020-05-09	Butler Schmidt	butler.schmidt@geemail.com	Newark	New Jersey	6011265321263652885	f1525e5fb1e18f968848c4c28983ae65	JCB 16 digit	40.6829351391091976	-74.0927969542540694
24070	2020-05-09 20:14:18	2020-05-09	Collie Wilkinson Jr.	collie.wilkinson.jr.@geemail.com	Berkeley	California	53212759543457845	594c7f4e43ef7fe5edd18ec93ce12b6b	Diners Club / Carte Blanche	37.9003254845397706	-122.219813967352039
24071	2020-05-09 20:20:40	2020-05-09	Daneen Blanda	daneen.blanda@geemail.com	Reno	Nevada	3046760431150773	889618ce7e8e800853965420bca21ff7	American Express	39.6239367403633906	-119.946558563707029
24072	2020-05-09 20:46:40	2020-05-09	Orie Rice-Effertz	orie.rice.effertz@geemail.com	Vista	California	869927799430181541	d432d683b7683b531a00cdd1890bdabf	JCB 16 digit	33.1603019481040562	-117.22020120258108
24073	2020-05-09 20:56:48	2020-05-09	Mr. Lonnie Donnelly III	mr.lonnie.donnelly.iii@geemail.com	Baltimore	Maryland	3337926893137414289	02b4fa5c2e354a8c5bfa3e8ec3b5277e	Diners Club / Carte Blanche	39.3297375391703099	-76.6598371557444409
24074	2020-05-09 21:01:09	2020-05-09	Dr. Windell Larkin	dr.windell.larkin@woohoo.com	Oakland	California	180065954587712043	e31cfb7faeb17d11e2088e89f4d598c4	Mastercard	37.7700983577134792	-122.290155976604566
24075	2020-05-09 21:15:02	2020-05-09	Alberto Schmeler DVM	alberto.schmeler.dvm@geemail.com	Chicago	Illinois	3088154460769710179	1f3440693967afbb0683ece711fbe98e	JCB 16 digit	41.81373949952647	-87.7676913444448275
24076	2020-05-09 21:15:10	2020-05-09	Adrian Wiza	adrian.wiza@geemail.com	Brownsville	Texas	3112408637129887169	3d313a8b23fef00bc87f9f60cb556ecf	Diners Club / Carte Blanche	26.0520012091457822	-97.5305635438021312
24077	2020-05-09 21:18:15	2020-05-09	Franklin Raynor	franklin.raynor@geemail.com	Madison	Wisconsin	3158888051871631495	b2fa4c13e47d6b3536eb2856db974173	American Express	43.1055259121555849	-89.5190892219428065
24078	2020-05-09 21:40:24	2020-05-09	Miss Danica Medhurst MD	miss.danica.medhurst.md@geemail.com	Baltimore	Maryland	869967890810610661	ca3d1627329b5922896167e1539f8ba8	Mastercard	39.369769152346997	-76.6560014244187613
24079	2020-05-09 21:41:17	2020-05-09	Leonora Bosco	leonora.bosco@geemail.com	Sugar Land	Texas	6011855209577500757	536d9d5fe218a92b1ce2b7bd30ad1f80	VISA 16 digit	29.555785719124227	-95.710940285353729
24080	2020-05-09 21:48:35	2020-05-09	Mr. Savon Nader	mr.savon.nader@geemail.com	Athens	Georgia	180056660038834507	f50d0ea104e3f5fe44a280e730f29782	JCB 15 digit	34.0386493003651438	-83.4482686882953999
24081	2020-05-09 22:13:21	2020-05-09	Maribel Emard	maribel.emard@geemail.com	Kansas City	Missouri	53450691787798421	320d189634b2cb8058ff2690ed0e4f7c	VISA 16 digit	39.1095786365050841	-94.630366493131973
24082	2020-05-09 22:14:18	2020-05-09	Esteban Rosenbaum	esteban.rosenbaum@geemail.com	San Francisco	California	3423119700979868	f70c3056b6dbfd8533a6414e0743ecde	VISA 16 digit	37.7746631477527828	-122.399900620683496
24083	2020-05-09 22:14:18	2020-05-09	Mr. Leigh Sanford	mr.leigh.sanford@warmmail.com	Athens	Georgia	3088576672996862058	812ad213459a89e70f08e8627333f835	Discover	34.0423153347525727	-83.3364714058231471
24084	2020-05-09 22:42:17	2020-05-09	Karol Roob	karol.roob@geemail.com	Philadelphia	Pennsylvania	3005099720586046	434ad822db72a0d76c7fc2d6e28601c3	VISA 13 digit	40.0154362903401264	-75.2163215993337388
24085	2020-05-09 22:52:33	2020-05-09	Mr. Glynn Bartoletti	mr.glynn.bartoletti@warmmail.com	New York	New York	210086068604536379	a9b497560d2cee3263fd489301c982db	Diners Club / Carte Blanche	40.6083391295503802	-73.8896567733388423
24086	2020-05-09 22:56:19	2020-05-09	Hjalmar Dibbert	hjalmar.dibbert@warmmail.com	Las Vegas	Nevada	51127678651314982	fa4dd9f77bd30e51a82655b67d68956d	Voyager	36.1635493868596853	-115.332269719450167
24087	2020-05-09 23:00:59	2020-05-09	Mr. Lovie Koepp	mr.lovie.koepp@geemail.com	Gilbert	Arizona	503855817522059	e458cf1d6efb0959455147dfa715787b	Diners Club / Carte Blanche	33.3072243258237819	-111.714404716682054
24088	2020-05-09 23:08:09	2020-05-09	Damond Shanahan-O'Conner	damond.shanahan.o'conner@geemail.com	Phoenix	Arizona	55740113830638652	1fb292038db6d91e8017bfce703f6b48	Maestro	33.5558955698207058	-111.991412369387604
24089	2020-05-09 23:21:31	2020-05-09	Bo Willms	bo.willms@warmmail.com	New York	New York	210064462781232876	cffaaea5f9812bf48ad7096b9a92d592	Mastercard	40.6278331628292761	-74.001593722392613
24090	2020-05-09 23:23:54	2020-05-09	Bolden Nicolas-Kuhn	bolden.nicolas.kuhn@warmmail.com	Milwaukee	Wisconsin	6011169034701057594	1f9396fe666d97668db2271f96c79f2b	JCB 15 digit	43.0495021957989792	-88.0525577302191493
24091	2020-05-09 23:25:38	2020-05-09	Elaina Homenick	elaina.homenick@geemail.com	San Francisco	California	53522778307708123	1dede2a02eb82ac43e8d9f41cbf7c033	VISA 13 digit	37.7823176346591794	-122.436207326085437
24092	2020-05-09 23:29:54	2020-05-09	Isabella Haley-Mann	isabella.haley.mann@geemail.com	Las Vegas	Nevada	3448966196488841	0b2e8443b893a9b45c9edb668b673f54	American Express	36.2265712042905363	-115.186481780346853
24093	2020-05-09 23:40:38	2020-05-09	Dr. Gino Bayer	dr.gino.bayer@woohoo.com	San Francisco	California	3417356960504147	2796e726436c01280f95c3461bc8fb3f	American Express	37.7683933169790365	-122.440125217738682
24094	2020-05-10 00:19:04	2020-05-10	Lila Kreiger DDS	lila.kreiger.dds@woohoo.com	Riverside	California	676382844931921	2b0e6cc322972224c560e6f9f4fa4f83	American Express	34.0181072067417176	-117.300459972533204
24095	2020-05-10 00:41:06	2020-05-10	Aurora Prohaska PhD	aurora.prohaska.phd@geemail.com	Santa Clarita	California	3726340463276147	6a639ad904b51881cf2bd3bf3b8fca14	VISA 13 digit	34.3045246780123563	-118.410395069476962
24096	2020-05-10 00:54:22	2020-05-10	Louis Feil	louis.feil@geemail.com	Hollywood	Florida	210022920335401066	834b0527b613ad2a1404ceb4f6af2eda	Diners Club / Carte Blanche	25.9811088644843551	-80.162234548321365
24097	2020-05-10 01:25:37	2020-05-10	Pearla Zemlak	pearla.zemlak@geemail.com	Minneapolis	Minnesota	210053072726123503	8be5f2959bf49ab13433697f4d02d2a3	VISA 13 digit	44.9286438332024929	-93.28028686351999
24098	2020-05-10 01:25:55	2020-05-10	Nunzio Stamm	nunzio.stamm@woohoo.com	Phoenix	Arizona	210012444450882846	b278c34146bfc3674d4881a875385c06	VISA 13 digit	33.5324093123830878	-112.119015429906923
24099	2020-05-10 01:31:44	2020-05-10	Sydney Gusikowski	sydney.gusikowski@woohoo.com	San Francisco	California	210077410590683255	600dde3654c5ba6cf6d3c149e9a31499	VISA 13 digit	37.7489411048320207	-122.440512773826953
24100	2020-05-10 01:33:36	2020-05-10	Denzil McGlynn Jr.	denzil.mcglynn.jr.@geemail.com	St. Louis	Missouri	51553737373696119	a75fdfa08b50b902f9ac50582682d5a0	Discover	38.6482160980038358	-90.188794905087363
24101	2020-05-10 01:34:01	2020-05-10	Christy Emmerich	christy.emmerich@woohoo.com	Warren	Michigan	4561594290455	18c4386c26d4a97b5da1bfb55bfc2688	Discover	42.57297259136066	-83.08219420779497
24102	2020-05-10 01:51:15	2020-05-10	Horatio Carroll-Ledner	horatio.carroll.ledner@geemail.com	Oakland	California	3112488002956982380	e3af1069cc6127a5c617a5dd422a1ee7	Discover	37.8111542502196869	-122.283486548029998
24103	2020-05-10 01:55:46	2020-05-10	Mr. Arden Baumbach	mr.arden.baumbach@woohoo.com	Las Vegas	Nevada	210015581781103926	a3144033ffbba5bc66525913725f0bd3	JCB 16 digit	36.2446578426852781	-115.312680915950239
24104	2020-05-10 01:57:42	2020-05-10	Mallie Trantow	mallie.trantow@geemail.com	Lowell	Massachusetts	180071388812616483	899923fec31a44c852d9ec881527811d	VISA 16 digit	42.7267832466736479	-71.2896862579848687
24105	2020-05-10 02:06:23	2020-05-10	Mylee Treutel	mylee.treutel@warmmail.com	San Francisco	California	3794516874924626	52eb4e2ce6db038ffbe184a5cb71e394	VISA 13 digit	37.7748457124528443	-122.436370460955317
24106	2020-05-10 02:17:23	2020-05-10	Greyson Dibbert	greyson.dibbert@geemail.com	Pittsburgh	Pennsylvania	869939926430958588	e2808f9290b90ac569a487a22cfd9f36	VISA 13 digit	40.3727416726715873	-80.0413140324115773
24107	2020-05-10 02:18:15	2020-05-10	Xzavier Keeling	xzavier.keeling@geemail.com	Baltimore	Maryland	4943459942679	42837bef13d3f600165319c5a326f78a	Maestro	39.3826643631793516	-76.5611237823981838
24108	2020-05-10 02:19:09	2020-05-10	Mrs. Cinda Muller MD	mrs.cinda.muller.md@geemail.com	San Francisco	California	4050237900955375	6cd2486e4b6acfbfeb8539ce952b9cdc	VISA 13 digit	37.7980527176675736	-122.434842575733683
24109	2020-05-10 02:19:31	2020-05-10	Blanca Feil	blanca.feil@woohoo.com	Santa Rosa	California	3088222304839107222	9bb8a69af149de66de27562df49535e8	VISA 16 digit	38.4238513725467072	-122.69649202649147
24110	2020-05-10 02:20:06	2020-05-10	Fannie Funk	fannie.funk@geemail.com	San Francisco	California	3022962351482798	477603f10331e698e1114af881d29b6c	VISA 16 digit	37.7921864146866184	-122.386169459384433
24111	2020-05-10 02:25:20	2020-05-10	Miss Jewel Harris	miss.jewel.harris@geemail.com	Philadelphia	Pennsylvania	54799726960005218	518acf2b93d3a1c1e5ced53fc56805b7	Discover	39.9989311899483226	-75.1503213805045931
24112	2020-05-10 02:34:28	2020-05-10	Dr. Elenore Rogahn DVM	dr.elenore.rogahn.dvm@geemail.com	San Antonio	Texas	3044286968077918	036e80ab00f242d7e6ade0e67f6fd2c5	Mastercard	29.5201844765409831	-98.4289669474422908
24113	2020-05-10 02:59:43	2020-05-10	Sister Watsica	sister.watsica@geemail.com	Clearwater	Florida	3499725411745627	d4c3ffd81ae1ac5144c6c330b9ab551f	Mastercard	28.0615895865611726	-82.7854721921760586
24114	2020-05-10 03:12:24	2020-05-10	Manie Batz	manie.batz@geemail.com	New York	New York	3088399885739688052	b2a77afb2e5a9ebf4671299f0de66e3b	JCB 16 digit	40.6166184102408607	-74.000647333766139
24115	2020-05-10 03:15:45	2020-05-10	Mina Okuneva	mina.okuneva@woohoo.com	Boston	Massachusetts	676145888039646	7de5fd6fde17c969bcc5464fcd3abde1	Mastercard	42.3171810491178206	-71.0550512949422028
24116	2020-05-10 03:29:33	2020-05-10	Mr. Drury Lowe	mr.drury.lowe@geemail.com	San Francisco	California	6011722683066328410	bbfc0e8c0a741a66003a88bbd4338f83	Diners Club / Carte Blanche	37.7825300714021637	-122.458898687100074
24117	2020-05-10 03:35:22	2020-05-10	Cicero Lowe	cicero.lowe@woohoo.com	Bellevue	Washington	52061361451157285	ba72b232e1bcd9cf2f0b55fa87dca8e6	Voyager	47.5102658657074031	-122.174107875028625
24118	2020-05-10 03:39:16	2020-05-10	Marrion Blick	marrion.blick@geemail.com	Warren	Michigan	3036105167797241	a8ed5e6336b42cc2d45d67db91b1b0b9	Voyager	42.5306682744990994	-82.9795847235247521
24119	2020-05-10 03:41:09	2020-05-10	Brogan Schmeler	brogan.schmeler@geemail.com	Chattanooga	Tennessee	4921268290660611	d8bdac55f649db6c671c060420c29819	Voyager	35.0415742760840843	-85.2025655136272348
24120	2020-05-10 03:45:48	2020-05-10	Delbert Ondricka	delbert.ondricka@geemail.com	Mesquite	Texas	4952622495911	2084f65896aa1bcd237f8a2871bd36b5	Discover	32.7318737239852595	-96.5331981538992494
24121	2020-05-10 03:54:32	2020-05-10	Darren Wuckert-Lesch	darren.wuckert.lesch@warmmail.com	Lincoln	Nebraska	060473408180773	8ae7c16c8fd65c32b723bcd40e616ab9	VISA 16 digit	40.8311241560168554	-96.711074583667525
24122	2020-05-10 04:02:57	2020-05-10	Lorine Reichert-Hintz	lorine.reichert.hintz@woohoo.com	Berkeley	California	4331519635535	872955c3f27a878684a273333a233c2d	VISA 16 digit	37.8861603356642007	-122.306302634874342
24123	2020-05-10 04:54:21	2020-05-10	Dyllan Halvorson V	dyllan.halvorson.v@woohoo.com	Hartford	Connecticut	4867730082999	7d0566c292e5df35f5e27521ca5498db	VISA 16 digit	41.7623420892298256	-72.5843194260153979
24124	2020-05-10 04:56:25	2020-05-10	Arden Daniel	arden.daniel@woohoo.com	Saint Paul	Minnesota	51888571966425289	fe029d4eb5ecf340f52e8e2a84d832b6	Diners Club / Carte Blanche	44.9312671660386016	-93.0529274555653387
24125	2020-05-10 05:14:56	2020-05-10	Primus Effertz Jr.	primus.effertz.jr.@warmmail.com	Oceanside	California	4482656265311	61020965655444ec6e37a087aae1103b	JCB 16 digit	33.2090111962873493	-117.239332982533426
24126	2020-05-10 05:21:37	2020-05-10	Oline Bergstrom	oline.bergstrom@geemail.com	Allen	Texas	3724744236045113	51af25e5a24a59ba0686cc62ddd852cc	American Express	33.0054009643409358	-96.5724567455187497
24127	2020-05-10 05:29:28	2020-05-10	Karim Flatley-Prosacco	karim.flatley.prosacco@geemail.com	New York	New York	3096380805942045933	a07055168851af10cbf83c8880895c7a	Mastercard	40.6773316093478314	-73.8943585774291307
24128	2020-05-10 05:36:51	2020-05-10	Florie Kassulke	florie.kassulke@warmmail.com	Memphis	Tennessee	3470541174428852	5595459b467c818fe2dd058e90dadfdf	Maestro	35.1246119246885229	-90.0718018474779996
24129	2020-05-10 05:43:47	2020-05-10	Katherine Schuppe-Kutch	katherine.schuppe.kutch@geemail.com	San Francisco	California	6011954626601093105	faa1fbb3b752563ddba6453b2e213d87	Voyager	37.7622622844815439	-122.453929447900805
24130	2020-05-10 05:46:19	2020-05-10	Antone Schmeler	antone.schmeler@geemail.com	Killeen	Texas	180052909926675843	73e4e56d27be217edadbf28e858ef28a	Diners Club / Carte Blanche	31.1249827231977143	-97.7714068261608418
24131	2020-05-10 05:53:06	2020-05-10	Hildegarde Mosciski	hildegarde.mosciski@geemail.com	Escondido	California	180071215028621447	c416caf1b47f3b940e281689f4ddf2cc	Mastercard	33.119784384196997	-117.033731261758135
24132	2020-05-10 05:55:59	2020-05-10	Marissa Roob DVM	marissa.roob.dvm@geemail.com	Cincinnati	Ohio	4283047063203508	0c23f7b779a1674f861cca2692eae611	VISA 13 digit	39.2020137634359287	-84.4984538511644985
24133	2020-05-10 05:58:09	2020-05-10	Landen Cronin IV	landen.cronin.iv@woohoo.com	Seattle	Washington	676352127768514	1f0ede7690de2d626bead03135839838	Diners Club / Carte Blanche	47.6291186231579644	-122.368556400566916
24134	2020-05-10 05:58:32	2020-05-10	Seaborn Johns-Treutel	seaborn.johns.treutel@geemail.com	San Francisco	California	3088160157918090881	9b32188bfe0879460e384712a4207e46	American Express	37.7821485405418755	-122.446957547870426
24135	2020-05-10 06:11:44	2020-05-10	Dr. Katheryn Mohr	dr.katheryn.mohr@geemail.com	Miramar	Florida	869994779226724553	c05cb4061ecf546c0a0eb142bc56874b	JCB 16 digit	25.8892772486880425	-80.2620197667732924
24136	2020-05-10 06:59:07	2020-05-10	Dr. Wade Lubowitz	dr.wade.lubowitz@geemail.com	Indianapolis	Indiana	3112986133223879864	9d1f2753419b08bbbdb170a3d643fc6b	VISA 16 digit	39.8011283070787769	-86.0807894149065049
24137	2020-05-10 07:07:17	2020-05-10	Dr. Anice Dibbert DVM	dr.anice.dibbert.dvm@geemail.com	New York	New York	3158226732522723267	e7bbd557467a030bdabcf69c1cb4fe02	VISA 16 digit	40.6759506511259801	-73.8793550372950705
24138	2020-05-10 07:21:43	2020-05-10	Luka Kutch	luka.kutch@geemail.com	Fresno	California	676377838683371	5febbe3662c6bac62456bf7a6625d2f5	VISA 16 digit	36.7964725366666912	-119.697345772768941
24139	2020-05-10 07:21:44	2020-05-10	Roosevelt Satterfield	roosevelt.satterfield@geemail.com	Naperville	Illinois	54348050319563710	f2e55f8b65c4968fb5a3044185f03eef	VISA 16 digit	41.7631946793671744	-88.0805603271704172
24140	2020-05-10 07:22:16	2020-05-10	Leif Von	leif.von@geemail.com	New York	New York	675968953616585	a3389ea062d2ae3f9cb2300fd5c01c94	American Express	40.7082245703544459	-74.021372512577841
24141	2020-05-10 07:22:38	2020-05-10	Liddie Jenkins DDS	liddie.jenkins.dds@geemail.com	New York	New York	52270448881427235	fc0bba16e6446d65305c86f94369033d	VISA 16 digit	40.6567266760617514	-74.0094872143946532
24142	2020-05-10 07:28:41	2020-05-10	Bascom Rath	bascom.rath@geemail.com	Charlotte	North Carolina	4649522668940	240a39095eb40d1c66e5ed23320a2b78	JCB 15 digit	35.2863331357736101	-80.8039787664022384
24143	2020-05-10 07:30:25	2020-05-10	Mr. Torrey Barton DVM	mr.torrey.barton.dvm@warmmail.com	San Francisco	California	630490376265188	4075aea7ade082ef8ab1248192f97789	Maestro	37.7652228965044756	-122.401487795900067
24144	2020-05-10 07:46:32	2020-05-10	Dane Jacobi	dane.jacobi@geemail.com	Saint Paul	Minnesota	3096312106281365419	4b3474742f2507411523783d8a0c7e59	American Express	44.9489273179262909	-93.1201893571097372
24145	2020-05-10 07:46:54	2020-05-10	Posey Sawayn	posey.sawayn@geemail.com	Tempe	Arizona	869973147201575181	df4750fe613ecac92c2c623944d3b1dd	VISA 13 digit	33.4284157698895754	-111.939852116911851
24146	2020-05-10 07:53:26	2020-05-10	Claudia Friesen DVM	claudia.friesen.dvm@warmmail.com	Phoenix	Arizona	3405425542786821	3a69eb06a81d32c23cbb966eec56eded	Diners Club / Carte Blanche	33.5026016791749797	-111.99248015288488
24147	2020-05-10 08:06:35	2020-05-10	London Connelly	london.connelly@geemail.com	New York	New York	4342172713554768	02d4afc8d8c88f6c2f564122ffcf6a48	Maestro	40.7631352081652736	-73.8576316224772427
24148	2020-05-10 08:19:13	2020-05-10	Lem Lindgren	lem.lindgren@geemail.com	Seattle	Washington	3037716959370861	1c4a4d732fd222ffad0ca65bb5729734	VISA 16 digit	47.538193705484268	-122.333469604879241
24149	2020-05-10 08:20:25	2020-05-10	Doll Kertzmann	doll.kertzmann@geemail.com	Philadelphia	Pennsylvania	180066731371051773	d7fcc335a2dea4d26dd52484b1b02df9	Diners Club / Carte Blanche	40.0100402403116249	-75.1962073684569532
24150	2020-05-10 08:32:15	2020-05-10	Son Hegmann DDS	son.hegmann.dds@geemail.com	Springfield	Missouri	6011958074782050519	544d2b74ae2b36ba6bfd9da53e68bc81	Discover	37.1380207164872473	-93.322063425957424
24151	2020-05-10 08:33:07	2020-05-10	Fawn Spencer	fawn.spencer@geemail.com	Jacksonville	Florida	3096550382185583909	1ae999213b2256872747b4e407d92ad6	Diners Club / Carte Blanche	30.3057666688743979	-81.6062631407830992
24152	2020-05-10 08:38:04	2020-05-10	Mr. Hosteen Schuster	mr.hosteen.schuster@geemail.com	Cedar Rapids	Iowa	4123943976744360	89a243bc882721f3f139cdbdabde51bf	JCB 16 digit	41.9581294316407281	-91.7402132994096746
24153	2020-05-10 08:41:30	2020-05-10	Mr. Randall Morar III	mr.randall.morar.iii@geemail.com	San Francisco	California	3046817134476481	1af2a5b923403e56f4ab87d583c93ad4	Diners Club / Carte Blanche	37.7640066276806152	-122.448547963613564
24154	2020-05-10 08:51:16	2020-05-10	Seldon Turner-Goyette	seldon.turner.goyette@geemail.com	Thousand Oaks	California	561259790933127	2903587903dcf83cd7472bc5979152a2	Mastercard	34.2015767114043214	-118.945506815790012
24155	2020-05-10 09:08:34	2020-05-10	Obed Jacobi	obed.jacobi@geemail.com	Chicago	Illinois	3112491932317661585	27424036a60483113a19f4b4485977a0	JCB 16 digit	41.830954067625477	-87.7135543544806495
24156	2020-05-10 09:13:44	2020-05-10	Mr. Adrien Frami IV	mr.adrien.frami.iv@geemail.com	San Francisco	California	180000951483630442	61815cda5d5677b6f7559c0adbe3b71a	American Express	37.7572314221551864	-122.453990973757385
24157	2020-05-10 09:17:48	2020-05-10	Miss Madie Hermiston	miss.madie.hermiston@geemail.com	Los Angeles	California	6011652157551995896	b4e9fc1d2a1ede3e17752fe41b596113	VISA 16 digit	33.9934140586160112	-118.369593089399103
24158	2020-05-10 09:43:06	2020-05-10	Pearla Zieme-Heathcote	pearla.zieme.heathcote@geemail.com	Fresno	California	6011954851678717978	8c5d8519fb1df059dabca1a7dde7a95a	VISA 16 digit	36.8407269587147965	-119.861700166120755
24159	2020-05-10 09:51:23	2020-05-10	Bambi Wiegand	bambi.wiegand@geemail.com	Dallas	Texas	3769445885800065	64b9c5db69a83553c658bfda68918bb5	JCB 16 digit	32.8773361339971473	-96.7514254576954897
24160	2020-05-10 10:08:40	2020-05-10	Dr. Polly Huels DVM	dr.polly.huels.dvm@woohoo.com	Mesquite	Texas	3088787186046836306	144362bc9a1b1d005b81929837c5c6d6	Diners Club / Carte Blanche	32.683520945561682	-96.64294078943432
24161	2020-05-10 10:09:13	2020-05-10	Ezequiel Jacobi MD	ezequiel.jacobi.md@geemail.com	Philadelphia	Pennsylvania	4289455294003809	5e550f1b620380b057a8c9e906fb347b	American Express	39.9960888454649606	-75.1599717221122319
24162	2020-05-10 10:11:31	2020-05-10	Tamisha Hane DVM	tamisha.hane.dvm@geemail.com	San Antonio	Texas	6011730783110603477	1b4f7fd9bfca88959d50a7c211d9ec0a	Mastercard	29.4658289011172947	-98.5433578219566471
24163	2020-05-10 10:17:48	2020-05-10	Salome Parisian	salome.parisian@geemail.com	Riverside	California	6011348903359275225	b0765595f4e3f56e536b1e2988234db0	VISA 16 digit	33.8796795644745217	-117.457371613100904
24164	2020-05-10 10:22:39	2020-05-10	Alissa Eichmann	alissa.eichmann@geemail.com	Alexandria	Virginia	6011770500696788170	0522d919691d301ada65c5ee4b1c9dca	JCB 16 digit	38.843605622101947	-77.1202170549411363
24165	2020-05-10 10:23:52	2020-05-10	Kisha Cormier DDS	kisha.cormier.dds@woohoo.com	New York	New York	869957104373321712	43b69ba3d724c734c0abd893f9e6952c	Voyager	40.6544745169337816	-73.9936087899271371
24166	2020-05-10 10:36:22	2020-05-10	Nestor Kautzer	nestor.kautzer@geemail.com	Tulsa	Oklahoma	210044798868134146	52c84df8bd3f37c3784dfb72e933f78f	JCB 15 digit	36.0693751220960124	-95.8057857623279006
24167	2020-05-10 10:40:54	2020-05-10	Tal Hirthe	tal.hirthe@geemail.com	Oakland	California	3096545988700938408	669f629a52722746649f8dffcb93e13b	VISA 16 digit	37.7711204862611467	-122.292752066282503
24168	2020-05-10 10:43:46	2020-05-10	Dann Hoeger	dann.hoeger@geemail.com	New York	New York	4440726979934021	23ef50d66810354953bebbb1b8ff504c	JCB 16 digit	40.6123568332977598	-73.909209323850277
24169	2020-05-10 10:44:23	2020-05-10	Simpson Smitham	simpson.smitham@geemail.com	Dallas	Texas	869954213634304939	b57f825d6a8372b00f03c118706bcb3d	Discover	32.7989167407892666	-96.7256020649299018
24170	2020-05-10 10:46:56	2020-05-10	Barb Hand	barb.hand@geemail.com	Oakland	California	210094235326815767	24c04515bc4b65f6eff13b9ac6be786d	JCB 16 digit	37.839258835024502	-122.266428458595996
24171	2020-05-10 10:48:41	2020-05-10	Farrell Bins V	farrell.bins.v@warmmail.com	Tempe	Arizona	210010847829722968	d65c56afdf4cf2529e91376d10b03dbf	VISA 16 digit	33.3348564321562648	-111.970333603819086
24172	2020-05-10 10:49:43	2020-05-10	Jayne Stroman	jayne.stroman@geemail.com	Austin	Texas	3158852308984380218	c862d293b6331518d65e4eecceb759b6	JCB 15 digit	30.2675595016345369	-97.8368861339293403
24173	2020-05-10 10:49:44	2020-05-10	Lon Gleason	lon.gleason@woohoo.com	Atlanta	Georgia	3441944252795539	800b7bf0311552fb80225bf2a1d5baf2	American Express	33.6741799065187593	-84.419066283483815
24174	2020-05-10 10:56:16	2020-05-10	Lockie Frami	lockie.frami@geemail.com	Des Moines	Iowa	4835500319583878	23a15cce634ba14ce71b415b55ccf6c3	American Express	41.635669817796348	-93.6834876451220424
24175	2020-05-10 11:07:15	2020-05-10	Dr. Rhett Boehm	dr.rhett.boehm@geemail.com	Chicago	Illinois	4914705079699	f29bf6ff8707f565db316fd3bd9cec08	JCB 15 digit	41.8706580874811891	-87.6616551044892418
24176	2020-05-10 11:20:16	2020-05-10	Hoy Braun	hoy.braun@geemail.com	New York	New York	3471554960607166	b9931c1863d5c50eddd412386e77ecbf	VISA 16 digit	40.7281945389919002	-73.8916438686091368
24177	2020-05-10 11:36:19	2020-05-10	Tobias Dickens	tobias.dickens@warmmail.com	Charlotte	North Carolina	3002276933724423	32535ecc7eca9b9112afa1334c5a9483	VISA 16 digit	35.1704159119885418	-80.9235092131830811
24178	2020-05-10 11:36:34	2020-05-10	Ina Hammes	ina.hammes@warmmail.com	Green Bay	Wisconsin	869963054043448761	17bcca1ec6bc25a6112d434015c5bea7	Maestro	44.5901943096954341	-87.9573821125838862
24179	2020-05-10 11:41:42	2020-05-10	Omie Howell	omie.howell@woohoo.com	Kansas City	Kansas	3746039215850391	5f8693c5025e91c89a2a00d3f283bc10	American Express	39.1314735783636607	-94.7067132893886452
24180	2020-05-10 11:45:08	2020-05-10	Susana Murazik	susana.murazik@geemail.com	San Antonio	Texas	3112812613227123179	19bc4b647dab5cc666ead29c8a21b1ff	Discover	29.3850266744919111	-98.6097651945263038
24181	2020-05-10 11:49:20	2020-05-10	Mrs. Brianne Zemlak PhD	mrs.brianne.zemlak.phd@geemail.com	San Diego	California	53591421487944434	34062419a6c1020b5363344fb8c72cde	Voyager	32.7694671483777498	-117.212532370574777
24182	2020-05-10 11:57:20	2020-05-10	Isaak Gaylord V	isaak.gaylord.v@geemail.com	Pompano Beach	Florida	51781147328550839	31c2745cc0ceb9c18cb014211ca80676	American Express	26.1806995070803907	-80.1205896505001931
24183	2020-05-10 12:00:57	2020-05-10	Ms. Nealie Koepp	ms.nealie.koepp@woohoo.com	Houston	Texas	6011820944874538736	b44986f7b0e889319bcdddaf85f2b7cf	Voyager	29.7189706826660789	-95.3077518198188471
24184	2020-05-10 12:12:35	2020-05-10	Ms. Gladis Blick	ms.gladis.blick@geemail.com	Seattle	Washington	3112747878906098378	a1385d24128f7c8915f83da9eb2643c8	JCB 15 digit	47.6982974324300883	-122.294318392259626
24185	2020-05-10 12:14:15	2020-05-10	Catrina Barton	catrina.barton@woohoo.com	Stamford	Connecticut	4498233135219554	f347e04d66ed57c415c5677cdb46fd26	VISA 16 digit	41.0150355703547618	-73.5899121407922365
24186	2020-05-10 12:14:55	2020-05-10	Jasmine Abbott	jasmine.abbott@geemail.com	Los Angeles	California	3482664870397043	38d165bfa184d63cc11b4e004ff11a24	Mastercard	33.9533747313410004	-118.491949374879894
24187	2020-05-10 12:15:11	2020-05-10	Mae Koelpin	mae.koelpin@geemail.com	Baltimore	Maryland	869951523795354157	6a3cfc6d68f462986f2fb1516e10800e	JCB 15 digit	39.2729043075814843	-76.6735876361392457
24188	2020-05-10 12:19:26	2020-05-10	Alecia Gottlieb	alecia.gottlieb@warmmail.com	New York	New York	4972082036845636	90382cbf595c9d6f48a8934752b301e1	VISA 16 digit	40.5746182948574443	-73.880468480651075
24189	2020-05-10 12:22:58	2020-05-10	Eulalia Rowe	eulalia.rowe@geemail.com	San Francisco	California	3758780920800057	083c3cadcfe5b97ec8406c13c16dc81b	Discover	37.7467459858289942	-122.448623355303781
24190	2020-05-10 12:26:38	2020-05-10	Rene Raynor DVM	rene.raynor.dvm@geemail.com	Anaheim	California	3767127255389034	fefa149770b17e614549e1f79618f9fd	VISA 16 digit	33.8741505231074953	-117.742400101267165
24191	2020-05-10 12:31:06	2020-05-10	Kevin Jast PhD	kevin.jast.phd@geemail.com	San Francisco	California	4744117592708625	e2adb49d00458045b320507c041f7970	Voyager	37.7676494806020671	-122.463354877981104
24192	2020-05-10 12:32:06	2020-05-10	Jayce VonRueden DVM	jayce.vonrueden.dvm@geemail.com	San Francisco	California	561277290089836	7f1b6fe3aaa7151382d1a79dff0ec805	JCB 16 digit	37.7445076475036814	-122.413911677025084
24193	2020-05-10 12:35:08	2020-05-10	Unknown Hodkiewicz	unknown.hodkiewicz@geemail.com	San Francisco	California	4209823184964298	39563cc6d37977d742e1e1212b9477c2	VISA 16 digit	37.7513957071574069	-122.413735429518354
24194	2020-05-10 12:37:33	2020-05-10	Mr. Belton Hermiston	mr.belton.hermiston@geemail.com	San Francisco	California	4386857714458	a4a4a122d9ef1192e7119048dab3764a	JCB 16 digit	37.8087724361048387	-122.416620490295642
24195	2020-05-10 12:38:20	2020-05-10	Ardis Stroman DDS	ardis.stroman.dds@geemail.com	Milwaukee	Wisconsin	3337174562225842771	f4ba94540a4f7a685bbc3a55f6217c89	Mastercard	43.1524681199893365	-87.9443969563681662
24196	2020-05-10 12:39:12	2020-05-10	Jenifer Jacobs PhD	jenifer.jacobs.phd@geemail.com	Roseville	California	3460877162230062	7010cee474cf4b8549e9990df0cce448	JCB 16 digit	38.761899990640579	-121.338126436503231
24197	2020-05-10 12:47:44	2020-05-10	Dr. Rona Kris	dr.rona.kris@geemail.com	Columbia	South Carolina	6011302520352540308	0106ce3b8e6ee2f8254824f02a9a0289	Mastercard	33.9676823125485328	-80.8987782258558923
24198	2020-05-10 12:51:21	2020-05-10	Rexford Armstrong	rexford.armstrong@woohoo.com	San Francisco	California	4004183484484837	e42cac614831229351d5171aa9fc4560	American Express	37.7893615180116598	-122.417980179114807
24199	2020-05-10 13:08:05	2020-05-10	Kinley Runolfsson	kinley.runolfsson@warmmail.com	San Francisco	California	52931437693060228	e875c8ad18745c5dad59b954f528b64b	JCB 16 digit	37.7928398425585357	-122.434668042097144
24200	2020-05-10 13:22:21	2020-05-10	Fernando Baumbach	fernando.baumbach@geemail.com	Berkeley	California	4432397368637078	0167dc6ff16782f8c0521a76fd6d3cc7	American Express	37.8668131539641664	-122.281507414447248
24201	2020-05-10 13:23:27	2020-05-10	Shavonne Olson	shavonne.olson@warmmail.com	Los Angeles	California	3528252399158043662	394f4f9ae9fdd44b643fe0141a88f58c	VISA 16 digit	34.1180808301880916	-118.43234469583183
24202	2020-05-10 13:30:10	2020-05-10	Dariana Lakin-Hilpert	dariana.lakin.hilpert@geemail.com	Tucson	Arizona	676210204281686	952fe339afb95db7c2b9a16c41003315	VISA 16 digit	32.1893468581646687	-110.898169008292626
24203	2020-05-10 13:30:24	2020-05-10	Junia Hagenes	junia.hagenes@woohoo.com	Garden Grove	California	4725297914634	061dd09784924ea29c1f058b5ac9c482	VISA 13 digit	33.6817697878286211	-117.864020318865769
24204	2020-05-10 13:33:05	2020-05-10	Ms. Nyah Hand	ms.nyah.hand@woohoo.com	Oakland	California	869923879703804724	502e8742407b5628ad10b4730b183c55	VISA 16 digit	37.7939092170004756	-122.252146257074415
24205	2020-05-10 13:33:41	2020-05-10	Obie Windler	obie.windler@woohoo.com	Seattle	Washington	6011157619114082983	e1807b94842403dc07c9179a2bba6275	VISA 13 digit	47.6899755063392234	-122.409168888480963
24206	2020-05-10 13:43:40	2020-05-10	Wilfredo Goyette	wilfredo.goyette@warmmail.com	Las Vegas	Nevada	4396357246246595	1437449276c1c16649617f8b4b2e6972	JCB 16 digit	36.3075970677759514	-115.234470892485604
24207	2020-05-10 13:57:12	2020-05-10	Ms. Chante Gerlach	ms.chante.gerlach@woohoo.com	San Francisco	California	869998469440824761	315fb6d4e485d97791cb0d361da8afd2	JCB 16 digit	37.7654327007854818	-122.441947996098506
24208	2020-05-10 14:05:06	2020-05-10	Nikolas Farrell	nikolas.farrell@woohoo.com	Mobile	Alabama	6011417426154726693	915e68e796dd67aed420ba2206bde374	JCB 16 digit	30.5924715811494714	-88.1736352535568244
24209	2020-05-10 14:10:08	2020-05-10	Mr. Colonel Langworth III	mr.colonel.langworth.iii@geemail.com	Buffalo	New York	3008170409265603	e6d4cda4b03cb0ba09bce162d754558a	Mastercard	42.9830728286132171	-78.9133834348924523
24210	2020-05-10 14:13:02	2020-05-10	Laron King-Schimmel	laron.king.schimmel@geemail.com	Honolulu	Hawaii	3704770585792447	738cb1656208c5d547770beb6c1fe395	Maestro	21.3427897734783585	-157.793204181522498
24211	2020-05-10 14:13:45	2020-05-10	Tressa Schaefer	tressa.schaefer@geemail.com	Chicago	Illinois	3337150110996183468	f3514de7fe895c81f0ad4db7a7325732	Maestro	41.921730982356145	-87.6486515232857215
24212	2020-05-10 14:25:40	2020-05-10	Dr. Laurel Predovic	dr.laurel.predovic@geemail.com	San Francisco	California	869947967980375732	91146f9a32bc69aa592d300790e13cc1	VISA 16 digit	37.7593752474696132	-122.441468225257282
24213	2020-05-10 14:37:39	2020-05-10	Miss Kinley Littel	miss.kinley.littel@geemail.com	Arlington	Texas	3096915446249712984	f4f2d995c7d8ee89cd657c0376444bd6	Mastercard	32.6995958225119807	-97.1393996377501736
24214	2020-05-10 14:38:05	2020-05-10	Veola King	veola.king@geemail.com	Grand Rapids	Michigan	561267320995060	042f746aad76a68784374cc2efe014e9	Voyager	43.0017341892037521	-85.6114778729755557
24215	2020-05-10 14:47:23	2020-05-10	Keisha Reynolds	keisha.reynolds@geemail.com	Newark	New Jersey	869964705838337639	e98815919e7cc0e6250441ac818de8e5	Mastercard	40.7810608506117021	-74.2023240643296447
24216	2020-05-10 14:50:19	2020-05-10	Arta Bartoletti	arta.bartoletti@warmmail.com	Los Angeles	California	4927712169333283	0228a7db9efbe141a89eac4c9626bac6	JCB 15 digit	33.9652581755403418	-118.453481534728027
24217	2020-05-10 15:09:13	2020-05-10	Rahsaan Hagenes MD	rahsaan.hagenes.md@geemail.com	Fort Worth	Texas	676218756883726	6252267f4555e819e30088c91619df8a	JCB 15 digit	32.8507835063673568	-97.4111709257408904
24218	2020-05-10 15:20:13	2020-05-10	Mr. Georgie Collins III	mr.georgie.collins.iii@geemail.com	Escondido	California	3158131525112754278	0ccd0e3364e6d9f62881c9a18f470a2f	VISA 16 digit	33.0580647416640048	-116.976314168820153
24219	2020-05-10 15:29:08	2020-05-10	Kendal White-McDermott	kendal.white.mcdermott@warmmail.com	Fort Worth	Texas	4515549737739	f8d14ea682bd579d5d0e9e9bc86e1cb3	Maestro	32.8436015172917379	-97.3469117375377522
24220	2020-05-10 15:37:28	2020-05-10	Daquan Schuppe	daquan.schuppe@geemail.com	Chicago	Illinois	55208973810567469	cfd2bd588c3efdeadc63693ab5545e3f	Diners Club / Carte Blanche	41.7409061625901643	-87.6070161204349205
24221	2020-05-10 15:44:22	2020-05-10	Mrs. Viney Okuneva	mrs.viney.okuneva@geemail.com	Plano	Texas	4572320881160550	33a0a4ee343e52d4c746957f291c26b0	Discover	32.9543990004427769	-96.78555906267799
24222	2020-05-10 15:48:47	2020-05-10	Johnathan Schowalter	johnathan.schowalter@geemail.com	Boston	Massachusetts	6011449987887535752	4a5252ccddc012a3aec77d2498ac660b	JCB 16 digit	42.4277643675152234	-71.0049480151802328
24223	2020-05-10 15:51:17	2020-05-10	Zoa Witting	zoa.witting@geemail.com	New Haven	Connecticut	180099998785424364	f42ed5f556ee39e6294bc70cdd05a135	VISA 16 digit	41.3496395642861714	-72.8774407257325976
24224	2020-05-10 16:05:44	2020-05-10	Dell Halvorson MD	dell.halvorson.md@geemail.com	Milwaukee	Wisconsin	6011680434777115542	7f748f6a92bcb7011f6e70d62d760e5a	JCB 15 digit	43.1117702314715814	-87.9916785831198069
24225	2020-05-10 16:12:51	2020-05-10	Aric Cormier	aric.cormier@geemail.com	Seattle	Washington	4456478734167	94c59ced1ce3af68e01e36dd760cc840	JCB 16 digit	47.614643141061066	-122.419207553417976
24226	2020-05-10 16:22:54	2020-05-10	Virgel Klocko-Durgan	virgel.klocko.durgan@geemail.com	Tampa	Florida	3096736682356506499	22483cfb628a6fddf6e162ba2ca08835	VISA 16 digit	27.9390974887296544	-82.514668774020663
24227	2020-05-10 16:31:00	2020-05-10	Rutherford Bogan	rutherford.bogan@geemail.com	Newark	New Jersey	3445044777709499	88a466a4f3906532bb09e4a5f6436cdf	JCB 15 digit	40.7021042548500063	-74.2269611573521075
24228	2020-05-10 16:37:53	2020-05-10	Danae Ortiz	danae.ortiz@geemail.com	Sacramento	California	4579329269305110	54f645295e201e8280dd04b92353a4b1	JCB 16 digit	38.5439893670644622	-121.567260491965712
24229	2020-05-10 16:44:49	2020-05-10	Mr. Wirt Wintheiser	mr.wirt.wintheiser@geemail.com	Houston	Texas	4466659726185069	64e850dd4d01f4c26a201f6654773f08	American Express	29.8066023096986115	-95.4310401176582985
24230	2020-05-10 16:47:23	2020-05-10	Dr. Meda Bernier MD	dr.meda.bernier.md@warmmail.com	Joliet	Illinois	3088920113243860580	78a80a65505a7a9291e2f2d7e399855e	JCB 16 digit	41.5517492667630322	-88.1887992569349706
24231	2020-05-10 16:51:19	2020-05-10	Ms. Mara Bahringer	ms.mara.bahringer@woohoo.com	Chesapeake	Virginia	869906734107009712	e9104f6e57a23ee913c1c37a4548b7c8	Diners Club / Carte Blanche	36.6356515255063755	-76.2765334260959236
24232	2020-05-10 17:11:25	2020-05-10	Karie Okuneva-Heathcote	karie.okuneva.heathcote@geemail.com	Philadelphia	Pennsylvania	6011672041384207834	064feef5a6f17ed71db56888557c470e	Discover	39.9201351419050212	-75.0732587339721675
24233	2020-05-10 17:14:00	2020-05-10	Earl Harvey I	earl.harvey.i@warmmail.com	Chicago	Illinois	4190204046982169	05679e75b27d834eb155a551f7abdd42	JCB 16 digit	41.9134448509499435	-87.7461476403783962
24234	2020-05-10 17:17:28	2020-05-10	Carly Weber-Cormier	carly.weber.cormier@geemail.com	Modesto	California	3022735595990713	16b258006911bc66497d31f9424c4f84	Mastercard	37.5942473909817636	-121.055453819941732
24235	2020-05-10 17:37:25	2020-05-10	Chadd Prohaska	chadd.prohaska@geemail.com	New York	New York	180072961129102238	5ed89733f2aac68682e1714c022a3ee0	VISA 13 digit	40.5816880248244871	-73.9180442208319874
24236	2020-05-10 17:41:57	2020-05-10	Kenton Hane-Osinski	kenton.hane.osinski@warmmail.com	San Bernardino	California	501844294119399	0bbb39ea52f2aefaaae8c8a704d0f205	Maestro	34.2254033019565043	-117.212162192982063
24237	2020-05-10 17:48:43	2020-05-10	Margaret Kemmer-Stroman	margaret.kemmer.stroman@geemail.com	Winston–Salem	North Carolina	4732661591486943	b81cc7b56a0b2c62b165bed414159019	Maestro	36.0274255735564992	-80.241250338139011
24238	2020-05-10 18:07:43	2020-05-10	Attie Hudson-Becker	attie.hudson.becker@geemail.com	Jacksonville	Florida	3016204125612392	ca0cf5a928ef4da46d95de90b0e62887	Mastercard	30.3875847707089051	-81.6353944108434035
24239	2020-05-10 18:08:03	2020-05-10	Dr. Shade Gusikowski MD	dr.shade.gusikowski.md@woohoo.com	Peoria	Arizona	3088637009804058529	19f7c259f41480cf4b3ba7a46b24eedc	American Express	33.8068347678788044	-112.352384145969538
24240	2020-05-10 18:08:22	2020-05-10	Major Reichert	major.reichert@geemail.com	San Antonio	Texas	869991256052430053	1d5639347facdfba72bc17bab251d7ed	Mastercard	29.4641591997422267	-98.5869258503731345
24241	2020-05-10 18:12:01	2020-05-10	Matias Schoen	matias.schoen@geemail.com	Mesa	Arizona	6011628541943946884	ec9543f7366126b17823feeaafb897ce	Voyager	33.3986867427505558	-111.77358241522461
24242	2020-05-10 18:16:08	2020-05-10	Dr. Jazmine Bailey	dr.jazmine.bailey@warmmail.com	Jacksonville	Florida	51102525213909925	1cd8741024cae3926406aeae61f1e94a	JCB 16 digit	30.321719241892545	-81.7546722855962855
24243	2020-05-10 18:33:01	2020-05-10	Dr. Judith Hand DVM	dr.judith.hand.dvm@geemail.com	Philadelphia	Pennsylvania	4441424445450629	aacf6c5cae76369c3ef015eaa5831625	Mastercard	40.0797164662234451	-75.1666598515484594
24244	2020-05-10 18:36:07	2020-05-10	Daxton Huel	daxton.huel@geemail.com	San Francisco	California	3753387310631335	2b50ae8d881994e1f126a9f48fb4521f	Diners Club / Carte Blanche	37.7958363051028243	-122.465792070333407
24245	2020-05-10 18:37:47	2020-05-10	Dr. Elwood Bayer DDS	dr.elwood.bayer.dds@woohoo.com	San Angelo	Texas	4324006979480072	7c158ca9a06c5b31e2378c92d3e567a2	Maestro	31.4735664798099535	-100.35887248703466
24246	2020-05-10 18:53:35	2020-05-10	Viva Batz	viva.batz@geemail.com	Memphis	Tennessee	4323862268797795	5093981bdf862e663fb83b55c5dca1f9	JCB 15 digit	35.1143785700269078	-90.0726920434996572
24247	2020-05-10 18:56:42	2020-05-10	Lafayette Daugherty	lafayette.daugherty@geemail.com	San Antonio	Texas	4479151423775	8cbc955fa752b9aa26496f58d57a8289	Discover	29.3947808961454768	-98.433906534204624
24248	2020-05-10 19:02:37	2020-05-10	Adline Marvin	adline.marvin@geemail.com	Chicago	Illinois	210037446280345820	8c50bb9c688a519271806842526c9991	VISA 16 digit	41.8187064622830604	-87.7341628223221761
24249	2020-05-10 19:05:25	2020-05-10	Dr. Vicky Jenkins	dr.vicky.jenkins@geemail.com	San Francisco	California	6011808959085538024	10f1fbffc686e46f15009bcd2048a433	JCB 16 digit	37.7767258883259274	-122.43636684640687
24250	2020-05-10 19:13:45	2020-05-10	Mylee Gutkowski	mylee.gutkowski@geemail.com	Columbus	Ohio	51551170943387674	676937b4213b40c95e42d0bb0287afe8	Mastercard	39.9372684694405606	-82.9941212644103956
24251	2020-05-10 19:29:08	2020-05-10	Mckinley Kuhlman	mckinley.kuhlman@geemail.com	Washington	District of Columbia	4610716578873054	5b3a93106d4da0e962719571c4d19e85	American Express	38.8827235847510408	-76.9677593320354845
24252	2020-05-10 19:30:51	2020-05-10	Melinda Bergnaum	melinda.bergnaum@geemail.com	Tucson	Arizona	4888628045807	3d3aa675f80130ebc801a89fa5736f8a	Maestro	32.1974863875232629	-110.887574632348858
24253	2020-05-10 19:47:24	2020-05-10	Mr. Brandin Mohr	mr.brandin.mohr@geemail.com	Santa Clarita	California	3337803558491829822	a2d3f05d3bd12aaf825f196052072ad9	Maestro	34.4528708805534976	-118.546011969829721
24254	2020-05-10 19:48:03	2020-05-10	Dr. Myrtle Greenholt	dr.myrtle.greenholt@geemail.com	San Diego	California	3754580932392505	358d54ad48746639d889805853a93b98	JCB 15 digit	32.8408964969750485	-117.068822484407576
24255	2020-05-10 19:50:03	2020-05-10	Daija Farrell	daija.farrell@geemail.com	Los Angeles	California	210065858059920994	bad9017845bd26d632e6fa26ee753693	Diners Club / Carte Blanche	33.9397276397194716	-118.33233776949271
24256	2020-05-10 19:54:40	2020-05-10	Mr. Epifanio Boyer MD	mr.epifanio.boyer.md@geemail.com	Phoenix	Arizona	4180110363361543	a9620609a52bbe17dc390411725649f2	JCB 16 digit	33.5240992623779945	-112.120941103056452
24257	2020-05-10 20:25:09	2020-05-10	Madonna Pouros	madonna.pouros@warmmail.com	Sacramento	California	869927532629224305	c1704a129b7fd549163febf4a0fecf0d	VISA 16 digit	38.612074929455666	-121.427583410941438
24258	2020-05-10 20:30:31	2020-05-10	Loni Lemke	loni.lemke@geemail.com	Chicago	Illinois	180056191360064836	be749b3c086f73e5c77e0eb333394e30	VISA 16 digit	41.8442998366266536	-87.6478958379041302
24259	2020-05-10 20:30:38	2020-05-10	Fredric Schulist	fredric.schulist@geemail.com	Tucson	Arizona	3744074343863661	1323420554d4c81ffde6e343d377426a	JCB 16 digit	32.1432950683910406	-110.944799672648685
24260	2020-05-10 20:34:51	2020-05-10	Encarnacion Breitenberg	encarnacion.breitenberg@geemail.com	San Francisco	California	3112563118250207080	9f3f13c2eacd914eef72c7409238358b	JCB 15 digit	37.7687339487139937	-122.41650160064755
24261	2020-05-10 20:34:59	2020-05-10	Eleanora Schroeder	eleanora.schroeder@geemail.com	New Orleans	Louisiana	3096117560537955356	e6cde0a22c821e81d7ec74a10775bdda	American Express	30.0403530333206064	-89.9522319793030647
24262	2020-05-10 20:52:10	2020-05-10	Telly Bradtke	telly.bradtke@geemail.com	Minneapolis	Minnesota	54330883395125875	c7b5889945db9f42ddd0b573d2ce1fb2	Diners Club / Carte Blanche	44.9453813415106325	-93.3559640608068548
24263	2020-05-10 20:52:21	2020-05-10	Jettie Hartmann	jettie.hartmann@geemail.com	Honolulu	Hawaii	4807202492349706	289dcb6bde6843070a3da6a0222f7eba	Discover	21.2622212828353057	-157.77362624171414
24264	2020-05-10 20:57:59	2020-05-10	Elza Crona-Dach	elza.crona.dach@geemail.com	Minneapolis	Minnesota	4390251200833	b0abde7eef5086c280e0a1565fc904ef	Voyager	45.0632910635407953	-93.2222845771156159
24265	2020-05-10 21:19:00	2020-05-10	Adalynn Reinger	adalynn.reinger@woohoo.com	Athens	Georgia	4191121039199	af386f979d7d585b2fe95aff44eaad42	JCB 16 digit	33.8695907728005139	-83.3297313271205837
24266	2020-05-10 21:26:30	2020-05-10	Harm Ruecker I	harm.ruecker.i@woohoo.com	San Francisco	California	869994368863917132	67ef7bb35c67fea37313dcef41dd013b	JCB 15 digit	37.7716497977978705	-122.450074415860612
24267	2020-05-10 21:30:01	2020-05-10	Boyce Koss	boyce.koss@warmmail.com	Los Angeles	California	4652340573805	d394cdf36535850ce99a016a7afc5fe7	Diners Club / Carte Blanche	33.9928285951592031	-118.326477944896737
24268	2020-05-10 22:06:13	2020-05-10	Morgan Bergnaum	morgan.bergnaum@geemail.com	Long Beach	California	869989244859355172	a58715b6d003e5ce14e333442af1380a	Discover	33.771128825732319	-118.173298846014958
24269	2020-05-10 22:07:01	2020-05-10	Alda Lockman-Luettgen	alda.lockman.luettgen@geemail.com	New York	New York	3158885021864407016	99c36ac3096eefd24041b484c39eb8ad	VISA 16 digit	40.7313381284233174	-73.9330726870231274
24270	2020-05-10 22:08:09	2020-05-10	Zeb Herzog	zeb.herzog@geemail.com	San Francisco	California	3454481057456128	f56b2975f7ce63b170ce2b6aa63634a9	American Express	37.784748655232228	-122.439887537866113
24271	2020-05-10 22:23:25	2020-05-10	Dillan Zemlak DDS	dillan.zemlak.dds@geemail.com	Fayetteville	North Carolina	55083490935941867	cebfe136ecfecced32bcf19e88f90f4a	JCB 16 digit	35.1675095784265537	-79.05906084171869
24272	2020-05-10 22:25:55	2020-05-10	Sherita Mueller PhD	sherita.mueller.phd@geemail.com	Los Angeles	California	869994792565780698	dc581cd68e4677fa965beb3e621a47fc	Diners Club / Carte Blanche	33.9999658747907674	-118.446123838051406
24273	2020-05-10 22:31:52	2020-05-10	Mrs. Jailene Bins	mrs.jailene.bins@geemail.com	Chula Vista	California	3009653237796195	da088b427b8da24df412983d68132fba	Discover	32.5861422158077332	-117.075828906916826
24274	2020-05-10 22:35:29	2020-05-10	Arietta Beahan	arietta.beahan@warmmail.com	San Francisco	California	3480132991758388	8ab5a9d0d3be88270645762362eebf6d	Discover	37.7751731901845531	-122.452409762242212
24275	2020-05-10 22:36:20	2020-05-10	Ari Ward	ari.ward@geemail.com	Chicago	Illinois	55237413951073519	897d0937835423721b30a26cb0e32504	VISA 16 digit	41.9337816685274234	-87.7104505221854822
24276	2020-05-10 22:39:09	2020-05-10	Dosha Lueilwitz	dosha.lueilwitz@geemail.com	Seattle	Washington	869966122331510126	9d1a9205e9d26d57081ce1b2acd5620f	Diners Club / Carte Blanche	47.550908501252529	-122.449329115302859
24277	2020-05-10 22:49:05	2020-05-10	Mr. Lindsey Carroll	mr.lindsey.carroll@geemail.com	New York	New York	180071338220862385	71254737037d6076077441b1cd4b91c6	JCB 16 digit	40.7232239467315367	-73.8683746993903014
24278	2020-05-10 22:50:14	2020-05-10	Fleta Kling	fleta.kling@geemail.com	San Francisco	California	4704645264967044	888ed95688ecb55a4dcc878c613ed7a5	Discover	37.7706704315470319	-122.411164177760199
24279	2020-05-10 23:11:19	2020-05-10	Jackson Stroman-Paucek	jackson.stroman.paucek@geemail.com	Anaheim	California	869991382384352623	68840a803a9ee75e6ce5f5e4bc6a3c53	Mastercard	33.7567862076982834	-117.676861098336417
24280	2020-05-10 23:17:13	2020-05-10	Dr. Ilene Halvorson PhD	dr.ilene.halvorson.phd@geemail.com	San Francisco	California	6011211987462371744	8b9ff7e87332ec7773ce39bde0c67f6d	VISA 13 digit	37.7571867911415424	-122.459643915642928
24281	2020-05-10 23:31:35	2020-05-10	Risa Hirthe	risa.hirthe@geemail.com	Killeen	Texas	55511712633202777	f3db014d7f8850728a46958fc593a6c1	Voyager	31.1155924545366318	-97.7414714648090239
24282	2020-05-10 23:39:18	2020-05-10	Mr. Vick Hegmann III	mr.vick.hegmann.iii@geemail.com	Honolulu	Hawaii	210063065836122157	5191ce453702bef6d25d9fdd59cc2e09	American Express	21.365242540438846	-157.922408824574575
24283	2020-05-10 23:46:45	2020-05-10	Floy Kris	floy.kris@geemail.com	Houston	Texas	3768897553449644	cd760833613063c037afdd32f14a3e25	JCB 15 digit	29.6942495398301638	-95.4890758588925053
24284	2020-05-10 23:53:10	2020-05-10	Marlana Jakubowski	marlana.jakubowski@warmmail.com	San Francisco	California	4240307800050758	9560bc9345c0cf1a46a59735346edd6d	VISA 16 digit	37.7913773606419596	-122.442066947430945
24285	2020-05-11 00:11:35	2020-05-11	Zandra Ziemann	zandra.ziemann@geemail.com	Mesa	Arizona	4246312502427423	04920ec4ddb4427478580bb11d4d3893	Voyager	33.3387296266999087	-111.668021835980568
24286	2020-05-11 00:18:21	2020-05-11	Ebba Hirthe-Kautzer	ebba.hirthe.kautzer@geemail.com	New York	New York	3337061866913742110	4f3b78e41233fab3d781cb8950aff230	Mastercard	40.726127995293588	-74.0229301584780188
24287	2020-05-11 00:27:07	2020-05-11	Mr. Della Barrows DVM	mr.della.barrows.dvm@geemail.com	Miami Gardens	Florida	6011893787852859471	0d60b68227858465c0812ebf91ecedd0	VISA 16 digit	25.9348148540068415	-80.2395010162390747
24288	2020-05-11 00:43:12	2020-05-11	Leisa Graham-Dach	leisa.graham.dach@geemail.com	Orlando	Florida	503812693653847	98b8e37abf346ef7d0613f7e671824d2	VISA 13 digit	28.4579302545901385	-81.1997801376007544
24289	2020-05-11 00:45:56	2020-05-11	Darrin Durgan	darrin.durgan@geemail.com	Chicago	Illinois	3019743277019259	5c5c02514c6ca1c569dab47775548bcf	JCB 16 digit	41.7420477027840917	-87.7606213186431603
24290	2020-05-11 01:12:33	2020-05-11	Mr. Christina Stracke MD	mr.christina.stracke.md@geemail.com	Los Angeles	California	4828909922092	2fde98da1984c258fee83a92fe48fba0	Diners Club / Carte Blanche	33.9203292260743652	-118.466827300609268
24291	2020-05-11 01:16:13	2020-05-11	Sena Kling	sena.kling@woohoo.com	Dallas	Texas	55541698255866276	f07d9b431808015c428f33eaf92f35ef	Voyager	32.7010174666803337	-96.7427844460550688
24292	2020-05-11 01:48:27	2020-05-11	Dedric Kihn	dedric.kihn@geemail.com	El Paso	Texas	4283239941641625	5d3a2e5c69f7f7d5b92133dad9325cce	Discover	31.8153754221569756	-106.496235308934004
24293	2020-05-11 01:57:00	2020-05-11	Dellar Kris MD	dellar.kris.md@geemail.com	Los Angeles	California	180086503295542898	7d871beadb61129192a8a8d496f97113	VISA 13 digit	33.9635918245982324	-118.397088926284752
24294	2020-05-11 02:01:28	2020-05-11	Levi Senger Jr.	levi.senger.jr.@geemail.com	El Paso	Texas	3021253806921254	d627b367bc66d44b872d6cb95e4ff031	Maestro	31.9365325962953293	-106.439083081156028
24295	2020-05-11 02:15:56	2020-05-11	Mozelle Wilkinson	mozelle.wilkinson@woohoo.com	Anaheim	California	180049634258499903	18618b92d21a0160749347a3ce549662	American Express	33.9010246140249052	-117.850193323681495
24296	2020-05-11 02:43:54	2020-05-11	Rae Reinger	rae.reinger@woohoo.com	Louisville	Kentucky	4219961776220733	5ba2d3914a06ba33d6484937ee24d890	JCB 15 digit	38.2048496127497401	-85.599610437413304
24297	2020-05-11 02:46:51	2020-05-11	Dr. Toshio Turcotte DDS	dr.toshio.turcotte.dds@geemail.com	Columbus	Ohio	3039203919473703	b9dce16a1cbd1201b341ba93b02767f5	VISA 13 digit	40.0810493329118955	-82.9212665744360606
24298	2020-05-11 02:55:41	2020-05-11	Alvan Beahan	alvan.beahan@geemail.com	Joliet	Illinois	53081873996633675	fc7dbbddd0454ba0d6f404ac2ec5f12e	JCB 16 digit	41.5846843644369386	-88.1195895587198379
24299	2020-05-11 03:07:23	2020-05-11	Ms. Adelynn Beahan MD	ms.adelynn.beahan.md@woohoo.com	Chicago	Illinois	3088890666502672554	6676519eb233315bf61e74edd48a8e14	Maestro	41.859856958996879	-87.6324624670699137
24300	2020-05-11 03:23:51	2020-05-11	Domenic McClure MD	domenic.mcclure.md@warmmail.com	Yonkers	New York	3004210337709860	b971dfbe9297320064a5d9cb4d63a5f1	VISA 13 digit	40.9532349101934585	-73.858608942979572
24301	2020-05-11 03:37:09	2020-05-11	Rosanne Stroman	rosanne.stroman@woohoo.com	Anchorage	Alaska	3088107827852189172	33279657265e10321cb0c4c382fb2108	JCB 16 digit	61.1965481357865073	-149.269794102910168
24302	2020-05-11 03:38:45	2020-05-11	Ms. Raelynn Waters	ms.raelynn.waters@geemail.com	San Francisco	California	4991375204369	7b25ca6b4d5264c48c367a62344f0207	JCB 16 digit	37.7892997689394576	-122.408585678987919
24303	2020-05-11 04:03:34	2020-05-11	Lexi Rohan MD	lexi.rohan.md@geemail.com	San Francisco	California	51233373041941899	1f26b06805deaa789a12c46c3cb4770b	VISA 16 digit	37.7829173135327352	-122.428440992380715
24304	2020-05-11 04:16:19	2020-05-11	Mr. Harvie Kemmer PhD	mr.harvie.kemmer.phd@geemail.com	Mesquite	Texas	4683122637801297	3962f48dd52cfcbb8a2b218ae8097eec	Discover	32.7332315876889979	-96.5590280513476671
24305	2020-05-11 04:20:56	2020-05-11	Jarrett Schumm	jarrett.schumm@woohoo.com	Washington	District of Columbia	3528362137730267079	da688c530534d703f507f23b915511cc	Voyager	38.8292217687968133	-76.922335040776801
24306	2020-05-11 04:35:22	2020-05-11	Brandon Kohler	brandon.kohler@woohoo.com	San Francisco	California	3790080792792072	71655f74219c5d974a45f30f0f1ae0cf	VISA 16 digit	37.7610134499216983	-122.423512940823471
24307	2020-05-11 04:35:30	2020-05-11	Keira Veum	keira.veum@woohoo.com	New York	New York	4170308536092993	5cfc541807e4015712a4ba36320d6638	Mastercard	40.5821103858519336	-74.0358343437209641
24308	2020-05-11 04:37:25	2020-05-11	Darold Tremblay	darold.tremblay@geemail.com	Dallas	Texas	3096009297193613117	19afd74b42732dcfd473f9d3c2b5f9e4	JCB 15 digit	32.7444726308614023	-96.7228997146673493
24309	2020-05-11 04:47:06	2020-05-11	Mr. Fitzhugh Denesik	mr.fitzhugh.denesik@woohoo.com	New York	New York	869941073952211744	616b1e570e4502a090bd595825d04d89	Voyager	40.6201822227556235	-74.0276833373948904
24310	2020-05-11 04:58:26	2020-05-11	Kristyn Crist	kristyn.crist@geemail.com	Oakland	California	210031149658552516	7bd979269fd0ec9f46443a1f756b63ca	Voyager	37.8162051230930985	-122.286404656741922
24311	2020-05-11 04:59:47	2020-05-11	Ms. Shelbi Romaguera DVM	ms.shelbi.romaguera.dvm@geemail.com	Baltimore	Maryland	3158762803846018260	2f78338e413a986b34aca0487af8d141	JCB 16 digit	39.3168144910130621	-76.5344080921281176
24312	2020-05-11 05:00:18	2020-05-11	Ms. Loreen Labadie	ms.loreen.labadie@geemail.com	Nashville	Tennessee	3096258229330609367	fca0558cece20e6333b42a52802e907a	JCB 16 digit	36.2078314994584716	-86.8319543258659508
24313	2020-05-11 05:23:39	2020-05-11	Dorinda Herzog	dorinda.herzog@geemail.com	Fairfield	California	4361760891379184	ce9ad8a25e147919a72408a92f7320c0	Diners Club / Carte Blanche	38.2298634092446434	-122.102249447070434
24314	2020-05-11 05:33:44	2020-05-11	Mr. Jameson Crist	mr.jameson.crist@woohoo.com	Sparks	Nevada	3407881273710034	39771f14c3a029d4b34a2214da8c25b7	Mastercard	39.544854646293075	-119.667117810095107
24315	2020-05-11 05:54:17	2020-05-11	Terri Abbott-Ferry	terri.abbott.ferry@warmmail.com	Tuscaloosa	Alabama	4279628156713	d1d338f2a1aea7e2f9a0e77c1ace1b06	JCB 16 digit	33.3048704148326067	-87.535095037576184
24316	2020-05-11 05:55:29	2020-05-11	Mr. Kinte Littel	mr.kinte.littel@warmmail.com	Philadelphia	Pennsylvania	180024828320303437	24d0bb01fc784ba70d38a7bd36aee7f2	JCB 16 digit	39.9237566167913371	-75.1661932310920236
24317	2020-05-11 05:58:26	2020-05-11	Brea Heller	brea.heller@geemail.com	San Francisco	California	4224818858918	a9f42fb740b05251d22e8aba0e45b30b	VISA 16 digit	37.7698438791766407	-122.43843106831909
24318	2020-05-11 06:16:36	2020-05-11	Joseph Hackett	joseph.hackett@geemail.com	New York	New York	3002381488583610	284162cf4b66345c4ef4886aa193911d	VISA 13 digit	40.6586343539636559	-73.8801625162258659
24319	2020-05-11 06:17:00	2020-05-11	Ivah White	ivah.white@geemail.com	Tampa	Florida	3477897229029050	12f2476d249b37dd844ea55be0c1a954	JCB 16 digit	27.9684452407177524	-82.4392051888842019
24320	2020-05-11 06:20:30	2020-05-11	Jessye Mueller-McCullough	jessye.mueller.mccullough@warmmail.com	Honolulu	Hawaii	501841831908987	7c15475c4932d08e680a9ab760805235	VISA 13 digit	21.3824296882126497	-157.903951915327838
24321	2020-05-11 06:41:42	2020-05-11	Mina Stark	mina.stark@geemail.com	Berkeley	California	4411269138094	e4e429101f9e6d680a64041f09773197	Maestro	37.8469382191107684	-122.276632440357915
24322	2020-05-11 07:30:55	2020-05-11	Laurene Swift	laurene.swift@geemail.com	Houston	Texas	3096646326351554562	cafbd5b1c82617ac09d6d34a4f7f4331	Mastercard	29.8832989756096161	-95.3841054977398386
24323	2020-05-11 07:34:48	2020-05-11	Ms. Mima Zulauf PhD	ms.mima.zulauf.phd@woohoo.com	New York	New York	6011115086835522336	2f597f093e7ca3ed645ccbd27b919ce8	Diners Club / Carte Blanche	40.6412949782554023	-73.8898692310217768
24324	2020-05-11 07:38:38	2020-05-11	Ms. Marietta Schaden PhD	ms.marietta.schaden.phd@warmmail.com	Boston	Massachusetts	4544976205044047	b7a6d2a79db88fe5791cd69215201079	Discover	42.3923238473646364	-71.0232833240132777
24325	2020-05-11 07:58:03	2020-05-11	Deon Gorczany	deon.gorczany@geemail.com	San Francisco	California	52782832567876990	1fe9e639bb677d1e8792085c3b486305	JCB 16 digit	37.769208500071251	-122.437679794832363
24326	2020-05-11 07:58:51	2020-05-11	Marcos Ernser	marcos.ernser@warmmail.com	San Francisco	California	3096280879899231219	aeb1de864f99c0496c2d1abb8d22bc88	Mastercard	37.7794571390735356	-122.419978784142458
24327	2020-05-11 08:03:50	2020-05-11	Shedrick Klocko-Cartwright	shedrick.klocko.cartwright@woohoo.com	Lakewood	New Jersey	180092625451209434	a43dca86a3402bde7a48158f28f00f04	JCB 16 digit	40.1006626038163887	-74.1518978883322291
24328	2020-05-11 08:04:55	2020-05-11	Dulcie Crist	dulcie.crist@geemail.com	Rochester	Minnesota	3001798084728599	5b346c950b695614491628d3f43c1610	JCB 15 digit	44.010711025856061	-92.4066471902307143
24329	2020-05-11 08:34:41	2020-05-11	Luz Littel-Kessler	luz.littel.kessler@geemail.com	Killeen	Texas	3015061420056811	fab30fe2a4ae28a1015b3dc3a623df5b	VISA 16 digit	31.1483681766547278	-97.6429533857088501
24330	2020-05-11 08:34:56	2020-05-11	Dave Schulist	dave.schulist@geemail.com	Lubbock	Texas	869936628959078177	708392e679c7aff436ff5a2d861fdb7a	Maestro	33.6628193110268583	-101.835414148579176
24331	2020-05-11 08:38:39	2020-05-11	Dr. Tamala Johns	dr.tamala.johns@geemail.com	San Francisco	California	54990019915429544	1143d419256c571ff59e8df63d6b53c4	VISA 16 digit	37.7814893541014669	-122.423897638383622
24332	2020-05-11 08:39:36	2020-05-11	Seldon Stokes II	seldon.stokes.ii@geemail.com	New York	New York	4501657456491654	559f525a1a0860f0631fd007736bc619	Voyager	40.6803223418761064	-73.879607606901601
24333	2020-05-11 08:42:47	2020-05-11	Macey Lemke DDS	macey.lemke.dds@woohoo.com	Pasadena	Texas	3528393330452574946	c5f1d8e0cb06b6aeb6728877a93a0529	VISA 13 digit	29.58948566553779	-95.1639047636132602
24334	2020-05-11 09:04:19	2020-05-11	Arvid Johnston	arvid.johnston@geemail.com	Sacramento	California	6011201036752084575	5f75cd71cd99262267a6460f4205ddcd	Discover	38.4764750098142798	-121.564483153472096
24335	2020-05-11 09:04:40	2020-05-11	Vernie Herman	vernie.herman@warmmail.com	Kansas City	Kansas	210029905107680503	8a0f76a3df67b515cf6accacc9ae44ba	JCB 16 digit	39.0862849932536491	-94.7465820805571894
24336	2020-05-11 09:12:26	2020-05-11	Isla Goodwin	isla.goodwin@geemail.com	Baltimore	Maryland	210018454652867820	15d2be9503be940dc046187db73f46fa	VISA 16 digit	39.3635488884523497	-76.5429638555292087
24337	2020-05-11 09:32:10	2020-05-11	Onnie Lind DDS	onnie.lind.dds@geemail.com	Billings	Montana	6011391623418415333	f28b6474451d741af12f97fd839fc3b0	JCB 16 digit	45.7233463177215285	-108.529208138927444
24338	2020-05-11 09:40:01	2020-05-11	Mr. Santo Gottlieb	mr.santo.gottlieb@warmmail.com	Clarksville	Tennessee	503826582919325	de47b2f526d4a9248f18b5aafc13d4c1	JCB 15 digit	36.4786549018356965	-87.3791767369907433
24339	2020-05-11 10:06:17	2020-05-11	Neva Emmerich	neva.emmerich@geemail.com	Chicago	Illinois	869907717391950518	dbb918722dfab6c77eb7968b3255a2a6	VISA 16 digit	41.7539174133282174	-87.5904345135699884
24340	2020-05-11 10:19:14	2020-05-11	Mrs. Trish Grady	mrs.trish.grady@warmmail.com	San Francisco	California	3528332649550519899	d03d4b882f6c744040f6bb61d4136178	VISA 16 digit	37.7919085119751657	-122.409186477264484
24341	2020-05-11 10:19:34	2020-05-11	Valerie Considine	valerie.considine@geemail.com	Oakland	California	6011464315267309087	6100e18720856f191e5add7a22af3691	Voyager	37.7928660671769592	-122.312300346813217
24342	2020-05-11 10:34:09	2020-05-11	Stanley Walter	stanley.walter@geemail.com	Los Angeles	California	6011266058745455243	1a22bdc898b264498de50cda26e5ede1	VISA 16 digit	34.0988010818470215	-118.356160598061223
24343	2020-05-11 10:36:55	2020-05-11	Aimee Smith	aimee.smith@warmmail.com	Fremont	California	210070779462711643	7e504115921c11ed0b6bceefd0bc8948	JCB 16 digit	37.4723302375692882	-122.000242063867674
24344	2020-05-11 11:00:23	2020-05-11	Zechariah Wehner I	zechariah.wehner.i@woohoo.com	San Francisco	California	3337562775884771418	c67b4b97d33355c2495afed71fbb9448	American Express	37.7990619875863629	-122.405330093673612
24345	2020-05-11 11:09:24	2020-05-11	Rosalyn Lindgren	rosalyn.lindgren@geemail.com	Berkeley	California	51016417091737237	b554e674c66b8038ceae41a1e93b09fa	JCB 16 digit	37.8576961596149815	-122.262665257784718
24346	2020-05-11 11:10:12	2020-05-11	Caylee Cartwright	caylee.cartwright@geemail.com	New York	New York	3112994775211454967	716ff5b6ac0617477bbb1da32dd127c5	JCB 16 digit	40.6539134624172007	-74.0339823250554474
24347	2020-05-11 11:10:13	2020-05-11	Gael Schulist	gael.schulist@geemail.com	Houston	Texas	54037990695647643	cbca75dfb7841cb79f3f837f3a8b27b5	Discover	29.7788813974786564	-95.3004848768949557
24348	2020-05-11 11:12:33	2020-05-11	Ms. Evie Weber MD	ms.evie.weber.md@geemail.com	Riverside	California	180019573353524551	2cd4821eb0777b144cf8f5a0f230f044	Discover	33.8776507691893727	-117.434487193214508
24349	2020-05-11 11:13:45	2020-05-11	Davey Ondricka	davey.ondricka@geemail.com	Toledo	Ohio	4110605790473	a93ddf407f3b93ba5ca0dff050e2e4d4	JCB 16 digit	41.7596951302777981	-83.6516795270476479
24350	2020-05-11 11:33:47	2020-05-11	Taraji Langworth DVM	taraji.langworth.dvm@warmmail.com	San Francisco	California	4822007115291537	8ada06feb0c732bf9c1971b17fa6994f	JCB 16 digit	37.7977603047662498	-122.44348560988702
24351	2020-05-11 11:41:51	2020-05-11	Shante Maggio	shante.maggio@geemail.com	San Diego	California	4167772546742290	119d8ab48d9ea8f3b965de900f02faea	American Express	32.8877952725227942	-117.07363019659185
24352	2020-05-11 11:44:05	2020-05-11	Mr. Tyron Breitenberg	mr.tyron.breitenberg@woohoo.com	New York	New York	3528508117631365979	6e9b421499d2cbc19e90d86a17124390	JCB 16 digit	40.6193676073793313	-73.8548685986444298
24353	2020-05-11 11:44:08	2020-05-11	Miss Madelene Sawayn DDS	miss.madelene.sawayn.dds@warmmail.com	Kent	Washington	3710722665791924	462c70c79ad072ad325e26ae968b8cf7	JCB 16 digit	47.3781820682454864	-122.176935280361022
24354	2020-05-11 12:11:31	2020-05-11	Maceo Volkman-Heaney	maceo.volkman.heaney@geemail.com	San Francisco	California	4373568490404	18947dfaa80ffc3a6283f2048e7b7721	Diners Club / Carte Blanche	37.7809683397072007	-122.436926057669922
24355	2020-05-11 12:12:06	2020-05-11	Jimmie Shanahan-Kuphal	jimmie.shanahan.kuphal@geemail.com	Omaha	Nebraska	869944899425344218	fb1f797465d9393bf3568519788d45a4	Diners Club / Carte Blanche	41.3434984176099292	-96.0762492480337613
24356	2020-05-11 12:14:41	2020-05-11	Foster Hyatt	foster.hyatt@geemail.com	Corpus Christi	Texas	52171813528146268	d4814016ebad2bd598254fa842e97048	JCB 16 digit	27.7528016380436711	-97.2357387357685781
24357	2020-05-11 12:14:53	2020-05-11	Dr. Lenny Kerluke V	dr.lenny.kerluke.v@geemail.com	Lexington	Kentucky	3058485814298357	ae7d2d507fe63d812c06b0815c95dace	Discover	38.1213682815309625	-84.5183665871053904
24358	2020-05-11 12:16:34	2020-05-11	Eston Borer	eston.borer@geemail.com	Jackson	Mississippi	6011077799153447862	2f71559abde411c0f84d8213926db357	Diners Club / Carte Blanche	32.3762669417254685	-90.1717838145300732
24359	2020-05-11 12:24:22	2020-05-11	Jessie Wiza	jessie.wiza@geemail.com	El Paso	Texas	54106256260943031	2643ba58ff1997db8bd15f05446ade11	Discover	31.8551068599630156	-106.356247480537746
24360	2020-05-11 12:26:14	2020-05-11	Mavis Ziemann	mavis.ziemann@geemail.com	St. Louis	Missouri	3528922272302637889	5f5c3b0bb0e566f757350eb1ec9ce7e6	JCB 15 digit	38.6366135518688694	-90.1787411072760818
24361	2020-05-11 12:26:59	2020-05-11	Verne Kozey	verne.kozey@geemail.com	Peoria	Arizona	4634914680075	e17dd1811bfd785463e107a86737577a	American Express	33.7102830902941548	-112.304167239034555
24362	2020-05-11 12:32:57	2020-05-11	Madie Mueller PhD	madie.mueller.phd@woohoo.com	Jacksonville	Florida	3158879611771703131	90f68963352bf68688031c452274d8bb	American Express	30.3230464712303132	-81.6199952477201833
24363	2020-05-11 12:38:45	2020-05-11	Shasta Bartell-Beier	shasta.bartell.beier@warmmail.com	Santa Clara	California	52757409120926413	3c8c171d85f3d8c26c419014810f2516	Voyager	37.3836981531515775	-122.04206800996289
24364	2020-05-11 13:03:32	2020-05-11	Roberta Ruecker DVM	roberta.ruecker.dvm@geemail.com	Milwaukee	Wisconsin	52644527001908809	47d90c3121f9462f048b19a156b5f78b	VISA 16 digit	43.0931427019268227	-88.0132239461045742
24365	2020-05-11 13:08:28	2020-05-11	Kathryne Ruecker	kathryne.ruecker@geemail.com	San Diego	California	3006014587610044	580ee0c9ecee91725fd1f14348353c49	JCB 16 digit	32.8368310696978156	-117.122236510170623
24366	2020-05-11 13:33:45	2020-05-11	Thora Tremblay	thora.tremblay@geemail.com	Fort Worth	Texas	4765492356705909	2561157fdb7ca6872b805a5eab5502c4	VISA 13 digit	32.7761526658255633	-97.3808745777521239
24367	2020-05-11 13:47:55	2020-05-11	Manning Stehr	manning.stehr@warmmail.com	San Francisco	California	3096952126291304427	06b690f1b0d96aa5a7b0ae2ab1dc4a61	JCB 16 digit	37.7734280317731717	-122.444873912439832
24368	2020-05-11 13:50:06	2020-05-11	Sudie Murray-Nader	sudie.murray.nader@geemail.com	Pittsburgh	Pennsylvania	3337889417003480714	ec9c49158798f3e39ad031cdb0266be3	VISA 13 digit	40.4028211425479498	-80.0609718139920403
24369	2020-05-11 14:14:25	2020-05-11	Skyla Bednar	skyla.bednar@warmmail.com	Columbia	Missouri	4250373204205486	206c47bff3b84434ebd58d67348cfb04	VISA 16 digit	38.9343456361789819	-92.266940744785316
24370	2020-05-11 14:14:26	2020-05-11	Payton Stamm	payton.stamm@warmmail.com	New Haven	Connecticut	3038058316292424	ad4fb7473117bb45f36ccbecf58a9634	VISA 13 digit	41.3987436238668849	-72.9895873937290105
24371	2020-05-11 14:23:07	2020-05-11	Miss Cheri Yundt	miss.cheri.yundt@geemail.com	San Francisco	California	6011927529349878023	35fceec2ce202f3d37350d918e24ea63	VISA 13 digit	37.793482117263558	-122.435541408183425
24372	2020-05-11 14:25:21	2020-05-11	Claud Sporer	claud.sporer@geemail.com	San Francisco	California	55380663951290522	62302a16e000de465b4a3519bbf06265	Diners Club / Carte Blanche	37.7895229755108275	-122.45391096944094
24373	2020-05-11 14:39:49	2020-05-11	Jadyn Treutel	jadyn.treutel@geemail.com	Athens	Georgia	51149993688313327	06b484636fb71e9b16aca4401c3e6fec	VISA 16 digit	33.8838111968901003	-83.3114714063353716
24374	2020-05-11 14:40:26	2020-05-11	Holland Grant-Zboncak	holland.grant.zboncak@geemail.com	Los Angeles	California	3158088884309149203	acb72bc3725ba481598a74e72ffdf6a7	VISA 16 digit	33.9588459155388165	-118.496920688216761
24375	2020-05-11 14:41:23	2020-05-11	Brande Brown	brande.brown@geemail.com	San Francisco	California	3007145618777060	9583d114d254c396b48fa8e2cd6de95c	Voyager	37.7673165416893895	-122.414092815690978
24376	2020-05-11 14:46:10	2020-05-11	Darold Emmerich	darold.emmerich@geemail.com	Antioch	California	4713775018844592	e3874d6005a96069476fbd4ca61a4400	JCB 15 digit	37.9479583916984495	-121.704262567375594
24377	2020-05-11 15:09:43	2020-05-11	Gail Jacobs	gail.jacobs@warmmail.com	Newport News	Virginia	210086561612871622	9ff4f47314b59e6da06baaed5d054da6	JCB 16 digit	37.1669746605109452	-76.5844376726802523
24378	2020-05-11 15:50:33	2020-05-11	Danyel Beier-Powlowski	danyel.beier.powlowski@geemail.com	Los Angeles	California	589375061515344	6e4fa079eff92a187fd63107c75aeb5f	JCB 15 digit	33.9628023001231227	-118.457458470202226
24379	2020-05-11 16:04:22	2020-05-11	Miss Chelsey Kreiger DDS	miss.chelsey.kreiger.dds@warmmail.com	San Francisco	California	3001567969913778	d36ff183627196258c3620fc6a61c5bd	Maestro	37.805058607253379	-122.430547764966789
24380	2020-05-11 16:11:13	2020-05-11	Ruel Wintheiser	ruel.wintheiser@geemail.com	Davie	Florida	4776117396708046	3d320ddcc627b07ad1822fe27647e967	Diners Club / Carte Blanche	26.1208162121739242	-80.3383341811969842
24381	2020-05-11 16:15:43	2020-05-11	Stephan Kiehn	stephan.kiehn@woohoo.com	New York	New York	869973198489770002	2428aae48a61c39005a110881d0e18e4	JCB 16 digit	40.6126797756869351	-73.9164610527351442
24382	2020-05-11 16:21:14	2020-05-11	Jessika Feest	jessika.feest@geemail.com	Los Angeles	California	502060652996442	52dc501ac856e067ede0841052cd86c3	VISA 13 digit	34.0375648741941887	-118.348464403114463
24383	2020-05-11 16:25:08	2020-05-11	Maria Botsford	maria.botsford@geemail.com	New York	New York	4039635449109	ffdce507355bb02f8a2f1900ac311148	Maestro	40.7116467090081429	-73.8546621313679879
24384	2020-05-11 16:27:01	2020-05-11	Cary Yost	cary.yost@woohoo.com	San Francisco	California	4243470251713121	d890471a6c861389cab4795f116e3763	Diners Club / Carte Blanche	37.7691507203539913	-122.424358378006318
24385	2020-05-11 16:34:43	2020-05-11	Willow Gorczany	willow.gorczany@geemail.com	Washington	District of Columbia	6011872777531740817	56ae8a4083d4c41eae6c214cb9a07efe	VISA 16 digit	38.998390298176929	-77.0153571987736996
24386	2020-05-11 16:35:18	2020-05-11	Rayan Pfannerstill	rayan.pfannerstill@warmmail.com	Plano	Texas	3016180109525430	f123b9fadeb0e2573bb48733c95ba451	Diners Club / Carte Blanche	33.0390313189562406	-96.8171160637117936
24387	2020-05-11 16:42:52	2020-05-11	Primus Reynolds	primus.reynolds@woohoo.com	San Francisco	California	6011529501713103611	a87a9f5bb751091d9bbe557d790651c8	VISA 16 digit	37.7615002111145159	-122.444535856105077
24388	2020-05-11 16:55:47	2020-05-11	Curtis Beatty	curtis.beatty@woohoo.com	Louisville	Kentucky	51293453816002692	3fc307ab4fb58808ef17f2de67a55e3f	VISA 16 digit	38.2318754286874096	-85.7140796663776143
24389	2020-05-11 17:16:22	2020-05-11	Dr. Crissie Ratke	dr.crissie.ratke@geemail.com	Riverside	California	676176064054992	f48dec6b6516e17eda6281c1041fedc0	VISA 16 digit	34.0232384411100313	-117.301411187506091
24390	2020-05-11 17:20:48	2020-05-11	Gaige Gutmann IV	gaige.gutmann.iv@geemail.com	New York	New York	3096200227136415442	3393273d1e00854118d1456f64f4c15b	VISA 16 digit	40.575994123820216	-74.0228404162347289
24391	2020-05-11 17:26:20	2020-05-11	Damari Treutel-Walter	damari.treutel.walter@geemail.com	Phoenix	Arizona	3010987606464327	d5430b80838ff2696cbe85e1254f3ff2	Voyager	33.5758709154490376	-112.102446422113488
24392	2020-05-11 17:38:44	2020-05-11	Metro Schuppe	metro.schuppe@woohoo.com	Nashville	Tennessee	3028942384535048	c9e57cfd7d53e5c1c476105e99090635	JCB 16 digit	36.1336548200931347	-86.7056790623255011
24393	2020-05-11 17:51:06	2020-05-11	Isidor Borer	isidor.borer@geemail.com	Columbus	Ohio	4592452692452052	5a156a2e87a4fe055dfefaed1c2debc8	VISA 13 digit	39.9896866120908427	-82.9435247120216559
24394	2020-05-11 17:56:06	2020-05-11	Leila Barrows-Deckow	leila.barrows.deckow@warmmail.com	New York	New York	3158781261364785736	ad784780e4df3d7160d2bdeff975c189	Voyager	40.7373804254680891	-73.8910183687124373
24395	2020-05-11 18:25:20	2020-05-11	Pinkey Klocko	pinkey.klocko@geemail.com	Chicago	Illinois	4582380589231	01730cacb790da57c9df026b9553fcb8	Mastercard	41.8082766011193385	-87.6419256530266182
24396	2020-05-11 18:41:03	2020-05-11	Amiyah Olson	amiyah.olson@geemail.com	Oakland	California	4000324551436342	a8295641163737ab10659feb6a5aa476	Discover	37.8221923825874455	-122.28801060623492
24397	2020-05-11 18:56:38	2020-05-11	Tamisha Welch DVM	tamisha.welch.dvm@geemail.com	Oklahoma City	Oklahoma	3112278875333717163	9219f1a1492b72bbf1ef036a3dd97e55	JCB 16 digit	35.483709473712743	-97.4257643387082908
24398	2020-05-11 18:59:30	2020-05-11	Henri Romaguera	henri.romaguera@geemail.com	Jacksonville	Florida	4484353221597	bd524483d41fb5725247fee96ab34694	Voyager	30.2561365074530251	-81.6756445959288726
24399	2020-05-11 19:02:13	2020-05-11	Gerhard Grant	gerhard.grant@warmmail.com	Newport News	Virginia	210059919530498634	b5e8a873ca2ac89acca8528873593781	Diners Club / Carte Blanche	36.9816195683449536	-76.4787456317134229
24400	2020-05-11 19:06:31	2020-05-11	Roma Strosin	roma.strosin@geemail.com	Ontario	California	630430020633555	f57cf54e1469842a8128cb136decb74f	VISA 13 digit	33.9398319644067428	-117.538431008589271
24401	2020-05-11 19:07:31	2020-05-11	Kael Collier	kael.collier@geemail.com	Indianapolis	Indiana	501847597033530	516fe56a3d454f690c2558d47e7738eb	VISA 13 digit	39.6853851179134054	-86.1599931133646493
24402	2020-05-11 19:15:27	2020-05-11	Dr. Hansel Ankunding II	dr.hansel.ankunding.ii@woohoo.com	Berkeley	California	3158388786026237350	f0a37e48f7a1bfff65ad82acc5c0d2e1	JCB 15 digit	37.8424715678802599	-122.292791965926966
24403	2020-05-11 19:22:53	2020-05-11	Phoenix Harber	phoenix.harber@warmmail.com	New York	New York	630468794567484	e5f6aa70bff69341e100ad9d31e97bdf	American Express	40.7087237611170849	-74.009424598830563
24404	2020-05-11 19:53:27	2020-05-11	Mr. Laron Hermiston IV	mr.laron.hermiston.iv@geemail.com	San Jose	California	4736172315979	a967f0c26ffb98b433271915926249d6	JCB 15 digit	37.3463417870745076	-121.849809876339137
24405	2020-05-11 20:22:21	2020-05-11	Dr. Hilton Zemlak III	dr.hilton.zemlak.iii@warmmail.com	Santa Ana	California	3112934403688460465	3755f1507e78046a19ef200ee295a5e5	JCB 15 digit	33.8049228976119309	-117.807456422962247
24406	2020-05-11 20:25:27	2020-05-11	Dawn Dietrich-Senger	dawn.dietrich.senger@geemail.com	Boston	Massachusetts	3022811242977070	805fb94554a5c5ba78bdcc51ec6d3165	Mastercard	42.4242053549438722	-71.0899363094892323
24407	2020-05-11 21:05:26	2020-05-11	Warren Keebler	warren.keebler@geemail.com	Oakland	California	3088858545357039871	5b8ff4bef5d69582a53ea8c9ae0555dd	Maestro	37.7993560376113606	-122.255335588761653
24408	2020-05-11 21:31:37	2020-05-11	Nohely Jast	nohely.jast@geemail.com	Washington	District of Columbia	869984826539354446	6f6216be54a7816ac8618abfd5987496	Discover	38.9321485062394288	-77.1156338683076257
24409	2020-05-11 21:31:41	2020-05-11	Mr. Dequan Borer	mr.dequan.borer@warmmail.com	Murfreesboro	Tennessee	4641383949923	cf3fe981367423b9dbd9f3a6733fb58f	Mastercard	35.782434547425062	-86.3482159806732028
24410	2020-05-11 21:35:43	2020-05-11	Kunta Smitham-Wyman	kunta.smitham.wyman@woohoo.com	Tempe	Arizona	6011566236271309987	21b730ff37da22937ca67e723415bebf	Diners Club / Carte Blanche	33.3797064048625529	-111.932548172355808
24411	2020-05-11 21:53:16	2020-05-11	Shellie Bauch	shellie.bauch@warmmail.com	Yonkers	New York	3755906292829266	7f190988f6d42c9f3f4aacfb13a21448	American Express	40.8794415599867733	-73.8842362014461287
24412	2020-05-11 21:56:37	2020-05-11	Harris Jerde	harris.jerde@geemail.com	Dayton	Ohio	3337248974665652085	6bc3d3c8176522fc66aad444566ca813	VISA 16 digit	39.749252998808025	-84.2297681986544262
24413	2020-05-11 22:00:04	2020-05-11	Dr. Lyric Shields	dr.lyric.shields@geemail.com	Rancho Cucamonga	California	210048887810981690	29e4c059c022fa42ea9b3f29769b92f9	Diners Club / Carte Blanche	34.0719093378625786	-117.526294753282144
24414	2020-05-11 22:01:53	2020-05-11	Maria Lind	maria.lind@geemail.com	Phoenix	Arizona	3528183134615265960	6c62e7be5e5a7fab98dee9a4008e0440	Voyager	33.5707171627253302	-112.11902075413839
24415	2020-05-11 22:18:18	2020-05-11	Mr. Alvie Jacobs	mr.alvie.jacobs@geemail.com	Fort Worth	Texas	3096728569866173623	bf8ac4015b7d08565383ae8d697e2d09	JCB 15 digit	32.7277242783978579	-97.2582799053572131
24416	2020-05-11 22:19:29	2020-05-11	Dr. Tawnya Donnelly	dr.tawnya.donnelly@warmmail.com	Charlotte	North Carolina	060405361078073	94662afd78b7d2790d992ca17df1fc02	VISA 16 digit	35.2679483245380183	-80.8699781869482308
24417	2020-05-11 22:19:38	2020-05-11	Dr. Jayvion Wilderman MD	dr.jayvion.wilderman.md@geemail.com	Berkeley	California	53116895936875313	0b36d29f612c0b9621e46ebf51f33c4a	Maestro	37.8826939597091226	-122.271179345449298
24418	2020-05-11 22:24:41	2020-05-11	Gregg Johns	gregg.johns@geemail.com	Wichita	Kansas	869981540109778404	04f29dc3b7ec3b8221467cd2a884d311	Diners Club / Carte Blanche	37.6357707545038309	-97.365251206580183
24419	2020-05-11 23:09:24	2020-05-11	Risa Pagac	risa.pagac@geemail.com	Philadelphia	Pennsylvania	3464720199249521	cbd460f65ac82ee0852002aff0434635	American Express	40.0424473929643625	-75.1402467285648044
24420	2020-05-11 23:09:24	2020-05-11	Rolanda Padberg	rolanda.padberg@warmmail.com	Columbus	Ohio	6011883877373460347	fb119c2f38fd6249b0ed6d41b1b08cfd	VISA 16 digit	39.8928444257050714	-83.0411233595807232
24421	2020-05-11 23:10:20	2020-05-11	Dr. Kayson Zboncak V	dr.kayson.zboncak.v@geemail.com	Fontana	California	3023653041924807	518ae9dfda8777d3051abbeb3aecbc6f	Maestro	34.1075025126487006	-117.392373209800198
24422	2020-05-11 23:13:53	2020-05-11	Lesley Harber	lesley.harber@woohoo.com	St. Petersburg	Florida	3096264568827456002	f218d70cf3ac0bcd7f26f052dc6fc6bb	JCB 15 digit	27.7517988840471972	-82.6091460317265245
24423	2020-05-11 23:41:09	2020-05-11	Adriane Sauer DDS	adriane.sauer.dds@geemail.com	Waco	Texas	52671933958875270	40855b20b425a402fbdae6433a2db17f	VISA 13 digit	31.4736609409306176	-97.185373903218661
24424	2020-05-11 23:41:47	2020-05-11	Luverne Morissette MD	luverne.morissette.md@geemail.com	Charlotte	North Carolina	6011650946572585229	f2f4e06a72ebffa2d6f613bcb21144c4	JCB 16 digit	35.2766390239607546	-80.7364242759011717
24425	2020-05-12 00:03:06	2020-05-12	Evelynn Waelchi	evelynn.waelchi@warmmail.com	Mobile	Alabama	3435830469994817	6cb16fec8ba05d6c1e8ea0fe16fb0b74	VISA 16 digit	30.7424679100155807	-88.068118201023708
24426	2020-05-12 00:03:21	2020-05-12	Alina McLaughlin	alina.mclaughlin@geemail.com	Boston	Massachusetts	3112286571492831826	467c8b417d578421c412b6ba1fbc2e90	Diners Club / Carte Blanche	42.4159077537879341	-71.0292088626835465
24427	2020-05-12 00:08:15	2020-05-12	Jule Sawayn	jule.sawayn@warmmail.com	Tampa	Florida	6011284184224033810	8b0a36c47b22b96fbb7c69d7e3fefd15	Mastercard	27.9537566161829965	-82.541309266605225
24428	2020-05-12 00:12:28	2020-05-12	Gaven Hauck	gaven.hauck@woohoo.com	Tucson	Arizona	3088865923624804453	e6d14d5bec91ceb81160b26c30dcd266	Voyager	32.0749914193101233	-110.850701446807378
24429	2020-05-12 00:17:46	2020-05-12	Polly Dibbert DDS	polly.dibbert.dds@geemail.com	Spokane	Washington	3472674485269604	ab9ecd8f1ab04b353380a514105f4b91	VISA 13 digit	47.6554688921902283	-117.451275503765046
24430	2020-05-12 00:53:42	2020-05-12	Shanita Rath DVM	shanita.rath.dvm@warmmail.com	Los Angeles	California	3797974511764938	53ea8d5d9e0413a8fd603f3a7d09a9a5	Maestro	34.0975846838071917	-118.468206280748547
24431	2020-05-12 01:32:00	2020-05-12	Jada Mraz	jada.mraz@warmmail.com	Tampa	Florida	3112893273381177982	3cdf0b13a2e2b3f89bfa6b541d2d1e0d	Discover	28.0066130264777691	-82.4685195042498407
24432	2020-05-12 01:34:25	2020-05-12	Mrs. Twyla Bosco	mrs.twyla.bosco@geemail.com	Burbank	California	675922149752432	16b9536cc19261717daa7c24416634fa	VISA 16 digit	34.2581527514778088	-118.320877460999043
24433	2020-05-12 01:46:49	2020-05-12	Mannie Schamberger	mannie.schamberger@geemail.com	Atlanta	Georgia	3112912527092127843	c06f0ce76bb3617b6b06879c8a617f89	American Express	33.6890644559912431	-84.362226715641853
24434	2020-05-12 01:47:47	2020-05-12	Malcom Adams	malcom.adams@geemail.com	Berkeley	California	6011735075116705108	094155353e1bc46c53720ed11d756460	Mastercard	37.9118204730165047	-122.266538876289744
24435	2020-05-12 01:56:22	2020-05-12	Misael Little V	misael.little.v@warmmail.com	San Francisco	California	4162253645125930	562b0c434962fa1126538bdd3b29bca1	Mastercard	37.7652175923032232	-122.444166409753777
24436	2020-05-12 02:36:27	2020-05-12	Christop Blanda	christop.blanda@geemail.com	Los Angeles	California	210041047178235885	044205f7b0d53251dd1ff144148dd2d1	Diners Club / Carte Blanche	33.9860802864987406	-118.342572859115151
24437	2020-05-12 02:41:16	2020-05-12	Geovanni Nitzsche	geovanni.nitzsche@geemail.com	Berkeley	California	6011727265859436637	404f9c6c7ca5e3cf5795676a227b0e9f	Discover	37.8600425446091364	-122.282870520987785
24438	2020-05-12 02:48:50	2020-05-12	Mr. Kelan Oberbrunner PhD	mr.kelan.oberbrunner.phd@geemail.com	Warren	Michigan	6011831382874077347	277cd9570c261afe51b504045da6f085	American Express	42.4876643714956899	-82.9942225424572939
24439	2020-05-12 02:51:13	2020-05-12	Faith Wilkinson	faith.wilkinson@geemail.com	College Station	Texas	52847009913180194	9adeca2f03a2e77358603a30e85f98b1	Discover	30.549392604366691	-96.2529536538139041
24440	2020-05-12 02:51:15	2020-05-12	Lukas Maggio	lukas.maggio@warmmail.com	New York	New York	6011703093048110600	300e31300c263979be219341227b26ab	American Express	40.6553594941962473	-73.9662903904810491
24441	2020-05-12 02:56:08	2020-05-12	Montana Bergnaum IV	montana.bergnaum.iv@geemail.com	San Francisco	California	3088421205583296443	b1700dae63d31773bb8bd50cd1a562ff	VISA 16 digit	37.795801694723032	-122.433129078293064
24442	2020-05-12 03:00:00	2020-05-12	Mr. Bertie O'Connell	mr.bertie.o'connell@warmmail.com	Denver	Colorado	060427115779939	441a61137e3577f894fa6da720662bd8	Maestro	39.8076507564220563	-104.904863205483565
24443	2020-05-12 03:08:38	2020-05-12	Mrs. Cleora Zemlak DVM	mrs.cleora.zemlak.dvm@warmmail.com	New York	New York	3112218757609862613	ccc7e9673fddd4513ba500e5001d059f	Mastercard	40.7169250397235132	-73.8509478166129441
24444	2020-05-12 03:09:33	2020-05-12	Maryann Schaefer	maryann.schaefer@geemail.com	Sterling Heights	Michigan	51661523906078580	32447f0750bab8c080fdc840ff6903c7	VISA 16 digit	42.5149766289245363	-82.9450036068141401
24445	2020-05-12 03:19:55	2020-05-12	Kiley Haley	kiley.haley@geemail.com	Corpus Christi	Texas	3096620280772512701	f4a9101b71bb57e8e7cdf66b0eeda942	Discover	27.7882069339446716	-97.1815232728902316
24446	2020-05-12 03:22:43	2020-05-12	Hampton Williamson	hampton.williamson@warmmail.com	Columbus	Ohio	4777763367953	22d930088115a6f5b2a2bda04d9bcd95	JCB 16 digit	40.0518966171003896	-82.9366018049188085
24447	2020-05-12 03:31:52	2020-05-12	Humphrey Rippin	humphrey.rippin@woohoo.com	Little Rock	Arkansas	3088751435859761933	4fb7ea628a7715c72eb07e7314b8ff8a	VISA 16 digit	34.7031214092202518	-92.3408569955140308
24448	2020-05-12 03:45:51	2020-05-12	Carolina Bartoletti	carolina.bartoletti@geemail.com	Oklahoma City	Oklahoma	3494803921681791	bbc6ca8a8565bca160753dc5126a3280	JCB 16 digit	35.39885973156467	-97.5472056581068756
24449	2020-05-12 03:57:05	2020-05-12	Ms. Hellen Beer	ms.hellen.beer@geemail.com	New York	New York	6011337779623943241	a55d4412f2630d4aaf922e49a4f61aec	Voyager	40.63160070420615	-73.9548849658936263
24450	2020-05-12 04:18:38	2020-05-12	Adams Hoppe-Miller	adams.hoppe.miller@geemail.com	Los Angeles	California	4621973004107	96d9f3dc857153ea53f145e12c05352b	Discover	33.9997676945157323	-118.311703804507104
24451	2020-05-12 04:21:39	2020-05-12	Alton Feest	alton.feest@geemail.com	Laredo	Texas	210065892746571738	4769c20070fb9c4ed351136a40e94bf1	JCB 16 digit	27.4979895510893328	-99.4033308288555588
24452	2020-05-12 04:36:18	2020-05-12	Nils Jacobi	nils.jacobi@warmmail.com	San Francisco	California	6011835121694857256	44a1718e966e5e853e1e3af3ed2921fb	JCB 16 digit	37.7721656906320007	-122.441618615747387
24453	2020-05-12 04:36:33	2020-05-12	Mr. Delphin Weimann	mr.delphin.weimann@geemail.com	Lexington	Kentucky	869960591206457348	3b937372fad26edaece12da50f12d972	VISA 13 digit	37.9571922798983792	-84.4070315858248534
24454	2020-05-12 04:55:58	2020-05-12	Clora Harvey	clora.harvey@geemail.com	Reno	Nevada	676228596955006	f93ef2d1b1b792ffe1ed41ac3a842687	VISA 16 digit	39.6211042038708925	-119.932921321939304
24455	2020-05-12 04:56:11	2020-05-12	Alanzo Paucek	alanzo.paucek@geemail.com	Surprise	Arizona	4803558318561160	22ab5b78fcf4d92bda92203b54e0900a	Diners Club / Carte Blanche	33.6647344228107457	-112.494045747793081
24456	2020-05-12 05:00:19	2020-05-12	Leslee Gorczany	leslee.gorczany@geemail.com	San Francisco	California	210072661363077027	7f6e54f97349f4601a9b81e13ca7c290	American Express	37.7578628342216049	-122.424828537155648
24457	2020-05-12 05:10:42	2020-05-12	Jackeline Kohler DVM	jackeline.kohler.dvm@geemail.com	El Paso	Texas	4382399477966083	fab2bd7d8f4b155b16628edd627926a1	JCB 16 digit	31.9337865270502874	-106.342592236863453
24458	2020-05-12 05:36:30	2020-05-12	Miss May Walter MD	miss.may.walter.md@geemail.com	Berkeley	California	3112720969324278279	6fca442692a4f1d118f6f24a6c4e9ee1	American Express	37.8714873941421999	-122.288868717869505
24459	2020-05-12 05:44:25	2020-05-12	Dr. Dejuan Parker DVM	dr.dejuan.parker.dvm@warmmail.com	Chicago	Illinois	4023281542029	1b692e94ed552073990fd28d01453767	VISA 13 digit	41.7854035359643419	-87.6827649557992714
24460	2020-05-12 05:44:52	2020-05-12	Dr. Garrison Emard	dr.garrison.emard@geemail.com	Reno	Nevada	4787465181040	e4d99b45dd9ff7738d1791645da56269	VISA 13 digit	39.5102691963858916	-119.880453350551065
24461	2020-05-12 05:49:46	2020-05-12	Hannah Stiedemann	hannah.stiedemann@warmmail.com	New York	New York	4960664616894052	e0a6d891f66727b45bef265b9a67bdb8	JCB 16 digit	40.568588685546068	-73.9363075408980279
24462	2020-05-12 05:50:05	2020-05-12	Dr. Connie Sawayn MD	dr.connie.sawayn.md@geemail.com	Fort Wayne	Indiana	180020075866600552	63cdd88d9457bc3ba0fc388ea7ca79a8	JCB 16 digit	41.1025892686348442	-85.1237192679882071
24463	2020-05-12 05:57:47	2020-05-12	Leisha Ryan	leisha.ryan@geemail.com	San Diego	California	3088851419868710452	7c76cc047ab54de0865fa72b81e54b67	Maestro	32.7458231170263119	-117.228832143489271
24464	2020-05-12 06:00:11	2020-05-12	Natasha Fisher	natasha.fisher@geemail.com	San Francisco	California	4128925715406695	59ccc8f3735205e1aa1743f6e821c062	VISA 16 digit	37.7983036452395211	-122.418471120420264
24465	2020-05-12 06:23:06	2020-05-12	Farris Stokes	farris.stokes@geemail.com	Lincoln	Nebraska	869961548112565753	1ccb80bdae7760602d0b3be05d3528ce	JCB 15 digit	40.7285999918840815	-96.7222237201567765
24466	2020-05-12 06:26:22	2020-05-12	Zoa Reichel	zoa.reichel@geemail.com	Overland Park	Kansas	869922276612967695	200ada11726dbfd3eabe07d04e986d6c	VISA 13 digit	38.903582862565294	-94.6161626959260644
24467	2020-05-12 06:35:17	2020-05-12	China Morar MD	china.morar.md@geemail.com	Moreno Valley	California	3477040006140887	7b2df8dd68d07150866c236389de793d	Diners Club / Carte Blanche	33.9893750682465736	-117.163488416463878
24468	2020-05-12 06:47:16	2020-05-12	Robb Cole	robb.cole@geemail.com	League City	Texas	3112867460458325238	2d5cd9622e6f102da219c8ef503119f3	VISA 13 digit	29.4835754937421548	-95.085100536046923
24469	2020-05-12 07:18:32	2020-05-12	Chandra Crooks DDS	chandra.crooks.dds@woohoo.com	Tacoma	Washington	3030807423820289	504c347c488d3eb6732beff7bf997bb0	Mastercard	47.2234288605980623	-122.514906008099388
24470	2020-05-12 07:23:35	2020-05-12	Dr. Pinkey Langworth	dr.pinkey.langworth@geemail.com	Philadelphia	Pennsylvania	6011084693626419031	1d15af7d7af48e02c8fdec98a3300561	Mastercard	40.041030232790483	-75.188695497381687
24471	2020-05-12 07:25:46	2020-05-12	Desmond Lindgren	desmond.lindgren@geemail.com	San Francisco	California	676287787402343	a4fd27a995d8b01a1ee1e3371718c83b	VISA 13 digit	37.7785964394415359	-122.426940496398871
24472	2020-05-12 07:39:33	2020-05-12	Francis Langosh IV	francis.langosh.iv@geemail.com	Phoenix	Arizona	4513102933370813	daf535580b423bf4790a102550e266bf	Diners Club / Carte Blanche	33.628866780775418	-112.030829670366273
24473	2020-05-12 07:53:40	2020-05-12	Shara Stamm	shara.stamm@geemail.com	New York	New York	3112416664863915030	57ec5c8b920241e3eb996feb20cbad61	JCB 15 digit	40.6015071269348269	-74.0045955280669006
24474	2020-05-12 07:57:47	2020-05-12	Esperanza Konopelski	esperanza.konopelski@geemail.com	Berkeley	California	3112991129269718910	b11efb6cd2ba331e0df0882bfc8432f5	American Express	37.8445089221659217	-122.256698940262382
24475	2020-05-12 07:57:53	2020-05-12	Garvin Barrows	garvin.barrows@woohoo.com	Kansas City	Kansas	3096125558640230931	74896c8d4fe9f06699e703068eed8862	Discover	39.1254322689864793	-94.8393678782910143
24476	2020-05-12 07:59:12	2020-05-12	Jerusha Runolfsdottir-Yundt	jerusha.runolfsdottir.yundt@warmmail.com	Oklahoma City	Oklahoma	180047883172810990	d7a0818993efa0368491ed0a58a71296	Voyager	35.4721680162385127	-97.4304236870620457
24477	2020-05-12 08:28:47	2020-05-12	Kem Crona	kem.crona@geemail.com	Colorado Springs	Colorado	3418219740032178	5d6414543fe76c4784ae15b03dfdce81	JCB 15 digit	38.8367568161852645	-104.665983093173054
24478	2020-05-12 08:50:58	2020-05-12	Deedee Stiedemann	deedee.stiedemann@geemail.com	Fremont	California	180073322383567963	830362aa0d4294cf98d74a8c83f22724	Mastercard	37.5648049653209739	-121.980465546761451
24479	2020-05-12 09:01:40	2020-05-12	Thornton Cassin	thornton.cassin@woohoo.com	Nashville	Tennessee	3112868454395304850	8e8ad95f04ba7b64769b6de6f14ba6ae	Discover	36.198948821903393	-86.7321137985587143
24480	2020-05-12 09:06:37	2020-05-12	Zachariah Kris	zachariah.kris@geemail.com	Chula Vista	California	55604251554563261	60e8aba0aca883f696d4d758a2c29273	Maestro	32.5744264720238732	-117.110147140105056
24481	2020-05-12 09:10:59	2020-05-12	Almond Hessel MD	almond.hessel.md@geemail.com	Tacoma	Washington	4561422328905028	f767751f15ac7111db4c5960d0cecd7e	Voyager	47.2084533253803897	-122.416848809574915
24482	2020-05-12 09:11:38	2020-05-12	Miss Miya Blick	miss.miya.blick@geemail.com	San Francisco	California	4263647619948599	85e1afdd0e41526a96a00af140d6e504	JCB 16 digit	37.7444875959813118	-122.449510902999435
24483	2020-05-12 09:17:18	2020-05-12	Newt Goodwin-Kautzer	newt.goodwin.kautzer@woohoo.com	Cincinnati	Ohio	3005401413708269	8a58a7c8b6a10e4c66f28cd051d1ed39	American Express	39.0965251846004307	-84.5064533179432118
24484	2020-05-12 09:18:54	2020-05-12	Liam Reichel	liam.reichel@geemail.com	Sioux Falls	South Dakota	53150431893271069	ceb97e1c0333ce5e119d0c84007adf9f	JCB 15 digit	43.6028949224941442	-96.7128282480109505
24485	2020-05-12 09:23:07	2020-05-12	Zachery Johnson	zachery.johnson@geemail.com	San Francisco	California	4870034641999	235c45acb166c4abf9f64c5c8b002b7f	VISA 16 digit	37.7935596980103057	-122.470587052129048
24486	2020-05-12 09:37:15	2020-05-12	Abril Howell	abril.howell@geemail.com	Madison	Wisconsin	180011996993815154	09cdbdd76dfc067eaa23462d1f93a125	JCB 16 digit	43.1532961307067424	-89.4485812498606805
24487	2020-05-12 09:39:03	2020-05-12	Bradly Bruen-Lang	bradly.bruen.lang@geemail.com	Antioch	California	3006950109694133	55ddb90bc3518cc5fe46b15c19b3fdc1	American Express	37.934525569787624	-121.738580562424659
24488	2020-05-12 09:44:34	2020-05-12	Koby Klein	koby.klein@geemail.com	Phoenix	Arizona	3088149162403666829	23407bbd70e8479c8fc614fabbb829ae	Diners Club / Carte Blanche	33.6373587879285267	-112.007066674197475
24489	2020-05-12 10:15:05	2020-05-12	Olie Botsford-Fisher	olie.botsford.fisher@warmmail.com	San Francisco	California	869997005690450732	77fdab7c95822e96afaed4709821f252	Voyager	37.7748271886877802	-122.447071586718664
24490	2020-05-12 10:22:36	2020-05-12	Leilani Hintz PhD	leilani.hintz.phd@geemail.com	Bridgeport	Connecticut	3096612263537695094	17019e19b727ecfba1163d63d7168975	Discover	41.1896847149986769	-73.2093446724481964
24491	2020-05-12 10:23:35	2020-05-12	Gerry Torphy	gerry.torphy@geemail.com	Oakland	California	869972178704943346	e8a26484211ea09ad5610478ff50c015	JCB 15 digit	37.7810199931584947	-122.254984680506183
24492	2020-05-12 10:30:24	2020-05-12	Dr. Stacey Blick Jr.	dr.stacey.blick.jr.@geemail.com	Philadelphia	Pennsylvania	55741542574032152	baeced5d5f277558b2e408af43975ba0	VISA 13 digit	40.0198762885719503	-75.1065906806748416
24493	2020-05-12 10:40:13	2020-05-12	Lenwood Osinski-Yost	lenwood.osinski.yost@woohoo.com	San Angelo	Texas	675947078074706	6adf5ee246d0e0a154c3ecf78288877b	VISA 16 digit	31.4878074012849467	-100.43343790933676
24494	2020-05-12 10:41:25	2020-05-12	Raegan Schulist DDS	raegan.schulist.dds@geemail.com	Los Angeles	California	869925114181327792	ac8583bcbeadee35be0d6fd4ac690f66	Diners Club / Carte Blanche	34.1016554648388137	-118.481314041138802
24495	2020-05-12 10:45:26	2020-05-12	Mr. Andra Collins	mr.andra.collins@geemail.com	Simi Valley	California	4019147607768437	c96ce31693bec2b5960510efa56bd7bf	VISA 16 digit	34.3052418769575667	-118.809409980162982
24496	2020-05-12 10:47:50	2020-05-12	Mr. Glendon Maggio	mr.glendon.maggio@geemail.com	New York	New York	4938408764812717	8eaef412dd40e7e33df3504b97c29671	Maestro	40.6765224260035865	-73.8863016329601408
24497	2020-05-12 10:49:37	2020-05-12	Mr. Donovan Runte V	mr.donovan.runte.v@woohoo.com	New York	New York	4987303098618	5af1ca7c1f2ad4ee788aaa5089fe1d23	Mastercard	40.5640661464761934	-73.9385774542938918
24498	2020-05-12 10:53:31	2020-05-12	Mrs. Elmira Medhurst	mrs.elmira.medhurst@geemail.com	San Jose	California	3015134136622125	96ad66fdc8d9452feba8deec41fb19f5	Mastercard	37.3223836577318622	-121.785850649395584
24499	2020-05-12 10:57:14	2020-05-12	Miss Rhona Watsica	miss.rhona.watsica@geemail.com	New Haven	Connecticut	55102570283413770	41b14057007a1cb9991cfd640e9c2cc2	Diners Club / Carte Blanche	41.2455228176891779	-72.9889402986038505
24500	2020-05-12 11:18:04	2020-05-12	Miss Ida Gleichner MD	miss.ida.gleichner.md@geemail.com	San Francisco	California	3528654423767260923	cd05e3cdcd2d0df545005c48af165016	American Express	37.7965152638398578	-122.415046706028591
24501	2020-05-12 11:18:24	2020-05-12	Dr. Sharon Conroy	dr.sharon.conroy@woohoo.com	Boston	Massachusetts	3052020060773211	ea473357074a47973799021e24e15e1d	Voyager	42.3191047962922582	-70.9435887766953641
24502	2020-05-12 11:40:00	2020-05-12	Aisha Maggio	aisha.maggio@geemail.com	Des Moines	Iowa	180016831194569083	6b0f822a617a018145cb774053e579eb	Discover	41.5969007417302592	-93.6730825572785051
24503	2020-05-12 11:40:05	2020-05-12	Mrs. Sydell O'Connell	mrs.sydell.o'connell@warmmail.com	Peoria	Arizona	4722879495933370	08e8dbaffc13bb44aa82b93bbaad65f3	VISA 16 digit	33.6938850015670042	-112.291313377946622
24504	2020-05-12 12:07:21	2020-05-12	Berniece Hilpert	berniece.hilpert@warmmail.com	Louisville	Kentucky	3784355012929136	611d04d7720d620a2911c50899d4d97f	JCB 15 digit	38.2209041169282031	-85.6998260260164813
24505	2020-05-12 12:12:42	2020-05-12	Pryor Jaskolski	pryor.jaskolski@geemail.com	Los Angeles	California	3158785434882539895	d25f17e815a79c7b9c712edc6b93fd7c	Maestro	34.1079602470952992	-118.323211435926325
24506	2020-05-12 12:28:11	2020-05-12	Kaylen Schmeler	kaylen.schmeler@geemail.com	Berkeley	California	4052600130444460	6b59af8693248ba056815641289e8026	Diners Club / Carte Blanche	37.8576384407410984	-122.272760841203521
24507	2020-05-12 12:32:28	2020-05-12	Chaney Yost	chaney.yost@geemail.com	Houston	Texas	639056230451025	c552bc75b997a9227ee9ea7649982aa8	Maestro	29.7048289435528226	-95.4893510112553798
24508	2020-05-12 12:53:56	2020-05-12	Kavon Gusikowski-Jakubowski	kavon.gusikowski.jakubowski@woohoo.com	Washington	District of Columbia	3528114482155150587	1ccd09cd20e97a9a6e862c78c14bae57	VISA 16 digit	38.9628674998212574	-77.0602545539129551
24509	2020-05-12 12:59:24	2020-05-12	Bartholomew Swift	bartholomew.swift@warmmail.com	New York	New York	210065104740035615	6b07dc5a9e4782e30127dff5b543357b	JCB 15 digit	40.7175997884236267	-73.8778383905895026
24510	2020-05-12 13:20:11	2020-05-12	Hildred Langworth	hildred.langworth@geemail.com	Murrieta	California	6011682846531388073	88d93be5951347f11ad02e26d671a620	JCB 15 digit	33.6659942910637682	-117.119876674273613
24511	2020-05-12 13:32:17	2020-05-12	Dr. Jerrod Gaylord Sr.	dr.jerrod.gaylord.sr.@geemail.com	Washington	District of Columbia	52189822540998671	a9032ac2fa3b0d5350a52366cf327f06	Mastercard	38.8928816933449326	-76.9600288892377193
24512	2020-05-12 13:58:27	2020-05-12	Leah Auer MD	leah.auer.md@geemail.com	Madison	Wisconsin	3112622913622859140	4793278ac5f0e9f8cccb2f3f275ab096	Mastercard	43.1220885200399948	-89.4734107466299093
24513	2020-05-12 14:17:14	2020-05-12	Delta Bauch	delta.bauch@warmmail.com	San Francisco	California	3429430658811878	dad16492fd58322d854c0b96fc3cf8ca	Maestro	37.7931397840692682	-122.437511299472021
24514	2020-05-12 14:34:37	2020-05-12	Bonny Hickle	bonny.hickle@geemail.com	Oakland	California	3009124125796895	1aa05d620ee03ba94ceefeef5f99f7f8	American Express	37.860521333576493	-122.230802092075677
24515	2020-05-12 14:44:22	2020-05-12	Anthony Bailey	anthony.bailey@geemail.com	High Point	North Carolina	3112074175582926029	eff06a2377cb7de6f9f5450ea0d76de7	JCB 16 digit	35.9416979395411929	-80.0176894018631373
24516	2020-05-12 14:45:08	2020-05-12	Leticia Leannon	leticia.leannon@geemail.com	Glendale	Arizona	503813323319619	264a63519f9af09edf9b4224bc9db422	JCB 15 digit	33.6222489307396089	-112.110428683485452
24517	2020-05-12 14:48:49	2020-05-12	Jacque Gleason DDS	jacque.gleason.dds@geemail.com	New York	New York	060403780115733	5ddee8554452fa7bd05c1e10f15db86b	VISA 16 digit	40.6553642262462489	-73.9586013261124435
24518	2020-05-12 14:55:34	2020-05-12	Latoria Breitenberg	latoria.breitenberg@woohoo.com	San Francisco	California	3337656244240368499	10a9fe6d2d3155c08e3efff1b51f3d21	American Express	37.7481522495165294	-122.458847375205494
24519	2020-05-12 15:04:42	2020-05-12	Gustav Kohler DVM	gustav.kohler.dvm@geemail.com	New York	New York	630474771150005	53428265ed2e99c14a75b2ea33ca8f0e	VISA 13 digit	40.6982365831024921	-74.0108946175675868
24520	2020-05-12 15:08:53	2020-05-12	Talmage Bruen	talmage.bruen@warmmail.com	Sunnyvale	California	6011595599700494174	250dbeccb14861bb9b6f4bfd32fd61e2	VISA 16 digit	37.4450650903854552	-122.08988354901895
24521	2020-05-12 15:13:38	2020-05-12	Catharine Sipes MD	catharine.sipes.md@geemail.com	Anaheim	California	3337434549613223579	785e058a7069739c63d466ae9beb0bff	Maestro	33.7706535932440275	-117.683701793963451
24522	2020-05-12 15:16:13	2020-05-12	Ryne Larson	ryne.larson@geemail.com	Phoenix	Arizona	6011727701221363547	d888c791be05b3231334db44e73545fb	JCB 16 digit	33.4887160131640726	-112.187858748196078
24523	2020-05-12 15:16:46	2020-05-12	Kelley Lockman I	kelley.lockman.i@geemail.com	San Francisco	California	4855491988950512	de5ad7ecf8a4b54b54048240a15eaf03	VISA 16 digit	37.77591418065591	-122.432657962625029
24524	2020-05-12 15:43:05	2020-05-12	Niki Kilback DVM	niki.kilback.dvm@geemail.com	Baltimore	Maryland	3096483703103264946	98a05d97ae55ec65be5fd2e43162dd91	JCB 16 digit	39.2393164493609206	-76.6368991734013036
24525	2020-05-12 15:53:17	2020-05-12	Mylee Feest	mylee.feest@geemail.com	Huntington Beach	California	4287935236978152	4b24556b1a169b98aaf28afd31826ceb	JCB 15 digit	33.651287380563474	-117.998481625191118
24526	2020-05-12 15:54:59	2020-05-12	Carly Walter	carly.walter@geemail.com	Fort Wayne	Indiana	4321452160511155	cd0c3d752218cca2247e71d87db38b9f	VISA 13 digit	40.9996505209028754	-85.1879656461753001
24527	2020-05-12 16:05:20	2020-05-12	Dr. Harlon Batz V	dr.harlon.batz.v@geemail.com	New York	New York	3779096177419268	823d8065fe97fb35c11bb8d7f7bc5409	Discover	40.5668910211175699	-73.994457613386956
24528	2020-05-12 16:06:03	2020-05-12	Ms. Verne Glover DVM	ms.verne.glover.dvm@geemail.com	Tampa	Florida	3096370720369781245	d9e1252b8d1c1df44ca055dd71a47c9b	JCB 15 digit	27.9936335340723375	-82.5216971817638694
24529	2020-05-12 16:08:30	2020-05-12	Miss Christie Metz	miss.christie.metz@woohoo.com	Los Angeles	California	6011649933029521407	a97d846f56f82493ed13d217cd2b4c42	Voyager	34.1001219146285166	-118.312041794833902
24530	2020-05-12 16:34:11	2020-05-12	Edmond Leffler DDS	edmond.leffler.dds@geemail.com	El Monte	California	6011460834563323067	13fbdc62e9e0f44310bcd33fb06a5df4	JCB 16 digit	34.1374489809110742	-117.949621039888257
24531	2020-05-12 16:41:48	2020-05-12	Mrs. Idamae Abernathy DDS	mrs.idamae.abernathy.dds@geemail.com	Reno	Nevada	3112712601338200722	1ae4f48dcee1316a76dcf04674495ffd	VISA 13 digit	39.5563011802345557	-119.822065355924522
24532	2020-05-12 16:42:21	2020-05-12	Lindsay Pfeffer	lindsay.pfeffer@woohoo.com	West Jordan	Utah	4182320214111876	1daafd380225a198e69d25f5dde893b7	VISA 16 digit	40.6927586770873546	-111.965939573579647
24533	2020-05-12 16:45:15	2020-05-12	Kaya Roberts	kaya.roberts@geemail.com	Fort Worth	Texas	4367014488814	4ae31b6006c946212b1620f7f3bae9e2	JCB 15 digit	32.8788788178991567	-97.3888245943754924
24534	2020-05-12 16:49:32	2020-05-12	Mr. Alois Flatley	mr.alois.flatley@geemail.com	San Francisco	California	869980093059953768	408c6574154ea1a092f519c9a4ae615e	VISA 16 digit	37.7632381401999595	-122.457095650351718
24535	2020-05-12 16:50:26	2020-05-12	Elizbeth Raynor-Dooley	elizbeth.raynor.dooley@warmmail.com	Salem	Oregon	4167737959336765	c0c4314b438615f397a16ca8908e4cf9	Maestro	44.9779077720630909	-122.933869289529326
24536	2020-05-12 17:22:12	2020-05-12	Becky Ebert-Hamill	becky.ebert.hamill@warmmail.com	Chicago	Illinois	6011013015532371518	9fa401d668b1360b031a24b649e36600	Mastercard	41.8521924552343805	-87.6191327798210011
24537	2020-05-12 17:44:56	2020-05-12	Hessie Murray DDS	hessie.murray.dds@geemail.com	Tucson	Arizona	4981769143417635	b4344cbe5abe4e714ddcbe0d02441a3a	VISA 13 digit	32.2485292545560753	-110.913074660603328
24538	2020-05-12 17:47:54	2020-05-12	Cloyd Monahan	cloyd.monahan@geemail.com	Moreno Valley	California	3088301354681425663	d8bb90cd460f11d41dd73774baba653e	JCB 16 digit	33.8669770921107371	-117.254844858773794
24539	2020-05-12 17:50:34	2020-05-12	Zackary Johnson	zackary.johnson@geemail.com	Jacksonville	Florida	3724508240412621	96b2440dcb54fc849d0bf61cb0fb33ae	JCB 15 digit	30.2850149509549134	-81.7183632003221732
24540	2020-05-12 17:55:44	2020-05-12	Zion Flatley	zion.flatley@geemail.com	New York	New York	51283738041419642	80e42dcc5e01b71b21f7a32e6cba4c14	JCB 16 digit	40.5812315047942107	-73.9043638835556749
24541	2020-05-12 17:56:13	2020-05-12	Dr. Ayanna Cronin	dr.ayanna.cronin@warmmail.com	New York	New York	4745284659713440	bf5428089dce8860931566542fc481bd	VISA 13 digit	40.7143283314295132	-73.8815775875829104
24542	2020-05-12 18:03:54	2020-05-12	Ernie Reinger	ernie.reinger@geemail.com	Oklahoma City	Oklahoma	4402857964161209	7012b9fa6d2127a5b7649043b3fcbd91	Mastercard	35.4810071614481544	-97.5341597666393909
24543	2020-05-12 18:10:38	2020-05-12	Thedore Maggio	thedore.maggio@geemail.com	Santa Rosa	California	3112571331310596315	5b6bf4777f60dd47db63104c7aefa0ee	VISA 16 digit	38.5269978224888447	-122.794030275639528
24544	2020-05-12 18:11:54	2020-05-12	Chaney Runolfsdottir	chaney.runolfsdottir@warmmail.com	Jacksonville	Florida	869911561749586374	a47cf8284a89e482b161a84e81062399	Maestro	30.4250257505156085	-81.6444772271983368
24545	2020-05-12 18:25:39	2020-05-12	Myrtis Rath	myrtis.rath@warmmail.com	Washington	District of Columbia	3337955603880279423	28ba8e1367c8f289d64d93835de7adc9	VISA 13 digit	38.8111336580742119	-76.9274538914885397
24546	2020-05-12 18:26:41	2020-05-12	Eden Lehner-Mueller	eden.lehner.mueller@geemail.com	New York	New York	561285372010414	0f835656fd28e1b7efa412dbdddac50b	JCB 16 digit	40.6853761699739849	-74.0199931304331784
24547	2020-05-12 18:42:02	2020-05-12	Hugh Morissette	hugh.morissette@geemail.com	San Francisco	California	3032507465128280	21562a4310f8bf10e3279fc0f0d8d8c4	American Express	37.7809364383501602	-122.460784173792788
24548	2020-05-12 18:44:49	2020-05-12	Sarina Wisozk	sarina.wisozk@geemail.com	San Francisco	California	4201658868397	a91c2ee9abcc8478625fe8f7c18fdf22	Discover	37.7596303474636343	-122.43142481829527
24549	2020-05-12 18:47:11	2020-05-12	Mrs. Giselle Hane	mrs.giselle.hane@geemail.com	Port St. Lucie	Florida	4942879438884064	077cadcc62d843afed27c0859861e62f	Discover	27.1995872188959282	-80.4569247567180525
24550	2020-05-12 18:47:22	2020-05-12	Melody Vandervort-Lebsack	melody.vandervort.lebsack@geemail.com	San Francisco	California	6011591773577537076	61957dd348e196634eeda50e433f41cf	JCB 16 digit	37.7409219364037227	-122.390222343296244
24551	2020-05-12 18:51:24	2020-05-12	Lessie O'Connell	lessie.o'connell@geemail.com	Long Beach	California	4246310032395	4756d09f76922e335b21748fb34dc78a	Mastercard	33.8473107958499284	-118.198233178180828
24552	2020-05-12 18:54:19	2020-05-12	Tresa Haley	tresa.haley@geemail.com	San Francisco	California	3112871936086915692	da578300822b3867d6f91e07c0cdf1ba	JCB 15 digit	37.766241396542469	-122.446719396562273
24553	2020-05-12 18:57:54	2020-05-12	Miss Lue Stroman DDS	miss.lue.stroman.dds@geemail.com	Austin	Texas	3043294333665921	cbc07c49e8ef9315b84ed8a103ab6248	JCB 15 digit	30.3728948511309902	-97.8025860158965088
24554	2020-05-12 19:02:53	2020-05-12	Hope Durgan-Jones	hope.durgan.jones@woohoo.com	Cedar Rapids	Iowa	501827265796188	3b6e2addf9f961db7c68a42a5a9d2a77	VISA 16 digit	42.0083357664830999	-91.6890119772005932
24555	2020-05-12 19:18:09	2020-05-12	Elaina Pacocha-Cassin	elaina.pacocha.cassin@geemail.com	Santa Ana	California	52847764840476285	c7f76de2a167e795b8357e94327e55c5	JCB 16 digit	33.7243457090679541	-117.920472431687628
24556	2020-05-12 19:23:38	2020-05-12	Nicola Grant MD	nicola.grant.md@woohoo.com	San Francisco	California	3014937581590782	6edd5d79ae4eb5f719d1fe5f7d23aad0	JCB 16 digit	37.7628013401468579	-122.39539841760002
24557	2020-05-12 19:31:04	2020-05-12	Cherrie Hessel	cherrie.hessel@geemail.com	Midland	Texas	4822322005157262	4a747e4719b85c36a7c27fe2508ed1c0	Maestro	31.9330748970344658	-102.172716751623895
24558	2020-05-12 19:36:28	2020-05-12	Alline Lockman	alline.lockman@geemail.com	Charlotte	North Carolina	3421670808937192	f6eca395ab843738d8d63fe1bf8c1cea	Maestro	35.2520232449538966	-80.7328047763966055
24559	2020-05-12 19:52:29	2020-05-12	Ms. Sasha Prohaska PhD	ms.sasha.prohaska.phd@warmmail.com	Kent	Washington	3337490432310353463	13c86800b5673e1a329e95691fc7b9a6	Diners Club / Carte Blanche	47.3128870913870614	-122.217821486028654
24560	2020-05-12 19:52:48	2020-05-12	Cristofer Runte	cristofer.runte@geemail.com	Naperville	Illinois	4482351599923	78dab2c38e5f0bf98d8cba441d050c6a	Maestro	41.7300493826538315	-88.1410221266448559
24561	2020-05-12 19:53:19	2020-05-12	Donavon Reichel	donavon.reichel@warmmail.com	Berkeley	California	54939801545002518	104c8be4ad62f8d53420b9b5a2d3223e	VISA 13 digit	37.8566129307516661	-122.288796361402007
24562	2020-05-12 20:01:52	2020-05-12	Addyson Johns	addyson.johns@woohoo.com	College Station	Texas	3785383896929963	a065d7e249f2adc6b2611e4ac9ed9dca	Diners Club / Carte Blanche	30.5448197982318703	-96.3635274242922719
24563	2020-05-12 20:04:57	2020-05-12	Korbin Douglas	korbin.douglas@geemail.com	New York	New York	869910110256349023	bd4a62859530441e33c59d5f0bf0bf70	Discover	40.6734946662783585	-73.9846042889997335
24564	2020-05-12 20:12:21	2020-05-12	Clytie Okuneva PhD	clytie.okuneva.phd@geemail.com	Glendale	California	4315796921684	e4fa3aa097c9f77851cb1b72d0fe7008	VISA 16 digit	34.2142927343245589	-118.24471802091152
24565	2020-05-12 20:20:11	2020-05-12	Dr. Jairo Runte	dr.jairo.runte@warmmail.com	Laredo	Texas	869923199421906317	7a7e970f0e06419dab49c18728e19b27	VISA 16 digit	27.6488698545560254	-99.523041505274179
24566	2020-05-12 20:25:10	2020-05-12	Ms. Candida Kassulke	ms.candida.kassulke@geemail.com	San Francisco	California	3058211743202819	af1b81563f3ebff164a3c55a670703cc	Maestro	37.7726980744116858	-122.405499195059477
24567	2020-05-12 20:48:01	2020-05-12	Chantel Heathcote	chantel.heathcote@geemail.com	Fort Worth	Texas	6011070452831696636	e241924e393aeed4207e2919f8fd0fef	Mastercard	32.8554180372096596	-97.277468502876161
24568	2020-05-12 20:55:56	2020-05-12	Louie McClure	louie.mcclure@geemail.com	Stamford	Connecticut	3033407254652419	4b53dc97401282194f040658bb0a6b24	JCB 16 digit	41.082039308582992	-73.4523246014062323
24569	2020-05-12 21:04:33	2020-05-12	Britta Bauch	britta.bauch@geemail.com	Lansing	Michigan	3337967429210988186	300ffd68d4f6a8aaef5f453f0924e5b3	JCB 16 digit	42.7686237489182517	-84.5416925347532953
24570	2020-05-12 21:10:06	2020-05-12	Cornelius Orn MD	cornelius.orn.md@geemail.com	Clarksville	Tennessee	6011848820205718932	4fdf8810a4b9e78bc20fa05f198887a8	Diners Club / Carte Blanche	36.6489124014169008	-87.4160550746087068
24571	2020-05-12 21:13:17	2020-05-12	Delma Kozey	delma.kozey@geemail.com	San Francisco	California	869990314680661457	e09f11f36da1cc8385dbd7fa6d1658fa	JCB 16 digit	37.8177379085439043	-122.413244249981489
24572	2020-05-12 21:19:30	2020-05-12	Dr. Alto Kuhlman IV	dr.alto.kuhlman.iv@geemail.com	Ontario	California	6011477879368044203	471c8532d8edd943bccef5eb082bbbee	JCB 15 digit	34.0349607656855113	-117.565541696931049
24573	2020-05-12 21:38:36	2020-05-12	Malvin Padberg	malvin.padberg@woohoo.com	San Diego	California	3096141377166529547	524143d59682fc857bc79a98859e004e	VISA 13 digit	32.7294034490894532	-117.168140694070615
24574	2020-05-12 21:56:46	2020-05-12	Nikolai Sawayn	nikolai.sawayn@woohoo.com	New York	New York	3465182390717542	ca88edfb02caf98c9e275677432594e6	Voyager	40.7530406939554979	-74.028319057439262
24575	2020-05-12 22:07:54	2020-05-12	Lillis McGlynn	lillis.mcglynn@geemail.com	Los Angeles	California	869955639789650305	604065d3099c48574ef0dfa25be9421c	JCB 16 digit	34.0340793145220672	-118.376354030286137
24576	2020-05-12 22:15:05	2020-05-12	Gussie Cole	gussie.cole@geemail.com	Bakersfield	California	4112193074716	0cb81080d76cebe41dfd7fe0686e142e	VISA 16 digit	35.2913260429341307	-119.066733810891577
24577	2020-05-12 22:27:29	2020-05-12	Alyssia Rath	alyssia.rath@woohoo.com	Raleigh	North Carolina	4353516050443	9d5911a4bfcd13888fbb58e3c61950b5	VISA 16 digit	35.7350517307542219	-78.5898980216525587
24578	2020-05-12 22:27:48	2020-05-12	Hollie Hahn	hollie.hahn@geemail.com	Houston	Texas	210042995240288135	4f9e75ee1f52fc2a8691afe75ac3200b	JCB 16 digit	29.7363905673924833	-95.2987630508389287
24579	2020-05-12 22:32:07	2020-05-12	Abelardo Kub	abelardo.kub@geemail.com	San Diego	California	4984063158583	81406830f89c1ff85e6e6f8790994a21	Maestro	32.8039844387277952	-117.144157067909845
24580	2020-05-12 22:36:13	2020-05-12	Kaylen Franecki DVM	kaylen.franecki.dvm@geemail.com	Oxnard	California	4207732442612	8da64bb981fe146e61803bf5cc98267b	JCB 15 digit	34.1633141134355256	-119.209831029959389
24581	2020-05-12 22:38:16	2020-05-12	Elodie Leannon-Hauck	elodie.leannon.hauck@woohoo.com	Virginia Beach	Virginia	51240163704511068	d0765ebb619b6e897f220b76bf611aed	Maestro	36.8248647252749635	-76.1236373472165297
24582	2020-05-12 22:41:29	2020-05-12	Hezekiah Dooley MD	hezekiah.dooley.md@geemail.com	Washington	District of Columbia	54314368855348563	72bc0734a0f30545cd3289addd3ff89c	JCB 16 digit	38.883195069365577	-76.9834554493174039
24583	2020-05-12 22:46:02	2020-05-12	Cuba Considine	cuba.considine@geemail.com	Paterson	New Jersey	4874200226723632	3bb88228769999bef370ebb5bf7e9509	Diners Club / Carte Blanche	41.00079948687479	-74.2376706907965342
24584	2020-05-12 22:46:51	2020-05-12	Keli Cole-Wunsch	keli.cole.wunsch@geemail.com	Boulder	Colorado	52126448326135167	47cff25d50267098ee8f6e9e6d60b5fb	Diners Club / Carte Blanche	40.0991524283755609	-105.165839306791881
24585	2020-05-12 22:48:13	2020-05-12	Cam Rutherford	cam.rutherford@woohoo.com	San Francisco	California	501826819280863	46aa9f362b4e38ab64a00f2285df74a8	VISA 16 digit	37.7991411076250898	-122.411394186731073
24586	2020-05-12 22:55:29	2020-05-12	Dr. Vester Treutel	dr.vester.treutel@warmmail.com	Cary	North Carolina	869927606008088604	c339c202cfac90da2b09fbadf313f130	American Express	35.8101986223474142	-78.7651602429423434
24587	2020-05-12 23:03:50	2020-05-12	Lanita Lind	lanita.lind@geemail.com	New York	New York	54264595645078346	477d5e95596cc191f816e7791c786fe1	Voyager	40.6496522719263993	-73.9539527683414519
24588	2020-05-12 23:10:00	2020-05-12	Dana Bailey	dana.bailey@geemail.com	Jacksonville	Florida	3053737594323846	8291edd6b8f779c0f77446d65217b899	Discover	30.3495482551917419	-81.6652181730683964
24589	2020-05-12 23:19:13	2020-05-12	Shaneka Block-Littel	shaneka.block.littel@geemail.com	New York	New York	3493201769036288	72f1dc0687b3b234374ae4d645867621	Voyager	40.5726574179474255	-73.848043940345562
24590	2020-05-12 23:23:36	2020-05-12	Lum Boehm	lum.boehm@geemail.com	Washington	District of Columbia	3034844795875183	4eb85e6a6c18d86f79070a220e9db984	VISA 16 digit	38.9015721512757224	-76.941164736005291
24591	2020-05-12 23:33:24	2020-05-12	Blake Rippin	blake.rippin@woohoo.com	Scottsdale	Arizona	869953515044489501	dd0c504d2957a7c04159f751c47272bf	VISA 16 digit	33.7820643000427623	-111.893011033904173
24592	2020-05-12 23:33:47	2020-05-12	Rosey Senger	rosey.senger@geemail.com	San Jose	California	4753121649598789	c11629bb709cd2a03e9e668a2902f7ee	Diners Club / Carte Blanche	37.2468059391070199	-121.851247864471375
24593	2020-05-12 23:41:41	2020-05-12	Elmira Medhurst	elmira.medhurst@geemail.com	Dallas	Texas	4153579862246152	44ce2d6655427d24f375dae209235124	Diners Club / Carte Blanche	32.7298727788303054	-96.6965411288626484
24594	2020-05-12 23:42:30	2020-05-12	Mr. Dan Turcotte	mr.dan.turcotte@geemail.com	Indianapolis	Indiana	6011004622909673755	c7f91d06b2d210eed3f30e8a499ff97e	Mastercard	39.8626037852380435	-86.0791261133938974
24595	2020-05-12 23:51:25	2020-05-12	Enid Ondricka PhD	enid.ondricka.phd@warmmail.com	Winston–Salem	North Carolina	4857611586507	609f1e684cf833b8c5505fb071cf6584	Voyager	36.1391754886366385	-80.280043005816637
24596	2020-05-12 23:52:02	2020-05-12	Britni Beier	britni.beier@woohoo.com	Charleston	South Carolina	4012284830125080	526a277210c5ea36206b17ca0c9121a3	JCB 15 digit	32.816450140066074	-80.0087407636139574
24597	2020-05-12 23:54:57	2020-05-12	River Leffler	river.leffler@warmmail.com	San Francisco	California	4888034394126219	314c2a3ee945ccf7633345130aae8f22	Discover	37.7790282115144507	-122.424869433966563
24598	2020-05-12 23:56:50	2020-05-12	Richmond Senger I	richmond.senger.i@woohoo.com	Los Angeles	California	4927498826381	77d8f783e084d9c058eeac6654a6e243	VISA 16 digit	34.0343212535470698	-118.435280287963522
24599	2020-05-13 00:03:17	2020-05-13	Bowman Kilback	bowman.kilback@woohoo.com	San Jose	California	4203672433158	2d1d624b5cadb8fca17e99b48fe397ca	Mastercard	37.2507751841384902	-121.885428108529752
24600	2020-05-13 00:04:30	2020-05-13	Corry Ebert	corry.ebert@geemail.com	San Jose	California	4459950438588362	4c56bbdd326d2bf0743625ee96ae657f	VISA 16 digit	37.3223953330710572	-121.886184224182372
24601	2020-05-13 00:06:37	2020-05-13	Cassie Mitchell	cassie.mitchell@woohoo.com	Meridian	Idaho	4442845748148	e1a78d8006c4ba1760d11b632a5b3218	JCB 15 digit	43.6598641091965121	-116.469161695608491
24602	2020-05-13 00:07:09	2020-05-13	Miss Tiara Mills	miss.tiara.mills@geemail.com	Mesa	Arizona	4686099486785	c764530da57b14d9bcbd726a67183eda	VISA 16 digit	33.3586512961570136	-111.631350051879508
24603	2020-05-13 00:13:13	2020-05-13	Alvaro Dickinson	alvaro.dickinson@geemail.com	Oakland	California	4039320635982041	dd1d41438027af0416a9e2368023e1d5	Diners Club / Carte Blanche	37.8160613779208106	-122.266671723409686
24604	2020-05-13 00:13:22	2020-05-13	Glendon Wuckert	glendon.wuckert@geemail.com	Santa Ana	California	869903471695478800	03d1ef8abbaf7636bb2ec639800c6026	Maestro	33.6572695468191085	-117.95756493652425
24605	2020-05-13 00:13:31	2020-05-13	Dionicio Krajcik	dionicio.krajcik@geemail.com	Detroit	Michigan	4350572596886253	0f0c4459f612db758597667cf22998c4	Discover	42.4279556664563771	-83.1212996480639958
24606	2020-05-13 00:14:56	2020-05-13	Nina Kuhic	nina.kuhic@warmmail.com	Elgin	Illinois	4839633875045200	5028d18e5a10ab4d37b1ae371cb486d9	VISA 16 digit	42.1217906882338227	-88.3218572411041833
24607	2020-05-13 00:28:24	2020-05-13	Sheron Waters	sheron.waters@geemail.com	Mesa	Arizona	4077095247709015	1ed57da94870ffc61ea963ff3eac417a	Discover	33.4215774154435792	-111.679396627785266
24608	2020-05-13 00:41:42	2020-05-13	Kade Kirlin	kade.kirlin@warmmail.com	San Jose	California	6011647161492964258	c17ae82c68f2de1667d17414172704b3	JCB 16 digit	37.3176643954411134	-121.772930285729089
24609	2020-05-13 00:52:33	2020-05-13	Dr. Kasandra Herman DVM	dr.kasandra.herman.dvm@geemail.com	San Francisco	California	869938371241478339	5a0e483663df8c5c83a08db4380dbf13	VISA 16 digit	37.7884869675078789	-122.416678611866189
24610	2020-05-13 00:54:14	2020-05-13	Celia Johnston	celia.johnston@geemail.com	Berkeley	California	3711693986802725	4acfc0c6c1aae998d15050bb6c8b580b	JCB 16 digit	37.8442596483038045	-122.279878038017884
24611	2020-05-13 01:04:33	2020-05-13	Forest Metz	forest.metz@geemail.com	Naperville	Illinois	4774449110790	bc546e057ae205c5d8e671c7bad4ee19	JCB 16 digit	41.7242339993275735	-88.1409293926674877
24612	2020-05-13 01:12:10	2020-05-13	Mr. Jermey Wyman II	mr.jermey.wyman.ii@geemail.com	Edison	New Jersey	3088593797831909621	a19ef6dc44e697f541bfbcb2b62a35eb	JCB 16 digit	40.5074772256854914	-74.395616984000057
24613	2020-05-13 01:35:38	2020-05-13	Mr. Lionel Daniel	mr.lionel.daniel@warmmail.com	New York	New York	53877279880417704	c4689b22441c1253c6a21a9bf5f69979	JCB 16 digit	40.5816623500306122	-74.0279011562362257
24614	2020-05-13 01:41:40	2020-05-13	Mal Farrell	mal.farrell@geemail.com	Garden Grove	California	180059482250377165	f6125a622b780ca1d0e77b50e5858804	Mastercard	33.7597193318244067	-118.053278905155139
24615	2020-05-13 02:08:23	2020-05-13	Yadiel Gulgowski-West	yadiel.gulgowski.west@geemail.com	San Francisco	California	55913215766433999	5f448392b6138d9e8ca68e0109b9e1a1	VISA 16 digit	37.7797426643067169	-122.470831269657296
24616	2020-05-13 02:51:31	2020-05-13	Donnell White	donnell.white@geemail.com	St. Louis	Missouri	3337242188123818941	6c5355da4c56f922424b295828538e01	Mastercard	38.5474688752245171	-90.2960052607584771
24617	2020-05-13 02:58:38	2020-05-13	Cade Terry IV	cade.terry.iv@warmmail.com	Los Angeles	California	4260249199324	828b4e38f1032acfa449c8fe2e37cae8	JCB 16 digit	34.0099256582424019	-118.4537794948548
24618	2020-05-13 03:08:04	2020-05-13	Ms. Miesha Hansen	ms.miesha.hansen@geemail.com	Fort Lauderdale	Florida	4296574921725930	928c64d93870de0bf9d84f87da581607	JCB 16 digit	26.1879173416633186	-80.2371577068984436
24619	2020-05-13 03:11:28	2020-05-13	Mat Pollich III	mat.pollich.iii@geemail.com	Miami	Florida	869907671449405241	1716b41325f0cb7853abe44cd36f376e	VISA 16 digit	25.8505167511429654	-80.1572017668154189
24620	2020-05-13 03:51:58	2020-05-13	Donita Vandervort	donita.vandervort@warmmail.com	San Francisco	California	180027367110399666	0a87f3de63facda658168c05e95c5e76	Voyager	37.7603852897538488	-122.445340342739669
24621	2020-05-13 03:55:27	2020-05-13	Adrianna Langworth-Dickens	adrianna.langworth.dickens@geemail.com	San Francisco	California	54143665253499337	569dbface06eea718c5c98817342bfff	American Express	37.7711258156838099	-122.403083973898177
24622	2020-05-13 03:56:37	2020-05-13	Dondre Prosacco	dondre.prosacco@geemail.com	Charlotte	North Carolina	54947080422438893	5052d7ce542d4eabbe1d69c385df0837	Diners Club / Carte Blanche	35.1752178509507303	-80.8462372115757404
24623	2020-05-13 03:57:42	2020-05-13	Dimitri O'Connell	dimitri.o'connell@warmmail.com	Irvine	California	3041750183720787	00c4c7c39e4aa01a010c601ead5b18f6	VISA 16 digit	33.6440098149251199	-117.676498068823662
24624	2020-05-13 04:13:36	2020-05-13	Shasta Gleichner	shasta.gleichner@warmmail.com	Phoenix	Arizona	4348996272780	b449a316cf346d89678eb26ab9890376	Mastercard	33.5489069346271478	-112.07707633747944
24625	2020-05-13 04:15:23	2020-05-13	Marlyn Kertzmann-Yundt	marlyn.kertzmann.yundt@geemail.com	New York	New York	52996646623842909	bd38300d800d7d60345df698f32a3e32	Mastercard	40.6398538786210111	-73.9751249031525049
24626	2020-05-13 04:23:39	2020-05-13	Emory Casper	emory.casper@geemail.com	Columbus	Ohio	53472017044659913	07e911fd256646d17a94917ba26f8a77	VISA 16 digit	39.8919248304840153	-82.9363391946770321
24627	2020-05-13 04:43:02	2020-05-13	Kristin Kautzer DDS	kristin.kautzer.dds@geemail.com	Lakewood	Colorado	54453588108971629	91154296eee88011e6d5ca40bb8f1273	JCB 16 digit	39.6635348602138507	-105.087065932575982
24628	2020-05-13 05:08:30	2020-05-13	Cyril Ernser V	cyril.ernser.v@geemail.com	Macon	Georgia	869937980390752418	b4f7eb57e39181132ca7a1d3dfbc7aab	VISA 13 digit	32.7724822286061936	-83.6816035835266092
24629	2020-05-13 05:17:47	2020-05-13	Laura Keeling	laura.keeling@woohoo.com	Davie	Florida	501886138291488	ebd67e78b390da586d6ccc5c2d25a6f8	Mastercard	26.0654182581961145	-80.1959057575929819
24630	2020-05-13 05:33:57	2020-05-13	Calleigh Miller	calleigh.miller@warmmail.com	Virginia Beach	Virginia	180012842234118603	24a7a2bf3ff3af53f49551f67fe6d678	American Express	36.7944064548891063	-75.9441041842240878
24631	2020-05-13 06:26:14	2020-05-13	Miss Lorena Weber	miss.lorena.weber@geemail.com	San Diego	California	6011475635212362163	d67ee0683f51d80bcdd6a3bc215448de	VISA 13 digit	32.8669066779382533	-117.20712688024156
24632	2020-05-13 06:38:13	2020-05-13	Spencer Hahn	spencer.hahn@geemail.com	Greensboro	North Carolina	6011526274232234449	5307c1be7caea70d73d160e9b1506f28	JCB 15 digit	36.1043316663358382	-79.8625477414559555
24633	2020-05-13 06:47:45	2020-05-13	Dr. Lizette Stark PhD	dr.lizette.stark.phd@warmmail.com	New York	New York	3528736009704141409	64b52ecf583785b301eea53e41e54580	JCB 15 digit	40.7324761191140823	-74.028947886115688
24634	2020-05-13 06:51:26	2020-05-13	Marylou Kutch DDS	marylou.kutch.dds@geemail.com	San Francisco	California	676362729900431	63b135294e17c9ed086d75b10f08e7a3	Maestro	37.7671981237470575	-122.457264561223624
24635	2020-05-13 07:00:49	2020-05-13	Eleanora Denesik	eleanora.denesik@geemail.com	Rochester	Minnesota	3096825151832932218	30e00200d323e33eb41921afeeb8dd6b	VISA 16 digit	43.920266361711171	-92.497546661563959
24636	2020-05-13 07:04:47	2020-05-13	Mr. Jasper Turner I	mr.jasper.turner.i@geemail.com	New York	New York	4283748529658892	9d904ab780424afc575d6e52a85f7036	VISA 13 digit	40.6522428553309254	-73.8856975226093056
24637	2020-05-13 07:13:16	2020-05-13	Kory Herzog	kory.herzog@geemail.com	Simi Valley	California	4057505987511	d013278215969f13b226038fe9b3ea55	JCB 15 digit	34.205069841933998	-118.649709677802406
24638	2020-05-13 07:26:38	2020-05-13	Arvilla Blick DVM	arvilla.blick.dvm@geemail.com	New York	New York	6011681047562553294	7b18dc7437e8c0b4d7adff03da23750e	Maestro	40.6382195517644291	-73.968494870968911
24639	2020-05-13 07:34:07	2020-05-13	Dicie Grady	dicie.grady@geemail.com	Glendale	Arizona	55244383303257451	032c3bb25bdde2b9d82d399edc9ec85b	American Express	33.4492485976073866	-112.13302677849083
24640	2020-05-13 07:44:51	2020-05-13	Georgene Dickens	georgene.dickens@geemail.com	Los Angeles	California	501816094685035	b19c02dee0be85e8c7bb01dcfae3d090	VISA 16 digit	34.0654980089381283	-118.35127179091721
24641	2020-05-13 08:08:24	2020-05-13	Emil Hilll III	emil.hilll.iii@geemail.com	Elizabeth	New Jersey	6011985388327496475	377d6514efe4aa1f8dac9f3c387ee2a0	VISA 16 digit	40.6191487619780034	-74.1551897417698029
24642	2020-05-13 08:25:56	2020-05-13	Dr. Geo Yost DDS	dr.geo.yost.dds@warmmail.com	San Francisco	California	3034456935725465	a18f03916cb4cf91280e53141a1f9d55	Mastercard	37.7998759286700974	-122.403398273597958
24643	2020-05-13 08:26:19	2020-05-13	Ms. Brande Fisher MD	ms.brande.fisher.md@geemail.com	San Francisco	California	869948761857347620	3c26915f9da15461919e24862e93ba3f	JCB 16 digit	37.7595089246149911	-122.458201846622956
24644	2020-05-13 08:37:39	2020-05-13	Florentino Ebert	florentino.ebert@geemail.com	New York	New York	869917250037222090	b1bb5b9ad153379828692d11a8b977f8	Diners Club / Carte Blanche	40.6093949311170732	-73.8537399221107336
24645	2020-05-13 08:44:22	2020-05-13	Claudia Bauch	claudia.bauch@geemail.com	Santa Ana	California	676221400430670	477b76b7c712366765e1c6863b0b9d99	Diners Club / Carte Blanche	33.7813669225305304	-117.819995884450151
24646	2020-05-13 08:47:58	2020-05-13	Tarik Kilback	tarik.kilback@geemail.com	Arlington	Texas	6011384756540143297	1277aafc3d4b323166044db756fc1934	Diners Club / Carte Blanche	32.756790313289315	-97.0545097447957943
24647	2020-05-13 08:48:42	2020-05-13	Virginia Stokes	virginia.stokes@warmmail.com	Houston	Texas	53048947748162944	06eac3ca8716b7eeed658b0d90bf3f55	Diners Club / Carte Blanche	29.7369132935613401	-95.4592734362944952
24648	2020-05-13 09:09:55	2020-05-13	Margy Moore DVM	margy.moore.dvm@warmmail.com	Chattanooga	Tennessee	6011979361982705256	8470d0b041f78159f9110d2d5762c443	JCB 16 digit	35.1326025584563624	-85.3209378854665914
24649	2020-05-13 09:18:16	2020-05-13	Wendell Price IV	wendell.price.iv@warmmail.com	Fort Worth	Texas	4797484580234469	9a2e22a8c0fce91ab5f2dba2d72bf216	Diners Club / Carte Blanche	32.790210488723595	-97.2893890749950003
24650	2020-05-13 09:39:11	2020-05-13	Mart Roob	mart.roob@warmmail.com	San Francisco	California	54551903201612650	93588de62c1968986ff0ca48e2833e7d	JCB 16 digit	37.7598260362290219	-122.432180048126895
24651	2020-05-13 09:56:36	2020-05-13	Reno Stracke V	reno.stracke.v@geemail.com	Denton	Texas	4139584839687834	59840cda5966290718e62b51a537c115	American Express	33.1998164603751178	-97.2243951705411149
24652	2020-05-13 10:08:50	2020-05-13	Alberto Kilback	alberto.kilback@woohoo.com	Philadelphia	Pennsylvania	3337354323653724979	e4adb269cea7a83edad8727ab2460d99	VISA 13 digit	39.9353892089292373	-75.0923595308225629
24653	2020-05-13 10:11:43	2020-05-13	Minervia VonRueden PhD	minervia.vonrueden.phd@geemail.com	Chicago	Illinois	869929592002412701	e8c2d3e83f89cc3d0db302571079cc02	Mastercard	41.8648825206629951	-87.6927489579219355
24654	2020-05-13 10:24:36	2020-05-13	Najee Graham	najee.graham@geemail.com	San Francisco	California	52039875672433083	82bb155bccf59468af55d5e3af2a98a5	JCB 15 digit	37.7894461431248772	-122.457209015951861
24655	2020-05-13 10:36:11	2020-05-13	Farrell Rice	farrell.rice@warmmail.com	San Bernardino	California	3088222937265085469	c28a7c3bc0717e3ea996f3b12e02bef1	VISA 16 digit	34.1711056768227337	-117.248855367793141
24656	2020-05-13 10:36:14	2020-05-13	Russel Johns-Bergnaum	russel.johns.bergnaum@warmmail.com	Irving	Texas	4966035996034	e92ffe5013586f9273b3f039741795a3	Diners Club / Carte Blanche	32.7710129493333397	-97.0266961504518974
24657	2020-05-13 11:01:26	2020-05-13	Raymond Funk IV	raymond.funk.iv@geemail.com	Berkeley	California	4204973679461022	ad9ecb71fd761a1858fcce44ae638f58	JCB 15 digit	37.8799656479957889	-122.254376479503009
24658	2020-05-13 11:44:23	2020-05-13	Kathy Cormier	kathy.cormier@geemail.com	Columbus	Ohio	3112408823003827436	f68eb1cbf19859b8e42736ddbea21dd1	VISA 13 digit	39.9782467211641332	-82.9711537276629372
24659	2020-05-13 12:38:11	2020-05-13	Elia Becker	elia.becker@geemail.com	New York	New York	6011723573894683566	df1a09ef0b4dc92bb4098f1a331a0698	Voyager	40.5994938797075307	-73.9411203433655118
24660	2020-05-13 12:41:20	2020-05-13	Deidra Parker	deidra.parker@geemail.com	Virginia Beach	Virginia	180070964353564430	e4af88b7f282f54436b0e8b86bc8e990	Maestro	36.8216232209187027	-76.0202246538035524
24661	2020-05-13 12:43:45	2020-05-13	Adella Powlowski	adella.powlowski@geemail.com	San Francisco	California	4779893242601	daec64f695692a996eec99b4bf28e9e3	JCB 15 digit	37.7744567029834002	-122.463761945952982
24662	2020-05-13 13:33:57	2020-05-13	Toriano Green	toriano.green@warmmail.com	Corona	California	3024527809394016	ef492c9d69c7b5d50f158a3de5116a3e	Voyager	33.9123593881614553	-117.649387858502564
24663	2020-05-13 13:47:56	2020-05-13	Chrystal Labadie	chrystal.labadie@geemail.com	Fresno	California	675984455045165	2906dda15bc67a3c1bec44aef6f9719b	JCB 15 digit	36.8274733408693251	-119.793801975726709
24664	2020-05-13 13:59:14	2020-05-13	Mrs. Makala Bruen	mrs.makala.bruen@geemail.com	Dallas	Texas	676124405149261	1a9cbee4ba5a18e28b786a0363fe7ac1	Voyager	32.8587003731440745	-96.7480193616785016
24665	2020-05-13 14:06:42	2020-05-13	Waylon Rosenbaum PhD	waylon.rosenbaum.phd@warmmail.com	Baton Rouge	Louisiana	3112020552044379697	ed777b9389be7b79bf934332bc192210	JCB 15 digit	30.488798611120135	-91.1808598085414559
24666	2020-05-13 14:23:19	2020-05-13	Dr. Billye Runolfsdottir PhD	dr.billye.runolfsdottir.phd@warmmail.com	Chicago	Illinois	3016480935387439	4868c24e592ebeb57c2c41faaedbadbb	JCB 15 digit	41.9279180159162763	-87.6861752362485873
24667	2020-05-13 14:46:51	2020-05-13	Rex Morar	rex.morar@geemail.com	Huntsville	Alabama	3006986116930573	2f2cde6ba7f1f8ffcb5107f9fec25449	Voyager	34.6220361004825676	-86.597104913137855
24668	2020-05-13 15:13:53	2020-05-13	Dr. Oda Haley DVM	dr.oda.haley.dvm@woohoo.com	Oakland	California	4494932446771	33afbb76cc86d935faa8d3a5393d5a9c	VISA 16 digit	37.7775458706472236	-122.264321004431878
24669	2020-05-13 15:14:15	2020-05-13	Buck Mante	buck.mante@geemail.com	Albuquerque	New Mexico	869955541087433659	de076c96e4dc733223e77bb54b26c49d	JCB 16 digit	35.0680102928675765	-106.55465185354241
24670	2020-05-13 15:18:38	2020-05-13	Reta Terry	reta.terry@geemail.com	Akron	Ohio	6011604090079123122	eb0a4bea3db316d6598fcc416105ff00	Discover	41.1707305081021033	-81.4450612984910549
24671	2020-05-13 15:42:11	2020-05-13	Keith Kutch	keith.kutch@woohoo.com	Los Angeles	California	6011462984965877273	6ef7c75c44e62cb8be47224fe63ac8d9	VISA 16 digit	33.9981157257087503	-118.31547295637354
24672	2020-05-13 15:58:08	2020-05-13	Demond Hamill	demond.hamill@warmmail.com	Austin	Texas	54738499889226067	2abcf57e3b014d0d13570a6907fb3826	American Express	30.3376259697262185	-97.7368365296866841
24673	2020-05-13 16:00:15	2020-05-13	Olen Hodkiewicz-Erdman	olen.hodkiewicz.erdman@geemail.com	Philadelphia	Pennsylvania	3528346279731784297	404518540b12ffb051972fde9fbfbef2	JCB 15 digit	40.0957358722999686	-75.1599834638547151
24674	2020-05-13 16:01:31	2020-05-13	Cam Daniel-Herzog	cam.daniel.herzog@geemail.com	Portland	Oregon	52415645778165226	67dd9c0ac8337fe7774f21ba88e6504f	JCB 15 digit	45.5755473094414896	-122.713149185851222
24675	2020-05-13 16:03:45	2020-05-13	Iva Leannon	iva.leannon@geemail.com	Edison	New Jersey	4661471038240357	25ac5b65051b58808ef3b9841d1320f8	JCB 15 digit	40.4453267302792483	-74.3588623319804753
24676	2020-05-13 16:16:54	2020-05-13	Dr. Debrah Johnston DVM	dr.debrah.johnston.dvm@woohoo.com	San Francisco	California	3408439067638090	369c66250fb2652e47d3c9e5ab8f5a54	Diners Club / Carte Blanche	37.7868703097717002	-122.423348850109463
24677	2020-05-13 16:20:54	2020-05-13	Mrs. Carrol Wiza DVM	mrs.carrol.wiza.dvm@warmmail.com	Phoenix	Arizona	6011555535887955635	e1ee5c3e8571e11e7b15a011c5608e1f	Discover	33.561982944135373	-112.121940654741977
24678	2020-05-13 16:35:19	2020-05-13	Mr. Alvan Prosacco III	mr.alvan.prosacco.iii@geemail.com	Washington	District of Columbia	869929760837174073	24c978cbd92dad233a1fb6f84d3a4ba3	Voyager	38.8723335169520254	-76.9438171066090462
24679	2020-05-13 16:36:11	2020-05-13	Dr. Manervia Jerde	dr.manervia.jerde@warmmail.com	New York	New York	3096566702474230403	57884389f4678e9c25f05bb965cc87b8	Diners Club / Carte Blanche	40.659323874603956	-73.9412564385112319
24680	2020-05-13 17:02:01	2020-05-13	Montana Klein I	montana.klein.i@geemail.com	Rochester	New York	869990574248721545	61a191f823d20ce729c1383f7d73455b	Voyager	43.1128327468853456	-77.6326718700356793
24681	2020-05-13 17:06:44	2020-05-13	Gennaro Crona	gennaro.crona@geemail.com	Fremont	California	4317599873658057	ae133d03ddaa3da564fbbd674451b963	VISA 16 digit	37.4023670467715732	-121.91450256961285
24682	2020-05-13 17:20:20	2020-05-13	Case Mohr	case.mohr@woohoo.com	San Antonio	Texas	3088390924320422602	ce1bfa1ee0f3be28a741ea2f95be58ab	JCB 16 digit	29.5142131931684908	-98.4667561439633374
24683	2020-05-13 17:20:26	2020-05-13	Dr. Mahlon McLaughlin PhD	dr.mahlon.mclaughlin.phd@woohoo.com	Oxnard	California	3096501257525397188	e4bb02bac10e487db1149358812032a0	VISA 13 digit	34.1651373485524203	-119.183356594983863
24684	2020-05-13 17:37:44	2020-05-13	Miss Mossie Feil	miss.mossie.feil@geemail.com	Berkeley	California	3112272515803786043	d66036f53cb83b8d66eccdea82856099	JCB 15 digit	37.8429199833719778	-122.289456074651397
24685	2020-05-13 17:53:22	2020-05-13	Chin Adams	chin.adams@geemail.com	Portland	Oregon	51311817239381040	06c5c2fa63771911b55f5dc78d063560	VISA 16 digit	45.4963255552463224	-122.693867512280121
24686	2020-05-13 18:12:05	2020-05-13	Patric Smith	patric.smith@geemail.com	Jackson	Mississippi	503880492425014	9ac1be36673b8f848a6c4b4ba32d8070	VISA 16 digit	32.2897413023460658	-90.2394093871090632
24687	2020-05-13 18:14:57	2020-05-13	Elsie Purdy DDS	elsie.purdy.dds@geemail.com	San Francisco	California	3112474168868510878	f5b7c0e2985414dc900788f94120e0ef	JCB 16 digit	37.788705378302538	-122.439597806888372
24688	2020-05-13 18:15:39	2020-05-13	Assunta McLaughlin	assunta.mclaughlin@geemail.com	Newport News	Virginia	3158636921585687626	dc346cd5aff7c1bca9e8d22cbe3c4353	JCB 16 digit	36.9960131135199219	-76.5852693038322059
24689	2020-05-13 18:26:30	2020-05-13	Dr. Kent Jast II	dr.kent.jast.ii@geemail.com	Los Angeles	California	4193666769139309	602e287fbecd03710bc518004cbdd9fd	Maestro	34.0638706065580195	-118.379151171025995
24690	2020-05-13 18:35:06	2020-05-13	Mr. Tylor Ritchie DVM	mr.tylor.ritchie.dvm@geemail.com	Phoenix	Arizona	4879613176793287	524987cebed670dfa3a15ee2b8913c1d	Discover	33.5874962854132093	-112.067224324860064
24691	2020-05-13 18:54:34	2020-05-13	Lyric Nitzsche	lyric.nitzsche@geemail.com	Carlsbad	California	4723483611296	c6ff6ebe31be94abd575a5b1b46d5165	Diners Club / Carte Blanche	33.0343067747481172	-117.185771097873513
24692	2020-05-13 19:05:58	2020-05-13	Cornelius Hermann-D'Amore	cornelius.hermann.d'amore@geemail.com	San Francisco	California	4035756912238959	c3b0c12076a7fb214faa87f0d041bb85	Mastercard	37.7918570917030792	-122.456567386020879
24693	2020-05-13 19:10:46	2020-05-13	Dr. Luvenia Bogisich DVM	dr.luvenia.bogisich.dvm@geemail.com	Provo	Utah	3528213299966022809	34c67d6554747e46648a31a972fba875	VISA 16 digit	40.2367739687927042	-111.612170116803796
24694	2020-05-13 19:19:09	2020-05-13	Aspen Rolfson	aspen.rolfson@woohoo.com	Anchorage	Alaska	4298819009384169	e694ced11a5aae51564157ed3853dbde	Mastercard	61.1077911585319811	-149.24023872088938
24695	2020-05-13 19:23:01	2020-05-13	Rayna Corwin	rayna.corwin@woohoo.com	Durham	North Carolina	3056645454929585	9a65e751c349174227497a355fc85716	JCB 16 digit	35.9023028583046013	-78.9050528747398374
24696	2020-05-13 19:23:14	2020-05-13	Dr. Carry Rohan	dr.carry.rohan@woohoo.com	North Las Vegas	Nevada	55701453474290767	553df0a498d80b1d089e6d9b1d3cc511	JCB 15 digit	36.1892929884761543	-115.099914794530349
24697	2020-05-13 19:31:57	2020-05-13	Mrs. Carol Turcotte	mrs.carol.turcotte@geemail.com	San Francisco	California	210049601969042926	ed34ebf8be25fcd2465567570433f1b4	VISA 13 digit	37.7991691100963649	-122.443714549452949
24698	2020-05-13 19:32:27	2020-05-13	Shantel Nienow-Thompson	shantel.nienow.thompson@geemail.com	Boulder	Colorado	3769858469039811	769f77aeb34bed5a374e026971bb3c6b	Mastercard	40.0642883349657097	-105.338865789087123
24699	2020-05-13 19:49:19	2020-05-13	Shauna Wolff	shauna.wolff@geemail.com	San Antonio	Texas	55089233404774367	7ccadd7b9eaab0dd8317d9792b109e2e	Discover	29.4690913391370337	-98.6090145612902944
24700	2020-05-13 20:05:22	2020-05-13	Alyse Schmitt	alyse.schmitt@woohoo.com	Modesto	California	180032279055262242	0909dda3687f390d180f54b87bb53bde	JCB 15 digit	37.5652206848375556	-121.073951995532965
24701	2020-05-13 20:05:30	2020-05-13	Lawrance Conroy	lawrance.conroy@geemail.com	Grand Prairie	Texas	3112436826311300174	bb3490bad1deada63e16871ff85b050c	Diners Club / Carte Blanche	32.6627508880622699	-96.9972826775502455
24702	2020-05-13 20:14:20	2020-05-13	Dillan Hand	dillan.hand@woohoo.com	Boston	Massachusetts	3112548533596134873	b6cb00c3ba7fd72a942a0f6b512854a4	Voyager	42.2995925110466757	-70.9806622700717327
24703	2020-05-13 20:17:55	2020-05-13	Dedrick Herman	dedrick.herman@geemail.com	Madison	Wisconsin	3158693259713126286	7a265753467969030cc97841c004f553	VISA 16 digit	43.0859861350126607	-89.4233915127698396
24704	2020-05-13 20:29:21	2020-05-13	Mr. Autry Jacobson	mr.autry.jacobson@geemail.com	San Francisco	California	3528848810499867040	43a66d2789d37033c16c4f63539147e8	JCB 16 digit	37.7939547778103346	-122.401475334115943
24705	2020-05-13 20:32:38	2020-05-13	Lindsey Dach DDS	lindsey.dach.dds@geemail.com	San Francisco	California	869906750002602633	502c8e22fad2af86a282b77be1958eac	VISA 16 digit	37.8046429536740476	-122.443907549121576
24706	2020-05-13 20:45:00	2020-05-13	Ivy Jacobs	ivy.jacobs@geemail.com	Rockford	Illinois	3112833688027847099	25f6638d85f9d569e4bb41a1a0c3e906	JCB 16 digit	42.2783496597792947	-89.112529909452789
24707	2020-05-13 20:53:25	2020-05-13	Billye Skiles	billye.skiles@warmmail.com	Philadelphia	Pennsylvania	4479955242264	f9c4d8b7968dc48b77e01a517871b651	VISA 16 digit	39.9732036189600848	-75.0602767044112085
24708	2020-05-13 20:54:44	2020-05-13	Harland Hyatt	harland.hyatt@woohoo.com	Kansas City	Kansas	3337562735422262999	8b89c0e6f3b9a34d29ae258aa652f729	VISA 16 digit	39.1027558904048078	-94.7904974430270499
24709	2020-05-13 21:09:15	2020-05-13	Wallace Schmitt	wallace.schmitt@geemail.com	Los Angeles	California	3006542171644706	e27e02e54df94f05998ad31ebdbdff58	JCB 16 digit	34.067096616826575	-118.366540260099981
24710	2020-05-13 21:20:51	2020-05-13	Mrs. Darcy Torphy	mrs.darcy.torphy@warmmail.com	Charlotte	North Carolina	6011955250129027484	104b4a1d8b09477634b8f418bb8ef3ee	American Express	35.3064754988320146	-80.8046442834138929
24711	2020-05-13 21:43:35	2020-05-13	Mayo Haley	mayo.haley@geemail.com	Alexandria	Virginia	4415433681884765	b2f85cb58d350f2119d7c3659de3caff	American Express	38.8216077682211989	-77.0275260047972239
24712	2020-05-13 21:57:26	2020-05-13	Kerri Pagac	kerri.pagac@geemail.com	Cincinnati	Ohio	3039059274443586	37d1200c61725de18c6af291b69310b1	Diners Club / Carte Blanche	39.1599811180260033	-84.5599706195566796
24713	2020-05-13 22:01:56	2020-05-13	Page Hansen DDS	page.hansen.dds@warmmail.com	New York	New York	639026821768764	75f331071dcb8ba82fe81937bbad4595	Discover	40.6484689276423268	-73.9550988473359467
24714	2020-05-13 22:05:33	2020-05-13	Yael Grant V	yael.grant.v@woohoo.com	San Francisco	California	54306524887998631	43bddb287edf39d19f6bd351a48b1cca	JCB 15 digit	37.7608679798583253	-122.430428220054822
24715	2020-05-13 22:06:29	2020-05-13	Abner Robel	abner.robel@geemail.com	Coral Springs	Florida	180091711116052210	f74495ae7ef4d8997c66a7adf52ad8eb	Discover	26.2930589385394029	-80.2035720109596753
24716	2020-05-13 22:06:56	2020-05-13	Shedrick Towne	shedrick.towne@warmmail.com	Aurora	Colorado	3337238881494490375	be5b17eecf1c8219d25b6cb79a0a86b5	JCB 16 digit	39.6264296279400625	-104.633470817993214
24717	2020-05-13 22:12:16	2020-05-13	Jaslyn Auer-Stokes	jaslyn.auer.stokes@geemail.com	Las Vegas	Nevada	52863865674696564	b64bd0f57c47be6418824c73d076e54b	JCB 16 digit	36.2547853336770061	-115.262441607585544
24718	2020-05-13 22:21:24	2020-05-13	Ryker Upton-Keeling	ryker.upton.keeling@warmmail.com	San Francisco	California	3528575236406555750	e30ff531d4ccd2b0c7a3f1be3ae77eb7	Diners Club / Carte Blanche	37.7627387721550605	-122.412962752039022
24719	2020-05-13 22:36:22	2020-05-13	Caroline Pollich	caroline.pollich@geemail.com	San Francisco	California	3002520196995414	4824ee9ee5a00d2f34b0acd24e1101ca	VISA 16 digit	37.77505406328644	-122.447512565769756
24720	2020-05-13 22:39:06	2020-05-13	Miss Halle Hintz DVM	miss.halle.hintz.dvm@warmmail.com	Charlotte	North Carolina	869948959184499847	48dadf758636af1a0b13c175ace1905d	Mastercard	35.2581694470506122	-80.7717024811953337
24721	2020-05-13 22:41:43	2020-05-13	Benedict Rice	benedict.rice@geemail.com	Chicago	Illinois	3049993706422182	4876832e71a4330eb22228e134e6760b	American Express	41.8544298758100766	-87.7057699819590795
24722	2020-05-13 23:05:29	2020-05-13	Elonzo Schneider	elonzo.schneider@geemail.com	Wichita	Kansas	3451650041542556	257a2bcdaeae267a703211d1aad16313	VISA 16 digit	37.645453803601491	-97.2539681056249918
24723	2020-05-13 23:36:20	2020-05-13	Vergil Spinka V	vergil.spinka.v@geemail.com	Philadelphia	Pennsylvania	6011003541444323810	a2a1d1ad1e0a9bce2ab109257bad30b1	Discover	40.0847336760215427	-75.1453252921711652
24724	2020-05-13 23:40:23	2020-05-13	Gasper Mertz	gasper.mertz@geemail.com	El Paso	Texas	6011125603565587889	5fb532375468c2420eab5982cb7d1f12	JCB 16 digit	31.84253537546061	-106.389920562364168
24725	2020-05-13 23:58:25	2020-05-13	Gemma Bahringer-Hills	gemma.bahringer.hills@warmmail.com	San Francisco	California	4527332522632	094a8625f311e91e92b7b6013a73d9c5	Discover	37.7522516742639809	-122.456674918850425
24726	2020-05-14 00:02:01	2020-05-14	Gay Klein	gay.klein@warmmail.com	Fresno	California	503881976918383	def09c9c9d0826c87790901efb7b135e	Discover	36.860617894061285	-119.715608184981718
24727	2020-05-14 00:04:18	2020-05-14	Djuna Dibbert	djuna.dibbert@woohoo.com	Las Vegas	Nevada	3026912781691779	6e6e88304e72814e21bbdac140fb09ff	Mastercard	36.1483992540843744	-115.248652141562104
24728	2020-05-14 00:21:27	2020-05-14	Porsha Quigley	porsha.quigley@geemail.com	Las Vegas	Nevada	3439883334171307	717914e36f3b3b3ec04827cf2053eadf	JCB 16 digit	36.2828116106901319	-115.255190543339026
24729	2020-05-14 00:30:29	2020-05-14	Mellissa Zieme	mellissa.zieme@geemail.com	Tampa	Florida	3112131278073540506	b342c715e7415670b579ad0974f012c6	VISA 16 digit	28.0621850665774168	-82.5259720629293412
24730	2020-05-14 00:52:20	2020-05-14	Damian Deckow	damian.deckow@woohoo.com	Jacksonville	Florida	060419375294188	7359ee92cf58a196eddbc7112716253d	JCB 15 digit	30.3305729094013579	-81.5731867858752651
24731	2020-05-14 00:52:55	2020-05-14	Haywood Bogan-Jenkins	haywood.bogan.jenkins@geemail.com	Vacaville	California	4524631306833	270872d2d54ce1d5fceb268e791dde08	VISA 13 digit	38.4042849613014639	-121.907695340213564
24732	2020-05-14 00:54:33	2020-05-14	Kevan Langworth	kevan.langworth@geemail.com	Columbus	Ohio	3059209123548073	6f39d28fcdba647d3ed9a0f5bcf72b7f	VISA 16 digit	39.8997212632138272	-83.0083786946490534
24733	2020-05-14 01:01:44	2020-05-14	Mai Reinger-Bergstrom	mai.reinger.bergstrom@geemail.com	Berkeley	California	3158282076138757983	375e833056df0b32480c9166f0b2e2da	Maestro	37.8494094642386116	-122.278025621582358
24734	2020-05-14 01:08:08	2020-05-14	Giovani Rau	giovani.rau@woohoo.com	Los Angeles	California	51308387046746244	09e1c7bb064ca368458dd2f497a6fcf4	Discover	34.0549837560258766	-118.331551228881992
24735	2020-05-14 01:14:04	2020-05-14	Mr. Armani Leffler Sr.	mr.armani.leffler.sr.@geemail.com	North Las Vegas	Nevada	869970857532987672	be3e103fca61cccf36633f995db126ed	Diners Club / Carte Blanche	36.3261664408415541	-115.046445261522763
24736	2020-05-14 01:19:40	2020-05-14	Mario Roob	mario.roob@woohoo.com	Cincinnati	Ohio	4151775076363906	6ee1eb3ebe1847819c659f98e8d3495d	American Express	39.188418039423226	-84.443143893339851
24737	2020-05-14 01:27:59	2020-05-14	Mr. Geraldo Wisoky	mr.geraldo.wisoky@geemail.com	Tulsa	Oklahoma	6011272057223874471	0206f1f8871ffd8849b499adac5599a1	JCB 15 digit	36.2271414290085403	-95.90123270526081
24738	2020-05-14 01:40:17	2020-05-14	Marcia Kiehn-Christiansen	marcia.kiehn.christiansen@woohoo.com	Philadelphia	Pennsylvania	4840745497669238	e87d9c9af649570f3ea6e65d9c832cef	VISA 16 digit	39.9352290311787286	-75.1398721557475682
24739	2020-05-14 01:41:03	2020-05-14	Hardie Weimann-Wyman	hardie.weimann.wyman@geemail.com	Sugar Land	Texas	869993488575635219	ab68492f91e609221560291476956769	JCB 16 digit	29.6986451947182424	-95.5535659507855684
24740	2020-05-14 01:43:01	2020-05-14	Ashely Sanford-Steuber	ashely.sanford.steuber@warmmail.com	Warren	Michigan	060413989519627	c78477a81c40269fc00eca60fdbf2855	Diners Club / Carte Blanche	42.5803072723556326	-82.9866155387833828
24741	2020-05-14 01:58:05	2020-05-14	Gordon Keeling-Rogahn	gordon.keeling.rogahn@geemail.com	Woodbridge	New Jersey	3013384422825278	0f297b6e827b1ae8cd9d1b406682dd28	Discover	40.5918262888368204	-74.2447762652158758
24742	2020-05-14 02:08:15	2020-05-14	Cam Romaguera-Hammes	cam.romaguera.hammes@geemail.com	Washington	District of Columbia	630400683818793	32cbeeb1902396eeb4fceabba823277c	American Express	38.8739286179453103	-77.0828806313432722
24743	2020-05-14 02:10:22	2020-05-14	Bernardo Gleason	bernardo.gleason@geemail.com	Colorado Springs	Colorado	869932310321102688	a7f442327184b2f28f7b7c0243d09c9c	American Express	38.8506361247554395	-104.710148347324505
24744	2020-05-14 02:36:08	2020-05-14	Retta Hettinger-Brekke	retta.hettinger.brekke@geemail.com	Montgomery	Alabama	869938014906521643	1d93beb5f730dfa2f6e12f9012edd9a3	Discover	32.2907461403336384	-86.2724665247056635
24745	2020-05-14 02:40:30	2020-05-14	Mareli Frami-Keebler	mareli.frami.keebler@geemail.com	Jersey City	New Jersey	3088215785609395311	7e35efb83247de2f45c329833fdecd70	Diners Club / Carte Blanche	40.6289032354891262	-74.1270235650662386
24746	2020-05-14 02:54:08	2020-05-14	Mr. Ancil Kshlerin MD	mr.ancil.kshlerin.md@geemail.com	Milwaukee	Wisconsin	4921456111951265	2fd31026bb9666e036caf6a0d4dac5ac	JCB 16 digit	43.1209798161491733	-87.9752059618577391
24747	2020-05-14 03:01:58	2020-05-14	Ivan Powlowski-Larkin	ivan.powlowski.larkin@geemail.com	Anaheim	California	6011877923380868151	5951239666d123bba51899ea0960c0cb	VISA 16 digit	33.9380627144891776	-117.811416182315341
24748	2020-05-14 03:10:10	2020-05-14	Dr. Oline Quitzon	dr.oline.quitzon@geemail.com	New York	New York	3752579456480862	57e50286e8c57de7b057abb002bc21eb	Diners Club / Carte Blanche	40.6689200533777466	-74.0376566959440652
24749	2020-05-14 03:12:44	2020-05-14	Millie Senger	millie.senger@geemail.com	Colorado Springs	Colorado	502002999740620	5cd073506808523b3ac288df6b078aa6	Diners Club / Carte Blanche	38.7814560266725721	-104.735599836257094
24750	2020-05-14 03:46:17	2020-05-14	Ann Murray	ann.murray@geemail.com	New York	New York	3088541776202287752	41ef9594d30a9fe254f0918aa22511b0	VISA 16 digit	40.5853712042085846	-73.8881126168545279
24751	2020-05-14 03:48:37	2020-05-14	Oliva Buckridge-Jerde	oliva.buckridge.jerde@geemail.com	Eugene	Oregon	3528118776000379069	2118e66078e34182b47abc19515225e8	Discover	44.0784019214760505	-123.04557836870552
24752	2020-05-14 03:48:46	2020-05-14	Cornell Sporer	cornell.sporer@geemail.com	San Francisco	California	6011986554575301498	68ba20ffaeeef085bd283138476a0d92	JCB 16 digit	37.7778093019463697	-122.387442474556238
24753	2020-05-14 04:03:48	2020-05-14	Stacey Emmerich	stacey.emmerich@geemail.com	Visalia	California	3158904884955192145	d31d3eab789312309a273975cad462d3	Voyager	36.337411901257191	-119.333200748556862
24754	2020-05-14 04:10:36	2020-05-14	Heyward Hettinger-Johnson	heyward.hettinger.johnson@geemail.com	San Antonio	Texas	3158976985431634759	ebc4624d64d8e31988603b78f53cac04	Voyager	29.4657485489338633	-98.4654759245760687
24755	2020-05-14 04:27:05	2020-05-14	Kurt Welch-Hegmann	kurt.welch.hegmann@geemail.com	San Antonio	Texas	676340161302134	dade27af60e141d991b5b608a9a2b5de	Diners Club / Carte Blanche	29.5173948723893602	-98.6193777545191352
24756	2020-05-14 04:38:57	2020-05-14	Reginald Casper	reginald.casper@geemail.com	Hartford	Connecticut	3481193896910135	2f0ba94a2e2f444f7f2b23a091781e73	VISA 16 digit	41.6682864143528064	-72.6722114448793235
24757	2020-05-14 04:41:02	2020-05-14	Tammi Crona	tammi.crona@warmmail.com	Oklahoma City	Oklahoma	3088286734182669340	f8d81fdfe9999d14890b3f6a62d60600	Diners Club / Carte Blanche	35.5212715220548247	-97.5116754402302206
24758	2020-05-14 04:51:28	2020-05-14	Tobi Strosin-Hamill	tobi.strosin.hamill@geemail.com	New York	New York	4157468711149369	24f3f3f3e4555baf2d417c7b75c15b7e	American Express	40.6282500320803379	-73.9499216603010865
24759	2020-05-14 04:53:23	2020-05-14	Mayra Bergnaum PhD	mayra.bergnaum.phd@geemail.com	Boise	Idaho	3337169365562052609	05376840fe3177a3761ef82eec1f9810	VISA 16 digit	43.6932786990560587	-116.198831047975276
24760	2020-05-14 04:54:30	2020-05-14	Gladyce Balistreri	gladyce.balistreri@geemail.com	Laredo	Texas	3088451313718175020	2cc8251be12ebeb421f363b9f799f7d5	Diners Club / Carte Blanche	27.5906733519580243	-99.5755983241375446
24761	2020-05-14 04:58:22	2020-05-14	Oleta Purdy	oleta.purdy@woohoo.com	Henderson	Nevada	4803973803338	d72958105c2ba4ffd0fb045b059d9072	Discover	35.9569742245532566	-115.095273082067081
24762	2020-05-14 05:05:17	2020-05-14	Solomon Willms	solomon.willms@geemail.com	Boise	Idaho	3088862194440753489	b8dcd1416a60fc766142e4ae85323ef2	American Express	43.6398572405938054	-116.240181640415273
24763	2020-05-14 05:11:38	2020-05-14	Dr. Tishie Schuster DVM	dr.tishie.schuster.dvm@geemail.com	Berkeley	California	51001379564831946	67b1413e42dd0a7ea3c73084ed958c43	Mastercard	37.8891921875455324	-122.238132589960159
24764	2020-05-14 05:17:00	2020-05-14	Andra Marks-VonRueden	andra.marks.vonrueden@warmmail.com	New Haven	Connecticut	3337171326779133364	45ef3c6b49ad9a6ebd3e5fffd4fc3eba	Discover	41.3939418209709231	-72.9503602990414919
24765	2020-05-14 05:34:00	2020-05-14	Trinidad Bogan	trinidad.bogan@geemail.com	Fort Worth	Texas	4942322769269	6571e3fabd67510a1de07e0fe337aae8	Voyager	32.8514778309091966	-97.2734366796731962
24766	2020-05-14 05:41:50	2020-05-14	Shalonda Kutch-Mayer	shalonda.kutch.mayer@warmmail.com	Berkeley	California	54441484427833937	322c6d147426ae720475200b046d0ac5	American Express	37.8869720070015532	-122.320292611122824
24767	2020-05-14 05:42:07	2020-05-14	Phoenix Ratke	phoenix.ratke@woohoo.com	San Francisco	California	4339546039555	57d4b6f4c70a72c1b70ebbae89776b87	Maestro	37.8026132381241737	-122.448686957866229
24768	2020-05-14 05:56:14	2020-05-14	Braeden Howe DVM	braeden.howe.dvm@geemail.com	Nashville	Tennessee	869953680450839639	0cc03593bee26573cadfb60f3e56bd78	Maestro	36.2655439234461596	-86.8449534479435528
24769	2020-05-14 06:06:13	2020-05-14	Belva Hermann-Larkin	belva.hermann.larkin@geemail.com	Las Vegas	Nevada	3096387165716123025	19ed73efa1e57ceaf0dab654a3fbdae9	Diners Club / Carte Blanche	36.3062889341831223	-115.176469427042079
24770	2020-05-14 06:06:20	2020-05-14	Dr. Erle Willms I	dr.erle.willms.i@woohoo.com	Akron	Ohio	4847989564431774	701af14c56882c295b19dcaf9e8eb86f	Diners Club / Carte Blanche	40.9858973301313796	-81.4218365643952069
24771	2020-05-14 06:24:28	2020-05-14	Lauretta Jerde DDS	lauretta.jerde.dds@geemail.com	Boston	Massachusetts	3043981459448724	613d2f0faabaab79ce31460b1ff7f3b6	VISA 16 digit	42.2896507470104837	-71.1001376019276705
24772	2020-05-14 06:29:55	2020-05-14	Mrs. Marceline Stokes	mrs.marceline.stokes@woohoo.com	New York	New York	675974071992957	d4267ddc5c9c144a1d55cea7f41bcd6e	JCB 16 digit	40.7264820500966138	-73.859107065236941
24773	2020-05-14 06:31:42	2020-05-14	Dr. Brion Hackett Sr.	dr.brion.hackett.sr.@geemail.com	Virginia Beach	Virginia	53845503295861829	8606e12211db89003c89bedbc9e7c1ac	Discover	36.7293111365009111	-76.0008933473516208
24774	2020-05-14 06:33:25	2020-05-14	Roma Nitzsche	roma.nitzsche@geemail.com	Oakland	California	4840100025524382	e4008ba03de8086e1333530dbd115108	VISA 13 digit	37.7954355694608495	-122.261698183208296
24775	2020-05-14 06:42:46	2020-05-14	Mrs. Jaunita Skiles	mrs.jaunita.skiles@geemail.com	Costa Mesa	California	3701628266125167	172f748bc63003446948ce4492562917	Maestro	33.6992004971500521	-117.848109523565697
24776	2020-05-14 06:48:55	2020-05-14	Felton Deckow-Purdy	felton.deckow.purdy@geemail.com	Irving	Texas	3015191095080596	62fdb0672a07691384359eb3936c18dd	Mastercard	32.8469927114386095	-96.9692604081518965
24777	2020-05-14 06:51:52	2020-05-14	Deegan Hyatt	deegan.hyatt@geemail.com	Sacramento	California	3088481456261937082	2b619ab86d8a5738b1e0dfe24b9ea90c	JCB 15 digit	38.514653519846874	-121.377257999010752
24778	2020-05-14 06:52:16	2020-05-14	Huey Hoeger	huey.hoeger@geemail.com	Torrance	California	4379839635693	6d2e9ad5c33475f5df2948bc9c100472	VISA 16 digit	33.9270133750885705	-118.275014641008895
24779	2020-05-14 06:54:01	2020-05-14	Alessandra Littel PhD	alessandra.littel.phd@woohoo.com	Waterbury	Connecticut	4897454777055257	fc163ca3ff32db7b42e6acfdc8e8c91a	JCB 15 digit	41.6221816464830212	-72.9516706583004435
24780	2020-05-14 07:15:11	2020-05-14	Latoya Lebsack-Corkery	latoya.lebsack.corkery@warmmail.com	El Paso	Texas	3337735441485912297	7c312db22a16174de899ff7129509978	Maestro	31.8435361975632638	-106.458033695442609
24781	2020-05-14 07:18:01	2020-05-14	Mr. Lewis Senger Sr.	mr.lewis.senger.sr.@geemail.com	Los Angeles	California	52660487857165088	166fcb629757f507842edd71fbdbe8d3	VISA 16 digit	33.9211663851845984	-118.464848386588685
24782	2020-05-14 07:26:24	2020-05-14	Dr. Hilario Lakin Sr.	dr.hilario.lakin.sr.@warmmail.com	Berkeley	California	53946457994926037	57f6c0211b928b69560cee58243c2afc	JCB 16 digit	37.8405968911022796	-122.25579533748467
24783	2020-05-14 07:43:39	2020-05-14	Mrs. Noemi Feeney	mrs.noemi.feeney@warmmail.com	New York	New York	501862116107392	aff9bc10d12702f85c5c20f31c32520d	JCB 15 digit	40.6685602339208145	-73.9449704905867549
24784	2020-05-14 07:56:39	2020-05-14	Cilla Ullrich DDS	cilla.ullrich.dds@warmmail.com	Lubbock	Texas	4362141819803473	c17f9631f406b07300157c58c3fa0ede	VISA 16 digit	33.6039955198340152	-101.897069642637675
24785	2020-05-14 08:25:06	2020-05-14	Joshuah Balistreri	joshuah.balistreri@geemail.com	Tulsa	Oklahoma	4996455949371696	2d00e13ec59b59a910a94fdc8d732df6	JCB 16 digit	36.1387239423017945	-95.9568766659080978
24786	2020-05-14 08:27:20	2020-05-14	Greg Crona	greg.crona@geemail.com	San Francisco	California	3158760220771950791	e94c0b21bc1583dea8741e2a13673246	VISA 13 digit	37.7979175941380277	-122.446735641105988
24787	2020-05-14 08:41:15	2020-05-14	Miss Karyl Weimann	miss.karyl.weimann@warmmail.com	McKinney	Texas	675958809770777	f0efe84ea82c43f8a987052806651f56	Diners Club / Carte Blanche	33.105272260367876	-96.6142571085896407
24788	2020-05-14 08:43:25	2020-05-14	Dr. Cortney Kilback V	dr.cortney.kilback.v@geemail.com	Springfield	Massachusetts	3158567234071230064	d74907e2a273881e464febee6240dd1e	VISA 16 digit	42.1752550173755694	-72.46114119445906
24789	2020-05-14 08:50:17	2020-05-14	Amya Hyatt DDS	amya.hyatt.dds@woohoo.com	Denver	Colorado	3088426714028675850	4b8e27b190d34417a7fe3d7dea06fe6f	Diners Club / Carte Blanche	39.7786705444153341	-104.820648558788378
24790	2020-05-14 08:58:29	2020-05-14	Mr. Theo Deckow MD	mr.theo.deckow.md@woohoo.com	Riverside	California	210087808234110130	f93481d631c120924b9fddc82bba0a39	Discover	33.9877178420260506	-117.381730040578915
24791	2020-05-14 09:00:30	2020-05-14	Shamar Thompson-McLaughlin	shamar.thompson.mclaughlin@geemail.com	West Valley City	Utah	676185027980037	9b8d815ca1d332b25fc35ed0f3f94735	Maestro	40.748310547577212	-111.983096977158624
24792	2020-05-14 09:09:56	2020-05-14	Anfernee Stroman I	anfernee.stroman.i@warmmail.com	Downey	California	6011508853448211572	4226401e024734a7aa3d400b7616cec1	VISA 16 digit	33.9915731400035313	-118.208121689326688
24793	2020-05-14 09:10:07	2020-05-14	Ms. Laurine Vandervort PhD	ms.laurine.vandervort.phd@geemail.com	San Francisco	California	55505506364475174	0ee29777b518d7d100f242533e0da9d0	VISA 13 digit	37.767065131807982	-122.416027378113611
24794	2020-05-14 09:11:26	2020-05-14	Arah Predovic	arah.predovic@geemail.com	Charlotte	North Carolina	3158885549847167117	b1c47a180548ad67c245b143426ec48d	JCB 15 digit	35.2472174669869247	-80.8081171161905019
24795	2020-05-14 09:11:54	2020-05-14	Malcolm Runte	malcolm.runte@geemail.com	Santa Ana	California	3742583467564980	4a5cb6dffe0bc6f22aa4658c148fca53	VISA 16 digit	33.6519940028071431	-117.875847178876398
24796	2020-05-14 09:12:28	2020-05-14	Dr. Elwyn Doyle Jr.	dr.elwyn.doyle.jr.@woohoo.com	Meridian	Idaho	869975894390034458	bf19f5fd00a4e11e91be415f1bf25725	American Express	43.710991838668285	-116.435385137557603
24797	2020-05-14 09:17:55	2020-05-14	Dalia Altenwerth	dalia.altenwerth@warmmail.com	Jacksonville	Florida	869916946593870708	6a75b9502793dc49ec70b12009e8e01f	American Express	30.3998095301497742	-81.6535157849624795
24798	2020-05-14 09:20:28	2020-05-14	Judy Renner-Kuhlman	judy.renner.kuhlman@geemail.com	Chicago	Illinois	53683230583737421	48a487a731802c20962b7e293ee6dc6c	Discover	41.8932854127440635	-87.7692842324759823
24799	2020-05-14 09:22:09	2020-05-14	Trinidad Corkery-Bins	trinidad.corkery.bins@warmmail.com	Visalia	California	4314686008349919	9f422a9859fc77d93d75081a3a8739af	JCB 16 digit	36.289651019866767	-119.402515807574247
24800	2020-05-14 09:28:28	2020-05-14	Mrs. Belia Williamson DDS	mrs.belia.williamson.dds@geemail.com	Houston	Texas	4444729474783	55480084d743323912aa73b648e92510	VISA 13 digit	29.6984052719160907	-95.4355975741535474
24801	2020-05-14 09:31:55	2020-05-14	Bertie Lakin	bertie.lakin@woohoo.com	Lakeland	Florida	4794435880824022	b81470d274025a7a97eb4bc475af667c	JCB 16 digit	28.1375135873742401	-81.9484435863677305
24802	2020-05-14 09:38:20	2020-05-14	Ms. Nelda Ritchie	ms.nelda.ritchie@geemail.com	San Francisco	California	3112316346140074036	153708fccdab4c78cfecfff21cade2d8	Voyager	37.8007634143880367	-122.443250672838857
24803	2020-05-14 09:47:00	2020-05-14	Oliver Bechtelar IV	oliver.bechtelar.iv@geemail.com	Evansville	Indiana	210060972127797022	da84e51720b2242431a3069d35ee450b	Maestro	37.92269201443046	-87.528184173854811
24804	2020-05-14 09:48:28	2020-05-14	Art Donnelly-Ryan	art.donnelly.ryan@geemail.com	Houston	Texas	4678734161361089	7d184c9f22b6771dfa1e1737ce13edaf	JCB 15 digit	29.7523515174243585	-95.4767262646943351
24805	2020-05-14 09:58:00	2020-05-14	Eathel Monahan	eathel.monahan@woohoo.com	Irving	Texas	4473424664786	779289cd5e1c9cad9861db8bbb508e79	VISA 16 digit	32.9538898691020918	-96.9384220017399656
24806	2020-05-14 10:05:18	2020-05-14	Goebel Kovacek	goebel.kovacek@geemail.com	New York	New York	3772914457709512	ce669d967d462b736edc593ed590043a	Diners Club / Carte Blanche	40.6139966327920519	-74.0319345573324625
24807	2020-05-14 10:23:31	2020-05-14	Joelle Padberg-Watsica	joelle.padberg.watsica@geemail.com	Athens	Georgia	3448128720486482	974cd88e5f8d4c7a1be2c3ba0307c4dc	VISA 16 digit	33.9883674124911366	-83.2967003615688526
24808	2020-05-14 10:23:44	2020-05-14	Yareli Runte	yareli.runte@geemail.com	Raleigh	North Carolina	3407011388620155	5a6c2dc05b74941477785b6935f7bd22	JCB 16 digit	35.7383410763595251	-78.5425493014913059
24809	2020-05-14 10:25:09	2020-05-14	Delma Pouros	delma.pouros@geemail.com	Los Angeles	California	6011462223299809813	2776932dcd06f9783bc2f6552c32ed5f	JCB 15 digit	33.9932271603360761	-118.491718882973487
24810	2020-05-14 10:26:58	2020-05-14	Mr. Powell Schowalter	mr.powell.schowalter@woohoo.com	Cincinnati	Ohio	3775526599333600	20b07fe988184782e19c8eb89040b4f3	VISA 16 digit	39.1786730300866068	-84.4114027544662235
24811	2020-05-14 10:30:45	2020-05-14	Ms. Eleanor Kub MD	ms.eleanor.kub.md@geemail.com	Murfreesboro	Tennessee	180039891767352997	fe658802dabc0f165f64d5758ecd2fd9	JCB 15 digit	35.7606194175899077	-86.3541184527184811
24812	2020-05-14 10:40:36	2020-05-14	Altie Quitzon DVM	altie.quitzon.dvm@geemail.com	Chula Vista	California	4150139653946	b87ee76b971ee2747012061c4f13c7f2	Maestro	32.700842351396382	-117.052632794412588
24813	2020-05-14 10:49:23	2020-05-14	Parker Brakus	parker.brakus@geemail.com	Raleigh	North Carolina	3733045340131073	951c73cb6af1b634b6b62dbdf2680b08	JCB 15 digit	35.7716951867233917	-78.7086176285456958
24814	2020-05-14 10:54:47	2020-05-14	Miss Shawanda Kautzer	miss.shawanda.kautzer@geemail.com	Baltimore	Maryland	4108386518409770	0afbceccdbaf9e21fcac240c8a9d1b95	Mastercard	39.2260544660501154	-76.6929142920319009
24815	2020-05-14 11:45:05	2020-05-14	Gibson Wuckert	gibson.wuckert@geemail.com	Rochester	New York	210061976303152893	762d88b403e0f1bce7a63ffff22ff114	VISA 13 digit	43.1855346989795521	-77.5294739015173207
24816	2020-05-14 11:45:47	2020-05-14	Dr. Zayne Hahn DVM	dr.zayne.hahn.dvm@geemail.com	Saint Paul	Minnesota	4675068599746840	ba21480844688ecd965ed63ee5df8a5d	JCB 16 digit	44.9125842857580651	-93.1807886965837326
24817	2020-05-14 11:52:01	2020-05-14	Ms. Earlean Bogisich	ms.earlean.bogisich@geemail.com	Waco	Texas	4892158985341	853e7dd723b528b1a466bf72842578e5	VISA 16 digit	31.646254472269117	-97.2018898107241966
24818	2020-05-14 11:55:46	2020-05-14	Mrs. Sherlyn O'Reilly MD	mrs.sherlyn.o'reilly.md@geemail.com	Pasadena	California	4398757457351	9bfcc5b1dd01060807e16788a5101dd7	VISA 16 digit	34.0763330771442554	-118.234142873324828
24819	2020-05-14 11:57:52	2020-05-14	Jerilynn Hessel	jerilynn.hessel@woohoo.com	Stamford	Connecticut	54084069476475276	7671b0241b4e9168df12572ad69ff0ca	Diners Club / Carte Blanche	41.0945716343704603	-73.4620841207951401
24820	2020-05-14 12:04:31	2020-05-14	Hideo VonRueden	hideo.vonrueden@geemail.com	Orlando	Florida	3022842899556545	15f9e431a6b893da91843bf9fca6e5c6	Discover	28.4038435584664342	-81.1989543621860435
24821	2020-05-14 12:11:10	2020-05-14	Dr. Marianna Braun	dr.marianna.braun@woohoo.com	Houston	Texas	6011981228651645657	b2080ed6f674d764ecd2bcdf8ad103c1	JCB 15 digit	29.7244111436963081	-95.3419895042214591
24822	2020-05-14 12:33:28	2020-05-14	Jalisa Hintz	jalisa.hintz@geemail.com	Cleveland	Ohio	3158454862493052280	42a4a808495cbdceeffd6f76b3e80ee4	VISA 16 digit	41.3908074927832885	-81.7188622121937556
24823	2020-05-14 12:34:41	2020-05-14	Spurgeon Gleichner	spurgeon.gleichner@woohoo.com	Lancaster	California	6011067861583017467	a279e5876e61a8879fde13b7856c6881	VISA 16 digit	34.7290431954212551	-118.113937251500033
24824	2020-05-14 12:48:37	2020-05-14	Grant Wisozk	grant.wisozk@geemail.com	Tacoma	Washington	869905294403360823	bf2df61c471ae8c796a2eddccad9a2ab	American Express	47.1793412216592571	-122.449340409343321
24825	2020-05-14 12:55:28	2020-05-14	Lorenzo Okuneva	lorenzo.okuneva@geemail.com	New York	New York	3047365369334131	d904ad504bfb24783f9d3772cde47285	Maestro	40.5715189729575059	-73.9568518534198347
24826	2020-05-14 13:09:30	2020-05-14	Delaney Kemmer	delaney.kemmer@geemail.com	Springfield	Missouri	3028605321091579	bba338fa4fa994273910bc20db3cfc59	Maestro	37.2124253933511682	-93.2445753162086106
24827	2020-05-14 13:20:42	2020-05-14	Alphons Roob	alphons.roob@woohoo.com	Phoenix	Arizona	869905525461122195	0893cb64ba0378ac73fc428277e94f3d	JCB 16 digit	33.5464922136560091	-112.098431692172227
24828	2020-05-14 13:23:44	2020-05-14	Kalel Sauer I	kalel.sauer.i@woohoo.com	Frisco	Texas	4836562979366	26d4e8567d8cb8da557572170acce9d9	VISA 16 digit	33.2353401544500144	-96.8709688987791537
24829	2020-05-14 13:23:46	2020-05-14	Jasiah Volkman	jasiah.volkman@geemail.com	Garland	Texas	869929416012680588	a570ac35e5ee6df2e17d76e172f2ce7d	VISA 13 digit	32.9791331487011163	-96.5912440116211855
24830	2020-05-14 13:28:09	2020-05-14	Joaquin Ledner Jr.	joaquin.ledner.jr.@geemail.com	Boston	Massachusetts	4075423282492	aa2a2e393ced592d8deb8bb9f703fcbd	JCB 16 digit	42.4114124535284915	-71.0896370757788389
24831	2020-05-14 13:28:23	2020-05-14	Julious Bednar	julious.bednar@geemail.com	Philadelphia	Pennsylvania	3730328492631279	554e7a3e1c9edda065754c34fe19043d	Maestro	40.0574071741621935	-75.1950077354807433
24832	2020-05-14 13:39:44	2020-05-14	Cloyd Lebsack	cloyd.lebsack@geemail.com	Naperville	Illinois	3053855289922480	33945b902fae0949958854d32a984407	Mastercard	41.6693631507836315	-88.1356974673811351
24833	2020-05-14 13:48:43	2020-05-14	Artis Robel	artis.robel@geemail.com	Norman	Oklahoma	3409505581563706	c6dba5a34e71cccf56198107242dc4a9	JCB 15 digit	35.3247694702860002	-97.2624536953188397
24834	2020-05-14 13:49:56	2020-05-14	Tammy Thiel DDS	tammy.thiel.dds@geemail.com	Houston	Texas	54205287801769163	15b06add243d69bd17c009e79d220c62	Maestro	29.771126383969932	-95.3960764904055765
24835	2020-05-14 14:07:48	2020-05-14	Dr. Vonnie Kautzer	dr.vonnie.kautzer@geemail.com	Bridgeport	Connecticut	869950798195983034	de25b0b53c3fe4c3b560d1774329dc92	VISA 13 digit	41.1964670676436242	-73.1605139066830361
24836	2020-05-14 14:15:54	2020-05-14	Gaige Lind	gaige.lind@geemail.com	Tempe	Arizona	180085259828326918	7ef9ec2086ec8fc7937a61a96b343fc4	JCB 16 digit	33.3956255747392774	-111.960333427044745
24837	2020-05-14 14:37:13	2020-05-14	Terrell Ernser	terrell.ernser@geemail.com	Houston	Texas	3158157842865705830	761a7371b2cc27f00433c56b539dcfa4	VISA 16 digit	29.7629734258245691	-95.4322786363787969
24838	2020-05-14 14:44:03	2020-05-14	Shelby Kreiger-Walsh	shelby.kreiger.walsh@woohoo.com	Long Beach	California	4962745676669	01e57b9e38a0ad42a79dddca246a2af4	VISA 13 digit	33.8089183332219676	-118.15514494834207
24839	2020-05-14 14:48:02	2020-05-14	Elda Rogahn PhD	elda.rogahn.phd@woohoo.com	San Antonio	Texas	6011631151616321418	48dcafd82ef78130c8939c07f741b139	Voyager	29.4689853395871815	-98.4992116415709233
24840	2020-05-14 15:00:34	2020-05-14	Waneta McKenzie	waneta.mckenzie@geemail.com	San Antonio	Texas	869976037803322420	808347c92c148397af05a7c7523dea66	Discover	29.5277806053474556	-98.4878195724286059
24841	2020-05-14 15:06:09	2020-05-14	Rosabelle Jacobs	rosabelle.jacobs@geemail.com	Fort Lauderdale	Florida	3158059936339612041	b0dd49db490e217919946f2d7bd8d7a3	VISA 13 digit	26.0970662360999732	-80.0707183518268124
24842	2020-05-14 15:07:58	2020-05-14	Leisa Rowe	leisa.rowe@geemail.com	New York	New York	3058983635266454	1f93d494a85e72a4b707aabfb97c0ea9	JCB 16 digit	40.6267181548979153	-74.0212949962716493
24843	2020-05-14 15:15:49	2020-05-14	Kahlil Schmidt	kahlil.schmidt@warmmail.com	Columbus	Ohio	3000536103821545	3d9763041d28e6bd8945c3038f854455	JCB 16 digit	40.0576256912711983	-82.9833946284141462
24844	2020-05-14 15:33:19	2020-05-14	Callum Wisoky	callum.wisoky@warmmail.com	San Francisco	California	869987624584005220	847ac18f735c81f03fa2576fff86af78	Maestro	37.7710043984416117	-122.439972189662512
24845	2020-05-14 15:54:32	2020-05-14	Palma Kilback	palma.kilback@warmmail.com	San Francisco	California	869960453020610992	74d0c7ffc89f11bb1a73e3db6e1354ce	Maestro	37.7910848369145285	-122.41381907648514
24846	2020-05-14 16:00:44	2020-05-14	Dr. Jo Lang PhD	dr.jo.lang.phd@geemail.com	Washington	District of Columbia	3024362863426359	c43be90390cec139883fa7a968b62612	Discover	38.9071717098619771	-76.9870245838284575
24847	2020-05-14 16:09:31	2020-05-14	Sheldon Kuhn Jr.	sheldon.kuhn.jr.@geemail.com	Seattle	Washington	6011956332108227357	df4d5c29af741750d3cf04bbdbc515be	Discover	47.625020225152376	-122.36435947883092
24848	2020-05-14 16:10:19	2020-05-14	Ezequiel Spencer	ezequiel.spencer@geemail.com	San Francisco	California	869982179298080899	8b8ef5235f37718c7e307b376f2edc33	Mastercard	37.780930051894714	-122.453863408147868
24849	2020-05-14 16:20:30	2020-05-14	Marlana Pacocha	marlana.pacocha@geemail.com	Philadelphia	Pennsylvania	4115617225048555	a39d8c035735cc4707619572e045c371	American Express	40.0423420217778556	-75.1211818100318425
24850	2020-05-14 16:53:04	2020-05-14	Wyatt Rohan	wyatt.rohan@geemail.com	Bellevue	Washington	4909968810210	4e5ae9660b353490b360bf2ad1b8cb7c	Maestro	47.5435468386109932	-122.204936807096004
24851	2020-05-14 17:02:28	2020-05-14	Rella Grimes	rella.grimes@geemail.com	San Francisco	California	3096183464814548068	81adc01530dc6377b8f20e84ed640806	Maestro	37.7945764359740579	-122.472200900877596
24852	2020-05-14 17:22:29	2020-05-14	Kami Wilkinson	kami.wilkinson@geemail.com	Gainesville	Florida	4205400011933	b0250ce8d9940a0733778e15fd8c0834	JCB 16 digit	29.7024775983124947	-82.3890060096386918
24853	2020-05-14 17:24:19	2020-05-14	Chancey Ernser	chancey.ernser@geemail.com	San Francisco	California	4839601230700801	a5691e5e8fc9d1e4dae402de00eaddfc	JCB 15 digit	37.8201897636039988	-122.432860831208927
24854	2020-05-14 17:34:34	2020-05-14	Ansley Murray	ansley.murray@geemail.com	Chicago	Illinois	3730733503317638	7c3513d2974880e6a7ee3918724decaf	Voyager	41.7962539372336153	-87.7645944808173937
24855	2020-05-14 17:36:48	2020-05-14	Monserrat Tromp	monserrat.tromp@geemail.com	San Antonio	Texas	4755437829658187	671a5b255ab61020289c0754746a9882	Maestro	29.5626708619367342	-98.5437375371646027
24856	2020-05-14 17:39:16	2020-05-14	Lucinda Ratke-Nikolaus	lucinda.ratke.nikolaus@geemail.com	Wichita	Kansas	210016693722212630	4c2b3835bf1fa5e9bcd2e249799014ae	Voyager	37.6639496818527562	-97.3255433266252226
24857	2020-05-14 17:41:11	2020-05-14	Dalvin Schamberger-Olson	dalvin.schamberger.olson@geemail.com	Chicago	Illinois	54666832213170864	fd03c77040a2f9a9c22a138d34bb1bdc	JCB 16 digit	41.7692273034550254	-87.5980361411377686
24858	2020-05-14 17:43:11	2020-05-14	Vivian King	vivian.king@woohoo.com	Plano	Texas	3044354227008536	e02e33765b268c8df5aacdf0b2ee63b4	VISA 16 digit	33.073212297315898	-96.7384553714372259
24859	2020-05-14 17:49:04	2020-05-14	Belia Bashirian	belia.bashirian@woohoo.com	Miami	Florida	4404849529394324	593187ea74d8246645ad23a77e2570aa	JCB 16 digit	25.8535060200978073	-80.1502102858726033
24860	2020-05-14 18:00:41	2020-05-14	Elvin Beahan	elvin.beahan@woohoo.com	Denver	Colorado	4491614525690	17626d4809b380d5605d3d7dda4232ca	VISA 16 digit	39.8089575301442267	-104.839586159704623
24861	2020-05-14 18:15:50	2020-05-14	Mr. Spenser Hoppe	mr.spenser.hoppe@warmmail.com	New York	New York	6011660093396855302	c24ac272244ff35f2a26d53c167359a8	Mastercard	40.6317457367889574	-74.0114535539772334
24862	2020-05-14 18:16:11	2020-05-14	Jayvion Gaylord MD	jayvion.gaylord.md@geemail.com	Topeka	Kansas	3753065936021087	8dbc881d00d6d752a2a13c661bcc8f2a	Discover	39.0290804360926131	-95.7011881456419928
24863	2020-05-14 18:23:04	2020-05-14	Nils Hayes-Tillman	nils.hayes.tillman@geemail.com	San Antonio	Texas	4565756754755076	3c7de3c1d02bd7740f637ae1d0429717	JCB 15 digit	29.3844693184435357	-98.5774759427480376
24864	2020-05-14 18:24:43	2020-05-14	Tatyanna Rogahn	tatyanna.rogahn@geemail.com	Wichita	Kansas	180088135992308030	9c9ba6c56eb4a377ee5d75ae3f6fbb1f	JCB 16 digit	37.7458112784538429	-97.3144921552125339
24865	2020-05-14 18:40:02	2020-05-14	Chrissy Ankunding-Schaden	chrissy.ankunding.schaden@woohoo.com	Irvine	California	869967907654914403	c5adbc8984631fa28bd5152ee05a9d56	Diners Club / Carte Blanche	33.6344158794745809	-117.707077768399557
24866	2020-05-14 18:43:20	2020-05-14	Delton Hackett	delton.hackett@geemail.com	Chicago	Illinois	3528835807469993272	0e9ac80f8fece59ee5ec34719a8da307	JCB 16 digit	41.7790814590476458	-87.7089538036875354
24867	2020-05-14 18:50:35	2020-05-14	Nikia Graham-Hackett	nikia.graham.hackett@warmmail.com	Irvine	California	4090669099126677	b18403387eaa5b0219047db9f21837e2	VISA 16 digit	33.7328531584251721	-117.695437033382433
24868	2020-05-14 18:52:51	2020-05-14	Dorthea Thompson	dorthea.thompson@geemail.com	San Francisco	California	3799019111242675	0e2efd721d5106b922cfebf4f9520cf7	Maestro	37.7777359118953697	-122.421784178944705
24869	2020-05-14 19:26:23	2020-05-14	Ezekiel Wiza	ezekiel.wiza@geemail.com	Pittsburgh	Pennsylvania	210064152843052111	a2ecbc8b2dd24c588d866e3f194a2b2e	JCB 16 digit	40.5276004509024332	-79.9922430644448923
24870	2020-05-14 19:28:10	2020-05-14	Gianna Jast	gianna.jast@geemail.com	Oakland	California	3158169564915240388	6466154dad1751d193b38ef6bb876bf0	VISA 16 digit	37.8243041760786909	-122.278002724704947
24871	2020-05-14 19:43:02	2020-05-14	Birtha Rowe	birtha.rowe@geemail.com	Long Beach	California	4716793112895508	b0bd13e6600633075c7dee03dc238403	Voyager	33.788440150097756	-118.230088770219311
24872	2020-05-14 19:52:06	2020-05-14	Lary Runte	lary.runte@geemail.com	San Francisco	California	869970438533605959	b145e36ee6586661ea07e6d2104622c3	Voyager	37.7878063510169753	-122.439308724679279
24873	2020-05-14 19:52:37	2020-05-14	Arely Mitchell	arely.mitchell@geemail.com	Houston	Texas	3715691918648980	fcd4b6ec0384dc3c3a67c22fe003b0a0	Diners Club / Carte Blanche	29.6882557204071418	-95.430422436121475
24874	2020-05-14 19:57:17	2020-05-14	Dr. Taurus Boehm	dr.taurus.boehm@geemail.com	New York	New York	4605196883025	7fd536e2d70368427b132321baa4826f	Mastercard	40.6514528277087948	-74.0029750864848523
24875	2020-05-14 19:57:51	2020-05-14	Kem Grady	kem.grady@geemail.com	Berkeley	California	3745869757824060	e2230d56ce45489b2760fd34f8a7986e	American Express	37.8695344994986769	-122.272648802402415
24876	2020-05-14 20:06:46	2020-05-14	Libbie Jenkins	libbie.jenkins@geemail.com	San Jose	California	4508480705519818	9e158cc037a47f0f3f6e42f153ed6456	VISA 16 digit	37.3777210330411833	-121.892302436543261
24877	2020-05-14 20:08:33	2020-05-14	Casie Hermiston	casie.hermiston@geemail.com	Cincinnati	Ohio	630471466546851	894543522d88128089f6f7c06becdc4f	JCB 16 digit	39.2359048649899691	-84.5788989504139863
24878	2020-05-14 20:16:03	2020-05-14	Letitia Leannon	letitia.leannon@geemail.com	Roseville	California	502018184494021	06d02e68da4e0febb665b63336fdf54c	JCB 15 digit	38.8375887268278746	-121.411812576068186
24879	2020-05-14 20:38:12	2020-05-14	Adrien Hayes	adrien.hayes@geemail.com	San Francisco	California	3088565652131537735	8d994f07798d2a492db787e32e7b9245	JCB 15 digit	37.7832612985707428	-122.41248813325835
24880	2020-05-14 20:38:53	2020-05-14	Lavinia Abbott	lavinia.abbott@geemail.com	Albuquerque	New Mexico	180039562424171555	529183b9cba145ee504640a67ad03245	Voyager	35.0228067346982712	-106.579749705835809
24881	2020-05-14 20:40:40	2020-05-14	Darian Sipes	darian.sipes@geemail.com	Honolulu	Hawaii	4060176389732855	060e06c400e449ebba2caeacc629bab5	VISA 16 digit	21.3221569979779417	-157.842063903689763
24882	2020-05-14 20:46:20	2020-05-14	Dafne Harber-Kihn	dafne.harber.kihn@woohoo.com	Philadelphia	Pennsylvania	3096051931012423384	4dc301ecda4754607162d50f7c4fa9b8	Mastercard	40.067358349958063	-75.0653964646991341
24883	2020-05-14 20:55:19	2020-05-14	Ryland Stracke	ryland.stracke@warmmail.com	Chicago	Illinois	4858364797325	32446d4912055f8d1d66c1a9e1976ab3	JCB 15 digit	41.7847526202280122	-87.6147288035631107
24884	2020-05-14 21:00:13	2020-05-14	Dr. Ibrahim Weissnat	dr.ibrahim.weissnat@geemail.com	Stockton	California	502044296253071	3b72fb6c0288b0f2adf10992e612342e	American Express	37.9909348079666529	-121.244901681746541
24885	2020-05-14 21:10:17	2020-05-14	Trevin Gibson	trevin.gibson@geemail.com	Oakland	California	3051397352338130	42fe01e07e09e59dd82d162efd2b55fe	VISA 13 digit	37.7988325380836798	-122.29061029231336
24886	2020-05-14 21:26:14	2020-05-14	Dr. Michaele Mitchell	dr.michaele.mitchell@geemail.com	San Francisco	California	52639431728074911	c9521891d883ea7a9cd962ae82cddd6f	JCB 15 digit	37.783604789217037	-122.410177654967541
24887	2020-05-14 21:28:52	2020-05-14	Deb Goyette	deb.goyette@warmmail.com	San Francisco	California	4429824648209	cd0e03af24117d4af8f27b1e3b5d76c2	Voyager	37.7638358796990943	-122.456058087382644
24888	2020-05-14 21:36:07	2020-05-14	Hessie Parisian	hessie.parisian@geemail.com	Cleveland	Ohio	4338219696556611	9949553b3e62b8fe0f44a2f9f880ec23	Mastercard	41.4244743723273245	-81.6881287543807133
24889	2020-05-14 21:38:20	2020-05-14	Bette Koelpin	bette.koelpin@geemail.com	Wilmington	North Carolina	3701910092444503	e67e29dd8f7411178004dddde54d61e0	Discover	34.2743249158196193	-77.8367658986702651
24890	2020-05-14 21:40:04	2020-05-14	Loyce Langosh-Skiles	loyce.langosh.skiles@geemail.com	San Francisco	California	6011092854194116033	57a70debcda977f33887e7f79ae71ce7	Diners Club / Carte Blanche	37.7764044413872924	-122.408121534482987
24891	2020-05-14 21:49:29	2020-05-14	Mrs. Melodee Welch	mrs.melodee.welch@geemail.com	Mesquite	Texas	53920992778855093	be1ec02338c05db91b5cf5ed6b90394d	JCB 15 digit	32.6788723849967155	-96.6548780941136272
24892	2020-05-14 21:58:34	2020-05-14	Mirtie Veum DDS	mirtie.veum.dds@woohoo.com	Carrollton	Texas	3769685823247305	b35964b21acf3aac0fbd50d8e90845a9	JCB 16 digit	32.9062939334116891	-96.8534578976549199
24893	2020-05-14 22:02:10	2020-05-14	Nina Adams	nina.adams@warmmail.com	Seattle	Washington	3088251921083025356	fa303cd11402d2231649a5d37dd5e33a	VISA 13 digit	47.6178268171772388	-122.381693066928165
24894	2020-05-14 22:06:24	2020-05-14	Germaine Bogan-Bechtelar	germaine.bogan.bechtelar@geemail.com	Surprise	Arizona	3528769226530990706	9548622a6ed786754d2d307973a5a73b	Mastercard	33.6835332747310403	-112.398826470481964
24895	2020-05-14 22:15:53	2020-05-14	Kellee Ullrich-Dickinson	kellee.ullrich.dickinson@geemail.com	Houston	Texas	3450890205750584	45b53dc7484a0ab28f8937a5ff5360bf	Diners Club / Carte Blanche	29.707983522031828	-95.3084281840842209
24896	2020-05-14 22:26:57	2020-05-14	Miss Leone Morissette	miss.leone.morissette@geemail.com	Henderson	Nevada	3792634455642186	ab9652c264c5317c405543a60264896c	Voyager	35.928427398198103	-115.067725843486201
24897	2020-05-14 22:33:23	2020-05-14	Keith Goldner	keith.goldner@geemail.com	Jacksonville	Florida	4658252340869	5b041582fff4ba451d8a3b88abbd2545	JCB 16 digit	30.4169381023902439	-81.5658016310151766
24898	2020-05-14 22:37:22	2020-05-14	Dario Dare	dario.dare@geemail.com	Oakland	California	3440964707495940	fb0e632c01b7db5db4b7b5c450f8a3f0	VISA 16 digit	37.825548037496965	-122.281394546296738
24899	2020-05-14 22:39:32	2020-05-14	Tawana Cole	tawana.cole@geemail.com	Houston	Texas	3000171425129573	b2779c96c09ce2d82aebdb6dc5175b43	VISA 16 digit	29.7683694545257822	-95.4698771301671911
24900	2020-05-14 22:42:01	2020-05-14	Latoya Runolfsson	latoya.runolfsson@geemail.com	Phoenix	Arizona	3528461538290395103	256375e7ca9730097c44945711653c12	VISA 16 digit	33.5579324079144783	-112.060269107103721
24901	2020-05-14 22:54:02	2020-05-14	Caswell Block	caswell.block@woohoo.com	San Francisco	California	6011776786036721831	ab1a4cb700af6eea203536b67d082b7b	JCB 15 digit	37.7554716615095813	-122.430325922790459
24902	2020-05-14 22:57:35	2020-05-14	Bryana Berge	bryana.berge@geemail.com	Oklahoma City	Oklahoma	180010446282039950	6cc5061748773b8a84ef559b8c5f21c6	Discover	35.5273899355813896	-97.4568878551375093
24903	2020-05-14 22:58:03	2020-05-14	Madison Zieme	madison.zieme@geemail.com	Indianapolis	Indiana	676363058884048	13558f8c1220d8bf98ac99f2fcedd381	Maestro	39.6962571724791076	-86.2375154412086999
24904	2020-05-14 23:12:35	2020-05-14	Ewin Fadel	ewin.fadel@geemail.com	Chula Vista	California	3337194014799962482	b037a84c891fc440a3955d71f5a84b40	VISA 16 digit	32.6762472635831642	-117.005857838992767
24905	2020-05-14 23:32:37	2020-05-14	Augustus McClure-Homenick	augustus.mcclure.homenick@woohoo.com	San Diego	California	3043925994000391	6a183e422c26b28e1599fc51befe2a5f	American Express	32.7736234815392677	-117.061675246329983
24906	2020-05-14 23:36:34	2020-05-14	Miss Dallas Rice	miss.dallas.rice@geemail.com	Berkeley	California	4557450152250	9007004faf7fd031dadb9a5cde4f30fa	JCB 16 digit	37.8471804397704901	-122.262361970518782
24907	2020-05-15 00:01:07	2020-05-15	Sheri Metz	sheri.metz@woohoo.com	West Palm Beach	Florida	3455985454063104	0de04fa6af8c1be51cc69e9b4af44ecb	Voyager	26.8322440544456242	-80.1501294967088853
24908	2020-05-15 00:04:34	2020-05-15	Krysten Oberbrunner DDS	krysten.oberbrunner.dds@warmmail.com	San Francisco	California	6011800662956981566	ecfd8e9a45501ebe89cde6b81c571b43	Diners Club / Carte Blanche	37.7583120157204917	-122.44641272105261
24909	2020-05-15 00:14:24	2020-05-15	Tanner Morar	tanner.morar@geemail.com	Gilbert	Arizona	52768709228256218	9de5466361c7c8a3c915f2c28013d2c6	JCB 16 digit	33.3543763037651786	-111.752951526888083
24910	2020-05-15 00:17:21	2020-05-15	Media Vandervort	media.vandervort@warmmail.com	Phoenix	Arizona	3158470326645007675	e8f9c49c2a77b08e3f5ed8800d62c982	Mastercard	33.512956375482311	-112.005773051076019
24911	2020-05-15 00:50:27	2020-05-15	Harrison Witting-Nikolaus	harrison.witting.nikolaus@geemail.com	New York	New York	4593753427913147	03192dd9da4f9fa8e4cc92ec4921228f	Voyager	40.7481628417726611	-73.8440190777543961
24912	2020-05-15 00:56:17	2020-05-15	Carma Mayer-O'Hara	carma.mayer.o'hara@geemail.com	Houston	Texas	639088168656358	c46dd94ad6b6dc2f92da7820958bf708	Maestro	29.7340403445143266	-95.4378608592335098
24913	2020-05-15 00:56:21	2020-05-15	Zachery Gulgowski	zachery.gulgowski@geemail.com	Berkeley	California	180096903852904325	a51f669b48793691545fe65e5783074f	VISA 13 digit	37.8449328647481522	-122.255937686836816
24914	2020-05-15 01:02:47	2020-05-15	Nya Conn	nya.conn@warmmail.com	New York	New York	55562644979315277	ac35ca93de7b6b0f0610291deb74c705	JCB 15 digit	40.5930920833945237	-73.9618913525611106
24915	2020-05-15 01:03:47	2020-05-15	Pate Fay	pate.fay@geemail.com	Eugene	Oregon	6011305328201909584	34ec9428bab44c9504c718b0d1a7947f	JCB 16 digit	44.0822820056423552	-123.142578306234256
24916	2020-05-15 01:20:29	2020-05-15	Evans Kohler	evans.kohler@woohoo.com	Tempe	Arizona	3013615820494104	20bb0266ab55939b71f8965826669bd5	VISA 16 digit	33.3025958284657406	-111.861526145882152
24917	2020-05-15 01:25:26	2020-05-15	Shirlee Casper PhD	shirlee.casper.phd@geemail.com	Chicago	Illinois	630495437846868	176780b1958cbefdb53ab111e240afdc	Mastercard	41.8112956656444865	-87.7141824515566242
24918	2020-05-15 01:28:09	2020-05-15	Dr. Alan Pouros	dr.alan.pouros@geemail.com	Columbus	Ohio	4601438513590195	23fbeaf269853f54837644b2ed733416	JCB 15 digit	39.9542269662532945	-83.0716009418714805
24919	2020-05-15 01:28:18	2020-05-15	Hamza Kozey	hamza.kozey@geemail.com	Lakewood	Colorado	4773162535431	c828528fe6792ba3fef8a396ad263481	Discover	39.6636464636247652	-105.103240311473982
24920	2020-05-15 01:29:17	2020-05-15	Ms. Maribeth Bode	ms.maribeth.bode@woohoo.com	Inglewood	California	4058381223874871	199e9423ef2f1eb004df0181390bfa82	Discover	33.8561598016194978	-118.376590962897239
24921	2020-05-15 01:29:35	2020-05-15	Loran Auer-Bogisich	loran.auer.bogisich@geemail.com	Indianapolis	Indiana	4571089067762221	4606343fdb37017c9045561ab206f1d6	VISA 16 digit	39.709299603058767	-86.0784443135574406
24922	2020-05-15 01:33:10	2020-05-15	Allean Bartoletti	allean.bartoletti@geemail.com	McAllen	Texas	54519474724435806	5b63c1aa14d1a29a95f35b0b737692e3	Diners Club / Carte Blanche	26.229438479275256	-98.3297283101208421
24923	2020-05-15 01:35:34	2020-05-15	Wess Corwin	wess.corwin@geemail.com	Hartford	Connecticut	869944040766805984	f3774711ec40577bf6b0751b61bf3c7d	Mastercard	41.6908284476973137	-72.6870104139562727
24924	2020-05-15 01:41:00	2020-05-15	Gerhardt Swaniawski	gerhardt.swaniawski@geemail.com	Los Angeles	California	4391503033724733	ff2f65f6dbfb4c1dcb548544a8a10872	American Express	33.9251374755851884	-118.455142403812332
24925	2020-05-15 01:56:52	2020-05-15	Mrs. Sarai Hauck DDS	mrs.sarai.hauck.dds@geemail.com	San Francisco	California	52805800344280276	53a67532a4522051cb6a9fadee51dc48	VISA 16 digit	37.8077655846123548	-122.446942249823749
24926	2020-05-15 02:04:45	2020-05-15	Iola Rolfson	iola.rolfson@geemail.com	Tulsa	Oklahoma	4801301536748760	54c8ff5db246bb2bfb8c07cf8b747fab	VISA 13 digit	36.048570552924275	-95.9729542665604498
24927	2020-05-15 02:09:26	2020-05-15	Caldonia Mertz	caldonia.mertz@woohoo.com	New York	New York	6011863729985530799	b3fd2548fae258f645995448157e5e98	Mastercard	40.7091050910055614	-73.981479521783811
24928	2020-05-15 02:31:14	2020-05-15	Evelyn Langworth	evelyn.langworth@geemail.com	Cape Coral	Florida	3337360855841979736	b04e1c44db9ab467ecaed319b203c448	Voyager	26.600438630764188	-82.0622129221983272
24929	2020-05-15 02:33:12	2020-05-15	Leif Collier	leif.collier@geemail.com	Houston	Texas	4602793582969	c6ac803d05d0ba1f01b8d42e492872b2	Diners Club / Carte Blanche	29.7087978846471756	-95.4536443031873603
24930	2020-05-15 02:42:23	2020-05-15	Palmer Schroeder	palmer.schroeder@geemail.com	Clovis	California	4826370639908820	459f275d8bebc26c005faf6a8156b642	American Express	36.7417303888935649	-119.605087293458723
24931	2020-05-15 02:48:15	2020-05-15	Jacey Murphy	jacey.murphy@warmmail.com	San Francisco	California	3337839317423204432	4f92b19b46fbd6bf194ea0250971a3ba	VISA 13 digit	37.7757584950755287	-122.441330543422367
24932	2020-05-15 02:53:57	2020-05-15	Fernando Bode-Berge	fernando.bode.berge@geemail.com	Hayward	California	3112454162618316615	fa78e6295489d064605b90afc9458f49	Voyager	37.5518820224784307	-122.039731367051232
24933	2020-05-15 03:06:46	2020-05-15	Berta Davis-Stokes	berta.davis.stokes@geemail.com	Corona	California	3158335191630757055	3d04b5c066776306276221e97487bfe1	JCB 16 digit	33.8552970001827944	-117.509403785059234
24934	2020-05-15 03:12:25	2020-05-15	Judd Heathcote	judd.heathcote@woohoo.com	New York	New York	180079535780500071	fd6341b79a82908d9e6834dc331d18e8	VISA 16 digit	40.5789567481018594	-74.0141214119631741
24935	2020-05-15 03:13:05	2020-05-15	Camila Murazik	camila.murazik@geemail.com	San Francisco	California	3112904830792637354	96edc7a31669236bb38223d3ff3eb8eb	VISA 16 digit	37.7905056274996269	-122.424916433765333
24936	2020-05-15 03:38:28	2020-05-15	Dr. Jorden Schneider	dr.jorden.schneider@warmmail.com	Denver	Colorado	4184744824428	cd08b46b29c40c5305d4f33de120a7b9	Discover	39.6691876847349079	-104.812480196940157
24937	2020-05-15 03:49:19	2020-05-15	Miss Cyntha O'Conner DVM	miss.cyntha.o'conner.dvm@geemail.com	San Francisco	California	4994964381920029	8f6c7bdcb17d0b8ca9ad17aa53c345cf	Mastercard	37.7739498486212995	-122.420573712899383
24938	2020-05-15 04:02:23	2020-05-15	Sidney Bahringer	sidney.bahringer@woohoo.com	Honolulu	Hawaii	52211486462210564	dbfc59a496d0bf30283611a9e530e309	JCB 15 digit	21.2484800932213673	-157.917752687141672
24939	2020-05-15 04:08:50	2020-05-15	Manilla Heller	manilla.heller@woohoo.com	New York	New York	3448229663937026	165445fd55debb65342ad313557e5e9a	American Express	40.6798303755689403	-73.901043850359315
24940	2020-05-15 04:09:45	2020-05-15	Isaac Kovacek	isaac.kovacek@geemail.com	Winston–Salem	North Carolina	210027838069773549	fdf2f417287b1354b4bf0be0fa5317b3	JCB 16 digit	36.0167899226535084	-80.1949048241730793
24941	2020-05-15 04:11:47	2020-05-15	Wilson Russel	wilson.russel@warmmail.com	Philadelphia	Pennsylvania	561206062935348	82516df77796ac9aff681fe5e3aa0f37	JCB 15 digit	39.9217716226778947	-75.0944763258930408
24942	2020-05-15 04:17:32	2020-05-15	Mr. Jameel Kilback	mr.jameel.kilback@geemail.com	Baton Rouge	Louisiana	3771213469172285	8d3ceed19fbf50df46a6e77bbbf59502	VISA 16 digit	30.5238842038184401	-91.0714028730165239
24943	2020-05-15 04:42:56	2020-05-15	Starla Daniel-McLaughlin	starla.daniel.mclaughlin@geemail.com	Berkeley	California	4155872128796542	15a69498fb58a6b9b7222ea837ea56f8	American Express	37.8644191124780534	-122.268271035588057
24944	2020-05-15 04:47:41	2020-05-15	Dr. Taylor Hane	dr.taylor.hane@geemail.com	Atlanta	Georgia	52788917629886089	47b2329999efe4dfbd37cbb0432a1047	Voyager	33.8606944277692605	-84.4341911915268781
24945	2020-05-15 05:07:24	2020-05-15	Carlee Zieme	carlee.zieme@warmmail.com	Costa Mesa	California	53303567426270023	7af7bee84a750f274a7c0d66fba6920a	Voyager	33.753986525397373	-117.979786349353574
24946	2020-05-15 05:09:02	2020-05-15	Mr. Trevon Hettinger	mr.trevon.hettinger@warmmail.com	Richmond	California	3088695984941925492	daa4e4c45518b1a0a2d63d68c1926d23	VISA 13 digit	38.0107377951454382	-122.368480240119993
24947	2020-05-15 05:09:59	2020-05-15	Zain Muller-Boyle	zain.muller.boyle@warmmail.com	Seattle	Washington	4361650911562937	a54ccbef519ebb23ebaef75da8ae5dd1	Voyager	47.6519638018142402	-122.258181496329229
24948	2020-05-15 05:16:30	2020-05-15	Ms. Pam Larkin DDS	ms.pam.larkin.dds@warmmail.com	Evansville	Indiana	3112317226115876699	229faa042cc586b37237a11b75dc9c28	VISA 16 digit	37.8880093929495629	-87.4740879173789239
24949	2020-05-15 05:19:50	2020-05-15	Florie Satterfield	florie.satterfield@geemail.com	San Antonio	Texas	3022183684271762	d6ce7f62bc8b43353dc9214e2fc7c340	Voyager	29.546932375577839	-98.5763125018518309
24950	2020-05-15 05:27:55	2020-05-15	Daisie Pouros	daisie.pouros@geemail.com	San Francisco	California	3468704324074356	43765e41a1725de586804363240cd9a1	VISA 16 digit	37.7774626354763683	-122.413454857577221
24951	2020-05-15 05:42:05	2020-05-15	Willard Kemmer	willard.kemmer@geemail.com	Tampa	Florida	561236763619800	e0f79804754c2b3fd4d509f47237920f	JCB 16 digit	27.8755126106668243	-82.5627537694040683
24952	2020-05-15 05:46:13	2020-05-15	Stevie Hilpert-Hilll	stevie.hilpert.hilll@warmmail.com	Chicago	Illinois	4080029209352	c517564f8551e98036a3bdacebcd7ff8	VISA 16 digit	41.7566677368082111	-87.7669757841184719
24953	2020-05-15 05:52:33	2020-05-15	Viola Steuber	viola.steuber@geemail.com	Berkeley	California	210023441493072432	c5d411e63218f4fbdedff6ddb5063a49	JCB 15 digit	37.8911107203085251	-122.284286707175298
24954	2020-05-15 06:13:36	2020-05-15	Gilford Prohaska-Gaylord	gilford.prohaska.gaylord@geemail.com	Louisville	Kentucky	4626262113613020	bfc3bdc960c4d21a08ec4377218bf140	Discover	38.2108545017797496	-85.7204157151818293
24955	2020-05-15 06:42:23	2020-05-15	Cleda Buckridge	cleda.buckridge@woohoo.com	San Francisco	California	3045437833040834	5a61320fc7f13d4358b0856be7ceb44b	Voyager	37.7491983032016876	-122.428746034939692
24956	2020-05-15 07:02:55	2020-05-15	Mrs. Lilie Erdman DDS	mrs.lilie.erdman.dds@warmmail.com	Miami	Florida	3528075266679251816	8b76ea36c107a8f97a84086f24d2473f	JCB 16 digit	25.8690256243709484	-80.2342871745455994
24957	2020-05-15 07:02:56	2020-05-15	Shedrick Lind	shedrick.lind@geemail.com	Lakeland	Florida	3055720254381351	fb01def7e3ea78e20fd63055ac9c50f4	Maestro	27.9953702926468075	-81.8654428258888345
24958	2020-05-15 07:17:14	2020-05-15	Miss Kalie Thiel DVM	miss.kalie.thiel.dvm@woohoo.com	Kansas City	Kansas	3528746993437769826	4e57e278a7186d5dbc30c5d7131f85cd	American Express	39.1576576075889164	-94.7236692657165236
24959	2020-05-15 07:24:10	2020-05-15	Joy Mills MD	joy.mills.md@woohoo.com	Columbus	Ohio	4330113362421	060a0cb55ea0dedde8642f49a6b1ac51	Maestro	40.0541069196581816	-82.9042713861681619
24960	2020-05-15 07:39:00	2020-05-15	Oren Larson	oren.larson@geemail.com	Cleveland	Ohio	4505232946245338	457bb9b28eddca7143b2f6039e81c69d	Diners Club / Carte Blanche	41.5457620248515127	-81.625957361446325
24961	2020-05-15 07:49:17	2020-05-15	Jule Hettinger	jule.hettinger@geemail.com	Miramar	Florida	52141297033118474	5c00ca7d9a8ce9a600e0b81fefa13569	VISA 16 digit	25.9634847468212264	-80.3922456246793331
24962	2020-05-15 07:57:55	2020-05-15	Sienna Bartoletti	sienna.bartoletti@geemail.com	Chesapeake	Virginia	4763285600955276	0771bfae7bf7d253362b4916f52002e9	JCB 15 digit	36.7292135300353166	-76.365523304215813
24963	2020-05-15 08:19:35	2020-05-15	Ms. Larue Harber	ms.larue.harber@geemail.com	Chicago	Illinois	4527430377385375	f36284174d4d2e53401310dde27ce14c	Mastercard	41.8889660326134461	-87.7814360750868872
24964	2020-05-15 08:24:41	2020-05-15	Dr. Myrl Hills	dr.myrl.hills@geemail.com	Berkeley	California	3112407321465716040	b1fd041231934c2e67380f206ed2450d	Mastercard	37.8491016429137517	-122.264844253678817
24965	2020-05-15 08:26:54	2020-05-15	Ms. Antonette Tromp	ms.antonette.tromp@geemail.com	Los Angeles	California	4917784675460928	02f461b9f077a06227773d8c0804c1cc	Diners Club / Carte Blanche	33.9635749974619543	-118.445147999468446
24966	2020-05-15 08:27:51	2020-05-15	Dr. Westin Denesik	dr.westin.denesik@warmmail.com	Louisville	Kentucky	3112749093516894111	ec4562f308fe9abaee1461ca00d3bdf4	JCB 15 digit	38.0698722522143242	-85.7088172274712576
24967	2020-05-15 08:27:57	2020-05-15	Dr. Purl Brakus	dr.purl.brakus@geemail.com	Lubbock	Texas	3462539350240943	347e56e05ab3f1d16acbc5c83ec65d6d	JCB 16 digit	33.4981498142745409	-101.850183218429621
24968	2020-05-15 08:39:57	2020-05-15	Kelsie Moore MD	kelsie.moore.md@geemail.com	San Francisco	California	4129594841352501	5aa592ef698bff5276243cfecdc3fdf4	Voyager	37.8017303246050389	-122.44329701272386
24969	2020-05-15 08:49:14	2020-05-15	Dayami Ankunding	dayami.ankunding@geemail.com	Wichita Falls	Texas	3528025906944057099	fb6e4f34989be7f76012e0e0f31e35b4	Discover	33.9530230866007514	-98.5208849327094782
24970	2020-05-15 09:01:25	2020-05-15	Thomasina Jacobi	thomasina.jacobi@woohoo.com	New York	New York	210081923621739999	0197b4f01c403f18d800859e1a46d161	VISA 13 digit	40.5719927239455274	-73.8623604182515265
24971	2020-05-15 09:03:36	2020-05-15	Indiana Christiansen	indiana.christiansen@warmmail.com	New York	New York	51869754115309892	78089268c2a740aa65df9a5472c491ae	VISA 16 digit	40.7304903561938545	-73.8423013407167019
24972	2020-05-15 09:11:15	2020-05-15	Dr. Garey Upton	dr.garey.upton@geemail.com	El Cajon	California	180029136070626329	fc0a2a5a8c8ca161c0e754f1bff3f371	JCB 16 digit	32.808579724469034	-117.046314034396417
24973	2020-05-15 09:14:05	2020-05-15	Deon Will	deon.will@warmmail.com	San Francisco	California	060419307315143	819961d99e80ee07254b6addd28b140f	VISA 16 digit	37.7485984750727823	-122.39446614635068
24974	2020-05-15 09:17:59	2020-05-15	Joetta O'Keefe-Roberts	joetta.o'keefe.roberts@geemail.com	Colorado Springs	Colorado	6011309162310326844	008238f0e8b17a61f861dfa47141f4b3	Discover	38.9287835301414162	-104.82257043394894
24975	2020-05-15 09:23:55	2020-05-15	Jess Daugherty	jess.daugherty@geemail.com	Los Angeles	California	4032317373736651	39471f575a88d800ce1e9357aed8b32d	American Express	34.099779089340565	-118.419234091368679
24976	2020-05-15 09:32:09	2020-05-15	Patrice Hettinger DVM	patrice.hettinger.dvm@geemail.com	Oakland	California	3096726042734673937	da496885f941401b9fe0ede139687c15	Voyager	37.7747270991980884	-122.259577971483495
24977	2020-05-15 09:47:06	2020-05-15	Shyheim Luettgen III	shyheim.luettgen.iii@woohoo.com	Houston	Texas	4065659682780585	183289d867bd5af0f4c69e856e511ab7	JCB 15 digit	29.8405707695599638	-95.3830580813825151
24978	2020-05-15 09:47:06	2020-05-15	Torrey Becker	torrey.becker@geemail.com	Arlington	Texas	3528458157939053695	be7a3a5426f0b89dcac1a053a29a9ed8	VISA 16 digit	32.6973284291353039	-97.0413194358840627
24979	2020-05-15 09:53:17	2020-05-15	Ophelia Ortiz	ophelia.ortiz@woohoo.com	Detroit	Michigan	3007942399843040	13ba78754fe119fcdc43b13be8f15d0b	VISA 13 digit	42.4634494069423525	-83.0183660719662839
24980	2020-05-15 10:02:35	2020-05-15	Venie Reynolds	venie.reynolds@geemail.com	Berkeley	California	3009721766719126	ce94dba977e30ea35fcbfffe76dee947	JCB 16 digit	37.8889266509368596	-122.295090521280784
24981	2020-05-15 10:06:48	2020-05-15	Mikhail Kreiger	mikhail.kreiger@woohoo.com	New York	New York	51047002860274654	e2fe90b1f4171f4b7dd239282aa6c7e5	Diners Club / Carte Blanche	40.5745696644056579	-73.9245696637209448
24982	2020-05-15 10:09:16	2020-05-15	Jax Larson	jax.larson@geemail.com	Corpus Christi	Texas	6011531449572215710	5138b3131e291e03d7c54822dc4dd23c	Mastercard	27.7211163518421344	-97.1301588699050313
24983	2020-05-15 10:11:39	2020-05-15	Wellington Stroman DVM	wellington.stroman.dvm@geemail.com	Wichita	Kansas	3528290579194909299	63f9df11d69420248f21935b892a77ef	VISA 16 digit	37.7826582586269808	-97.3048952845126394
24984	2020-05-15 10:13:14	2020-05-15	Cesar Aufderhar-Larkin	cesar.aufderhar.larkin@warmmail.com	Waco	Texas	3442483529482281	a79454fa90dc85739685d4a8d31b03ad	JCB 16 digit	31.6307303484272211	-97.148276034336547
24985	2020-05-15 10:19:30	2020-05-15	Mrs. Wilda Carter	mrs.wilda.carter@woohoo.com	Baltimore	Maryland	3057348426811085	6778643b9690f6fbd29d8f2afd0ac230	Maestro	39.3047255056444556	-76.6019899853523896
24986	2020-05-15 10:33:34	2020-05-15	Stoney Harris V	stoney.harris.v@geemail.com	Tampa	Florida	51543041401663099	4243b920081be404d1d850483c91c200	Discover	27.9221368151832365	-82.4190593753222345
24987	2020-05-15 10:44:28	2020-05-15	Danniel Jones PhD	danniel.jones.phd@warmmail.com	Louisville	Kentucky	3112813557699122384	75a57babd0bad7f1e512a35de3adc5f3	JCB 16 digit	38.0956544578444181	-85.7443805724453227
24988	2020-05-15 10:50:01	2020-05-15	Savana Schulist	savana.schulist@geemail.com	Houston	Texas	3096987863132829472	f13f313cbd936f98a376c3f831f17d07	JCB 15 digit	29.7223926450204097	-95.4084408942159286
24989	2020-05-15 11:00:20	2020-05-15	Lorrie O'Conner	lorrie.o'conner@geemail.com	San Francisco	California	060430518517856	cfc641b5fab03630c3c36b34f581db59	JCB 16 digit	37.7735645737945092	-122.447363179139913
24990	2020-05-15 11:15:03	2020-05-15	Dr. Thalia Gulgowski DVM	dr.thalia.gulgowski.dvm@geemail.com	Chicago	Illinois	3112285038468831868	ba9e71a50052f65e9e8114a48f1f9fb3	VISA 16 digit	41.8043053846176704	-87.6355739654071613
24991	2020-05-15 11:25:16	2020-05-15	Julious Harvey	julious.harvey@geemail.com	Oakland	California	6011348361544806984	b661771bf050b7336a3934aacabd4422	Discover	37.8311826945946805	-122.27620759479997
24992	2020-05-15 11:25:40	2020-05-15	Dr. Marjorie Kunde	dr.marjorie.kunde@geemail.com	Bakersfield	California	3407633995075307	f008ae047cf0d3246b38244dc8b85e9b	Mastercard	35.3883807632315879	-118.99107313345111
24993	2020-05-15 11:48:36	2020-05-15	Darwyn Blanda	darwyn.blanda@geemail.com	Chicago	Illinois	676280736071061	cefb9057fd1320fcb16da7444ace1507	Discover	41.9289018934894386	-87.7622812205024019
24994	2020-05-15 11:51:37	2020-05-15	Shawnda Carter	shawnda.carter@geemail.com	San Francisco	California	4784000243534	2a12fc73fa9fb2a2b18c731803d68ed1	Voyager	37.7616165003030559	-122.433667363194289
24995	2020-05-15 12:10:08	2020-05-15	Corry Fadel	corry.fadel@geemail.com	Tulsa	Oklahoma	4993429031715	1acf3b2ace685a13653841f4f3fbc919	Mastercard	36.0564875024739635	-95.8528021768622125
24996	2020-05-15 12:11:31	2020-05-15	Achsah Gottlieb	achsah.gottlieb@geemail.com	San Francisco	California	54107130317323621	0f761678f600a15dcc0e959524a52014	Voyager	37.7376036015879208	-122.447588770138722
24997	2020-05-15 12:24:37	2020-05-15	Lutie Brown	lutie.brown@woohoo.com	Columbus	Ohio	3448069063496193	3050f4c204c0eb13f8feef72735f88d2	JCB 16 digit	39.8888312774289417	-82.9237866652898532
24998	2020-05-15 12:32:06	2020-05-15	Amin Pouros	amin.pouros@geemail.com	Honolulu	Hawaii	4813234997566718	840abc5107a2f5d4d025eb43fcafed1e	JCB 16 digit	21.3654859065759943	-157.899508042840665
24999	2020-05-15 12:33:32	2020-05-15	Tori Gaylord DDS	tori.gaylord.dds@woohoo.com	New York	New York	4071377788595789	683b757f497af003f1947fe8ea7e105d	Discover	40.6139387611523262	-73.9306081844389382
25000	2020-05-15 12:33:35	2020-05-15	Stacy Bernhard	stacy.bernhard@geemail.com	Coral Springs	Florida	3337540826052536484	dc3543cee93fc2b81c6e200f7761beae	JCB 15 digit	26.2222785581432305	-80.3109095999628266
25001	2020-05-15 12:37:29	2020-05-15	Mr. Emanuel Reinger	mr.emanuel.reinger@geemail.com	Boise	Idaho	3034649170613848	2c110bce197cfcd509fe547b8515bdd5	Voyager	43.5347626350957881	-116.155525322324408
25002	2020-05-15 12:38:33	2020-05-15	Basil Dach	basil.dach@geemail.com	Temecula	California	52161967251628173	fb575f0352c8a4650554824a52136984	Diners Club / Carte Blanche	33.5650182000961124	-117.189157667170093
25003	2020-05-15 12:49:26	2020-05-15	Evelyne Becker	evelyne.becker@geemail.com	Naperville	Illinois	4769580832548202	7892d6dd5bdbb6b96f79e5110f9f8cb1	JCB 16 digit	41.8438321665309374	-88.1811464819014077
25004	2020-05-15 13:29:18	2020-05-15	Arlyn Cole	arlyn.cole@geemail.com	San Francisco	California	3058074095098205	05229b4d44cc94be3d40570e91321d85	Discover	37.7667816577437705	-122.387438701905282
25005	2020-05-15 13:39:49	2020-05-15	Kermit Carroll	kermit.carroll@geemail.com	Victorville	California	4795463593181	8745492a013a202fff7cd580dcc9049e	Diners Club / Carte Blanche	34.4354863050624758	-117.266951153908295
25006	2020-05-15 13:46:21	2020-05-15	Lassie Senger	lassie.senger@geemail.com	Berkeley	California	869908130061514797	4313ee91ab8a088217213f344abc4209	JCB 16 digit	37.8526556995936758	-122.273923927295684
25007	2020-05-15 13:58:01	2020-05-15	Rigoberto Macejkovic	rigoberto.macejkovic@geemail.com	Joliet	Illinois	51853391821279495	34a16b71eb11040bffaa54d972c200c5	Diners Club / Carte Blanche	41.4212575018264317	-88.1326784602470639
25008	2020-05-15 13:59:55	2020-05-15	Jeffry Will	jeffry.will@geemail.com	League City	Texas	4167165967307901	cc259ebabd696a85d92b7af856fcebf2	JCB 15 digit	29.5327699144765745	-95.1654317185267757
25009	2020-05-15 14:01:24	2020-05-15	Asher Hyatt	asher.hyatt@geemail.com	Memphis	Tennessee	4909543828112103	301e09197c36849adbd440ed119c6530	JCB 16 digit	35.051908547763901	-90.0527681615926383
25010	2020-05-15 14:01:35	2020-05-15	Mr. Sebastian Block III	mr.sebastian.block.iii@geemail.com	Visalia	California	4380430244917943	a761e8a10309405947c0cd1bc1be9b7f	JCB 16 digit	36.2513207314025649	-119.284177876649053
25011	2020-05-15 14:04:24	2020-05-15	Vivienne Ward	vivienne.ward@geemail.com	Arvada	Colorado	3158636289935297128	9a2d4aededdb1bedee925a6131f725ad	JCB 16 digit	39.8210815663624587	-105.070679255339499
25012	2020-05-15 14:07:09	2020-05-15	Cammie Aufderhar	cammie.aufderhar@geemail.com	Rochester	New York	6011388955284565907	4e9337d1c04805f9b1b47b71f75bc737	JCB 15 digit	43.2073307854101074	-77.6093103591591102
25013	2020-05-15 14:09:41	2020-05-15	Trace Smitham	trace.smitham@geemail.com	Dallas	Texas	3337655405231374546	cabaf28620442d2e732acf912951a445	American Express	32.7425057159077397	-96.803042418273165
25014	2020-05-15 14:14:00	2020-05-15	Beverly Schultz	beverly.schultz@woohoo.com	Philadelphia	Pennsylvania	53738336786344926	9348a59a03565201b05511c788b1c02a	JCB 16 digit	39.9935786142438658	-75.1129266461722551
25015	2020-05-15 14:29:47	2020-05-15	Chace Lakin IV	chace.lakin.iv@woohoo.com	San Francisco	California	51747463593281056	daaee825a433af1d48896dacf64921b6	Voyager	37.8015371506525852	-122.43066382343514
25016	2020-05-15 14:30:47	2020-05-15	Burt DuBuque	burt.dubuque@warmmail.com	Seattle	Washington	676186948764542	b96ad29d75b55ad8f2c08bfb2693ce67	VISA 16 digit	47.5318547037821233	-122.265814004737507
25017	2020-05-15 14:38:17	2020-05-15	Mr. Syed Turner IV	mr.syed.turner.iv@woohoo.com	Ann Arbor	Michigan	3096788101883870820	4d2f43d5b434e4b97aa48085c89d4ed8	Maestro	42.1974110480457512	-83.6906312104888315
25018	2020-05-15 14:43:10	2020-05-15	Ms. Destiny Cassin	ms.destiny.cassin@warmmail.com	Elizabeth	New Jersey	3528234254564390665	9ef35c0fa50fcc233f2f4842358ecb17	Maestro	40.6296493970915691	-74.2537080672513667
25019	2020-05-15 14:47:36	2020-05-15	Shavonne Wolf	shavonne.wolf@geemail.com	Berkeley	California	55618423772853501	d8b75d6af3e38f589a157ae622a26bc4	Mastercard	37.8857797393254572	-122.309065201484501
25020	2020-05-15 15:01:10	2020-05-15	Danial Kuvalis-Hartmann	danial.kuvalis.hartmann@geemail.com	Cincinnati	Ohio	6011799246341779076	fc40076882d6b0b68b6477976970ebfe	Voyager	39.2105410079702708	-84.5223249349549377
25021	2020-05-15 15:08:53	2020-05-15	Burke Hodkiewicz	burke.hodkiewicz@warmmail.com	San Francisco	California	180048013268422471	dc37a4ca3e3341cb023e5b5b02b1d479	JCB 16 digit	37.7715404250500697	-122.429018688289815
25022	2020-05-15 15:09:34	2020-05-15	Norton Wolf	norton.wolf@geemail.com	Arlington	Texas	869920132626860958	876f43e3ec01fd87ba4f596d0c64f38d	VISA 16 digit	32.7775342352006547	-97.058591907287763
25023	2020-05-15 15:23:47	2020-05-15	Miss Fabiola Pagac PhD	miss.fabiola.pagac.phd@geemail.com	Lubbock	Texas	6011627951818463322	744a83260e703fc75af64156a3a5c8e4	JCB 15 digit	33.6148714624386287	-101.795965233343466
25024	2020-05-15 15:27:58	2020-05-15	Libby Kreiger	libby.kreiger@geemail.com	Oakland	California	3447445121050209	f2670efa6a8c59419a84c8f4f90aef7d	Mastercard	37.7938448299218379	-122.283298059736424
25025	2020-05-15 15:31:57	2020-05-15	Aria Morissette	aria.morissette@woohoo.com	Oxnard	California	3088322672579243558	189c08d33abb8cab86749a66441b9de6	Discover	34.1592994183257233	-119.245994557524469
25026	2020-05-15 15:32:14	2020-05-15	Marcelo Auer	marcelo.auer@warmmail.com	Atlanta	Georgia	3053953515599543	193af4e9107343cd6abad6d835fd3d52	JCB 15 digit	33.6710091419327995	-84.3697389099791764
25027	2020-05-15 15:45:03	2020-05-15	Rosanne Baumbach	rosanne.baumbach@geemail.com	Jacksonville	Florida	060459090431079	8c6bdbd13e044af2462289d04bd71a8e	JCB 15 digit	30.3008420123770819	-81.7006409228391988
25028	2020-05-15 15:49:11	2020-05-15	Bambi Witting	bambi.witting@woohoo.com	Oakland	California	4152388036708	0ebf897c605866a6061ee043cff4b56b	JCB 16 digit	37.8171890772753727	-122.229753768102128
25029	2020-05-15 15:52:39	2020-05-15	Evertt Hyatt	evertt.hyatt@geemail.com	Houston	Texas	3112395632911521899	1197a9953bae3a1303b2337f4380cb5a	JCB 16 digit	29.7669591303993002	-95.4890256932020236
25030	2020-05-15 15:59:57	2020-05-15	Ervin Hartmann	ervin.hartmann@geemail.com	New York	New York	210046936326660181	98e4cc17da8c65d7c89f66b623c14e8e	VISA 16 digit	40.7377911134380852	-73.9564856367547065
25031	2020-05-15 16:03:27	2020-05-15	Thomasina Weber	thomasina.weber@warmmail.com	San Diego	California	589319858950942	3cddcdd256ea2bda9b5d3903faec6d43	VISA 16 digit	32.8318096273180089	-117.206488926094025
25032	2020-05-15 16:03:56	2020-05-15	Mr. Chadd Becker Jr.	mr.chadd.becker.jr.@geemail.com	Cary	North Carolina	3439874820245606	9cd680c097863adcf4ba0abbb362926e	JCB 16 digit	35.7596364751566256	-78.716290356646482
25033	2020-05-15 16:12:50	2020-05-15	Kiera Kreiger	kiera.kreiger@geemail.com	Chicago	Illinois	3045432717902944	715530189bedc9985b269bb93a220e8a	American Express	41.7755247982986262	-87.630734066621585
25034	2020-05-15 16:19:48	2020-05-15	Leta Larson	leta.larson@geemail.com	New York	New York	3476845948827859	495ea6fc329cd00aea4dce1d351e3ca6	Diners Club / Carte Blanche	40.6274403970912061	-73.9049739843130027
25035	2020-05-15 16:21:22	2020-05-15	Dimitri Reilly-Watsica	dimitri.reilly.watsica@geemail.com	Bakersfield	California	210005691343889649	01945276581469400ba798ef43926f9f	VISA 16 digit	35.2970152844384302	-119.069964209272712
25036	2020-05-15 16:31:34	2020-05-15	Chastity Jacobi	chastity.jacobi@geemail.com	San Antonio	Texas	180078517808513139	04cac962a84141c03601c2799c9eba87	JCB 16 digit	29.4978594272468229	-98.5195591443520016
25037	2020-05-15 16:33:07	2020-05-15	Vernell Kessler	vernell.kessler@geemail.com	San Bernardino	California	3528551114351719267	14255eea6270f509838c1fb8b95be5ea	JCB 16 digit	34.2247766320858133	-117.381276250282667
25038	2020-05-15 16:38:15	2020-05-15	Gerold Borer III	gerold.borer.iii@geemail.com	Los Angeles	California	3463021728424276	7cb4b6e26c4bf28ccb12104b44a697fb	VISA 13 digit	34.0351701755873819	-118.417114237881449
25039	2020-05-15 16:39:37	2020-05-15	Mr. Parley Barrows MD	mr.parley.barrows.md@geemail.com	Austin	Texas	3029349973351796	a58683d1a487e1f16023363f1e87d38f	Voyager	30.3798192776866252	-97.7718893273972043
25040	2020-05-15 16:41:02	2020-05-15	Dr. Darwyn Parisian V	dr.darwyn.parisian.v@geemail.com	Phoenix	Arizona	180007647469301577	bea02c4844f9638615c20db7de757287	Diners Club / Carte Blanche	33.4817270869322172	-112.088413104640694
25041	2020-05-15 16:46:25	2020-05-15	Belton Leannon	belton.leannon@geemail.com	Detroit	Michigan	3528135222931135865	95487e48763b9b5c7f417085351076b3	VISA 16 digit	42.4467159773148595	-83.1082008441563715
25042	2020-05-15 16:50:58	2020-05-15	Calvin Gerlach	calvin.gerlach@geemail.com	Norfolk	Virginia	060402548424452	82b5b12a2dadac1d5975a28e3089736f	American Express	36.8454175643641548	-76.2773920729760135
25043	2020-05-15 16:53:22	2020-05-15	Parlee McCullough-Thiel	parlee.mccullough.thiel@geemail.com	Honolulu	Hawaii	4254313807221494	ff94b060d0113ac98470943c44017bcf	American Express	21.2418735902506874	-157.830281359397247
25044	2020-05-15 17:04:02	2020-05-15	Doc Mosciski	doc.mosciski@geemail.com	Lincoln	Nebraska	4013639732068051	25e430a37cb226d54a5c3f832668d2e5	JCB 15 digit	40.8010227350536709	-96.7274359659452045
25045	2020-05-15 17:09:50	2020-05-15	Encarnacion Kulas III	encarnacion.kulas.iii@geemail.com	Philadelphia	Pennsylvania	3158451241364167969	441bf8121924650c059c4fa03365fc22	Mastercard	39.9863103032071123	-75.1242737424925053
25046	2020-05-15 17:15:07	2020-05-15	Madelynn Shanahan	madelynn.shanahan@geemail.com	Concord	California	869973686008040147	fc374867c42fe1471697d3ef567e795e	Voyager	37.8867950349513478	-122.055576856963711
25047	2020-05-15 17:44:50	2020-05-15	Don Pouros	don.pouros@geemail.com	San Jose	California	3007370667878748	72ce2c05a09db7c93e87e5ed8999ebad	Voyager	37.2715579805251238	-121.770076474429672
25048	2020-05-15 17:52:46	2020-05-15	Nova Stiedemann	nova.stiedemann@warmmail.com	Long Beach	California	4314758135609018	95d9a0c02e849a222a01fc419f17d2a6	VISA 16 digit	33.8148052471045375	-118.178692591625449
25049	2020-05-15 18:10:12	2020-05-15	Dr. Aiden Shields DDS	dr.aiden.shields.dds@geemail.com	Las Vegas	Nevada	3022311853916947	9761398b54d61529f14890c282a54cec	JCB 15 digit	36.3072048254411683	-115.310063976349682
25050	2020-05-15 18:16:26	2020-05-15	Adell Champlin	adell.champlin@geemail.com	San Francisco	California	502094544023248	f87e326ccdfb9c06f954347322d99c05	VISA 16 digit	37.7748244502726322	-122.455499792617985
25051	2020-05-15 18:20:43	2020-05-15	Gerold Ward-Jones	gerold.ward.jones@geemail.com	Baltimore	Maryland	3528621971048515671	2a2cbc00ad49cbe46b50ef2fa10cd7ae	JCB 16 digit	39.2480291303247171	-76.5194941604994199
25052	2020-05-15 18:26:47	2020-05-15	Maleah Wisoky	maleah.wisoky@warmmail.com	Atlanta	Georgia	501883183739479	fe8f626c42d7eb99953feb9c9c0a41fb	Mastercard	33.6842575476780581	-84.5103801713835452
25053	2020-05-15 18:27:33	2020-05-15	Ritchie Hettinger II	ritchie.hettinger.ii@geemail.com	San Francisco	California	6011543324064189937	58a1c30fb53a818153a69967a6292520	Voyager	37.7792936650209796	-122.425760812218897
25054	2020-05-15 18:41:33	2020-05-15	Angella Dickinson	angella.dickinson@woohoo.com	San Jose	California	3158625641174298014	6f509229d873c2b81e96cf3d40f6453b	Mastercard	37.2182177164878709	-121.850766719992833
25055	2020-05-15 19:06:47	2020-05-15	Ty Grimes	ty.grimes@geemail.com	New York	New York	6011066048245052972	025925adff01d174188e1c833def5373	JCB 15 digit	40.6014898881074018	-73.9589367527410388
25056	2020-05-15 19:16:53	2020-05-15	Kiyoshi Kulas	kiyoshi.kulas@geemail.com	Charlotte	North Carolina	869912355896057522	bc38c25dc18b8a31dacbdcf9d97c13ef	Diners Club / Carte Blanche	35.1630595893386726	-80.7502563154269097
25057	2020-05-15 19:18:02	2020-05-15	Collier Mueller	collier.mueller@geemail.com	Seattle	Washington	6011869856229029678	15c2349bd03e5a3c744a47542c67d986	VISA 13 digit	47.5819673778414725	-122.30237385820746
25058	2020-05-15 19:41:23	2020-05-15	Rudolf Oberbrunner	rudolf.oberbrunner@woohoo.com	San Francisco	California	3499852133801460	f333ed77b34570bccb0aff4b0ec09cb5	Diners Club / Carte Blanche	37.7594710328192846	-122.417519190367429
25059	2020-05-15 19:46:40	2020-05-15	Dr. Cato Torp	dr.cato.torp@geemail.com	Amarillo	Texas	3425061886606055	cd1f8515798d46f7d040654c3c78d1d5	VISA 16 digit	35.2904290721450025	-101.846115559977292
25060	2020-05-15 19:48:56	2020-05-15	Dawn McLaughlin	dawn.mclaughlin@woohoo.com	Los Angeles	California	3528237632628323284	2e3c8efa9b28cf7678d3cdbd2e9488f1	JCB 16 digit	34.0625451040320044	-118.341792925167084
25061	2020-05-15 19:54:28	2020-05-15	Silver Kris	silver.kris@geemail.com	Tacoma	Washington	3337985942569050927	d052c16c10f0feac38304b7e00e69454	VISA 16 digit	47.2655988935034728	-122.523299901350583
25062	2020-05-15 19:58:11	2020-05-15	Trisha Altenwerth	trisha.altenwerth@geemail.com	Milwaukee	Wisconsin	4978440701413201	ad40dcea36ce94d668c371597f85977f	VISA 16 digit	43.0765004525978128	-87.9852768336989044
25063	2020-05-15 19:58:45	2020-05-15	Albert Schaden V	albert.schaden.v@geemail.com	Dallas	Texas	3754785321803158	5f8c056d741bb73f63acd2478742f4ac	Mastercard	32.8435552296966335	-96.8509640542287258
25064	2020-05-15 20:00:42	2020-05-15	Cleora Cummerata	cleora.cummerata@geemail.com	Glendale	Arizona	3719601466378571	2ff99f06140285e0f22705417c6a1a0d	Maestro	33.4536704099033031	-112.160120427541059
25065	2020-05-15 20:03:51	2020-05-15	Kian Olson-Okuneva	kian.olson.okuneva@geemail.com	Durham	North Carolina	675943680105749	c0ef6dbd76b930a79e23a35e161737ba	Discover	35.9681553428307126	-78.9530723244786259
25066	2020-05-15 20:05:58	2020-05-15	Carina Bartoletti	carina.bartoletti@geemail.com	Philadelphia	Pennsylvania	3051132131495830	b0026520e46d66e3e454946e32a8121c	Diners Club / Carte Blanche	40.0790168853901321	-75.0369983530968483
25067	2020-05-15 20:12:48	2020-05-15	Dr. Trey Buckridge	dr.trey.buckridge@geemail.com	Los Angeles	California	3037832893614619	45c43a9edf0bd24f221be49b07675e75	JCB 16 digit	33.9699499162711192	-118.424255561222509
25068	2020-05-15 20:16:33	2020-05-15	Elissa Kilback	elissa.kilback@warmmail.com	New York	New York	4228153555390742	e54bd07d031d1d6c21b55b81334a3157	VISA 16 digit	40.6808701505642389	-73.8906039111677586
25069	2020-05-15 20:17:37	2020-05-15	Pascal Swaniawski DDS	pascal.swaniawski.dds@geemail.com	Cambridge	Massachusetts	3434838575335271	25e2c4aaeaec5600ac55648cba44c401	JCB 16 digit	42.3091119266338609	-71.0621365362860331
25070	2020-05-15 20:25:17	2020-05-15	Anabelle Sawayn-Howe	anabelle.sawayn.howe@geemail.com	Los Angeles	California	3498688840518638	ba4db587b69d1e692effbf7f4c3e4787	JCB 15 digit	34.0811821783292999	-118.313406979710976
25071	2020-05-15 20:33:27	2020-05-15	Latoya Ryan	latoya.ryan@geemail.com	New York	New York	4156605011436	7eb9ca8f19e9fe464ba481eff34a324f	American Express	40.709719099219889	-73.9605125527258878
25072	2020-05-15 20:44:50	2020-05-15	Letty O'Hara	letty.o'hara@geemail.com	Milwaukee	Wisconsin	3158240873976524603	0db3ad5bb14cfc0a8e191f278e104959	JCB 15 digit	42.9807853370059263	-87.9682255595557479
25073	2020-05-15 20:55:38	2020-05-15	Dollie Bernier	dollie.bernier@warmmail.com	Anchorage	Alaska	675978354726180	e7884e88c759ab1a2513b964a8b89794	American Express	61.1026516387455203	-149.253408242075892
25074	2020-05-15 20:57:56	2020-05-15	Nona Parker	nona.parker@geemail.com	San Diego	California	54783974139380538	187e6879839ccd1298fe5f03373725e4	VISA 13 digit	32.8283243794992572	-117.059659159546726
25075	2020-05-15 21:08:40	2020-05-15	Zollie Frami	zollie.frami@geemail.com	Albuquerque	New Mexico	53298937308104680	75b8f5345fe2bfb86084e2e8eb68634d	Diners Club / Carte Blanche	35.0218809220608378	-106.683739765088632
25076	2020-05-15 21:17:56	2020-05-15	Tamela Leuschke	tamela.leuschke@woohoo.com	New York	New York	210010622750716200	8f671a6a873d88857bec8c764f29a14c	Diners Club / Carte Blanche	40.7095858101490862	-73.9303696601547244
25077	2020-05-15 21:24:58	2020-05-15	Mr. Ford Sauer MD	mr.ford.sauer.md@woohoo.com	San Antonio	Texas	180096397616275769	845f3b87748073e004ddb37010bb2f38	JCB 16 digit	29.4347574695549916	-98.484078410204873
25078	2020-05-15 21:28:18	2020-05-15	Mrs. Zetta Sipes DDS	mrs.zetta.sipes.dds@warmmail.com	San Francisco	California	060447451372453	813d0d736f28e2df8f9e6d02678c82c7	VISA 16 digit	37.7594313396115382	-122.399685688127448
25079	2020-05-15 21:40:14	2020-05-15	Fredric Schuppe	fredric.schuppe@geemail.com	Vallejo	California	060437085759829	0d93fa4ce8ae7b5637d09e7992b52302	JCB 16 digit	38.015903043849022	-122.320004073284565
25080	2020-05-15 21:40:37	2020-05-15	Jerri Douglas	jerri.douglas@geemail.com	Orlando	Florida	210011439440830856	465ad29cf1f2d27f6614f28a9bf77b1e	American Express	28.3372500301137542	-81.2513816958725528
25081	2020-05-15 21:41:57	2020-05-15	Miss Kaylyn Bahringer PhD	miss.kaylyn.bahringer.phd@woohoo.com	Tampa	Florida	3027035386803356	9b1f3ada5120f8ec922ce101319b1320	Diners Club / Carte Blanche	27.9908457817159579	-82.5616222307298244
25082	2020-05-15 21:49:11	2020-05-15	Antonio Heathcote	antonio.heathcote@geemail.com	Columbus	Ohio	869917263810420963	3d159605f2e6391909d8ffc5526c5dfe	American Express	39.9526336911179101	-83.0469666554361652
25083	2020-05-15 21:50:25	2020-05-15	Marie Kovacek	marie.kovacek@geemail.com	Billings	Montana	4282219049917	919006182823b28b34ee844494eeb4c3	VISA 16 digit	45.7927350855190269	-108.529856555552769
25084	2020-05-15 22:04:20	2020-05-15	Audy Macejkovic	audy.macejkovic@geemail.com	Riverside	California	4289993606837654	0345b9949d4e2c07df93184395cc15f2	Voyager	33.9309059971891358	-117.480800317364555
25085	2020-05-15 22:05:09	2020-05-15	Primus Johnson	primus.johnson@warmmail.com	Glendale	California	502005344716591	4b6d5610a062ad46c9b133fb5cf3aa5a	JCB 15 digit	34.263828087946024	-118.294640489890426
25086	2020-05-15 22:08:12	2020-05-15	Elliott Lebsack	elliott.lebsack@warmmail.com	Fort Collins	Colorado	210005080170369034	62fc5390c29d684fa68ab9b7da4d5815	Maestro	40.484648995163667	-105.037152368570872
25087	2020-05-15 22:19:40	2020-05-15	Shannon Stehr	shannon.stehr@warmmail.com	New York	New York	52467274691068685	13873913f4b3b0b303cb0c4748341f78	Voyager	40.6984323410075177	-73.8775907766900986
25088	2020-05-15 22:39:58	2020-05-15	Ruth Rohan	ruth.rohan@geemail.com	San Francisco	California	3112913642099292034	0c6e33a5290f808487bbc8241377d128	VISA 16 digit	37.7534891871510538	-122.419165374038968
25089	2020-05-15 22:40:00	2020-05-15	Martine Ferry	martine.ferry@geemail.com	San Francisco	California	3002138090910130	0950b811ed206e12cda36bfe564085cb	VISA 16 digit	37.7497360981616481	-122.443279070180182
25090	2020-05-15 22:53:42	2020-05-15	Hughey Rath-Kozey	hughey.rath.kozey@geemail.com	Laredo	Texas	180035990174427287	8fa5925678a8b89ac1d58970dce1ac6b	Diners Club / Carte Blanche	27.6434718130338943	-99.4966166388716573
25091	2020-05-15 22:54:18	2020-05-15	Isaias Weissnat	isaias.weissnat@geemail.com	Tucson	Arizona	869970962524199409	61187b5bd0e040c99b61887b03bf94e0	American Express	32.0721019108820755	-110.90504848242216
25092	2020-05-15 23:00:15	2020-05-15	Yamilet Wilkinson-Altenwerth	yamilet.wilkinson.altenwerth@geemail.com	Tucson	Arizona	4020868402841841	230ea8008350fb01b85e2e2e686c78b9	Maestro	32.1436281787272549	-110.939734381925689
25093	2020-05-15 23:31:10	2020-05-15	Braeden Dibbert	braeden.dibbert@warmmail.com	Denver	Colorado	561215122721697	a74ad97aa6e7ec492bbd58d0d34ae471	VISA 16 digit	39.7565311388164702	-104.861059943797443
25094	2020-05-15 23:38:12	2020-05-15	Mrs. Aspen Gulgowski	mrs.aspen.gulgowski@geemail.com	San Jose	California	180024120846896528	e87878a9a8f389258d0f4b948c2131cd	VISA 16 digit	37.3296606005456297	-121.813029798561331
25095	2020-05-15 23:41:58	2020-05-15	Tressa Weissnat	tressa.weissnat@warmmail.com	Hampton	Virginia	3088130473981626890	ca0f8bb58ee764c04cd1ddd41e715c08	JCB 16 digit	37.1242880666181492	-76.2103361922878833
25096	2020-05-15 23:49:19	2020-05-15	Dr. Colonel Dietrich	dr.colonel.dietrich@geemail.com	Frisco	Texas	3052149450977460	4ac33d1bc4668a4168e74b6f206858d3	Discover	33.1466922804709512	-96.8104007423132629
25097	2020-05-15 23:55:36	2020-05-15	Thursa West-Torp	thursa.west.torp@geemail.com	Baton Rouge	Louisiana	869925269828921306	11cd96c87fbe97b977e20c11cc2a8319	VISA 16 digit	30.5190014047294866	-91.1313973683040501
25098	2020-05-16 00:01:28	2020-05-16	Jeannie Mitchell	jeannie.mitchell@geemail.com	San Antonio	Texas	3528622791410683140	4f73cac57bbd26371bb08e802a0276cf	Mastercard	29.4788787893556048	-98.4582506517250096
25099	2020-05-16 00:03:58	2020-05-16	Hebert Pfannerstill	hebert.pfannerstill@geemail.com	Berkeley	California	3337893410552689946	ada6bc03b40bf26311468722cf3364eb	Discover	37.8848321657331866	-122.24060630064389
25100	2020-05-16 00:07:32	2020-05-16	Mrs. Sister Jacobson MD	mrs.sister.jacobson.md@geemail.com	San Francisco	California	55002343023319611	605f887745fb2c2a7f9ddb756ce2c168	American Express	37.7783500336846885	-122.419035627062073
25101	2020-05-16 00:15:04	2020-05-16	Dr. Nicky McLaughlin	dr.nicky.mclaughlin@geemail.com	Philadelphia	Pennsylvania	6011525493375787010	539ded1899d8dbd5f8b9eca4d39312bd	Diners Club / Carte Blanche	39.9327075174037347	-75.1964440029479562
25102	2020-05-16 00:15:19	2020-05-16	Hailey Cummings	hailey.cummings@geemail.com	Yonkers	New York	4504875722263882	b05c6277a676309cf9417d1b8589e771	Discover	40.8721525503989298	-73.9644867083408002
25103	2020-05-16 00:16:53	2020-05-16	Audley Walsh	audley.walsh@geemail.com	San Antonio	Texas	3158514591721154034	4773d65d6657fd6ec379517e73b3adb7	Diners Club / Carte Blanche	29.4705793115846824	-98.5211642276331787
25104	2020-05-16 00:17:09	2020-05-16	Daunte Klocko-VonRueden	daunte.klocko.vonrueden@warmmail.com	Chicago	Illinois	210096864364882245	ea2a772135261c5394be67aac5746016	VISA 13 digit	41.7689851930666762	-87.7811306581862283
25105	2020-05-16 00:29:40	2020-05-16	Donnie Ratke	donnie.ratke@woohoo.com	Cambridge	Massachusetts	4555246169679	84b168bc65deaf4256bf5f685c3df297	Voyager	42.3922375589366993	-71.1243100554764283
25106	2020-05-16 00:39:09	2020-05-16	Miss Georgiann Thiel DDS	miss.georgiann.thiel.dds@warmmail.com	Vancouver	Washington	55858772962746571	2c0d1b7060020a796278729807e730e5	JCB 16 digit	45.6036686339020747	-122.536487647943943
25107	2020-05-16 00:42:54	2020-05-16	Gaige Swaniawski	gaige.swaniawski@woohoo.com	Killeen	Texas	4711330313901	e53e2f83a981785f99f8b5d5ecc3fa1f	Voyager	31.0365202397339033	-97.6755635388828836
25108	2020-05-16 00:53:34	2020-05-16	Cleora Stamm	cleora.stamm@geemail.com	Philadelphia	Pennsylvania	503893404114923	7bc121976826e25b984e48f18f132b50	JCB 15 digit	40.0083187705796206	-75.2298298172086533
25109	2020-05-16 01:01:13	2020-05-16	Arminta Mertz	arminta.mertz@geemail.com	Shreveport	Louisiana	4296350661442485	c57bb9b30f18b93d3625dfc3d24404a8	Mastercard	32.4733469025470356	-93.6945467814549744
25110	2020-05-16 01:02:36	2020-05-16	Hasan Boyle	hasan.boyle@geemail.com	Tyler	Texas	53454990355534762	64fe931cff2995749f549ad63bac58f0	VISA 16 digit	32.3506413165528386	-95.2517920477423701
25111	2020-05-16 01:09:56	2020-05-16	Camron Littel	camron.littel@geemail.com	New York	New York	3158872088994742104	44c385b743c8473022c89f63e4bcc697	American Express	40.6352015885747946	-74.0165507535811429
25112	2020-05-16 01:11:00	2020-05-16	Mr. Glendon Becker V	mr.glendon.becker.v@woohoo.com	Philadelphia	Pennsylvania	675957066243650	88093babddcc827b9343d11087086734	JCB 15 digit	39.9858913917053513	-75.0745682278081858
25113	2020-05-16 01:34:26	2020-05-16	Tasia Goodwin	tasia.goodwin@geemail.com	Augusta	Georgia	589336333806689	e8bcbc690251ee0cd19c6b9ae6336ae6	Discover	33.2873098257668261	-82.1212781937621656
25114	2020-05-16 01:49:23	2020-05-16	Jacqulyn King	jacqulyn.king@woohoo.com	St. Louis	Missouri	3031548018289451	e0ddd645c96b7fbdaa3e1b9bede5283d	VISA 13 digit	38.6386740777797968	-90.177370404266199
25115	2020-05-16 02:25:03	2020-05-16	Wells Dietrich-Hirthe	wells.dietrich.hirthe@warmmail.com	Houston	Texas	3764672196422546	e554815ef6082b9ec255d32c1a2851fa	Discover	29.7514509179707609	-95.4658123475514344
25116	2020-05-16 02:30:16	2020-05-16	Mrs. Susanna VonRueden MD	mrs.susanna.vonrueden.md@geemail.com	Anchorage	Alaska	3482800418723916	d46249acce3316ccba9711399eb42147	JCB 16 digit	61.2201478500135252	-149.248842561490079
25117	2020-05-16 02:40:17	2020-05-16	Kelby Koelpin	kelby.koelpin@woohoo.com	San Francisco	California	639020432548392	3cbe3cbeecc5ae23cd781b46b4b9243d	Maestro	37.7717990807438184	-122.452580961205541
25118	2020-05-16 02:57:48	2020-05-16	Mcarthur Torphy Sr.	mcarthur.torphy.sr.@geemail.com	Bakersfield	California	676223028133611	e054c90b70783bedf4d7c569f569daa4	Voyager	35.2502994617622321	-118.937775933397191
25119	2020-05-16 03:10:33	2020-05-16	Mrs. Christeen Abernathy PhD	mrs.christeen.abernathy.phd@geemail.com	Bellevue	Washington	3025634776668577	f9dc350cce560ef561d989ae5b647c3f	Discover	47.5576074272576719	-122.12539244830235
25120	2020-05-16 03:27:46	2020-05-16	Olaf Douglas	olaf.douglas@geemail.com	Ventura	California	4047672858805253	a23112c232a14ec6bcda57d649392fe2	American Express	34.2878908278580781	-119.321088206126163
25121	2020-05-16 03:29:50	2020-05-16	Dr. Elsie Walsh	dr.elsie.walsh@geemail.com	Tacoma	Washington	3088057085854402768	f6078351e4b2fa725616305a162a9b7f	American Express	47.1696458346329663	-122.524789196741949
25122	2020-05-16 03:39:32	2020-05-16	Shonna Lehner	shonna.lehner@woohoo.com	Oakland	California	4882658219156450	cac9ced5d0aeed83969ef5976e596cb0	VISA 16 digit	37.8216930607114463	-122.255065099826794
25123	2020-05-16 03:48:00	2020-05-16	Cecile Boyer	cecile.boyer@geemail.com	Wilmington	North Carolina	3053096922998278	f0ed093978eeb3335cac02fd93fcc20f	Voyager	34.1783008389927474	-77.9089906305998596
25124	2020-05-16 04:07:50	2020-05-16	Bev Stamm	bev.stamm@geemail.com	El Cajon	California	4989449913371450	95d890f984d622b5949cfa22c61e90eb	JCB 15 digit	32.7234556911986303	-117.00027793796697
25125	2020-05-16 04:32:05	2020-05-16	Dr. Reese Durgan	dr.reese.durgan@geemail.com	Dallas	Texas	4878821117396	7f08e0e93ea4cb2d37b1c501ab18f2e0	VISA 16 digit	32.7201752521835303	-96.8566260045356984
25126	2020-05-16 04:35:53	2020-05-16	Dr. Wong Walsh I	dr.wong.walsh.i@geemail.com	San Jose	California	52640927089980122	908b378836a0a930238b0809d0768cb9	Mastercard	37.381704180530086	-121.783720527192202
25127	2020-05-16 04:37:35	2020-05-16	Elvira Bahringer DVM	elvira.bahringer.dvm@warmmail.com	San Francisco	California	3756337813990859	410359a415d126a571879e0dedbb04a8	Mastercard	37.7654480322927171	-122.439028812824674
25128	2020-05-16 04:45:14	2020-05-16	Dr. Daryle Fritsch DVM	dr.daryle.fritsch.dvm@warmmail.com	New York	New York	3528331159192030702	ca755e9515ecde577ce4a314d064e4c0	JCB 16 digit	40.6190109374225159	-73.8956684548769118
25129	2020-05-16 04:51:50	2020-05-16	Dr. Garnett Cummerata	dr.garnett.cummerata@warmmail.com	Scottsdale	Arizona	6011158587817099852	194b94eedf6dc4a4d18b4443b3f6035d	VISA 13 digit	33.7064658816095459	-111.875173212677609
25130	2020-05-16 04:54:47	2020-05-16	Gaylene Collier	gaylene.collier@woohoo.com	Oakland	California	3015812593553681	0f3f4286fab08f1ea62f07fb2a3c7006	Voyager	37.8082136601056504	-122.287717180889445
25131	2020-05-16 05:07:59	2020-05-16	Venice Luettgen	venice.luettgen@geemail.com	San Francisco	California	4259307829781043	5f8e9fe3e7aed2b2bb60629cda171daa	American Express	37.765049300726858	-122.403951440254161
25132	2020-05-16 05:16:07	2020-05-16	Dr. Campbell Barrows MD	dr.campbell.barrows.md@woohoo.com	Los Angeles	California	4696537676988	869462a1d764656bcb69b9c3dbdf34e6	JCB 15 digit	34.0980426477599892	-118.358909391424802
25133	2020-05-16 05:50:19	2020-05-16	Lena Cremin-Frami	lena.cremin.frami@warmmail.com	Jacksonville	Florida	210071853985326095	a8381fe5e228726882226fc7e4128733	VISA 13 digit	30.4359574014373138	-81.7394263496235141
25134	2020-05-16 06:25:20	2020-05-16	Gabe Walker-Gislason	gabe.walker.gislason@geemail.com	North Charleston	South Carolina	3465840672220036	24d2327d5b0c3e0dca5148dc014dc3e6	Discover	32.9221362169992204	-80.0332219605427184
25135	2020-05-16 06:28:16	2020-05-16	Dr. Raekwon McCullough	dr.raekwon.mccullough@geemail.com	Pomona	California	55678038484858320	b8efebd7be9fa8563c070c951fae5693	JCB 15 digit	33.9753590386398159	-117.810183429528394
25136	2020-05-16 06:31:17	2020-05-16	Tamika Block-Block	tamika.block.block@woohoo.com	Philadelphia	Pennsylvania	180034414944865842	28930737e3afba1580aefd21d63358f4	VISA 16 digit	40.0515189486049081	-75.1824888182237743
25137	2020-05-16 06:36:45	2020-05-16	Mr. Avery Johns	mr.avery.johns@geemail.com	San Jose	California	3088179035422514530	3b05a1625ae953bd720096c850cb868e	JCB 16 digit	37.2154573134433519	-121.895541202205791
25138	2020-05-16 06:49:56	2020-05-16	Ms. Jesica Koelpin PhD	ms.jesica.koelpin.phd@geemail.com	Philadelphia	Pennsylvania	4941879780917927	9a86a473f1318b1007a3d1d33b64858e	Diners Club / Carte Blanche	39.9482405050151073	-75.0996455971051091
25139	2020-05-16 06:56:03	2020-05-16	Kittie Gorczany	kittie.gorczany@geemail.com	New York	New York	53056233993218544	f75b652731395fe0a6eb47a9353605d9	JCB 16 digit	40.5894728997014482	-73.8522850122664067
25140	2020-05-16 06:59:11	2020-05-16	Miss Carin Bruen	miss.carin.bruen@warmmail.com	New York	New York	3112165047728507957	035e84b0a39527ce01ff1a5c95a98c2d	Maestro	40.7448835881650453	-73.9801940155576858
25141	2020-05-16 07:18:59	2020-05-16	Milas Little-Yundt	milas.little.yundt@geemail.com	San Francisco	California	4841770786802877	b23942896e5f2e50a0bb4466dacebaa9	VISA 16 digit	37.787002633895348	-122.428198629325351
25142	2020-05-16 07:19:24	2020-05-16	Fletcher White DDS	fletcher.white.dds@geemail.com	Oakland	California	3419942216111759	e859024e6734f3d690f2bc98729273ca	JCB 16 digit	37.7907781722957239	-122.257985069925212
25143	2020-05-16 07:23:38	2020-05-16	Gannon Purdy	gannon.purdy@warmmail.com	El Paso	Texas	180031797355449368	7b4f48657b3e21b928ce3ee6b619520a	Voyager	31.8013402850195774	-106.495515635700897
25144	2020-05-16 07:24:22	2020-05-16	Ryann Mosciski	ryann.mosciski@geemail.com	Huntington Beach	California	3788305891116285	d2771e4c4ce3eb72f72204f94c0d7a5e	Diners Club / Carte Blanche	33.6160228744655853	-117.978360030160474
25145	2020-05-16 07:36:27	2020-05-16	Ethelene Bruen-Sawayn	ethelene.bruen.sawayn@woohoo.com	Greeley	Colorado	3474496777708422	54b080a4465a81d4eecd18bc72a9e868	VISA 16 digit	40.511368431669851	-104.77702613187283
25146	2020-05-16 07:37:46	2020-05-16	Estella Renner PhD	estella.renner.phd@warmmail.com	Riverside	California	180075208608106430	f9e59d3db9143046320ff1d20deaabc5	JCB 16 digit	33.9535925030656145	-117.326692405153807
25147	2020-05-16 08:05:22	2020-05-16	Pearly Stanton	pearly.stanton@geemail.com	New York	New York	53484141607744239	86e37a8edd1f55a297d8b75a528a51d8	Maestro	40.6490488850269429	-73.9045217255957425
25148	2020-05-16 08:11:51	2020-05-16	Cornelious Beier	cornelious.beier@geemail.com	San Diego	California	6011875081209061854	488477ff54befbd2e91c868d69132227	JCB 16 digit	32.8687951309673494	-117.208520157812174
25149	2020-05-16 08:15:20	2020-05-16	Clay Moore Sr.	clay.moore.sr.@geemail.com	Wichita	Kansas	3112659903641588347	ff8babe6844fd44a88045fad7d4474c7	JCB 15 digit	37.6317623019561154	-97.3049087930671845
25150	2020-05-16 08:37:45	2020-05-16	Antoinette Gleason	antoinette.gleason@warmmail.com	San Francisco	California	3112731446917719099	c4373a3fbbb60cc05e022f8f70234b1a	VISA 13 digit	37.7639643220092793	-122.451895745931282
25151	2020-05-16 08:50:00	2020-05-16	Hilary Rogahn	hilary.rogahn@woohoo.com	San Jose	California	4061244730956083	419c89a3f2b5bcff92ff0e53da988679	Discover	37.3507414500050245	-121.878674273913347
25152	2020-05-16 09:02:21	2020-05-16	James Rempel	james.rempel@geemail.com	San Diego	California	53668155794685284	4ff30648afba35724ea69b8f68b960de	JCB 15 digit	32.8849184790693201	-117.077274669138717
25153	2020-05-16 09:09:46	2020-05-16	Santiago White Sr.	santiago.white.sr.@warmmail.com	Charlotte	North Carolina	4412621054144436	07a11f6e24baf1db8cfc382ce2494c0d	Mastercard	35.2237692931920279	-80.8987617753855943
25154	2020-05-16 09:10:29	2020-05-16	Dr. Jens Simonis	dr.jens.simonis@warmmail.com	Los Angeles	California	3112358161155020413	473be4a822f6468b13d8c79eacfc855b	VISA 16 digit	34.0613061055872564	-118.467418389580388
25155	2020-05-16 09:11:12	2020-05-16	Kailee Lakin-O'Reilly	kailee.lakin.o'reilly@geemail.com	San Bernardino	California	869908933733440634	d628f3917bcb9771b21e741a3222240f	Mastercard	34.2403194946967062	-117.371463256959245
25156	2020-05-16 09:24:21	2020-05-16	Randy Boyer	randy.boyer@warmmail.com	Baton Rouge	Louisiana	561224489557207	4a8c5c3513746cb5e6edc23996e1d4d4	VISA 16 digit	30.4953696213874963	-91.2071316118460089
25157	2020-05-16 09:26:51	2020-05-16	Dania Crist	dania.crist@woohoo.com	Richmond	Virginia	3088328605554702390	63039b3152398d15f77c367cdb28f0e4	Diners Club / Carte Blanche	37.5220829038169228	-77.5226411991510531
25158	2020-05-16 09:37:18	2020-05-16	Hebert Thompson	hebert.thompson@geemail.com	Las Vegas	Nevada	3414401089501781	d283bf0a1699465ebe72b7c13d30a46e	Maestro	36.2942312426965685	-115.262346931800607
25159	2020-05-16 09:56:55	2020-05-16	Leatrice Purdy	leatrice.purdy@geemail.com	Miami	Florida	4012446502707996	399d5ce342a45846dcc50e5da4a7ca9b	Discover	25.7180498111199611	-80.2308618822474102
25160	2020-05-16 10:00:27	2020-05-16	Dr. Luther Lesch	dr.luther.lesch@geemail.com	Irving	Texas	3158644728076969961	d16734460cb554d0d140b1062de703a5	VISA 16 digit	32.8810213090803458	-96.9899299127329186
25161	2020-05-16 10:09:26	2020-05-16	Corrina Bednar	corrina.bednar@geemail.com	Berkeley	California	3023731668995142	e8149275210f9b9e723e063f2f13c193	VISA 16 digit	37.855545575898482	-122.284318054852108
25162	2020-05-16 10:14:22	2020-05-16	Shirley Leffler	shirley.leffler@geemail.com	Atlanta	Georgia	869978096235411316	332eeead6d69608a4597bb05cc25f3fd	Voyager	33.8203948829598744	-84.5136561174456062
25163	2020-05-16 10:33:41	2020-05-16	Ancil Gusikowski IV	ancil.gusikowski.iv@geemail.com	San Francisco	California	4075383723330262	a5d91f4b1ece8e7c4549147407bab52e	JCB 16 digit	37.7588275251417187	-122.470811070554191
25164	2020-05-16 10:33:57	2020-05-16	Mr. Mason Braun IV	mr.mason.braun.iv@woohoo.com	Memphis	Tennessee	3112758842827302992	1b89080017a46eb70c57a7b1f54fd3c0	VISA 16 digit	35.1136736948575816	-89.9327946226835309
25165	2020-05-16 10:35:04	2020-05-16	Leander Beier	leander.beier@geemail.com	Aurora	Colorado	210098955914883531	09c9a0dfdc23e37791fa58922aab3727	VISA 13 digit	39.7836571545451889	-104.756887064327302
25166	2020-05-16 10:35:32	2020-05-16	Teagan Mante	teagan.mante@geemail.com	Oceanside	California	503814647367987	d90f8615b24177faf1404847631212cf	Maestro	33.2823830990474647	-117.309744978145517
25167	2020-05-16 10:36:57	2020-05-16	Danyell Leffler	danyell.leffler@geemail.com	Chicago	Illinois	3337571639360222677	76d8465dc566d9cc48ed6b126a4eba13	American Express	41.9370569978676784	-87.6279696838494289
25168	2020-05-16 10:43:38	2020-05-16	Stan Ritchie MD	stan.ritchie.md@woohoo.com	Mesa	Arizona	869904434184921507	1342567e652bcb9975b04ddaad3061a0	Discover	33.4226639966160022	-111.710874456341941
25169	2020-05-16 10:47:11	2020-05-16	Sampson Johnson	sampson.johnson@geemail.com	Baltimore	Maryland	869956237994086230	46f6f8e646472e8bab90fdec4a8291f3	Diners Club / Carte Blanche	39.2085884808562639	-76.5464994463156927
25170	2020-05-16 10:54:01	2020-05-16	Miss Flonnie Schultz MD	miss.flonnie.schultz.md@geemail.com	San Francisco	California	51421296621572036	630326d41d8e46b2103f62dd2de9e611	VISA 13 digit	37.804305035893357	-122.431997852776519
25171	2020-05-16 10:54:37	2020-05-16	Madelene Kub	madelene.kub@woohoo.com	Jurupa Valley	California	54111869764413591	b059e070c8552bd52296b5c9f41b5d8d	JCB 16 digit	34.0856389471724626	-117.459202461179729
25172	2020-05-16 11:06:40	2020-05-16	Mrs. Netta Stiedemann	mrs.netta.stiedemann@warmmail.com	Clarksville	Tennessee	3758583652335924	e081bfe6aec50142a047ee0aec40d07f	American Express	36.4949584246739747	-87.3955394495695828
25173	2020-05-16 11:06:41	2020-05-16	Kathrine Pfannerstill DDS	kathrine.pfannerstill.dds@geemail.com	Oakland	California	4296399347504929	5b1061d6daa936fb2b7be9c31530570b	Diners Club / Carte Blanche	37.7917678745136243	-122.290916732310592
25174	2020-05-16 11:13:51	2020-05-16	Mrs. Lexi Luettgen MD	mrs.lexi.luettgen.md@geemail.com	New York	New York	3528364510261390015	49c37aaa08b314a192306ac9cab09407	Mastercard	40.6992106682378818	-74.0368648494955153
25175	2020-05-16 11:14:17	2020-05-16	Derik Cruickshank	derik.cruickshank@geemail.com	New York	New York	3032974541502096	791c4ccd47b8e6e2542c90a4d6088d2a	VISA 16 digit	40.584139848662538	-74.0349549508083555
25176	2020-05-16 11:14:19	2020-05-16	Arianna Schimmel	arianna.schimmel@geemail.com	Lansing	Michigan	3705159944915262	c2ee8a0e90b25d27fd26fba2d9484f3c	Maestro	42.6359349445283442	-84.5533411205869072
25177	2020-05-16 11:16:26	2020-05-16	Ms. Kathy Reilly DVM	ms.kathy.reilly.dvm@geemail.com	Augusta	Georgia	6011709172704535153	5242c02c7041aa773baca02e9173b910	Maestro	33.3175613539498272	-82.0662020194638586
25178	2020-05-16 11:30:56	2020-05-16	Dr. Alonzo Lehner II	dr.alonzo.lehner.ii@geemail.com	San Francisco	California	4776713506363	6ec1e1ce43104c873a8d4d603cabbc23	Voyager	37.7533018953967172	-122.460607562421401
25179	2020-05-16 11:37:49	2020-05-16	Fenton Kshlerin	fenton.kshlerin@geemail.com	Knoxville	Tennessee	676221046757486	a37fc79d999e6b12d0d974d3423a16ac	JCB 15 digit	36.0417376763250701	-84.0411497820850428
25180	2020-05-16 11:44:27	2020-05-16	Mr. Hurley Macejkovic	mr.hurley.macejkovic@geemail.com	Phoenix	Arizona	210062212944871298	c12bd74f7c8a92ff922340a33ef41b11	Maestro	33.6263903346777013	-112.013327700265137
25181	2020-05-16 11:44:39	2020-05-16	Robley Lesch	robley.lesch@geemail.com	Miami	Florida	869904517200092244	04eca1151a7cd7f16319444cc56de8e5	VISA 16 digit	25.7387707406327131	-80.1472077688075615
25182	2020-05-16 11:46:14	2020-05-16	Dashawn Fisher	dashawn.fisher@geemail.com	Fremont	California	180065521698116396	2f075071216ca3c52528e6e400f6bddd	JCB 15 digit	37.5498808072581909	-121.998069082013146
25183	2020-05-16 11:56:06	2020-05-16	Maritza Crooks MD	maritza.crooks.md@geemail.com	San Diego	California	4759215658429425	ca1c7a8a5f0a2bb6a55a4f74d249ed0d	JCB 16 digit	32.886910794728621	-117.192675915211439
25184	2020-05-16 12:10:50	2020-05-16	Camden Stracke	camden.stracke@geemail.com	Torrance	California	3158564663848164847	c8198f273f7154bbbced085ee0c5d659	VISA 16 digit	33.7510854489542567	-118.328799909272789
25185	2020-05-16 12:18:04	2020-05-16	Mr. Isadore Swift V	mr.isadore.swift.v@geemail.com	Berkeley	California	3427887822726104	e4ed90d502c814511fde33249e050318	Voyager	37.8682701502413295	-122.300302418927203
25186	2020-05-16 12:18:32	2020-05-16	Alexander Kovacek DDS	alexander.kovacek.dds@geemail.com	Cleveland	Ohio	4825042105698331	0d93d02e9b20ac7752aa427a7785f1a0	JCB 16 digit	41.5278630324956026	-81.7629597362834915
25187	2020-05-16 12:25:07	2020-05-16	Ceylon Terry	ceylon.terry@warmmail.com	Charlotte	North Carolina	4985107430173866	0867eb014c18ddfe2f51d0013adea0aa	Discover	35.1413098519455644	-80.7367623576372893
25188	2020-05-16 12:37:40	2020-05-16	Mr. Greggory Hauck	mr.greggory.hauck@geemail.com	Waterbury	Connecticut	54236938040774009	d052baed84812ab3774cd28ef2e89800	JCB 15 digit	41.6397743210233742	-73.0343182577665857
25189	2020-05-16 12:39:31	2020-05-16	Johnna Nolan	johnna.nolan@warmmail.com	Charlotte	North Carolina	55237781459334173	0154d6af43bd8424a718be55d61ec753	JCB 16 digit	35.3068834420081217	-80.7993260840363803
25190	2020-05-16 12:49:19	2020-05-16	Cherelle Kshlerin	cherelle.kshlerin@geemail.com	San Francisco	California	869926608865400204	090da8030efb936df399b739eeca2ca8	VISA 13 digit	37.8228314701340551	-122.417453638248489
25191	2020-05-16 13:00:17	2020-05-16	Teresa Stracke-Adams	teresa.stracke.adams@geemail.com	New Orleans	Louisiana	869913470939841961	041a874438f5db36396e0e254e04b66c	JCB 15 digit	30.119977363898979	-89.8841974160894779
25192	2020-05-16 13:03:17	2020-05-16	Mr. Khalil Robel II	mr.khalil.robel.ii@geemail.com	Fremont	California	3029838209407117	287ea795ebbf9157f4182eceb666df18	American Express	37.4894915675446398	-122.031690849222983
25193	2020-05-16 13:03:24	2020-05-16	Dylan Schulist III	dylan.schulist.iii@warmmail.com	New York	New York	4818424593673852	3effff24583bd4a9814786581cbe7727	Maestro	40.7454336860440662	-73.9048516170483083
25194	2020-05-16 13:08:25	2020-05-16	Maura Reinger	maura.reinger@geemail.com	St. Petersburg	Florida	869977081816019846	b3a3c9a5faa0a623218cbaf474e47151	Mastercard	27.8117180369682622	-82.5606875935927036
25195	2020-05-16 13:28:06	2020-05-16	Allene Miller-Beer	allene.miller.beer@geemail.com	Costa Mesa	California	869933581547779967	612228aef6db9191795ae31e97ba9427	Maestro	33.7547112335000179	-117.951133784312006
25196	2020-05-16 13:31:15	2020-05-16	Mr. Harve Adams	mr.harve.adams@geemail.com	Charlotte	North Carolina	6011019194214570459	7a15e4b756b57e2fd06888199ed8ccb8	Diners Club / Carte Blanche	35.2424425370778849	-80.8929833708275083
25197	2020-05-16 13:37:02	2020-05-16	Dr. Glenn Schaden PhD	dr.glenn.schaden.phd@geemail.com	Los Angeles	California	3035490773539869	75d32d960c1541530e236932117a3613	VISA 16 digit	34.0293759124685025	-118.316384929650638
25198	2020-05-16 13:39:48	2020-05-16	Cindy Pacocha	cindy.pacocha@warmmail.com	Seattle	Washington	4516149410064523	4c740f952e7330b8a88fad44e4259a31	JCB 15 digit	47.5634704296868307	-122.339334499222787
25199	2020-05-16 13:46:08	2020-05-16	Tomika Turcotte	tomika.turcotte@geemail.com	Palm Bay	Florida	4367180079899552	877edcb020c5b94db917808780a34f63	Mastercard	27.9623693775240341	-80.6915317108225025
25200	2020-05-16 13:49:58	2020-05-16	Dr. Adelbert Wintheiser DVM	dr.adelbert.wintheiser.dvm@woohoo.com	Albuquerque	New Mexico	3337878519090536689	5c348162c4f805b33217245a09fa4e02	Diners Club / Carte Blanche	35.1760161229077752	-106.571278854978829
25201	2020-05-16 13:52:59	2020-05-16	Miss Milan Gulgowski	miss.milan.gulgowski@woohoo.com	Eugene	Oregon	180074496959061731	1ca93273503981749c6d90cc31f96fdf	JCB 16 digit	44.0990208850901553	-123.107117776152492
25202	2020-05-16 14:00:03	2020-05-16	Ms. Felipa Parisian DVM	ms.felipa.parisian.dvm@geemail.com	New York	New York	3007557705939744	d43d8e1801250699f7b7c1cf783344f7	Mastercard	40.7316479795370228	-74.0321307153802337
25203	2020-05-16 14:11:20	2020-05-16	Miss Bianca Roberts	miss.bianca.roberts@geemail.com	New York	New York	53126239936017972	5f0a49043ca86a6eae2d39c3acc8ee45	JCB 16 digit	40.6698713237177572	-74.0059171105630611
25204	2020-05-16 14:28:26	2020-05-16	Kittie Champlin	kittie.champlin@geemail.com	Henderson	Nevada	502002238241760	82865e38a64599e9442938da866c7f2c	Voyager	35.9486048649929515	-114.975737586446854
25205	2020-05-16 14:34:00	2020-05-16	Arianna Block	arianna.block@warmmail.com	New York	New York	3759166634620115	b257eeaa491f23e2e5878d4eeea84d2a	VISA 13 digit	40.7123099068868868	-73.9064435297053279
25206	2020-05-16 14:35:28	2020-05-16	Emma Hilll DDS	emma.hilll.dds@woohoo.com	Indianapolis	Indiana	3048899713807219	7e8fda89cccd2f57dd15ebc4c8688229	Mastercard	39.7907915219206316	-86.2051651759274336
25207	2020-05-16 14:37:15	2020-05-16	Melton Boyle II	melton.boyle.ii@geemail.com	Oklahoma City	Oklahoma	501818638865693	207fab17410ba1d65caa786780abaef2	Voyager	35.5353947939261801	-97.4553287860367448
25208	2020-05-16 14:38:18	2020-05-16	Aidan Feest	aidan.feest@geemail.com	Chicago	Illinois	54592290820634963	9218e1efffb9e16a3557f6d9aff7b52b	JCB 16 digit	41.8200835106264819	-87.6723345413833783
25209	2020-05-16 14:53:26	2020-05-16	Collette Kunze	collette.kunze@geemail.com	Winston–Salem	North Carolina	3742490723119130	76a9a6d38b8de100c8844ed6ffa45c74	Discover	36.0309366642262745	-80.2443195459563299
25210	2020-05-16 14:54:58	2020-05-16	Macarthur Predovic V	macarthur.predovic.v@geemail.com	Berkeley	California	3789881866048629	e3fed33c5a97bfe9ba8997edc78e6c6b	VISA 16 digit	37.8940865518350947	-122.276029499512077
25211	2020-05-16 14:55:30	2020-05-16	Dink Bayer	dink.bayer@geemail.com	San Antonio	Texas	4031190986474833	ef0912ce2e6be7327a36050cfd5b0667	Mastercard	29.5076568723727028	-98.5207561950500974
25212	2020-05-16 15:08:28	2020-05-16	Duane Bernhard	duane.bernhard@warmmail.com	Chicago	Illinois	869906164001762184	de2f6d69990e8a136ae5cfd30c1aedfd	VISA 13 digit	41.9205890614841152	-87.7717746594950512
25213	2020-05-16 15:09:17	2020-05-16	Dr. Ailene Kiehn	dr.ailene.kiehn@warmmail.com	Boston	Massachusetts	4976627637167198	96c1d2b88fa3550c5dddf0f91a374c56	Maestro	42.3939623467326143	-70.9387369610320775
25214	2020-05-16 15:15:16	2020-05-16	Dr. Willie Runte	dr.willie.runte@geemail.com	Oakland	California	4637222894452193	f7ab4893cab2d6e2bc02dba362c78c2a	JCB 16 digit	37.8047432396332397	-122.282871496243644
25215	2020-05-16 15:24:17	2020-05-16	Shania Collins	shania.collins@geemail.com	San Francisco	California	503849327013675	50c7f21a1bff529ed798f8e863aa76da	VISA 16 digit	37.7522344022834346	-122.407890498066934
25216	2020-05-16 15:35:53	2020-05-16	Imanol Bradtke	imanol.bradtke@woohoo.com	Newark	New Jersey	3096541497869831226	53765cba43166038256181484ca2b909	JCB 16 digit	40.6934945494782241	-74.2093107690312053
25217	2020-05-16 15:40:10	2020-05-16	Kelis Parker	kelis.parker@geemail.com	Overland Park	Kansas	3112818788528620406	a86b9697d46e5f4f1176cc6a0ebe6bfc	JCB 16 digit	38.9726584025528311	-94.6558958511374868
25218	2020-05-16 15:44:38	2020-05-16	Ms. Sigrid Huels	ms.sigrid.huels@geemail.com	Saint Paul	Minnesota	3158698693974053539	764bb0be3ad6b7f0bd7bd2a10cd23458	VISA 16 digit	44.8843298714082692	-93.1121203671008431
25219	2020-05-16 15:46:39	2020-05-16	Dr. Alessandro Senger	dr.alessandro.senger@warmmail.com	San Francisco	California	3459009911257674	0674fa85dd2c96cffae935380ea597d9	Maestro	37.779081279410228	-122.44485108904793
25220	2020-05-16 15:49:12	2020-05-16	Neoma Cremin	neoma.cremin@warmmail.com	Long Beach	California	4922439533819756	71b3c6277cdc6668419599cc399e2d41	Discover	33.7829334871198981	-118.194792640970277
25221	2020-05-16 15:58:58	2020-05-16	Ms. Deb Cormier	ms.deb.cormier@geemail.com	Concord	California	3337685199857297677	23931565a29abc12bffe8bdb3a3f8936	VISA 16 digit	37.8987310970600717	-121.954984903492402
25222	2020-05-16 15:59:23	2020-05-16	Mr. Rock Hoeger	mr.rock.hoeger@geemail.com	Salem	Oregon	3528521389829755740	90ef4e3662ff455610ec5f6d0b4d51ac	Discover	44.9469538925949479	-122.980548138513043
25223	2020-05-16 16:00:09	2020-05-16	Rosemarie Cronin-Swaniawski	rosemarie.cronin.swaniawski@woohoo.com	Dallas	Texas	869944023323197970	119a4448ee0bd2331e52b23d9376069a	JCB 15 digit	32.696262316619233	-96.7549653238579594
25224	2020-05-16 16:00:57	2020-05-16	Joshuah Kulas	joshuah.kulas@geemail.com	Mobile	Alabama	3039304029286728	4ff8631572b3702c89193a63cb430b0e	Discover	30.6407714822437605	-88.1713857202928466
25225	2020-05-16 16:09:54	2020-05-16	Mrs. Savanah Rice	mrs.savanah.rice@geemail.com	Eugene	Oregon	869932280432675627	ec7d6d86de42d97340a41165dede348a	VISA 16 digit	43.958391581448538	-123.108598519068963
25226	2020-05-16 16:13:51	2020-05-16	Ms. Crystal Wilkinson	ms.crystal.wilkinson@woohoo.com	San Francisco	California	4726436702311498	6ced54a2b2ce47b34355f5f5d8634da8	VISA 16 digit	37.7758862659400663	-122.458948059735647
25227	2020-05-16 16:22:12	2020-05-16	Myrtice Kulas	myrtice.kulas@geemail.com	Henderson	Nevada	060426765424325	a49071df368efbe7beafd6dc0f7d91eb	VISA 13 digit	36.0310824765756763	-115.009406323187804
25228	2020-05-16 16:35:52	2020-05-16	Dr. Joeseph Marquardt Sr.	dr.joeseph.marquardt.sr.@woohoo.com	San Diego	California	4682157071999844	4251868c38a34acfa8e5d1cbf4ca45d6	American Express	32.7758266311205944	-117.167219073735183
25229	2020-05-16 16:43:26	2020-05-16	Donaciano West	donaciano.west@woohoo.com	Columbus	Ohio	6011019586409544233	6a9ff7ba0eee80d344e01fe5a0a7344f	JCB 15 digit	39.9556286279156794	-83.0449910998579242
25230	2020-05-16 17:15:27	2020-05-16	Sallie Brakus	sallie.brakus@geemail.com	St. Louis	Missouri	060460345545135	456522f64e040e437edc762cef408052	Diners Club / Carte Blanche	38.5777640911441324	-90.3216908269100003
25231	2020-05-16 17:26:04	2020-05-16	Sharyl Raynor	sharyl.raynor@woohoo.com	Seattle	Washington	3015049669630990	2e373c98cc18b2fea52ed731113dff56	Voyager	47.5891937508173299	-122.450463470855354
25232	2020-05-16 17:46:30	2020-05-16	Mallory Olson	mallory.olson@geemail.com	Louisville	Kentucky	675972762044245	260320b04990ae4a18bee2d8e20bac11	Diners Club / Carte Blanche	38.2241807618081566	-85.6027933931514724
25233	2020-05-16 17:46:47	2020-05-16	Dr. Encarnacion Kertzmann Jr.	dr.encarnacion.kertzmann.jr.@geemail.com	Gilbert	Arizona	3528094916639080971	236e7d3deeeea1c93822363f45edee60	VISA 16 digit	33.341265555459259	-111.735556896556545
25234	2020-05-16 17:49:04	2020-05-16	Mr. Jackson Boyer	mr.jackson.boyer@woohoo.com	Grand Prairie	Texas	4160189597752	124514963b4884a992f3dac228e250db	VISA 13 digit	32.7208619370177374	-97.1020204673394574
25235	2020-05-16 18:04:51	2020-05-16	Leesa Hodkiewicz	leesa.hodkiewicz@woohoo.com	Jersey City	New Jersey	210084524946481544	b346a671744b956d2b81b583d7bead52	JCB 16 digit	40.7913539025872893	-74.0137226418081724
25236	2020-05-16 18:13:30	2020-05-16	Alba Feeney	alba.feeney@geemail.com	San Francisco	California	55167457687327123	23215830a612328cf5442cba75b9d58a	American Express	37.799801244905666	-122.416567186203679
25237	2020-05-16 18:31:36	2020-05-16	Ashlynn Reichert-Rutherford	ashlynn.reichert.rutherford@geemail.com	Joliet	Illinois	4629721650276076	6d42658bdf36dfcfa35962deca21b33c	JCB 16 digit	41.4262630075540343	-88.1977847886376054
25238	2020-05-16 18:34:40	2020-05-16	Una Schmitt	una.schmitt@warmmail.com	Aurora	Colorado	3024641195328585	5a6b3b7c82b1296579052b910afa33a3	American Express	39.7793250438403376	-104.728944972122832
25239	2020-05-16 18:39:14	2020-05-16	Worley Nolan	worley.nolan@geemail.com	Albuquerque	New Mexico	6011252882284000573	ed95108d45c194ffe712338e42307202	VISA 16 digit	35.109193861265112	-106.709279798071464
25240	2020-05-16 19:03:33	2020-05-16	Ariel Ernser	ariel.ernser@geemail.com	Columbus	Ohio	676161064107065	1f29b5629f47062c4f002d5ea186e291	Maestro	40.0653589538343269	-82.9779307586841384
25241	2020-05-16 19:07:38	2020-05-16	Ms. Miranda Torp	ms.miranda.torp@geemail.com	Knoxville	Tennessee	3337906942636218552	89329d9b9da5e189903b06612d1516f2	Discover	36.0562738693382627	-83.9920376627921996
25242	2020-05-16 19:25:08	2020-05-16	Jillian Will-Roob	jillian.will.roob@warmmail.com	Sacramento	California	561201350380034	e2bc17d85dfb2f26f9d392fa3f5ce4ed	Maestro	38.6506044048614825	-121.523720385577903
25243	2020-05-16 19:35:59	2020-05-16	Jarett Balistreri	jarett.balistreri@warmmail.com	San Francisco	California	3747610539662156	09995d46a374c4fc047035dbf3ae74c9	Diners Club / Carte Blanche	37.744128095699871	-122.431253655865561
25244	2020-05-16 19:39:32	2020-05-16	Ambrose Barton	ambrose.barton@geemail.com	Houston	Texas	4704402025507267	15ec66203045a27ad21bd925f894242b	JCB 16 digit	29.8636980321802206	-95.3812083398472481
25245	2020-05-16 19:39:50	2020-05-16	Dennis DuBuque	dennis.dubuque@geemail.com	Memphis	Tennessee	3158589154186046482	a397f6ddef98cf006eeab9ac5ddf99fd	Discover	35.1373692560542423	-89.8937426003418949
25246	2020-05-16 19:40:07	2020-05-16	Lennie Franecki-Harris	lennie.franecki.harris@warmmail.com	Des Moines	Iowa	6011938908037670180	c03c015fed0dda1b1f7d633316e02b30	American Express	41.579504990505427	-93.6167885499119876
25247	2020-05-16 19:48:03	2020-05-16	Berta Sanford	berta.sanford@geemail.com	Charleston	South Carolina	53789521855869543	c2fb7ec253a5069291dad9beb34aa475	JCB 16 digit	32.7643663850609244	-80.0118660141397271
25248	2020-05-16 19:52:19	2020-05-16	Dr. Lim Marks	dr.lim.marks@geemail.com	Tucson	Arizona	180010575349067289	174e8ee42eae8e44ed92c18aa2776353	JCB 15 digit	32.1102036707144265	-110.854515081573652
25249	2020-05-16 19:55:12	2020-05-16	Mrs. Charisse Larson DVM	mrs.charisse.larson.dvm@geemail.com	New York	New York	52848465084108209	d32bb84e2581a858c0551c4c83f38eb6	JCB 16 digit	40.6791607587821744	-73.8626481478929549
25250	2020-05-16 20:02:43	2020-05-16	Yurem D'Amore	yurem.d'amore@geemail.com	Charlotte	North Carolina	639024860476761	2c5d8d16c26ff3f0ce9a870d915e2528	VISA 13 digit	35.3054089054252955	-80.9287487414143953
25251	2020-05-16 20:13:42	2020-05-16	Guillermo Waters-Robel	guillermo.waters.robel@geemail.com	New York	New York	4642056263799112	0bd2041430b5f40a72707659de18bdf2	VISA 13 digit	40.6090969480331978	-73.870657802316174
25252	2020-05-16 20:17:12	2020-05-16	Kendall Grant	kendall.grant@geemail.com	San Francisco	California	4954130532132215	4fcef42282965396ff65b03fc20198fc	JCB 15 digit	37.7384669864857401	-122.421048782643254
25253	2020-05-16 20:29:16	2020-05-16	Kallie Ryan	kallie.ryan@geemail.com	Lexington	Kentucky	54810074184163520	5e1c896167a31f4dd3f6da0ab79f681a	VISA 16 digit	38.0675391184974501	-84.4805850497346285
25254	2020-05-16 20:33:07	2020-05-16	Carson Konopelski	carson.konopelski@geemail.com	Berkeley	California	3056431535599055	1938ae854269c9edf3801bd82578de41	Discover	37.8759652750231552	-122.282566924472889
25255	2020-05-16 20:35:01	2020-05-16	Stan Welch	stan.welch@geemail.com	Pasadena	Texas	6011025594379420360	a5b6635b7bbdffa06eeb462be1f2a9b6	VISA 13 digit	29.7579406483437872	-95.2400454244989874
25256	2020-05-16 20:39:58	2020-05-16	Olga Hegmann DVM	olga.hegmann.dvm@geemail.com	Irvine	California	869986179850783308	26ee8da5c7da038d5ce9a862d40adf17	JCB 16 digit	33.675119334134834	-117.836341080256915
25257	2020-05-16 20:50:55	2020-05-16	Dr. Caren Dare	dr.caren.dare@geemail.com	Houston	Texas	4308330843175647	e0775f4072697f40254d0a946c1f1715	VISA 16 digit	29.8251635260492556	-95.4134058229174542
25258	2020-05-16 21:02:25	2020-05-16	Dell Pouros	dell.pouros@woohoo.com	Kansas City	Missouri	4598241530449725	338316fbcbf0f1b460ce9e053cb201fc	Voyager	39.1493352358065607	-94.646074133621525
25259	2020-05-16 21:15:34	2020-05-16	Djuana Yundt	djuana.yundt@geemail.com	Charleston	South Carolina	561224138103882	b86d326d92b1403f33ccfe1b6527931e	Discover	32.7968771390147538	-80.0254091734681339
25260	2020-05-16 21:19:29	2020-05-16	Jessee Morar	jessee.morar@geemail.com	Gresham	Oregon	52567717080806759	8d384bbc6bd180d67090eaacf2bd56c5	American Express	45.4059424144636807	-122.423115745539207
25261	2020-05-16 21:23:24	2020-05-16	Felton Collier	felton.collier@geemail.com	Norwalk	California	4645680602597155	0c3270a577e68db22b23c61296dee823	VISA 16 digit	33.8554218913078344	-118.161883481921635
25262	2020-05-16 21:34:25	2020-05-16	Link Koss	link.koss@geemail.com	San Antonio	Texas	3158152632877907846	006510f9b361b3a922e82946d356ccb1	Diners Club / Carte Blanche	29.393214648224042	-98.5566398646984254
25263	2020-05-16 21:35:47	2020-05-16	Miss Nannie Windler	miss.nannie.windler@geemail.com	Providence	Rhode Island	3158114752630102985	5f26181832e8046b71c10be444c15859	VISA 16 digit	41.8448957716900836	-71.4858554122421879
25264	2020-05-16 21:36:12	2020-05-16	Johnpaul Keebler	johnpaul.keebler@geemail.com	Dallas	Texas	869933241320690895	ed4335323254b10b25784ac5788464f0	VISA 13 digit	32.7997772171434008	-96.6980466510597552
25265	2020-05-16 21:38:42	2020-05-16	Reagan Herzog	reagan.herzog@woohoo.com	Killeen	Texas	502065135104910	abc6a907762baa5fb8f0477d8f3e7a92	Discover	31.1228105059124545	-97.6648323551453643
25266	2020-05-16 21:50:23	2020-05-16	Clarissa Haag-Wilkinson	clarissa.haag.wilkinson@geemail.com	Philadelphia	Pennsylvania	502002665922890	af9748ee640fa7e74b388f9f47ca4a2f	Discover	39.9629297006368631	-75.2224124192625396
25267	2020-05-16 22:15:33	2020-05-16	Inger Kshlerin DVM	inger.kshlerin.dvm@warmmail.com	Green Bay	Wisconsin	3528145880875442437	d3f224cfe24abc5e471cd7d2ad51c2ca	Maestro	44.5835982301801437	-87.9819089373860521
25268	2020-05-16 22:17:13	2020-05-16	Marianne Anderson	marianne.anderson@woohoo.com	Mesa	Arizona	4168885101142	65297387a9dafde0d8605d63c419f8e3	JCB 16 digit	33.3412281350377953	-111.628189412492887
25269	2020-05-16 22:21:20	2020-05-16	Dr. Janay Botsford	dr.janay.botsford@geemail.com	San Jose	California	210096019923463082	b878b1404e5eb244d648d9533083b394	Diners Club / Carte Blanche	37.3341393776059149	-121.830189498303085
25270	2020-05-16 22:33:16	2020-05-16	Artie Hane-Leannon	artie.hane.leannon@woohoo.com	South Bend	Indiana	6011873801779557144	f83a293bb595736bae969fbac376e3e7	JCB 16 digit	41.6041493115626295	-86.2509323843810733
25271	2020-05-16 23:01:16	2020-05-16	Nallely Ryan	nallely.ryan@geemail.com	Overland Park	Kansas	6011926845779433456	6c924187074e58fb990f12f1b073fbec	Maestro	38.8234417994841934	-94.7136535713024443
25272	2020-05-16 23:31:04	2020-05-16	Ms. Stormy Harber	ms.stormy.harber@woohoo.com	Lansing	Michigan	54671291889840156	41719db55a84d19606df657828a89533	VISA 16 digit	42.6516314198106556	-84.523095392587777
25273	2020-05-16 23:32:12	2020-05-16	Hakeem Kreiger	hakeem.kreiger@warmmail.com	Oakland	California	869916155122097334	466921a1946dd96449e1360c70da6869	Diners Club / Carte Blanche	37.8094011412266724	-122.257411478765263
25274	2020-05-16 23:33:40	2020-05-16	Tawanna Pouros DDS	tawanna.pouros.dds@geemail.com	San Jose	California	869911160304969107	6cd71e7b0e9e2fc5857a097fc6f8ccf4	Voyager	37.2402568029992267	-121.858930888328331
25275	2020-05-16 23:40:13	2020-05-16	Dr. Worley Rice I	dr.worley.rice.i@warmmail.com	Corona	California	4935757220129063	8643a4b23af42afece2b995775fbe623	VISA 13 digit	33.8338079994432661	-117.492433280006054
25276	2020-05-16 23:43:04	2020-05-16	Carole Barton	carole.barton@warmmail.com	San Francisco	California	180086055896899409	5d53a7da1361cd9943a7d80b50c1832c	JCB 15 digit	37.7578444213830338	-122.434600310113524
25277	2020-05-16 23:45:11	2020-05-16	Jack Ferry	jack.ferry@geemail.com	Odessa	Texas	4140517346098	f146a82dd2abd444e2bcf3b6f618a741	JCB 16 digit	31.819395870437102	-102.396292201305172
25278	2020-05-16 23:49:11	2020-05-16	Melvin Prosacco Sr.	melvin.prosacco.sr.@geemail.com	Sparks	Nevada	3112633245672520844	7c046b3dddd383c4b2feac3a1e22f9d1	Diners Club / Carte Blanche	39.5086609573341931	-119.801954827303447
25279	2020-05-16 23:49:52	2020-05-16	Jamil Schamberger	jamil.schamberger@warmmail.com	San Francisco	California	3750306019859289	8002bf8aba43435360a51d3b6911e60d	JCB 16 digit	37.737300512302177	-122.395938043582163
25280	2020-05-17 00:04:19	2020-05-17	Miss Cherelle Metz	miss.cherelle.metz@geemail.com	Buffalo	New York	3158358954541717340	700cf648ae8ac01ffab49a99e5fca135	JCB 16 digit	42.8907285917270897	-78.9454253255788245
25281	2020-05-17 00:05:49	2020-05-17	Mr. Robert Cummings	mr.robert.cummings@warmmail.com	Oakland	California	869943536368651800	eba4acd7f0d95d989c031d774441f8fd	JCB 15 digit	37.7763107612141127	-122.268252562452517
25282	2020-05-17 00:16:44	2020-05-17	Teddy Anderson	teddy.anderson@geemail.com	San Francisco	California	3732701059344619	eeb5840172650199bf6ec20ecadb52a1	Maestro	37.7888255765401198	-122.436421244044837
25283	2020-05-17 00:36:16	2020-05-17	Jerry Stehr	jerry.stehr@geemail.com	Philadelphia	Pennsylvania	3088980750013427251	6680c61d5b6a1970a7737ec67048d83c	VISA 16 digit	40.0557015561923393	-75.0665761941477712
25284	2020-05-17 00:38:35	2020-05-17	Shelbi Brekke	shelbi.brekke@warmmail.com	Las Vegas	Nevada	53908690219656932	09ed6b0bbe6097bcded0da01098fcf77	VISA 16 digit	36.255831631143387	-115.23205897279307
25285	2020-05-17 00:47:01	2020-05-17	Albertha Kertzmann	albertha.kertzmann@geemail.com	High Point	North Carolina	060407390057888	3cd4c4c059c2f8116e13ed9156fa360c	Maestro	35.9701054914481944	-80.0349451319053742
25286	2020-05-17 00:47:22	2020-05-17	Dr. Roseanne Dicki DDS	dr.roseanne.dicki.dds@geemail.com	Charlotte	North Carolina	4045533758714072	6f222201fbefa47b0df9fc35f15d78da	Discover	35.2521148920778202	-80.740035783819863
25287	2020-05-17 00:49:35	2020-05-17	Dr. Edmon Boyer	dr.edmon.boyer@geemail.com	Oklahoma City	Oklahoma	55143067650290965	49cd59e6cf52a5926f36dc93c95f5042	JCB 16 digit	35.4670627254903366	-97.5475824756909162
25288	2020-05-17 00:53:03	2020-05-17	Eathel Cummerata	eathel.cummerata@warmmail.com	San Francisco	California	869982666964971393	09eadac759e08065f4f9c36a3acdb103	JCB 16 digit	37.7986273942582898	-122.430332999474103
25289	2020-05-17 00:54:27	2020-05-17	Orelia Steuber DVM	orelia.steuber.dvm@geemail.com	Norfolk	Virginia	3051227444393480	7dce95f8eb237f57d2c09b52673c5fdd	JCB 16 digit	37.0198110282439785	-76.3069425983358229
25290	2020-05-17 00:56:29	2020-05-17	Erving Pagac	erving.pagac@geemail.com	Charlotte	North Carolina	6011661513000882136	622f008a22e72b2c474acab44ce5d8bf	Discover	35.1354622421573808	-80.8490662287864836
25291	2020-05-17 00:57:51	2020-05-17	Brandan Braun-Pouros	brandan.braun.pouros@geemail.com	Tampa	Florida	3023284711367588	ee39fefe685f06896f82a8e617edc023	Discover	27.8812249838024364	-82.4389318078968643
25292	2020-05-17 01:01:32	2020-05-17	Pansy Reichert	pansy.reichert@woohoo.com	Knoxville	Tennessee	3031022126685281	ad4092d14717b6aebbc59bc3d30ca337	VISA 16 digit	35.9941715527389192	-83.9931578564673629
25293	2020-05-17 01:19:06	2020-05-17	Clarence Hickle	clarence.hickle@geemail.com	Wichita	Kansas	869988972507164403	df1bb22ede77e30000600047349b6747	JCB 16 digit	37.7399254754994047	-97.3475212448943381
25294	2020-05-17 02:09:41	2020-05-17	Ibrahim Kutch	ibrahim.kutch@woohoo.com	Stockton	California	3528898753542946339	8fa05bc8d72b8786b08b7ca34d1a72ba	Discover	37.9923595649387735	-121.292129801967363
25295	2020-05-17 02:19:16	2020-05-17	Tyriq Treutel	tyriq.treutel@geemail.com	San Francisco	California	3048152320583678	f43c98b08a7b2a0b5ac7b6ddb211e44c	American Express	37.7784189659456331	-122.429100462016692
25296	2020-05-17 02:20:36	2020-05-17	Dr. Burdette Jast	dr.burdette.jast@warmmail.com	San Francisco	California	4312953367934620	13b61ef1c10adecac54795ace3e9a8d7	VISA 13 digit	37.767218396546788	-122.438593263677561
25297	2020-05-17 02:28:26	2020-05-17	Mr. Duard Conn MD	mr.duard.conn.md@geemail.com	Mesa	Arizona	503835827716586	33ef297a6143d843dc3dd0249ad4433a	JCB 16 digit	33.3622861365467287	-111.697313794482127
25298	2020-05-17 02:41:18	2020-05-17	Dr. Denver Donnelly II	dr.denver.donnelly.ii@woohoo.com	Chicago	Illinois	54642042482320146	2eefbbcfc5883cb7b84dc845227c70ee	JCB 16 digit	41.9162056399811078	-87.6325049899548247
25299	2020-05-17 02:44:35	2020-05-17	Hubert Hintz	hubert.hintz@geemail.com	Kent	Washington	4579119998709	ef1c2504f820c0bc1edc6d69c5425787	Mastercard	47.3557292370237377	-122.179287262880052
25300	2020-05-17 02:57:51	2020-05-17	Caesar Kuvalis	caesar.kuvalis@geemail.com	Murfreesboro	Tennessee	4104229986456440	ddd6be84cd7484997b0fa48a3c308361	Diners Club / Carte Blanche	35.764328654681151	-86.3491506282556713
25301	2020-05-17 03:02:36	2020-05-17	Harding Klein	harding.klein@geemail.com	Berkeley	California	3337339414384525312	63bfd7a4f0d755e22840550625b22d18	Maestro	37.8598664819659163	-122.278232916685511
25302	2020-05-17 03:21:58	2020-05-17	Crockett Farrell	crockett.farrell@warmmail.com	Tucson	Arizona	4935410237454	9e380176a5ff926200ac7b0e95ae6708	JCB 16 digit	32.2342765929218373	-110.968022664426258
25303	2020-05-17 03:27:22	2020-05-17	Thurlow Rohan	thurlow.rohan@warmmail.com	Lansing	Michigan	180074982107486490	c134e0025b66d19dcb09135799323200	Diners Club / Carte Blanche	42.7185208311148017	-84.4709129119880373
25304	2020-05-17 03:44:06	2020-05-17	Faustino Powlowski IV	faustino.powlowski.iv@woohoo.com	Lincoln	Nebraska	3488588291181047	8729335373147463b930a900856d0376	Voyager	40.8548777556531135	-96.65294130227268
25305	2020-05-17 03:46:42	2020-05-17	Lupe Corwin DDS	lupe.corwin.dds@geemail.com	Santa Clarita	California	869907420656030437	4a5b071868e58bcdc6460771d7a9ec22	Voyager	34.4422232328653308	-118.497891900651894
25306	2020-05-17 03:47:38	2020-05-17	Ms. Rosemarie Herman	ms.rosemarie.herman@geemail.com	Baltimore	Maryland	3096198218776493975	cdb06ec73f3f5784910028ecdeddb789	Diners Club / Carte Blanche	39.3897535644005927	-76.5185600176472178
25307	2020-05-17 03:59:02	2020-05-17	Tami Howell PhD	tami.howell.phd@warmmail.com	San Francisco	California	869974779091231316	4ea61772ed3f44a91cf0f3e261d94dfe	American Express	37.7805887462816017	-122.412815489691255
25308	2020-05-17 04:00:35	2020-05-17	Jennings Prosacco	jennings.prosacco@geemail.com	Sandy Springs	Georgia	4326448223986090	7a9b4ef269e48fee0f0b5b72f844beef	American Express	33.8359562871102213	-84.3214701440733023
25309	2020-05-17 04:04:23	2020-05-17	Turner Williamson Sr.	turner.williamson.sr.@geemail.com	Detroit	Michigan	3005627722782831	53e10455fcc9c9e982416a3723f7c036	Diners Club / Carte Blanche	42.2974428944215219	-83.078572420461839
25310	2020-05-17 04:04:25	2020-05-17	Jossie Spencer	jossie.spencer@geemail.com	Oakland	California	3096417851111812932	cf0e3bc468d621fe9a1fde02da4c4071	American Express	37.7950209426555048	-122.231621556974972
25311	2020-05-17 04:12:36	2020-05-17	Elana Nader-Watsica	elana.nader.watsica@geemail.com	Oakland	California	3053422871175249	edcd3d5188763f432a027913b7538a82	VISA 16 digit	37.7386949820790178	-122.274711712148488
25312	2020-05-17 04:37:20	2020-05-17	Thora Cronin	thora.cronin@geemail.com	Chicago	Illinois	6011276496167735999	6183616666315600b842508dc025bd69	JCB 15 digit	41.8475888954311657	-87.6858019541513158
25313	2020-05-17 05:15:35	2020-05-17	Jan Harvey	jan.harvey@geemail.com	Los Angeles	California	869984444647431492	7623ee6c842af126681996387acaecb0	Voyager	33.9298822490364316	-118.355789683758459
25314	2020-05-17 05:20:16	2020-05-17	Dr. Alvena Jakubowski DVM	dr.alvena.jakubowski.dvm@geemail.com	Lakeland	Florida	210009951630839863	0a621e370d3fa9234be6c6843767cc6a	JCB 15 digit	28.0654254234228269	-81.8766801519203824
25315	2020-05-17 05:23:18	2020-05-17	Kris Yost	kris.yost@geemail.com	Newport News	Virginia	869962649298726398	e9b6810bea7cf183a78c32de36ee28e8	VISA 16 digit	36.9988683495566235	-76.4844231182504473
25316	2020-05-17 05:28:47	2020-05-17	Hezzie Nolan	hezzie.nolan@geemail.com	Los Angeles	California	3714121391252598	f10047abc5b06468f1f2ba21942d1afc	Discover	34.0449574736278464	-118.457708347588024
25317	2020-05-17 05:29:12	2020-05-17	Worley Mills	worley.mills@geemail.com	San Francisco	California	6011767261911215441	4dbe60a28931c9e10d46affb052448e8	VISA 16 digit	37.7714780298921937	-122.451595752377244
25318	2020-05-17 05:30:01	2020-05-17	Young Schulist	young.schulist@geemail.com	San Francisco	California	4998607565554009	623ac0469fba89a4dc5a5e1c9b6c8842	VISA 13 digit	37.7672736492878229	-122.418325864711932
25319	2020-05-17 05:37:51	2020-05-17	Madison Pacocha DDS	madison.pacocha.dds@geemail.com	Cape Coral	Florida	869981455319204820	2d7f06d21e6c1c25838271b8ab7629f4	American Express	26.6019185764219621	-81.9925767588965613
25320	2020-05-17 05:43:27	2020-05-17	Dr. Lesia Nolan MD	dr.lesia.nolan.md@geemail.com	San Francisco	California	54452633050381889	b74a9d34dfab4ab592ce659481a71f82	VISA 13 digit	37.7746391569488082	-122.405543810723273
25321	2020-05-17 06:05:26	2020-05-17	Jolette Medhurst DVM	jolette.medhurst.dvm@warmmail.com	Denver	Colorado	3757756933838038	4cd06f589b7ada1edb219aabb59eebc4	VISA 16 digit	39.6782887767121153	-104.929681132246188
25322	2020-05-17 06:10:11	2020-05-17	Marcel Lubowitz	marcel.lubowitz@geemail.com	Oklahoma City	Oklahoma	3780852110942882	3b4dcbffd652a6992b61baea0f549d7b	VISA 16 digit	35.4528757362537092	-97.459891645693034
25323	2020-05-17 06:17:49	2020-05-17	Saundra Maggio	saundra.maggio@geemail.com	Milwaukee	Wisconsin	4137950145146637	9833e7729e4ccb85ad60c083f9fe9e75	VISA 16 digit	43.1023325297135855	-88.022495264523485
25324	2020-05-17 06:18:15	2020-05-17	Harmony Beer	harmony.beer@warmmail.com	San Francisco	California	4158459833659855	815c89bf41181a40eb1c9a11a53b2d7b	VISA 13 digit	37.7705239533620158	-122.412049501405534
25325	2020-05-17 06:36:57	2020-05-17	Ruffus Brekke	ruffus.brekke@geemail.com	Oakland	California	676162237544150	aaf0c2372a6835a2d21dea91825ad543	Maestro	37.8203660554503003	-122.273431953778129
25326	2020-05-17 06:52:49	2020-05-17	Kailyn Larson	kailyn.larson@geemail.com	Nashville	Tennessee	54129944360506096	a712062de3dbcd6da0f1b607ca60e320	JCB 16 digit	36.1074050744187076	-86.8756257961410938
25327	2020-05-17 07:03:44	2020-05-17	Mrs. Sybilla Wehner	mrs.sybilla.wehner@geemail.com	Tampa	Florida	3017736176085555	b3de4ea6f24e903fb22be61d35e4de54	VISA 16 digit	27.9186134130809442	-82.442408690436551
25328	2020-05-17 07:12:04	2020-05-17	Ferman Welch	ferman.welch@geemail.com	Seattle	Washington	869960641232074789	6a66047d85188f09568f5aed1511713c	JCB 15 digit	47.6903530261404782	-122.386943690517541
25329	2020-05-17 07:18:27	2020-05-17	Verlie McDermott-Ryan	verlie.mcdermott.ryan@geemail.com	Arvada	Colorado	6011532837724729779	10cefe3a5393466a37e2228c95aba8b9	Discover	39.8300534061796938	-105.169472658026223
25330	2020-05-17 07:21:02	2020-05-17	Hedy Haley	hedy.haley@geemail.com	Louisville	Kentucky	869969190194424260	e15a99cde4dfa9e0ad7d13c614870eb7	Voyager	38.1862025441504969	-85.7372216719273581
25331	2020-05-17 07:34:09	2020-05-17	Stormy Schuppe	stormy.schuppe@woohoo.com	Phoenix	Arizona	4270164389263929	c4a9bbad7d06c48a2020af019294ae67	Maestro	33.5536424818847365	-112.188400667153672
25332	2020-05-17 07:35:09	2020-05-17	Huldah Ankunding	huldah.ankunding@woohoo.com	Toledo	Ohio	4496316009877	dbd3ae3fff2411749703e67f2b18df51	Diners Club / Carte Blanche	41.6918205937542012	-83.6581028472032386
25333	2020-05-17 07:40:30	2020-05-17	Dr. Kalvin Wiza	dr.kalvin.wiza@geemail.com	Berkeley	California	3112034615378132794	364be299da2d3ccc0c01aeae5b2e0149	JCB 16 digit	37.9037745696605555	-122.294940905172808
25334	2020-05-17 07:49:23	2020-05-17	Ancel Stehr	ancel.stehr@geemail.com	Albuquerque	New Mexico	4387427561156660	ce6f954d038086139fac8633759874c4	JCB 16 digit	35.0252921621449289	-106.630995147635787
25335	2020-05-17 08:17:32	2020-05-17	Latesha Schinner DDS	latesha.schinner.dds@geemail.com	Orlando	Florida	4267753821557	672f44d992b40956c94e44f67f8a6f0a	Diners Club / Carte Blanche	28.3572432120595117	-81.309409450317176
25336	2020-05-17 08:22:44	2020-05-17	Alonza Hilll	alonza.hilll@geemail.com	Fort Wayne	Indiana	869979368807728537	4d97cfd581218ee7fb9c99b3c266e90b	Diners Club / Carte Blanche	41.026695252188297	-85.2406687529977489
25337	2020-05-17 08:26:57	2020-05-17	Ms. Loda Sipes	ms.loda.sipes@geemail.com	San Francisco	California	4520778719546808	2aebb7edbeb9dbc32d02f07edbf50e87	VISA 13 digit	37.7699225166513628	-122.475363959579767
25338	2020-05-17 08:27:35	2020-05-17	Miss Lydia Tromp MD	miss.lydia.tromp.md@geemail.com	Fayetteville	North Carolina	676313452668190	329316cf4499d2aaca1f1e823b31c34e	Diners Club / Carte Blanche	35.0469085078474123	-78.9603588920217021
25339	2020-05-17 08:32:33	2020-05-17	Parthenia Kautzer-Pfeffer	parthenia.kautzer.pfeffer@geemail.com	Dallas	Texas	51029477493406620	3629c2a6ab1dfbf4f6a0daedce350099	JCB 16 digit	32.8571104583602391	-96.7027183815333871
25340	2020-05-17 08:35:12	2020-05-17	Dr. Halsey Pfeffer	dr.halsey.pfeffer@woohoo.com	Miami Gardens	Florida	3112960859396665710	6af6a3f145b850ce70df188e59cc9a2b	Voyager	26.0261339800838378	-80.2778949009034761
25341	2020-05-17 08:49:55	2020-05-17	Nikolas Kunde	nikolas.kunde@geemail.com	Indianapolis	Indiana	4195904271168	4968dae90a3089e9bc7a7d5990239ea0	Discover	39.7264481002006633	-86.2306741591278438
25342	2020-05-17 08:58:42	2020-05-17	Jeannine Hudson DDS	jeannine.hudson.dds@geemail.com	San Jose	California	3043111412235691	7b32349bd412aaf914e3ae81f887a9ae	JCB 16 digit	37.3590954665847121	-121.770347707181799
25343	2020-05-17 09:25:34	2020-05-17	Gretchen Hansen	gretchen.hansen@warmmail.com	Berkeley	California	3731305464516117	981e471a2e37fa71dfc8a6c2912ba5e9	VISA 16 digit	37.8714860324693845	-122.269777553591766
25344	2020-05-17 09:30:42	2020-05-17	Hakim Upton	hakim.upton@geemail.com	San Francisco	California	210054045170697106	9a06a8343f36b2fba8acea7d4c238288	VISA 16 digit	37.7740415180873512	-122.410381206246214
25345	2020-05-17 09:33:49	2020-05-17	Chance Von	chance.von@geemail.com	Milwaukee	Wisconsin	3024068234964164	7da93cadddf0f8fbe91fcbb7bb51dfb7	Diners Club / Carte Blanche	43.0457117867276082	-88.0476604945592669
25346	2020-05-17 09:56:30	2020-05-17	Branch Borer-Quitzon	branch.borer.quitzon@geemail.com	San Francisco	California	6011133303213043654	1b2cdcff65f5cd488f5fc6b861d86a2b	JCB 16 digit	37.7538604494948373	-122.453803992315969
25347	2020-05-17 09:58:06	2020-05-17	Nadine Kulas-Eichmann	nadine.kulas.eichmann@geemail.com	San Jose	California	6011377033300337777	c53f0d735c2279701402348be60676c7	VISA 13 digit	37.3548603574566584	-121.795677933118867
25348	2020-05-17 10:07:44	2020-05-17	Mrs. Rubi Steuber PhD	mrs.rubi.steuber.phd@geemail.com	Houston	Texas	4742165858553	92d0e766b1c695eaca8007bbdabc894c	JCB 15 digit	29.8476581106506273	-95.4476388352472327
25349	2020-05-17 10:22:55	2020-05-17	Dr. Mikaela Hoppe	dr.mikaela.hoppe@woohoo.com	Dallas	Texas	676374652589313	f8d694ea40597f5753611d2a3dcb2cdb	JCB 16 digit	32.7501434519693291	-96.7781935972124217
25350	2020-05-17 10:23:17	2020-05-17	January Leannon	january.leannon@geemail.com	Killeen	Texas	3730817932955363	34a4315420acea05c342bbd594562251	VISA 16 digit	31.1569602370493115	-97.7423829560335662
25351	2020-05-17 10:55:05	2020-05-17	Dr. Ammon Herman	dr.ammon.herman@warmmail.com	San Francisco	California	3008648339220871	686ed6da1e998280b99513ee6f9d98e7	Voyager	37.781750223981355	-122.409966242115871
25352	2020-05-17 10:59:18	2020-05-17	Elodie Waelchi	elodie.waelchi@geemail.com	Corpus Christi	Texas	3022277693932446	28b2f114987c6675245f55e095fd2b4b	Diners Club / Carte Blanche	27.6690308608517057	-97.1246811326887496
25353	2020-05-17 11:10:54	2020-05-17	Zakary Yundt DVM	zakary.yundt.dvm@geemail.com	San Francisco	California	4332102398061336	f9e013fa329c8e86e6fe53f302d027f8	Mastercard	37.7837379856636559	-122.442068953621217
25354	2020-05-17 11:17:48	2020-05-17	Roy Schmeler II	roy.schmeler.ii@geemail.com	New York	New York	4664812645897088	f03ed3d378be0534925e15c1a797300c	JCB 15 digit	40.6238128455579286	-73.9854581810429721
25355	2020-05-17 11:18:59	2020-05-17	Wallace Sanford	wallace.sanford@geemail.com	Fargo	North Dakota	589343514636448	7c9d8abe95feee7e16bfef8f1922c605	VISA 16 digit	46.940952826593815	-96.7473469343930361
25356	2020-05-17 11:32:43	2020-05-17	Dr. Tobin Weissnat DDS	dr.tobin.weissnat.dds@geemail.com	Rancho Cucamonga	California	4313146023715	4802e42342b4306fe02fd7a9c67d4b92	JCB 15 digit	34.0631524788208324	-117.638669669070097
25357	2020-05-17 11:33:43	2020-05-17	Sabra Harber-Gibson	sabra.harber.gibson@geemail.com	Berkeley	California	4301634939861151	229dd816cb3e5f87a8e8441cb907e780	Diners Club / Carte Blanche	37.867535298688928	-122.291709071724398
25358	2020-05-17 11:37:10	2020-05-17	Lise Larson	lise.larson@geemail.com	New York	New York	3486767956916010	6c7a68f8393ded02aac5fee63f7daeb4	Voyager	40.6998480709958841	-73.8625025756552844
25359	2020-05-17 11:39:25	2020-05-17	Lue Runolfsdottir PhD	lue.runolfsdottir.phd@warmmail.com	San Francisco	California	4391467785680222	89a562fc182b5be30046c6d94b59b66b	Voyager	37.7986738836806495	-122.43544353588733
25360	2020-05-17 11:41:43	2020-05-17	Emmalee Emard	emmalee.emard@geemail.com	San Francisco	California	4971094489646594	113bcb96b0994ca3b2e238a6faa3ebae	JCB 15 digit	37.7709561124662798	-122.43498074585986
25361	2020-05-17 11:47:06	2020-05-17	Mrs. Lizzie Schneider	mrs.lizzie.schneider@geemail.com	San Francisco	California	869935890697622846	30864fd4bf3d42c816554a19d2f9d6a9	American Express	37.7839047040585001	-122.43524610607065
25362	2020-05-17 11:49:15	2020-05-17	Mrs. Dulce Reynolds DVM	mrs.dulce.reynolds.dvm@geemail.com	Thornton	Colorado	3034846852398975	3203abdda3d8f832ca2ff5724bce1e90	Discover	39.9934032611414807	-104.913249777273464
25363	2020-05-17 12:00:49	2020-05-17	Geneva Rowe	geneva.rowe@geemail.com	Memphis	Tennessee	4892056787427	e8f2dd11388aa06a929f2eca74c6c8dc	JCB 16 digit	35.0537277751669336	-89.8856831684034319
25364	2020-05-17 12:06:53	2020-05-17	Chelsea Stiedemann	chelsea.stiedemann@warmmail.com	McAllen	Texas	3055557752341440	2d71f307776a1dcbab827ea4aa98580e	Voyager	26.1564800861597035	-98.2637223944846454
25365	2020-05-17 12:13:18	2020-05-17	Gaynell Raynor-Dach	gaynell.raynor.dach@geemail.com	Austin	Texas	4959523063342	ca84173fd996e400f3b6b12dcbfbd301	VISA 16 digit	30.2775008029896746	-97.6709562863927374
25366	2020-05-17 12:22:52	2020-05-17	Branson Jacobson-Hyatt	branson.jacobson.hyatt@geemail.com	Frisco	Texas	4130890481654660	70a735b593abd36f5765cd696d6b1f95	VISA 16 digit	33.1947209081143129	-96.9046394763257268
25367	2020-05-17 12:32:19	2020-05-17	Robby McClure	robby.mcclure@geemail.com	San Francisco	California	3158614344740216239	2006e7ae63bfb97dab914c274255cf00	Diners Club / Carte Blanche	37.7733686121800503	-122.435420184049818
25368	2020-05-17 12:35:11	2020-05-17	Ardell Braun	ardell.braun@geemail.com	Buffalo	New York	52126449341356382	f211983bea86b1e0e18363045ba71a99	JCB 16 digit	42.8995211458951218	-78.8252537949409344
25369	2020-05-17 12:44:54	2020-05-17	Miss Carlota Cruickshank DVM	miss.carlota.cruickshank.dvm@geemail.com	Albuquerque	New Mexico	4079295678621	53d89594639de0b60769923413e008d8	JCB 16 digit	35.1188177487947044	-106.630697644183044
25370	2020-05-17 12:46:42	2020-05-17	Bret Grant II	bret.grant.ii@woohoo.com	McAllen	Texas	3028798432729037	60df287428edaef0658e7dd6388872ee	Voyager	26.1405786206785571	-98.1873885183908044
25371	2020-05-17 13:00:19	2020-05-17	Alpha Shields	alpha.shields@geemail.com	New York	New York	869933035216768785	fa24d26fea4561c6235bad59dca43765	Maestro	40.5749825299009643	-73.9793075946986676
25372	2020-05-17 13:22:32	2020-05-17	Cal Terry IV	cal.terry.iv@geemail.com	New York	New York	3337346635730128457	3b6fe9618a7c58ecaa72a679149ee460	JCB 16 digit	40.5949870523754512	-73.9926788402616893
25373	2020-05-17 13:30:13	2020-05-17	Kendal Weber PhD	kendal.weber.phd@warmmail.com	San Francisco	California	3776115332059075	84fd0ec4cb93bff34ae1237cf7e566f1	Mastercard	37.7730766443553136	-122.428261834105285
25374	2020-05-17 13:42:58	2020-05-17	Ethan Sipes IV	ethan.sipes.iv@geemail.com	Antioch	California	51246557336062040	c19113d702c5385dd2504d3d4848945e	VISA 16 digit	37.9865889507144701	-121.818574005895101
25375	2020-05-17 13:48:36	2020-05-17	Tawanda Wiza-Waters	tawanda.wiza.waters@warmmail.com	Springfield	Massachusetts	869920503534050454	38cb32c2168afffbe643cca07383ef0e	Voyager	42.1577389735467705	-72.5476090435963243
25376	2020-05-17 13:59:18	2020-05-17	Miss Clara Dach	miss.clara.dach@geemail.com	San Diego	California	6011979214394435444	4b3d850d07a19f5a770d51065b884f3b	Mastercard	32.8484773386802544	-117.214336846852675
25377	2020-05-17 14:26:33	2020-05-17	Sean O'Reilly II	sean.o'reilly.ii@geemail.com	San Diego	California	3158186761164053137	cc2df69ddde438b35a8d291696b456cb	VISA 13 digit	32.8640361787352688	-117.094686199296277
25378	2020-05-17 14:36:08	2020-05-17	Tishie Little-Fritsch	tishie.little.fritsch@geemail.com	Chesapeake	Virginia	3088575488649310309	957cd8ba3c03987fdf803fa3561fe2b0	Discover	36.7389432186033602	-76.3760743990384015
25379	2020-05-17 14:44:56	2020-05-17	Dr. Cary Stroman	dr.cary.stroman@geemail.com	Memphis	Tennessee	6011128567799013359	aed256f9ab6caa66d7ab8b09d95ae44c	JCB 16 digit	35.0619811134945607	-90.0372286441993026
25380	2020-05-17 14:45:39	2020-05-17	Mr. Kadyn Hackett	mr.kadyn.hackett@geemail.com	San Francisco	California	3044221678211945	651d49b7c01a6cc83b422823869fe8e9	JCB 15 digit	37.7975952231328876	-122.469818237588939
25381	2020-05-17 14:51:58	2020-05-17	Ms. Francis Howe	ms.francis.howe@geemail.com	New York	New York	869909569336619759	9cd55b4c36457adb7c3330fd59a50398	VISA 13 digit	40.6064428488481752	-73.9076313789363866
25382	2020-05-17 15:16:35	2020-05-17	Burrel Rutherford	burrel.rutherford@geemail.com	Albuquerque	New Mexico	6011594446518911992	328bcebb01c27ea44125479bf36a584a	Maestro	35.0223532054241744	-106.657255173900722
25383	2020-05-17 15:34:42	2020-05-17	Leyla Considine	leyla.considine@warmmail.com	Frisco	Texas	180082224799318206	bacd358794d74cf85bfb2b9e9831ca1f	VISA 16 digit	33.2073461992196712	-96.7780863180499438
25384	2020-05-17 15:41:43	2020-05-17	Yazmin Hoeger-Wunsch	yazmin.hoeger.wunsch@geemail.com	San Francisco	California	3112004669385886435	4748758379429b2c411cfee0938a9639	JCB 16 digit	37.7700552376108618	-122.448381562229528
25385	2020-05-17 15:42:15	2020-05-17	Calhoun Lang	calhoun.lang@geemail.com	Phoenix	Arizona	3462034988660530	268b51c0c640ad4053f1374df4b3a7fd	Discover	33.6371855165276727	-112.072999549882866
25386	2020-05-17 15:45:41	2020-05-17	Mr. Dallas Runolfsdottir	mr.dallas.runolfsdottir@warmmail.com	West Jordan	Utah	6011677472511364336	3b1d909878d590a0b4558e46652170aa	VISA 16 digit	40.6190447560768604	-112.008673738510538
25387	2020-05-17 15:46:20	2020-05-17	Dixon Schimmel	dixon.schimmel@geemail.com	Inglewood	California	4433132382683900	7a28aa40dea0cc6d906161a23975d996	VISA 16 digit	33.9687631740015021	-118.259405225611488
25388	2020-05-17 15:47:05	2020-05-17	Vincent Thompson	vincent.thompson@geemail.com	New York	New York	6011403629842699711	ef779cc66cc097825440a7e1e524337e	JCB 16 digit	40.6446274575535185	-73.9148415507178669
25389	2020-05-17 15:52:26	2020-05-17	Danna Haley-Schimmel	danna.haley.schimmel@warmmail.com	Houston	Texas	180005096261526910	65f06b2ebd666c6eed40e7930b563479	VISA 16 digit	29.8175978211298585	-95.3711996820770196
25390	2020-05-17 15:58:33	2020-05-17	Dora Stroman	dora.stroman@geemail.com	New York	New York	4066985985310617	029ac8446f50db44d60b8803fd5e4e42	VISA 16 digit	40.617147002438081	-73.9691334981366992
25391	2020-05-17 16:45:21	2020-05-17	Carie Murray	carie.murray@geemail.com	Philadelphia	Pennsylvania	6011638161533959714	8da45f586d6738362e4f84e551276130	JCB 16 digit	40.0033758596941809	-75.1113207255855286
25392	2020-05-17 16:57:17	2020-05-17	Lolita Howe	lolita.howe@geemail.com	Detroit	Michigan	180080364525487438	566c83b873535f0a9aa4c572b60976fb	Diners Club / Carte Blanche	42.3559089550673988	-83.0635593325950197
25393	2020-05-17 17:02:56	2020-05-17	Otha Howell I	otha.howell.i@geemail.com	Oakland	California	4681818480925917	864bc3f5716bba3a5f975338a884ccbe	JCB 15 digit	37.8040450544233053	-122.25968168306531
25394	2020-05-17 17:32:19	2020-05-17	Essex Konopelski	essex.konopelski@geemail.com	Cincinnati	Ohio	3088787309138303825	080b661d85df6ba4444d85aaf5e4c6ab	JCB 16 digit	39.0975846338782489	-84.4915720824889718
25395	2020-05-17 17:32:36	2020-05-17	Ole Rempel	ole.rempel@geemail.com	Escondido	California	3337213562614537209	68b5fd54d8c9df5580be6e60d6af764f	Voyager	33.1943868308089662	-117.146464925609521
25396	2020-05-17 17:37:07	2020-05-17	Alvy Shanahan	alvy.shanahan@geemail.com	Berkeley	California	4166344010730	90865d44c8e9fad21fb10a565dcf3914	Mastercard	37.8860702893721708	-122.25143687328115
25397	2020-05-17 17:37:24	2020-05-17	Dempsey Paucek	dempsey.paucek@geemail.com	New York	New York	3030114492003032	980faef0bbed4aea5a97997adc8f39df	VISA 16 digit	40.6457295034769928	-73.9802949565824122
25398	2020-05-17 17:47:02	2020-05-17	Kelcie Romaguera	kelcie.romaguera@geemail.com	Denver	Colorado	4185956876376450	91b5ef6b90a6ac64ccf36c4a93d99810	Discover	39.8568056833982425	-104.944548630040515
25399	2020-05-17 17:50:07	2020-05-17	Dr. Dyllan Will	dr.dyllan.will@geemail.com	Springfield	Massachusetts	6011632880900583254	2c497837df6376ae3adbe5347894d2db	Diners Club / Carte Blanche	42.1816476653534878	-72.545009408341727
25400	2020-05-17 18:02:57	2020-05-17	Jones Torp	jones.torp@geemail.com	San Francisco	California	869962064301929106	5670a603335a4e76192549dc798bd073	JCB 16 digit	37.7704362150261161	-122.417149205092656
25401	2020-05-17 18:20:57	2020-05-17	Roselyn Nader DDS	roselyn.nader.dds@geemail.com	Berkeley	California	180040645754980666	cbc167b89a056099e6fb40ccc76e17b3	VISA 16 digit	37.8609767911848394	-122.245191608470122
25402	2020-05-17 18:27:30	2020-05-17	Beau Schamberger	beau.schamberger@geemail.com	Tulsa	Oklahoma	6011790704325710987	bfca035fde871f4fd01248b3fa724bf7	VISA 16 digit	36.1990160073056799	-95.870450910595423
25403	2020-05-17 18:41:21	2020-05-17	Eric Koch	eric.koch@warmmail.com	San Francisco	California	55482263013727152	dbb082124c112d8fd5fe6af1543b6927	Mastercard	37.7765916947549414	-122.424709426630741
25404	2020-05-17 18:41:40	2020-05-17	Enola Robel	enola.robel@geemail.com	Louisville	Kentucky	3096600174288934240	b89af3ec6fca50da73d13db66be70cfc	JCB 16 digit	38.0708331090766947	-85.7026859856747194
25405	2020-05-17 18:45:11	2020-05-17	Ms. Annemarie Gibson DVM	ms.annemarie.gibson.dvm@warmmail.com	Las Vegas	Nevada	55240305658447928	ac5ebdc91566730fb3b04d86a3e21024	Mastercard	36.1409723949253561	-115.21342393278367
25406	2020-05-17 19:09:20	2020-05-17	Abbey Stoltenberg DVM	abbey.stoltenberg.dvm@geemail.com	New York	New York	210074851533378029	3687da16b178564b8f065a3a9a63f4a4	Maestro	40.6674820296224198	-74.0122723737627268
25407	2020-05-17 19:11:34	2020-05-17	Mrs. Joanne Cormier	mrs.joanne.cormier@geemail.com	Fontana	California	869985762264810196	92bc0bd02a2b8837e08d478d073853d7	Maestro	34.1078924667704868	-117.383325393898048
25408	2020-05-17 19:11:55	2020-05-17	Shea Boyer	shea.boyer@geemail.com	Berkeley	California	3708020567673363	aa834db93397bdd0299ac85fa43bf571	JCB 16 digit	37.9134193948602203	-122.288902498655503
25409	2020-05-17 19:13:08	2020-05-17	Parlee Herman	parlee.herman@geemail.com	Frisco	Texas	3054784604491048	3de90fc6051c43ffabed5bb65121e13a	VISA 16 digit	33.2199802483428286	-96.9204791623376281
25410	2020-05-17 19:22:25	2020-05-17	Cressie Conroy-Wehner	cressie.conroy.wehner@geemail.com	Madison	Wisconsin	6011566947642427627	fc2f595565708f784e10afee433dec27	JCB 15 digit	42.9968811735019116	-89.3993950073957535
25411	2020-05-17 19:28:58	2020-05-17	Loni Gulgowski	loni.gulgowski@geemail.com	New York	New York	210076121773524957	e35fdfad087946618189dc2385e73eac	Voyager	40.7600160633902959	-74.0105102638609651
25412	2020-05-17 19:34:48	2020-05-17	Makaila Erdman	makaila.erdman@woohoo.com	Berkeley	California	3032209945921034	0a86ba067cf89fb1e1b1955b27e9a931	Diners Club / Carte Blanche	37.8872872030569496	-122.258680368729856
25413	2020-05-17 20:00:01	2020-05-17	Carlyle Stoltenberg-Smitham	carlyle.stoltenberg.smitham@geemail.com	Columbus	Ohio	6011476925933783451	b2efe2c42ec45545304ad59ab9e74943	VISA 16 digit	39.9070660829588775	-82.994758207746969
25414	2020-05-17 20:00:13	2020-05-17	Mckayla Hahn DDS	mckayla.hahn.dds@geemail.com	Mesa	Arizona	52057174375422040	c383af9c151e1c6210db56b00c02dc91	VISA 16 digit	33.4633672373514628	-111.708956227440012
25415	2020-05-17 20:05:06	2020-05-17	Jo Medhurst-Kuvalis	jo.medhurst.kuvalis@woohoo.com	Hayward	California	210074237037627113	2091c4b2f7ce07a0da4a6ccd6147786c	JCB 16 digit	37.580724595253173	-122.044439371002468
25416	2020-05-17 20:17:27	2020-05-17	Asberry Kub	asberry.kub@woohoo.com	Chicago	Illinois	6011759547969647968	e2e3793ac180ed1f44fe3f66204f34f8	Maestro	41.8957829022616153	-87.6730380279973076
25417	2020-05-17 20:45:22	2020-05-17	Melton Roberts	melton.roberts@warmmail.com	Wichita	Kansas	3158934988197015040	91867da100b937f4290b5e00f90c2289	Mastercard	37.664171051547676	-97.3886371553145409
25418	2020-05-17 20:58:03	2020-05-17	Launa Frami DVM	launa.frami.dvm@geemail.com	New York	New York	6011396815326237495	acbb9c38a54c6f429f914ab7af02e5eb	VISA 13 digit	40.6046460535135125	-73.890148451075703
25419	2020-05-17 21:04:34	2020-05-17	Yahaira Boyle	yahaira.boyle@geemail.com	Las Vegas	Nevada	4613902598291	54c5937a88b33a1ef6a13da8016ec69a	Voyager	36.1851200570918579	-115.167005899662513
25420	2020-05-17 21:20:46	2020-05-17	Elberta Gusikowski DVM	elberta.gusikowski.dvm@woohoo.com	Chesapeake	Virginia	869970577301223519	0331faf4bd0bc2fdedd99884c32e7461	VISA 16 digit	36.5983588174223939	-76.2430125838454842
25421	2020-05-17 21:27:45	2020-05-17	Hetty Sporer	hetty.sporer@warmmail.com	Los Angeles	California	3010562259887049	6200c5a24da3e9115934ec3e90b3e32a	Voyager	34.0130743319500226	-118.473555889678366
25422	2020-05-17 21:30:08	2020-05-17	Dudley Goldner	dudley.goldner@geemail.com	Jurupa Valley	California	869999362724798240	b40c623634bf5626b7be0e36bd58f842	Diners Club / Carte Blanche	33.9223137752082238	-117.549970293699204
25423	2020-05-17 21:44:29	2020-05-17	Ms. Karrie Braun MD	ms.karrie.braun.md@woohoo.com	New York	New York	210043997833960087	07ad577aa100e41864374c406312254b	JCB 15 digit	40.602518291886895	-74.0035540990427165
25424	2020-05-17 22:14:44	2020-05-17	Camilo Effertz	camilo.effertz@geemail.com	Long Beach	California	4880714799913521	d2ce299fd33b5bf42ba94a42f5d9e907	VISA 13 digit	33.8972825391970574	-118.070356979237118
25425	2020-05-17 22:20:28	2020-05-17	Mrs. Shalon Johnston	mrs.shalon.johnston@warmmail.com	Washington	District of Columbia	6011424096581056039	c9a9accd7be725ee56cd7d4002c19947	JCB 16 digit	38.8343579016890388	-76.9343880981419233
25426	2020-05-17 22:25:20	2020-05-17	Dr. Dalton Purdy	dr.dalton.purdy@geemail.com	New York	New York	6011630892791370784	06f928e45aee3023261435d3ffabeadc	JCB 15 digit	40.726859078345818	-73.9307817760750652
25427	2020-05-17 22:31:12	2020-05-17	Clifton Langworth	clifton.langworth@geemail.com	Aurora	Colorado	6011258970770786526	b0b2860d72041a2e87a25310ba5e9c92	Discover	39.7457542832121291	-104.648959159443905
25428	2020-05-17 22:32:17	2020-05-17	Leota Wuckert	leota.wuckert@geemail.com	Aurora	Illinois	6011696594875898331	e3c3008a1b859e3fbeb9ffbfd82f7898	JCB 15 digit	41.7491551336124544	-88.269059326166655
25429	2020-05-17 22:48:40	2020-05-17	Amerigo Fadel	amerigo.fadel@geemail.com	Fort Worth	Texas	180089820875169992	a3ba1baad04142494efe846717638084	VISA 16 digit	32.7031833919752373	-97.4117529910344615
25430	2020-05-17 22:52:10	2020-05-17	Anthoney D'Amore	anthoney.d'amore@geemail.com	Charlotte	North Carolina	675924263206435	cafc6701fc8e332c5632a00c0925e1e7	Discover	35.125492124377935	-80.8157900615073714
25431	2020-05-17 22:54:16	2020-05-17	Velva Weimann	velva.weimann@geemail.com	Elgin	Illinois	4263693685566	4511f8b173a2d4384273a93d8f0d255e	JCB 16 digit	42.076558303675057	-88.3893550730131636
25432	2020-05-17 22:55:40	2020-05-17	Manson Schultz	manson.schultz@geemail.com	Baltimore	Maryland	3528249262666479982	150357f2361492104d64cc7e379dec4f	Discover	39.3525839144363943	-76.5765277821589336
25433	2020-05-17 23:03:52	2020-05-17	Dr. Gerri Lockman MD	dr.gerri.lockman.md@warmmail.com	New Orleans	Louisiana	210008494690145872	54a04d903e37022bf925cd86193c8a4a	JCB 15 digit	30.0487418453224002	-89.8790288240909518
25434	2020-05-17 23:34:52	2020-05-17	Miss Glenda Raynor MD	miss.glenda.raynor.md@geemail.com	West Palm Beach	Florida	180051058580488522	809316a327078d93162003ad31d56492	JCB 15 digit	26.7446528154738274	-80.2012069381609649
25435	2020-05-17 23:38:47	2020-05-17	Mr. Brian Hansen I	mr.brian.hansen.i@geemail.com	Philadelphia	Pennsylvania	4132428121199	18ce64e5eafbc546d407874bfb4e963f	JCB 16 digit	40.0298942960757742	-75.0858939027778831
25436	2020-05-17 23:41:30	2020-05-17	Verla Eichmann-Bode	verla.eichmann.bode@geemail.com	Costa Mesa	California	55826702696373524	3e960360fa82df1593bdd37e9589b29a	Discover	33.6209622080918393	-117.885504854177313
25437	2020-05-17 23:50:58	2020-05-17	Debbie Botsford MD	debbie.botsford.md@geemail.com	San Antonio	Texas	4247249619427	3f9a218334476bb2b0b99d2d14e15af2	VISA 16 digit	29.4788773267600703	-98.4491580492187239
25438	2020-05-17 23:52:19	2020-05-17	Yadira Kuhn	yadira.kuhn@geemail.com	Houston	Texas	4443380642662	c0401180c80ef02c5357c0e53673974c	VISA 13 digit	29.7252353815905757	-95.3937947837650739
25439	2020-05-18 00:00:01	2020-05-18	Manervia Adams MD	manervia.adams.md@geemail.com	Paterson	New Jersey	4592347888245403	22f31aa490c9dcb44a2e87cbc28e59db	VISA 13 digit	40.8203284869391467	-74.1218287893544954
25440	2020-05-18 00:02:43	2020-05-18	Tilda Metz-Macejkovic	tilda.metz.macejkovic@woohoo.com	Dallas	Texas	4972173553249	f320cc2127dd5ce012b72ae40f046a8a	Discover	32.8654212584991043	-96.7694752305708761
25441	2020-05-18 00:03:46	2020-05-18	Shianne Kuhn-Mayert	shianne.kuhn.mayert@geemail.com	Nashville	Tennessee	210095961358735933	f5be50ad02ec839f7665f57e4a8b5928	Mastercard	36.1112266344606851	-86.7776004444714602
25442	2020-05-18 00:11:47	2020-05-18	Dr. Claudius McGlynn II	dr.claudius.mcglynn.ii@geemail.com	Phoenix	Arizona	180086958551045442	5e4b97e8e87c39c79c74b6ff890a6d5c	Voyager	33.5928843203399339	-112.023132764727251
25443	2020-05-18 00:15:30	2020-05-18	Adella Haley	adella.haley@geemail.com	Joliet	Illinois	3036625263954966	9e5eff3e6f939f06bc338a9515504c19	VISA 13 digit	41.4548628232765921	-88.0815382110990583
25444	2020-05-18 00:15:42	2020-05-18	Ewell Kutch	ewell.kutch@woohoo.com	Buffalo	New York	53762874299088464	2028cedf4c99dd10d86208fd8744529b	Mastercard	42.9259306146949484	-78.7642020479708975
25445	2020-05-18 00:21:21	2020-05-18	Adin Reinger	adin.reinger@geemail.com	Arlington	Texas	4695193222988	d429577828e8e91c018bc7c81058521d	JCB 16 digit	32.7100591495417063	-97.1183750274151549
25446	2020-05-18 00:21:30	2020-05-18	Nora Gorczany	nora.gorczany@geemail.com	Des Moines	Iowa	4459702340977906	e71829af422aaafa99c3a1521bf0ae9e	JCB 15 digit	41.4931202163197099	-93.6191895364362807
25447	2020-05-18 00:27:43	2020-05-18	Christian Shanahan	christian.shanahan@warmmail.com	Philadelphia	Pennsylvania	4373783469240592	9509fe951a6c3a7532143f893336df3a	VISA 16 digit	39.9809262501034866	-75.0639586148217433
25448	2020-05-18 00:47:07	2020-05-18	Loraine Jerde DDS	loraine.jerde.dds@geemail.com	Riverside	California	3010420291282002	640a98675695e8db845e170c16200016	VISA 16 digit	33.893547415728122	-117.44179785521402
25449	2020-05-18 01:14:34	2020-05-18	Jerold Bayer II	jerold.bayer.ii@geemail.com	Pittsburgh	Pennsylvania	676205422754431	acb009c7229fcebca435c3727096aca3	Diners Club / Carte Blanche	40.5293665930118365	-79.9965230006896064
25450	2020-05-18 01:21:00	2020-05-18	Mr. Less Gulgowski II	mr.less.gulgowski.ii@woohoo.com	Columbus	Ohio	3006545350525513	e018c2accd0c8ee20fa5aee5f148d20e	Maestro	40.0085546064235231	-83.0481828175254293
25451	2020-05-18 01:28:21	2020-05-18	Lexus Cassin	lexus.cassin@geemail.com	San Francisco	California	3040809905202192	d34f02cee1f3cdb1d5587f5e67949999	JCB 16 digit	37.774716586497135	-122.452803474149945
25452	2020-05-18 01:42:56	2020-05-18	Rosella Gislason-Schinner	rosella.gislason.schinner@geemail.com	Houston	Texas	53311191715438942	21d25f918409ee2b436a6b584fac990e	American Express	29.688802144823967	-95.3522362966570967
25453	2020-05-18 01:56:16	2020-05-18	Mr. Montana Kulas	mr.montana.kulas@woohoo.com	Tucson	Arizona	3774311249950504	7a9dfdb5a83130bc1e96ce7d643e819f	Discover	32.0696541454218362	-110.848612467641374
25454	2020-05-18 02:08:24	2020-05-18	Erna Roob-Dooley	erna.roob.dooley@woohoo.com	Bakersfield	California	52314652958712779	d0c2813c9915901e1493fab51a13604d	American Express	35.2218369779352045	-119.024208074695608
25455	2020-05-18 02:17:55	2020-05-18	Vollie Torphy-Schamberger	vollie.torphy.schamberger@geemail.com	San Francisco	California	869970889665660586	92ae478032a3b52ca8b839dd2c16be64	JCB 15 digit	37.7468383719812905	-122.40928945300756
25456	2020-05-18 02:20:57	2020-05-18	Sallie Marks-Stamm	sallie.marks.stamm@geemail.com	Cary	North Carolina	869994292390953057	bfe7eeb35d67e7cf205778adbed2a27f	Diners Club / Carte Blanche	35.7146862147483972	-78.7209443278696313
25457	2020-05-18 02:25:07	2020-05-18	Mrs. Yaritza Auer	mrs.yaritza.auer@geemail.com	Victorville	California	3158687249538952741	2aff21e6653667670de07dc1e6e2d8aa	JCB 16 digit	34.4738759987752914	-117.350942073358596
25458	2020-05-18 02:34:55	2020-05-18	Willian Gislason	willian.gislason@geemail.com	Detroit	Michigan	4303036421707	2ccfbabb969ca0e76448eedb3ee317ac	VISA 16 digit	42.3254632482230662	-83.0928608266290212
25459	2020-05-18 02:54:59	2020-05-18	Dr. Alanna Cummings MD	dr.alanna.cummings.md@geemail.com	Miami	Florida	180044991866829078	c21415ec6110eb0637be91680956e07b	VISA 13 digit	25.8183657989975082	-80.1931740671735298
25460	2020-05-18 02:59:33	2020-05-18	Dave Green	dave.green@geemail.com	Chicago	Illinois	3088624807554068126	1b5d566d75f3b9c9873466a80427ba69	Maestro	41.8773131513338583	-87.7172952490422801
25461	2020-05-18 03:35:08	2020-05-18	Mickey Labadie	mickey.labadie@geemail.com	Los Angeles	California	3477570011887098	e5839c5a1237b99c8a39833e943c2ae2	JCB 16 digit	33.9687262861389669	-118.363266096775604
25462	2020-05-18 03:36:08	2020-05-18	Lisa Marvin	lisa.marvin@geemail.com	Hollywood	Florida	3018497208577304	4dfbcdbfade9b1470a053a26bc41be1c	Diners Club / Carte Blanche	26.1243473272249105	-80.1651395858082907
25463	2020-05-18 04:07:38	2020-05-18	Mrs. Harriette Gorczany	mrs.harriette.gorczany@warmmail.com	San Jose	California	180087431717981727	e342e1fdbc537e462316000dd0fef7ad	American Express	37.3607621940605341	-121.749261218238246
25464	2020-05-18 04:13:16	2020-05-18	Odis Sawayn	odis.sawayn@geemail.com	San Francisco	California	180061291978424035	01fbe8e958b17cbd257f3a4e577b0a79	Diners Club / Carte Blanche	37.7840265091166003	-122.438305342814203
25465	2020-05-18 04:15:16	2020-05-18	Malorie Kertzmann	malorie.kertzmann@geemail.com	Abilene	Texas	180035542538926940	133195a7fc9e8958efc77b2a2ab30189	VISA 16 digit	32.4900110762640892	-99.6524079453613609
25466	2020-05-18 04:25:39	2020-05-18	Aubrey McKenzie	aubrey.mckenzie@warmmail.com	Phoenix	Arizona	6011773291751683947	f47712a4c6e42d06ee8947feef26da93	VISA 16 digit	33.4897657280720793	-112.162075765377296
25467	2020-05-18 04:26:58	2020-05-18	Bartholomew Murray	bartholomew.murray@geemail.com	Dallas	Texas	3528651560865873488	6980f1ac5c197fd1c7eb48fcbbb5a3be	American Express	32.7834688363868736	-96.7748345022052519
25468	2020-05-18 04:29:58	2020-05-18	Dr. Mackenzie Roberts Sr.	dr.mackenzie.roberts.sr.@geemail.com	Houston	Texas	3764282115500255	73b8d73fae6dd432d56dfa3ca61a9811	Diners Club / Carte Blanche	29.8763168784867972	-95.3419741328354888
25469	2020-05-18 04:39:44	2020-05-18	Emmalee Gulgowski	emmalee.gulgowski@geemail.com	San Francisco	California	3528931970792989145	59942899338265864be21c2c7394f707	VISA 16 digit	37.7680641418932623	-122.407882635252918
25470	2020-05-18 04:48:23	2020-05-18	Giovani McGlynn	giovani.mcglynn@warmmail.com	Los Angeles	California	4033397604944	d430fbc6741920ec65a498ff8e19eb6a	JCB 16 digit	33.9676747273053934	-118.348722286940728
25471	2020-05-18 05:18:33	2020-05-18	Oney Larson	oney.larson@geemail.com	New York	New York	869948750844371264	1efdd960b2baaada61b573e15ec1c5b2	Diners Club / Carte Blanche	40.6968655302412827	-73.9824188949901611
25472	2020-05-18 05:37:52	2020-05-18	Ms. Maleah Ortiz	ms.maleah.ortiz@geemail.com	Charlotte	North Carolina	3773202999990116	d7b5e12ca79d8f202db5e0b51b3b7ae0	Mastercard	35.3069376755759095	-80.8550345184225563
25473	2020-05-18 05:39:55	2020-05-18	Julie Emard-Kuhlman	julie.emard.kuhlman@geemail.com	Savannah	Georgia	3711546703251784	642a68a5e4e5acd340e84aacfc23a382	Maestro	31.9215905954688779	-81.1245939832799081
25474	2020-05-18 05:39:58	2020-05-18	Bartholomew Nienow MD	bartholomew.nienow.md@geemail.com	Tulsa	Oklahoma	180049119321964109	69ec43ea0694cda64e8d96aa27089de6	American Express	36.0581242171484959	-95.858885743650788
25475	2020-05-18 05:56:19	2020-05-18	Arlie Bogan	arlie.bogan@woohoo.com	San Antonio	Texas	869902869602179109	21957a6fdda01a34f7417985dd36b5e2	Maestro	29.4732411995135237	-98.4474083162680245
25476	2020-05-18 06:06:51	2020-05-18	Blaze Bogan	blaze.bogan@geemail.com	Oklahoma City	Oklahoma	6011695898102157903	5c69762436576f707864a38c8844d5e8	JCB 16 digit	35.4529966302126667	-97.4415118792455672
25477	2020-05-18 06:07:21	2020-05-18	Margie Bernhard	margie.bernhard@geemail.com	Vallejo	California	6011176769892576529	af8f26c86ad0318784bb26ecf9519a38	VISA 16 digit	38.0508072360042462	-122.228396329969158
25478	2020-05-18 06:09:14	2020-05-18	Lillia Bode-Kemmer	lillia.bode.kemmer@geemail.com	Riverside	California	4858897886864166	95bd9da3e7a15c68c5c90eb5ea0f4bcf	VISA 16 digit	33.8921861871559145	-117.407866706603016
25479	2020-05-18 06:21:12	2020-05-18	Claude Hilpert	claude.hilpert@geemail.com	Jacksonville	Florida	3158831270535278232	3e4bac31a89d9601726c29375777d43f	VISA 16 digit	30.396587739843504	-81.7396309094116162
25480	2020-05-18 06:31:23	2020-05-18	Encarnacion Halvorson	encarnacion.halvorson@geemail.com	Toledo	Ohio	3042488913165671	080927d22a6653fccbd8c44eb7d37895	Voyager	41.6556037496015392	-83.5493498023465264
25481	2020-05-18 06:32:50	2020-05-18	Delbert Bayer	delbert.bayer@geemail.com	San Antonio	Texas	3498763312896521	356c0d85acf3a9d218419b51170da638	Maestro	29.4631351614441712	-98.4284008015714562
25482	2020-05-18 06:41:55	2020-05-18	Ms. Altha Emmerich	ms.altha.emmerich@geemail.com	Plano	Texas	210095637948179408	468e4bbe88d10369461d6a3eaa1e1782	Diners Club / Carte Blanche	33.0412294104315336	-96.716621415288742
25483	2020-05-18 06:44:39	2020-05-18	Lisette Fahey-Moen	lisette.fahey.moen@warmmail.com	New York	New York	6011474431733158434	6842abd3534d9df1f2d57ac1a0ff6d0f	Voyager	40.5666141500920077	-73.9713452395878761
25484	2020-05-18 06:45:10	2020-05-18	Neely Schuppe	neely.schuppe@geemail.com	Huntsville	Alabama	3528280984694142478	68c5b62dbfea07ca6a0002d80e9de163	Diners Club / Carte Blanche	34.7429075886271903	-86.6327072425298468
25485	2020-05-18 06:46:00	2020-05-18	Orpha Schiller	orpha.schiller@geemail.com	Sacramento	California	3470619678890825	e6c46542436c2102441dd09d305a9360	JCB 15 digit	38.6323719419337834	-121.446163946694128
25486	2020-05-18 06:46:30	2020-05-18	Eveline Oberbrunner	eveline.oberbrunner@geemail.com	Lexington	Kentucky	3112387264750784907	2fa7c964e36799073234939f6e6483b5	Maestro	37.9415878284133967	-84.3908138073880139
25487	2020-05-18 06:58:34	2020-05-18	Louis Flatley	louis.flatley@geemail.com	Louisville	Kentucky	4086230565818275	94a6ec624742a12d81215a8fa78bd7e2	VISA 13 digit	38.1100296553127436	-85.6680306210253377
25488	2020-05-18 07:06:01	2020-05-18	Flora Dare	flora.dare@geemail.com	Oakland	California	4452187754534624	71f4a845e48acd30725bb0110dd29d45	JCB 16 digit	37.7964707281613386	-122.267136569663563
25489	2020-05-18 07:08:14	2020-05-18	Kade Kerluke-Sawayn	kade.kerluke.sawayn@geemail.com	Berkeley	California	3088328388577108297	0e0edb4826fab99717badccae0f1fb1d	Discover	37.8998096656956278	-122.272976738004161
25490	2020-05-18 07:12:31	2020-05-18	Shreya Hyatt	shreya.hyatt@geemail.com	Yonkers	New York	869923513946842353	c6bd296a95112f232bc1761697d6b855	American Express	41.034829065363482	-73.953700680786369
25491	2020-05-18 07:28:16	2020-05-18	Ara Turner-Daugherty	ara.turner.daugherty@geemail.com	Honolulu	Hawaii	3733253534674029	1646f81b63ee98d7a9f466648c3d8f98	Discover	21.3708611589141206	-157.775955285292497
25492	2020-05-18 07:41:28	2020-05-18	Dr. Madyson Zieme DDS	dr.madyson.zieme.dds@geemail.com	Honolulu	Hawaii	503819094221413	13484240aaf86957da731d358424095b	JCB 15 digit	21.2746021085169161	-157.877364704965061
25493	2020-05-18 07:44:13	2020-05-18	Harriet Altenwerth	harriet.altenwerth@geemail.com	Salt Lake City	Utah	52339005291295583	22b86fb03bd8d0e337d7b08065364d70	VISA 16 digit	40.8206021728139348	-111.857795188290993
25494	2020-05-18 07:52:41	2020-05-18	Hobert Nader	hobert.nader@geemail.com	San Francisco	California	4834806768943	7f8184745b51ce3dc0ad8304dbd849e5	VISA 16 digit	37.7895064853096514	-122.427487591074808
25495	2020-05-18 08:03:44	2020-05-18	Mannie Effertz	mannie.effertz@geemail.com	Overland Park	Kansas	6011205663638721629	c061af4dfce13dc98c3ba84dd056efa6	Maestro	38.8157007414251609	-94.6421943862032151
25496	2020-05-18 08:15:13	2020-05-18	Montel Kris III	montel.kris.iii@geemail.com	Boston	Massachusetts	3019646919918418	651ca350377d25ccc0e4cb0f9ce97d4a	Discover	42.2876305058300517	-71.1187107892658616
25497	2020-05-18 08:33:27	2020-05-18	Tayshaun Macejkovic MD	tayshaun.macejkovic.md@geemail.com	Seattle	Washington	4686952280318877	1210eb38855acd3e5965bcc6b1a085f1	Maestro	47.5330339091289815	-122.432050441197674
25498	2020-05-18 08:43:04	2020-05-18	Mr. Robin Leannon	mr.robin.leannon@geemail.com	Phoenix	Arizona	6011485877227923427	ddef0e86a365a01198d4019b6a2779d3	JCB 15 digit	33.5916038608577097	-112.111614702728019
25499	2020-05-18 08:44:56	2020-05-18	Nathanael McCullough	nathanael.mccullough@geemail.com	Gilbert	Arizona	3799195562825000	f181675febf0699a35dc824089e635f5	JCB 16 digit	33.3763865396261181	-111.664081548773126
25500	2020-05-18 08:47:38	2020-05-18	Vinie Kerluke MD	vinie.kerluke.md@warmmail.com	San Francisco	California	3088804126630440304	9d453436504fd1e9719c521ef52a2678	Discover	37.752613113259379	-122.443355777375373
25501	2020-05-18 08:48:25	2020-05-18	Mr. Lamont Gerlach DDS	mr.lamont.gerlach.dds@geemail.com	San Francisco	California	3337867767617991514	c32be3df051b901f67899254a7c73dff	VISA 16 digit	37.7793839403868503	-122.428450084415744
25502	2020-05-18 08:50:41	2020-05-18	Jayme Gutkowski	jayme.gutkowski@geemail.com	Colorado Springs	Colorado	869973925574062584	7528a4b57de49044dee59ac113b09161	Diners Club / Carte Blanche	38.9300336580306308	-104.679245974232259
25503	2020-05-18 09:07:49	2020-05-18	Julien Bayer IV	julien.bayer.iv@geemail.com	New York	New York	3760708672992521	6ac016bcfcfc867ff6e9b07e4c835f8e	JCB 16 digit	40.6244031516127251	-73.8989156373206555
25504	2020-05-18 09:21:46	2020-05-18	Palmer Satterfield	palmer.satterfield@geemail.com	San Francisco	California	51771677591385960	e736913131bb2f236a32259ccb1f5989	JCB 16 digit	37.732050528898192	-122.442126659440632
25505	2020-05-18 09:26:25	2020-05-18	Ms. Carlyn Lehner MD	ms.carlyn.lehner.md@warmmail.com	Orlando	Florida	675904785585060	9f998a0004853a23ba0403014226edd4	JCB 15 digit	28.4832708530858163	-81.2330389026053297
25506	2020-05-18 09:26:58	2020-05-18	Tracey Ondricka-Bogisich	tracey.ondricka.bogisich@geemail.com	New York	New York	869974720243143298	faf406dae4c22011ec40fd67865667c3	Discover	40.6700789191052294	-73.9129930241860365
25507	2020-05-18 09:46:56	2020-05-18	Dr. Marcy Smith	dr.marcy.smith@warmmail.com	Norfolk	Virginia	3023994784618242	26676626ecf142c804a472db41b8be69	Mastercard	36.9484662684630649	-76.2015081566762262
25508	2020-05-18 09:53:04	2020-05-18	Dagmar Nicolas	dagmar.nicolas@woohoo.com	Oakland	California	4751223186649512	7ab625bfe2f864c39d9f6c7b200ccdba	Maestro	37.7859164853335017	-122.262667151841882
25509	2020-05-18 10:09:57	2020-05-18	Dr. Almeda Schamberger	dr.almeda.schamberger@geemail.com	Fayetteville	North Carolina	675969201916223	9668334bdafd2f715a0c6c74f69fc307	Mastercard	35.0528160334352421	-78.8920208329930972
25510	2020-05-18 10:12:36	2020-05-18	Eustace Wolf	eustace.wolf@geemail.com	Colorado Springs	Colorado	6011159821996732838	fb8aab5c6d6f0261432a6b499e474a16	VISA 13 digit	38.8826209588956075	-104.763128292110565
25511	2020-05-18 10:16:23	2020-05-18	Kaia McDermott	kaia.mcdermott@woohoo.com	San Francisco	California	4711228011773	173d19281863f4547af98363910a0fc2	American Express	37.7676629769694259	-122.427720084993481
25512	2020-05-18 10:20:20	2020-05-18	Jabez Eichmann	jabez.eichmann@woohoo.com	Pomona	California	52221165465107971	a2e6530c2a747b0232729aa44d6427e7	American Express	33.9659138352181813	-117.812547944296526
25513	2020-05-18 10:36:52	2020-05-18	Mordechai Beer	mordechai.beer@geemail.com	New York	New York	180071385841411852	a11d01e4aa243a516f0e84a3a9207cc8	Diners Club / Carte Blanche	40.6450754674375077	-73.9798671674810322
25514	2020-05-18 10:38:35	2020-05-18	Griselda Lang	griselda.lang@woohoo.com	New York	New York	54993793540299657	018d40a16bbe08e421566ef4a03a69ae	JCB 15 digit	40.6024743329957118	-73.950908452494815
25515	2020-05-18 10:59:39	2020-05-18	Waldo Steuber	waldo.steuber@geemail.com	Gilbert	Arizona	3158666400372876331	ddd8665525f66e4e49a4218dbf944b21	Discover	33.3661518585748951	-111.787703007473056
25516	2020-05-18 11:14:15	2020-05-18	Dr. Reuben Borer	dr.reuben.borer@geemail.com	San Francisco	California	6011425511083814718	d0c16b41f90a2e77602d4bd176f33414	JCB 16 digit	37.7810958655932367	-122.41529630826804
25517	2020-05-18 11:16:20	2020-05-18	Jethro Watsica Sr.	jethro.watsica.sr.@geemail.com	New York	New York	3112659172738154476	a31dade00280b064138c822556cc726d	American Express	40.7479468603841966	-73.9655906194716692
25518	2020-05-18 11:19:31	2020-05-18	Ayleen Huel	ayleen.huel@geemail.com	Sacramento	California	3427577868141066	9cfe1fc4a5e35a9f423f9ce22e7ee679	Discover	38.6176053549893226	-121.479076030036808
25519	2020-05-18 11:22:27	2020-05-18	Mr. Lavar Hyatt II	mr.lavar.hyatt.ii@woohoo.com	Baton Rouge	Louisiana	869987486176299110	581c022ca2de5873d4440a2dcd95b876	Diners Club / Carte Blanche	30.496387151556835	-91.0952691624514728
25520	2020-05-18 11:25:59	2020-05-18	Inez Kuhlman	inez.kuhlman@geemail.com	Charlotte	North Carolina	3337187913697235751	8c9bb1b3f45283170c4c644299f9dbf8	Mastercard	35.2650548221796711	-80.8296024599522411
25521	2020-05-18 11:29:17	2020-05-18	Sherie Herzog	sherie.herzog@geemail.com	Birmingham	Alabama	3088557301050826097	eafe7ef51210275285af56c632cc845e	American Express	33.4516858008947224	-86.8698642152603782
25522	2020-05-18 11:35:30	2020-05-18	Pink Waters-Ruecker	pink.waters.ruecker@geemail.com	Greensboro	North Carolina	4909277249435369	13f8110002f64a5df02c015488420786	Discover	36.0856908723361798	-79.8455894744470669
25523	2020-05-18 11:40:26	2020-05-18	Tiarra Corkery	tiarra.corkery@geemail.com	Charlotte	North Carolina	6011549579073856875	2603a520090ba1ed50cc1ced390e48ac	JCB 16 digit	35.2358190816149133	-80.923997016850862
25524	2020-05-18 11:42:00	2020-05-18	Orlando Jones DVM	orlando.jones.dvm@geemail.com	Chicago	Illinois	3055967817430429	75b09034fb02a94bd7031f8d16b999d5	VISA 16 digit	41.7620761412963262	-87.6500939925696656
25525	2020-05-18 11:44:13	2020-05-18	Dr. Laquan Rodriguez	dr.laquan.rodriguez@geemail.com	San Francisco	California	4184081384515	75d9ba814264bea06d0605731d3c604d	JCB 15 digit	37.7730005822391135	-122.417869563884352
25526	2020-05-18 11:48:04	2020-05-18	Dandre Grant Jr.	dandre.grant.jr.@geemail.com	Oakland	California	3088612946622429243	093284200325698797d0dc2efe3c09fc	Discover	37.8044123602592776	-122.289542351454088
25527	2020-05-18 11:52:33	2020-05-18	Demetrios Tromp-Schroeder	demetrios.tromp.schroeder@geemail.com	Vancouver	Washington	4925916324492221	f17747954e9d1bc4993204e40fe50413	JCB 16 digit	45.6293518910720977	-122.619429566019022
25528	2020-05-18 11:58:26	2020-05-18	Maranda Beer-Yundt	maranda.beer.yundt@geemail.com	New Orleans	Louisiana	6011622753286171857	5297b8b10c57ae054ed7ab96a1a46c2d	JCB 16 digit	30.1344681665781877	-89.9865389540586591
25529	2020-05-18 12:10:16	2020-05-18	Fredy Bailey	fredy.bailey@woohoo.com	Tulsa	Oklahoma	869900295281212577	eadd8623b1700745f709bcd2bb292a27	JCB 16 digit	36.1795783762257486	-95.8862630990754781
25530	2020-05-18 12:24:49	2020-05-18	Vicky Wisoky	vicky.wisoky@geemail.com	Milwaukee	Wisconsin	4199116988510	40f491a513b27e46bb97ffd1584b56de	American Express	43.1307237135332073	-88.0536764960836678
25531	2020-05-18 12:42:03	2020-05-18	Roswell Dickens	roswell.dickens@geemail.com	Chicago	Illinois	869919174905083145	e7fab90be5a290e694ddd84fa9bd2494	Discover	41.7535043628256801	-87.7806577327691002
25532	2020-05-18 12:49:58	2020-05-18	Valarie Gutkowski	valarie.gutkowski@geemail.com	San Francisco	California	3702699262405167	1887735d6b5f26b8b5aee6d88823b3e7	VISA 13 digit	37.755592345874966	-122.420770306588395
25533	2020-05-18 12:56:30	2020-05-18	Justice Reinger	justice.reinger@geemail.com	Oxnard	California	4507378256596881	78eb2f1d3772e1d96f8a8d199ae702fb	American Express	34.2886760563544968	-119.149812138304483
25534	2020-05-18 13:06:16	2020-05-18	Dr. Lahoma Hagenes PhD	dr.lahoma.hagenes.phd@geemail.com	Detroit	Michigan	3014811510028836	8a37d4ea7c8e07e3d234f17794b957bc	Mastercard	42.3265493519995388	-83.0554696159556443
25535	2020-05-18 13:18:50	2020-05-18	Madalyn West MD	madalyn.west.md@geemail.com	Spokane	Washington	3709395157379434	7b2655c3b53eed7aa21832dc6e7cebe1	VISA 16 digit	47.7561550349235517	-117.411687826075777
25536	2020-05-18 13:25:43	2020-05-18	Emilio Altenwerth	emilio.altenwerth@geemail.com	Albuquerque	New Mexico	3158332237715206469	3347f79258fd81dab1eeeb4ad17f2ecf	JCB 15 digit	35.077052752174815	-106.5870327932831
25537	2020-05-18 13:37:53	2020-05-18	Gwenda Crona	gwenda.crona@geemail.com	Miami	Florida	3158446680354165467	da8b30452f7088b4b2a92b3552d1a8b2	Mastercard	25.685414974265548	-80.2791619137268526
25538	2020-05-18 13:47:51	2020-05-18	Rocky Harber	rocky.harber@geemail.com	San Diego	California	180054369498936073	07028c1a163dcc061ca5840401df820c	VISA 13 digit	32.8795068526241963	-117.164073125729345
25539	2020-05-18 13:49:47	2020-05-18	Governor Mraz-Hintz	governor.mraz.hintz@geemail.com	Colorado Springs	Colorado	060430284962831	67208386d7b9ec6aaa59852ce8848567	VISA 16 digit	38.8966338556773934	-104.747672774891186
25540	2020-05-18 13:55:46	2020-05-18	Miss Janiyah Hansen	miss.janiyah.hansen@geemail.com	Los Angeles	California	4801297701923	9c05700c12330cd8c15dd8540d394e12	Maestro	34.1003384148567861	-118.503910055942086
25541	2020-05-18 14:05:33	2020-05-18	Vanessa Streich DDS	vanessa.streich.dds@geemail.com	Lowell	Massachusetts	3002988153340132	88dc139a241efd347e70f4ccc7211967	Discover	42.7264833177775145	-71.2312606040727303
25542	2020-05-18 14:08:04	2020-05-18	Bertram Kessler	bertram.kessler@geemail.com	Athens	Georgia	4229512367373247	4c2487639c3e8cc62bab5a7d1e058616	Mastercard	33.9198499365434003	-83.2761452577192216
25543	2020-05-18 14:13:41	2020-05-18	Geraldine Smitham	geraldine.smitham@geemail.com	Stockton	California	3112759763393224627	99af2748bc2f3a997763d892297acd3d	Maestro	37.996721381620695	-121.295511789768184
25544	2020-05-18 14:23:47	2020-05-18	Blossom Hackett DDS	blossom.hackett.dds@geemail.com	San Francisco	California	4133247363640	63d604be9fe890df8e075cb2b92f41b8	VISA 13 digit	37.7702294748854399	-122.448629219902685
25545	2020-05-18 14:24:46	2020-05-18	Miss Jasmyne Jerde MD	miss.jasmyne.jerde.md@geemail.com	Raleigh	North Carolina	3528934021726072249	d9345278193db19154dbb67feeba47a9	American Express	35.8444466215692401	-78.6173702299997217
25546	2020-05-18 14:35:45	2020-05-18	Dr. Keshaun Hessel PhD	dr.keshaun.hessel.phd@geemail.com	San Francisco	California	3056254481054226	f8b7826865cb7a19339ff8d604c90c65	VISA 16 digit	37.7911801613638545	-122.450488496913948
25547	2020-05-18 14:39:37	2020-05-18	Deeann Mosciski	deeann.mosciski@geemail.com	Norfolk	Virginia	6011744369663664019	6414a9ec4e0725c510b9d7e1becd1af9	JCB 16 digit	36.9741606745887594	-76.2043874511033295
25548	2020-05-18 14:44:49	2020-05-18	Antione Hayes	antione.hayes@warmmail.com	Oakland	California	4559269656882210	45cb14c101c823816fd4cd7ba27d4934	VISA 16 digit	37.8337481789299517	-122.273270147494173
25549	2020-05-18 14:46:36	2020-05-18	Mrs. Dominque Altenwerth DVM	mrs.dominque.altenwerth.dvm@warmmail.com	New York	New York	4217568826226	2fd1e99fef738d57a1ed1ec52629cb5c	JCB 16 digit	40.6207117281146353	-73.8590620955347958
25550	2020-05-18 14:51:08	2020-05-18	Dr. Cristina Lueilwitz MD	dr.cristina.lueilwitz.md@geemail.com	Renton	Washington	55264165113434643	4afdde1f16b06838b5b1ad09be39dc90	JCB 16 digit	47.4805386851135651	-122.159561702104284
25551	2020-05-18 14:55:26	2020-05-18	Julian Bergstrom	julian.bergstrom@geemail.com	Chula Vista	California	869903072675962373	cb299e8c37abcb3d23811e61f5b3582a	Discover	32.5789322801165255	-116.934333987789969
25552	2020-05-18 14:57:45	2020-05-18	Florance Roberts	florance.roberts@geemail.com	Anchorage	Alaska	869984803848051971	38e83cc1ec37ed1143d0f1fcd037899e	Mastercard	61.2064100513450811	-149.378421022056784
25553	2020-05-18 15:04:53	2020-05-18	Estella Koelpin	estella.koelpin@geemail.com	Houston	Texas	4625631479064	131f6c6fc34beb27f29b4879a024f5b9	Discover	29.8618657474484301	-95.3239978884361676
25554	2020-05-18 15:12:57	2020-05-18	Dr. Annabell Cormier MD	dr.annabell.cormier.md@woohoo.com	Naperville	Illinois	180045684940026006	0dc6966fdbe025a222f4b6549fee4aef	Voyager	41.7296140817374024	-88.0804243207797413
25555	2020-05-18 15:27:55	2020-05-18	Gustavus Beer	gustavus.beer@geemail.com	Minneapolis	Minnesota	3046354054194290	95019f9dffcbeda3c83637415637cfab	Discover	45.0417905188716929	-93.3217332192037219
25556	2020-05-18 15:48:56	2020-05-18	Clora Ryan	clora.ryan@geemail.com	Los Angeles	California	869929138600693654	81de84d0f19b048f3caac5b8fcbbffb2	Maestro	33.9645218561269289	-118.383021188852553
25557	2020-05-18 15:54:47	2020-05-18	Izayah Bernhard	izayah.bernhard@warmmail.com	Los Angeles	California	3096171467194260919	fc6d155ea6c6d2b5fe4dd66af07fae18	JCB 16 digit	34.0497997428156438	-118.385368828847248
25558	2020-05-18 16:01:15	2020-05-18	Miss Marti Mayert PhD	miss.marti.mayert.phd@warmmail.com	Milwaukee	Wisconsin	3088799136692874255	925cfeb6462c119d98a2b9134890cd94	VISA 16 digit	42.9740645573560158	-87.9103272426042679
25559	2020-05-18 16:07:28	2020-05-18	Arlin O'Reilly DVM	arlin.o'reilly.dvm@geemail.com	Los Angeles	California	4670763673340	8ebee959005191ee21d90f28c4a89ca0	JCB 16 digit	34.1068688815325487	-118.444390787230049
25560	2020-05-18 16:09:24	2020-05-18	Merrily Brakus	merrily.brakus@geemail.com	Nashville	Tennessee	54628236342639707	88ff3fa20b6ea32b0acb2e7cbdee5741	VISA 16 digit	36.1378799587145423	-86.7653495396859853
25561	2020-05-18 16:10:14	2020-05-18	Kimberly Rippin	kimberly.rippin@geemail.com	Glendale	Arizona	3088655931300855792	9d8e85c28cc0d8669bae6850ce802ca1	Discover	33.5212845859345023	-112.195085290798545
25562	2020-05-18 16:19:34	2020-05-18	Mr. Troy Dibbert	mr.troy.dibbert@geemail.com	Los Angeles	California	639050386543461	a57c7c231d34373eba36d3302b329679	VISA 16 digit	34.0360024513542641	-118.397506869816397
25563	2020-05-18 16:23:25	2020-05-18	Gladis Johnston	gladis.johnston@woohoo.com	Aurora	Colorado	4035024239055451	c182ed84ea49e6dbbfce021b8b02e970	JCB 15 digit	39.6371084210109004	-104.7224358846087
25564	2020-05-18 16:23:39	2020-05-18	Crysta Bergstrom-Pouros	crysta.bergstrom.pouros@geemail.com	New York	New York	4482132403871203	8b9cf649a5a50a87945d7456f0cc0b79	Discover	40.7005799709111429	-73.9321450451750337
25565	2020-05-18 16:24:50	2020-05-18	Lila Lebsack	lila.lebsack@warmmail.com	Cincinnati	Ohio	4414182035543459	4df9d8c3d857ad1328f2b365359da4d0	Diners Club / Carte Blanche	39.2330789557423429	-84.54112411437481
25566	2020-05-18 16:35:52	2020-05-18	Treva Konopelski	treva.konopelski@warmmail.com	New Orleans	Louisiana	3158734604605975590	08072f606ec79dfd745543abfdccd394	Maestro	30.1294446151718489	-89.9053653395529864
25567	2020-05-18 16:44:45	2020-05-18	Nery Bauch	nery.bauch@geemail.com	Clovis	California	180070612200642822	614e3598967bfc641c46f1d4392a37f1	American Express	36.8070611891679462	-119.663921319048484
25568	2020-05-18 16:47:43	2020-05-18	Veronica Thompson	veronica.thompson@warmmail.com	Vancouver	Washington	3731368600750727	a201924b91576fa784843f66e9b1d65f	Voyager	45.6031012487668548	-122.649988834007445
25569	2020-05-18 16:47:52	2020-05-18	Lorraine Pagac	lorraine.pagac@geemail.com	Honolulu	Hawaii	6011708698133395133	3f8bee400c8fed49c9449acec86ef4e3	Discover	21.4168861616618926	-157.777756271392491
25570	2020-05-18 16:57:47	2020-05-18	Dr. Hector Wunsch	dr.hector.wunsch@woohoo.com	Fort Wayne	Indiana	52033566396536899	c77cddcf14615f6a78728ecf0bf7b863	VISA 13 digit	41.0573606477834261	-85.0504263651311447
25571	2020-05-18 17:10:57	2020-05-18	Malachi Bernhard	malachi.bernhard@warmmail.com	San Francisco	California	4904656873588	236725bad2fdf15f27516cf0874c7a91	Diners Club / Carte Blanche	37.7697483171034492	-122.430483939851925
25572	2020-05-18 17:11:03	2020-05-18	Ms. Felecia Ondricka	ms.felecia.ondricka@woohoo.com	San Francisco	California	3715290066434614	ee508c7f2a754fb9b4812f1cf508c192	JCB 16 digit	37.7953924338024265	-122.443572560200877
25573	2020-05-18 17:13:44	2020-05-18	August Casper Jr.	august.casper.jr.@warmmail.com	Olathe	Kansas	6011869304631841802	1557cceeb225558d7640203c49b7398e	Discover	38.9303365137085322	-94.7312088868282842
25574	2020-05-18 17:15:06	2020-05-18	Mr. Kamden Morissette	mr.kamden.morissette@geemail.com	Washington	District of Columbia	869984108561973249	1b98ac2c6b8cf2ca9f37366326e2075b	JCB 15 digit	38.9312811928600055	-77.0172270413700488
25575	2020-05-18 17:19:25	2020-05-18	Shan Jaskolski	shan.jaskolski@geemail.com	Chicago	Illinois	6011127676350537234	b22932953b53fc47810f4fa8ec1eb369	Diners Club / Carte Blanche	41.9111855035483885	-87.7710320622224316
25576	2020-05-18 17:19:45	2020-05-18	Miss Prudence Hauck DDS	miss.prudence.hauck.dds@geemail.com	Visalia	California	3088435761073457485	b99bda384a71bd7ff668dcb8373674ce	JCB 16 digit	36.3588334582701336	-119.297376875312636
25577	2020-05-18 17:34:44	2020-05-18	Cheyenne Schuster-Langosh	cheyenne.schuster.langosh@geemail.com	Berkeley	California	4188295983414814	0eb22e708ca6cc84c242e16844c6a017	American Express	37.8841144998801553	-122.292291948780814
25578	2020-05-18 17:38:48	2020-05-18	Shari Bogisich	shari.bogisich@woohoo.com	Glendale	Arizona	3096795606258055709	a6d90ca3eb313ea315696d8ddd0e7ce6	VISA 16 digit	33.5406950130820221	-112.107747068607807
25579	2020-05-18 17:42:38	2020-05-18	Cruz Durgan	cruz.durgan@geemail.com	Philadelphia	Pennsylvania	4242317642203	c0473a0ce64b424d63778a74daf49c99	American Express	40.1003365546423964	-75.0737832400847225
25580	2020-05-18 17:44:16	2020-05-18	Jacey Reichert DDS	jacey.reichert.dds@geemail.com	San Francisco	California	3003693751332361	c052ffd38da645baea3c04047c20764b	JCB 16 digit	37.7534129209396241	-122.413489704594227
25581	2020-05-18 17:46:52	2020-05-18	Nicole Kovacek	nicole.kovacek@warmmail.com	St. Louis	Missouri	6011037046119845089	4974633426bc4503b377917869541523	JCB 16 digit	38.724521964850652	-90.2860121789857857
25582	2020-05-18 17:48:47	2020-05-18	Hosteen Christiansen Sr.	hosteen.christiansen.sr.@geemail.com	New York	New York	6011894586391093702	27e2069b14171c59c57bc8dbf593de2c	Voyager	40.5662075065765535	-74.0186369011539966
25583	2020-05-18 17:50:48	2020-05-18	Dock Monahan	dock.monahan@geemail.com	Clearwater	Florida	502027680462051	71eede535a080fd547274ca4191c448a	Diners Club / Carte Blanche	27.968110536610336	-82.7989772955220218
25584	2020-05-18 18:03:51	2020-05-18	Albertine Bergstrom-Wisoky	albertine.bergstrom.wisoky@geemail.com	San Francisco	California	210021680661768170	23bb703df5ec0063023a2b491aca0ce8	Voyager	37.7590275624029204	-122.420899717618099
25585	2020-05-18 18:40:07	2020-05-18	Mr. Clearence Flatley	mr.clearence.flatley@woohoo.com	Waco	Texas	3112600048271190152	c66cfd9ec3ba8235559c37b2d28858a3	VISA 13 digit	31.6016138530544914	-97.2576866989154496
25586	2020-05-18 19:00:30	2020-05-18	Coley Friesen	coley.friesen@geemail.com	Jacksonville	Florida	180001401017259986	bfd26b11b1dcb1f19571e384c6ea1005	VISA 16 digit	30.3636567223403588	-81.7307058234777344
25587	2020-05-18 19:24:15	2020-05-18	Bridgett Mertz	bridgett.mertz@geemail.com	Eugene	Oregon	4182300112815430	9852e7bbc511f4e6b34c11baad964f7d	JCB 16 digit	43.9814421670239426	-123.042583361406628
25588	2020-05-18 19:28:39	2020-05-18	Mr. Selmer Farrell I	mr.selmer.farrell.i@geemail.com	Manchester	New Hampshire	4788838601753537	9334e2478e7ee1b1d0cc5bd0a4524119	Discover	42.9185231245659295	-71.3441477936118957
25589	2020-05-18 19:49:38	2020-05-18	Tyrik Adams	tyrik.adams@geemail.com	Sandy Springs	Georgia	869931924297823209	73d8f8296651e4063a87958498bd744f	Maestro	33.9639700436554861	-84.3417070771183859
25590	2020-05-18 19:56:19	2020-05-18	Mr. Bernardo Hagenes	mr.bernardo.hagenes@geemail.com	San Francisco	California	676335786251476	e49d73e18e64ec378c360ceb6dc72840	Mastercard	37.7633630164747771	-122.453721734717234
25591	2020-05-18 20:05:58	2020-05-18	Ezequiel Bogan	ezequiel.bogan@geemail.com	Houston	Texas	4666987914166494	ba0b5c39ac5347371e49150796345c53	Voyager	29.6998207821123295	-95.3816747925259136
25592	2020-05-18 20:25:46	2020-05-18	Kimberley Larson	kimberley.larson@geemail.com	High Point	North Carolina	6011846289108934008	f005a20e225e9141aefb9d362a64b6d2	VISA 16 digit	36.0662835951521998	-79.9865245920810821
25593	2020-05-18 20:34:46	2020-05-18	Elgin Renner-Glover	elgin.renner.glover@woohoo.com	Spokane	Washington	210070484032542434	95805cc3735acaf09de94cbe7a31b2b4	JCB 15 digit	47.6182675007037801	-117.427286827274784
25594	2020-05-18 20:36:42	2020-05-18	Amari Osinski	amari.osinski@geemail.com	Hialeah	Florida	676270844237720	5bf8d5ddef779fa3c7ea798be22330d0	Voyager	25.9327875189926473	-80.2234983649007916
25595	2020-05-18 20:41:51	2020-05-18	Therman Beer	therman.beer@woohoo.com	New Haven	Connecticut	4670517816852091	176c30ddeaf0ef917a7e050e1c423092	JCB 15 digit	41.2465236623764042	-72.8460590924601945
25596	2020-05-18 20:43:39	2020-05-18	Olivia Bernier	olivia.bernier@geemail.com	San Francisco	California	4373889322654703	126ab33bbdba4183f794b60e487a962c	VISA 16 digit	37.8005830078762344	-122.462020107239994
25597	2020-05-18 20:54:53	2020-05-18	Zoey Christiansen	zoey.christiansen@woohoo.com	Oxnard	California	6011827282686441689	8a2fa259245091e3f85e66a2af3f631c	Mastercard	34.2123037184543932	-119.262153473161533
25598	2020-05-18 21:15:32	2020-05-18	Kasey Hackett PhD	kasey.hackett.phd@geemail.com	Tucson	Arizona	869990456994595374	206c23622fc06438d6dddd54d4f5b09c	Voyager	32.1671596029814353	-110.787220036726808
25599	2020-05-18 21:24:30	2020-05-18	Elena Koepp-Will	elena.koepp.will@geemail.com	Alexandria	Virginia	210097660148905503	03ac7aefe26f8bfa855514b54a30b12e	Diners Club / Carte Blanche	38.8002023143809254	-77.0589533610720281
25600	2020-05-18 21:24:46	2020-05-18	Dr. Vilma Beer	dr.vilma.beer@warmmail.com	Bakersfield	California	4327435208810659	7330a1dacd2bc0b933f91e3fad698b44	Voyager	35.3055795706517941	-118.964607645551851
25601	2020-05-18 21:51:54	2020-05-18	Gustave Homenick	gustave.homenick@woohoo.com	Milwaukee	Wisconsin	869978472718403650	0dcfa5c49a0bdfe0e45df280c1871d13	VISA 16 digit	43.004892446109281	-87.9894947648149071
25602	2020-05-18 22:44:00	2020-05-18	Nealy Konopelski-McDermott	nealy.konopelski.mcdermott@geemail.com	Montgomery	Alabama	210022127267647423	368fd42969ea3dac689d87314cdd23e9	JCB 16 digit	32.3558261970922345	-86.2058815952077424
25603	2020-05-18 22:46:06	2020-05-18	Ms. Cailyn Borer DDS	ms.cailyn.borer.dds@geemail.com	New York	New York	869937970666383238	f8bf4989c2056e21ce3879681e31477f	Discover	40.6468389186300314	-73.8900792371842954
25604	2020-05-18 22:51:32	2020-05-18	Brook Turcotte-Ullrich	brook.turcotte.ullrich@warmmail.com	Irvine	California	3096112849830928466	ad24325b2ee346ab808a523810b928a3	VISA 16 digit	33.733215979627893	-117.727674481879177
25605	2020-05-18 22:55:09	2020-05-18	Carey Watsica	carey.watsica@geemail.com	Charlotte	North Carolina	4804311311563026	82245f6f02c0190d59372be8159d16be	Maestro	35.2270255397792909	-80.8853867700733247
25606	2020-05-18 23:05:36	2020-05-18	Milton Cronin-Harvey	milton.cronin.harvey@geemail.com	Charlotte	North Carolina	503803411064300	d58e3956a51887cce3abeb22232e821b	Maestro	35.1123494623947892	-80.8138707166481822
25607	2020-05-18 23:07:10	2020-05-18	Dr. Judi Padberg MD	dr.judi.padberg.md@geemail.com	El Paso	Texas	3720862201113684	f703042e744d70d6b89a82f1d2d9918f	American Express	31.9323768434409061	-106.351486068729315
25608	2020-05-18 23:33:02	2020-05-18	Shan Lehner DVM	shan.lehner.dvm@geemail.com	Philadelphia	Pennsylvania	4290576262916347	e4a74b866f4669dcab6a4b6f6be8e848	Discover	39.9349741813685739	-75.1992350403118905
25609	2020-05-18 23:38:51	2020-05-18	Ellis Graham-Bins	ellis.graham.bins@woohoo.com	Wilmington	North Carolina	3088078519480330378	60f3ad13ba542f92510cc8f2bf255819	JCB 16 digit	34.2570949594777119	-77.9063618665088029
25610	2020-05-18 23:40:05	2020-05-18	Rayburn Willms Jr.	rayburn.willms.jr.@geemail.com	Charlotte	North Carolina	4899290082067738	95cc18d4eb833704ca4cefce0ee7f249	JCB 16 digit	35.2779280448120076	-80.8390421551596461
25611	2020-05-19 00:48:31	2020-05-19	Tressie Schowalter	tressie.schowalter@geemail.com	Portland	Oregon	3528862696755611557	a51b31d5c268c10879c13b8eef796935	JCB 15 digit	45.5582843257933874	-122.587020117463553
25612	2020-05-19 00:49:14	2020-05-19	Callum Trantow Sr.	callum.trantow.sr.@geemail.com	Los Angeles	California	675935369305301	7cd9ad39b5fc366bebe53cecdd1d5339	JCB 15 digit	33.9211860657535453	-118.317981229954583
25613	2020-05-19 00:54:10	2020-05-19	Alexandra Schaden	alexandra.schaden@geemail.com	New York	New York	502077527732273	371aca642df2626de866c8104e16a179	JCB 16 digit	40.725691921332853	-73.9908847139112567
25614	2020-05-19 01:01:04	2020-05-19	Kathi Kautzer	kathi.kautzer@warmmail.com	Grand Prairie	Texas	3112204903719163403	e54cfd83c46f00aeabb91fa475eb5cd1	JCB 16 digit	32.6375324651651084	-97.0236447161868227
25615	2020-05-19 01:08:15	2020-05-19	Marchello Kozey	marchello.kozey@geemail.com	Providence	Rhode Island	3059937877271563	3443c7c6ee022bcbe15cd70421cfccac	Mastercard	41.8736492725875209	-71.4715084155939593
25616	2020-05-19 01:12:47	2020-05-19	Miss Juanita Monahan DVM	miss.juanita.monahan.dvm@geemail.com	New York	New York	4582627880136961	d855708775f7fba3919aa20ddc62a098	JCB 16 digit	40.7025718651004098	-73.8962397622305929
25617	2020-05-19 01:38:49	2020-05-19	Dino Dare	dino.dare@geemail.com	Grand Prairie	Texas	630417217771587	743bf48ea9b17e41d898f9bb38ecc7b0	VISA 13 digit	32.6036773806955651	-96.928105340000613
25618	2020-05-19 01:55:46	2020-05-19	Julianna Torp	julianna.torp@geemail.com	St. Louis	Missouri	4779612025826737	9b8b5053ac7fd5f81d8684ec3d539152	JCB 15 digit	38.5386068861622348	-90.2303255247421561
25619	2020-05-19 02:00:32	2020-05-19	Mr. Deven Kris	mr.deven.kris@warmmail.com	Los Angeles	California	3708293895956160	6662658452e3bee32a57a3b70b340c06	JCB 16 digit	34.0180204208340484	-118.316511705656723
25620	2020-05-19 02:15:12	2020-05-19	Ancel McClure	ancel.mcclure@geemail.com	Grand Prairie	Texas	51316722752351518	04dc72214fe7d7eb25467b629533f3ac	JCB 15 digit	32.6764793124567703	-96.9592378456018906
25621	2020-05-19 02:23:02	2020-05-19	Unique Yost	unique.yost@woohoo.com	Pasadena	Texas	6011811429616776159	27753596f603597b0d53fb4010f00e52	JCB 15 digit	29.7253085670866071	-95.1645692355878623
25622	2020-05-19 02:27:22	2020-05-19	Shanda Heaney	shanda.heaney@warmmail.com	New York	New York	501899075122459	437df09726d4fea44e205c4e73ee6b73	Mastercard	40.6197959965318418	-73.8910116771597387
25623	2020-05-19 02:32:10	2020-05-19	Marlyn Roberts	marlyn.roberts@geemail.com	Concord	California	4999280108658	4a15d7b150d99ebb03971784f5ccf9d3	JCB 16 digit	37.9865541700206677	-121.9917173746679
25624	2020-05-19 02:37:06	2020-05-19	Jaslyn Hintz	jaslyn.hintz@geemail.com	Tulsa	Oklahoma	180095985457747754	067784de2a4f17e022385bcb0bea0302	JCB 15 digit	36.1851420591954138	-95.9722965219944655
25625	2020-05-19 02:38:31	2020-05-19	Valencia Boehm-Rutherford	valencia.boehm.rutherford@woohoo.com	Rockford	Illinois	4483883492629170	e0ce7c4e0f5d4a3b913eb1d0e3f52aed	JCB 16 digit	42.2398387723613524	-89.0604116538357005
25626	2020-05-19 03:04:46	2020-05-19	Rosemary Miller DDS	rosemary.miller.dds@woohoo.com	Winston–Salem	North Carolina	4858343212420	7e321145a24991947575af38375482b0	Maestro	36.1396395200628788	-80.2507314500063558
25627	2020-05-19 03:24:06	2020-05-19	Mrs. Altha Beier DVM	mrs.altha.beier.dvm@woohoo.com	Orlando	Florida	51717619000950122	5df11b7026812de479d1c57fb431b448	VISA 16 digit	28.3914891649302099	-81.2896732916556317
25628	2020-05-19 03:26:46	2020-05-19	Sheri McClure	sheri.mcclure@woohoo.com	Miramar	Florida	6011089994749584296	6dc83d68dd19d4aab5683d7790f61b4c	JCB 15 digit	26.0570797155126925	-80.4238374327767644
25629	2020-05-19 03:35:50	2020-05-19	Karolyn Christiansen-Kunde	karolyn.christiansen.kunde@woohoo.com	Lancaster	California	51771038728565141	f80f3a726a78add179bb3c5ab31f9538	Maestro	34.6324117337599446	-118.159403898843749
25630	2020-05-19 03:57:38	2020-05-19	Mrs. Geralyn Osinski	mrs.geralyn.osinski@geemail.com	Tallahassee	Florida	210008808916530411	79d57205d4140ba0f94ad62e64fbc13b	Voyager	30.4074739570286141	-84.2397164624664896
25631	2020-05-19 04:07:05	2020-05-19	Randal Mohr-Grady	randal.mohr.grady@woohoo.com	San Antonio	Texas	3423721173113741	b89ec753858ec9cd174351aef4e775fb	Voyager	29.4696672487143445	-98.4836316698066838
25632	2020-05-19 04:11:37	2020-05-19	Hobart Mills Jr.	hobart.mills.jr.@geemail.com	Oakland	California	210050786108971717	586fdab72e01810566366addf3dfc9ce	JCB 16 digit	37.8146046073484641	-122.275549874764849
25633	2020-05-19 04:17:17	2020-05-19	Campbell Gibson	campbell.gibson@geemail.com	McKinney	Texas	4013697159757614	fd6c1296e92eb0dc019be21d866b4377	JCB 16 digit	33.2712287208661479	-96.7253114294558856
25634	2020-05-19 04:55:51	2020-05-19	Shandra Beer-Hoppe	shandra.beer.hoppe@woohoo.com	Atlanta	Georgia	4371272321136000	62ac0fe38a474a1abbe78a733dc7c609	Mastercard	33.7696747292574528	-84.5162603814665232
25635	2020-05-19 05:11:54	2020-05-19	Unnamed Osinski II	unnamed.osinski.ii@geemail.com	Des Moines	Iowa	3046265476680494	b73a916bfe6e29049024fac6bbc746fe	VISA 16 digit	41.6032716111488625	-93.5172786920841901
25636	2020-05-19 05:13:05	2020-05-19	Roman Gorczany	roman.gorczany@geemail.com	Berkeley	California	3112096654128994588	197257ac23ce4a3b7bfee1e13b864875	Discover	37.9008022703238012	-122.261226528086681
25637	2020-05-19 05:14:57	2020-05-19	Annabelle Wilkinson	annabelle.wilkinson@geemail.com	Odessa	Texas	4901217331387	12f8a8975368592dd5cfb9473886d78e	Voyager	31.8826165112677984	-102.381868836950886
25638	2020-05-19 05:15:17	2020-05-19	Marie Kunze-Hyatt	marie.kunze.hyatt@geemail.com	Albuquerque	New Mexico	53451999957709956	e1e71cc19683c8775cb0596f71743794	Maestro	35.062589288842311	-106.718019789883499
25639	2020-05-19 05:16:44	2020-05-19	Adison Volkman	adison.volkman@warmmail.com	San Francisco	California	53486179099125598	736c04012541113924877de539887f83	JCB 15 digit	37.7476710942508262	-122.434959492938134
25640	2020-05-19 05:24:07	2020-05-19	Lelia Hoppe	lelia.hoppe@geemail.com	Sterling Heights	Michigan	3088873490527721317	7e8b345777967c7012bbd7414d215ad3	VISA 13 digit	42.5051991463255163	-83.0062047929197462
25641	2020-05-19 05:36:04	2020-05-19	Julio Hills	julio.hills@geemail.com	San Francisco	California	6011893418068202708	1ce501ec7d39543a56a58e89dd906ef9	Discover	37.7702737447630525	-122.434342666159466
25642	2020-05-19 05:54:54	2020-05-19	Betsy Pollich-Stark	betsy.pollich.stark@geemail.com	Los Angeles	California	54550990139320689	12bf07798cf7f28d3e6f85b519b0da85	American Express	34.053134676241875	-118.451982238282625
25643	2020-05-19 05:58:15	2020-05-19	Lilly McKenzie	lilly.mckenzie@geemail.com	San Francisco	California	52556952998839765	eb43cc24db288e7c2f36eee25e7d80e5	JCB 16 digit	37.7802090667634118	-122.434038369821536
25644	2020-05-19 06:02:53	2020-05-19	Sharon Weimann MD	sharon.weimann.md@warmmail.com	San Francisco	California	4929250872249	8829ae5b8a4b7c8bb6a341c1b8429c24	Diners Club / Carte Blanche	37.7438136560066226	-122.45082874992265
25645	2020-05-19 06:04:31	2020-05-19	Lorne Runolfsdottir	lorne.runolfsdottir@geemail.com	Gainesville	Florida	3112427141807562829	038e70cfca2c2677915f7538a041eeb4	VISA 16 digit	29.7483318327285353	-82.3901338966436754
25646	2020-05-19 06:28:05	2020-05-19	Levern Hirthe DVM	levern.hirthe.dvm@geemail.com	Pasadena	Texas	502047336969804	fdbbdee4030158ccc70d15adc3c87352	Discover	29.5772436739750191	-95.230547079299015
25647	2020-05-19 06:35:59	2020-05-19	Buena Fadel	buena.fadel@geemail.com	Dallas	Texas	676230389760213	2a4fcacb77001b793435a3a201f11f54	VISA 16 digit	32.811035270271077	-96.7482231346387351
25648	2020-05-19 06:42:50	2020-05-19	Macarthur Marks	macarthur.marks@geemail.com	New York	New York	3781427861409891	9ba2ecc45512bbceada2d1e7fd79395e	JCB 15 digit	40.6054824043288818	-73.907292588277528
25649	2020-05-19 06:44:04	2020-05-19	Darnell Breitenberg	darnell.breitenberg@geemail.com	Mesa	Arizona	52210055373224484	90728ed11f98c3a91ec45adb5f770c49	American Express	33.4326630587834828	-111.76056253419965
25650	2020-05-19 06:53:57	2020-05-19	Gaven Carroll	gaven.carroll@geemail.com	Phoenix	Arizona	4428978795816	d6c7b58102ec7a00ec242d24374e20b5	VISA 13 digit	33.5247246541481516	-112.083220985431609
25651	2020-05-19 06:58:58	2020-05-19	Ms. Alvina Bins	ms.alvina.bins@woohoo.com	Mesa	Arizona	4718701071687	f5da820732b0cb7b708d007bf954d785	VISA 16 digit	33.4297030843473948	-111.756981389399243
25652	2020-05-19 07:00:38	2020-05-19	Con Wisozk	con.wisozk@geemail.com	New York	New York	6011712324929628926	eb2d7aa09a43c413e4ef8203da6554b9	Voyager	40.6132506587300455	-74.0170254093956146
25653	2020-05-19 07:04:30	2020-05-19	Mitchel Ankunding-Shields	mitchel.ankunding.shields@geemail.com	Lincoln	Nebraska	4597149724237783	08d087672c63b3a04d991a0c270977fe	JCB 16 digit	40.737088575495406	-96.7759158389337415
25654	2020-05-19 07:15:28	2020-05-19	Nikolai Anderson	nikolai.anderson@geemail.com	Clinton	Michigan	4004629503574388	364e15e51c94bf92fb89418e6067f0df	JCB 16 digit	42.5888519619658581	-83.0018056081216855
25655	2020-05-19 07:42:58	2020-05-19	Dr. Alf Pouros	dr.alf.pouros@woohoo.com	Overland Park	Kansas	869903331933318574	424da2d2f9385d8d243f75e0128969c8	American Express	38.9517029788680418	-94.7679224806413032
25656	2020-05-19 07:50:53	2020-05-19	Joy Schultz	joy.schultz@geemail.com	Vacaville	California	4205176931682810	8586706a7b2f0e62d6356f2ec04748d5	JCB 15 digit	38.3178849707018614	-122.006820491130654
25657	2020-05-19 07:52:28	2020-05-19	Gregorio Smitham I	gregorio.smitham.i@geemail.com	San Francisco	California	3400286861516107	13cebd6b5c365d9d1f1e46e35ef31f93	JCB 16 digit	37.7697229028667962	-122.450284274232473
25658	2020-05-19 08:04:56	2020-05-19	Mr. Delton Schaefer DDS	mr.delton.schaefer.dds@geemail.com	Norman	Oklahoma	4184548505188918	568b9685591ef6e99fb1321d32cefbe1	American Express	35.1876635258592643	-97.2822852372910774
25659	2020-05-19 08:17:49	2020-05-19	Dr. Cain Schamberger MD	dr.cain.schamberger.md@geemail.com	New York	New York	3473850891011553	ad0878c2bec6894014ee7434cda52413	Maestro	40.6042204819843136	-73.9022767146479254
25660	2020-05-19 08:29:26	2020-05-19	Lulie Lebsack	lulie.lebsack@geemail.com	New York	New York	676376421056185	2987dc0530bd62537b1fb49ed3c9b651	Discover	40.6486603658869825	-73.8580783746100877
25661	2020-05-19 08:35:02	2020-05-19	Breanne Kulas	breanne.kulas@warmmail.com	Oakland	California	3088466608163793562	a43a686d13be068068c3c84423cfbf93	Voyager	37.8256912979083353	-122.278609042313846
25662	2020-05-19 08:44:36	2020-05-19	Blanchie Tremblay	blanchie.tremblay@warmmail.com	Austin	Texas	4178796724940	3bc3eab5fca2e06d552e4f9abb65a637	Mastercard	30.3872963728044176	-97.6752876758348236
25663	2020-05-19 08:51:15	2020-05-19	Kadijah Gerlach	kadijah.gerlach@geemail.com	Wichita	Kansas	4403321653392	818fc32bc65a1600b0a72e2cd7121be8	VISA 16 digit	37.7084467106375811	-97.3597144661672473
25664	2020-05-19 08:55:04	2020-05-19	Dr. Roddy Dickinson Jr.	dr.roddy.dickinson.jr.@geemail.com	Seattle	Washington	52293042124935477	32464d1c113bf928ba81ba85090eca5f	Discover	47.5715244366712895	-122.39557060575261
25665	2020-05-19 09:03:26	2020-05-19	Fred Auer	fred.auer@geemail.com	New York	New York	4331805112595	9d9a3d72594f142d9356ec4524d10ad2	Diners Club / Carte Blanche	40.6184412777181691	-74.0243345875654342
25666	2020-05-19 09:11:05	2020-05-19	Dr. Rakeem Grimes DVM	dr.rakeem.grimes.dvm@woohoo.com	Los Angeles	California	4882947906861393	8b3fb830f9b5cf2f07de436ee303ecdd	Diners Club / Carte Blanche	34.0064073647238274	-118.346933057484392
25667	2020-05-19 09:24:02	2020-05-19	Memphis Boyer	memphis.boyer@warmmail.com	Dallas	Texas	3528275847362411789	9f9257bf1f837da1a2ce2b1a9db95310	Diners Club / Carte Blanche	32.71015901824385	-96.7936237958222563
25668	2020-05-19 09:39:03	2020-05-19	Louetta Huels	louetta.huels@geemail.com	Stockton	California	4765293748982	fe4aead6b222349a7df370a5b1114cc3	Discover	38.0031159552942981	-121.233678847559915
25669	2020-05-19 09:45:22	2020-05-19	Derrick Borer	derrick.borer@geemail.com	Augusta	Georgia	4674634549419084	484b1f822a9cce8731df276dc7fdbcfd	JCB 15 digit	33.3658852542024107	-82.1657118888400504
25670	2020-05-19 09:59:50	2020-05-19	Valentine Balistreri	valentine.balistreri@geemail.com	Lansing	Michigan	3054344865779605	75198bcc5f597ffb6fd59d959e6a629f	VISA 16 digit	42.6533963056124747	-84.611429064453759
25671	2020-05-19 10:03:26	2020-05-19	Wong Hammes	wong.hammes@warmmail.com	New York	New York	3088356290569141325	5b5d60fe375b3b3fc5c5d6255c80561c	JCB 16 digit	40.579464711410921	-73.8831166426546844
25672	2020-05-19 10:05:41	2020-05-19	Vicy Lubowitz	vicy.lubowitz@geemail.com	Baton Rouge	Louisiana	675979114191897	6d6ad04a94dfdb52e84c4d2b48ee11b4	VISA 16 digit	30.4030667381573458	-91.0946358469422819
25673	2020-05-19 10:06:31	2020-05-19	Jeptha Jerde	jeptha.jerde@geemail.com	Vancouver	Washington	6011936456132845481	a6d616e1380f59499131550cf9af274d	JCB 15 digit	45.6568364810734977	-122.524503008701643
25674	2020-05-19 10:06:36	2020-05-19	Maddison Dicki	maddison.dicki@geemail.com	New York	New York	3743880454334701	b83b73113705930379706986b526c299	Discover	40.6890203058943172	-73.88907042386829
25675	2020-05-19 10:07:28	2020-05-19	Enrique McClure MD	enrique.mcclure.md@warmmail.com	Omaha	Nebraska	4007284205904389	2485b8c64e77618797b17429c011ce89	VISA 13 digit	41.3332766347710034	-96.1382214550975789
25676	2020-05-19 10:23:25	2020-05-19	Marla Bashirian	marla.bashirian@geemail.com	Kent	Washington	676180335430502	e018dca1f5b5b081c3e0e5d54c41901e	American Express	47.3712869356498132	-122.306829541888831
25677	2020-05-19 10:35:30	2020-05-19	Acie Hintz Jr.	acie.hintz.jr.@geemail.com	Dallas	Texas	502096898651813	67fb3a114760cf71475ceb9402959771	Diners Club / Carte Blanche	32.7897664997532985	-96.8258877603299908
25678	2020-05-19 10:46:08	2020-05-19	Geovanni Sporer	geovanni.sporer@geemail.com	New York	New York	180036990418435384	b2418cc865beaa4bcd063c8f72bb5bc5	Discover	40.6385768132507792	-73.9594991346251192
25679	2020-05-19 10:48:16	2020-05-19	Buelah Labadie	buelah.labadie@geemail.com	Oakland	California	3002537832179575	e2b26d163deb93fa4c8e4e03970f3fcc	Mastercard	37.8133180903324444	-122.28547721745116
25680	2020-05-19 10:52:53	2020-05-19	Mr. Montie Volkman MD	mr.montie.volkman.md@geemail.com	Phoenix	Arizona	3715751942754913	e3f33683c4d1431a5d38884cf280a749	JCB 16 digit	33.5398564390771128	-112.011936117748178
25681	2020-05-19 11:03:17	2020-05-19	Frazier Turcotte	frazier.turcotte@geemail.com	Anaheim	California	4997056308791	655c3f2070682f0da969036d7262b726	Discover	33.7844671014994375	-117.832332608264309
25682	2020-05-19 11:06:41	2020-05-19	Keven Gislason	keven.gislason@geemail.com	El Paso	Texas	3528126023188587985	e731bb445fc80ba5024a0a4c6e806f7d	American Express	31.7855736377477669	-106.462118466895078
25683	2020-05-19 11:09:29	2020-05-19	Adolf Hilll III	adolf.hilll.iii@warmmail.com	Worcester	Massachusetts	53270315543129329	327f8b7aecfe0b09c4b591b7f896995c	Diners Club / Carte Blanche	42.1934267329685397	-71.7854448484510215
25684	2020-05-19 11:10:43	2020-05-19	Miss Dulce Wyman	miss.dulce.wyman@geemail.com	San Francisco	California	3768237849461006	3ed7cd15dbe0f7b60cbade94a43873f3	Diners Club / Carte Blanche	37.7765715709712424	-122.43624687108877
25685	2020-05-19 11:13:05	2020-05-19	Russel Koss	russel.koss@geemail.com	Sunnyvale	California	3088658427583650320	f7efdcde7bc8262b52eb0d7fc7a1667b	JCB 16 digit	37.3268593612585278	-122.004186460488668
25686	2020-05-19 11:19:30	2020-05-19	Vesta Goodwin-Williamson	vesta.goodwin.williamson@geemail.com	Scottsdale	Arizona	4980350495826300	290f4f922e0814a811c5aeb229db37b2	VISA 13 digit	33.6220734521869602	-111.938336137213184
25687	2020-05-19 11:20:03	2020-05-19	Gunnar Johnson	gunnar.johnson@geemail.com	Berkeley	California	3757906118306687	3f4b2694652be654d643accc3dd48c4c	Diners Club / Carte Blanche	37.8680063505387352	-122.276905768907767
25688	2020-05-19 11:21:09	2020-05-19	Jaleesa Wunsch	jaleesa.wunsch@warmmail.com	San Angelo	Texas	4217103516829	1b21a13f3e32aaaf18887c97ed9c26b2	Maestro	31.5116046022776501	-100.454904299426829
25689	2020-05-19 11:21:36	2020-05-19	Malinda Schaefer	malinda.schaefer@geemail.com	New York	New York	6011978341802190534	d8f3c3d1560f1b1cccf8f022228a1272	VISA 13 digit	40.7479815152231595	-74.0107709570217907
25690	2020-05-19 11:30:21	2020-05-19	Salvador Jacobson	salvador.jacobson@geemail.com	Oakland	California	3528465328341399536	c714321138fa749e500ef78807fb4323	Diners Club / Carte Blanche	37.8283027312683444	-122.280460674623285
25691	2020-05-19 11:43:16	2020-05-19	Sherrie Homenick	sherrie.homenick@geemail.com	Seattle	Washington	180080469051799773	6cafc96634811e2d0d712ed7ec8567e0	VISA 16 digit	47.6190306291375336	-122.361638182906063
25692	2020-05-19 12:05:58	2020-05-19	Hildegard Wisoky DDS	hildegard.wisoky.dds@geemail.com	Boston	Massachusetts	3010718825353037	3b5e59c44f4c014a0afb6b483559d636	JCB 16 digit	42.4193604090884335	-70.9984716964371501
25693	2020-05-19 12:23:50	2020-05-19	Maximiliano Yost	maximiliano.yost@geemail.com	El Paso	Texas	55016609768835613	6d7e045148f7c8a544911733136d2c44	American Express	31.8788273205809318	-106.513546536162508
25694	2020-05-19 12:25:43	2020-05-19	Nichelle Ondricka	nichelle.ondricka@warmmail.com	New York	New York	3112874381929551601	66aa25191f18fcd8e5a0daf46302cdd2	VISA 16 digit	40.5683007782082967	-73.9120708885032656
25695	2020-05-19 12:28:24	2020-05-19	Dr. Carrol Smitham	dr.carrol.smitham@geemail.com	Denver	Colorado	3337852973837332797	9ff340800a1dd47194b7fe4d6234fcde	VISA 16 digit	39.7944620098039508	-104.832054354833815
25696	2020-05-19 12:31:39	2020-05-19	Dr. Dawson Bailey II	dr.dawson.bailey.ii@geemail.com	Norfolk	Virginia	210047736336870534	397ff66bcd6b5dd2a5b2b5e262a4b5e7	VISA 16 digit	36.9937458481658297	-76.2422771927904392
25697	2020-05-19 12:38:15	2020-05-19	Beryl Koch	beryl.koch@geemail.com	San Diego	California	4652186152868616	01165393921c0acae687742ce2031f20	JCB 16 digit	32.7724937401313312	-117.136820513047283
25698	2020-05-19 12:39:08	2020-05-19	Otha Leannon	otha.leannon@woohoo.com	Durham	North Carolina	210014157177123413	d1a32eb9b16e4adf15af656dd1035caf	VISA 16 digit	35.9050640040788807	-78.9323970883056489
25699	2020-05-19 12:39:21	2020-05-19	Tristen Terry	tristen.terry@geemail.com	Chicago	Illinois	3096385571627491611	6dc066fe9cfd648603c991beef229249	JCB 16 digit	41.7534890496473778	-87.7281716239202751
25700	2020-05-19 12:41:35	2020-05-19	Ethan Cormier-Mitchell	ethan.cormier.mitchell@geemail.com	San Francisco	California	6011992911801843507	155b4d6e8c1e200fefa0920f07c6dc79	Discover	37.7801772166049972	-122.420026180962836
25701	2020-05-19 12:49:02	2020-05-19	Tess Runolfsdottir-Pollich	tess.runolfsdottir.pollich@geemail.com	Norman	Oklahoma	3528153276950585464	88374dd221e7ce7e2d7adda97b586fab	VISA 16 digit	35.2478223183698987	-97.2649722039487159
25702	2020-05-19 12:54:21	2020-05-19	Dr. Fritz Glover	dr.fritz.glover@woohoo.com	Jacksonville	Florida	6011468082371335251	a71e0dff814d44c3cba400d9ee1f7cf6	Discover	30.4269493596680469	-81.7426764657333536
25703	2020-05-19 13:04:25	2020-05-19	Dr. Shanda Hettinger	dr.shanda.hettinger@geemail.com	New York	New York	4801930164043829	889db857b88368d452b68c687be2e508	Voyager	40.6027348647583253	-73.9139342076972099
25704	2020-05-19 13:06:08	2020-05-19	Dr. Tomie Vandervort	dr.tomie.vandervort@geemail.com	Pittsburgh	Pennsylvania	6011090473580085744	6e1ee4dbf607b34e6b00f661fcad7d0c	Mastercard	40.5121919487092654	-79.9887598585508783
25705	2020-05-19 13:06:40	2020-05-19	Chalmer McKenzie	chalmer.mckenzie@geemail.com	Columbia	South Carolina	52865008905046725	95138260e31f36754257ba4696a8d143	VISA 16 digit	34.1196762739479524	-80.8490914211161424
25706	2020-05-19 13:10:04	2020-05-19	Sydnie Considine	sydnie.considine@geemail.com	Los Angeles	California	675925051136239	89701714fadd9221aa1432c33ba10aab	American Express	34.0718948637466852	-118.363095943908391
25707	2020-05-19 13:13:09	2020-05-19	Juliann Dooley	juliann.dooley@warmmail.com	Columbus	Ohio	52786566670241496	5c74b30e298972ede67736d0c2d891c8	American Express	40.0417080388914783	-82.9549393914874713
25708	2020-05-19 13:26:16	2020-05-19	Dakotah Daugherty	dakotah.daugherty@warmmail.com	Sacramento	California	3009645106965729	49663afc95ed04998198e6d3ae93c4a6	American Express	38.6507873631812657	-121.404517503107328
25709	2020-05-19 13:40:38	2020-05-19	Sarrah Grady	sarrah.grady@geemail.com	Greensboro	North Carolina	869906296738764461	fdec102d2aa28741d2884b32e8fab694	JCB 15 digit	36.0565145371131592	-79.7487827062588224
25710	2020-05-19 13:49:15	2020-05-19	Ashleigh Eichmann	ashleigh.eichmann@geemail.com	Bridgeport	Connecticut	6011869732559271547	45c044d316f15e81741a1f9718edfac8	Voyager	41.2654031026340959	-73.2769630785465296
25711	2020-05-19 13:58:19	2020-05-19	Dori Kihn	dori.kihn@warmmail.com	Anchorage	Alaska	55129788200163125	c23a38cbed0df9a8a2914f0e145e0f95	VISA 16 digit	61.1700700265571484	-149.200230836228656
25712	2020-05-19 14:00:45	2020-05-19	Zena Herzog DVM	zena.herzog.dvm@geemail.com	Miami	Florida	3475267864647867	d7d35d4f5db53cd10396d1aabfdc7717	Voyager	25.7381134969785812	-80.1957032238006633
25713	2020-05-19 14:08:34	2020-05-19	Dossie Lakin	dossie.lakin@geemail.com	Los Angeles	California	210041030598833422	0d3cb80eebbd2e1e5f33b9624a22bd16	VISA 16 digit	34.0026870440091926	-118.476206216727562
25714	2020-05-19 14:20:14	2020-05-19	Lyndia Grady-Kutch	lyndia.grady.kutch@geemail.com	Memphis	Tennessee	3010671046916225	49f26669618f778fcdfea25ca19deb10	Voyager	35.0976009503539643	-90.0767150796275615
25715	2020-05-19 14:32:02	2020-05-19	Marshal Jaskolski-Kuhn	marshal.jaskolski.kuhn@warmmail.com	Cleveland	Ohio	3528902326898287006	7a172cce2a14df12a5848fae490de559	JCB 16 digit	41.5286651877537309	-81.7243970463756426
25716	2020-05-19 14:34:42	2020-05-19	Belinda Marvin-Boyle	belinda.marvin.boyle@geemail.com	Meridian	Idaho	4428899645942	e9421c3a922fe7d0100ca40e5986b180	JCB 16 digit	43.5259959267459777	-116.427535801840577
25717	2020-05-19 14:36:40	2020-05-19	Mr. Jory Ondricka	mr.jory.ondricka@geemail.com	New York	New York	210070356290209791	b04319ea9917517edddefbcaa4673b02	Voyager	40.5845361258126758	-73.975503016765046
25718	2020-05-19 14:39:02	2020-05-19	Samira Osinski	samira.osinski@geemail.com	Portland	Oregon	3158027740139966568	ef1ccb14140f13199f9ca392fbd87c56	Voyager	45.5463626291491082	-122.645399134932092
25719	2020-05-19 14:39:13	2020-05-19	Jacquez Murphy	jacquez.murphy@geemail.com	San Francisco	California	3112216329706632141	3a197ea413458d94c40f7f7d396675e2	Diners Club / Carte Blanche	37.7699186015109447	-122.444277267798029
25720	2020-05-19 14:45:01	2020-05-19	Alexandrea Satterfield	alexandrea.satterfield@geemail.com	Detroit	Michigan	180042535774606920	98797776e87d59deafc79b7d9e166235	VISA 16 digit	42.4826947228442933	-83.1888784421727081
25721	2020-05-19 14:45:55	2020-05-19	Judson Towne	judson.towne@geemail.com	Thornton	Colorado	4239915055292447	e3f84f0978f362a7e2fc733810589464	Discover	39.8520842677779541	-105.028534248626983
25804	2020-05-20 00:18:55	2020-05-20	Mr. Donnell Hermann	mr.donnell.hermann@geemail.com	Austin	Texas	4548075228414612	b9f9b19aa5daff9f74daf98b8cad8688	American Express	30.2122432264160352	-97.8415497631538642
25722	2020-05-19 14:53:48	2020-05-19	Valentino Ankunding	valentino.ankunding@geemail.com	Jersey City	New Jersey	4385315059225	4d9583144412248236c1f409603a315e	Mastercard	40.6629520083717964	-74.0722194890912675
25723	2020-05-19 15:01:36	2020-05-19	Zetta Mraz	zetta.mraz@woohoo.com	Philadelphia	Pennsylvania	3041662407138136	76ff6274ba0c9c0129a71d33bad2d193	Voyager	40.0999184194911251	-75.0586872632049023
25724	2020-05-19 15:04:42	2020-05-19	Ashton Mueller	ashton.mueller@geemail.com	Berkeley	California	3429878055023531	6cc610ca3056b33a5ce3fb9de6c9b6aa	Discover	37.8281364556274653	-122.29625204031943
25725	2020-05-19 15:04:56	2020-05-19	Liz Romaguera	liz.romaguera@geemail.com	Sacramento	California	180069548883168219	92ce2e62caf3cafcc6e50c4198179312	VISA 16 digit	38.5710844265561548	-121.406198698353393
25726	2020-05-19 15:07:16	2020-05-19	Suzette Willms	suzette.willms@woohoo.com	Phoenix	Arizona	53288833297632322	a82eca84fdd23683393fe09c23de4d93	JCB 16 digit	33.6003288738362542	-112.106882091790823
25727	2020-05-19 15:11:23	2020-05-19	Ms. Noretta Roberts PhD	ms.noretta.roberts.phd@geemail.com	Louisville	Kentucky	53316057565679932	7e21b3dd5653f1a55d0872286804707d	American Express	38.2643722389262138	-85.5588624421112343
25728	2020-05-19 15:12:35	2020-05-19	Franklin Ritchie-Quitzon	franklin.ritchie.quitzon@geemail.com	Philadelphia	Pennsylvania	3337071333720255818	6558f65212d01a0b7a50c80ab124094e	JCB 16 digit	39.9821316051721567	-75.0429547080203889
25729	2020-05-19 15:16:04	2020-05-19	Lela Wilkinson	lela.wilkinson@geemail.com	Moreno Valley	California	54209317194251101	d36f8a341f0403ecc5437e0c88032a0f	Discover	33.836798678198079	-117.126087117704373
25730	2020-05-19 15:17:19	2020-05-19	Tavon Denesik	tavon.denesik@geemail.com	Renton	Washington	4377390265381095	46221e7fdc01599702df20c037647694	JCB 16 digit	47.472604193311561	-122.167418466888364
25731	2020-05-19 15:19:22	2020-05-19	Tyler Fisher	tyler.fisher@geemail.com	Fontana	California	210072306072731361	8f600ac594e4408324d0fb2b94eebd19	American Express	34.0461932325884717	-117.447148683787887
25732	2020-05-19 15:48:22	2020-05-19	Rohan Marvin	rohan.marvin@geemail.com	Los Angeles	California	3096987716321332932	6b55ca92cf7875965445e851cc904ddf	Voyager	34.0109003785863493	-118.472044952445842
25733	2020-05-19 15:49:22	2020-05-19	Mr. Ransom Crooks DDS	mr.ransom.crooks.dds@warmmail.com	Killeen	Texas	3005725206351592	4fa43eff1f3a0d91f1c2767475edfe08	Mastercard	31.036355848354102	-97.8090067088305943
25734	2020-05-19 15:50:46	2020-05-19	Mrs. Makenzie Price DDS	mrs.makenzie.price.dds@geemail.com	Philadelphia	Pennsylvania	55602945181347822	a89d23bfe6dc6cc299ec1becdd7ff0fc	Discover	40.0280620682943606	-75.0742804647322828
25735	2020-05-19 15:58:58	2020-05-19	Jo Robel-Frami	jo.robel.frami@geemail.com	Berkeley	California	3050985523228916	144e07f9537a1ea3ba95e5888e0f70c0	Voyager	37.9194930057372517	-122.231524466627661
25736	2020-05-19 16:06:20	2020-05-19	Newell Gerlach	newell.gerlach@geemail.com	Virginia Beach	Virginia	3796970067707348	2213ab21c9faa2e5984d49346a8caca2	Mastercard	36.7314294229913543	-76.0878923929434308
25737	2020-05-19 16:12:33	2020-05-19	Braxton Fahey	braxton.fahey@warmmail.com	Los Angeles	California	869962898996413599	55081d5fb6c6cc04f537ee1d68febf87	VISA 16 digit	34.0890655082981979	-118.448479802766059
25738	2020-05-19 16:17:33	2020-05-19	Shanika Greenfelder	shanika.greenfelder@geemail.com	San Diego	California	3096324212566477253	260073a926678030bfe266462e111bf7	JCB 15 digit	32.7944804678738109	-117.166434527598327
25739	2020-05-19 16:20:32	2020-05-19	Mr. Nathen Huel V	mr.nathen.huel.v@warmmail.com	San Antonio	Texas	210034372016892534	f601ee35b164a07115597fe517310934	VISA 16 digit	29.3909458032414328	-98.4509991317357844
25740	2020-05-19 16:20:39	2020-05-19	Taryn Zulauf	taryn.zulauf@geemail.com	Charlotte	North Carolina	3492971939095098	031b3b94c33557555883c7cf9d2d2af7	Voyager	35.1656996132593562	-80.8445654058773044
25741	2020-05-19 16:22:37	2020-05-19	Calla Champlin	calla.champlin@geemail.com	San Francisco	California	3040435061755292	62c568b2e1e985869afab0166a942a0c	Discover	37.7690448928661482	-122.407986204543519
25742	2020-05-19 16:29:28	2020-05-19	Shalon Gibson	shalon.gibson@geemail.com	Glendale	California	4712310935161507	3a5d45359332166b885175b96b887640	JCB 16 digit	34.0982078316375592	-118.295426856204131
25743	2020-05-19 16:29:56	2020-05-19	Miss Jessika Sawayn	miss.jessika.sawayn@geemail.com	Oklahoma City	Oklahoma	869960801204058927	f442112a0e5f4ede0838a46d18e8cea0	Mastercard	35.4168726086992791	-97.5135039463069262
25744	2020-05-19 16:38:32	2020-05-19	Add Gorczany	add.gorczany@geemail.com	Oxnard	California	53109508499934075	448e605e40140cb8a9b35861b78b6c50	American Express	34.2774641774084401	-119.264185434943442
25745	2020-05-19 16:46:17	2020-05-19	Tatianna Abernathy	tatianna.abernathy@geemail.com	San Diego	California	4304747030620743	0dab2a36550bb5b484e5ae91310b60c1	Voyager	32.9062069213550572	-117.178377583194532
25746	2020-05-19 17:16:39	2020-05-19	Dr. Garnet Sporer	dr.garnet.sporer@geemail.com	New York	New York	4079727529968004	63d5efde2bfc11f14480315430cee169	JCB 15 digit	40.726852660182864	-74.0135470780439704
25747	2020-05-19 17:17:56	2020-05-19	Zackery King	zackery.king@geemail.com	Birmingham	Alabama	060435639300371	4970f96390e009fd228a50ee88e03970	Mastercard	33.4329280398111806	-86.7752603684328534
25748	2020-05-19 17:20:52	2020-05-19	Mr. Cassius Nienow DVM	mr.cassius.nienow.dvm@geemail.com	Jersey City	New Jersey	55184106613010324	3bbb20e68506c3a4428d7a034b8d3a14	Discover	40.7585203440800257	-74.1405833937183019
25749	2020-05-19 17:37:42	2020-05-19	Ashlyn Lowe-Dibbert	ashlyn.lowe.dibbert@geemail.com	Henderson	Nevada	6011575601900362278	604f8dfeb6f62674d0bd01bf2e193be9	VISA 16 digit	35.9965282036390164	-115.132621690367174
25750	2020-05-19 17:37:59	2020-05-19	Charlotta Connelly PhD	charlotta.connelly.phd@geemail.com	San Francisco	California	4223283058898886	b4aafe96e5a2371b7e7663e53a05e537	VISA 13 digit	37.7647351151808834	-122.420450335755504
25751	2020-05-19 18:03:19	2020-05-19	Sam Wilkinson	sam.wilkinson@geemail.com	Surprise	Arizona	210065407249288548	097fc6d79009f39ef09d93d2aac95d19	American Express	33.7659951604664315	-112.427850358257814
25752	2020-05-19 18:04:18	2020-05-19	Arnett Wilderman	arnett.wilderman@geemail.com	Dallas	Texas	52642638695033630	c1d1e1afe96ee6f80eef4a927fe9310e	Discover	32.7463568082816892	-96.8103258048612503
25753	2020-05-19 18:05:00	2020-05-19	Dr. Esker Hahn Sr.	dr.esker.hahn.sr.@woohoo.com	San Francisco	California	3416661498976167	5caca5292d9a241bc3b1edb6c42261ad	Voyager	37.7497344473702086	-122.423073732968192
25754	2020-05-19 18:09:55	2020-05-19	Clarence Franecki	clarence.franecki@geemail.com	New York	New York	3031939954149108	9ef5bc43ce8f757be0c2c1f0352f8560	JCB 16 digit	40.6511625422853982	-74.0077507367253276
25755	2020-05-19 18:11:30	2020-05-19	Dana Reichel	dana.reichel@warmmail.com	Joliet	Illinois	869975995835310336	53824eadd53d7b2ee56fa0ec3353ab73	Mastercard	41.605064736851304	-88.2168808174889421
25756	2020-05-19 18:12:11	2020-05-19	Mr. Chauncey Olson IV	mr.chauncey.olson.iv@geemail.com	New Orleans	Louisiana	869993098429612221	fb8d278f33f8ae1aae9d65bd93a23741	Voyager	30.0800539080534115	-89.9817519484814312
25757	2020-05-19 18:15:15	2020-05-19	Myrtle Prosacco-Cormier	myrtle.prosacco.cormier@geemail.com	Brownsville	Texas	6011647250702282625	7ac03daee57847d4108e2a77d4cef00b	VISA 16 digit	26.035952956982328	-97.513695385977627
25758	2020-05-19 18:17:20	2020-05-19	Mr. Brody Crooks	mr.brody.crooks@geemail.com	Syracuse	New York	6011655957546158923	d53e17d2db4b636016fcc8a5110e9d28	Maestro	43.0675940109733446	-76.0920372196719086
25759	2020-05-19 18:19:48	2020-05-19	Chanda Rutherford MD	chanda.rutherford.md@geemail.com	Grand Prairie	Texas	3707269045071747	ca5229499fd5c1ca6516920522aa34a6	American Express	32.6933157811459196	-96.9856977105014124
25760	2020-05-19 18:23:13	2020-05-19	Verdie Ebert	verdie.ebert@warmmail.com	Phoenix	Arizona	3475284397951732	49deba4413c4232e176885fe8d7f05b8	American Express	33.5402996825918578	-112.148602096030871
25761	2020-05-19 18:35:58	2020-05-19	Dollye Hodkiewicz	dollye.hodkiewicz@geemail.com	Indianapolis	Indiana	180052323897821354	4588a4e08e1fc33449bd13cc76909312	Diners Club / Carte Blanche	39.806247646269199	-86.0685089867763224
25762	2020-05-19 18:36:52	2020-05-19	Shira Larkin	shira.larkin@woohoo.com	San Francisco	California	6011485467240677802	4af5031bba3d123a166d8f08d3273807	JCB 16 digit	37.8235148927501825	-122.448098330526634
25763	2020-05-19 18:44:59	2020-05-19	Dr. Amarion Marks Sr.	dr.amarion.marks.sr.@geemail.com	Los Angeles	California	3017391271178135	bb61501e8d0aa2e4ab3a1df55581e688	VISA 13 digit	33.978346615550663	-118.416521990065647
25764	2020-05-19 18:45:27	2020-05-19	Sheila Heathcote	sheila.heathcote@warmmail.com	Pittsburgh	Pennsylvania	6011410950662581404	bbd50b88185ce50af97036f23f1bddcb	VISA 16 digit	40.3410809082400021	-79.9424837174531149
25765	2020-05-19 18:55:05	2020-05-19	Terri Gusikowski	terri.gusikowski@geemail.com	Pearland	Texas	869986940649853557	993ac4029212301ad34998e6d69c04d0	Discover	29.4930682757675662	-95.4119901842292393
25766	2020-05-19 19:20:33	2020-05-19	Norine Kuhlman	norine.kuhlman@geemail.com	Oakland	California	4779115794871132	db0ea7d7dd89693588757f084f1d205c	JCB 16 digit	37.8136318836950593	-122.279060228262964
25767	2020-05-19 19:28:21	2020-05-19	Kimora Leannon	kimora.leannon@geemail.com	Fort Worth	Texas	869962669862034656	542e4cb1600ab60e4d7dcbc91b546b28	JCB 16 digit	32.7180296266507398	-97.2600319814689414
25768	2020-05-19 19:36:17	2020-05-19	Albertina Turcotte-Shields	albertina.turcotte.shields@geemail.com	Indianapolis	Indiana	4348994341137110	ec8e95719b1560b818d41b352d465374	JCB 15 digit	39.7533229997388986	-86.0550936317272459
25769	2020-05-19 19:47:19	2020-05-19	Dr. Lise Runolfsson DDS	dr.lise.runolfsson.dds@warmmail.com	New Orleans	Louisiana	210009822350056279	1537ecce0c9f01456b08391142da0aee	VISA 16 digit	30.0807897675797342	-89.9953081431593773
25770	2020-05-19 19:55:47	2020-05-19	Cortez Jast	cortez.jast@woohoo.com	Berkeley	California	4367009975767	ac79129c31f472fa0678bff41ade67e5	JCB 15 digit	37.8839114665276	-122.289064240758137
25771	2020-05-19 19:56:50	2020-05-19	Calista Olson	calista.olson@warmmail.com	San Francisco	California	210070813453608441	ee07c4f61b243ad3685812c1b13a4c2e	VISA 13 digit	37.7797427464368525	-122.431750627139294
25772	2020-05-19 20:03:04	2020-05-19	Will Lind	will.lind@woohoo.com	Midland	Texas	4941632167789249	f44621564bf5e622552e23b67242e34c	JCB 16 digit	31.9735611406344908	-102.019025868525731
25773	2020-05-19 20:11:49	2020-05-19	Don Lockman	don.lockman@woohoo.com	Joliet	Illinois	4218861550527702	9da46a2cb55c3ea9d37c614face9e4bb	Maestro	41.4216910743944311	-88.1958995104871661
25774	2020-05-19 20:12:27	2020-05-19	May Pouros	may.pouros@geemail.com	Corona	California	3033369538000908	30b47dd379b384c8719b0947671c833b	Discover	33.8701379893701571	-117.500793474234641
25775	2020-05-19 20:14:05	2020-05-19	Burnice Connelly	burnice.connelly@warmmail.com	San Francisco	California	6011471661064373748	84105b09fa4a376e17ba2879d90d8822	Discover	37.7631837658534977	-122.410999668687111
25776	2020-05-19 20:19:59	2020-05-19	Maddox Prosacco	maddox.prosacco@geemail.com	Indianapolis	Indiana	210080142482710061	03d19eb327e64a7ff9da4f99978345a0	VISA 16 digit	39.8234134355567377	-86.2132217013012649
25777	2020-05-19 20:33:05	2020-05-19	Clement Hoppe	clement.hoppe@warmmail.com	New York	New York	55198753444155697	3f784f2979fde9b718ebaa7d571173bf	VISA 16 digit	40.6552846667580283	-74.0007605385862206
25778	2020-05-19 20:34:31	2020-05-19	Dr. Inga Dietrich MD	dr.inga.dietrich.md@woohoo.com	Los Angeles	California	4838019929853	295401cfe9ee902ddbab99b4667cd509	Discover	33.9757682021573189	-118.406887011881167
25779	2020-05-19 20:42:08	2020-05-19	Millie Lang	millie.lang@geemail.com	Indianapolis	Indiana	3528984988805650724	8aad40948fccd759580643cdb519aedc	JCB 16 digit	39.6990345140926522	-86.069392448963228
25780	2020-05-19 20:43:59	2020-05-19	Jessi Klocko-Schiller	jessi.klocko.schiller@woohoo.com	San Francisco	California	675928280674277	8a926a823a5c4d17683d04ddb0cf6e02	Maestro	37.7867225874027355	-122.401440042488204
25781	2020-05-19 21:01:11	2020-05-19	Lexi Purdy	lexi.purdy@woohoo.com	Madison	Wisconsin	3051382480304931	896bc2ee2d944346edd0683de0761009	Mastercard	43.0885859176490484	-89.4273775241222211
25782	2020-05-19 21:27:55	2020-05-19	Kamryn Nader	kamryn.nader@woohoo.com	Atlanta	Georgia	4945569967313810	c3609c475425b4decc82134938112b63	VISA 16 digit	33.7836302927039611	-84.3894597989551727
25783	2020-05-19 21:29:09	2020-05-19	Daulton Moore I	daulton.moore.i@geemail.com	New York	New York	54456933514394635	325cd1c2607184d9867a532f7a23f0f0	JCB 15 digit	40.640823875995352	-73.9885078180476938
25784	2020-05-19 21:35:11	2020-05-19	Nile Stracke-Ritchie	nile.stracke.ritchie@geemail.com	San Jose	California	676299041172661	9e66a2696d991e63b2bd6984fcaadba6	VISA 16 digit	37.2184947192955775	-121.850029262084135
25785	2020-05-19 21:36:10	2020-05-19	Amiyah Pfannerstill-Cummerata	amiyah.pfannerstill.cummerata@geemail.com	Grand Prairie	Texas	55600997657846565	bccdbcc45f8e223f9a77e5274751af21	Mastercard	32.7229019023530228	-97.0330041239377152
25786	2020-05-19 21:47:38	2020-05-19	Oren Walker	oren.walker@warmmail.com	Saint Paul	Minnesota	869902300789542083	f969f2e27c1a75857ee72d814187d5fb	JCB 16 digit	44.8834698684919644	-93.1753028130888907
25787	2020-05-19 21:51:43	2020-05-19	Leatha O'Hara	leatha.o'hara@warmmail.com	Oakland	California	3158603845529176199	386e425db8cb39a830b3c5458bcbd6e8	VISA 13 digit	37.7984733983063208	-122.274562283713436
25788	2020-05-19 21:54:19	2020-05-19	Mrs. Willodean Bechtelar MD	mrs.willodean.bechtelar.md@geemail.com	Boston	Massachusetts	502049366458336	fdab6c6339cef7f1930a95f4492982a3	Discover	42.2382389912549385	-71.0271105559960034
25789	2020-05-19 21:56:18	2020-05-19	Rosalind Hahn	rosalind.hahn@woohoo.com	Jacksonville	Florida	180049163409560637	9ceec969ed0dcf5a91c16d200d51ab05	JCB 16 digit	30.3422707806393497	-81.677294244392229
25790	2020-05-19 22:13:39	2020-05-19	Merle Littel	merle.littel@woohoo.com	Los Angeles	California	4121690172154157	2c6ccafd300862f06d1c93319424df4b	Diners Club / Carte Blanche	33.9843771002586905	-118.422400455781442
25791	2020-05-19 22:17:42	2020-05-19	Macarthur Mante	macarthur.mante@warmmail.com	Phoenix	Arizona	180018413966962487	646b807831f1838b959dc782d5cd84bb	JCB 16 digit	33.6412059041138747	-112.025921540933112
25792	2020-05-19 22:18:11	2020-05-19	Ms. Corine Rutherford	ms.corine.rutherford@geemail.com	New York	New York	4426893647506447	c2dabdd93d241793b405853fd5ae2f4f	JCB 15 digit	40.7097675621267427	-73.8853697413474322
25793	2020-05-19 22:35:32	2020-05-19	Marcelino Ward	marcelino.ward@warmmail.com	San Francisco	California	210009153053288005	0c6ba0818694856494e4d1b05a5b8cee	JCB 16 digit	37.7810005147195866	-122.427946711585491
25794	2020-05-19 22:48:05	2020-05-19	Mrs. Savanah Orn MD	mrs.savanah.orn.md@warmmail.com	Louisville	Kentucky	3096814804717288253	c55dfcf51ae7dc03493fdd53ebc95a9f	VISA 16 digit	38.2593170004799958	-85.6446585745155886
25795	2020-05-19 22:54:10	2020-05-19	Tessa Kohler	tessa.kohler@warmmail.com	San Francisco	California	3096374023846965341	b20da34f1a0c9384146dfbdda28c81b7	VISA 13 digit	37.7942487917748693	-122.461205658046083
25796	2020-05-19 22:59:28	2020-05-19	Ivory Cruickshank	ivory.cruickshank@geemail.com	Oakland	California	6011908968325153436	4ccd4d77d037e1d7043d2a4c3a87e9d7	Voyager	37.8071468937909287	-122.237397309450714
25797	2020-05-19 23:12:11	2020-05-19	Samatha Rice	samatha.rice@woohoo.com	St. Louis	Missouri	210059196469774927	39694d9a2f6bdf80abfaf2c2290f5923	JCB 16 digit	38.7129033233661204	-90.1836941569581683
25798	2020-05-19 23:37:08	2020-05-19	Ms. Astrid Schroeder PhD	ms.astrid.schroeder.phd@geemail.com	Pembroke Pines	Florida	4673595822595901	a85c6fe83d57eea1d3eb2dee1b104fe0	JCB 15 digit	25.9596733925901368	-80.4382053812868918
25799	2020-05-19 23:47:13	2020-05-19	Teddie Lubowitz	teddie.lubowitz@geemail.com	Los Angeles	California	639047630629963	fbf8d9f1437431ee8110d8a52de42c65	JCB 15 digit	33.9728421057440286	-118.502527564577008
25800	2020-05-19 23:52:12	2020-05-19	Miss Ruie Daugherty MD	miss.ruie.daugherty.md@geemail.com	Jacksonville	Florida	3457013889696386	abdf2ddd172d065b557b414582f11dd7	American Express	30.3394788678321987	-81.6431945667214762
25801	2020-05-19 23:53:44	2020-05-19	Bernadine Swaniawski	bernadine.swaniawski@warmmail.com	San Francisco	California	4704761894550710	3fe753e6ff4e03a5292175a50e616599	Diners Club / Carte Blanche	37.7368725479040847	-122.45567186534808
25802	2020-05-19 23:55:30	2020-05-19	Charlie Crooks	charlie.crooks@geemail.com	Minneapolis	Minnesota	3712890568113211	db6baf914f09caf0fb4e331b8c844f5c	Discover	44.9454360311470893	-93.3148025048237315
25803	2020-05-20 00:02:39	2020-05-20	Frances Fadel	frances.fadel@geemail.com	San Francisco	California	869986533035762597	3625fba89c369d96ac02f3256bbeea79	JCB 16 digit	37.7581050387761579	-122.452804277227983
25805	2020-05-20 00:25:16	2020-05-20	Shirleyann Berge MD	shirleyann.berge.md@geemail.com	New York	New York	4952226102478723	044cb7f25844f8fcdd19bb2590115fce	VISA 13 digit	40.701968775805085	-73.9882776866096918
25806	2020-05-20 00:33:55	2020-05-20	Linna Collins	linna.collins@geemail.com	Salem	Oregon	6011045477404143320	1646a068e752e24a632010b4f07a9a6c	Mastercard	45.0214860347367818	-123.106137232404947
25807	2020-05-20 00:38:23	2020-05-20	Ms. Clydie Anderson	ms.clydie.anderson@geemail.com	Meridian	Idaho	3051964008630028	0d08209cda080649dc49e570b57bf12e	Voyager	43.6699164049241659	-116.351047207874799
25808	2020-05-20 00:43:44	2020-05-20	Andre King	andre.king@geemail.com	San Francisco	California	4658568597069310	e72172b1e1e1d4ca1d3a589b88a22b33	VISA 13 digit	37.7718616954940885	-122.396910304075817
25809	2020-05-20 00:45:41	2020-05-20	Marylin Kuhic	marylin.kuhic@geemail.com	Chesapeake	Virginia	589334198927187	7d2c0d975789a85c568f073a38928459	Mastercard	36.6539417112484571	-76.364353110346201
25810	2020-05-20 00:56:02	2020-05-20	Jon Kulas	jon.kulas@woohoo.com	Macon	Georgia	6011665023374845913	2f3646a1591592aebaf417ad3c4907de	JCB 15 digit	32.8647571544174113	-83.7788084342338095
25811	2020-05-20 00:57:10	2020-05-20	Rudolf Schmidt-Kohler	rudolf.schmidt.kohler@geemail.com	Albuquerque	New Mexico	4133977705076494	babfaf8032e32875e461d8e01bd588e6	VISA 16 digit	35.1310148864187326	-106.721383943322678
25812	2020-05-20 00:58:47	2020-05-20	Horacio Willms-Lubowitz	horacio.willms.lubowitz@warmmail.com	Visalia	California	4449069644293684	dcafba8a830e6d70e07e95163add4d4e	JCB 16 digit	36.3051506589587802	-119.387933603081478
25813	2020-05-20 01:12:52	2020-05-20	Wende Volkman	wende.volkman@geemail.com	Houston	Texas	3528288145618628305	0fd3593af6fc898cb597a6f1df14e486	JCB 16 digit	29.704493775226549	-95.357011739072945
25814	2020-05-20 01:28:34	2020-05-20	Timmie Schimmel	timmie.schimmel@geemail.com	San Antonio	Texas	6011798495204110462	6a37a0d660d86eff0feefc4e705a3558	JCB 16 digit	29.4623731334298853	-98.435202756693954
25815	2020-05-20 01:45:32	2020-05-20	Arley Rau MD	arley.rau.md@geemail.com	Augusta	Georgia	4176208490298798	cfb98ed98ca53f648548f5019823f3ca	Voyager	33.2854042231775793	-82.1668709174558529
25816	2020-05-20 02:20:22	2020-05-20	Linton Koss-Trantow	linton.koss.trantow@geemail.com	San Francisco	California	52738769764967484	4374116aa9290ba4ec372dbf80b95ea9	American Express	37.7938640606512095	-122.436948509164424
25817	2020-05-20 02:27:51	2020-05-20	Liller Corkery	liller.corkery@warmmail.com	Henderson	Nevada	3059280488201798	2a4ef15903b7204be68b30fc428e73fa	Maestro	36.0323289791986383	-114.997675269019609
25818	2020-05-20 02:30:53	2020-05-20	Marin McLaughlin	marin.mclaughlin@geemail.com	Chicago	Illinois	4522056419438	2581c3ef8596743538e372f34f051c48	Maestro	41.750565176487342	-87.5940540501877649
25819	2020-05-20 02:42:20	2020-05-20	Ulysses Kiehn	ulysses.kiehn@woohoo.com	Carrollton	Texas	210037520274985955	e569148d8d1c850ae630e80b5e6165ba	JCB 15 digit	33.0869991448629648	-96.9721898707423406
25820	2020-05-20 02:43:43	2020-05-20	Webb Friesen	webb.friesen@geemail.com	Tallahassee	Florida	51682086490517723	9d417529958ec9ee6bad592a9cc1c189	Voyager	30.3732406792718947	-84.275399115170913
25821	2020-05-20 03:19:12	2020-05-20	Leontine Nikolaus	leontine.nikolaus@geemail.com	San Francisco	California	3023938908552613	417125c9cb60ec3cc972c53d85ec0b74	VISA 16 digit	37.7714292936242302	-122.425234083536822
25822	2020-05-20 03:21:39	2020-05-20	Cash Thompson	cash.thompson@geemail.com	Washington	District of Columbia	210065955369714859	b4170f5a31f0a39b2cd77a573a01a893	Voyager	38.9382037310194207	-76.9458430475302038
25823	2020-05-20 03:26:00	2020-05-20	Rogers Schimmel	rogers.schimmel@geemail.com	Macon	Georgia	869987658707041092	699612900cabd628d67425e0d6f9bee5	VISA 16 digit	32.87623489168584	-83.735664600106702
25824	2020-05-20 03:32:08	2020-05-20	Kamren Stracke-Rowe	kamren.stracke.rowe@geemail.com	San Francisco	California	55461505662557891	c9dc1379082f3cced3487478a495cc49	Discover	37.7818036828137949	-122.441295444640673
25825	2020-05-20 03:34:25	2020-05-20	Gail Hackett	gail.hackett@warmmail.com	Los Angeles	California	6011007642562365645	6fd554ae71d579bfa28f4be8222766b3	VISA 16 digit	34.0142597047477935	-118.420076737272737
25826	2020-05-20 03:36:41	2020-05-20	Raphael Rodriguez	raphael.rodriguez@geemail.com	Anaheim	California	869907775091099051	f5fd94568f86516b461261098430fd4f	VISA 13 digit	33.8064506171569192	-117.704088413829353
25827	2020-05-20 03:48:19	2020-05-20	Mr. Dessie Purdy II	mr.dessie.purdy.ii@geemail.com	San Francisco	California	6011475532869185122	89578840dc6c4186d05e2ca696d0b7b0	Mastercard	37.7636119436709237	-122.466821506214018
25828	2020-05-20 03:53:31	2020-05-20	Dr. Rashaan Swift PhD	dr.rashaan.swift.phd@geemail.com	Las Vegas	Nevada	4327131746619	2acc5f99d8caf2d74606799646ff0266	Maestro	36.3210948299717131	-115.249040383773291
25829	2020-05-20 04:19:05	2020-05-20	Mrs. Arvilla Gerhold	mrs.arvilla.gerhold@geemail.com	Glendale	Arizona	6011069812152200586	ba2894db7bcefd693eb7d42b128b2927	JCB 16 digit	33.5567328864470085	-112.101749349085239
25830	2020-05-20 04:26:41	2020-05-20	Miss Meg Abernathy	miss.meg.abernathy@geemail.com	Los Angeles	California	4265699974672411	efcadfd28eb37edb8f9c02922639b76c	Voyager	34.0111011356446866	-118.326805008341736
25831	2020-05-20 04:28:34	2020-05-20	Ivanna Hagenes PhD	ivanna.hagenes.phd@geemail.com	San Francisco	California	3158493684784900362	48b8c799c031af6eff4255c4d602d005	JCB 16 digit	37.7895499315118002	-122.446539949069106
25832	2020-05-20 04:37:51	2020-05-20	Miss Braelyn Bashirian	miss.braelyn.bashirian@geemail.com	Tampa	Florida	4610216251823	f3bf089fa2157c948359c8f9586a3c67	Mastercard	28.0344141911365092	-82.4760561384007218
25833	2020-05-20 05:06:14	2020-05-20	Terell Rutherford	terell.rutherford@geemail.com	Berkeley	California	4998469406602	6cdaa4ce5cdbff7d4d92a0d2a3b565f3	JCB 15 digit	37.8577238976994437	-122.245152069890352
25834	2020-05-20 05:13:11	2020-05-20	Sammie Robel DDS	sammie.robel.dds@geemail.com	Tacoma	Washington	3158237210474574100	4bbd22267ed6ecab5bfd4f147563f83d	Diners Club / Carte Blanche	47.3255371604699633	-122.39576594999545
25835	2020-05-20 05:14:32	2020-05-20	Mace D'Amore	mace.d'amore@geemail.com	Chicago	Illinois	4371187212849794	c34d43584ba6120cac77646899d1449c	Discover	41.8322003907360127	-87.6029884927004474
25836	2020-05-20 05:15:35	2020-05-20	Vonda Erdman	vonda.erdman@geemail.com	San Francisco	California	3035587675948534	a1db2d551dfc5c17e461ec503cbe77ac	Discover	37.7769517262270469	-122.447254801184442
25837	2020-05-20 05:35:53	2020-05-20	Dr. Abdiel Nikolaus	dr.abdiel.nikolaus@geemail.com	New York	New York	3049045396508133	7f791b4be6caf48d2af95a6900c45f99	Voyager	40.6747042065709792	-73.8827283078700248
25838	2020-05-20 05:45:35	2020-05-20	Tayla Welch	tayla.welch@geemail.com	Bakersfield	California	4434474023885323	6b7bb7795d40afa2f2348d2dafc317c5	JCB 16 digit	35.2273449792701712	-119.093077371622613
25839	2020-05-20 05:51:45	2020-05-20	Emery Wintheiser	emery.wintheiser@geemail.com	Virginia Beach	Virginia	4923982719349	6e3f257cc4f51379a9511fec692b6c1e	Maestro	36.7703008880093734	-75.956284058107812
25840	2020-05-20 05:53:58	2020-05-20	Ola Balistreri-Conroy	ola.balistreri.conroy@geemail.com	Detroit	Michigan	630459594844157	c1144e7879dd7a65a78195f904b5426a	JCB 15 digit	42.2938833216130732	-83.1336878168981457
25841	2020-05-20 06:26:30	2020-05-20	Burdette Torphy	burdette.torphy@woohoo.com	Tempe	Arizona	869979674447132695	62e03838e749a944b172d08fbd801626	JCB 16 digit	33.3082834275826798	-111.882755392513417
25842	2020-05-20 06:38:10	2020-05-20	Akeem Runte	akeem.runte@geemail.com	Chicago	Illinois	502065620406853	010a9291d13dab9d07b60edbed260c67	VISA 13 digit	41.8906111215077388	-87.703742490572111
25843	2020-05-20 06:43:48	2020-05-20	Noreta Crooks	noreta.crooks@woohoo.com	Riverside	California	6011882528345258530	ecf5aa668603c971b1672f3bcc4eb7c7	JCB 16 digit	33.9219210665620849	-117.436308723545437
25844	2020-05-20 06:45:21	2020-05-20	Kent Schimmel	kent.schimmel@geemail.com	New York	New York	4778336582292	a30d90f0475c718181a4cd6caebd4696	Diners Club / Carte Blanche	40.6803024780228739	-73.8705645171821033
25845	2020-05-20 06:52:23	2020-05-20	Manuela Orn-Nicolas	manuela.orn.nicolas@geemail.com	Houston	Texas	6011212491878127385	a2ef5e6c8722cb7e957247018f632603	Voyager	29.7718641667239368	-95.4024654050838166
25846	2020-05-20 06:54:39	2020-05-20	Nelda Gerhold-Sporer	nelda.gerhold.sporer@geemail.com	Chicago	Illinois	3014343399258458	8436907af1a125e49b1e05755a844ef3	JCB 15 digit	41.7436638694558297	-87.7262547755643709
25847	2020-05-20 07:08:29	2020-05-20	Layne Dach	layne.dach@woohoo.com	Peoria	Illinois	4675390447178962	4a7a62befcecb02199af82da31db7489	Voyager	40.7521684315856518	-89.5886627077009621
25848	2020-05-20 07:12:39	2020-05-20	Dr. Benito Reilly V	dr.benito.reilly.v@geemail.com	Spokane	Washington	3158170382943144655	4c7018270f64a5efaf59bad2571f2f2d	American Express	47.6752836589008524	-117.403195685324448
25849	2020-05-20 07:12:48	2020-05-20	Shannan Reilly	shannan.reilly@warmmail.com	Independence	Missouri	4113653152307351	2f10f19fee965be2317f00dbb5b2d2c7	VISA 16 digit	39.0112330693770204	-94.3902948503199895
25850	2020-05-20 07:24:16	2020-05-20	Gabe Kuhlman	gabe.kuhlman@geemail.com	St. Petersburg	Florida	180078215204902481	f88c5c6241f6e762970c59fe34bad4a6	Diners Club / Carte Blanche	27.7341996093634506	-82.6871749406106744
25851	2020-05-20 07:34:04	2020-05-20	Gerry Schneider-Jacobson	gerry.schneider.jacobson@woohoo.com	El Monte	California	4353969737861434	dbb86d339cbb899a9555a1141991fbd0	Discover	34.1444452759068398	-118.050070300491896
25852	2020-05-20 07:42:52	2020-05-20	Penny Botsford	penny.botsford@geemail.com	San Francisco	California	4918609118835742	696127556fe2f36f46aa61a6d3f3087b	VISA 16 digit	37.7605033002985877	-122.429324036402605
25853	2020-05-20 07:50:12	2020-05-20	Phil Hessel MD	phil.hessel.md@woohoo.com	Berkeley	California	676350778790779	1e321193bf03adc60aa01d93ce3a9300	JCB 16 digit	37.8290253139130428	-122.285989161795754
25854	2020-05-20 07:55:46	2020-05-20	Mrs. Lina Casper DDS	mrs.lina.casper.dds@geemail.com	Springfield	Illinois	3337014934521761076	ce39505e705ccbaefb6522814eb5a1c9	JCB 15 digit	39.8739720583114803	-89.5744835302702995
25855	2020-05-20 08:08:16	2020-05-20	Helaine Koepp	helaine.koepp@geemail.com	Greensboro	North Carolina	4513771385830	fe629727723083c1e0a7f44c74a41396	American Express	36.168929749878501	-79.9258807164132605
25856	2020-05-20 08:09:42	2020-05-20	Boston Gislason	boston.gislason@geemail.com	Berkeley	California	3037181842830128	cbcef90d7b01a76d9c6616808c846d63	Mastercard	37.8890527605956677	-122.284140570474719
25857	2020-05-20 08:22:34	2020-05-20	Lars Larkin V	lars.larkin.v@geemail.com	Salinas	California	869933101903702550	09c0e1ab12ce09f5c366d7a3bdba0327	American Express	36.6282891422275441	-121.691251623834304
25858	2020-05-20 08:24:36	2020-05-20	Leonidas Waters Jr.	leonidas.waters.jr.@woohoo.com	Vallejo	California	6011008320981384955	f550b2fefc31701572e9590d8e843fb7	JCB 16 digit	38.0687559607993791	-122.309881402026861
25859	2020-05-20 08:26:32	2020-05-20	Hugh Lockman	hugh.lockman@woohoo.com	Billings	Montana	869972901008117204	c4557df16b85555ef7e88870a9bf90f9	JCB 16 digit	45.7786393441949002	-108.625026226386055
25860	2020-05-20 08:44:34	2020-05-20	Dr. Lular Gibson MD	dr.lular.gibson.md@geemail.com	Newark	New Jersey	3021347845583172	542bceb6bd5b5916d4f40dd9372271bc	Maestro	40.6710189253006149	-74.2406433570873077
25861	2020-05-20 08:53:17	2020-05-20	Keeley Terry	keeley.terry@geemail.com	San Jose	California	210086048682690850	132c477a39f71ff1968880c5c717f171	Voyager	37.2838478885412243	-121.906904781818014
25862	2020-05-20 08:53:50	2020-05-20	Ruthie Cormier	ruthie.cormier@warmmail.com	Wichita	Kansas	4325871205240296	9403923b02ad6313c893e3f12da16639	JCB 16 digit	37.7669385696638358	-97.3798419365394921
25863	2020-05-20 09:09:26	2020-05-20	Mr. Joe Hermann MD	mr.joe.hermann.md@warmmail.com	Fort Worth	Texas	3096775902161404496	52d241428169517a90a46eaaeddb83ad	JCB 16 digit	32.8213811673279849	-97.2971577667452436
25864	2020-05-20 09:13:50	2020-05-20	Miss Daniela Gusikowski	miss.daniela.gusikowski@geemail.com	Dallas	Texas	210097777213637348	8d8015483de1d53beb3eb3de9177d451	Discover	32.7582735051207266	-96.8404041328895744
25865	2020-05-20 09:17:32	2020-05-20	Dorris Baumbach	dorris.baumbach@geemail.com	Thornton	Colorado	3003963250564057	b365f6dd2c465a718e467495a756eb15	VISA 16 digit	39.9056317119725108	-104.978489039109277
25866	2020-05-20 09:20:22	2020-05-20	Christoper Cruickshank-Jacobson	christoper.cruickshank.jacobson@warmmail.com	Columbia	South Carolina	210083627995283389	b10c67f8f041a7fa667735595d59850e	Discover	34.0195261958319719	-80.9067658931501228
25867	2020-05-20 09:29:09	2020-05-20	Lyndia Johnston	lyndia.johnston@woohoo.com	Oklahoma City	Oklahoma	4849629985716803	f962649d9def3a28e7f270b89a03e2dc	VISA 16 digit	35.5377702615134439	-97.4842905437935201
25868	2020-05-20 09:47:16	2020-05-20	Tavaris Beier-Hegmann	tavaris.beier.hegmann@geemail.com	Philadelphia	Pennsylvania	6011392494655441146	751f209f71024f3b31d83e375f7a6a1c	JCB 16 digit	39.9152537790086086	-75.056863980730256
25869	2020-05-20 09:56:15	2020-05-20	Nello Gulgowski	nello.gulgowski@geemail.com	Irvine	California	6011609444703015607	e93b9aa43cf7d0215ac6e6433c90d15b	Voyager	33.6217431791607311	-117.864388479619464
25870	2020-05-20 10:14:13	2020-05-20	Lossie Kunde	lossie.kunde@warmmail.com	Houston	Texas	3337919129078398614	879cc992f713021ed8a20299c00594bf	VISA 16 digit	29.8725742702450603	-95.4204930490829071
25871	2020-05-20 10:17:30	2020-05-20	Arturo Rath	arturo.rath@geemail.com	Houston	Texas	4319773373179785	00b24f8616371fa0579a98f67d98347c	VISA 13 digit	29.7434137724418193	-95.4390866859830993
25872	2020-05-20 10:21:51	2020-05-20	Kamari Bogisich	kamari.bogisich@geemail.com	Santa Clarita	California	676336926277546	b57659674996fd2d57628124b6ab22cd	Discover	34.4227992420755342	-118.47459236952551
25873	2020-05-20 10:25:40	2020-05-20	Mr. Lee Grimes	mr.lee.grimes@geemail.com	Murfreesboro	Tennessee	3771300986990495	1982502d43925761e2c6a6fb68ce6cee	Discover	35.9181420761279782	-86.3230159338414609
25874	2020-05-20 10:31:01	2020-05-20	Son Rogahn-Upton	son.rogahn.upton@woohoo.com	Toledo	Ohio	180059062580631844	42351855e59c03614f4712c717d2f6d1	VISA 13 digit	41.7295863028321392	-83.6766070667985815
25875	2020-05-20 10:33:29	2020-05-20	Dorthy Wiegand	dorthy.wiegand@geemail.com	Los Angeles	California	4977533442319785	5cdb9c1297233cc4322cfc4b116c14af	VISA 16 digit	33.9621613485138809	-118.48929684045649
25876	2020-05-20 10:35:38	2020-05-20	Rodney Grady-Treutel	rodney.grady.treutel@geemail.com	Columbus	Ohio	3112340212855980694	bf443b0268485ad18574a9cbfc79ee57	Diners Club / Carte Blanche	39.9872994452293966	-83.0138060922503485
25877	2020-05-20 10:47:16	2020-05-20	Clabe Nolan Sr.	clabe.nolan.sr.@geemail.com	Chicago	Illinois	210003468035405758	f0b7dc09b5c458500737d68100b52a0c	Mastercard	41.7925214236438265	-87.5912742506742461
25878	2020-05-20 10:48:19	2020-05-20	Janet McLaughlin	janet.mclaughlin@warmmail.com	New York	New York	4157803672237284	d2f71a3b249d6e7b1ce1c082e384e51c	JCB 16 digit	40.6691856077164431	-73.8425341638632062
25879	2020-05-20 11:06:41	2020-05-20	Lincoln Zboncak	lincoln.zboncak@geemail.com	Milwaukee	Wisconsin	503856334289693	22704c86b3fbf88942ebc1d4d1450443	JCB 15 digit	42.980589460683241	-88.0112949084125518
25880	2020-05-20 11:36:55	2020-05-20	Channie Lubowitz	channie.lubowitz@geemail.com	Berkeley	California	3158774766145086484	49228b2c8f27d36c4c1e4c4fbbe456b8	Maestro	37.8762780663346845	-122.252773770512349
25881	2020-05-20 12:09:41	2020-05-20	Miss Lynette Collier DVM	miss.lynette.collier.dvm@woohoo.com	New York	New York	4556311692439796	64c6323503964a2cf16aff72c97848a6	VISA 13 digit	40.6549520032238192	-73.9347382220800995
25882	2020-05-20 12:12:34	2020-05-20	Male Rodriguez	male.rodriguez@geemail.com	San Francisco	California	210025273292829219	07fcd264b6aadd4d4338220e7b3df42f	JCB 16 digit	37.7740449975468948	-122.459689776052898
25883	2020-05-20 12:22:56	2020-05-20	Lacy Cruickshank	lacy.cruickshank@geemail.com	Los Angeles	California	3337872475608452149	306e19ccbc2f613b23439c342968686d	Maestro	34.0471007022872527	-118.36088266097866
25884	2020-05-20 12:39:47	2020-05-20	Mai Mitchell	mai.mitchell@woohoo.com	Mesa	Arizona	4258249423328345	e8d8a991cc9de5eb8a05aa859cf7cd76	Maestro	33.3996486586663863	-111.798397674679379
25885	2020-05-20 12:55:42	2020-05-20	Nola Block	nola.block@geemail.com	San Francisco	California	3777461761679606	15527f1f658ba0c99ee5380f604763b5	VISA 13 digit	37.7804670372192319	-122.447684964827218
25886	2020-05-20 12:57:51	2020-05-20	Dr. Emit Bogisich	dr.emit.bogisich@geemail.com	Washington	District of Columbia	630465473260837	34db3c483a6b1d5d1f9ed43561de6a40	JCB 16 digit	38.8706638251695793	-77.0425378391731499
25887	2020-05-20 13:13:01	2020-05-20	Ismael Hermann-Howell	ismael.hermann.howell@geemail.com	San Francisco	California	3337335756150098849	150a07c41c7b92f9aebd51a569cc97a8	VISA 13 digit	37.7894953052777467	-122.453551127092155
25888	2020-05-20 13:17:43	2020-05-20	Ambers Mitchell	ambers.mitchell@warmmail.com	Corpus Christi	Texas	676277819771039	1cbcb2f1456faa81cf5430bf1be52cfc	Discover	27.7086373797554515	-97.2668671238064775
25889	2020-05-20 13:19:27	2020-05-20	Dessie Treutel-Barrows	dessie.treutel.barrows@geemail.com	New York	New York	180070806274457576	8044be2f11fb7b4b8e0798191a026efe	JCB 15 digit	40.6270159334167857	-73.9997342627391248
25890	2020-05-20 13:29:32	2020-05-20	Faith Treutel	faith.treutel@geemail.com	San Mateo	California	3026224043697267	9e3b485322a520a864b22882c6483d8e	VISA 16 digit	37.5923846815127831	-122.397108538387712
25891	2020-05-20 13:56:51	2020-05-20	Harrie Schulist	harrie.schulist@woohoo.com	Evansville	Indiana	3158201231308043940	9473d400fbb1aee292a7cd6195c789b2	Mastercard	37.9789086530122901	-87.4747712247472293
25892	2020-05-20 14:02:35	2020-05-20	Lidia McDermott	lidia.mcdermott@geemail.com	Raleigh	North Carolina	180056174998599803	e1357695b8cfe84b9600d1692d492067	Voyager	35.903252236418794	-78.7040184482868739
25893	2020-05-20 14:13:48	2020-05-20	Dr. Dominic Walsh Sr.	dr.dominic.walsh.sr.@woohoo.com	Berkeley	California	4495498590638217	63e1d57bd59509dd0c052b1fe21648e5	Maestro	37.9088726836335894	-122.272759820344476
25894	2020-05-20 14:17:43	2020-05-20	Trace Fadel-Gerhold	trace.fadel.gerhold@warmmail.com	Houston	Texas	3053399406145287	429324142c2284329fd44b13ca30a2e1	VISA 16 digit	29.7129368732295944	-95.486316191127159
25895	2020-05-20 14:30:27	2020-05-20	Kirstin Spencer	kirstin.spencer@geemail.com	El Paso	Texas	3766674647648834	dfb4cb045546991599ead2758551e42e	Mastercard	31.9088036804288642	-106.469592096142478
25896	2020-05-20 14:30:30	2020-05-20	Dr. Zackary O'Keefe	dr.zackary.o'keefe@geemail.com	Cleveland	Ohio	55441866584848890	814509f74b158d07060398cb94780e6d	VISA 13 digit	41.4455692151878026	-81.6906213067710354
25897	2020-05-20 14:35:26	2020-05-20	Dr. Finn Adams DVM	dr.finn.adams.dvm@geemail.com	Des Moines	Iowa	3460779050994207	23a3152f2df74755c747e11b53234622	Maestro	41.4970227408431498	-93.5577212716031852
25898	2020-05-20 14:36:25	2020-05-20	Khari Predovic	khari.predovic@geemail.com	Columbus	Georgia	630429865713019	d51c7111a534ff058fd2a77733c3509a	JCB 16 digit	32.4377261234492025	-84.9201300839126105
25899	2020-05-20 14:37:53	2020-05-20	Dominick Grant	dominick.grant@geemail.com	Charlotte	North Carolina	676249145755408	b3429e80e1cbb77a0c075761c2e03f6f	VISA 16 digit	35.2182037385433873	-80.9142645541522683
25900	2020-05-20 14:40:20	2020-05-20	Kaleena Cummings	kaleena.cummings@geemail.com	Omaha	Nebraska	180001787839566073	0b840e66feca5c1a1725876607015cea	VISA 16 digit	41.2849959393177173	-96.143613737926259
25901	2020-05-20 14:41:31	2020-05-20	Goldia Larkin	goldia.larkin@geemail.com	Denver	Colorado	180099630471312609	cde015a0a6d3c07dba5800b687d4fb77	Discover	39.7126241191808091	-104.934717835743356
25902	2020-05-20 14:44:40	2020-05-20	Dr. Phylis Muller DVM	dr.phylis.muller.dvm@geemail.com	Los Angeles	California	3112357463038126636	5df11ab1f25ec5acc6bd5caff3cc5eee	Maestro	34.0867172271810475	-118.487358290980751
25903	2020-05-20 14:48:37	2020-05-20	Dr. Vergil Altenwerth I	dr.vergil.altenwerth.i@geemail.com	Woodbridge	New Jersey	4720949832011	cb887f1c938eb55abae83e2024d4c0c7	American Express	40.5550544498644712	-74.3891297011960262
25904	2020-05-20 14:54:00	2020-05-20	Verda Skiles DDS	verda.skiles.dds@geemail.com	Pomona	California	54733899238478274	f352f3c1a66242abc73a56c9353eedec	Voyager	33.9797084653321662	-117.780522153104101
25905	2020-05-20 15:04:05	2020-05-20	Ricky Kreiger MD	ricky.kreiger.md@geemail.com	San Francisco	California	869967375417035629	7c1ce805e54fe7bf32c9336d8e2f1f44	Voyager	37.7826501691356427	-122.447427015801821
25906	2020-05-20 15:21:05	2020-05-20	Kyson Frami	kyson.frami@geemail.com	Omaha	Nebraska	4794252816753930	dd85debead238f3981ee09284f34b19e	VISA 13 digit	41.2975058850046253	-96.0763154342420478
25907	2020-05-20 15:21:53	2020-05-20	Ms. Dezzie Mayer	ms.dezzie.mayer@geemail.com	San Francisco	California	869996456587408385	9c8d113325d00dcd4095444a8e1522b1	Mastercard	37.7710602616576523	-122.417814433541054
25908	2020-05-20 15:27:09	2020-05-20	Tremaine Hyatt Sr.	tremaine.hyatt.sr.@warmmail.com	Burbank	California	4661057366959542	e6c37de66d15cc640ad91acda29d359f	Voyager	34.1931239533167357	-118.267713572786761
25909	2020-05-20 15:30:57	2020-05-20	Caro Keebler	caro.keebler@geemail.com	Phoenix	Arizona	3705337152220829	c9669ba88b22219068fb8a99c95cf483	Maestro	33.499879829392583	-112.026597652996344
25910	2020-05-20 16:02:41	2020-05-20	Parrish Murray-Schamberger	parrish.murray.schamberger@geemail.com	Houston	Texas	180010326518760381	43f4a00a2ea718dcfb409b4f08d6406b	JCB 15 digit	29.7916200916826739	-95.291438883544501
25911	2020-05-20 16:11:25	2020-05-20	Janay Green PhD	janay.green.phd@geemail.com	Los Angeles	California	4142941475675	c07a21bd328ad36229ebd6ba6ea174b0	Voyager	33.9760963637247642	-118.381256868223844
25912	2020-05-20 16:23:34	2020-05-20	Benito Ebert	benito.ebert@warmmail.com	Phoenix	Arizona	4115714122362088	ffbb925c12842020804e8d2f89da7d8b	JCB 16 digit	33.532782343814894	-112.045881458411372
25913	2020-05-20 16:24:51	2020-05-20	Mr. Coby Boehm	mr.coby.boehm@warmmail.com	Lafayette	Louisiana	869916662419924724	503a4a3e27ef0a47e45148cf7fb97146	JCB 16 digit	30.1595172712557016	-92.0485000449083657
25914	2020-05-20 16:34:47	2020-05-20	Weldon Kuphal IV	weldon.kuphal.iv@geemail.com	Burbank	California	4820406561671	811e918f06111e0996a5a0755819863b	Diners Club / Carte Blanche	34.1930851007740984	-118.354278719242302
25915	2020-05-20 16:40:15	2020-05-20	Mora Muller	mora.muller@warmmail.com	Oakland	California	3055650933215375	25abadc3b385aede2f3780dc0bbcf332	Mastercard	37.7719465325100927	-122.252260845747301
25916	2020-05-20 16:50:01	2020-05-20	Romeo Torphy	romeo.torphy@geemail.com	Plano	Texas	3027392010707663	528621e751d0819a6e6f41c78ca10e3a	VISA 13 digit	33.1352990166835539	-96.8185887643784326
25917	2020-05-20 17:05:16	2020-05-20	Mr. Harlon Weissnat	mr.harlon.weissnat@geemail.com	Portland	Oregon	51719442818124410	a50824d567fc31e640b975de9cb04e95	Voyager	45.4968385364748542	-122.578161396551877
25918	2020-05-20 17:22:53	2020-05-20	Kathlyn Glover	kathlyn.glover@geemail.com	Santa Ana	California	4014623103907260	e845f4891780af8a031d474dfbfaec63	VISA 16 digit	33.8305217841744437	-117.832421129189427
25919	2020-05-20 17:25:36	2020-05-20	Cal McCullough	cal.mccullough@geemail.com	Huntsville	Alabama	4441705442133311	609b5a630ef7757e3f8788e6eaeab1fb	American Express	34.6336749756950866	-86.7030696736201634
25920	2020-05-20 17:30:18	2020-05-20	Roma Hessel PhD	roma.hessel.phd@geemail.com	New York	New York	3055855236606747	c7bda775d90e7cc00655218fea6cc7bf	American Express	40.7444397283010176	-74.0182943302102387
25921	2020-05-20 17:32:14	2020-05-20	Tinie Deckow	tinie.deckow@geemail.com	Rochester	Minnesota	3528609280919933906	41c9f1ff17bd9cead06746b91852e730	Diners Club / Carte Blanche	44.0719987211186464	-92.417061919777467
25922	2020-05-20 17:40:56	2020-05-20	Brenton Frami	brenton.frami@geemail.com	Houston	Texas	3052849571479003	ea1df45b9469de6f01d47d9f65ff72e3	VISA 16 digit	29.689033325257153	-95.4118232360124665
25923	2020-05-20 17:43:43	2020-05-20	Hobart Aufderhar	hobart.aufderhar@geemail.com	Fort Worth	Texas	4456812692444	d51a39fbc781280d626f9edf30c7fc1e	VISA 16 digit	32.7115946761388372	-97.2914220894042359
25924	2020-05-20 17:54:14	2020-05-20	Darlene Gutkowski-Beier	darlene.gutkowski.beier@geemail.com	Hartford	Connecticut	869944035122951043	bf4c8fa8befdc4af0f2f044a263a0cf5	JCB 15 digit	41.6787090654034174	-72.7554719609100431
25925	2020-05-20 17:59:41	2020-05-20	Javion Botsford	javion.botsford@warmmail.com	Washington	District of Columbia	3158967064167312971	a35884e03f002b59c3c738165b60ed0b	American Express	38.8502060666479139	-77.0312123310033314
25926	2020-05-20 18:21:22	2020-05-20	Marybeth Pfannerstill	marybeth.pfannerstill@warmmail.com	Los Angeles	California	630405955981971	c9968376aff4646b398a416c08150c7a	JCB 15 digit	34.0050905005406534	-118.328602470456801
25927	2020-05-20 18:38:50	2020-05-20	Mrs. Aja Legros MD	mrs.aja.legros.md@geemail.com	Austin	Texas	3528711429636811847	9f87dfddde7a0146f562b5a0d48276e2	JCB 15 digit	30.2044033962428564	-97.8167970706015808
25928	2020-05-20 18:53:02	2020-05-20	Zakary Halvorson	zakary.halvorson@warmmail.com	Charlotte	North Carolina	869979194122085381	b558e2275903b1473908d522c748ab8d	VISA 16 digit	35.135396353553233	-80.7387080828603416
25929	2020-05-20 18:57:32	2020-05-20	Elza Kuhn	elza.kuhn@warmmail.com	Philadelphia	Pennsylvania	3528995306396859546	1cf5aebbf09a50a740426800d6553da9	VISA 13 digit	40.0541983061429079	-75.0699457901429383
25930	2020-05-20 18:58:39	2020-05-20	Iver Labadie	iver.labadie@geemail.com	San Francisco	California	869911717048965905	52bdd8a4e1fe94654c2106519c3f9619	Diners Club / Carte Blanche	37.7395360580308363	-122.416081630355279
25931	2020-05-20 19:28:28	2020-05-20	Versie Boehm	versie.boehm@geemail.com	Burbank	California	54007103540295347	7967b34b5b92f37d8d6f2aa21921f4ca	VISA 16 digit	34.282683328438921	-118.241039759203431
25932	2020-05-20 19:48:49	2020-05-20	Westin Pfeffer	westin.pfeffer@geemail.com	New York	New York	060402001394176	116f89c39e4656a1bfbd713d297d7d16	VISA 16 digit	40.6715332126468425	-73.9687535742659037
25933	2020-05-20 19:52:59	2020-05-20	Dr. Avis Prosacco PhD	dr.avis.prosacco.phd@warmmail.com	Denver	Colorado	3720986664168396	eff81e433c0dba969e76b394e6e5b412	JCB 16 digit	39.7786552940547438	-104.815949207615489
25934	2020-05-20 20:01:16	2020-05-20	Mr. Luigi Gutkowski	mr.luigi.gutkowski@geemail.com	Phoenix	Arizona	210078631831976922	c8add482aaf4bea890fcfcf2bf6f40be	American Express	33.5088550446022353	-112.168891074920452
25935	2020-05-20 20:07:17	2020-05-20	Mr. Ford Crist III	mr.ford.crist.iii@geemail.com	Kansas City	Missouri	52619322606946821	9d94c346ec3539f364590f4c0edc1d65	VISA 16 digit	39.1568143728025291	-94.5606753453835864
25936	2020-05-20 20:22:26	2020-05-20	Ms. Dariana Rosenbaum	ms.dariana.rosenbaum@warmmail.com	Seattle	Washington	4288063398896	9c4d3f02c05efc99f109a2e991aa4723	Voyager	47.6909862723126992	-122.341723581209408
25937	2020-05-20 20:25:37	2020-05-20	Georgene Bahringer	georgene.bahringer@woohoo.com	Vallejo	California	54269318035186867	a91d4dffadf3db8cad334e4f3288ae70	Diners Club / Carte Blanche	38.1194252495277652	-122.291761020092295
25938	2020-05-20 20:30:02	2020-05-20	Mac Renner	mac.renner@geemail.com	Providence	Rhode Island	6011815182430745050	9c748cf075354e664593b7be485602ba	JCB 16 digit	41.7320318255428191	-71.4095782937865806
25939	2020-05-20 20:36:42	2020-05-20	Ura Muller DVM	ura.muller.dvm@geemail.com	San Francisco	California	503821817424605	1500a5be163ec29d81eb465c3b86c7cf	Voyager	37.7744314273188664	-122.45495925460105
25940	2020-05-20 20:47:23	2020-05-20	Lucile Muller MD	lucile.muller.md@geemail.com	New York	New York	180013292619259326	8602be0b3896f1c22f8aa7d0ebd38f1e	VISA 16 digit	40.59048540035635	-73.9152689912252043
25941	2020-05-20 20:48:39	2020-05-20	Dr. Rickie Jones	dr.rickie.jones@woohoo.com	Beaumont	Texas	4510210533020	f6c4112c00aeb279864a241454cc3e1a	Diners Club / Carte Blanche	30.1657137836400437	-94.1311511744998484
25942	2020-05-20 20:51:14	2020-05-20	Hilah Rohan	hilah.rohan@geemail.com	New York	New York	3337772873948436072	3dc79ccd283c81d3d8e711af56ecf455	JCB 15 digit	40.6197535955570643	-73.8944634397409885
25943	2020-05-20 20:57:52	2020-05-20	Dustyn McLaughlin	dustyn.mclaughlin@geemail.com	New York	New York	3158011631447856278	5af1ae5f2df7d40ec0584751b194fac1	JCB 16 digit	40.6644645796846618	-74.0151745654538189
25944	2020-05-20 21:02:31	2020-05-20	Winifred Kunze	winifred.kunze@warmmail.com	Oakland	California	180053167634989027	5aba3bf1e6af16b749b2ab869fd80a69	American Express	37.8089766390980557	-122.262523070069491
25945	2020-05-20 21:03:09	2020-05-20	Melville DuBuque-Powlowski	melville.dubuque.powlowski@woohoo.com	San Mateo	California	3112763630339738230	fb7c3ee0267b1df4174289dd19b39f6d	Maestro	37.5779978042349185	-122.316690743979436
25946	2020-05-20 21:12:49	2020-05-20	Miss Vickey Harvey	miss.vickey.harvey@geemail.com	Thornton	Colorado	4645667365503652	e750ee89573f56d946ea3f2d909fcb4a	VISA 16 digit	39.955876385127759	-104.906231965466588
25947	2020-05-20 21:19:05	2020-05-20	Rochelle Stanton	rochelle.stanton@woohoo.com	Oakland	California	210022800871982168	197038871d2f6cae14c14e8a79d569d6	Mastercard	37.8208699824380403	-122.253145717884564
25948	2020-05-20 21:19:13	2020-05-20	Angelo Fahey	angelo.fahey@geemail.com	Berkeley	California	3528981512368423718	e463db430587051806a0a7f2ead63d58	Voyager	37.8965069902557232	-122.287530062577488
25949	2020-05-20 21:21:21	2020-05-20	Stacy Ankunding	stacy.ankunding@geemail.com	El Paso	Texas	3528980309482853438	327a49dce065eb9e85e155f194574454	Diners Club / Carte Blanche	31.936906744336337	-106.509695590844387
25950	2020-05-20 21:28:15	2020-05-20	Deward Towne	deward.towne@woohoo.com	Toledo	Ohio	4105288400036716	87c16c0d21522bb728c215ee18b78aff	Discover	41.713120383460442	-83.6370965659949945
25951	2020-05-20 21:33:08	2020-05-20	Kadence Parker	kadence.parker@geemail.com	Houston	Texas	4475157144431875	af2fdd8be503f1d3ed03363b078ae5f9	VISA 13 digit	29.7350220866579562	-95.3856217225562801
25952	2020-05-20 21:47:00	2020-05-20	Dellar Harber	dellar.harber@geemail.com	Los Angeles	California	3528477410809394484	095280fefde1491782bfebdf20e1b137	Diners Club / Carte Blanche	33.9355965064238703	-118.457002614111815
25953	2020-05-20 21:47:12	2020-05-20	Blanca Erdman	blanca.erdman@geemail.com	Waco	Texas	3112564223597075247	54b2e898b5e5634caed1ad677eaf5850	Mastercard	31.4611393178556114	-97.2406571657992913
25954	2020-05-20 21:51:41	2020-05-20	Matilde Daugherty-Green	matilde.daugherty.green@geemail.com	San Francisco	California	55052502425525781	5aa8d9fddf3b50662f1a5c45c0128830	JCB 16 digit	37.8143427433408732	-122.4398098590421
25955	2020-05-20 21:57:22	2020-05-20	Sigmund Bogisich	sigmund.bogisich@woohoo.com	Reno	Nevada	3337965700943349249	39a33e9e22187486fefd4d35cb9db7a8	VISA 16 digit	39.5144945763129769	-119.918453920043632
25956	2020-05-20 21:58:14	2020-05-20	Dr. Darion Leffler Jr.	dr.darion.leffler.jr.@geemail.com	New York	New York	51675510333574376	0204705311f5080da8839583a4691123	American Express	40.5915785519164061	-73.9082800729561598
25957	2020-05-20 22:09:39	2020-05-20	Margarete Wisoky-Dibbert	margarete.wisoky.dibbert@warmmail.com	Fort Wayne	Indiana	4709687063186	afe2469ac7489f7d9243ef9b90260300	Mastercard	41.185876160885023	-85.2266970875892866
25958	2020-05-20 22:09:48	2020-05-20	Marcelle Boyle-Kris	marcelle.boyle.kris@geemail.com	Aurora	Illinois	3014329100299626	27ff888eca45118e7058b973eb1290bd	Maestro	41.7729695169012984	-88.2939236571010184
25959	2020-05-20 22:17:35	2020-05-20	Sedrick Pollich	sedrick.pollich@warmmail.com	New York	New York	6011369819293401913	429548ccee80e4c02d97d7bb26136cb1	Mastercard	40.7084368723668177	-73.9038972983032494
25960	2020-05-20 22:43:18	2020-05-20	Dr. Dell Rogahn II	dr.dell.rogahn.ii@warmmail.com	El Monte	California	180042813579193141	1530c605b47892fd591a1bbc7090d0ec	American Express	34.145805897675821	-118.019537209466478
25961	2020-05-20 22:51:12	2020-05-20	Orene Ritchie	orene.ritchie@geemail.com	Naperville	Illinois	3337958032444484153	2a7ac707180606ae4900e86563a0d87b	Voyager	41.7908110055521149	-88.0967777880728278
25962	2020-05-20 23:04:26	2020-05-20	Maddison O'Conner MD	maddison.o'conner.md@geemail.com	Miami	Florida	869973209817753600	e67268a149d754a315bbfd47667aee9c	Discover	25.7470808094039576	-80.1099768597971718
25963	2020-05-20 23:19:11	2020-05-20	Rashaad Steuber	rashaad.steuber@woohoo.com	New York	New York	51411750880062685	c60bcba9953c90a9a554a9854416687a	Discover	40.5751385064087771	-73.9646119740221621
25964	2020-05-20 23:23:25	2020-05-20	Billy Zemlak	billy.zemlak@woohoo.com	Berkeley	California	180049260006181781	56095835ec0f7133ad17d37fc1f96e33	Maestro	37.8842228608508478	-122.250579647201832
25965	2020-05-20 23:46:26	2020-05-20	Shelton Howe	shelton.howe@geemail.com	Aurora	Illinois	51008518943308745	2ce17ba8bae552e13749eee2245a4ada	Maestro	41.8047051256746087	-88.2590980867318819
25966	2020-05-21 00:11:27	2020-05-21	Dr. Webb Powlowski I	dr.webb.powlowski.i@geemail.com	Fort Worth	Texas	869906564966824053	a184b8d935911656824f48f7e34a7d25	VISA 16 digit	32.7766841262169208	-97.3021134113248394
25967	2020-05-21 00:15:40	2020-05-21	Kameron Nikolaus DDS	kameron.nikolaus.dds@geemail.com	New York	New York	869981251732142782	a0d83fef451727f59e7f81715a5768e1	VISA 16 digit	40.5911665478479122	-73.8597782064590547
25968	2020-05-21 00:17:40	2020-05-21	Willie Haley	willie.haley@woohoo.com	Syracuse	New York	3019183762436777	e44b39bf8ae6bc12cbceb051057c57e5	Diners Club / Carte Blanche	43.0528501638527956	-76.2196945743881287
25969	2020-05-21 00:21:10	2020-05-21	Mona Raynor	mona.raynor@geemail.com	Los Angeles	California	3455614970155075	b0281e5be6b0778cd6a42b533dd984d4	JCB 15 digit	33.9232151416927579	-118.322525263064719
25970	2020-05-21 00:27:02	2020-05-21	Huey Lueilwitz	huey.lueilwitz@geemail.com	New York	New York	6011286416701736525	77eff8e1cf1278dd5c0b5356abbd0ebb	American Express	40.5751687928792109	-73.978512173321846
25971	2020-05-21 01:00:37	2020-05-21	Gwenda Moore	gwenda.moore@geemail.com	Gainesville	Florida	3448922678367771	57e19eb306a47bb2f3e43475a24e76fb	VISA 16 digit	29.6745707997877126	-82.3374880103267799
25972	2020-05-21 01:09:08	2020-05-21	Kendrick Schumm	kendrick.schumm@woohoo.com	Abilene	Texas	6011251229568676044	0e9bedbfce758cb5f56171906a75f40f	JCB 16 digit	32.4068443789221377	-99.7347751144733365
25973	2020-05-21 01:10:14	2020-05-21	Glenna Kunze	glenna.kunze@geemail.com	Milwaukee	Wisconsin	6011191200563993620	b3c49cc4fb3af388f630948f2fcddca2	Discover	43.0750616782896216	-87.9912333313010606
25974	2020-05-21 01:28:42	2020-05-21	Rozella Marquardt-Roob	rozella.marquardt.roob@woohoo.com	Fairfield	California	4630194350280	01743281dd6552011cf36a51c2a6be5d	JCB 16 digit	38.193478007533777	-122.112996904878315
25975	2020-05-21 01:36:01	2020-05-21	Zoe Pfannerstill	zoe.pfannerstill@geemail.com	Berkeley	California	4506151731753992	e51bf4cc60d47a9c3df35c4300bac7e0	Diners Club / Carte Blanche	37.8627903976692579	-122.298955288897574
25976	2020-05-21 01:37:45	2020-05-21	Katlin Wolff	katlin.wolff@geemail.com	Hartford	Connecticut	4678340392551926	6634c60e237215d6b049773e12b23ad7	Mastercard	41.7472558692112585	-72.6367050321664749
25977	2020-05-21 01:37:49	2020-05-21	Mr. Jaydin Kshlerin	mr.jaydin.kshlerin@geemail.com	Cleveland	Ohio	3730816750902770	263ca0c3057c386aed526bb3eec02cef	JCB 16 digit	41.4429968596752687	-81.7102096801396414
25978	2020-05-21 01:39:20	2020-05-21	Angelita Ondricka	angelita.ondricka@geemail.com	Aurora	Colorado	3158718784438914097	b03983194573f2b8f20314cce53d4be2	Maestro	39.7569830402377988	-104.657123189012339
25979	2020-05-21 01:48:48	2020-05-21	Allyson Price	allyson.price@geemail.com	Colorado Springs	Colorado	4751878102039252	b406e5425b9ffc46fb6c47913d47b30a	JCB 15 digit	38.83596242848337	-104.767521874994785
25980	2020-05-21 01:49:07	2020-05-21	Johny Kiehn IV	johny.kiehn.iv@geemail.com	Charlotte	North Carolina	3038242882619398	593d1084e8381dee7df4f89272442feb	VISA 16 digit	35.1956118657972681	-80.8277127013020191
25981	2020-05-21 01:49:52	2020-05-21	Gisele Koelpin DDS	gisele.koelpin.dds@geemail.com	Phoenix	Arizona	3088714941548968405	3f403e982a591aa00f6926849eedacf4	JCB 15 digit	33.6583314726527831	-112.178832026144875
25982	2020-05-21 02:06:15	2020-05-21	Natalya Dietrich PhD	natalya.dietrich.phd@warmmail.com	Houston	Texas	180002549180829081	9b3b41d5b061526db865a2a7ae6a0ab2	American Express	29.7731625228267163	-95.2928455196335875
25983	2020-05-21 02:16:14	2020-05-21	Rheta Feest	rheta.feest@geemail.com	Phoenix	Arizona	6011821681183554660	7aafbe0b5ac3224d461c2b0b1c113674	JCB 16 digit	33.5256878407605043	-112.047321155287705
25984	2020-05-21 02:17:18	2020-05-21	Ms. Dorthea Botsford	ms.dorthea.botsford@geemail.com	San Francisco	California	4009561955595113	e0b7cd936f428393daf7c729223fb732	JCB 16 digit	37.7738408863098414	-122.427655805419477
25985	2020-05-21 02:23:12	2020-05-21	Mrs. Victory Ullrich	mrs.victory.ullrich@warmmail.com	Baltimore	Maryland	4792057015698352	e861b31e5ffa2a5f7fea1b48c3d5cf51	VISA 16 digit	39.3285922169685307	-76.6241719121597669
25986	2020-05-21 02:26:59	2020-05-21	Lesa Ernser	lesa.ernser@woohoo.com	Plano	Texas	4159274814734422	2df394a05b89c52e1c5ddc50ec63f09d	Discover	33.1375492898367341	-96.7208545892681997
25987	2020-05-21 02:27:25	2020-05-21	Alda Crooks-Kemmer	alda.crooks.kemmer@woohoo.com	St. Louis	Missouri	3710491215666388	df29ff577227465309fb9a28049662e7	VISA 16 digit	38.7169116194516434	-90.2660180386159681
25988	2020-05-21 02:41:30	2020-05-21	Kassandra Leuschke	kassandra.leuschke@geemail.com	Hialeah	Florida	4635584503348548	c3e945078e918de8d75a79e81ae80d33	VISA 16 digit	25.9140885090433066	-80.298555253203574
25989	2020-05-21 02:42:34	2020-05-21	Ninnie Koch	ninnie.koch@warmmail.com	Allentown	Pennsylvania	180090106893300521	025087ebb18b2b5761cec8108caecb94	Discover	40.5381603469386746	-75.534199077358096
25990	2020-05-21 02:47:19	2020-05-21	Lemuel Considine	lemuel.considine@geemail.com	Tulsa	Oklahoma	501822553126537	494a5f03dbd6c6d800ef903e08f380a4	Maestro	36.0532990209661364	-95.9224608608942475
25991	2020-05-21 02:58:26	2020-05-21	Angelica Dietrich-Smitham	angelica.dietrich.smitham@geemail.com	Vallejo	California	639021943477907	37b950281864350a60836bf4ef340ffb	Maestro	38.1726267302963862	-122.334397380040954
25992	2020-05-21 03:08:10	2020-05-21	Sue Doyle	sue.doyle@geemail.com	El Paso	Texas	3030859197443269	784b4a954f61dfc4b45727612e6276dd	American Express	31.7494997930075975	-106.482973289487887
25993	2020-05-21 03:11:51	2020-05-21	Samiyah Lubowitz	samiyah.lubowitz@geemail.com	New York	New York	4374705383262	7a01f35de6a69c7ea9f63984ca170adc	American Express	40.7206305308490997	-73.8982631338655978
25994	2020-05-21 03:27:10	2020-05-21	Tamica Crona	tamica.crona@geemail.com	Gilbert	Arizona	869966049016842872	8d89d4358e735d30449f4aacc90ee812	Voyager	33.346627918665483	-111.814109889990092
25995	2020-05-21 03:28:44	2020-05-21	Damon Wisoky	damon.wisoky@geemail.com	Jacksonville	Florida	3476800423451345	6fa841c33c4dd38c4ebca3b58c0e4699	VISA 16 digit	30.2904846077371381	-81.7206498647186947
25996	2020-05-21 03:36:16	2020-05-21	Bruno Ferry	bruno.ferry@geemail.com	Memphis	Tennessee	4010501117835822	5681589aef6a3ec13cc1a1e44583d199	Diners Club / Carte Blanche	35.0112745591972043	-90.0167881574738828
25997	2020-05-21 03:48:53	2020-05-21	Dr. Obie Goyette PhD	dr.obie.goyette.phd@woohoo.com	San Francisco	California	6011996636655427786	f5fcd8c73d49e70e663e0dcfd08bbd5c	JCB 16 digit	37.8141352455842821	-122.466258116084589
25998	2020-05-21 03:49:02	2020-05-21	Ms. Lilla Kozey	ms.lilla.kozey@geemail.com	Los Angeles	California	3456641117945893	a3a393244d6d86ea2494d80cde51389d	Maestro	34.0464609512925094	-118.419023996590823
25999	2020-05-21 03:49:39	2020-05-21	Ardyce Jacobson	ardyce.jacobson@geemail.com	San Francisco	California	3780321049687893	1cdaec57c2b8bf4d08dbd7394b459022	VISA 16 digit	37.7443185122417759	-122.42202717326218
26000	2020-05-21 03:49:49	2020-05-21	Celestia Feeney DDS	celestia.feeney.dds@woohoo.com	New Orleans	Louisiana	3476048627991530	808b4b48934604c9b128e2f78278c52d	Discover	30.0183025086779161	-89.8888226604815515
26001	2020-05-21 03:50:56	2020-05-21	Anatole Flatley DDS	anatole.flatley.dds@geemail.com	San Francisco	California	3337948262401696985	2bc4dc1ce68fa5048760f33d2e4f69da	JCB 15 digit	37.7602500918097945	-122.446376516589041
26002	2020-05-21 03:54:00	2020-05-21	Mia Boyle	mia.boyle@geemail.com	Santa Ana	California	3337631557262314954	8923878517cbd42cb231199fff08537d	Discover	33.7650409288808717	-117.821992507103829
26003	2020-05-21 03:54:33	2020-05-21	Dr. Marcela Jerde	dr.marcela.jerde@geemail.com	New York	New York	4515160403132	8caedfd2c0d22de7a6b8e4210e3191c0	Discover	40.6664765954241147	-73.9945894997462545
26004	2020-05-21 03:55:16	2020-05-21	Orvin Purdy-Schmidt	orvin.purdy.schmidt@warmmail.com	Knoxville	Tennessee	3052116322247877	478c886ed368552083334aad87bf1226	Voyager	35.8759143903449171	-83.9415512294258832
26005	2020-05-21 04:02:01	2020-05-21	Cam Walker	cam.walker@geemail.com	New York	New York	210045301297849340	7a4adbdb6c1756f1f1556916a6bf9dab	VISA 16 digit	40.7612709824685027	-73.9579243117373437
26006	2020-05-21 04:02:03	2020-05-21	Shyla Wintheiser	shyla.wintheiser@woohoo.com	Oakland	California	3755027066921302	c802446a633689965032a427e401cc54	American Express	37.7788444883196561	-122.28850177155752
26007	2020-05-21 04:06:10	2020-05-21	Brodie Abbott	brodie.abbott@geemail.com	Berkeley	California	3158547221332785338	9471fa3c4b9f2eef28a6945ae9883e22	Maestro	37.8829835457359394	-122.315742398471599
26008	2020-05-21 04:28:06	2020-05-21	Cornie Greenholt	cornie.greenholt@geemail.com	San Antonio	Texas	869943613807455331	8f76cec568489badd91ccfca17b1ea4b	JCB 16 digit	29.5576021723054367	-98.5379050908446317
26009	2020-05-21 04:30:58	2020-05-21	Gerold Sporer	gerold.sporer@geemail.com	Plano	Texas	4105504289779949	34058b096c8e51078e6b50ab9da963c8	JCB 15 digit	33.1490336374465429	-96.6680852297410382
26010	2020-05-21 04:32:52	2020-05-21	Rosendo Hermiston	rosendo.hermiston@geemail.com	Fort Worth	Texas	869994857554005207	99b017bed8c9b198179ede87f61a6c12	Voyager	32.8448593030739602	-97.3405982707448345
26011	2020-05-21 05:05:46	2020-05-21	Mrs. Deasia Anderson	mrs.deasia.anderson@warmmail.com	Colorado Springs	Colorado	3528346833398288438	05e64cfcbe4f891bd45c713b36aff6e1	Diners Club / Carte Blanche	38.8624767151244015	-104.689380937411258
26012	2020-05-21 05:09:09	2020-05-21	Mrs. Bobbye Zemlak DDS	mrs.bobbye.zemlak.dds@geemail.com	Portland	Oregon	3034371563589820	8ca207c50c956aa00eb5f08a7b8df550	JCB 16 digit	45.5890745254587344	-122.617299921764072
26013	2020-05-21 05:12:21	2020-05-21	Ms. Albina Lesch PhD	ms.albina.lesch.phd@geemail.com	San Francisco	California	3112328061847374904	05a5449a1e4af79c80e6b254c0e44b35	Mastercard	37.785738859864658	-122.445464667882888
26014	2020-05-21 05:18:54	2020-05-21	Lamonte Stiedemann	lamonte.stiedemann@geemail.com	Las Vegas	Nevada	210004799920405183	a644f40f338b18a55862a84d0d2c7b41	American Express	36.1873409469246852	-115.346439676473281
26015	2020-05-21 05:43:51	2020-05-21	Mr. Madden Koepp	mr.madden.koepp@geemail.com	Chicago	Illinois	210037128947215907	c9f6f896d6d03b7ff546c8f0756ca2b4	Maestro	41.7576557238422339	-87.6405290824390875
26016	2020-05-21 06:05:15	2020-05-21	Anson Cormier	anson.cormier@geemail.com	Jersey City	New Jersey	3088278638636936751	6eb44313f3e5f3c675e2807fd714dc73	Diners Club / Carte Blanche	40.7935096193510986	-74.1604270228605742
26017	2020-05-21 06:34:34	2020-05-21	Casen Lakin	casen.lakin@geemail.com	El Paso	Texas	4563665915822018	984e5149d420b8c936291fcc6cfa4e27	Voyager	31.921861716854945	-106.470430939735849
26018	2020-05-21 06:44:23	2020-05-21	Daron Thiel-Hills	daron.thiel.hills@geemail.com	Los Angeles	California	3112316638229858986	7ded0288f331e70ce3c718aacec4b123	VISA 16 digit	34.0807174935802806	-118.395331138185412
26019	2020-05-21 06:44:59	2020-05-21	Blake Hayes DVM	blake.hayes.dvm@woohoo.com	Los Angeles	California	3751378297320929	119a856a557cd33c0ef686caf632f54e	JCB 16 digit	34.0481759454455215	-118.449697847989569
26020	2020-05-21 06:45:15	2020-05-21	Smith Kreiger	smith.kreiger@geemail.com	Virginia Beach	Virginia	4838097081240503	58b0008a5588a3ab907da07ebf498be5	JCB 16 digit	36.7549458350241167	-76.002231522244216
26021	2020-05-21 06:55:14	2020-05-21	Kaylin Maggio	kaylin.maggio@geemail.com	Albuquerque	New Mexico	3005802364514699	a5c8b06334c37cc0d7c2f22ade934991	Discover	35.0660897664859945	-106.706849006943031
26022	2020-05-21 07:09:59	2020-05-21	Sylvanus Luettgen	sylvanus.luettgen@geemail.com	Jersey City	New Jersey	3088469819488013316	cb900949a0cb0c70f894419ef76d6e0f	JCB 15 digit	40.6473008537605409	-74.1100577088493964
26023	2020-05-21 07:13:55	2020-05-21	Ximena Brekke-Block	ximena.brekke.block@woohoo.com	Spokane	Washington	180001973750078286	85fcda52462a15121245e2d118cd88c1	JCB 16 digit	47.7280866080202131	-117.476153369889786
26024	2020-05-21 07:48:05	2020-05-21	Augusta Grady	augusta.grady@geemail.com	New York	New York	4246474067930	b2c13080322c3e54f2d4b42dbb3e09f3	VISA 13 digit	40.7352135052196687	-73.8960748146183732
26025	2020-05-21 07:53:01	2020-05-21	Mr. Tolbert Powlowski	mr.tolbert.powlowski@geemail.com	New York	New York	4492825238440668	c6cb34f40c53ae266794551a154a8289	VISA 16 digit	40.6627650007829047	-73.907977586368844
26026	2020-05-21 08:11:51	2020-05-21	Erma Schaden-Walker	erma.schaden.walker@geemail.com	Fort Lauderdale	Florida	869952999327169991	4e73de4540c066faa4b5a1a3411df8b7	Mastercard	26.0730646302446729	-80.0963459124609756
26027	2020-05-21 08:31:29	2020-05-21	Elisha Kreiger	elisha.kreiger@geemail.com	San Jose	California	3088817857626221416	28a22c83a0970fa885b4ce0e7c9a518f	JCB 15 digit	37.3943057489868238	-121.906495937866723
26028	2020-05-21 08:37:51	2020-05-21	Loria Borer	loria.borer@geemail.com	Pittsburgh	Pennsylvania	869983556054414843	3c35ac9451c69c2a491fc631a3af568d	VISA 13 digit	40.4673051628705096	-79.886190224409475
26029	2020-05-21 08:41:52	2020-05-21	Davin Reichel	davin.reichel@geemail.com	Virginia Beach	Virginia	4772089553957662	789bc9c09290406b209bf0f872d3c659	Maestro	36.8635867993999256	-76.0678542608067403
26030	2020-05-21 08:50:42	2020-05-21	Rosia Medhurst	rosia.medhurst@woohoo.com	Los Angeles	California	869940334645390613	9c9e992df15fe784698902d8a9e04b50	VISA 13 digit	33.9662432231340503	-118.459755996055151
26031	2020-05-21 08:57:54	2020-05-21	Kennard Larson	kennard.larson@woohoo.com	Los Angeles	California	55270712460826038	0073274b747c92862a184ae65f7cef55	American Express	33.9398039668198663	-118.378180121070884
26032	2020-05-21 09:02:21	2020-05-21	Kasandra Corwin	kasandra.corwin@geemail.com	Colorado Springs	Colorado	4361277337363458	af1f5c9cecbedb49a5b3d825eec9e63d	American Express	38.7728099520366669	-104.766968842611462
26033	2020-05-21 09:08:28	2020-05-21	Linnie Crooks	linnie.crooks@geemail.com	New York	New York	3471849692739257	0cefab1efede7123f56b0ae0480acccf	Discover	40.6169381934441631	-73.9075841476570758
26034	2020-05-21 09:27:23	2020-05-21	Obed Emmerich-Hand	obed.emmerich.hand@geemail.com	Phoenix	Arizona	4463721653134990	24fafad5b6803643426f1b6fb348c741	JCB 16 digit	33.4765972925748727	-112.18939547258654
26035	2020-05-21 09:29:41	2020-05-21	Alfreda Swift	alfreda.swift@geemail.com	San Francisco	California	869922638986979111	fa1dadf2d47b5fe89bdcb4c557f28a12	VISA 16 digit	37.754230062339154	-122.409527703101787
26036	2020-05-21 09:32:19	2020-05-21	Annika Hilpert	annika.hilpert@geemail.com	Tyler	Texas	869970738106222045	f4adb48550bc308b2e0f4e1064ed6ea4	VISA 16 digit	32.2362269412308962	-95.2116191297877492
26037	2020-05-21 09:41:57	2020-05-21	Kris Blanda	kris.blanda@geemail.com	Rancho Cucamonga	California	3768668931562337	d6fb69e1f90a4cc71c1c18a6e0efa849	VISA 16 digit	34.2137919735155975	-117.604430244118717
26038	2020-05-21 09:46:34	2020-05-21	Darion Kovacek	darion.kovacek@woohoo.com	Chicago	Illinois	639089377113629	e9629b4c4fa1579df56a015590333c11	Diners Club / Carte Blanche	41.847027057346331	-87.6722155515600008
26039	2020-05-21 09:47:06	2020-05-21	Miss Nelle Kulas DDS	miss.nelle.kulas.dds@warmmail.com	Wichita Falls	Texas	4735575721833	9f85f6a3643ea56ed8975e2e42f428e6	VISA 16 digit	33.8819927906811245	-98.4960658202335111
26040	2020-05-21 09:47:25	2020-05-21	Rosendo Dare V	rosendo.dare.v@geemail.com	Lakeland	Florida	3088325544390610454	3f5684dd3a76d24e1adc1cdf5e81c9ce	Voyager	28.0154070476833716	-81.8559869400110074
26041	2020-05-21 09:49:11	2020-05-21	Devaughn Sawayn	devaughn.sawayn@woohoo.com	Oklahoma City	Oklahoma	53465884057115235	d28e2be8589d32daa287b66c90a63b01	JCB 16 digit	35.507618119977792	-97.4812049977842747
26042	2020-05-21 09:59:52	2020-05-21	Mrs. Jazlynn Dooley	mrs.jazlynn.dooley@warmmail.com	Austin	Texas	3158302309320559578	f01a806ff5b5a371ef93913bb8c81d1b	VISA 16 digit	30.2888291791673723	-97.793479907443384
26043	2020-05-21 10:07:19	2020-05-21	Bena Stiedemann	bena.stiedemann@geemail.com	St. Petersburg	Florida	210028266862285181	018544ac80bcbf8296226d55561671e4	VISA 13 digit	27.6691507941000161	-82.6583915083095349
26044	2020-05-21 10:13:03	2020-05-21	Jaylon Haley	jaylon.haley@geemail.com	Tucson	Arizona	3045623872207760	69b2be99c73ed4c3a980a2eb17519ea3	JCB 15 digit	32.1018507572397596	-110.82847403159775
26045	2020-05-21 10:13:07	2020-05-21	Mrs. Khloe Harris	mrs.khloe.harris@woohoo.com	Los Angeles	California	4430487565983821	9f44e4634f396134f7a66844436fb59c	JCB 16 digit	34.0157621787726825	-118.367123272269211
26046	2020-05-21 10:13:33	2020-05-21	Carmen King PhD	carmen.king.phd@geemail.com	San Francisco	California	6011127009221548141	648cf99232b86df2af931e1e1cf3f2fa	Diners Club / Carte Blanche	37.7620593016426085	-122.401473462515895
26047	2020-05-21 10:32:30	2020-05-21	Lalla Bayer MD	lalla.bayer.md@geemail.com	Berkeley	California	869982346496421148	200a97866bb311b97142d07c3d7847e9	JCB 16 digit	37.8942303669821214	-122.285069237782437
26048	2020-05-21 11:16:36	2020-05-21	Miss Abigale Beier PhD	miss.abigale.beier.phd@geemail.com	Los Angeles	California	4038987923559409	e796543c90c329f642e708cfede6c5e1	Voyager	34.0987453310150599	-118.465535435731709
26049	2020-05-21 11:18:11	2020-05-21	Daneen Sauer	daneen.sauer@geemail.com	Phoenix	Arizona	4044219822844506	2a00d8bdfd16ede435e1758b194ab04f	JCB 15 digit	33.5940473743181727	-112.088794969993089
26050	2020-05-21 11:22:16	2020-05-21	Veta Becker	veta.becker@woohoo.com	Fresno	California	869916334486337178	be3cb61b42b7fb6082ff86534ae837e8	Mastercard	36.841733283862844	-119.729537473583221
26051	2020-05-21 11:48:30	2020-05-21	Ora Towne	ora.towne@warmmail.com	Burbank	California	4830664373081	ad7e90a30b365de1521047f591e21809	American Express	34.2413805828359017	-118.289282586196066
26052	2020-05-21 11:48:56	2020-05-21	Mr. Raynard Bogan	mr.raynard.bogan@warmmail.com	New York	New York	53831460394470729	dc8494c37ccc5a352883bd7ad5b21db2	Diners Club / Carte Blanche	40.719661291943865	-73.9656769032951473
26053	2020-05-21 11:50:06	2020-05-21	Paxton Ondricka	paxton.ondricka@geemail.com	Greensboro	North Carolina	4684377048229	2d71e6f982840381fd824603d39299ef	Discover	36.064049838727712	-79.8640445637032315
26054	2020-05-21 11:56:11	2020-05-21	Ebenezer Bahringer II	ebenezer.bahringer.ii@geemail.com	North Las Vegas	Nevada	3088074363396799309	15a0b247b6bc481ffde674fc957be090	VISA 16 digit	36.2200573402147725	-115.183751448219269
26055	2020-05-21 11:58:37	2020-05-21	Marcela Wilkinson	marcela.wilkinson@warmmail.com	San Francisco	California	4356149683084	46f79cf4e1882e3d0a737bc71955a146	Voyager	37.7697642220629248	-122.443690786526432
26056	2020-05-21 12:31:01	2020-05-21	Mr. Fred Maggio DVM	mr.fred.maggio.dvm@geemail.com	Los Angeles	California	4480594008579	62047248d1afc9a4241701b0b939decd	Mastercard	34.0207893708121034	-118.408521832199014
26057	2020-05-21 12:43:49	2020-05-21	Dr. Kayleen Sauer PhD	dr.kayleen.sauer.phd@geemail.com	Macon	Georgia	3713195652452395	b45b159e32609d1fe860f4c90f1430e7	Diners Club / Carte Blanche	32.8730262925393859	-83.6599124315388423
26058	2020-05-21 12:55:03	2020-05-21	Elle Luettgen-Connelly	elle.luettgen.connelly@geemail.com	Norfolk	Virginia	53847352442778280	c377cd0216c47c499d145eea187dbd69	Mastercard	36.8491258176527907	-76.2132323669273433
26059	2020-05-21 13:04:17	2020-05-21	Harm Barton	harm.barton@geemail.com	San Francisco	California	3112499881704643817	5ece7b7f072020bc766d53a716351d4d	JCB 15 digit	37.7865600485824444	-122.422530404626912
26060	2020-05-21 13:07:16	2020-05-21	Mrs. Shauna Doyle	mrs.shauna.doyle@geemail.com	Eugene	Oregon	53782733183691922	4d482b5eb15b93b00571bcf0bea5d676	VISA 16 digit	44.1394243114355973	-123.030139955085517
26061	2020-05-21 13:11:28	2020-05-21	Miss Adriana Von	miss.adriana.von@geemail.com	New Orleans	Louisiana	501846452092888	e41dd586d882927d8cc08f7901557512	VISA 13 digit	30.1270232839524752	-90.0022773280534949
26062	2020-05-21 13:12:36	2020-05-21	Leopold Lubowitz-Beatty	leopold.lubowitz.beatty@geemail.com	Long Beach	California	4369897759386596	6fa39a007ad9027b56f548165569b06c	Maestro	33.763259491213411	-118.094016429052871
26063	2020-05-21 13:16:19	2020-05-21	Burrel Anderson	burrel.anderson@geemail.com	New York	New York	561250942880936	f24abfc4809deea82e4089087b649273	Mastercard	40.5918553703222429	-73.9349028183508636
26064	2020-05-21 13:40:54	2020-05-21	Dr. Lessie Cremin DVM	dr.lessie.cremin.dvm@geemail.com	Louisville	Kentucky	180006930343092955	4fabb1e91038184b1275ceea649a4f18	VISA 13 digit	38.1733007243737532	-85.7411354370485981
26065	2020-05-21 13:41:08	2020-05-21	Rohan Lind-Wolff	rohan.lind.wolff@warmmail.com	San Francisco	California	3088412258076692181	4f78b2c645f3386b595d8fac37cb564c	American Express	37.7908433902556808	-122.454707214011563
26066	2020-05-21 13:45:19	2020-05-21	Orion Larson	orion.larson@geemail.com	Indianapolis	Indiana	55809696632077127	5c2d316786e0b8e934a7cf73842e0e75	Discover	39.6822249398574201	-86.1770767393257415
26067	2020-05-21 13:52:24	2020-05-21	Cris Bahringer	cris.bahringer@geemail.com	Rochester	New York	4644182420017806	73fcd5c5739277aa320bb1f6019617ca	Discover	43.2390777591127886	-77.5865589768864226
26068	2020-05-21 13:58:03	2020-05-21	Ambers Berge	ambers.berge@woohoo.com	New York	New York	3024286663924786	b58b2284ae3624986220242e7253dcae	Mastercard	40.7383830464202887	-73.9667952450353567
26069	2020-05-21 14:05:43	2020-05-21	Che O'Kon	che.o'kon@geemail.com	Phoenix	Arizona	55189151613096167	01437f0dd2dcd61b237c899eab1c4999	American Express	33.4745746057413527	-112.132397973483805
26070	2020-05-21 14:06:32	2020-05-21	Dr. Julio O'Hara IV	dr.julio.o'hara.iv@geemail.com	Plano	Texas	4782833564681003	904f9861b542a7707ea244db64bf4f93	Maestro	33.0267407390374714	-96.8288286190196885
26071	2020-05-21 14:07:06	2020-05-21	Alize Larson	alize.larson@geemail.com	Surprise	Arizona	3096315381430001564	d4453b7e6cef7d29e0b8915cf7ac54d7	JCB 16 digit	33.5815348654747012	-112.473262618598341
26072	2020-05-21 14:09:44	2020-05-21	Mr. Mcarthur Nader Sr.	mr.mcarthur.nader.sr.@geemail.com	Memphis	Tennessee	4201013302470	15655c7b55c77c79fa62ae03efbf5d0b	JCB 16 digit	35.2014431473866125	-90.0333466535691258
26073	2020-05-21 14:10:38	2020-05-21	Leeroy Smith	leeroy.smith@geemail.com	Los Angeles	California	4101112359281491	ed9d28b1e8a1fb4062478cf8db9ad537	Diners Club / Carte Blanche	34.0223956312850078	-118.378160353516407
26074	2020-05-21 14:17:11	2020-05-21	Andrae Bauch	andrae.bauch@geemail.com	San Francisco	California	869992273595978950	6fbc337ff17c965e8bb32a03ef18cfa2	Discover	37.7694219682299277	-122.454114612665308
26075	2020-05-21 14:17:42	2020-05-21	Leticia Wolff	leticia.wolff@geemail.com	Ventura	California	3337364677766602127	e8b6fd720ee42ff60c6abc887492fd18	VISA 16 digit	34.3578620090309528	-119.285383911301196
26076	2020-05-21 14:34:01	2020-05-21	Amin Green DVM	amin.green.dvm@geemail.com	San Francisco	California	6011032128626458765	b68b92d6055f0d44bc66adf32b4e96bc	American Express	37.7478598690084439	-122.428662047141955
26077	2020-05-21 14:35:35	2020-05-21	Abb Wisozk IV	abb.wisozk.iv@woohoo.com	New York	New York	4159428321974042	643886ef79c54490edd00b5c8ede7007	JCB 16 digit	40.7438569177165633	-73.8559648715786636
26078	2020-05-21 14:40:27	2020-05-21	Dr. Dominik Rippin DDS	dr.dominik.rippin.dds@warmmail.com	College Station	Texas	3088668864534339926	365f40452d86ba1c8e9e66910043ebe0	Discover	30.5456320667218435	-96.2184309711527135
26079	2020-05-21 15:17:12	2020-05-21	Eura Veum DDS	eura.veum.dds@geemail.com	San Francisco	California	4415410451416762	4618a51c71d05c1c06b1c6a023124b80	VISA 16 digit	37.7405743768496507	-122.446892851271969
26080	2020-05-21 15:30:58	2020-05-21	Sally Hand	sally.hand@geemail.com	New York	New York	4249363677978739	5bcc2293cfda360d5ca7f9df7cc81a58	JCB 15 digit	40.6905200490020178	-73.9967519746523266
26081	2020-05-21 15:38:38	2020-05-21	Dr. Quintin Kris	dr.quintin.kris@geemail.com	Dallas	Texas	6011157452448559678	57c441a059290ea2d1230698a6a40d26	JCB 16 digit	32.7791249929267963	-96.7309957513082708
26082	2020-05-21 16:09:25	2020-05-21	Annie Watsica	annie.watsica@geemail.com	Los Angeles	California	180012539365749467	c08d849a4b4a900efa5533eff2222b85	VISA 16 digit	34.0205830823961648	-118.47236959743239
26083	2020-05-21 16:09:29	2020-05-21	Libbie Keebler	libbie.keebler@geemail.com	New York	New York	4522685387039099	4d141d450edce2dd96f244d466a65bde	Diners Club / Carte Blanche	40.6715989678390315	-73.9581843332748861
26084	2020-05-21 16:10:16	2020-05-21	Dell Nader	dell.nader@geemail.com	Odessa	Texas	180007898285099925	58821fd88cfac07e4c7c624fb5b5c778	Diners Club / Carte Blanche	31.8454217550821603	-102.304676673902563
26085	2020-05-21 16:16:36	2020-05-21	Nada Bartell MD	nada.bartell.md@geemail.com	Chandler	Arizona	3158325074241941379	5ea3eff6433d177483ad9dd8bb7ec4c8	VISA 16 digit	33.3579177294947158	-111.928887008119005
26086	2020-05-21 16:16:49	2020-05-21	Clevie Thiel	clevie.thiel@warmmail.com	Fort Worth	Texas	676171603837080	260a89997b2219ebe53fa458daa24480	Discover	32.7689081638175992	-97.3068751679554538
26087	2020-05-21 16:40:46	2020-05-21	Denice Barton	denice.barton@geemail.com	Austin	Texas	4324339466006534	3f019714b0c5fee8f0f80c5a15f2a0eb	American Express	30.365920692182705	-97.6554443245992161
26088	2020-05-21 16:44:24	2020-05-21	Dionte Cormier	dionte.cormier@geemail.com	Boston	Massachusetts	4212291490101	f3ef2701cae0bab7fde4bcc0f8975d2f	Maestro	42.2328139462675907	-71.0934395476195959
26089	2020-05-21 16:50:49	2020-05-21	Connie Kiehn	connie.kiehn@geemail.com	San Jose	California	4316588516639377	eea1605d9656025d34c7c47b0b09e326	American Express	37.2606870901592089	-121.774573223081973
26090	2020-05-21 16:58:53	2020-05-21	Windell Emard Jr.	windell.emard.jr.@warmmail.com	New York	New York	3528004769933659530	470c3036c78c96bed511f1e56d6a8415	JCB 15 digit	40.6078575159646533	-73.9956572678767088
26091	2020-05-21 17:03:33	2020-05-21	Baron Wiegand	baron.wiegand@warmmail.com	San Diego	California	4053187687495	bf35e57b11ec7422b9e99d256563cc4e	Mastercard	32.7836189612813271	-117.058512387322267
26092	2020-05-21 17:09:22	2020-05-21	Mr. Arlis Ferry II	mr.arlis.ferry.ii@geemail.com	Amarillo	Texas	6011201488093391963	dda490c4e1a64ec4977fe54ce31f2e38	JCB 16 digit	35.1377851370885992	-101.79497712756023
26093	2020-05-21 17:22:06	2020-05-21	Lita Schowalter	lita.schowalter@geemail.com	Alexandria	Virginia	4472225659837795	9dbf2dbc911d19a0ee159968240f2beb	Discover	38.8538776765227283	-77.1506587863884903
26094	2020-05-21 17:23:42	2020-05-21	Zed Monahan DVM	zed.monahan.dvm@woohoo.com	Charlotte	North Carolina	210014106562482322	464e90773111dbcbad664cefe1633712	VISA 16 digit	35.2887374131262277	-80.8392795826718213
26095	2020-05-21 17:28:04	2020-05-21	Talmage Cartwright	talmage.cartwright@geemail.com	Oakland	California	4500171588518005	dca0bdfd4e9f8a13e930fd46b9ddf82d	American Express	37.7908507165688761	-122.265220847741844
26096	2020-05-21 17:43:16	2020-05-21	Lou Schaefer	lou.schaefer@woohoo.com	Chicago	Illinois	6011822987207499058	5aca818dd420d07e49cf991169e9820d	American Express	41.9318009428050402	-87.691738999358563
26097	2020-05-21 17:50:55	2020-05-21	Lionel Welch	lionel.welch@geemail.com	Broken Arrow	Oklahoma	4483747302191442	824f71bfc67a8f35e5267c975c1bd1ce	Discover	35.9612179043479259	-95.8614310455452738
26098	2020-05-21 17:58:07	2020-05-21	Conley Gerhold	conley.gerhold@geemail.com	South Bend	Indiana	55189950874896532	b8f94c910251f6ba52dcbbd6a3979a98	Voyager	41.6783777475968051	-86.2538154552280929
26099	2020-05-21 18:04:42	2020-05-21	Phillis Kuvalis-Boehm	phillis.kuvalis.boehm@woohoo.com	Berkeley	California	210021149086286937	ce110270d63a1b6fc72a62bc1a57a445	Diners Club / Carte Blanche	37.8645414074845874	-122.264187353639514
26100	2020-05-21 18:08:50	2020-05-21	Vashti Hamill	vashti.hamill@geemail.com	New Orleans	Louisiana	869940354103660885	1dfb6f989d62a4394cabc0b4de0e31f5	JCB 16 digit	29.9756956522833562	-89.9369413784034606
26101	2020-05-21 18:09:00	2020-05-21	Javion Rolfson	javion.rolfson@geemail.com	Lexington	Kentucky	4867366743291798	cb97d7db18c5f83762abf8ded1a25108	American Express	38.0017151704866478	-84.3870484842352511
26102	2020-05-21 18:37:16	2020-05-21	Johnie Russel	johnie.russel@geemail.com	Los Angeles	California	3088018446217784516	a79066aa8b12aa4166a5a38615821b50	American Express	33.9701803536951488	-118.498674844577152
26103	2020-05-21 18:39:53	2020-05-21	Ivy Kozey	ivy.kozey@geemail.com	San Francisco	California	3787652302610344	66b19d81dfa839ec0e832777a0316cea	VISA 13 digit	37.7870333168060029	-122.452613268764921
26104	2020-05-21 18:44:05	2020-05-21	Fleda Anderson	fleda.anderson@geemail.com	San Francisco	California	53067296904002544	4a923ca6fbb11e07a359631f341b8699	VISA 16 digit	37.8002231593882669	-122.438076775491012
26105	2020-05-21 18:47:11	2020-05-21	Rutha Haley	rutha.haley@woohoo.com	Sacramento	California	180020719288899819	882ce7b9f503475c1d76966e15bd1fb7	Discover	38.4708328850831833	-121.447508314974968
26106	2020-05-21 18:49:44	2020-05-21	Lashawn Rohan PhD	lashawn.rohan.phd@geemail.com	New York	New York	6011778807534850506	d9f8a2a4df1435ffc75b9ddf634b3597	Discover	40.6885219422858171	-73.8973336838081423
26107	2020-05-21 18:53:03	2020-05-21	Carlo Dare	carlo.dare@geemail.com	Detroit	Michigan	52062628243056259	7c168d516b12ce5406e1e59cf6610a0a	Discover	42.4428419016227139	-83.1135376874476606
26108	2020-05-21 19:11:00	2020-05-21	Fatima Gaylord	fatima.gaylord@geemail.com	San Francisco	California	54479158129450027	31686c345324154a80e05c2f389699ea	American Express	37.7606250353138719	-122.449279846316344
26109	2020-05-21 19:11:19	2020-05-21	Yahir Beatty-Boehm	yahir.beatty.boehm@geemail.com	Corpus Christi	Texas	51616840746606180	267858bfd71b803857b3a33cad05dcef	VISA 13 digit	27.8174224645767367	-97.1803439485203455
26110	2020-05-21 19:13:27	2020-05-21	Debbie Lehner	debbie.lehner@geemail.com	Atlanta	Georgia	53866948056668836	a42e9e6e0271e3a37aafa6478b4015b6	VISA 13 digit	33.8318881467260439	-84.3909652083225552
26111	2020-05-21 19:18:40	2020-05-21	Buren Grant II	buren.grant.ii@geemail.com	Woodbridge	New Jersey	4915320966841781	6837fc0e7197401a6892328ddf35aa88	Mastercard	40.6186210739117115	-74.2576103543255499
26112	2020-05-21 19:19:39	2020-05-21	Lannie Lindgren DDS	lannie.lindgren.dds@warmmail.com	Lexington	Kentucky	3732112825040509	6685cd0c7c63e581549fab45df832b0b	Discover	38.0437110002029684	-84.5112709635302366
26113	2020-05-21 19:29:18	2020-05-21	Kendell Mante PhD	kendell.mante.phd@geemail.com	Jurupa Valley	California	3015323696776906	2c9ba4fbfaef6df41ad1470144958faa	VISA 16 digit	34.0782055341567869	-117.385189300498368
26114	2020-05-21 19:40:08	2020-05-21	Curt Quitzon-Leuschke	curt.quitzon.leuschke@warmmail.com	Philadelphia	Pennsylvania	869974353241071012	7d2f561b15fca4e2d346503428aff7d1	JCB 15 digit	39.9301352986093576	-75.072214740039044
26115	2020-05-21 19:47:43	2020-05-21	Leland Harvey	leland.harvey@geemail.com	Oakland	California	6011924312727906564	83649f82baa68705f508d375893078d5	JCB 16 digit	37.81544277151675	-122.319146150789393
26116	2020-05-21 19:50:53	2020-05-21	Sylvania Cole-Stoltenberg	sylvania.cole.stoltenberg@geemail.com	Norfolk	Virginia	4170031981823	50fbe5e40f47e7cd33f316ad176fbe63	VISA 16 digit	36.889712943883616	-76.2153964415661989
26117	2020-05-21 19:51:52	2020-05-21	Marquez Cremin	marquez.cremin@geemail.com	Glendale	Arizona	4409899134020	9540b9563ff50fbb4221910de7625783	Voyager	33.4474483087886085	-112.262788335306197
26118	2020-05-21 19:53:10	2020-05-21	Aaden Casper IV	aaden.casper.iv@geemail.com	Santa Rosa	California	6011534165688236708	757047e1b1114c9afbed2a8c3d676897	Maestro	38.5180692738976376	-122.672861821834374
26119	2020-05-21 20:15:00	2020-05-21	Miss Rayna Rice PhD	miss.rayna.rice.phd@warmmail.com	San Francisco	California	4115700316246336	cc16f8eb9065ea2de38e2cacd8c9c7cd	Maestro	37.7706746280426273	-122.41034402018721
26120	2020-05-21 20:37:14	2020-05-21	Pearla Hirthe PhD	pearla.hirthe.phd@geemail.com	San Francisco	California	3088540531799869368	1d7bb8dfb95efc8b9835c68c0a80e7db	JCB 15 digit	37.797912575024057	-122.429134157508372
26121	2020-05-21 20:51:36	2020-05-21	August Vandervort	august.vandervort@geemail.com	San Francisco	California	869903629564559345	feeeb5e808e73cb2fd3fa806ee7ebcfa	Voyager	37.7403303666182168	-122.442832187731355
26122	2020-05-21 20:59:11	2020-05-21	Shawnna Schmeler DVM	shawnna.schmeler.dvm@woohoo.com	Vancouver	Washington	4227579825182	274ac9de9d660e1cd939d81fccc73f12	Mastercard	45.6996495168726895	-122.579254622204971
26123	2020-05-21 21:02:30	2020-05-21	Michaela Upton-Stracke	michaela.upton.stracke@warmmail.com	Gresham	Oregon	4842427197749	37c9358f18a41ef98cdf008b0384634c	Diners Club / Carte Blanche	45.4716555559031619	-122.473387330098447
26124	2020-05-21 21:12:08	2020-05-21	Kaylie Rau	kaylie.rau@warmmail.com	Greensboro	North Carolina	3528104372720447109	44c0d2f474dae7de90ca5f577e34c292	JCB 16 digit	36.1248360184602433	-79.8711905640996918
26125	2020-05-21 21:17:36	2020-05-21	Georgetta Pagac-Parker	georgetta.pagac.parker@geemail.com	Los Angeles	California	869993882646865195	f2b022697e4abac901b580766606547e	Mastercard	33.9407095939252486	-118.445558510347453
26126	2020-05-21 21:27:18	2020-05-21	Lesia Schiller PhD	lesia.schiller.phd@geemail.com	Virginia Beach	Virginia	6011516456554659699	7431cc0966d1da94ee51c19cc83a9503	Maestro	36.7709537111409048	-76.0257854445509622
26127	2020-05-21 21:28:09	2020-05-21	Dr. Emely Wintheiser MD	dr.emely.wintheiser.md@geemail.com	Oakland	California	675925016758036	33b1404837f2d1a594eb028f66926968	Discover	37.838714477005972	-122.2883714766417
26128	2020-05-21 22:31:27	2020-05-21	Dr. Ericka Smith	dr.ericka.smith@geemail.com	Houston	Texas	180029681158667240	e3cd3f61ea893386a529c5298d847f5d	VISA 16 digit	29.7964362276796244	-95.2931431159392019
26129	2020-05-21 22:36:05	2020-05-21	Dr. Halsey Kris	dr.halsey.kris@geemail.com	Berkeley	California	3088554563444403684	9ce9786f7b21e8c783bd62d603155e82	Maestro	37.877849358322031	-122.242623684982306
26130	2020-05-21 22:39:50	2020-05-21	Asa Zieme-Schuster	asa.zieme.schuster@woohoo.com	San Francisco	California	3440240815062413	912018663a68210a2bba3ca8b9b41a7a	VISA 13 digit	37.7732353952324473	-122.409566424797632
26131	2020-05-21 22:40:52	2020-05-21	Laisha White	laisha.white@geemail.com	Pomona	California	4001834382375476	f492431203e9234867fe8d0555bda45e	VISA 16 digit	33.9700395009517706	-117.841074455386405
26132	2020-05-21 22:47:16	2020-05-21	Merwin Carroll	merwin.carroll@geemail.com	Nashville	Tennessee	4611693362117	f12fb8ae1d280251bfd71a694d48fd9a	Mastercard	36.1535584823816976	-86.7710083990730254
26133	2020-05-21 22:59:07	2020-05-21	Mr. Doyle Jast Sr.	mr.doyle.jast.sr.@geemail.com	West Valley City	Utah	4931013366877956	ccb7945f1d9215c8bd2ef342edd7df77	JCB 16 digit	40.7500985652431851	-111.94288155536465
26134	2020-05-21 23:09:37	2020-05-21	Mr. Duwayne Heathcote	mr.duwayne.heathcote@woohoo.com	Palm Bay	Florida	6011087572175283179	625d9ab3dfa55664caa794350c68d1de	Maestro	27.9069854806032041	-80.5760369597304589
26135	2020-05-21 23:12:19	2020-05-21	Cherelle Bosco	cherelle.bosco@geemail.com	Baltimore	Maryland	4972167450774	7a7cdbe4cf7ad9995681344deade32fd	JCB 16 digit	39.229139802092682	-76.6729461736995717
26136	2020-05-21 23:17:03	2020-05-21	Gearld Grimes	gearld.grimes@geemail.com	Spokane	Washington	55021425488599089	3d41005f7935042dfdc0981baf0a2daf	VISA 13 digit	47.6549339336115878	-117.428772900150349
26137	2020-05-21 23:18:59	2020-05-21	Dolores Abshire	dolores.abshire@geemail.com	Rancho Cucamonga	California	869955998215218974	089d2f172f1a0102ffee03c038c3ac79	JCB 16 digit	34.0295444599345345	-117.574290097459027
26138	2020-05-21 23:35:48	2020-05-21	Nathen Boyle Sr.	nathen.boyle.sr.@geemail.com	Houston	Texas	4674665192821	bf1096436376f274f0713cba94209747	American Express	29.7776809687338755	-95.3544637485422157
26139	2020-05-21 23:36:19	2020-05-21	Barton Jacobs	barton.jacobs@geemail.com	Anaheim	California	55961323316359853	b3c16668606f786a331ea960ff0adf0f	Voyager	33.9520894150082029	-117.697241038151446
26140	2020-05-21 23:38:47	2020-05-21	Dell Torp	dell.torp@woohoo.com	St. Petersburg	Florida	3528529186515448909	b6c4c00a03d53bfe9786cff1c70b4545	JCB 15 digit	27.6748995335660872	-82.7387154407691128
26141	2020-05-21 23:47:51	2020-05-21	Mr. Cornelious Homenick DDS	mr.cornelious.homenick.dds@geemail.com	Chicago	Illinois	869949080232585666	15d6ff50b891a12cb7aaa28509c070fe	Voyager	41.8477559002418076	-87.7725335668802273
26142	2020-05-21 23:51:11	2020-05-21	Orpha Gorczany	orpha.gorczany@geemail.com	Lincoln	Nebraska	4576251019054	140d9a7b9f0dc816e9a0064815ca2d9a	JCB 16 digit	40.8893512393832168	-96.5875498544119324
26143	2020-05-22 00:13:31	2020-05-22	Shandra Farrell	shandra.farrell@geemail.com	San Francisco	California	3005566417667602	ea224b048b5a4554b343beb880edb34d	VISA 16 digit	37.7641612235992525	-122.416465183884753
26144	2020-05-22 00:23:15	2020-05-22	Miss Anitra Hodkiewicz	miss.anitra.hodkiewicz@geemail.com	Buffalo	New York	4164267748778781	f8ee0f7ea13c208afad284ccf6c36656	Mastercard	42.8736248878017037	-78.8514708933819151
26145	2020-05-22 00:23:42	2020-05-22	Ashlyn Effertz PhD	ashlyn.effertz.phd@woohoo.com	Albuquerque	New Mexico	3158264653790253790	f3695bc840840d2d77b6b03f798cb8d9	JCB 16 digit	35.1606328406505284	-106.659119827726485
26146	2020-05-22 00:28:15	2020-05-22	Shirlee Yundt	shirlee.yundt@geemail.com	Sunnyvale	California	676311971683856	7fbbbfa8050b2299a094304cc27127a3	Maestro	37.3164586032267707	-122.011004131633044
26147	2020-05-22 01:02:11	2020-05-22	Mari Hoeger	mari.hoeger@geemail.com	Colorado Springs	Colorado	6011049884568671416	53757411b3c6c73c4bcc05173c2619b5	VISA 16 digit	38.8422510791618407	-104.773886944322655
26148	2020-05-22 01:02:59	2020-05-22	Mr. Theodis Larkin DDS	mr.theodis.larkin.dds@woohoo.com	Centennial	Colorado	3019235987796797	9a3a1df5baa43ea5a080af00d739a5e9	VISA 13 digit	39.5541382265318191	-104.776616966201374
26149	2020-05-22 01:04:37	2020-05-22	Tasia Leuschke DDS	tasia.leuschke.dds@geemail.com	New York	New York	3439199007661676	32c08f9ff327c29de7980f75b9fde6ed	Voyager	40.7440641849990897	-73.8853678122058426
26150	2020-05-22 01:04:55	2020-05-22	Miss Christina Bahringer PhD	miss.christina.bahringer.phd@geemail.com	San Francisco	California	4304752938917787	55d0ad5c41b188a161c36be96fb5108f	VISA 16 digit	37.7894556086324158	-122.386231107658915
26151	2020-05-22 01:27:36	2020-05-22	Joelle Hand	joelle.hand@warmmail.com	Corona	California	3707971747780919	af934e26959284471c25f6c30925ac72	VISA 13 digit	33.9474715416673618	-117.619089825006199
26152	2020-05-22 01:48:13	2020-05-22	Sigmund Wolff	sigmund.wolff@geemail.com	Austin	Texas	51328488902004334	5e026f3a4bae90a223a9323a6732ff33	American Express	30.4036376214247177	-97.7665323308441856
26153	2020-05-22 02:02:35	2020-05-22	Citlalli Bayer	citlalli.bayer@warmmail.com	Pasadena	California	51620507315456271	436dbb2ccad3a5f8ee4b519f9954c01d	Mastercard	34.2147263284627385	-118.112654169770337
26154	2020-05-22 02:03:50	2020-05-22	Arra Hegmann	arra.hegmann@geemail.com	Overland Park	Kansas	869934985011215300	0f2beab0ca132d2b19e88e00a25b6972	VISA 16 digit	38.8465796217657626	-94.7294170423451902
26155	2020-05-22 02:07:28	2020-05-22	Ms. Ardeth Hansen DDS	ms.ardeth.hansen.dds@geemail.com	Phoenix	Arizona	52558420483667628	dda6e8009d776df6aac763c7a5148634	JCB 15 digit	33.6326223096277559	-112.051921953859193
26156	2020-05-22 02:16:19	2020-05-22	Burr Pagac	burr.pagac@warmmail.com	Fort Wayne	Indiana	3000617475481686	be055bd0e34af1434d9b3970cd4dd515	JCB 15 digit	41.0970803347665807	-85.1849819485317994
26157	2020-05-22 02:19:16	2020-05-22	Mrs. Prudence Gerhold	mrs.prudence.gerhold@geemail.com	Reno	Nevada	4395865851566	49b8151323c141de28f26ae77f981ed1	JCB 16 digit	39.5542295545417844	-119.753439652004843
26158	2020-05-22 02:20:02	2020-05-22	Dr. Kaycee Rath PhD	dr.kaycee.rath.phd@geemail.com	New York	New York	3337114396089604081	c02d4256fc4093a4c2647a4bb1bb79a1	Voyager	40.6493523183502248	-73.9880992134928732
26159	2020-05-22 02:22:06	2020-05-22	Arla Feil	arla.feil@warmmail.com	San Francisco	California	4587756077564258	fa0737c7ce96cc76a869c2cc4873c7b3	Diners Club / Carte Blanche	37.7386848969075075	-122.442007250943036
26160	2020-05-22 02:56:22	2020-05-22	Elder Stark	elder.stark@geemail.com	New York	New York	3467093265866652	6013926144dea7c377a796ae15677413	Maestro	40.72148228844069	-73.9819318144477904
26161	2020-05-22 03:01:01	2020-05-22	Kenyatta Hirthe V	kenyatta.hirthe.v@woohoo.com	Chicago	Illinois	3158453936519095548	3313a83150ccd4db36887c81a16d52be	JCB 16 digit	41.8615127025473868	-87.7257072899985957
26162	2020-05-22 03:18:35	2020-05-22	Faye Champlin DVM	faye.champlin.dvm@geemail.com	Brownsville	Texas	869910633914270794	8eb9a489ebb40989c64e5b301ab19e59	Voyager	26.0869615383058786	-97.4524677897989733
26163	2020-05-22 03:21:37	2020-05-22	Adelle Kunze	adelle.kunze@geemail.com	New York	New York	4533475942686	5ba7d9ee3209cc978e795a56735372c9	Mastercard	40.597279291389512	-73.8418980295199816
26164	2020-05-22 03:23:22	2020-05-22	Nathaly Berge DVM	nathaly.berge.dvm@geemail.com	San Antonio	Texas	180051619144277741	4d72e0ac9a35052c050c59aac41cefb8	Mastercard	29.5506438765745614	-98.4315164988696552
26165	2020-05-22 03:25:05	2020-05-22	Alfreda Kozey	alfreda.kozey@woohoo.com	Berkeley	California	4628136339635	13785a593aaa206ab0703e79bc4cbbc2	Voyager	37.8998791907229631	-122.271809915155472
26166	2020-05-22 03:30:30	2020-05-22	Isidore Bechtelar-Feest	isidore.bechtelar.feest@geemail.com	Elizabeth	New Jersey	3112194616737441963	8369749104c42250b2ea4ae1b95ea470	VISA 16 digit	40.6449935055930212	-74.1041397862080515
26167	2020-05-22 03:31:41	2020-05-22	Mr. Torey O'Kon	mr.torey.o'kon@geemail.com	Austin	Texas	3112872388758067296	7dec7036106073bfb993a99032d3704e	VISA 16 digit	30.3196410006038839	-97.6741609379421902
26168	2020-05-22 03:35:34	2020-05-22	Camryn O'Reilly	camryn.o'reilly@geemail.com	Hialeah	Florida	3477284553071430	95129265b427bd73d17dc77c488f883c	Mastercard	25.8672815077915814	-80.2383253479745235
26169	2020-05-22 03:45:44	2020-05-22	Hershel Feil	hershel.feil@warmmail.com	Davie	Florida	6011062579733280257	a494d4aa0bac0c62f1ce79aa86c293af	American Express	26.0749629265893255	-80.202432545358306
26170	2020-05-22 03:50:38	2020-05-22	Refugio Armstrong	refugio.armstrong@warmmail.com	Houston	Texas	3052999174554155	6f68a19cb05498e141a85e7b9d5cfe8f	JCB 16 digit	29.7950880897775292	-95.4186613810729227
26171	2020-05-22 03:51:33	2020-05-22	Mahala Corwin	mahala.corwin@warmmail.com	Waco	Texas	4922453718102243	ca64051c9fce4142e2a3cdb4cdaf3dbb	VISA 16 digit	31.6123593179717659	-97.2496567000299734
26172	2020-05-22 04:05:07	2020-05-22	Estevan Hamill	estevan.hamill@warmmail.com	Chicago	Illinois	3528517178875415093	c3f3b3f7a12ede272e2df291d352d1a9	JCB 15 digit	41.7412866229027557	-87.781434775007142
26173	2020-05-22 04:06:36	2020-05-22	Kanesha Nienow DVM	kanesha.nienow.dvm@woohoo.com	Indianapolis	Indiana	3044315279842999	d2ebee92e6473d60436d40a86996689e	Diners Club / Carte Blanche	39.8267285742338757	-86.2286433230820961
26174	2020-05-22 04:22:31	2020-05-22	Kirstie Aufderhar	kirstie.aufderhar@geemail.com	Los Angeles	California	676142516071745	3042dff1234bca0b9adf606042fc96ca	JCB 16 digit	33.9730296685226207	-118.476865568011249
26175	2020-05-22 04:30:27	2020-05-22	Sherwood Murray-Nader	sherwood.murray.nader@geemail.com	Des Moines	Iowa	3473732783528250	05925f47f6e788a4166c7aa670bbbd61	Mastercard	41.5799253920767455	-93.560019317879167
26176	2020-05-22 04:32:07	2020-05-22	Racheal Heathcote	racheal.heathcote@geemail.com	Ontario	California	4122941235041009	4805c62dd6b48ed9fd58e36b9de154b8	JCB 15 digit	34.063354992415384	-117.528508398831647
26177	2020-05-22 04:33:49	2020-05-22	Deshawn Hartmann-Hartmann	deshawn.hartmann.hartmann@geemail.com	Berkeley	California	3052029921928096	2706ad5c0baf73acff8ff8722c7f2e66	Diners Club / Carte Blanche	37.8489948605084194	-122.3063910968757
26178	2020-05-22 04:36:02	2020-05-22	Miss Rillie O'Keefe	miss.rillie.o'keefe@geemail.com	San Antonio	Texas	4239088707863765	13c9796cae8ab4c6c51e3d8024ef2c62	JCB 15 digit	29.3830625692453253	-98.5041166078135291
26179	2020-05-22 04:38:18	2020-05-22	Karlie Bahringer-Hilpert	karlie.bahringer.hilpert@geemail.com	Los Angeles	California	6011036794911287924	623373c0504f151ffad7b088de777dc8	Discover	34.0082257066253533	-118.40560799091979
26180	2020-05-22 04:53:35	2020-05-22	Markita Gleichner-Waters	markita.gleichner.waters@warmmail.com	Austin	Texas	3730096754151852	9e11ec02f687f9eebdadf3e22d5b4e1d	VISA 13 digit	30.3539859233550722	-97.6818848049040866
26181	2020-05-22 04:55:04	2020-05-22	Ricki Herman	ricki.herman@warmmail.com	Buffalo	New York	4973490808969	dc76791b4d8018d5fe735aeaada74cb8	JCB 15 digit	42.912852393016216	-78.942698507469899
26182	2020-05-22 05:26:12	2020-05-22	Dr. Alivia Hirthe DDS	dr.alivia.hirthe.dds@geemail.com	Sunnyvale	California	3017794648882455	497f9688e4cf6ab666da36110ea3d6c3	JCB 16 digit	37.3023100608486686	-122.050470829914516
26183	2020-05-22 05:26:52	2020-05-22	Demond Stiedemann DDS	demond.stiedemann.dds@geemail.com	Boston	Massachusetts	869945608703514874	d0f9a72a164a33d309cb582da7fbc045	VISA 13 digit	42.3697532236743726	-70.9236419492818442
26184	2020-05-22 05:27:30	2020-05-22	Leatha Oberbrunner	leatha.oberbrunner@geemail.com	Carrollton	Texas	6011490718301717892	aa956d548a6f0ce7a9084b8934a263c6	Mastercard	32.9539852288473369	-96.924641342633592
26185	2020-05-22 05:32:34	2020-05-22	Dr. Jorja Olson	dr.jorja.olson@geemail.com	Phoenix	Arizona	639040490406382	1a96a06d7038ebf3d39d56cb29b2ced4	VISA 13 digit	33.5936098857250087	-112.158980532262859
26186	2020-05-22 05:47:51	2020-05-22	Makai Hayes	makai.hayes@geemail.com	Louisville	Kentucky	3034854097871426	839cd2a6c04270f3372512569d267d61	Voyager	38.1950162674669187	-85.5730547790486469
26187	2020-05-22 05:49:24	2020-05-22	Devon Collier MD	devon.collier.md@geemail.com	Chula Vista	California	869930080853634356	7c5e4a9042b6e666bb78d0a1593215c7	American Express	32.722856815648079	-116.98107514374405
26188	2020-05-22 05:49:51	2020-05-22	Dr. Hector Jones	dr.hector.jones@warmmail.com	Virginia Beach	Virginia	4189732961454	26b279c6a9c078971d0a1bd627e696f9	VISA 16 digit	36.7878081745654342	-76.0600975193686821
26189	2020-05-22 05:51:54	2020-05-22	Celestino Feeney	celestino.feeney@geemail.com	Fargo	North Dakota	3799264019004146	71360d26b50213c4aa3032cf895c1b6a	Mastercard	46.8173672189235717	-96.7911687240432883
26190	2020-05-22 06:11:27	2020-05-22	Mandy Lynch	mandy.lynch@geemail.com	McAllen	Texas	51691048161263309	498e8689552fe63125da06567b991aad	Maestro	26.2166915476161968	-98.1558236018136085
26191	2020-05-22 06:19:23	2020-05-22	Willis Jast	willis.jast@geemail.com	New York	New York	3337190750187152236	e6d5d53bd225c80970df931c596d368d	JCB 16 digit	40.5724449745137221	-74.0371325072262465
26192	2020-05-22 06:25:36	2020-05-22	Isaac Becker	isaac.becker@warmmail.com	New York	New York	503865002147885	884ca707339dc0d314399b30b76c2348	Diners Club / Carte Blanche	40.7023121194671802	-74.0267320535041335
26193	2020-05-22 06:50:26	2020-05-22	Kurt Upton-Krajcik	kurt.upton.krajcik@warmmail.com	Cincinnati	Ohio	4194281813033042	d1849beaa68810eb3f19903dadb0430f	Mastercard	39.20359356331155	-84.4266374242763931
26194	2020-05-22 06:50:43	2020-05-22	Mrs. Letty Mohr	mrs.letty.mohr@geemail.com	Odessa	Texas	869980943658723410	3117f071ab08149b750329a6d2d4f008	JCB 16 digit	31.8170620057743037	-102.440501112925261
26195	2020-05-22 06:53:28	2020-05-22	Lee Roberts	lee.roberts@geemail.com	Sioux Falls	South Dakota	869977858782792765	5e4123645044b645df1160c2b8111c2c	Maestro	43.5509719243824449	-96.6784550594799157
26196	2020-05-22 06:57:02	2020-05-22	Love Barton-Reinger	love.barton.reinger@geemail.com	Cape Coral	Florida	4595656132072	f09b820229886bc0ea069e8016474d1b	VISA 13 digit	26.7133978908386069	-82.0415499964799722
26197	2020-05-22 07:01:42	2020-05-22	Delbert Ortiz-Daugherty	delbert.ortiz.daugherty@geemail.com	Phoenix	Arizona	675901831264070	df723ed15f361b68ff4d6306b10f6a48	Maestro	33.4888644121985877	-112.140591369143138
26198	2020-05-22 07:05:04	2020-05-22	Darry Ziemann	darry.ziemann@geemail.com	Denver	Colorado	4685978069238888	bab4752d93eca3b18ed4575610648190	Discover	39.6664641335658672	-104.971681658249722
26199	2020-05-22 07:28:49	2020-05-22	Krysta Abbott	krysta.abbott@geemail.com	Houston	Texas	53605104481135381	e3e096a4cdfc38625055fcefc470ce8a	JCB 16 digit	29.7682224921494729	-95.3388510299395762
26200	2020-05-22 07:29:13	2020-05-22	Mr. Gerardo Stroman	mr.gerardo.stroman@geemail.com	San Francisco	California	561297398162434	990af1a5f05cff9eb8a3d60f961baa45	Mastercard	37.7646782738893947	-122.39494374526636
26201	2020-05-22 07:29:45	2020-05-22	Mr. Rodger O'Keefe	mr.rodger.o'keefe@geemail.com	San Francisco	California	4863365805376673	7e94fc534b27ff4085c3d4d0f95594db	Discover	37.7827636320452953	-122.399258809138928
26202	2020-05-22 07:33:10	2020-05-22	Easter Buckridge	easter.buckridge@woohoo.com	Boston	Massachusetts	4371688156835871	e14cdde4674c91ee49e940049cd5c5ce	American Express	42.4181291866749532	-71.0071117150548901
26203	2020-05-22 07:49:19	2020-05-22	Elsworth Herzog	elsworth.herzog@woohoo.com	Philadelphia	Pennsylvania	630410159705739	78ba4b50f91d8b0c5851a55ee11de041	VISA 16 digit	39.9709107534453238	-75.0342064191952431
26204	2020-05-22 07:52:35	2020-05-22	Karel Davis	karel.davis@geemail.com	Winston–Salem	North Carolina	3034568564232397	67e41b1157f7185ecf14d749cd983ce4	JCB 15 digit	36.1086605608694242	-80.258675045998757
26205	2020-05-22 08:02:03	2020-05-22	Amelia Turcotte-Upton	amelia.turcotte.upton@geemail.com	Phoenix	Arizona	3088560354828352081	1e22fbaf01c81cb1048f5deec4f8e562	JCB 16 digit	33.6478806601304612	-112.18857766007298
26206	2020-05-22 08:11:33	2020-05-22	Lavonia Prosacco-Mertz	lavonia.prosacco.mertz@geemail.com	Chicago	Illinois	3528160561024912021	44790796dd2e1b704b2738153dee30b6	JCB 16 digit	41.9169449282180508	-87.6775731182221278
26207	2020-05-22 08:20:42	2020-05-22	Jerri Stracke DDS	jerri.stracke.dds@geemail.com	New York	New York	4450887779735633	34ead737ba5ec214ffd0fdc0130663c9	Voyager	40.5865772044043993	-73.914545609838143
26208	2020-05-22 08:24:53	2020-05-22	Pearlie Schinner-Adams	pearlie.schinner.adams@warmmail.com	Oakland	California	675986551113961	e00c5ab7b5722dd95647d902378cd242	American Express	37.8114939001143853	-122.320318663398268
26209	2020-05-22 08:40:43	2020-05-22	Miss Robyn Wehner PhD	miss.robyn.wehner.phd@geemail.com	San Francisco	California	3406858147267988	e5e06670ba920df75c6439184a61ea60	American Express	37.8023435114895889	-122.459131392609393
26210	2020-05-22 08:46:58	2020-05-22	Marget Kautzer	marget.kautzer@geemail.com	San Francisco	California	3528998323475172755	49e057c517107da160c20ac75d08e550	Maestro	37.7809529385781389	-122.423172420070387
26211	2020-05-22 09:00:48	2020-05-22	Dr. Dovie Koepp	dr.dovie.koepp@geemail.com	Chicago	Illinois	060435834071082	d7aae17abdfb3be4ab139ef75af6cc57	JCB 16 digit	41.7805371060803523	-87.6027644691087204
26212	2020-05-22 09:21:29	2020-05-22	Ms. Emmalee Jacobson	ms.emmalee.jacobson@woohoo.com	Berkeley	California	3030429343342102	2aa771d709005efc2d76e0e9836ace81	Voyager	37.8652907190359329	-122.254587115567716
26213	2020-05-22 09:34:06	2020-05-22	Crystal Halvorson-Price	crystal.halvorson.price@warmmail.com	Las Vegas	Nevada	180028978394443662	00a92072c7bc498801a40adf2e329deb	VISA 16 digit	36.2001681256208556	-115.280572293905905
26214	2020-05-22 09:35:39	2020-05-22	Delmus Wiegand	delmus.wiegand@geemail.com	Washington	District of Columbia	3088078259213898348	7b81cf64fb3ccc4fd3cccd85f8408b62	VISA 13 digit	38.9446310496687857	-77.0673399306114817
26215	2020-05-22 09:37:12	2020-05-22	Dr. Jennings Bashirian	dr.jennings.bashirian@woohoo.com	Naperville	Illinois	180090998248864221	c93b6939d4a8f462adce8c30eba1df67	American Express	41.6621964326508376	-88.2585363408438894
26216	2020-05-22 09:38:30	2020-05-22	Irvine Corwin	irvine.corwin@geemail.com	Woodbridge	New Jersey	180012939153178715	68237596dcdd05f1aaacb0c6b733633d	Discover	40.4713958537828162	-74.3653328525692245
26217	2020-05-22 09:42:47	2020-05-22	Heriberto Schumm-Hackett	heriberto.schumm.hackett@geemail.com	New York	New York	180059435236076756	d852973c7085411981a5b05bf66a7e8c	VISA 16 digit	40.6033416757583581	-73.8841624773934456
26218	2020-05-22 10:08:17	2020-05-22	Gino Gibson-Grady	gino.gibson.grady@geemail.com	Columbus	Ohio	4028375131746	7f7d9b2996b70c716220a24b63cd441e	Diners Club / Carte Blanche	40.0043242173779774	-82.966692617512507
26219	2020-05-22 10:10:18	2020-05-22	Chelsea Gerlach-Schinner	chelsea.gerlach.schinner@geemail.com	San Antonio	Texas	210083872125290744	1a9506e54e3a8361c0f9943a317c37c0	Maestro	29.5002660329524424	-98.4308085187174271
26220	2020-05-22 10:11:39	2020-05-22	Dr. Jakobe Mraz II	dr.jakobe.mraz.ii@geemail.com	Austin	Texas	869966941804629406	a2274f0c9667666fa674c65becb9f83f	VISA 16 digit	30.3839801344215843	-97.7521346897590888
26221	2020-05-22 10:27:04	2020-05-22	Marta Bradtke-Wunsch	marta.bradtke.wunsch@geemail.com	Virginia Beach	Virginia	53012116193338704	f15ec3b30da2e54745d8dc92bcccd301	VISA 13 digit	36.8137371604051467	-75.9806347126744726
26222	2020-05-22 10:27:50	2020-05-22	Reba Kuvalis	reba.kuvalis@woohoo.com	San Francisco	California	3528965152557974369	f83b70d8fd77d78f99e481ff8156056a	Discover	37.7762856208337752	-122.43110923240863
26223	2020-05-22 10:39:44	2020-05-22	Orrie Bayer	orrie.bayer@woohoo.com	Philadelphia	Pennsylvania	4382943151714127	9d5894e3c1f0241541b93dc864dd914e	American Express	39.9580286802217373	-75.1806815502598909
26224	2020-05-22 10:44:29	2020-05-22	Cathryn Ward	cathryn.ward@geemail.com	Hialeah	Florida	3709110883207738	351ac760d7abd53dca8af688ae93aade	Discover	25.8569608719531452	-80.3209996411479921
26225	2020-05-22 10:50:25	2020-05-22	Dr. Maribeth Ebert	dr.maribeth.ebert@geemail.com	Oakland	California	52147360227222611	70bba62ac2d21a6b99ac4809143a0ccc	JCB 16 digit	37.8111364300126453	-122.324306369348662
26226	2020-05-22 10:59:50	2020-05-22	Mr. Long Paucek	mr.long.paucek@woohoo.com	New York	New York	4788540210846641	6b09e08e3048524486b8d568a2486ed1	VISA 13 digit	40.7115807281099222	-73.9956982640910894
26227	2020-05-22 11:06:36	2020-05-22	Norbert Yost DVM	norbert.yost.dvm@geemail.com	San Francisco	California	4489428424253303	fb0aac6625342d5a2d0828acadb31cc1	VISA 16 digit	37.7819383293673567	-122.412763290330389
26228	2020-05-22 11:19:51	2020-05-22	Corine Lehner DVM	corine.lehner.dvm@geemail.com	San Francisco	California	3158414679931473913	17a86b29a65e6cd68eaaab7dbe3d515c	Maestro	37.7871702897549753	-122.425811299275594
26229	2020-05-22 11:26:34	2020-05-22	Mr. Chauncey Abshire II	mr.chauncey.abshire.ii@geemail.com	Sioux Falls	South Dakota	676278560237113	d4ca0f8952887980feb4fb47a3ec41a3	Maestro	43.5191499698061506	-96.7722024121954973
26230	2020-05-22 11:47:40	2020-05-22	Dr. Evan Ryan	dr.evan.ryan@geemail.com	Fort Worth	Texas	54348390028681472	77d8f6d91a8f20112ad14d066a2099a8	Voyager	32.7384603272248071	-97.4258464130394088
26231	2020-05-22 11:54:37	2020-05-22	Manilla Keebler	manilla.keebler@geemail.com	San Francisco	California	869946804754460385	dd785b6469808770184f98647fc5add3	Mastercard	37.7564070971385277	-122.428726391518822
26232	2020-05-22 12:12:47	2020-05-22	Deon Swift	deon.swift@geemail.com	San Francisco	California	52623469841751070	1bf5605aa43a6e4b538001758d4b805e	JCB 16 digit	37.768270680990824	-122.415040172144927
26233	2020-05-22 12:17:23	2020-05-22	Milburn Carter-Davis	milburn.carter.davis@geemail.com	Cape Coral	Florida	3041268504714488	672bc65e951308e88acdf6d27e620b63	VISA 16 digit	26.6906714461714039	-81.9557201573230287
26234	2020-05-22 12:34:12	2020-05-22	Siobhan Grant	siobhan.grant@geemail.com	Washington	District of Columbia	3158815658531652329	c6293c311cc6958ec5391af2bef9278c	Discover	38.8572328925862891	-76.9280252259436992
26235	2020-05-22 12:36:30	2020-05-22	Dr. Irving Dicki	dr.irving.dicki@geemail.com	New Orleans	Louisiana	4904683049157431	cf2a64b7308da59e7505a83377282f55	American Express	30.1452881723191588	-90.0070457335356622
26236	2020-05-22 12:40:19	2020-05-22	Mitchel Padberg	mitchel.padberg@geemail.com	Columbia	Missouri	3096592873650187838	94a2d1b2c7df513fd3b9b204e6d64f01	Diners Club / Carte Blanche	39.0010677386422273	-92.2531739869673828
26237	2020-05-22 12:40:27	2020-05-22	Irl Orn PhD	irl.orn.phd@geemail.com	New York	New York	4453529352511	d796555c1a7ab91cafa29c1bfae5f592	VISA 16 digit	40.7524768117573117	-73.9920047391567408
26238	2020-05-22 12:42:08	2020-05-22	Hoyt Schmitt I	hoyt.schmitt.i@woohoo.com	Kenosha	Wisconsin	3528875449332098772	03d603090707a8ee6015cf2661e2c383	Diners Club / Carte Blanche	42.5214354529816632	-87.7598168697435455
26239	2020-05-22 12:42:20	2020-05-22	Mrs. Cristal Labadie	mrs.cristal.labadie@geemail.com	San Francisco	California	4547601365622492	3da0b504626e71d7fd79dc6d05f7fe29	Voyager	37.7532216539351424	-122.42983515784907
26240	2020-05-22 12:46:05	2020-05-22	January Boyer	january.boyer@woohoo.com	New York	New York	869919347366557332	de09ffa690a26c5deac7cc894c4f30c1	JCB 16 digit	40.7567781869545556	-73.9678685704141827
26241	2020-05-22 13:01:46	2020-05-22	Keaton Jones	keaton.jones@geemail.com	Los Angeles	California	180003160355978361	385b97ee50c780924198097bde9aa538	VISA 16 digit	34.0134855433233056	-118.372307184896613
26242	2020-05-22 13:09:09	2020-05-22	Norma Ondricka	norma.ondricka@geemail.com	Las Vegas	Nevada	3337378595687784754	04d0cc28fc16800c78e6e70fba4c7d9e	JCB 16 digit	36.2310373483791963	-115.258040831677988
26243	2020-05-22 13:11:56	2020-05-22	Wally Gislason	wally.gislason@geemail.com	Joliet	Illinois	4891827395072	beb5096decfd17b8264ec9dbee8b53e3	JCB 15 digit	41.5975161854967439	-88.1738854149460707
26244	2020-05-22 13:26:55	2020-05-22	Bobbie Runolfsdottir	bobbie.runolfsdottir@woohoo.com	San Francisco	California	210034418844379002	f77afd1b7867ba011c23bab9b8659cfe	JCB 16 digit	37.7688241318750784	-122.465000022204109
26245	2020-05-22 13:30:59	2020-05-22	Mr. Marshal Batz PhD	mr.marshal.batz.phd@geemail.com	Fort Worth	Texas	4963505745132	ad5fbaf0de5bbbd1c4d610b78dca41de	Maestro	32.7602544818129431	-97.4326395106788681
26246	2020-05-22 13:32:37	2020-05-22	Vessie Ondricka	vessie.ondricka@woohoo.com	Milwaukee	Wisconsin	060447688420059	3d4f930d50d12104c9f0929509582f9f	VISA 13 digit	43.155997035521267	-88.0046869076889067
26247	2020-05-22 13:33:09	2020-05-22	Jeff Erdman	jeff.erdman@warmmail.com	New Haven	Connecticut	869950306615895380	7ed9f3a923605ba095a9fef76c99d6c4	Discover	41.341163600142302	-72.9515893384348573
26248	2020-05-22 13:40:36	2020-05-22	Devontae Abshire	devontae.abshire@geemail.com	Cleveland	Ohio	3059643425976964	32a9385d70a34ed6d0deda2ee667a2ac	Maestro	41.5656340685523986	-81.7338090580195171
26249	2020-05-22 13:42:41	2020-05-22	Jeramiah Fadel	jeramiah.fadel@warmmail.com	Thornton	Colorado	3528246628870957018	3e81b1ae7b6e00cd28af2c9bfe6686be	Discover	39.8412673430848869	-104.945048438261452
26250	2020-05-22 13:43:01	2020-05-22	Mai Reilly-Herman	mai.reilly.herman@warmmail.com	Phoenix	Arizona	51999682629377340	51e58b1f1770e0d2ec4df27fed62600a	VISA 16 digit	33.636491255967691	-112.066110508555923
26251	2020-05-22 13:50:29	2020-05-22	Lalla Langworth MD	lalla.langworth.md@geemail.com	Lowell	Massachusetts	869962219415259226	ffaa71bda46e240112e00e498c42c920	Maestro	42.7020089594982579	-71.3001378880221353
26252	2020-05-22 14:06:40	2020-05-22	Dr. Arnold Howe	dr.arnold.howe@geemail.com	San Francisco	California	4479798507677046	3b6950f4e4deffe3472eb8f6a4b7271f	JCB 16 digit	37.7830329073675344	-122.412316841738971
26253	2020-05-22 14:09:35	2020-05-22	Thornton Schamberger	thornton.schamberger@geemail.com	Oakland	California	3528316212875864639	a4ce6c84eb73449a6505aaa811e8598e	VISA 16 digit	37.7910111926843371	-122.289003955785077
26254	2020-05-22 14:14:57	2020-05-22	Durell Cronin	durell.cronin@geemail.com	Louisville	Kentucky	3474956556788069	8221f38722c57b6cd6371c8d78c7c330	Mastercard	38.0916774887960372	-85.5554520350020482
26255	2020-05-22 14:29:19	2020-05-22	Dr. Brittaney Reynolds PhD	dr.brittaney.reynolds.phd@geemail.com	Oakland	California	3088043384250081442	17647bf9c59048db00421b712d3dfd49	Diners Club / Carte Blanche	37.8012994822584076	-122.292274782753367
26256	2020-05-22 14:38:31	2020-05-22	Kenna Feest	kenna.feest@geemail.com	San Francisco	California	4256199706589	c10a1084ff3f7f4710a936cbe7c1e949	JCB 16 digit	37.739599520786264	-122.435159573251113
26257	2020-05-22 14:47:40	2020-05-22	Dr. Clarisa Gerhold DVM	dr.clarisa.gerhold.dvm@warmmail.com	Philadelphia	Pennsylvania	4046434593383	82de679e8ef2485908688490a8c13a1c	Diners Club / Carte Blanche	39.9184687457937741	-75.0912277611337657
26258	2020-05-22 14:50:44	2020-05-22	Delfina Schaden MD	delfina.schaden.md@geemail.com	Los Angeles	California	3701432619335023	242a460e10b77ded6f920e2df34966f7	JCB 15 digit	33.9720000720914399	-118.383634534477437
26259	2020-05-22 15:29:40	2020-05-22	Gillian Goldner	gillian.goldner@geemail.com	Albuquerque	New Mexico	3741133845872365	8a0928062b94ad055e17681ef28cc032	VISA 13 digit	35.1936858191289019	-106.59294205108435
26260	2020-05-22 15:46:59	2020-05-22	Sammie Rohan	sammie.rohan@warmmail.com	Baton Rouge	Louisiana	4298763170827368	2d8d2dfd972ab59fc777bb612619abfc	Discover	30.3720071771860134	-91.1554602570008399
26261	2020-05-22 15:56:13	2020-05-22	Dr. Gwendolyn Romaguera PhD	dr.gwendolyn.romaguera.phd@warmmail.com	Roseville	California	503877340308277	747b4718fe835691409e4d37ec057c9e	VISA 16 digit	38.8076645179707569	-121.221921555859595
26262	2020-05-22 15:56:24	2020-05-22	Miss Clarissa Johnson DDS	miss.clarissa.johnson.dds@geemail.com	San Francisco	California	6011169382114348112	8d3cfe68d784ab7fe2e83f396ed93772	Mastercard	37.7488164544854499	-122.408750237763073
26263	2020-05-22 15:58:03	2020-05-22	Vernon McLaughlin	vernon.mclaughlin@warmmail.com	New York	New York	3056856410651771	ea6f162e04001b08d25d4412972a7254	VISA 16 digit	40.6178072611093484	-73.9499837248016121
26264	2020-05-22 16:00:27	2020-05-22	Santana Sawayn	santana.sawayn@geemail.com	Berkeley	California	3741423411863785	c9186591993caadf5e3c18dc065ce160	VISA 16 digit	37.8614154415579165	-122.251487226948157
26265	2020-05-22 16:07:24	2020-05-22	Gene Bednar	gene.bednar@geemail.com	Chicago	Illinois	3418436990803526	43364afb560b55a6e476256ff09a1c34	Mastercard	41.8757915449630502	-87.6081206991832602
26266	2020-05-22 16:15:15	2020-05-22	Katerina Cormier	katerina.cormier@geemail.com	Fremont	California	6011763249690073325	e342a8ba88d9a7c5b5746f7e157f370c	VISA 16 digit	37.5783538405485444	-121.987340421787266
26267	2020-05-22 16:29:11	2020-05-22	Amit Jakubowski	amit.jakubowski@woohoo.com	Toledo	Ohio	3029491706554153	518cdfabb43e699afa8a2043d2e734a4	Maestro	41.569943975627794	-83.6266474067565042
26268	2020-05-22 16:29:48	2020-05-22	Mrs. Cleva Streich	mrs.cleva.streich@geemail.com	San Francisco	California	3088012970159143502	a4d9254e08d2b90fe437364d9b3ea41b	Mastercard	37.766955267809422	-122.434235638166058
26269	2020-05-22 16:45:24	2020-05-22	Louisa Toy	louisa.toy@woohoo.com	Simi Valley	California	6011616362755200888	63255f00ea87d2904c0cd25760cf2a68	JCB 16 digit	34.2431151536997405	-118.700936946332462
26270	2020-05-22 16:47:49	2020-05-22	Ms. Azzie Steuber	ms.azzie.steuber@geemail.com	Aurora	Illinois	3035830496807863	65c4bc6042beb85d80d9b17139e6a0a1	Mastercard	41.6673377325050538	-88.3597064915042267
26271	2020-05-22 17:02:26	2020-05-22	Jane Blick	jane.blick@geemail.com	San Francisco	California	55579698326067198	c17f4dfd7dd10dcd33f780396148bcc1	American Express	37.7432934186574158	-122.42448862493697
26272	2020-05-22 17:11:43	2020-05-22	Wirt Kunze	wirt.kunze@geemail.com	Wichita	Kansas	6011607195040535770	77063f3c48ae3e3f2b012ff52dc18470	VISA 16 digit	37.6656738089740273	-97.2999132105816216
26273	2020-05-22 17:14:36	2020-05-22	Sherree Windler	sherree.windler@warmmail.com	Birmingham	Alabama	6011339953117184947	bb654743a9c0d03be3ab1f6b8ebf4e76	Voyager	33.4284048377793255	-86.8353360349088916
26274	2020-05-22 17:16:08	2020-05-22	Malik Collins-Wilkinson	malik.collins.wilkinson@geemail.com	New York	New York	3088115822943383470	9a6fb790c07206994a4a2e11af21fe65	Maestro	40.6030719423890076	-73.8922423126537353
26275	2020-05-22 17:18:17	2020-05-22	Basil Cummings	basil.cummings@geemail.com	San Francisco	California	3041652316255717	91b17091960ab4fc44485022624c2eb0	VISA 16 digit	37.7908400500653983	-122.439495902350245
26276	2020-05-22 17:26:53	2020-05-22	Augustine Mann	augustine.mann@geemail.com	Mesquite	Texas	6011962030895751314	ca463e59e09a8b6b3cf85bfb35640051	Diners Club / Carte Blanche	32.7355509188301852	-96.5012758153222592
26277	2020-05-22 17:29:26	2020-05-22	Simpson Steuber-Kilback	simpson.steuber.kilback@geemail.com	Colorado Springs	Colorado	210017712556368505	2159c0e9fe4f8c8bac2cf7246db65e62	Diners Club / Carte Blanche	38.9340927968781472	-104.810088484796509
26278	2020-05-22 17:38:33	2020-05-22	Casper Weber	casper.weber@geemail.com	Jacksonville	Florida	3027635362094423	0b980765cc23543f3161bed2be83b563	Discover	30.344205297721178	-81.5857745423991361
26279	2020-05-22 18:04:01	2020-05-22	Hadley Klein	hadley.klein@woohoo.com	Arvada	Colorado	4538275493307952	1677d5d2ac29a455f3bcc140fa173d24	Maestro	39.8155453517742473	-105.052485606816788
26280	2020-05-22 18:07:00	2020-05-22	Savannah Langosh	savannah.langosh@geemail.com	Oceanside	California	4361040058146613	89e2651beb76ddd057879c51a69adc7a	JCB 15 digit	33.1319772380292434	-117.229318935991088
26281	2020-05-22 18:07:24	2020-05-22	Erving Ledner	erving.ledner@geemail.com	Detroit	Michigan	4500271836826	2b973d38de247f72e9223cf61b066ed6	Mastercard	42.3834344227258129	-83.0469993763256724
26282	2020-05-22 18:37:27	2020-05-22	Miss Alexis Kuvalis MD	miss.alexis.kuvalis.md@geemail.com	San Angelo	Texas	676258071347999	8e266b0bbace9e2f6bc7b8d3f473efc1	Maestro	31.4200901727810482	-100.38913660269418
26283	2020-05-22 18:55:09	2020-05-22	Khari Rolfson	khari.rolfson@warmmail.com	Fort Worth	Texas	4907364067932719	afba0f5eb51ce82449141a65783dcca7	Mastercard	32.7110499707106541	-97.3792192914344383
26284	2020-05-22 19:14:27	2020-05-22	Lashonda Krajcik	lashonda.krajcik@geemail.com	Los Angeles	California	6011516979222890875	5382f9727f7aa48f6bf1febe2e8d5ff9	Diners Club / Carte Blanche	33.9469837940163899	-118.458346271700407
26285	2020-05-22 19:17:42	2020-05-22	Afton Swift	afton.swift@warmmail.com	Coral Springs	Florida	3007352540347844	534be68a381957b8335d5d953f78eba7	JCB 16 digit	26.2136010503459751	-80.248052642739566
26286	2020-05-22 19:39:59	2020-05-22	Bonny Kerluke-Pagac	bonny.kerluke.pagac@geemail.com	High Point	North Carolina	4022597878028	5c8fbefb781fcab0571b383eb011e91d	Diners Club / Carte Blanche	36.0713066341914228	-79.9603684618342641
26287	2020-05-22 19:42:48	2020-05-22	Jep Boyle	jep.boyle@geemail.com	Chattanooga	Tennessee	3337893845459526032	96cce26a3d4ea25d6269650e2fb47e1a	VISA 16 digit	35.1599559869933884	-85.3410126323640412
26288	2020-05-22 19:46:52	2020-05-22	Grecia Conroy PhD	grecia.conroy.phd@geemail.com	San Jose	California	869965404433090236	0bb33c5bf55542d06a2ad56c3b95c67f	VISA 16 digit	37.2895072333335875	-121.746595473190396
26289	2020-05-22 19:49:21	2020-05-22	Mikel Rath	mikel.rath@warmmail.com	Aurora	Colorado	4766331454818553	a00896a1ff609f08cf3f07142990e090	JCB 15 digit	39.7147196866218053	-104.680762006074943
26290	2020-05-22 19:51:20	2020-05-22	Esau Haley	esau.haley@warmmail.com	Woodbridge	New Jersey	4791642501388658	afb26f09e4a9eeb2c05b1910a0d21bcd	Maestro	40.4832769117940217	-74.1996652684964175
26291	2020-05-22 19:51:22	2020-05-22	Ms. Joann Rowe	ms.joann.rowe@warmmail.com	Dallas	Texas	3038306390595497	e02cf6fdc1c774ab6f6ee29aef43c195	Voyager	32.7121688306137912	-96.8348785980101638
26292	2020-05-22 20:15:33	2020-05-22	Adonis Considine	adonis.considine@geemail.com	New York	New York	3465380215309103	a02870a4709a4df88ffed898fb8ecf18	American Express	40.6744955736901588	-73.9191559259675444
26293	2020-05-22 20:16:29	2020-05-22	Wong Hayes	wong.hayes@geemail.com	Gilbert	Arizona	4117607978136887	0338b252e2ed1a5086a924167db22f9f	VISA 13 digit	33.2549694661397481	-111.799382265437771
26294	2020-05-22 20:17:36	2020-05-22	Gaylene Doyle	gaylene.doyle@woohoo.com	New York	New York	3487976241795233	999b29406d19afffe900703f8fe6f942	VISA 16 digit	40.7397255317065827	-73.9752586168132638
26295	2020-05-22 20:21:27	2020-05-22	Ancil Braun	ancil.braun@geemail.com	Columbus	Ohio	4088048867873519	ac0579342f04c10eba607f8e7ecdfe5e	JCB 15 digit	40.0298429617702922	-82.8969374181006202
26296	2020-05-22 20:27:36	2020-05-22	Dexter Labadie	dexter.labadie@geemail.com	Houston	Texas	3446943040985852	5cba82a9a2c6e78cf21fe50c9ec886e4	VISA 13 digit	29.8275753720741719	-95.4383332844372916
26297	2020-05-22 20:28:13	2020-05-22	Llewellyn Walker Jr.	llewellyn.walker.jr.@woohoo.com	Los Angeles	California	3337042760293027198	34ab9d81afba5634e06f9458497fb63f	JCB 16 digit	33.95883441370502	-118.335092513541866
26298	2020-05-22 20:28:44	2020-05-22	Miss Jessenia Ernser DVM	miss.jessenia.ernser.dvm@geemail.com	Berkeley	California	4795494031531803	729afc1e8f01490b7395179d62549f76	Voyager	37.8671234469841451	-122.255285484677543
26299	2020-05-22 20:29:50	2020-05-22	Ely Roob	ely.roob@geemail.com	Pittsburgh	Pennsylvania	3088770124915120865	f15ca03ec684892c04b3a6a470f69f86	JCB 16 digit	40.4738789602603717	-79.9758228159681011
26300	2020-05-22 20:30:46	2020-05-22	Noel Bruen	noel.bruen@geemail.com	North Las Vegas	Nevada	6011051130087184670	6b3229b0ce86e6f70cd2437eacfde1b8	VISA 13 digit	36.3630180882912128	-115.005032300365727
26301	2020-05-22 20:40:28	2020-05-22	Gray Schamberger	gray.schamberger@geemail.com	New York	New York	4916282307073913	37cc926c66366d107445ca340bdad7b2	JCB 16 digit	40.7128889416102311	-73.8840620707616154
26302	2020-05-22 20:52:05	2020-05-22	Red Moore	red.moore@warmmail.com	El Paso	Texas	4575090849002163	cfc31e50654024f68980fa5553b7b5ff	JCB 16 digit	31.9403075854588323	-106.399585160378379
26303	2020-05-22 20:55:37	2020-05-22	Edward Schowalter	edward.schowalter@geemail.com	Detroit	Michigan	4114444796642	61822209cc1db65cfd3a96a7bed25a90	American Express	42.4676633621025843	-83.11164269630126
26304	2020-05-22 21:05:54	2020-05-22	Rubi Gibson DVM	rubi.gibson.dvm@warmmail.com	Fayetteville	North Carolina	4736698469375	8b734db3aba156bde21a13d1851db549	Discover	35.1341275664765362	-79.0410257632043169
26305	2020-05-22 21:16:20	2020-05-22	Kinsey Heaney	kinsey.heaney@warmmail.com	Seattle	Washington	869900311030642574	18da5ef645b893b49719c190124fb698	American Express	47.6854994147475821	-122.263979805113365
26306	2020-05-22 21:16:31	2020-05-22	Kingston Gutmann	kingston.gutmann@woohoo.com	Denton	Texas	4363923735046447	32cedf1a2ae5d930ed09be2907678527	VISA 16 digit	33.3133295041307775	-97.1733035529624658
26307	2020-05-22 21:16:35	2020-05-22	Erika Schmeler	erika.schmeler@geemail.com	Pittsburgh	Pennsylvania	180047631469549114	f3a890ffeab56d284522ea482aca3767	JCB 15 digit	40.5182696063026739	-80.0719980504535158
26308	2020-05-22 21:26:23	2020-05-22	Paola Fahey	paola.fahey@woohoo.com	Pasadena	Texas	3787522105386352	72e171bcfeb2fd6389331574e7bc5220	Voyager	29.5893863892521694	-95.1196637315623406
26309	2020-05-22 21:37:26	2020-05-22	Cecily Hammes	cecily.hammes@geemail.com	Anaheim	California	4813962798415	a0f269ad934e17161d63a404c5f6e0db	JCB 16 digit	33.7633137340024092	-117.736846759237721
26310	2020-05-22 21:43:48	2020-05-22	Santino Collier PhD	santino.collier.phd@geemail.com	Cleveland	Ohio	3424391235433229	778fbb63d5ad1011c299837487ed77ef	VISA 16 digit	41.5758151774145617	-81.6638319295603736
26311	2020-05-22 21:45:24	2020-05-22	Georgie Turcotte V	georgie.turcotte.v@geemail.com	San Francisco	California	4840213059904188	65885e712f9a18609e41fd008f2195c3	Diners Club / Carte Blanche	37.7857460223104624	-122.409641055281327
26312	2020-05-22 21:45:57	2020-05-22	Ora Romaguera DDS	ora.romaguera.dds@woohoo.com	Anaheim	California	3158651272600819491	ba2758ffd9f997e9081e485a7ebc42c6	Mastercard	33.8608853064775488	-117.761452098304773
26313	2020-05-22 21:51:20	2020-05-22	Ason Welch	ason.welch@geemail.com	San Jose	California	3001219545943420	dc062f5dbc2a1dbc2a4dcb952967e71a	Maestro	37.2209679840419483	-121.886514200152462
26314	2020-05-22 21:57:49	2020-05-22	Mr. Hudson Monahan	mr.hudson.monahan@geemail.com	Oklahoma City	Oklahoma	210050491370970592	e9660756329af4e8aea3e9a7ea8e3e2c	VISA 16 digit	35.4813444452736562	-97.4464119481284143
26315	2020-05-22 22:01:45	2020-05-22	Luciano Prosacco	luciano.prosacco@geemail.com	Oakland	California	3088219697008100513	2daf78550719c7e740226ab8472d2c70	JCB 16 digit	37.7835828392165709	-122.274185300348648
26316	2020-05-22 22:15:16	2020-05-22	Deandre Beatty	deandre.beatty@woohoo.com	Columbia	Missouri	869942884956216102	42c8a1e88bd902ac47f3061e745f6c2a	American Express	38.8552890194927016	-92.25360279195543
26317	2020-05-22 22:18:54	2020-05-22	Dr. Vern Howell	dr.vern.howell@geemail.com	Raleigh	North Carolina	869911932363252108	60b2ac1ac57e1bb73ccbadbbec4ac9ea	Voyager	35.8846989437606183	-78.5704086395382859
26318	2020-05-22 22:18:58	2020-05-22	Odalis Kohler	odalis.kohler@woohoo.com	Berkeley	California	869925396929740804	d3db6a9e63a40d9faf3c35927b03c41d	Mastercard	37.8542326022549744	-122.267439651036582
26319	2020-05-22 22:41:58	2020-05-22	Alwina Zboncak	alwina.zboncak@woohoo.com	New York	New York	54339731729257644	220bd5ff708115c026d466796adae14c	JCB 16 digit	40.7206904513053587	-74.0221892279468392
26320	2020-05-22 22:48:29	2020-05-22	Amin Gutmann II	amin.gutmann.ii@geemail.com	Dallas	Texas	4026661002357	f122009ea9aa2385be9c937518cfeed2	American Express	32.7336644291218377	-96.7831191784664924
26321	2020-05-22 22:52:17	2020-05-22	Cherie Hermann MD	cherie.hermann.md@geemail.com	Grand Prairie	Texas	3489201982491886	8985f9d6612c74fb1fb2f09f73bbfde2	JCB 16 digit	32.7312116313777892	-96.943914341308556
26322	2020-05-22 22:55:27	2020-05-22	Walt Rohan	walt.rohan@warmmail.com	San Francisco	California	502066833982946	1935afbb283e13e4ced75383e3638047	JCB 16 digit	37.7700537922707582	-122.448392135191
26323	2020-05-22 22:55:57	2020-05-22	Alston Langosh-Heathcote	alston.langosh.heathcote@geemail.com	Chicago	Illinois	869929577524450255	3facb37554ab8f6ad3e5d41feb6360ef	Maestro	41.8761588204488149	-87.6911604680616392
26324	2020-05-22 23:05:11	2020-05-22	Dr. Molly Cassin MD	dr.molly.cassin.md@woohoo.com	Chandler	Arizona	6011286720008099556	83356b0b8484ed4388442ea151fc8fe0	JCB 16 digit	33.2308825156740824	-111.925349858997023
26325	2020-05-22 23:09:07	2020-05-22	Nikko Medhurst	nikko.medhurst@geemail.com	Milwaukee	Wisconsin	3088010649971768470	e4579d197baf0c5177bdb692a60847af	JCB 16 digit	42.9992743715263899	-88.0013940422430636
26326	2020-05-22 23:19:32	2020-05-22	Eithel Schuster	eithel.schuster@warmmail.com	San Francisco	California	53064277737810801	8d627035d51f66c7d2e8b510a801f99c	Maestro	37.8215335054456361	-122.439282051296928
26327	2020-05-22 23:27:56	2020-05-22	Emmer Barton	emmer.barton@geemail.com	Jacksonville	Florida	180077923022810304	168d17724ad99a5f332a1eb578459886	Voyager	30.3105841122619815	-81.6563306523099612
26328	2020-05-22 23:28:12	2020-05-22	Rayan Nolan	rayan.nolan@geemail.com	Salt Lake City	Utah	3752066760562353	7d982eb10a58ca57b3f404caef51a000	JCB 15 digit	40.8507566592335678	-111.847372674424193
26329	2020-05-22 23:36:51	2020-05-22	Adelard Walter	adelard.walter@woohoo.com	San Diego	California	4932577783577620	8bf33405cb954a76e7534a4f41c80df5	Maestro	32.7611002070430644	-117.161252687117084
26330	2020-05-23 00:00:53	2020-05-23	Lowell Kiehn	lowell.kiehn@geemail.com	Stamford	Connecticut	4330714980902586	b2a25160c27c4fa6f0bfc5628bc270b9	American Express	41.1666344539146891	-73.5205699771214398
26331	2020-05-23 00:01:06	2020-05-23	Georgianna Rippin	georgianna.rippin@geemail.com	Louisville	Kentucky	3759396344424553	bf9c1fcdc67faf2175120c60c0ea0f0c	Voyager	38.1712939458802296	-85.5715540371906087
26332	2020-05-23 00:06:45	2020-05-23	Christ Romaguera I	christ.romaguera.i@geemail.com	Centennial	Colorado	3732600294335723	f0d08337dfc6ca0259bba4f407fc826b	VISA 13 digit	39.560495825395364	-104.807920021227005
26333	2020-05-23 00:27:53	2020-05-23	Cole Feest	cole.feest@geemail.com	New York	New York	52824766454783796	c11c3b38df6c073e7f35cf21debcaec4	American Express	40.6646751134879878	-73.9259405054513365
26334	2020-05-23 00:28:52	2020-05-23	Dr. Joesph Hilpert DDS	dr.joesph.hilpert.dds@geemail.com	Henderson	Nevada	4165006222683235	6f91d83ce4a0a36a5773efbd083dfeff	VISA 13 digit	35.9683053870152705	-114.986369514667246
26335	2020-05-23 00:31:15	2020-05-23	Eugene Mayer-Crist	eugene.mayer.crist@geemail.com	Berkeley	California	51749363913305890	5423acc1aabca84f200faa458e86a4e5	VISA 16 digit	37.8742801083886533	-122.292119044972935
26336	2020-05-23 00:45:02	2020-05-23	Kenna Jones PhD	kenna.jones.phd@geemail.com	Berkeley	California	3528197600713791069	1882388c8f998df0ce00442169515cd1	American Express	37.8886078781612099	-122.267738116272284
26337	2020-05-23 00:55:20	2020-05-23	Gena Kihn	gena.kihn@geemail.com	El Monte	California	060497561098761	83bf37cc1793c6790dae6455a1b977c2	JCB 16 digit	34.0531054006148111	-117.988595666669681
26338	2020-05-23 00:55:31	2020-05-23	Dr. Laquan Nienow V	dr.laquan.nienow.v@geemail.com	Charlotte	North Carolina	3016298473098915	6ed580b4f2491ea9fc4ab54b6004c1fe	Mastercard	35.222075515591726	-80.7779320730306267
26380	2020-05-23 04:54:32	2020-05-23	Devin Marks	devin.marks@woohoo.com	Everett	Washington	3096928073878133210	951b2f53768ac1b0ca881cd2580ec727	Discover	47.9226393263213382	-122.146220306459441
26339	2020-05-23 00:59:07	2020-05-23	Dessie Schuster	dessie.schuster@warmmail.com	West Palm Beach	Florida	639046054050169	6322132ce9152205549acd5ad6d20e20	Diners Club / Carte Blanche	26.6701459628377116	-80.1963907099164999
26340	2020-05-23 01:02:22	2020-05-23	Watt Lindgren Jr.	watt.lindgren.jr.@geemail.com	New York	New York	4170895039255259	73bd8c40f35df7f4a5d383db2488b1a2	JCB 15 digit	40.5671911454983061	-73.8817685370229214
26341	2020-05-23 01:13:41	2020-05-23	Dr. Oscar Swaniawski PhD	dr.oscar.swaniawski.phd@geemail.com	Odessa	Texas	52658859680038217	76a9d048b5845878d43f49a8021f2156	JCB 16 digit	31.9799284517776243	-102.280494011674449
26342	2020-05-23 01:17:29	2020-05-23	Geno Orn III	geno.orn.iii@geemail.com	Cleveland	Ohio	210000765593620824	22d2b4faa3da28d2247b5d147b53e032	Discover	41.5046115245521037	-81.6033295736420854
26343	2020-05-23 01:21:40	2020-05-23	Jinnie Crooks	jinnie.crooks@geemail.com	Chicago	Illinois	869981719408579826	8cd38ecf50f8cc224f6d3b7a221e0f1a	Discover	41.7873317346278625	-87.6911329753726676
26344	2020-05-23 01:34:16	2020-05-23	Oscar Rempel	oscar.rempel@woohoo.com	Omaha	Nebraska	3717587812882519	b3e12ea00a8d823982ac8b90cb5e641e	Discover	41.2654224820114663	-96.0435543435275605
26345	2020-05-23 01:35:34	2020-05-23	Wilbert Steuber I	wilbert.steuber.i@geemail.com	St. Louis	Missouri	3096239575830198960	388248d55347bec11814a4ffb4b7d9bd	JCB 16 digit	38.7016991942346067	-90.2198792882267497
26346	2020-05-23 01:41:14	2020-05-23	Mr. Wade Beatty	mr.wade.beatty@woohoo.com	Worcester	Massachusetts	4715412990288	de26904a0bb9babc3e2fa5382978b10c	American Express	42.2384575882628539	-71.834220715404669
26347	2020-05-23 01:42:09	2020-05-23	Rahul Stamm	rahul.stamm@warmmail.com	Murrieta	California	210025438357886723	d31fef3ee724d93ab7ea9142e5c1f010	JCB 16 digit	33.66948993151113	-117.185591025873649
26348	2020-05-23 01:46:24	2020-05-23	Richard Lockman	richard.lockman@geemail.com	San Francisco	California	51655773400061768	63279f5bf2cd5947203f9e71ab3b7855	JCB 15 digit	37.7563943497513392	-122.434105547864988
26349	2020-05-23 01:50:32	2020-05-23	Doreen Botsford	doreen.botsford@geemail.com	Minneapolis	Minnesota	3528055481079889784	0a930f26cf9346fc0ebbe07f9af1e4ea	Maestro	44.9475132052406607	-93.2092573950804706
26350	2020-05-23 01:52:39	2020-05-23	Lakeshia Boehm	lakeshia.boehm@geemail.com	Tuscaloosa	Alabama	55593567596986803	edf62c30fa060efdb78452930d4c102d	JCB 16 digit	33.2780995893348006	-87.4904031251654004
26351	2020-05-23 01:57:29	2020-05-23	Dr. Jakob Stokes II	dr.jakob.stokes.ii@warmmail.com	Portland	Oregon	3038782899610229	83dbd0e1bd818737ff80390993229590	American Express	45.4750370085593332	-122.619685532525182
26352	2020-05-23 02:19:28	2020-05-23	Hattie Grant	hattie.grant@geemail.com	Baltimore	Maryland	3014655815307340	8a6d537a3613223b2f16092885ab38a8	VISA 16 digit	39.3351064086426021	-76.5260085983686196
26353	2020-05-23 02:25:32	2020-05-23	Dr. Owens Bartell	dr.owens.bartell@geemail.com	Joliet	Illinois	869900446996124553	86d496994549eb88bfae4e48b23eaf01	Mastercard	41.5558699671037459	-88.137604425392297
26354	2020-05-23 02:27:43	2020-05-23	Gerrit Herzog	gerrit.herzog@woohoo.com	Fresno	California	561245405185633	a36f573c44200886bd808335596eeb60	VISA 16 digit	36.7108089634556336	-119.849703224246952
26355	2020-05-23 02:29:09	2020-05-23	Dr. Delores Frami PhD	dr.delores.frami.phd@geemail.com	New York	New York	3006344388268423	08bc63714f6f3e9b20ef76a2fd44fa45	VISA 16 digit	40.5751020848043282	-73.9653665690578492
26356	2020-05-23 02:42:15	2020-05-23	Mrs. Vonetta Armstrong MD	mrs.vonetta.armstrong.md@geemail.com	Louisville	Kentucky	630465366875162	12a21c58628d173e8f52bbc7ac179d5c	Mastercard	38.2330554457750154	-85.6162443201594101
26357	2020-05-23 02:42:29	2020-05-23	Edna Herzog	edna.herzog@geemail.com	Fort Lauderdale	Florida	3528549126488308694	c476e4232bd2d3f098388738af8876a7	Diners Club / Carte Blanche	26.061961853130537	-80.1755570956792667
26358	2020-05-23 02:52:18	2020-05-23	Kay Doyle	kay.doyle@geemail.com	Portland	Oregon	3050523314373557	bfb153b81b1f4086fbe2365d559b5d42	JCB 16 digit	45.6174830717854221	-122.712680320534858
26359	2020-05-23 02:57:08	2020-05-23	Jerilyn Walter	jerilyn.walter@geemail.com	Clarksville	Tennessee	3033990339600354	be44bad2d74f2db2952d4c656b974857	VISA 13 digit	36.655864015699926	-87.3889836476601687
26360	2020-05-23 02:58:47	2020-05-23	Rich Gorczany	rich.gorczany@geemail.com	New York	New York	3731224119971504	7c766a3f05199a61d2989270fa3ef376	VISA 16 digit	40.75011413216032	-73.8619301144860714
26361	2020-05-23 03:05:04	2020-05-23	Alex Conroy	alex.conroy@geemail.com	Charlotte	North Carolina	3033668815628905	f9921fce3ff6b06295ccb638a1415b48	VISA 16 digit	35.2202924588017154	-80.871586592629555
26362	2020-05-23 03:05:46	2020-05-23	Kymani Cruickshank	kymani.cruickshank@geemail.com	Garland	Texas	4286213691418	c1495146ad4975e4d35c2890041af7b6	JCB 16 digit	32.9130530020456717	-96.7169887699812705
26363	2020-05-23 03:06:59	2020-05-23	Katharina Sanford	katharina.sanford@geemail.com	Columbia	South Carolina	869923679334821695	0969ccc4ad25d8736c4259e3a12b1c05	Voyager	33.9833727713938814	-80.929647441396483
26364	2020-05-23 03:07:40	2020-05-23	Hadley Heidenreich	hadley.heidenreich@geemail.com	Allen	Texas	3112202712637416609	5b3a2e44d50313a82e7f75dd766b87e3	JCB 16 digit	33.1846612286780029	-96.5932407823339076
26365	2020-05-23 03:09:32	2020-05-23	Allen Ondricka	allen.ondricka@warmmail.com	San Francisco	California	6011417633303824176	fd44cb11beb41a240cc06b7bb3296a56	JCB 16 digit	37.7637046009684525	-122.405458360340972
26366	2020-05-23 03:21:07	2020-05-23	Dr. Santino Klocko Jr.	dr.santino.klocko.jr.@warmmail.com	Nashville	Tennessee	4198943198525	f24fb03bc94e3f90b086ac72a974d9dd	JCB 16 digit	36.2717659924767872	-86.8010772060975455
26367	2020-05-23 03:24:22	2020-05-23	Mrs. Bobbie Koelpin	mrs.bobbie.koelpin@geemail.com	San Francisco	California	3408502714135719	26250dcb55dace5cb3167bd8802c33b2	Diners Club / Carte Blanche	37.7799664962391333	-122.400881921568029
26368	2020-05-23 03:30:15	2020-05-23	Silver Harris-Nienow	silver.harris.nienow@geemail.com	San Francisco	California	3158444616145643026	768d9e17466acbf1cb6d9da35fbc71d7	VISA 16 digit	37.7734707698282293	-122.409319617356047
26369	2020-05-23 03:33:43	2020-05-23	Else Pouros-Russel	else.pouros.russel@warmmail.com	Baltimore	Maryland	676114294113288	6b88e7dbc0d12446586fceb94b04e481	JCB 16 digit	39.3532175319734918	-76.5382482957579242
26370	2020-05-23 03:36:08	2020-05-23	Marlon Pollich	marlon.pollich@geemail.com	San Francisco	California	210083465870118499	c4ded47faa0cd746ae4a5b8bee1c76ad	JCB 16 digit	37.7524541840000509	-122.458303777353123
26371	2020-05-23 03:59:21	2020-05-23	Irine Gleichner MD	irine.gleichner.md@warmmail.com	Oxnard	California	676101897309694	a08264db45f391b5f15cda0e4b2422c5	Mastercard	34.2979825115717958	-119.117001581788429
26372	2020-05-23 04:01:53	2020-05-23	Dr. Robbin Christiansen	dr.robbin.christiansen@geemail.com	Saint Paul	Minnesota	869900959676849547	9674d019c73ff39f96bc0142245be116	Discover	44.928480596042796	-93.1263477280069196
26373	2020-05-23 04:17:27	2020-05-23	Marlin Goyette-Konopelski	marlin.goyette.konopelski@geemail.com	San Francisco	California	6011724666392437839	76ad8005db1b104bc30776f3c48570ec	Voyager	37.7409413702677128	-122.429713498065766
26374	2020-05-23 04:28:01	2020-05-23	Jaimie Barrows	jaimie.barrows@geemail.com	New York	New York	4434706078534433	dc149040945b0431b9d4157a460c6074	Voyager	40.6448665691297464	-74.0185119588289382
26375	2020-05-23 04:34:15	2020-05-23	Elmer Macejkovic II	elmer.macejkovic.ii@geemail.com	Fullerton	California	6011154945634619282	99d35434a44c259187634ce9a1fe76a1	Maestro	33.9821120388496638	-117.852747198261312
26376	2020-05-23 04:36:19	2020-05-23	Rohan Herzog	rohan.herzog@geemail.com	San Francisco	California	6011490655114837899	c0196d2101baccd52f64dd0ebcb5a66e	Voyager	37.7629292966967753	-122.424006313212629
26377	2020-05-23 04:37:29	2020-05-23	Scot Casper-O'Reilly	scot.casper.o'reilly@geemail.com	San Francisco	California	3158965850077891142	b7ae94c6e155de8e5b6160ebdfc29c16	VISA 16 digit	37.7856131491286078	-122.405952829624439
26378	2020-05-23 04:38:34	2020-05-23	Cordell Konopelski	cordell.konopelski@geemail.com	Wilmington	North Carolina	3158768569774443283	6760daa44737aca952ddcb4982bc5c7c	Voyager	34.1381553514681784	-77.8084612662430857
26379	2020-05-23 04:46:59	2020-05-23	Avon Feil	avon.feil@geemail.com	New Orleans	Louisiana	210046660696441929	066b511e6e112f7b96ad518aa4367af9	Discover	30.0219175213962792	-89.9517863668762203
26381	2020-05-23 05:01:37	2020-05-23	Anona Wintheiser DDS	anona.wintheiser.dds@geemail.com	Gilbert	Arizona	210087934889906323	5ab7c99842ee51c3606201ac75e752da	Mastercard	33.2914517457477714	-111.740267544858526
26382	2020-05-23 05:02:20	2020-05-23	Dicy Mills	dicy.mills@geemail.com	Honolulu	Hawaii	6011712346453611986	c17600dcc5d1d32b5aa3ab90beabb8a4	Discover	21.3768668455753499	-157.761871513279516
26383	2020-05-23 05:04:07	2020-05-23	Timmy Murphy	timmy.murphy@warmmail.com	San Diego	California	3033317499280985	f25743d2f32d37e07347f187ae4be578	JCB 15 digit	32.7775668615542344	-117.213915049089124
26384	2020-05-23 05:09:28	2020-05-23	Miesha Mohr	miesha.mohr@woohoo.com	San Francisco	California	3096168568087578690	d074b51fcd04b05e966fe108226e6366	VISA 13 digit	37.7800785552657814	-122.440604870786245
26385	2020-05-23 05:17:58	2020-05-23	Ms. Lethia Kohler MD	ms.lethia.kohler.md@geemail.com	Columbia	South Carolina	4379775711516	5a46f305bd38c5f03a4b66b6e8a1d3ae	American Express	33.9696944854021083	-80.8107625838853352
26386	2020-05-23 05:18:05	2020-05-23	Imanol Herman	imanol.herman@geemail.com	San Diego	California	3467598263104963	c653e964d91cac207c5fb007063d7669	Voyager	32.9143660475566975	-117.088471928136428
26387	2020-05-23 05:21:20	2020-05-23	Kierra Klein	kierra.klein@geemail.com	Los Angeles	California	180064219191336204	929d64e0c2a77d3f9a25045bcba3eff7	Maestro	34.0857267152383869	-118.451564779690642
26388	2020-05-23 05:23:26	2020-05-23	Anton Lehner	anton.lehner@warmmail.com	Plano	Texas	4920943555830502	25317c1a3fd1193173bfe2a05decf7f5	Maestro	33.1491716188464309	-96.8120592965926932
26389	2020-05-23 05:30:01	2020-05-23	Fulton Stoltenberg V	fulton.stoltenberg.v@geemail.com	Denver	Colorado	3158193898530808520	cfb0cc8df7e6f323a6d5d8e6af8ed230	Diners Club / Carte Blanche	39.7352517473563509	-104.800544569433114
26390	2020-05-23 05:42:33	2020-05-23	Cris Gusikowski II	cris.gusikowski.ii@geemail.com	Tulsa	Oklahoma	53907994589999471	3cb94bd83bd12b2d163bee8ca468f6fb	Discover	36.1045656976658833	-95.9888963533986299
26391	2020-05-23 05:47:55	2020-05-23	Elnora Langosh	elnora.langosh@woohoo.com	San Francisco	California	501865136289553	56c5824eebac6ef9eeb9c94f1feb1205	Maestro	37.78025107895796	-122.443592178962078
26392	2020-05-23 06:07:20	2020-05-23	Dr. Marylin Klocko MD	dr.marylin.klocko.md@geemail.com	Cape Coral	Florida	3729849442885445	dab0e081c39aede33dc0767120c064b9	VISA 16 digit	26.6478451878268281	-82.0112928457163264
26393	2020-05-23 06:10:00	2020-05-23	Nayely Hackett	nayely.hackett@warmmail.com	Berkeley	California	180038417716392255	5f626ba6b67fa650e324f2dae8188e5f	Mastercard	37.9006894544034054	-122.279653164510449
26394	2020-05-23 06:17:28	2020-05-23	Reatha Carroll	reatha.carroll@geemail.com	Columbia	Missouri	180058335931946611	44f565db4d31658405209c4866830d70	VISA 13 digit	38.8944707060579802	-92.3054693894514031
26395	2020-05-23 06:23:04	2020-05-23	Ewart Schiller	ewart.schiller@geemail.com	Chicago	Illinois	869966050326214646	c0a9a5c7bca7b973324316efc6256bfd	VISA 16 digit	41.8980808871634309	-87.7646359026927456
26396	2020-05-23 06:28:37	2020-05-23	Ivah Fritsch-Ryan	ivah.fritsch.ryan@warmmail.com	Detroit	Michigan	4953237479575602	d8c7779ac619e0883daecba821101d16	JCB 16 digit	42.3228890800308477	-83.13539676388055
26397	2020-05-23 06:29:15	2020-05-23	Marcellus Heller	marcellus.heller@woohoo.com	Odessa	Texas	3028434000479363	b0cd989bdf7fdfb8681f616dd19a6d98	American Express	31.9771254062663779	-102.258050146201995
26398	2020-05-23 06:40:41	2020-05-23	Mrs. Giada Braun	mrs.giada.braun@woohoo.com	Pomona	California	3047739010783625	8369f4f81488c7f851c98563eaea63d8	Maestro	34.1087962709870212	-117.834745328916611
26399	2020-05-23 06:42:21	2020-05-23	Mrs. Tonia Bayer	mrs.tonia.bayer@geemail.com	Oklahoma City	Oklahoma	4460667576809031	873e1c274a43168ba2afebe88b7e3587	American Express	35.3724114506881691	-97.4227212978888275
26400	2020-05-23 06:45:14	2020-05-23	Rene Goldner	rene.goldner@woohoo.com	New York	New York	210065846598252003	51104b75ed94408fb279f309f3d26aa4	Mastercard	40.7507871370054744	-73.921410881019014
26401	2020-05-23 06:49:05	2020-05-23	Tab Windler	tab.windler@geemail.com	Houston	Texas	3528590763527879513	6d37d146f3305330cf12616048a80fa3	Diners Club / Carte Blanche	29.8705377314783647	-95.3330488458290688
26402	2020-05-23 06:50:05	2020-05-23	Scotty Lebsack	scotty.lebsack@geemail.com	Carrollton	Texas	4366871395906540	5ffc910ebbfb632ec9e9e8aefd057675	JCB 15 digit	33.0388876922350363	-96.9400391398791186
26403	2020-05-23 06:50:25	2020-05-23	Aedan Jacobs	aedan.jacobs@geemail.com	San Francisco	California	3762910133028089	8cae9d62926ac705efa7e8e8efb67ff7	VISA 16 digit	37.7880683654800507	-122.464397714564143
26404	2020-05-23 06:52:48	2020-05-23	Gisele Block	gisele.block@warmmail.com	Jacksonville	Florida	639091333818416	0b2cc20a4672b0cbc67afeaabdafebe8	JCB 16 digit	30.4368036850407719	-81.717346001377706
26405	2020-05-23 06:59:44	2020-05-23	Shari Fadel	shari.fadel@geemail.com	Huntington Beach	California	676185859960537	28f416c7acfdaca50115ea371d4f06c6	American Express	33.6357939293183392	-118.069877902616923
26406	2020-05-23 07:17:40	2020-05-23	Glenwood Bins	glenwood.bins@geemail.com	Fort Worth	Texas	3049073033018647	a0bd319821035576d3152de6007da120	JCB 16 digit	32.6888898405767989	-97.2967995798967706
26407	2020-05-23 07:24:04	2020-05-23	Meghan Anderson-O'Connell	meghan.anderson.o'connell@geemail.com	Tampa	Florida	6011170640494114603	c0e017d05e91ec72126f9288a22ade36	VISA 13 digit	28.0172241558436284	-82.4733027230229112
26408	2020-05-23 07:28:54	2020-05-23	Dr. Isadore Kozey Sr.	dr.isadore.kozey.sr.@geemail.com	Oakland	California	6011610672877174381	81116f2fd9d5108835dbd95f2a82683d	JCB 16 digit	37.7949835597138701	-122.225988238261252
26409	2020-05-23 07:30:57	2020-05-23	Dr. Furman Sauer IV	dr.furman.sauer.iv@geemail.com	New York	New York	51731766675739181	e45590a48833da9c2123daf39c86d694	Voyager	40.7630596104301475	-73.9694127712294431
26410	2020-05-23 07:32:16	2020-05-23	Andon Brekke	andon.brekke@geemail.com	Orange	California	4745089590798	9fc275f4e27b9e0669aa293351809641	VISA 13 digit	33.7688534017074815	-117.903603437739605
26411	2020-05-23 07:39:23	2020-05-23	Susana Rogahn	susana.rogahn@woohoo.com	Antioch	California	4927517613220667	c86e27a2d7f0f04c52050c432aa59c35	JCB 16 digit	38.0196477269087012	-121.893925287964564
26412	2020-05-23 07:57:19	2020-05-23	Mrs. Hazelle Bartell	mrs.hazelle.bartell@geemail.com	Pomona	California	6011944087648296669	db8d5be48a883bc57e25dce2e830e485	JCB 15 digit	34.0139152559954709	-117.780714688819273
26413	2020-05-23 07:58:18	2020-05-23	Natalie Nienow	natalie.nienow@geemail.com	Charlotte	North Carolina	630418692562012	b5753ac5864d5f0eb039e58949f88bf7	Maestro	35.2272086171686638	-80.9283631156142889
26414	2020-05-23 07:59:34	2020-05-23	Lary Welch I	lary.welch.i@geemail.com	San Diego	California	3036033957362606	8f1357e556a1d306a331c7f7bb815e40	Voyager	32.778702427779514	-117.064001869633799
26415	2020-05-23 08:12:00	2020-05-23	Dona Larkin	dona.larkin@woohoo.com	Concord	California	6011202568606005306	2fffe0a5648182a8fa917f4d5783c7d2	Voyager	37.8976830932710342	-121.947911305649569
26416	2020-05-23 08:26:21	2020-05-23	Paulo Goldner-Brown	paulo.goldner.brown@geemail.com	Houston	Texas	4392468951045959	e45a83f442fa066cd989e59b00df897d	Mastercard	29.7785790183193981	-95.3315520687043687
26417	2020-05-23 08:28:51	2020-05-23	Melville Mitchell-Schneider	melville.mitchell.schneider@woohoo.com	Nashville	Tennessee	55228190527213073	d14aff1e72c843435702a17f707a5a22	JCB 16 digit	36.1454490290611972	-86.8800932997744439
26418	2020-05-23 08:34:49	2020-05-23	Santos Roob	santos.roob@woohoo.com	Joliet	Illinois	676148419206239	7cb5a7d03bf427143f5955fafbd5615e	JCB 16 digit	41.4923547082904705	-88.149338260675961
26419	2020-05-23 08:37:48	2020-05-23	Johnie Hettinger	johnie.hettinger@woohoo.com	Miami	Florida	6011352839763835266	9d7059db4322a5fc8409472a17151e04	VISA 16 digit	25.6991476624876292	-80.1318573592104002
26420	2020-05-23 08:40:21	2020-05-23	Christian Hackett-Hand	christian.hackett.hand@geemail.com	Chesapeake	Virginia	3721199610465895	b6158a86d74500b3aed4b85a7992bee6	VISA 13 digit	36.6992868308216345	-76.379760760379213
26421	2020-05-23 08:46:11	2020-05-23	Fredy Gulgowski	fredy.gulgowski@warmmail.com	New York	New York	210082129214234013	5281dbe6eb495478f5ae9989fddae955	JCB 16 digit	40.711229243291541	-73.970391476935518
26422	2020-05-23 08:51:58	2020-05-23	Destini Feeney-Doyle	destini.feeney.doyle@geemail.com	Birmingham	Alabama	060437029778406	bfa7afcef2e1ad28458adad359714cde	Discover	33.5087637383747818	-86.7212577225416936
26423	2020-05-23 09:00:22	2020-05-23	Misael Reichert-Kuvalis	misael.reichert.kuvalis@warmmail.com	Winston–Salem	North Carolina	3009200710181196	9b4567de354433db0a1a64131e0d02a1	VISA 16 digit	36.1372849596429617	-80.2144956480842097
26424	2020-05-23 09:06:27	2020-05-23	Gianna Mitchell PhD	gianna.mitchell.phd@warmmail.com	North Las Vegas	Nevada	4188899706212072	741fe48a2c8011c20abcb341bafa14da	JCB 16 digit	36.3441321440663145	-115.131425620544334
26425	2020-05-23 09:18:05	2020-05-23	Simeon Marvin Jr.	simeon.marvin.jr.@geemail.com	Elk Grove	California	6011073075298505458	c456f336171a2b17907d6cc8bdb2b332	Maestro	38.389948913576454	-121.336142476778477
26426	2020-05-23 09:18:12	2020-05-23	Tremayne Weissnat	tremayne.weissnat@woohoo.com	Philadelphia	Pennsylvania	4864349543619494	f689c79a23c8931cd1f0dd6069648ef2	VISA 16 digit	40.0603095458313803	-75.2045001985870414
26427	2020-05-23 09:22:27	2020-05-23	Verna Ruecker	verna.ruecker@warmmail.com	Toledo	Ohio	210042329179562445	ec282a37877af47492e0e473c821d5e7	VISA 16 digit	41.6513693398967391	-83.6189919632259802
26428	2020-05-23 09:35:21	2020-05-23	Dr. Venus Gutkowski DDS	dr.venus.gutkowski.dds@geemail.com	San Francisco	California	4339354952755307	c9f3e52872262d7e5c033b5a171ca909	JCB 16 digit	37.7992890417013285	-122.451582201864653
26429	2020-05-23 09:44:53	2020-05-23	Vidal Kovacek	vidal.kovacek@geemail.com	Chicago	Illinois	501878582234494	f1532c9de4c9fd977a192be3a9d838fc	VISA 16 digit	41.8358998747378621	-87.640056254717706
26430	2020-05-23 09:47:27	2020-05-23	Vick Anderson	vick.anderson@geemail.com	San Francisco	California	3408108980773983	84933a8c30824b74913af8379cc735ce	Mastercard	37.7693476275221514	-122.434580334662058
26431	2020-05-23 09:53:57	2020-05-23	Latonya Mueller PhD	latonya.mueller.phd@warmmail.com	Garland	Texas	502015215400977	10b0b2dfc475d3d6b5a7e00a6c615579	VISA 16 digit	32.9148913362763764	-96.6171034370243547
26432	2020-05-23 10:10:23	2020-05-23	Earnestine Franecki	earnestine.franecki@warmmail.com	Tyler	Texas	53131411235870335	9404482012c94d1526a5a063c6bafbf1	JCB 16 digit	32.2445906859405369	-95.3449577008481981
26433	2020-05-23 10:20:41	2020-05-23	Mrs. Mickey Upton MD	mrs.mickey.upton.md@warmmail.com	Austin	Texas	52940685256874448	970a2981e1790f0e09ed60937974c00e	Discover	30.3256907023150468	-97.6808550175052233
26434	2020-05-23 10:34:20	2020-05-23	Kyrie Padberg	kyrie.padberg@geemail.com	San Francisco	California	3096145543711140512	9773e79280642d9d43f259a487b1951c	VISA 16 digit	37.7859584225177656	-122.4381154506614
26435	2020-05-23 10:51:47	2020-05-23	Macy Gibson	macy.gibson@warmmail.com	Memphis	Tennessee	3484193618302717	2030da41b5c05bbd7698f551d4ef5395	Voyager	35.0271116448633393	-89.8779245249252767
26436	2020-05-23 11:07:08	2020-05-23	Ms. Caryn Auer PhD	ms.caryn.auer.phd@geemail.com	New York	New York	180084344225929117	1c2413a16b29142c9834de338860b5ab	American Express	40.6190437916424116	-74.0367583580210749
26437	2020-05-23 11:10:24	2020-05-23	Dr. Neppie Cremin DVM	dr.neppie.cremin.dvm@geemail.com	Thousand Oaks	California	3038005716379426	befa901fc4f8d29698d8302c27fb07d7	American Express	34.2029990909893087	-118.860398745667936
26438	2020-05-23 11:18:12	2020-05-23	Norval Kuvalis	norval.kuvalis@woohoo.com	Warren	Michigan	4211523870157449	9a11b266503f9cbe3f3cf4ead296020d	JCB 16 digit	42.5331594161219897	-83.1180200190749048
26439	2020-05-23 11:32:24	2020-05-23	Hanson Gislason	hanson.gislason@geemail.com	Anaheim	California	6011937798037043004	d485e2cb596c532e47e336c4c1332c16	Diners Club / Carte Blanche	33.8965254091955686	-117.821400694104284
26440	2020-05-23 11:36:19	2020-05-23	Ishaan Considine	ishaan.considine@geemail.com	Irvine	California	3088365150801926728	37c40b4b53876e91372f17283594da14	JCB 15 digit	33.6241500391639789	-117.781308856933563
26441	2020-05-23 11:44:11	2020-05-23	Carolee Marvin PhD	carolee.marvin.phd@geemail.com	Fort Collins	Colorado	3528206131230291895	ec296ab027f87f23e2aa42cabf9baa79	VISA 13 digit	40.5509013177983491	-105.116081494833537
26442	2020-05-23 11:45:18	2020-05-23	Miss Lucetta O'Kon	miss.lucetta.o'kon@geemail.com	San Francisco	California	869953365290869158	2100b832583edfbf33e89aaa56980c4d	Discover	37.8052355556439537	-122.428825309659203
26443	2020-05-23 11:57:21	2020-05-23	Adina Carter	adina.carter@geemail.com	Springfield	Illinois	6011939347349130311	304e8096fb99112e4964e1902ac1c1f3	JCB 16 digit	39.7536385095365361	-89.7149877044841588
26444	2020-05-23 12:07:15	2020-05-23	Ishmael Kerluke	ishmael.kerluke@geemail.com	Augusta	Georgia	4239806793159552	838a161f7b3e8c35226742c36987a3b7	VISA 16 digit	33.3169487609732897	-82.0548696169458367
26445	2020-05-23 12:07:20	2020-05-23	Melinda Friesen	melinda.friesen@woohoo.com	San Francisco	California	676232469468642	a64956daaed1d6600a2f4684ea53062f	JCB 16 digit	37.7542241099173097	-122.424212219987837
26446	2020-05-23 12:10:04	2020-05-23	Mr. Seneca Swaniawski II	mr.seneca.swaniawski.ii@geemail.com	Colorado Springs	Colorado	502082496545615	87e3a3ffe9dcd8667e38c57d0cfad410	Mastercard	38.9280528131920818	-104.79831581541039
26447	2020-05-23 12:16:07	2020-05-23	Aubrey Bogisich	aubrey.bogisich@warmmail.com	Lincoln	Nebraska	6011722165429001777	cb998e1e309c8e2c2ed9cc5c6ee372e7	Diners Club / Carte Blanche	40.8385388454440985	-96.611927023266631
26448	2020-05-23 12:23:45	2020-05-23	Shannen Glover	shannen.glover@woohoo.com	Atlanta	Georgia	210081222277325165	33e45e45ccc0f3a053b006ecfe251fc9	American Express	33.8131756335306903	-84.383753540883589
26449	2020-05-23 12:24:06	2020-05-23	Mr. Coleman Grady	mr.coleman.grady@geemail.com	San Francisco	California	6011153309814677308	1758be2eeed54246f2df3b31e536297e	JCB 15 digit	37.7260506511130842	-122.462594534099765
26450	2020-05-23 12:30:46	2020-05-23	Dr. Argie Hegmann PhD	dr.argie.hegmann.phd@geemail.com	El Paso	Texas	3088574409161184253	945461b2b2796325232e0263ab4ddfb1	JCB 16 digit	31.8487249072469787	-106.438311873141686
26451	2020-05-23 12:32:29	2020-05-23	Stevie Krajcik	stevie.krajcik@woohoo.com	Saint Paul	Minnesota	3007311292723941	b997fda3c20abf07e62de4770a357bb5	American Express	44.9711340921871354	-93.1528185047008179
26452	2020-05-23 12:32:35	2020-05-23	Jessika Hand	jessika.hand@geemail.com	San Francisco	California	4735843348920211	053565f4cc42d6639f36d5cc170433b9	American Express	37.7945561351215886	-122.467280717322978
26453	2020-05-23 12:35:32	2020-05-23	Dr. Jonathan Reilly II	dr.jonathan.reilly.ii@geemail.com	San Francisco	California	180062022469476195	6eb244f02bd108f67546e340ba5f125b	Voyager	37.804173161658845	-122.458308612109207
26454	2020-05-23 12:35:32	2020-05-23	Darci Renner	darci.renner@geemail.com	Kansas City	Missouri	869966585399514505	2525e368fef290ac74e374775104d652	American Express	39.1063888062093454	-94.6027701820936073
26455	2020-05-23 12:38:46	2020-05-23	Maurice Thiel	maurice.thiel@woohoo.com	Spokane	Washington	52967770912385001	a3e88e17b4c9e6bdd1766f75d87cdfca	VISA 13 digit	47.6209294114034591	-117.493835316262391
26456	2020-05-23 12:45:47	2020-05-23	Amira Zulauf-Cruickshank	amira.zulauf.cruickshank@geemail.com	Topeka	Kansas	55279875786545110	8e493ec2f7f5309bacd7cfd7e78fbcfe	American Express	39.0686696904178703	-95.6431366167206392
26457	2020-05-23 13:02:55	2020-05-23	Osa McCullough	osa.mccullough@warmmail.com	Houston	Texas	4256881343492652	f819d29ff0db1ea4c957c76f72600fef	American Express	29.8534044545687749	-95.4902925730232113
26458	2020-05-23 13:04:26	2020-05-23	Danielle Fadel	danielle.fadel@geemail.com	New York	New York	3337245904913496608	6566dbbd787a7d0f7d89eb82c801bc3f	JCB 15 digit	40.7197883562408407	-73.857005740458888
26459	2020-05-23 13:13:34	2020-05-23	Cami Mayer	cami.mayer@woohoo.com	San Francisco	California	3337895337137212175	6c42c321bf0885fcca758be25471a941	Diners Club / Carte Blanche	37.7394755663910644	-122.43607675703538
26460	2020-05-23 13:14:34	2020-05-23	Chas Keebler-Boehm	chas.keebler.boehm@geemail.com	Wichita	Kansas	3096171565064497626	b914b51e5b6ff047abd6a2c0f14dd194	VISA 13 digit	37.7429896870505033	-97.4083260243494067
26461	2020-05-23 13:20:02	2020-05-23	Clotilde Barton	clotilde.barton@geemail.com	Ann Arbor	Michigan	54807511055045992	2fc07ce1d77e8698199faa31e3fe000d	Mastercard	42.368580771103872	-83.6663272325523195
26462	2020-05-23 13:24:10	2020-05-23	Chandler Witting	chandler.witting@geemail.com	Salem	Oregon	210058720357131279	f23624ca2f24cac732edb3729e752b9b	JCB 15 digit	44.8557748194120762	-123.023505183138695
26463	2020-05-23 13:28:03	2020-05-23	Lura Bauch MD	lura.bauch.md@geemail.com	Los Angeles	California	589344890546722	3617a86a983d17929fc4f4fa89a2c877	JCB 16 digit	33.9535775692999309	-118.398150036529813
26464	2020-05-23 13:56:37	2020-05-23	Mr. Collie O'Keefe	mr.collie.o'keefe@geemail.com	Santa Ana	California	3528745334527485836	d99974f88f557ac902dfc0aca6d7a470	Maestro	33.7581349306844203	-117.981093414586027
26465	2020-05-23 13:57:55	2020-05-23	Mr. Graydon Jacobson III	mr.graydon.jacobson.iii@geemail.com	Berkeley	California	4890626139490077	29a941a514a506de9b37ea68a7d44f3e	VISA 16 digit	37.8255403442775489	-122.28262525030614
26466	2020-05-23 13:58:06	2020-05-23	Thornton Rolfson PhD	thornton.rolfson.phd@geemail.com	Columbia	South Carolina	4643910019183147	7084ceb85fb37f010e1b160a24641d6a	JCB 16 digit	33.9766271962117372	-80.8674635301362628
26467	2020-05-23 14:00:40	2020-05-23	Kinsley Rutherford	kinsley.rutherford@woohoo.com	Philadelphia	Pennsylvania	6011840328161825509	364062ca4717f6e3c22a818ebba263b6	American Express	40.0221859911881381	-75.151688917995628
26468	2020-05-23 14:09:32	2020-05-23	Dr. Louis Kovacek	dr.louis.kovacek@woohoo.com	Alexandria	Virginia	4621442615871855	2e8f2adc2cc0dae75f7169d3685d5d78	JCB 16 digit	38.8394222104571725	-77.1101249739047176
26469	2020-05-23 14:16:05	2020-05-23	Nikia Adams	nikia.adams@geemail.com	Houston	Texas	4378677909830	c520b9380d3497644e3409d3962b9c7b	JCB 16 digit	29.7142025534141823	-95.4429792962983328
26470	2020-05-23 14:16:48	2020-05-23	Mr. Iver Harris	mr.iver.harris@woohoo.com	Chicago	Illinois	3096674290008400527	8122ae3272d24e0a4ae672c5c5dbb2d5	VISA 13 digit	41.7602646790280971	-87.6716981577716723
26471	2020-05-23 14:25:11	2020-05-23	Anjelica Smitham	anjelica.smitham@geemail.com	Charlotte	North Carolina	3158272525926753770	770fccc49cc478f817b35a9153f2cb0a	VISA 16 digit	35.2242380477741364	-80.8773811713270874
26472	2020-05-23 14:27:52	2020-05-23	Ina Doyle	ina.doyle@warmmail.com	Waco	Texas	6011602943694230825	150af4cb7f2edf138b17206c1503c4c3	Maestro	31.4692045424807816	-97.2208147898446811
26473	2020-05-23 14:38:23	2020-05-23	Ronan Armstrong-Romaguera	ronan.armstrong.romaguera@woohoo.com	Kansas City	Kansas	4714899357244	cb17113e38423836157ce73da828a339	Maestro	39.0655039534345292	-94.6821340713120918
26474	2020-05-23 14:45:27	2020-05-23	Mahalie D'Amore DDS	mahalie.d'amore.dds@geemail.com	Colorado Springs	Colorado	53896381139954599	98e879d2b58fabd7e732843e82b52016	JCB 15 digit	38.8812008151832984	-104.744218599811944
26475	2020-05-23 14:48:48	2020-05-23	Rowan Hodkiewicz	rowan.hodkiewicz@geemail.com	Jurupa Valley	California	3528745616304770673	0f811e06d04037abff570a9fe9bec72f	Voyager	33.9723684229351619	-117.389159595223518
26476	2020-05-23 14:54:23	2020-05-23	Lorine Armstrong	lorine.armstrong@warmmail.com	Washington	District of Columbia	869905984553245390	c8abaea618b1109a88b2ac2ed8404eec	VISA 16 digit	38.9290831686262067	-76.9295507349286254
26477	2020-05-23 14:55:27	2020-05-23	Francis Will-Lemke	francis.will.lemke@geemail.com	Los Angeles	California	869934784008924093	c3c2afa5d0d89d2697f001467cba8697	Discover	34.1081023048009726	-118.327655662455783
26478	2020-05-23 15:22:04	2020-05-23	Ferrell Tromp III	ferrell.tromp.iii@geemail.com	San Francisco	California	4882266381285	aa35b6bdf323795e2cbf6c1b252a84e3	Maestro	37.8046711742482557	-122.423009892132143
26479	2020-05-23 15:22:30	2020-05-23	Miesha Steuber	miesha.steuber@geemail.com	Greensboro	North Carolina	3796132822526204	f920336bb1d535e7333b2e170164fa44	JCB 15 digit	36.1386044965241098	-79.8562512642685363
26480	2020-05-23 15:25:18	2020-05-23	Dr. Geoffrey Breitenberg II	dr.geoffrey.breitenberg.ii@geemail.com	Berkeley	California	4906446386095194	686fdde3af6b4fd8d19f9d887ad9a5dd	VISA 13 digit	37.8453289556374202	-122.274175894673846
26481	2020-05-23 15:25:58	2020-05-23	Karley Mertz-Kshlerin	karley.mertz.kshlerin@geemail.com	Wichita	Kansas	3112073686738793965	24260efe25cb57ce125e9e64fd018b8b	JCB 16 digit	37.6673472077462819	-97.3076770593613389
26482	2020-05-23 15:28:31	2020-05-23	Tremayne Ledner	tremayne.ledner@geemail.com	Anaheim	California	51510273652327939	26e47c67e0c2366541c7c9d2d260e091	Mastercard	33.9110260942783199	-117.771280985299867
26483	2020-05-23 15:28:42	2020-05-23	Dr. Cary Towne	dr.cary.towne@geemail.com	Las Vegas	Nevada	180092384664153704	ed1c3d49920819e55f5b163fac16779a	JCB 16 digit	36.2692976952165367	-115.302917824566734
26484	2020-05-23 15:33:10	2020-05-23	Adelyn Homenick	adelyn.homenick@geemail.com	Austin	Texas	3528872574961617122	a50ccb96897b6bf4265e6aba25a921fb	VISA 16 digit	30.3098090876020478	-97.7699028691981056
26485	2020-05-23 15:44:46	2020-05-23	Edd Stroman	edd.stroman@warmmail.com	New York	New York	3158787353045202670	6ca5f2aebd5ece3cbdbcf1e3db70141e	VISA 16 digit	40.737540190223605	-74.0057359972398672
26486	2020-05-23 15:47:03	2020-05-23	Ally Christiansen	ally.christiansen@geemail.com	Pasadena	Texas	3158359871146950804	dd8c62afefb427d88e71729dcca50698	Mastercard	29.5748247485015554	-95.1013590302266181
26487	2020-05-23 15:48:47	2020-05-23	Krysta Hane	krysta.hane@geemail.com	San Francisco	California	3408885853686356	721010bc8376a5d01d3ce8d3e947e46a	VISA 16 digit	37.7840280580683228	-122.437961836808412
26488	2020-05-23 15:59:13	2020-05-23	Anastasia Ortiz	anastasia.ortiz@geemail.com	Dallas	Texas	589395625479373	89f7e9022c0877f38258ecee329f2dcf	Mastercard	32.7604361804008519	-96.6707199607007084
26489	2020-05-23 15:59:47	2020-05-23	Amin Kutch	amin.kutch@geemail.com	Berkeley	California	502039133707180	812c15a0b04a44b06435e1c1e053547e	VISA 16 digit	37.8986686366109424	-122.277369328246365
26490	2020-05-23 16:06:56	2020-05-23	Dr. Ramiro Tillman	dr.ramiro.tillman@geemail.com	Columbus	Ohio	180081559651199397	692e7818acef34cfc0fe96ea88e29c99	American Express	39.9803940436847469	-83.0684842800956318
26491	2020-05-23 16:15:19	2020-05-23	Olivine Turcotte	olivine.turcotte@geemail.com	Olathe	Kansas	6011936078793843967	bfb5bd31c0f437f6dae965ddbe00f305	VISA 16 digit	38.8106860279694246	-94.8964368669949465
26492	2020-05-23 16:26:15	2020-05-23	Tamela Dickinson	tamela.dickinson@geemail.com	Oklahoma City	Oklahoma	3703041537632920	292e4fdd4a2937e44729530f963bc7bc	Discover	35.4947309778448243	-97.5091821777064354
26493	2020-05-23 16:37:23	2020-05-23	Miss Ashlyn Monahan MD	miss.ashlyn.monahan.md@woohoo.com	Yonkers	New York	3726680225011906	e0ac3605e2ba023cd06573321a4c0e2f	JCB 16 digit	40.9841573401555408	-73.802749569283435
26494	2020-05-23 16:40:43	2020-05-23	Glenn Schulist DVM	glenn.schulist.dvm@geemail.com	Seattle	Washington	3528891141156341996	cd72a648de336d5ef046c0da932d8a83	Discover	47.6736649723649037	-122.365167878700049
26495	2020-05-23 16:42:42	2020-05-23	Kimberly Murray DVM	kimberly.murray.dvm@geemail.com	Portland	Oregon	3031689957453276	e62c80967509d4717dc4b48b4eee5554	Mastercard	45.6160123171638716	-122.582384118484342
26496	2020-05-23 16:44:48	2020-05-23	Demetra Bartoletti	demetra.bartoletti@woohoo.com	Phoenix	Arizona	4664786514532	158b14c2dbefbd486fc057b9cd070498	Mastercard	33.5305832242060475	-112.078571049815423
26497	2020-05-23 16:46:16	2020-05-23	Ernst Koepp II	ernst.koepp.ii@geemail.com	Sugar Land	Texas	676393122154169	3419aa4ac29af7cfe8d6da7e98edd175	Diners Club / Carte Blanche	29.5896872456703335	-95.6558092683561085
26498	2020-05-23 16:58:05	2020-05-23	Catalina Mueller	catalina.mueller@geemail.com	San Diego	California	869992131990151799	e6f28d7cc9a2215bcb13f893808faa17	VISA 16 digit	32.8311748661633587	-117.137807474182921
26499	2020-05-23 17:00:20	2020-05-23	Ceola Collins-Schinner	ceola.collins.schinner@warmmail.com	Omaha	Nebraska	503892882264937	a46ae8396acabe6e1b565204d6313425	Maestro	41.2334332836471518	-96.0074416983522525
26500	2020-05-23 17:03:22	2020-05-23	Miss Eboni Hoeger	miss.eboni.hoeger@warmmail.com	Winston–Salem	North Carolina	676387205738773	0cea60e6de2ab8d06a110e3b0671d57c	VISA 16 digit	36.047924769972262	-80.2959164167419033
26501	2020-05-23 17:09:38	2020-05-23	Ballard Wilkinson III	ballard.wilkinson.iii@geemail.com	Houston	Texas	3788071270380609	4044249883c9b25d2447355dc43dbd56	JCB 15 digit	29.7659626836966709	-95.2969665291268342
26502	2020-05-23 17:16:40	2020-05-23	Hilliard Sanford	hilliard.sanford@geemail.com	Los Angeles	California	53082341440701406	689e104c1355e779ff856581280b9b92	JCB 16 digit	33.9731828453816433	-118.326009803450845
26503	2020-05-23 17:19:07	2020-05-23	Genie Mosciski	genie.mosciski@warmmail.com	Hialeah	Florida	3096578539565717252	c62dea12bfd64c11beac28a93333d277	VISA 16 digit	25.8073377514235673	-80.2217433998729916
26504	2020-05-23 17:21:26	2020-05-23	Michal Effertz-Funk	michal.effertz.funk@geemail.com	New York	New York	3037862748517725	883dee2e40c259e9eb4c436914eb72f4	JCB 15 digit	40.724626269958911	-74.0045213641960089
26505	2020-05-23 17:23:17	2020-05-23	Council Tremblay DVM	council.tremblay.dvm@geemail.com	Indianapolis	Indiana	55501270736943831	114f24a85ea4ac601fdeca09699f9135	VISA 16 digit	39.796198639786617	-86.2273866348635352
26506	2020-05-23 17:25:21	2020-05-23	Isadora Gusikowski	isadora.gusikowski@woohoo.com	Cedar Rapids	Iowa	180010545161604006	12a286238597e5de417e6a8708c8f554	Diners Club / Carte Blanche	41.9625929735209766	-91.7196477330356856
26507	2020-05-23 17:39:58	2020-05-23	Audrianna Farrell	audrianna.farrell@geemail.com	Augusta	Georgia	4770194113180813	26047b91522981acea98e9eedebe5e54	JCB 15 digit	33.3525428679976557	-82.0473090100862095
26508	2020-05-23 17:43:07	2020-05-23	Kash Hodkiewicz	kash.hodkiewicz@warmmail.com	New York	New York	060489441936609	c473e16b73ab3c3032214b23f1c2843d	Discover	40.6010806313473722	-73.9990733673226089
26509	2020-05-23 17:51:55	2020-05-23	Briley Ratke	briley.ratke@warmmail.com	Fresno	California	4864085508401169	ebdad4fc9d6da2231549bac7a5244010	JCB 16 digit	36.7611294910185009	-119.716792741288998
26510	2020-05-23 18:08:37	2020-05-23	Mr. Sonny Prohaska IV	mr.sonny.prohaska.iv@woohoo.com	Cape Coral	Florida	4026712381372374	6125e25a96c3172b5896d5371b38eefd	VISA 13 digit	26.6084838723268362	-82.0103432573448856
26511	2020-05-23 18:14:29	2020-05-23	Mr. Walker Homenick I	mr.walker.homenick.i@woohoo.com	Modesto	California	3043586538523551	9e3fac253c4f1d3a399a9a66b95d4a8f	Voyager	37.6553029246162652	-121.021325373483819
26512	2020-05-23 18:16:19	2020-05-23	Miss Chandra Pollich DVM	miss.chandra.pollich.dvm@woohoo.com	San Antonio	Texas	676188248584711	3bc07a94ae6fe5fd26b7aaca6cd9ec2a	VISA 16 digit	29.3814088749770086	-98.551414422767607
26513	2020-05-23 18:20:24	2020-05-23	Sina Champlin	sina.champlin@geemail.com	Dallas	Texas	3112053062799848755	dca303c505c0a8c0daf16d368a723cc3	Mastercard	32.7376288260605222	-96.6734693565368559
26514	2020-05-23 18:36:48	2020-05-23	Garnet Bartoletti	garnet.bartoletti@geemail.com	Jersey City	New Jersey	210036410430712595	68cff854f351ccfd419161b518729855	VISA 13 digit	40.6613163226224472	-74.1279625383161118
26515	2020-05-23 18:46:10	2020-05-23	Cecilia Wilkinson DDS	cecilia.wilkinson.dds@woohoo.com	Round Rock	Texas	869941568776493741	2f728b3bc53faa602eb1a670c1a8c2eb	VISA 16 digit	30.4653325813028992	-97.5918248198311744
26516	2020-05-23 18:56:02	2020-05-23	Marceline Koepp	marceline.koepp@geemail.com	San Diego	California	869924423039413352	db3e329964ea2c3b8ad1ae7647027580	VISA 16 digit	32.7272541600346543	-117.137827329142027
26517	2020-05-23 18:56:40	2020-05-23	Osbaldo Welch-Rosenbaum	osbaldo.welch.rosenbaum@warmmail.com	Fresno	California	210039567283764630	9217cab1973a0144cb0edc0de1dc7a65	Maestro	36.8498988860625758	-119.778089660696324
26518	2020-05-23 19:01:07	2020-05-23	Nathanial Cremin	nathanial.cremin@geemail.com	Berkeley	California	3088580286530006991	b739e73026b7b034f40d6a997a933094	JCB 15 digit	37.8329032469539186	-122.259571967204323
26519	2020-05-23 19:14:21	2020-05-23	Evander Torphy	evander.torphy@geemail.com	Las Vegas	Nevada	6011461787950385645	11d1196ffde1b28f38092e4f91bf3dab	JCB 16 digit	36.1579401047069595	-115.276722443078086
26520	2020-05-23 19:16:26	2020-05-23	Brennen Turner II	brennen.turner.ii@warmmail.com	Houston	Texas	3042130679350259	6f8a1da59ed79d3e251eac02c0f52fad	JCB 16 digit	29.7167814139820621	-95.3270528083216391
26521	2020-05-23 19:18:29	2020-05-23	Dr. Collin Luettgen I	dr.collin.luettgen.i@warmmail.com	Birmingham	Alabama	501891346108185	71f1a08c93827b7959576bf6425affab	Mastercard	33.4385694855149822	-86.7871538397632634
26522	2020-05-23 19:18:36	2020-05-23	Brycen Kovacek	brycen.kovacek@geemail.com	San Antonio	Texas	4941897177890	13e7c36250201bce775a20fcd2dae048	VISA 13 digit	29.5230865059025582	-98.6084952858112729
26523	2020-05-23 19:20:59	2020-05-23	Darwyn Ernser-Johnston	darwyn.ernser.johnston@geemail.com	Phoenix	Arizona	3112886321779518280	e1476f000f324b9fbfcdc15539c954c7	JCB 15 digit	33.4821366768263289	-112.028036497898782
26524	2020-05-23 19:22:46	2020-05-23	Fran Wilkinson	fran.wilkinson@warmmail.com	Saint Paul	Minnesota	3046739307445582	b1291a9cc16ffa48c051bc6243d7f918	JCB 16 digit	45.0451171747349193	-93.0130066922199035
26525	2020-05-23 19:34:16	2020-05-23	Danica Bechtelar MD	danica.bechtelar.md@geemail.com	Seattle	Washington	3528724390170319768	a1aa0477126777fd8a2a892b6dc7af27	Discover	47.6943875683862686	-122.31035598906837
26526	2020-05-23 19:37:51	2020-05-23	Vernal Reichel	vernal.reichel@geemail.com	San Francisco	California	6011355983801803352	aaf7e15a0d7afe2dfd750d9ef0296a02	VISA 16 digit	37.7724176632092821	-122.451735218647769
26527	2020-05-23 19:48:00	2020-05-23	Levin Breitenberg	levin.breitenberg@woohoo.com	Los Angeles	California	869980899107106302	1b6958cbb0cf25550e76a32b7748cc72	Maestro	34.082273991671947	-118.500640736007313
26528	2020-05-23 20:00:52	2020-05-23	Makena Paucek	makena.paucek@woohoo.com	San Francisco	California	4762109523988902	d64687e6dd6d3d06d5173063b0bb860d	VISA 16 digit	37.784671093794195	-122.423993629174134
26529	2020-05-23 20:04:56	2020-05-23	Ms. Willodean Grant DDS	ms.willodean.grant.dds@geemail.com	Columbia	Missouri	210070537754445977	caf0970636c419667908dd20eff13b5e	VISA 16 digit	39.0342644960966538	-92.4234636092611623
26530	2020-05-23 20:11:27	2020-05-23	Ronny Dicki	ronny.dicki@geemail.com	San Antonio	Texas	180067446205838381	e06fef03c744a1052854bc869f17eb63	Voyager	29.4908171447064724	-98.5521035641267815
26531	2020-05-23 20:17:32	2020-05-23	Dr. Afton Lesch PhD	dr.afton.lesch.phd@geemail.com	San Bernardino	California	4406851090139540	3eef80c9b1e2fd6ec344e2e195e0ec1e	VISA 16 digit	34.0810950027577562	-117.342045692006494
26532	2020-05-23 20:32:54	2020-05-23	Mathews Bahringer	mathews.bahringer@geemail.com	Portland	Oregon	869958871567544882	b44bc3d732c609643c27c20ce9773cf4	JCB 16 digit	45.4991648691128958	-122.612649099156272
26533	2020-05-23 20:36:40	2020-05-23	Arabella Pfeffer-Feest	arabella.pfeffer.feest@geemail.com	Chicago	Illinois	060466013918355	5700d800bd63ffbbc1bc5d5bba27d98b	JCB 16 digit	41.7446402122102711	-87.7464470584906593
26534	2020-05-23 20:52:40	2020-05-23	Emerson Ferry	emerson.ferry@geemail.com	New York	New York	869918988799692450	2fa450b46b780a791f605f9ab6905233	VISA 13 digit	40.7443552670292561	-73.9877678952541231
26535	2020-05-23 20:53:36	2020-05-23	Esperanza Strosin DDS	esperanza.strosin.dds@geemail.com	Philadelphia	Pennsylvania	630445680086191	5d6fc950e7af344fff8ac2eeb42262d3	VISA 16 digit	39.9792801331222023	-75.1268386786703104
26536	2020-05-23 21:00:47	2020-05-23	Humphrey Adams	humphrey.adams@woohoo.com	Charlotte	North Carolina	869995810949322083	7542c372a34cb7d7de2214e5e3b2b543	JCB 16 digit	35.1999808009035888	-80.8636658766716749
26537	2020-05-23 21:01:51	2020-05-23	Lenora Reichel	lenora.reichel@warmmail.com	Newark	New Jersey	6011543218692052485	d3e10ffac3ac6ce7b81429cf7398e392	JCB 16 digit	40.7274023487612666	-74.1683561010029138
26538	2020-05-23 21:06:08	2020-05-23	Aloys Kunze	aloys.kunze@geemail.com	San Jose	California	3158373115710682365	378675a1044103acfe522f18cb0f05f2	Diners Club / Carte Blanche	37.2927813882295069	-121.71913342976346
26539	2020-05-23 21:07:33	2020-05-23	Kinte Moen	kinte.moen@woohoo.com	Columbus	Ohio	3782541440402919	b387eb7b87dd8a9efb178dfa3fe25649	VISA 13 digit	40.0485488257881244	-82.9849582485158095
26540	2020-05-23 21:09:00	2020-05-23	Yahir Witting	yahir.witting@geemail.com	Boston	Massachusetts	4500325360933135	adff914a4c1cde4f54be38c453e4f723	VISA 16 digit	42.2695785546377323	-71.0336645693469819
26541	2020-05-23 21:14:06	2020-05-23	Sydnie Mante	sydnie.mante@geemail.com	Fontana	California	3528778523350359478	6e302f027749bd5f51c040101b9b175f	VISA 16 digit	34.2015692970398817	-117.436577671607594
26542	2020-05-23 21:21:59	2020-05-23	Cheryl Corkery DDS	cheryl.corkery.dds@warmmail.com	San Francisco	California	210045166837876545	090a9145b8d526b76e600f74e09f658b	VISA 16 digit	37.772465617712605	-122.443315944452365
26543	2020-05-23 21:44:57	2020-05-23	Lester Ebert	lester.ebert@geemail.com	Norman	Oklahoma	180079147083725510	25bcd105db914e65f17d80c28fd68b33	JCB 16 digit	35.2685249968938521	-97.3970206680960899
26544	2020-05-23 21:50:05	2020-05-23	Ms. Maybell Lynch	ms.maybell.lynch@geemail.com	Washington	District of Columbia	639066739052026	e240b1a9c02e6b445c2e3cd24db6fabb	JCB 16 digit	38.835210526993869	-76.949162614646184
26545	2020-05-23 22:11:48	2020-05-23	Nikko Dickinson	nikko.dickinson@geemail.com	Austin	Texas	3731182395926560	6a12f06d17c3861a200771632daec4b4	VISA 13 digit	30.25933428021483	-97.8226132243178768
26546	2020-05-23 22:24:40	2020-05-23	Erving Glover Jr.	erving.glover.jr.@geemail.com	Torrance	California	4257926334119506	ac5487dba459b9177ddc17278d999798	Discover	33.7902336737047904	-118.425232009136664
26547	2020-05-23 22:28:17	2020-05-23	Merton Breitenberg-Lesch	merton.breitenberg.lesch@geemail.com	Atlanta	Georgia	3337217777874192935	68d1cbc36f262860221d25614ca2ba24	VISA 13 digit	33.8013738265536716	-84.3494094089184046
26548	2020-05-23 22:32:03	2020-05-23	Trinity Cummings	trinity.cummings@warmmail.com	Lubbock	Texas	3022061865543441	207d3ff98c541dc85f8733a52bcc3a34	VISA 13 digit	33.6356113320723225	-101.88327701314428
26549	2020-05-23 22:33:07	2020-05-23	Ricci Schimmel	ricci.schimmel@woohoo.com	Louisville	Kentucky	4435601336829130	0dc70933026d4cb367bcce7ae2e03a12	Mastercard	38.068298877765983	-85.6874860692840059
26550	2020-05-23 22:49:55	2020-05-23	Dr. Eligah Ullrich	dr.eligah.ullrich@woohoo.com	Cambridge	Massachusetts	501801178646020	4b4880df60dc1080bd6775ebc9f50b6f	JCB 16 digit	42.2872505534663787	-71.1778713843401505
26551	2020-05-23 22:58:03	2020-05-23	Serena Fahey	serena.fahey@geemail.com	Phoenix	Arizona	3088538960964679936	aba5bc37c645949807f42e12adb0514b	VISA 13 digit	33.5835074661232582	-112.166713737270243
26552	2020-05-23 22:59:11	2020-05-23	Margrett Fisher	margrett.fisher@geemail.com	San Jose	California	3158055093523839784	a50544c20b18a69ea27ad66eebdfd589	JCB 16 digit	37.3326764026943607	-121.726311339692771
26553	2020-05-23 23:21:55	2020-05-23	Raekwon Adams	raekwon.adams@geemail.com	Santa Clarita	California	4662200232922240	1b4e4ff8f0d2364d135af82c3f97df12	JCB 16 digit	34.4370242770034807	-118.593328967002037
26554	2020-05-23 23:22:27	2020-05-23	Alfred DuBuque	alfred.dubuque@warmmail.com	Anaheim	California	3112494287938410145	61216bdc22013984db0dbda0fff44b72	Mastercard	33.789317207906393	-117.778214535743359
26555	2020-05-23 23:27:57	2020-05-23	Perry Ortiz I	perry.ortiz.i@geemail.com	Lubbock	Texas	3096786044869731586	1361a9911367cd74926e6c4ce30ce405	Discover	33.5717448508407941	-101.92873389352188
26556	2020-05-23 23:37:34	2020-05-23	Vernia Murray	vernia.murray@geemail.com	New York	New York	210089129290111484	4d4a4f30282a98c907d7d743a4403bda	VISA 13 digit	40.7499214428234851	-73.8854125722672705
26557	2020-05-23 23:37:56	2020-05-23	Renita Champlin	renita.champlin@geemail.com	North Las Vegas	Nevada	180051390145733906	8e68d8cfd31dc2ec5976e3023244d9d7	Diners Club / Carte Blanche	36.2160687177132772	-115.052140263909109
26558	2020-05-24 00:05:47	2020-05-24	Leslie Robel-Witting	leslie.robel.witting@warmmail.com	Corpus Christi	Texas	3088955769656222143	205faa089a1ecebd06844220d3018703	American Express	27.703934736729785	-97.2055452196687497
26559	2020-05-24 00:21:24	2020-05-24	Dr. Lu Kunde	dr.lu.kunde@geemail.com	Portland	Oregon	3337324062286239685	07bf5e8c7d64483b072ed6486bc9b0be	VISA 13 digit	45.4633206570874862	-122.59730409779587
26560	2020-05-24 00:32:56	2020-05-24	Emilee Fisher	emilee.fisher@geemail.com	New York	New York	54940278816500081	f5318625294d9684df74ef0a59166b1b	Maestro	40.7030314832217996	-73.9835055249638884
26561	2020-05-24 00:32:58	2020-05-24	Dr. Lovell Schoen	dr.lovell.schoen@geemail.com	Sacramento	California	210009472004046605	6cf846dbeb6edd0abc887e51d96bca9a	Discover	38.6253292380165334	-121.386244355725495
26562	2020-05-24 00:33:39	2020-05-24	Dr. Cary Wolff I	dr.cary.wolff.i@woohoo.com	Port St. Lucie	Florida	4094690586881	920acc8e34165d1b43ed9f945cada54a	JCB 16 digit	27.3805870129395288	-80.3424600613389117
26563	2020-05-24 00:58:35	2020-05-24	Torrey Wilderman	torrey.wilderman@woohoo.com	San Francisco	California	3747139800942865	a5ea4dc9c6aa81eca15285e59a35f48e	Voyager	37.7759697253518922	-122.419527405907985
26564	2020-05-24 01:06:35	2020-05-24	Kaeden Connelly	kaeden.connelly@warmmail.com	Mesa	Arizona	3528265959445006072	03ae6f15f9c9fe84ad82f3b26be17d5f	Maestro	33.4768638338107607	-111.675166964239992
26565	2020-05-24 01:09:07	2020-05-24	Siena Schmidt	siena.schmidt@warmmail.com	Berkeley	California	4950676316583159	c032f1a463851228db188f41459e2001	Mastercard	37.8659833450026611	-122.271235731459441
26566	2020-05-24 01:11:27	2020-05-24	Mrs. Lorean Windler MD	mrs.lorean.windler.md@geemail.com	Chicago	Illinois	4478592573024	3d7d3c1a9c880f0bf1ee25e15675f44b	VISA 13 digit	41.913924060326444	-87.6154677924729839
26567	2020-05-24 01:21:38	2020-05-24	Dr. Raymond Kshlerin	dr.raymond.kshlerin@warmmail.com	San Francisco	California	4074493160787	d4be91d851f9ae8a0626fbb57d746ada	JCB 16 digit	37.7857561086215625	-122.480059326168885
26568	2020-05-24 01:23:42	2020-05-24	Dr. Purl Grady	dr.purl.grady@geemail.com	Oakland	California	3033282365299842	9050519b00d9ed32a2f731c2d55da937	American Express	37.7918191088655036	-122.290467722267508
26569	2020-05-24 01:24:27	2020-05-24	Dr. Delphia Labadie	dr.delphia.labadie@geemail.com	Charlotte	North Carolina	180035341973641795	1e9afda344208e7acd6d8ff5a7155439	JCB 15 digit	35.166057862273604	-80.7678499089498132
26570	2020-05-24 01:39:54	2020-05-24	Huey Waelchi	huey.waelchi@woohoo.com	Springfield	Massachusetts	4299006195194326	896556d2d843a1f959479a4424262992	VISA 13 digit	42.1929735458195196	-72.6128467278182512
26571	2020-05-24 01:45:58	2020-05-24	Lafayette Gaylord	lafayette.gaylord@geemail.com	Houston	Texas	3429951206949712	ef2ad579ed91895e2be821eb7456fe62	JCB 16 digit	29.7853777752336129	-95.4693343231003695
26572	2020-05-24 01:51:48	2020-05-24	Kristine Bartoletti	kristine.bartoletti@woohoo.com	Oakland	California	4479612898078	55a8b6b5b268603baa9fc9993882c7d0	JCB 15 digit	37.8311052308321862	-122.294377709029987
26573	2020-05-24 01:53:53	2020-05-24	Tory Ledner	tory.ledner@geemail.com	Baltimore	Maryland	51838145827754152	c9441f49574c09dcf2d963b3f74345fa	Diners Club / Carte Blanche	39.3718143921811077	-76.5337394398190156
26574	2020-05-24 02:08:50	2020-05-24	Miss Jazlyn Muller	miss.jazlyn.muller@geemail.com	Jersey City	New Jersey	180044558974327137	9703dc86c169bf7dbdc401d74e0f8772	Diners Club / Carte Blanche	40.7796579326909026	-73.9998208851508821
26575	2020-05-24 02:11:36	2020-05-24	Dr. Romello Mante Sr.	dr.romello.mante.sr.@geemail.com	Joliet	Illinois	4430893494090754	e34df47ea8c203e64d2b808324b62528	JCB 15 digit	41.6159918399851776	-88.0745775744888846
26576	2020-05-24 02:21:13	2020-05-24	Julisa Nienow	julisa.nienow@geemail.com	New York	New York	4222504567983	639b2c2979817dbc73b3ee298d594221	VISA 13 digit	40.7541000026501692	-73.8927481543168341
26577	2020-05-24 02:46:58	2020-05-24	Vivienne Parker	vivienne.parker@geemail.com	Houston	Texas	3337853688673581229	ea7e1b6aa647af94874c00d1a566da5b	VISA 16 digit	29.7276965427290634	-95.3989807463266004
26578	2020-05-24 02:50:16	2020-05-24	Emilee McCullough	emilee.mccullough@geemail.com	New York	New York	4176996127162763	2bf075a6be3b90591d424c6f7bf7ef48	Discover	40.6241914504896826	-73.8411052722845227
26579	2020-05-24 02:52:45	2020-05-24	Vincenza Sanford	vincenza.sanford@warmmail.com	Columbia	Missouri	53249084705775257	e616b8051c915519e1a0622f2b347ac4	Discover	38.8967968419541279	-92.2366941464652399
26580	2020-05-24 02:55:51	2020-05-24	Delaney Purdy DDS	delaney.purdy.dds@woohoo.com	Oakland	California	210054277113065865	3d2c7cb14c0faccff7ec83a6bfd961f2	Mastercard	37.8086644083768846	-122.24375545407193
26581	2020-05-24 03:09:39	2020-05-24	Jalen Daniel	jalen.daniel@warmmail.com	Seattle	Washington	3474958585229008	2e97181d210a792dbf6103b80316d035	JCB 16 digit	47.6051649447456029	-122.252092321907725
26582	2020-05-24 03:10:23	2020-05-24	Sean Schuster-Harvey	sean.schuster.harvey@geemail.com	New York	New York	4407383747418415	addd6870860223374a2065d00aef3a19	VISA 16 digit	40.7419967098385101	-73.9453107530146809
26583	2020-05-24 03:17:45	2020-05-24	Dr. Hosea Stehr	dr.hosea.stehr@woohoo.com	Oakland	California	4864040420050	e1cedd355586020598be54b4ff612aa5	Mastercard	37.8152012709946135	-122.325346034389867
26584	2020-05-24 03:39:50	2020-05-24	Marilla Goldner-Ondricka	marilla.goldner.ondricka@geemail.com	Reno	Nevada	869983203891812570	ef02c1d47dd91cfcbe27c4e933df5024	VISA 16 digit	39.4614784375376999	-119.785686981787535
26585	2020-05-24 03:47:56	2020-05-24	Dr. Shaquille Treutel MD	dr.shaquille.treutel.md@geemail.com	Indianapolis	Indiana	3015913249629998	dfe3876c2dd0a5a6a8ffa1e9b3d7c582	VISA 13 digit	39.8392065931584654	-86.1126832762468553
26586	2020-05-24 04:03:49	2020-05-24	Estella Nikolaus-Lind	estella.nikolaus.lind@geemail.com	New York	New York	501849303664509	0730cecf882e0e8ae017fada7981dc6f	JCB 15 digit	40.6660245359167476	-73.8610579998593693
26587	2020-05-24 04:06:30	2020-05-24	Landin Powlowski	landin.powlowski@geemail.com	Louisville	Kentucky	53796614131860302	64035304f2219b2164dd7d14ffcad631	VISA 16 digit	38.1272552511092258	-85.6907810684364364
26588	2020-05-24 04:08:04	2020-05-24	Versa Fay	versa.fay@warmmail.com	Visalia	California	3008647267330900	4fe23fad2b4cd4f005d573c660ede12a	Diners Club / Carte Blanche	36.3456323125354928	-119.263115796599166
26589	2020-05-24 04:09:54	2020-05-24	Kael Nitzsche	kael.nitzsche@geemail.com	Portland	Oregon	4485046278215154	9adc1b630608bb1b8ee18fe54573bbca	VISA 13 digit	45.4916454325318327	-122.550773463537922
26590	2020-05-24 04:23:04	2020-05-24	Mrs. Antionette McLaughlin	mrs.antionette.mclaughlin@geemail.com	Chicago	Illinois	869969430812627955	f2134291392c9d8b24f5083b910cbc4e	VISA 16 digit	41.8366083173383032	-87.7497375929757908
26591	2020-05-24 04:24:17	2020-05-24	Chauncey Nitzsche	chauncey.nitzsche@geemail.com	Surprise	Arizona	4423770068392551	44eeb98d418847c051b2e5445214a441	JCB 16 digit	33.6710186971113075	-112.398019323800497
26592	2020-05-24 04:25:02	2020-05-24	Mrs. Gabriella Cassin DDS	mrs.gabriella.cassin.dds@geemail.com	Philadelphia	Pennsylvania	3044023137226674	1559f65cc9e8610124cf3d92e0812961	VISA 16 digit	39.9667604621924468	-75.1206641362413876
26593	2020-05-24 04:34:05	2020-05-24	Myla Okuneva	myla.okuneva@geemail.com	Columbus	Ohio	869904640484872857	fcb3be991e08feabf7dc13dcdb3938e3	Maestro	40.0272580967795122	-83.0588800169296633
26594	2020-05-24 04:39:50	2020-05-24	Ethelene Ritchie DVM	ethelene.ritchie.dvm@geemail.com	Fort Worth	Texas	3112638203765920145	644c70bb84ee90616d0bc7cdbbdb022c	VISA 13 digit	32.8672016396708813	-97.4235618717789578
26595	2020-05-24 04:49:59	2020-05-24	Oakley Frami	oakley.frami@warmmail.com	Garden Grove	California	4252117746606968	f8f8988068fbea4566cec36492cfa9e0	Voyager	33.7359405397262364	-117.912650471881022
26596	2020-05-24 04:52:57	2020-05-24	Silvio Gorczany-Rath	silvio.gorczany.rath@geemail.com	Houston	Texas	4073636099498	53515d8bbd87ca5227fcf7b2daf0980d	VISA 16 digit	29.7978141105346381	-95.3582067250754761
26597	2020-05-24 04:58:26	2020-05-24	Dr. Asa Schaden DVM	dr.asa.schaden.dvm@geemail.com	New York	New York	3337223972156216476	3c56098c4a3cbbe1cf6a39fdca8be4e5	JCB 15 digit	40.6881792162768505	-73.8825367581460597
26598	2020-05-24 05:04:57	2020-05-24	Ailene Boehm	ailene.boehm@geemail.com	Richardson	Texas	3158829724144059577	c2aa2cd82fc63b6b93a974a4897d0c0f	VISA 16 digit	32.9763256550535502	-96.7096515500679601
26599	2020-05-24 05:09:48	2020-05-24	Octavio Conroy MD	octavio.conroy.md@geemail.com	Waco	Texas	4384992281211635	634d89085ba6bfa9262fe91b049ca8d7	American Express	31.5487213571764507	-97.2541342958938344
26600	2020-05-24 05:16:51	2020-05-24	Royce Hilpert	royce.hilpert@warmmail.com	San Francisco	California	561276254522618	96a5f9252aaf029f0b0160bbd76fc16c	VISA 16 digit	37.760936177555763	-122.433302481025805
26601	2020-05-24 05:22:17	2020-05-24	Alanzo Quitzon	alanzo.quitzon@geemail.com	San Diego	California	3473182207430958	ffbd0fb8357e78319443647e93658ce0	Diners Club / Carte Blanche	32.9072638323597602	-117.14453018674628
26602	2020-05-24 05:25:27	2020-05-24	Kamryn Hilll	kamryn.hilll@geemail.com	Port St. Lucie	Florida	6011992949401774714	0383e586f0386061b82ee364811622ca	Maestro	27.3707180168613782	-80.3292313832875351
26603	2020-05-24 05:27:25	2020-05-24	Mayme Kassulke	mayme.kassulke@warmmail.com	Berkeley	California	4741255342973	d98e59d3b8d78497c3a4f1077d1bcfda	VISA 16 digit	37.8893143132073504	-122.270669327995321
26604	2020-05-24 05:39:33	2020-05-24	Braedon Boyer-Smitham	braedon.boyer.smitham@woohoo.com	New York	New York	3022226681446547	f80919cbe55291d874c98e781157bf90	Discover	40.6033545077070599	-73.9228479661408784
26605	2020-05-24 05:41:44	2020-05-24	Lindsay Hettinger	lindsay.hettinger@geemail.com	Honolulu	Hawaii	4236025935628	7083ba4d9945888c54e7a5e9184b4c1c	Diners Club / Carte Blanche	21.2365495370451356	-157.770471860163298
26606	2020-05-24 05:44:44	2020-05-24	Beatrice Spencer	beatrice.spencer@geemail.com	New York	New York	676209205523625	a5bb2e06061cd073be078b48c4a303cd	Mastercard	40.5647502419296657	-73.8853478083282624
26607	2020-05-24 05:55:54	2020-05-24	Camilo Brakus	camilo.brakus@geemail.com	Winston–Salem	North Carolina	3427866961980391	a4e04ed3fe5233e29a1cb376a506ce36	Mastercard	36.1665425230048569	-80.2772472172174503
26608	2020-05-24 06:11:00	2020-05-24	Ebenezer Thiel	ebenezer.thiel@geemail.com	Chicago	Illinois	3415791691634130	4cd4c4c333af08f391ce40c0d9d05a37	Discover	41.914865879884367	-87.7508372540149821
26609	2020-05-24 06:33:32	2020-05-24	Derick Monahan Jr.	derick.monahan.jr.@geemail.com	Oklahoma City	Oklahoma	4097344795361977	af1482841572cea3bbc632bd8da95503	Voyager	35.5363297311965383	-97.4721169732872426
26610	2020-05-24 06:40:16	2020-05-24	Maxine Wuckert	maxine.wuckert@woohoo.com	North Charleston	South Carolina	4636058593364003	0e3380d5e44311659648db6443ea7707	American Express	32.9735802245952172	-80.0366140477918009
26611	2020-05-24 06:40:48	2020-05-24	Lonnie Lowe	lonnie.lowe@geemail.com	San Francisco	California	52174026898204800	23eb44431e66526bfdf13090c7119002	JCB 15 digit	37.7274920670577174	-122.447692879220824
26612	2020-05-24 06:43:32	2020-05-24	Armin Blick	armin.blick@geemail.com	Riverside	California	4137326494392660	88242084923c4c2cd08ef88568eb7554	Discover	33.9242974280327516	-117.48308390811718
26613	2020-05-24 06:44:00	2020-05-24	Isis Crona-Dibbert	isis.crona.dibbert@woohoo.com	Tulsa	Oklahoma	3158956092428251426	2217fa0eaa9d6750c8894e767ac3afb8	VISA 16 digit	36.0323893194455636	-95.956618029806009
26614	2020-05-24 07:00:06	2020-05-24	Shianne Osinski MD	shianne.osinski.md@woohoo.com	San Antonio	Texas	3088816304361691553	fc930aaf2333245eaf913b30cb4a6f2c	Diners Club / Carte Blanche	29.4798901919346292	-98.5898258241195151
26615	2020-05-24 07:02:45	2020-05-24	Laylah Tromp	laylah.tromp@geemail.com	North Las Vegas	Nevada	55688546818079239	c5d504efeddbd48a764353a8ce980e51	VISA 16 digit	36.2547412133466409	-115.128287913346298
26616	2020-05-24 07:04:19	2020-05-24	Francis Hills	francis.hills@geemail.com	Anaheim	California	52355494883437309	3194b3d90a48bffa3d39b14e9418c018	VISA 16 digit	33.7767293015327326	-117.826783816257858
26617	2020-05-24 07:20:23	2020-05-24	Dr. Tavares Larkin DVM	dr.tavares.larkin.dvm@geemail.com	Burbank	California	6011748686465799552	a4717c1ed5f4456a363405cd7b899aa3	American Express	34.1534547317236701	-118.345059499473876
26618	2020-05-24 07:24:20	2020-05-24	Monte Bernhard	monte.bernhard@geemail.com	San Francisco	California	4148943945389157	3cbcff0aa7da3889a1c65854da153d1a	Diners Club / Carte Blanche	37.8221303199313326	-122.391449216781041
26619	2020-05-24 07:41:37	2020-05-24	Dr. Charlene Prosacco	dr.charlene.prosacco@geemail.com	Santa Rosa	California	4539974445444	3896b908687433b7185f8fddff8f0796	JCB 15 digit	38.4681182414416227	-122.76229620187209
26620	2020-05-24 07:44:43	2020-05-24	Alphonsus Macejkovic	alphonsus.macejkovic@geemail.com	Baltimore	Maryland	3497926906888631	4453385ea04051160ab9b6b27824bb57	VISA 13 digit	39.327392288623372	-76.5220995357744442
26621	2020-05-24 07:45:15	2020-05-24	Jasen Cummerata III	jasen.cummerata.iii@geemail.com	Palm Bay	Florida	53025814100989073	c861a353c8d1a400b574adf853282042	Maestro	27.9077240421291464	-80.5782644734553912
26622	2020-05-24 07:50:39	2020-05-24	Dr. Yancy Kuhic	dr.yancy.kuhic@warmmail.com	Independence	Missouri	3112539627475221156	fd4913d0fbba829fae2923978e4fe966	Maestro	39.0685418575089471	-94.3986409472584711
26623	2020-05-24 08:05:22	2020-05-24	Ms. Ragna Lesch	ms.ragna.lesch@geemail.com	Los Angeles	California	3088005324963927669	8dd225167f2628d9d227bc03e7515911	Diners Club / Carte Blanche	34.0352636503852892	-118.470395353901381
26624	2020-05-24 08:13:09	2020-05-24	Kenia Parker	kenia.parker@geemail.com	Salinas	California	4915309731513098	b6f04f44527b83a6a6e5e0459b8c47ef	VISA 16 digit	36.6690225555326776	-121.629713305336239
26625	2020-05-24 08:16:46	2020-05-24	Benard Monahan	benard.monahan@woohoo.com	Chicago	Illinois	4635756750062465	392a6cd9b9a82916ed878fe2d759b20c	Diners Club / Carte Blanche	41.7801106399692586	-87.6007321396872385
26626	2020-05-24 08:26:33	2020-05-24	Arba Schimmel	arba.schimmel@geemail.com	Oakland	California	3528116244201374811	0b9329a7208a4ac50dde75a833e0c22e	VISA 16 digit	37.8258437248370996	-122.300433190970821
26627	2020-05-24 08:29:46	2020-05-24	Albertine Schmeler	albertine.schmeler@geemail.com	Huntington Beach	California	4617073494644	c7446717b0b0a22580124f07627f105e	Diners Club / Carte Blanche	33.614094288185612	-117.95446624258831
26628	2020-05-24 08:38:07	2020-05-24	Jerilynn O'Connell	jerilynn.o'connell@woohoo.com	San Francisco	California	180097909179280322	f936f55f5e57d25dc0bee419322a091d	Maestro	37.7455492109747865	-122.43003097309996
26629	2020-05-24 08:44:30	2020-05-24	Ebony Bins	ebony.bins@warmmail.com	New York	New York	4216583148616449	6b772d5961966c7c920d88531767066f	American Express	40.6518375850971765	-73.8970639256190509
26630	2020-05-24 08:53:50	2020-05-24	Bennett Kuhic	bennett.kuhic@warmmail.com	Roseville	California	4020057135988	64235ac508b26ec6e7c32541ca132087	JCB 16 digit	38.8130943555440737	-121.242353878145664
26631	2020-05-24 09:02:48	2020-05-24	Leva Wyman	leva.wyman@warmmail.com	Chicago	Illinois	180037600929924078	60ec62f59b59b553714eceb94fd3e5e3	VISA 13 digit	41.7605179532267172	-87.5962329101312918
26632	2020-05-24 09:04:53	2020-05-24	Ms. Kylah Dare PhD	ms.kylah.dare.phd@geemail.com	El Monte	California	4285398835815881	cf09863b10118a79d2860697b38e3c3c	VISA 16 digit	34.1513539469059495	-118.025524472751101
26633	2020-05-24 09:12:33	2020-05-24	Miss Zola McLaughlin	miss.zola.mclaughlin@woohoo.com	Cape Coral	Florida	3158068183399867848	d0dbf38a6cf764ebc01f24a6e9a2e4bc	Voyager	26.6265189222961673	-81.8974557005405472
26634	2020-05-24 09:13:07	2020-05-24	Mr. Lucky Hartmann	mr.lucky.hartmann@geemail.com	Coral Springs	Florida	3096490131807160494	5f867a4584ee99aee12b91aeb25a7906	VISA 13 digit	26.3184324326057002	-80.1662920275825996
26635	2020-05-24 09:29:15	2020-05-24	Moe Jacobs DDS	moe.jacobs.dds@geemail.com	San Francisco	California	3433667307040219	87a9c17ff8fdec718a4949ba09a79bf8	Voyager	37.7830247153852241	-122.409341568519991
26636	2020-05-24 10:04:36	2020-05-24	Curley Altenwerth	curley.altenwerth@geemail.com	Norwalk	California	54697626169562691	0fc19fcf58eb59a05a4775a3b76fc5c2	Discover	33.8437595008522294	-118.120428242491556
26637	2020-05-24 10:21:41	2020-05-24	Lenard Kub	lenard.kub@geemail.com	San Francisco	California	4611703121501803	41033b77fe2192221906c13db663d503	Diners Club / Carte Blanche	37.7603845048392941	-122.441256496292695
26638	2020-05-24 10:28:32	2020-05-24	Ivey Lind	ivey.lind@geemail.com	San Francisco	California	4997831439967491	24a995d819ca850d370c7dd12324107d	JCB 16 digit	37.7810654301047535	-122.43035821517951
26639	2020-05-24 10:35:15	2020-05-24	Romaine Quitzon	romaine.quitzon@warmmail.com	Long Beach	California	55873007937568359	2a7272172a1b439af5de0bf36555c975	VISA 16 digit	33.7134104569729374	-118.171866369635978
26640	2020-05-24 10:36:59	2020-05-24	Mr. Augustine Towne	mr.augustine.towne@warmmail.com	West Palm Beach	Florida	3096310047945951255	02dabf268d531b7ae8d69f4ad567c6f7	VISA 16 digit	26.839474327893555	-80.1978423768956219
26641	2020-05-24 10:39:56	2020-05-24	Heidy Douglas	heidy.douglas@geemail.com	Chula Vista	California	4763081762109	55160bcc94815caa33f8d1da914849f8	JCB 16 digit	32.6415362411409617	-117.082966128247591
26642	2020-05-24 10:59:50	2020-05-24	Arlie O'Keefe	arlie.o'keefe@geemail.com	Berkeley	California	4997169569243767	bb70e4daaa2b5f42b1a9b4f3f79821bf	VISA 13 digit	37.8864492870265792	-122.320614166881569
26643	2020-05-24 11:01:14	2020-05-24	Kathern Lakin	kathern.lakin@woohoo.com	Oklahoma City	Oklahoma	51388394943446103	a8d47d284c5a0dbfa9a88bcf6b82d18a	VISA 16 digit	35.5193658120840823	-97.6093334674730926
26644	2020-05-24 11:10:49	2020-05-24	Karsyn Block	karsyn.block@geemail.com	San Francisco	California	3158629344998520970	c527be2c32c89847f4128c5ab5fd405b	Mastercard	37.7620360765112864	-122.400022157216327
26645	2020-05-24 11:14:49	2020-05-24	Joelle Brakus	joelle.brakus@geemail.com	San Francisco	California	4321587429698549	5aaa74b0b7f4acb84517aa8e256cca68	JCB 16 digit	37.7868993178169603	-122.442495948396271
26646	2020-05-24 11:16:46	2020-05-24	Eudora Goodwin	eudora.goodwin@geemail.com	Hayward	California	6011368412281213275	c43a94a9cc527f9cb46d307cf34a435a	Voyager	37.5959390426043427	-122.116245242187389
26647	2020-05-24 11:19:27	2020-05-24	Laraine Walker	laraine.walker@geemail.com	San Francisco	California	4582831680696	524116da36a3b3b626ed3ad56cea0991	VISA 13 digit	37.7591464564386428	-122.420353631743055
26648	2020-05-24 11:24:57	2020-05-24	Dr. Soledad Parker MD	dr.soledad.parker.md@geemail.com	San Francisco	California	4081272436122771	94a65b948594f821c3dfa74e5c104eaf	Maestro	37.7950574555567655	-122.429570541752867
26649	2020-05-24 11:25:48	2020-05-24	Charle Harris	charle.harris@warmmail.com	New York	New York	630497139626002	f0a0e5a5be8bef978de202b7fdafe29a	JCB 16 digit	40.6507891327831885	-73.9265511133603752
26650	2020-05-24 11:32:59	2020-05-24	Tyreese Herzog	tyreese.herzog@geemail.com	Surprise	Arizona	869943271300363963	7f24086f78e78bb915b983cca9525d1f	Maestro	33.6621191263891788	-112.444699912681045
26651	2020-05-24 11:37:55	2020-05-24	Lawson Hackett	lawson.hackett@geemail.com	San Francisco	California	3009459234516309	b480878b364a91296636d7d0b54a265a	JCB 15 digit	37.7935205131523659	-122.405457452113055
26652	2020-05-24 11:40:51	2020-05-24	Dr. Nels Cronin	dr.nels.cronin@geemail.com	Davie	Florida	4774278307475	10602a7cba5174d8a77325a4d2a6d020	Maestro	26.1066010961573589	-80.1919151419680531
26653	2020-05-24 11:46:21	2020-05-24	Dontae Daniel	dontae.daniel@warmmail.com	New York	New York	4586321663319061	f1e8a4dd7ae8ab2042f78e642bf7e311	Diners Club / Carte Blanche	40.6296389207933117	-74.0114103285025777
26654	2020-05-24 11:48:47	2020-05-24	Quincy Fadel	quincy.fadel@geemail.com	Lakewood	New Jersey	4402098719523282	c9f854384d4f3b35bed8db625d3280b6	JCB 16 digit	40.1462224635113074	-74.1024876001566639
26655	2020-05-24 11:50:35	2020-05-24	Vincenza Dibbert	vincenza.dibbert@geemail.com	Indianapolis	Indiana	4159029395739228	1a2317c83273000abaab6967b5e80a8c	Discover	39.8324340951170726	-86.177807658837736
26656	2020-05-24 11:59:48	2020-05-24	Casey Rice	casey.rice@geemail.com	Nashville	Tennessee	869980064148046237	ef6a487c3a61d9a99b076a39c23feaaf	JCB 16 digit	36.2435427171301043	-86.8439471200480995
26657	2020-05-24 12:00:27	2020-05-24	Suzan Wunsch	suzan.wunsch@geemail.com	Chicago	Illinois	3096973970504461648	0eafedd77ae291fdc91171a21b4c8ce6	American Express	41.8399414403200183	-87.6269799273025143
26658	2020-05-24 12:12:21	2020-05-24	Shawnte McLaughlin-Schimmel	shawnte.mclaughlin.schimmel@warmmail.com	Scottsdale	Arizona	3337519694531494445	d897796a39ff67862171f464aa85953a	VISA 13 digit	33.7632439299609501	-111.889603205161535
26659	2020-05-24 12:13:48	2020-05-24	Watt Klein	watt.klein@geemail.com	Houston	Texas	4736240146051084	31d61009eaa6d76644f2c5d58168c179	JCB 16 digit	29.8449040273282691	-95.4035536019146519
26660	2020-05-24 12:16:33	2020-05-24	Avery Grimes	avery.grimes@woohoo.com	Tulsa	Oklahoma	4243954957757185	971906c1a37222e12e1539c9d0bea9e7	Voyager	36.1611075120881154	-95.9319680503524808
26661	2020-05-24 12:20:14	2020-05-24	Stacy Kutch	stacy.kutch@geemail.com	Cleveland	Ohio	6011811709143268790	4ae9917a7695acd11079fb890396412d	VISA 16 digit	41.4722231583520724	-81.5896161266841062
26662	2020-05-24 12:23:38	2020-05-24	Miss Birtie Rodriguez PhD	miss.birtie.rodriguez.phd@geemail.com	Davie	Florida	3011450847449085	6f4b48792ee66e3aa3588c2a5b1da1a8	VISA 13 digit	26.1469904901258658	-80.2531109028868315
26663	2020-05-24 12:30:04	2020-05-24	Dr. Rocco Schiller Sr.	dr.rocco.schiller.sr.@geemail.com	San Diego	California	869979972789565732	6bff910009a188e034917ab114102e41	American Express	32.8120377549037343	-117.195510492417966
26664	2020-05-24 12:31:58	2020-05-24	Irene Heathcote MD	irene.heathcote.md@geemail.com	Portland	Oregon	3096394128652556989	dd3ae10cc7021685fd480df948b1783d	VISA 13 digit	45.5370059893820454	-122.619227464217701
26665	2020-05-24 12:35:56	2020-05-24	Minnie Zieme	minnie.zieme@warmmail.com	San Francisco	California	3443919051787570	70ca8312e300d023d829df4c57428a96	Discover	37.7536022692669846	-122.455433098294804
26666	2020-05-24 12:42:12	2020-05-24	Ean Lubowitz	ean.lubowitz@woohoo.com	San Antonio	Texas	3158032410041065221	f49769159c4e431e3cb9b7fd770e5e23	JCB 15 digit	29.4988733503106992	-98.4937193431727565
26667	2020-05-24 12:50:35	2020-05-24	Rollo Quitzon	rollo.quitzon@geemail.com	Omaha	Nebraska	3057862186529877	67446592911c5a0fedc198475b943ac6	Diners Club / Carte Blanche	41.1690678456012193	-96.1061817243810736
26668	2020-05-24 13:03:31	2020-05-24	Nicholaus Bashirian	nicholaus.bashirian@geemail.com	New York	New York	4838934829717	04bcd08cfabca8d7c318a09b7ad27b07	VISA 13 digit	40.5943669604361048	-73.9466404325690121
26669	2020-05-24 13:17:39	2020-05-24	Dr. Hedwig Ryan MD	dr.hedwig.ryan.md@warmmail.com	Phoenix	Arizona	53252044869658933	f2a6e43532224ddb12e9a02dad5de6e5	American Express	33.5188142751742149	-112.017852630785114
26670	2020-05-24 13:25:46	2020-05-24	Ms. Roma Braun	ms.roma.braun@warmmail.com	San Francisco	California	6011367054660994488	01b240d7db47282efc203e6998b3fc3f	Maestro	37.7331476080145336	-122.446489258062272
26671	2020-05-24 13:43:11	2020-05-24	Karim McDermott	karim.mcdermott@geemail.com	Dallas	Texas	4620689678220	107ae532a0b94ff0959090805ebb886e	VISA 16 digit	32.7792382492024501	-96.6723687273878483
26672	2020-05-24 13:48:31	2020-05-24	Gaven Harber	gaven.harber@geemail.com	Fresno	California	3464645120717256	8e014ac104ee050a5343467b88691939	VISA 16 digit	36.8653662942688882	-119.726586594536528
26673	2020-05-24 13:51:28	2020-05-24	Dr. Rollie Boyle MD	dr.rollie.boyle.md@geemail.com	Corpus Christi	Texas	3706256571369331	0f5ce87374a0f78d3d82c16a3f7ab671	Discover	27.8477120712801813	-97.2704905642490871
26674	2020-05-24 13:53:00	2020-05-24	Angelica Lesch PhD	angelica.lesch.phd@geemail.com	Glendale	Arizona	060446336410975	096f48b9d6047a2e5574723570a51566	JCB 16 digit	33.456570060154796	-112.149436931104958
26675	2020-05-24 13:56:29	2020-05-24	Hanson Nicolas-Dickens	hanson.nicolas.dickens@geemail.com	Hialeah	Florida	3088783843934041894	c9ff6e83d172fecea59ee62b7e0a7e5b	VISA 16 digit	25.7738562074467552	-80.393696596556893
26676	2020-05-24 13:58:24	2020-05-24	Fabiola Prohaska DVM	fabiola.prohaska.dvm@geemail.com	Berkeley	California	52193939552511905	a37ce2bcbf874eef45a6996954440532	JCB 15 digit	37.8815959139148006	-122.273997924304254
26677	2020-05-24 14:05:43	2020-05-24	Sada Block	sada.block@geemail.com	Joliet	Illinois	4824975885293347	96e0afbfaaead62efd909bfeba67e74e	VISA 13 digit	41.4501192644562551	-88.2327175769127905
26678	2020-05-24 14:10:39	2020-05-24	Blaine Oberbrunner	blaine.oberbrunner@woohoo.com	Denton	Texas	3088406187095827924	6b02749868dc671405f8528d4406c026	VISA 16 digit	33.1640199353251575	-97.2380489779762911
26679	2020-05-24 14:19:51	2020-05-24	Aleah Heaney	aleah.heaney@geemail.com	Philadelphia	Pennsylvania	210001603206475535	c04576169cbc682457da2d1c9c710639	VISA 16 digit	40.0201533478643725	-75.1594997603345689
26680	2020-05-24 14:23:03	2020-05-24	Zeke Labadie	zeke.labadie@geemail.com	Gilbert	Arizona	6011599299973473171	286ba250d7deebbb68cc8584c1ef05ee	Voyager	33.2814156146600837	-111.749898151554532
26681	2020-05-24 14:31:40	2020-05-24	Toney Goyette	toney.goyette@warmmail.com	Concord	California	3528713131761523944	b31c2dd0e5d79d4ec5a575ffcadd6c2c	Maestro	38.0215313958868393	-121.982925033400207
26682	2020-05-24 14:33:54	2020-05-24	Hank Parisian	hank.parisian@geemail.com	Grand Prairie	Texas	180079437844170589	9cf31c53cb05b2cfd1ccca45ebbba8eb	Discover	32.5906156833801433	-97.0492130540650351
26683	2020-05-24 14:34:17	2020-05-24	Griffin Quigley	griffin.quigley@warmmail.com	San Francisco	California	3758336343277033	7f7efc41affb694183444f0e18bf4525	Diners Club / Carte Blanche	37.7531818565128816	-122.404653222627445
26684	2020-05-24 14:34:50	2020-05-24	Huldah Wilderman	huldah.wilderman@warmmail.com	San Francisco	California	180035907595739595	36b166fc6c579d78f7598aceccb13ab4	VISA 16 digit	37.7928953461162749	-122.407810923315637
26685	2020-05-24 14:38:47	2020-05-24	Mabel Homenick	mabel.homenick@geemail.com	Grand Rapids	Michigan	4103738227711	e5d402935d3c80324036d6180348cad2	VISA 16 digit	43.0573731131188566	-85.5924746518157491
26686	2020-05-24 14:49:40	2020-05-24	Maddux Pollich	maddux.pollich@geemail.com	Lafayette	Louisiana	4238598606021290	a134dedcb5f52a9d6962c55f39925efd	JCB 16 digit	30.1830509518716497	-91.9397859396729586
26687	2020-05-24 14:52:13	2020-05-24	Georgie Kerluke	georgie.kerluke@geemail.com	Los Angeles	California	51281065360526548	4ce512ae8c87298085231eaf1bf48387	JCB 16 digit	33.9991175603918734	-118.359033033716671
26688	2020-05-24 14:58:01	2020-05-24	Lucia Langworth	lucia.langworth@geemail.com	Honolulu	Hawaii	3112942823810247532	5c17463bff837005ea2e4f21c34314fa	JCB 16 digit	21.3216949622362861	-157.91416170100905
26689	2020-05-24 15:03:52	2020-05-24	Kailee Yundt	kailee.yundt@geemail.com	New Orleans	Louisiana	3337388844556791799	00f5aec2d0637c8437e68172a1d34fde	JCB 16 digit	30.1210707289181663	-89.9011311843786416
26690	2020-05-24 15:13:14	2020-05-24	Shonda McClure MD	shonda.mcclure.md@geemail.com	San Antonio	Texas	4445639398468387	fa89af5294b85b6cbc33954f00856d54	VISA 13 digit	29.4784050790198151	-98.4848980431746668
26691	2020-05-24 15:24:17	2020-05-24	Denine Murazik	denine.murazik@geemail.com	Oakland	California	3158797162148459816	db59a0591b948833d0ed949d0f309f77	JCB 15 digit	37.794546274636545	-122.253559804122276
26692	2020-05-24 15:59:50	2020-05-24	Lorayne Quitzon	lorayne.quitzon@geemail.com	Santa Clarita	California	3010428148568119	57e9b464152626cf0c0bf429fca9d23f	JCB 15 digit	34.4667872685678276	-118.447751971949629
26693	2020-05-24 16:09:47	2020-05-24	Dr. Zion Medhurst	dr.zion.medhurst@geemail.com	New York	New York	869931826695273095	635ca2ff153debd8de3df55d3a13aecc	JCB 16 digit	40.7250304731298201	-73.8854775610275567
26694	2020-05-24 16:15:55	2020-05-24	Ms. Odelia Greenholt	ms.odelia.greenholt@woohoo.com	San Francisco	California	869991531311508109	38ef57acbb94fdf77cac561651b68478	Voyager	37.7688904739797024	-122.430548151133848
26695	2020-05-24 16:24:05	2020-05-24	Napoleon Lindgren	napoleon.lindgren@geemail.com	Indianapolis	Indiana	869976810219296267	ff39af405901027131c07f12080bf31f	Maestro	39.7365251922056046	-86.1115374969519678
26696	2020-05-24 16:34:28	2020-05-24	Millie Reinger	millie.reinger@geemail.com	Tacoma	Washington	3472664469241083	c3bfd9393fdec08af856a85c48705812	JCB 16 digit	47.3289491644248415	-122.544191477843754
26697	2020-05-24 16:35:35	2020-05-24	Nereida Crona	nereida.crona@geemail.com	Houston	Texas	6011219542704884673	649a04ae4a6fe330cf39d40a263ed507	Discover	29.8727498489044621	-95.3935729779317967
26698	2020-05-24 16:46:08	2020-05-24	Nayeli Reynolds	nayeli.reynolds@geemail.com	Fontana	California	3443341088401168	7f67051d8df6cd759a326704a2d79f09	JCB 15 digit	34.021550385110082	-117.548020501555513
26699	2020-05-24 16:46:20	2020-05-24	Dedra Zulauf	dedra.zulauf@geemail.com	Everett	Washington	3158960017950771305	47d3e8f1dcb4bdf4a1be7a7063653f3e	Diners Club / Carte Blanche	48.0093623778674754	-122.107604315749924
26700	2020-05-24 16:51:06	2020-05-24	London Reichert PhD	london.reichert.phd@geemail.com	Port St. Lucie	Florida	4975416552779	86a5c8faca8a5a44d648d2116d6cf9c9	Maestro	27.3268284901179364	-80.3216960548974583
26701	2020-05-24 16:53:11	2020-05-24	Clemmie Gottlieb	clemmie.gottlieb@geemail.com	St. Petersburg	Florida	6011545580045663500	ed39a191a9667ed0ef5950d92dbc18f9	VISA 16 digit	27.8202608274184158	-82.6669118472732549
26702	2020-05-24 16:56:45	2020-05-24	Angelic Kessler	angelic.kessler@geemail.com	Columbus	Ohio	6011927360331505311	21dad434ee4e34960dcf6238c8d39619	American Express	40.0027789809785759	-83.0589775538306725
26703	2020-05-24 16:58:59	2020-05-24	Ephriam Labadie Jr.	ephriam.labadie.jr.@geemail.com	Los Angeles	California	3717686517757958	79e03dce17b52a03d4b342cd2e032167	Diners Club / Carte Blanche	34.0666601775545601	-118.506453056958691
26704	2020-05-24 17:02:01	2020-05-24	Maryjane Green	maryjane.green@warmmail.com	Charlotte	North Carolina	4142379611006153	eb83f685cf318d638e046a76a3c85a8c	VISA 16 digit	35.2225380989510555	-80.8505801333058685
26705	2020-05-24 17:03:15	2020-05-24	Mamie Cartwright	mamie.cartwright@geemail.com	Dallas	Texas	3088233355129578693	48ab6c276d688cba7f8f0647e0b40e7e	JCB 15 digit	32.7817337139781557	-96.7350970931779557
26706	2020-05-24 17:08:03	2020-05-24	Delos Schaefer	delos.schaefer@geemail.com	Meridian	Idaho	6011356007561612784	b86b6cf296698f6a85f1dd1a80c2dc2d	Discover	43.6802088033880977	-116.347903842798985
26707	2020-05-24 17:14:08	2020-05-24	Mettie Cruickshank-Dooley	mettie.cruickshank.dooley@geemail.com	West Covina	California	3337020603520572576	32096d7c1489d5b61e4cae34b182631a	Mastercard	34.1179212452486169	-117.95073795947954
26708	2020-05-24 17:14:52	2020-05-24	Dayse Gulgowski	dayse.gulgowski@woohoo.com	Anchorage	Alaska	4081184697003063	5c8cbef5a49c8cb398f77ef792a9ebd6	Voyager	61.0928520923230849	-149.254321956413975
26709	2020-05-24 17:15:26	2020-05-24	Eden Nader DVM	eden.nader.dvm@geemail.com	Huntsville	Alabama	3112800855780470570	2dbe79ee5a9e6028d7c45184567cbe84	JCB 15 digit	34.6146490773893873	-86.5770079588070587
26710	2020-05-24 17:21:27	2020-05-24	Mr. Roosevelt Kertzmann III	mr.roosevelt.kertzmann.iii@geemail.com	Chicago	Illinois	4908236655571	61dfd15afd6df7a12f299f394cadd206	Maestro	41.7989226516172323	-87.5987616540428178
26711	2020-05-24 17:33:59	2020-05-24	Siena Keeling	siena.keeling@woohoo.com	Honolulu	Hawaii	869919778913872578	96645a31b88f7bc83911cb9628eddf33	Diners Club / Carte Blanche	21.2883041869599374	-157.901654733039805
26712	2020-05-24 17:43:39	2020-05-24	Zaid Volkman IV	zaid.volkman.iv@geemail.com	Lexington	Kentucky	3528765156066541942	d5f06329701cfd728ad721c1ff03b208	Maestro	38.0990733917213973	-84.5576155404925345
26713	2020-05-24 17:46:02	2020-05-24	West Cole	west.cole@geemail.com	Mesa	Arizona	3096032234425228159	95e1cfe3464082b6d2a22ba1f56ea7cd	JCB 16 digit	33.3698079523775704	-111.712171593390025
26714	2020-05-24 17:51:14	2020-05-24	Dillard Corwin-Kerluke	dillard.corwin.kerluke@geemail.com	Fresno	California	3047615467419287	c0c3529b55370a9a0626c09f05be3d5d	VISA 16 digit	36.837405466322231	-119.76184498780556
26715	2020-05-24 17:52:53	2020-05-24	Dr. Lige Kuhic	dr.lige.kuhic@geemail.com	McKinney	Texas	54186338562788596	d21e0e34f0ffa030e6fa25927132928a	Voyager	33.2415820919107645	-96.6073309885636036
26716	2020-05-24 18:01:13	2020-05-24	Sloane Hills	sloane.hills@geemail.com	Minneapolis	Minnesota	4116320998978	f5639dbc425c9503e967ceac6ca97889	Maestro	44.9408127722881687	-93.3033981548428528
26717	2020-05-24 18:05:41	2020-05-24	Tomas Crooks	tomas.crooks@geemail.com	St. Louis	Missouri	4600254729167764	eb6da092cc8e84e4e529bcc1ae271f5f	VISA 16 digit	38.5799286024801447	-90.2412248352546271
26718	2020-05-24 18:06:24	2020-05-24	Dr. Brendon Kautzer	dr.brendon.kautzer@geemail.com	Berkeley	California	3051948389738153	87e127cc1d1238cc1b97cbfc2a0cccde	VISA 13 digit	37.9047049557015399	-122.263896827788187
26719	2020-05-24 18:14:26	2020-05-24	Roseanna Dare	roseanna.dare@geemail.com	Seattle	Washington	54560003896356199	17c2f34df76ef7a568fc01aacf0aeeba	JCB 15 digit	47.6682586163673534	-122.259895568566023
26720	2020-05-24 18:27:07	2020-05-24	Mylee Mayert-Armstrong	mylee.mayert.armstrong@woohoo.com	Pittsburgh	Pennsylvania	4393901210728949	1d74bb6952778a3abd5a09c8d4e08559	JCB 16 digit	40.4840648898810116	-79.9748866255100808
26721	2020-05-24 18:45:02	2020-05-24	Barron Borer-Kuphal	barron.borer.kuphal@warmmail.com	Clearwater	Florida	3096055704895538891	0b4c6412d19fa3613ee0cfcbfe651078	Voyager	27.9627273110799486	-82.7800328052867229
26722	2020-05-24 18:57:37	2020-05-24	Spurgeon Dibbert	spurgeon.dibbert@geemail.com	Fort Lauderdale	Florida	3046143617404142	7fc7c8aadbaa4ed59b8bd1a6ca41914c	JCB 16 digit	26.1821808379132328	-80.1496377860948428
26723	2020-05-24 19:03:17	2020-05-24	Danica Thiel	danica.thiel@geemail.com	Fort Worth	Texas	4159176934218	10e4ff06a2ec92f7049a4a8ed792d9b3	Mastercard	32.7967681420091566	-97.317237156704806
26724	2020-05-24 19:18:11	2020-05-24	Ewell Carroll-Friesen	ewell.carroll.friesen@geemail.com	San Francisco	California	6011568631926774312	469abba7cea561433883de9cfe6468cf	American Express	37.7806222752267331	-122.442656326348541
26725	2020-05-24 19:24:54	2020-05-24	Mrs. Glenda Yundt PhD	mrs.glenda.yundt.phd@geemail.com	Orlando	Florida	55636312657580685	593e22eca74f3eee74abc91194c14795	Discover	28.3657676864214245	-81.3181960678160181
26726	2020-05-24 19:27:47	2020-05-24	Carlo Terry	carlo.terry@geemail.com	Pueblo	Colorado	630416311930818	d9e240df5178b10a3413c198a948bfae	Voyager	38.1783463316481573	-104.639191845371585
26727	2020-05-24 19:38:16	2020-05-24	Miss Willene Quigley DDS	miss.willene.quigley.dds@woohoo.com	Oakland	California	3337932520272780354	b9cf8045a1bd046447638f9394ea32f1	VISA 13 digit	37.7954117328390353	-122.272942828243856
26728	2020-05-24 19:50:20	2020-05-24	Osie Pfeffer	osie.pfeffer@warmmail.com	Boston	Massachusetts	4905868334096340	b39150456ec46d3c3446706e87ac208d	Maestro	42.3802275579124696	-70.975856771594664
26729	2020-05-24 20:17:26	2020-05-24	Edmonia Pacocha	edmonia.pacocha@geemail.com	Ontario	California	4920484261641768	c94bfdf0d44967f3f52db4918bc10fda	VISA 16 digit	34.1094338620692525	-117.640546890358266
26730	2020-05-24 20:27:22	2020-05-24	Mr. Tyrus Ankunding	mr.tyrus.ankunding@geemail.com	Nashville	Tennessee	676143092533009	e732a12ce8ab1aa812d3cd1ba39ee33a	Diners Club / Carte Blanche	36.2615062718402541	-86.7142815423104878
26731	2020-05-24 20:31:03	2020-05-24	Dr. Lonie Heaney V	dr.lonie.heaney.v@geemail.com	New Orleans	Louisiana	675958388965525	c6f2c827cc9f6ee32f116114b725527c	American Express	30.0358307693634181	-89.9767926852013886
26732	2020-05-24 20:33:48	2020-05-24	Tiffani Cronin	tiffani.cronin@geemail.com	San Antonio	Texas	54795424911432335	2a0a775c461460386c46e0927d62fcaf	JCB 16 digit	29.4473682965222743	-98.61270721655562
26733	2020-05-24 21:04:28	2020-05-24	Valentina McKenzie	valentina.mckenzie@geemail.com	Las Cruces	New Mexico	3405944538435714	37cc41ad6882182c0c393ca09c4dc6e6	Mastercard	32.3946072369847471	-106.73475185522139
26734	2020-05-24 21:10:02	2020-05-24	Mr. Boston Marvin	mr.boston.marvin@warmmail.com	Newport News	Virginia	3031003968086960	f7210f9fb6a14fd4a73b0f27f6493427	Diners Club / Carte Blanche	37.077007038275525	-76.444965426649901
26735	2020-05-24 21:16:57	2020-05-24	Tyron Leannon	tyron.leannon@woohoo.com	Clovis	California	3088503023324625510	98d4f3200b963433c9915668095b198e	VISA 16 digit	36.884255114697666	-119.713528909448158
26736	2020-05-24 21:26:15	2020-05-24	Mr. Davonte Morar	mr.davonte.morar@geemail.com	Toledo	Ohio	51934499531377997	20058e9c73df99dd920206e09f372955	Diners Club / Carte Blanche	41.6808575559578784	-83.6192168538790241
26737	2020-05-24 21:33:04	2020-05-24	Olan Treutel	olan.treutel@geemail.com	Raleigh	North Carolina	4276159023983373	38a96fc470ad6e91e97e2bba577177bb	VISA 13 digit	35.8576058130845396	-78.7191147230502253
26738	2020-05-24 21:39:18	2020-05-24	Lena Mohr Sr.	lena.mohr.sr.@woohoo.com	New Orleans	Louisiana	4232685168343109	3722b57ee83e6170a56bf0960ff64ac4	JCB 16 digit	29.9868762386046335	-89.85419934431836
26739	2020-05-24 21:55:25	2020-05-24	Joanna Stoltenberg	joanna.stoltenberg@geemail.com	San Francisco	California	3528696878459295364	559201bac3254aeffab52c7c6b9cd6dc	JCB 16 digit	37.7853384802309193	-122.446867325366455
26740	2020-05-24 21:56:53	2020-05-24	Dianna Kunze	dianna.kunze@geemail.com	San Angelo	Texas	55026360765142474	8e3ac26b2181c8c4380bb94d8fd9d7c5	JCB 15 digit	31.4178656711861493	-100.370286452036353
26741	2020-05-24 22:16:38	2020-05-24	Raymond Effertz	raymond.effertz@geemail.com	New Orleans	Louisiana	180023157806471034	4cfc52b790cbd23a286a149ba7197fd4	VISA 16 digit	29.9833686617683632	-89.9482913831975281
26742	2020-05-24 22:26:26	2020-05-24	Deangelo Waters	deangelo.waters@geemail.com	Phoenix	Arizona	6011753173198410544	73d63cea6ea93788b852b47235b0ed96	JCB 16 digit	33.5201204135946966	-112.018779000446585
26743	2020-05-24 22:31:59	2020-05-24	Beckham Kreiger	beckham.kreiger@geemail.com	Atlanta	Georgia	4663452683195144	0eb96aee8614fab763bc6c763837526d	JCB 16 digit	33.8625983724646318	-84.493684409516689
26744	2020-05-24 22:40:23	2020-05-24	Glenwood Moen-Quitzon	glenwood.moen.quitzon@geemail.com	Fresno	California	3010001030912669	c30e15670609f9ac5c2615de5b22ee63	JCB 16 digit	36.8251954736992744	-119.726509859796252
26745	2020-05-24 22:51:11	2020-05-24	Shandra Kling	shandra.kling@woohoo.com	Fargo	North Dakota	53713146297500877	c2f366141a1d59c58d628f3ad1bb6567	Maestro	46.821877000224589	-96.8464962820950888
26746	2020-05-24 22:52:16	2020-05-24	Demetri Sauer	demetri.sauer@geemail.com	Oakland	California	4092422917218	de6d5cb8536affd8647d6daafea7c045	Maestro	37.8098122161019887	-122.289074150868387
26747	2020-05-24 23:06:28	2020-05-24	Prentice Anderson	prentice.anderson@geemail.com	Raleigh	North Carolina	52601394312100183	5e5b980623b77d1bcd91fa95993d4514	Diners Club / Carte Blanche	35.8844856610190064	-78.7158253404248569
26748	2020-05-24 23:08:40	2020-05-24	Arlen Marks-Sawayn	arlen.marks.sawayn@geemail.com	Corona	California	4060612193256970	6c08caace470ef4cc383fc19496f9b09	Diners Club / Carte Blanche	33.88827980327234	-117.630718239789829
26749	2020-05-24 23:16:36	2020-05-24	Miss Mell Pfeffer	miss.mell.pfeffer@geemail.com	Dallas	Texas	4338243417532891	5c83f3c9404a548db63ddb2e28949882	JCB 16 digit	32.8734050368696487	-96.6841509419921721
26750	2020-05-24 23:22:20	2020-05-24	Mr. Owens Lynch	mr.owens.lynch@woohoo.com	Seattle	Washington	4692094097926956	43efd79a95e8154ffd38afc50831c7b7	Mastercard	47.6903549793567478	-122.275242582840463
26751	2020-05-24 23:40:42	2020-05-24	Mohammad Howe	mohammad.howe@woohoo.com	Cary	North Carolina	4069196336307750	402cd385f2e036336090827952aa676c	JCB 15 digit	35.6854865186955834	-78.8741971011824887
26752	2020-05-25 00:02:43	2020-05-25	Daisye Hodkiewicz MD	daisye.hodkiewicz.md@geemail.com	Victorville	California	3006850021514502	378ad9c5110ad362609c25c8df61d332	JCB 16 digit	34.4777258906744422	-117.401780906614292
26753	2020-05-25 00:03:23	2020-05-25	Montana Buckridge	montana.buckridge@warmmail.com	Indianapolis	Indiana	3714533798600817	fbfb2a44708bed92b8fdd16fd8637ac1	Maestro	39.7589772786021243	-86.2110210993062651
26754	2020-05-25 00:08:05	2020-05-25	Tal Fahey	tal.fahey@geemail.com	Victorville	California	3048288104198620	7b250bee6dc7fa68fce7a82d9e5a9192	American Express	34.6251243029952107	-117.276147120880339
26755	2020-05-25 00:16:42	2020-05-25	Hayleigh Christiansen	hayleigh.christiansen@geemail.com	Berkeley	California	502039763299649	a8ff236d1be72c51a64728612a55235a	Maestro	37.9103241457554532	-122.262179812018175
26756	2020-05-25 00:20:28	2020-05-25	Calla Gottlieb	calla.gottlieb@warmmail.com	Los Angeles	California	4913900292461	eede1d0dc63a784200bf8d68438dbeba	American Express	34.0783654123410571	-118.418600805335856
26757	2020-05-25 00:25:50	2020-05-25	Primus Nader-Satterfield	primus.nader.satterfield@geemail.com	San Francisco	California	4916163481041142	0a0ff9747d3d45759e7c945552fa0fa9	JCB 15 digit	37.8082310909038242	-122.421709717769374
26758	2020-05-25 00:31:33	2020-05-25	Dorian Brown	dorian.brown@geemail.com	Austin	Texas	3055366800726218	75617b6b2578ec2dab8fa9345f2e3176	VISA 13 digit	30.3238702171143117	-97.8151090449426306
26759	2020-05-25 00:33:57	2020-05-25	Emerson Mante	emerson.mante@geemail.com	Broken Arrow	Oklahoma	6011749231503299825	40990b0689ba5e71beee4b67376fc835	VISA 16 digit	35.9418101870696987	-95.8772524366565051
26760	2020-05-25 00:38:48	2020-05-25	Ludwig Jaskolski	ludwig.jaskolski@woohoo.com	New York	New York	869977667138934595	1964936c2bf4d816c419dda15796f48f	JCB 15 digit	40.5947930949032312	-73.8876665250293883
26761	2020-05-25 00:54:31	2020-05-25	Rosetta Brekke	rosetta.brekke@geemail.com	Anchorage	Alaska	869996216772098460	8e399424a9294f995f6c0e48f5086ccc	American Express	61.1021852089773887	-149.341856816656133
26762	2020-05-25 00:55:14	2020-05-25	Omarion Altenwerth	omarion.altenwerth@warmmail.com	San Francisco	California	4913536035728855	92f6e61b75a519ed4278b93b89917186	VISA 13 digit	37.7617529058032275	-122.43016348374546
26763	2020-05-25 01:00:32	2020-05-25	Mrs. Latosha Mosciski	mrs.latosha.mosciski@woohoo.com	Philadelphia	Pennsylvania	6011282718399068416	96665bf03ccd8efa2185216750dd5b41	JCB 16 digit	40.0538195681251565	-75.1442332515392479
26764	2020-05-25 01:07:38	2020-05-25	Ramiro Collins	ramiro.collins@geemail.com	Berkeley	California	4849140287962277	b5bdec4df6d3ad388b61155abbb774f9	Maestro	37.8570408949581321	-122.263710894337166
26765	2020-05-25 01:15:18	2020-05-25	Dr. Armand Graham	dr.armand.graham@woohoo.com	Huntington Beach	California	3337916047194380634	833e061aa63b7c2a9227b5c251914517	VISA 13 digit	33.7273458208464092	-117.937343137583881
26766	2020-05-25 01:16:08	2020-05-25	Beatriz Pfeffer	beatriz.pfeffer@geemail.com	San Francisco	California	869971076139539732	88400c17e24b8cf2a6216d412e24d864	VISA 16 digit	37.7803377110585146	-122.421143883627309
26767	2020-05-25 01:19:46	2020-05-25	Leva Rau	leva.rau@geemail.com	Overland Park	Kansas	210015589263371648	e39b434bf6b7797e6b0b92f8926db8e4	JCB 15 digit	38.866482651965697	-94.7364810281008545
26768	2020-05-25 01:32:35	2020-05-25	Foch Brekke	foch.brekke@geemail.com	Louisville	Kentucky	4943252377404	95b9a64e616a903e1a2a2cc2df85fe2d	JCB 16 digit	38.1875800452563894	-85.6621187568247393
26769	2020-05-25 01:37:03	2020-05-25	Echo Dooley	echo.dooley@geemail.com	Lubbock	Texas	3737378933866102	cee4c257c996373ac28f4f76bda73038	Maestro	33.6429558230139349	-101.968911937429382
26770	2020-05-25 01:46:58	2020-05-25	Easton Schaden	easton.schaden@woohoo.com	New York	New York	180013116970685425	6a978675862fcd3deafbd690ca097125	JCB 16 digit	40.6842681454252428	-73.9352314682107448
26771	2020-05-25 01:47:41	2020-05-25	Miss Albina Farrell	miss.albina.farrell@woohoo.com	Evansville	Indiana	4050962372117341	7a646df884e03a4f9132026eab4879bd	Maestro	38.0503293682027603	-87.4506580179024553
26772	2020-05-25 01:53:07	2020-05-25	Elsa Bauch	elsa.bauch@geemail.com	Paterson	New Jersey	3479158809368790	4922cf0ea911304b7d7b0280a4ce7e33	Voyager	40.921760371462625	-74.2548618477277529
26773	2020-05-25 02:07:26	2020-05-25	Ms. Noemie Beahan PhD	ms.noemie.beahan.phd@geemail.com	Henderson	Nevada	4005124498642	90421bc84c576d420cbe999b4717cb7f	VISA 16 digit	36.0428552395597137	-115.066280239742994
26774	2020-05-25 02:08:38	2020-05-25	Adelle Kemmer	adelle.kemmer@geemail.com	Renton	Washington	3710996030771155	5da439ffacdd62ec8eb41c3ff3894f07	Voyager	47.450295183115081	-122.291098267639043
26775	2020-05-25 02:14:16	2020-05-25	Shirley Koch MD	shirley.koch.md@geemail.com	Fresno	California	4821705691458	0583804807d86bcd9c9977db5ce72ad0	American Express	36.7313409660350558	-119.762644591565802
26776	2020-05-25 02:22:26	2020-05-25	Fidel Wehner-Bauch	fidel.wehner.bauch@woohoo.com	New York	New York	3023869596998653	c6bd3667b833f89a9c7acd0509f638db	Voyager	40.6702416790407142	-74.0124280933186327
26777	2020-05-25 02:24:16	2020-05-25	Mrs. Elaina Satterfield PhD	mrs.elaina.satterfield.phd@woohoo.com	Wichita	Kansas	3112107225431115018	5f8cd50ea21b37739563ff9ca05d48d7	JCB 16 digit	37.7223575612407203	-97.4279625652559105
26778	2020-05-25 02:24:23	2020-05-25	Jamal Lemke	jamal.lemke@geemail.com	New York	New York	53815311628108173	6b25a871f81f2496e3cef4e60f81cb77	JCB 16 digit	40.6802128921020767	-74.0061242759589106
26779	2020-05-25 02:26:10	2020-05-25	Perri King	perri.king@woohoo.com	Cincinnati	Ohio	4444393484989358	da3a3e131f119acc712f6d4f9b43e854	VISA 16 digit	39.202990866754952	-84.4263215946771197
26780	2020-05-25 02:27:04	2020-05-25	Alejandro Hartmann	alejandro.hartmann@woohoo.com	Portland	Oregon	4202877625340788	c3c2b538593571a3ff569ccf11bf924c	Diners Club / Carte Blanche	45.6128816693909442	-122.656495318654933
26781	2020-05-25 02:41:07	2020-05-25	Afton Turner	afton.turner@geemail.com	Pompano Beach	Florida	210083387362345770	7a9c2a7a163d323c7b95f727e7ce847a	Mastercard	26.202463343114033	-80.0453984368439677
26782	2020-05-25 02:46:26	2020-05-25	Casen Weimann	casen.weimann@geemail.com	Tacoma	Washington	4155078406495506	687ecc6fd3365b3435736156709576e2	VISA 13 digit	47.3400418531268841	-122.503594376449655
26783	2020-05-25 02:52:03	2020-05-25	Micayla Grimes	micayla.grimes@warmmail.com	New York	New York	6011228818475820180	837ef5c0a50e22e3b6c696026e6973b2	VISA 16 digit	40.6066917558889813	-74.0090131409827592
26784	2020-05-25 02:56:12	2020-05-25	Dr. Cleveland Rippin I	dr.cleveland.rippin.i@geemail.com	Akron	Ohio	869934733276094345	1ba4b1a283f8b3b71a2d1bebc8d8172e	Discover	41.0485271612480318	-81.5631113507166532
26785	2020-05-25 02:59:02	2020-05-25	Milas Rice	milas.rice@warmmail.com	Seattle	Washington	3096266727981649954	828e5a6386232d8bf205bfbcf1f1649a	JCB 16 digit	47.5385169844999922	-122.276042505904655
26786	2020-05-25 03:06:58	2020-05-25	Dr. Elton Morissette PhD	dr.elton.morissette.phd@geemail.com	Anaheim	California	4531658610291737	bcb0d7f05bd3a050be73352dc128cf0a	VISA 16 digit	33.8933968059550992	-117.840297710078204
26787	2020-05-25 03:15:32	2020-05-25	Shawnte Labadie	shawnte.labadie@woohoo.com	Round Rock	Texas	4747312782205188	7c41d2ebe3377caa780d06b461cb3e0c	VISA 16 digit	30.5095717271462092	-97.6805443144254326
26788	2020-05-25 03:20:48	2020-05-25	Mr. Bishop Corwin III	mr.bishop.corwin.iii@geemail.com	Fort Lauderdale	Florida	4331667867492	80b3e076a169d86bad03899c2e193b17	VISA 16 digit	26.1250652482721968	-80.0748645170412914
26789	2020-05-25 03:27:32	2020-05-25	Dovie Schroeder	dovie.schroeder@geemail.com	Los Angeles	California	4981099919043583	6507dd36f155739d16fca0b3dd7810a0	JCB 16 digit	34.0257579735346098	-118.495088974478833
26790	2020-05-25 03:29:44	2020-05-25	Clella Kulas-Cummerata	clella.kulas.cummerata@warmmail.com	San Francisco	California	3456960946472758	3da078fc7e02d6a97647d893b9296d3c	JCB 16 digit	37.7975477164280633	-122.447312600941103
26791	2020-05-25 03:36:01	2020-05-25	Otis Mraz	otis.mraz@warmmail.com	Billings	Montana	676383345678839	f7683abe86894ebd7d83202d707850b5	Voyager	45.7431944960486163	-108.606283655965328
26792	2020-05-25 03:39:16	2020-05-25	Buna Olson	buna.olson@warmmail.com	Gresham	Oregon	869921107894238102	0a00e595d20e4ff5781e31b459f5a559	JCB 15 digit	45.456818895549695	-122.460404262392217
26793	2020-05-25 03:50:31	2020-05-25	Rex Kertzmann PhD	rex.kertzmann.phd@warmmail.com	Providence	Rhode Island	180075781380188115	e9609d62f8fbd5779bf957f744205db5	VISA 13 digit	41.856091298474368	-71.4944934017408684
26794	2020-05-25 03:54:13	2020-05-25	Alwina Dach	alwina.dach@warmmail.com	Tyler	Texas	869905406107596938	a3ba397f3b9f3ac847c2f2a43257215c	VISA 16 digit	32.2266362782150537	-95.4047902587909249
26795	2020-05-25 03:54:48	2020-05-25	Daisye Bogisich MD	daisye.bogisich.md@geemail.com	New York	New York	3088703368025282170	c3f52b136bc1fbd894ec529a6b3cf3d1	Voyager	40.5972789762299513	-73.9597983342491005
26796	2020-05-25 03:55:18	2020-05-25	Jeffery McClure	jeffery.mcclure@geemail.com	League City	Texas	3028966981997772	cac7b387a0238fd862068a6369b360e5	Discover	29.5619287844676535	-95.0198257617637552
26797	2020-05-25 03:59:34	2020-05-25	Cayden Marquardt	cayden.marquardt@geemail.com	Phoenix	Arizona	4512630152097577	6201e23db2ce8807c040dc1388a27bb0	Mastercard	33.5606144829586199	-111.994960801808546
26798	2020-05-25 04:03:17	2020-05-25	Manson Wyman	manson.wyman@geemail.com	San Francisco	California	4375512431289009	22d3a41f40615dc6a65249d37c965e2f	Voyager	37.7579789280074536	-122.415242276388426
26799	2020-05-25 04:07:01	2020-05-25	Sada Stark	sada.stark@geemail.com	New York	New York	4830500512926	4feaf767c583480f9e06429f7e99d4d2	JCB 15 digit	40.6183873911611713	-74.0228405422426761
26800	2020-05-25 04:09:17	2020-05-25	Myrta Kunze-Walter	myrta.kunze.walter@geemail.com	San Francisco	California	53555537360383400	f5560c752bd02cac5bab2e45eaae61dc	VISA 13 digit	37.751788378369838	-122.457140962053117
26801	2020-05-25 04:11:02	2020-05-25	Harland Balistreri Sr.	harland.balistreri.sr.@geemail.com	Amarillo	Texas	3096266914082570715	a10c64ed6d53b58f30237e8a1c85ac14	JCB 15 digit	35.1816747878842051	-101.764729798803856
26802	2020-05-25 04:24:13	2020-05-25	Mr. Juwan Hayes	mr.juwan.hayes@geemail.com	Chicago	Illinois	53025225501753911	bfa6ce08acc3d46596ff8caa8f624d9e	Maestro	41.8132470060907337	-87.6110602405883299
26803	2020-05-25 04:29:36	2020-05-25	Bama Bayer	bama.bayer@geemail.com	Boston	Massachusetts	869979701691038722	5101a9df7704d3c2bee14054784367aa	American Express	42.3945853738281855	-71.0419422903049735
26804	2020-05-25 04:34:28	2020-05-25	Lee Bernhard	lee.bernhard@geemail.com	Oakland	California	3112295742798379542	2d7ffe6b14082cf8777f919663e2caae	JCB 16 digit	37.8085252952159223	-122.255443432625327
26805	2020-05-25 04:44:37	2020-05-25	Adan Wilkinson	adan.wilkinson@geemail.com	Irving	Texas	180023918534110966	2a88b5c4e14703f5088a353147a54f24	American Express	32.7798258198842447	-96.9005500587914099
26806	2020-05-25 04:48:13	2020-05-25	Domonique Schmitt	domonique.schmitt@geemail.com	San Diego	California	4983157563902484	da5d55dd7902bcefe06423fe045b3afd	Maestro	32.7419296880319735	-117.158348300112422
26807	2020-05-25 04:52:43	2020-05-25	Mr. Raquan Hyatt DVM	mr.raquan.hyatt.dvm@geemail.com	Chicago	Illinois	180024126797021545	87051ad4631546b01c6ffdfc720ce65d	VISA 16 digit	41.7815151731785406	-87.7172251774027956
26808	2020-05-25 05:07:45	2020-05-25	Murry O'Keefe	murry.o'keefe@geemail.com	Sunnyvale	California	589363567009277	e8044d2cef09097baabf52d65d1e3d9a	Discover	37.310834304242583	-121.968646052872018
26809	2020-05-25 05:20:11	2020-05-25	Geoffrey Schuppe	geoffrey.schuppe@geemail.com	Meridian	Idaho	3457919139546520	52fae46990d8305bed04645d6b455ef0	Discover	43.5344980889938711	-116.476724734058223
26810	2020-05-25 05:27:39	2020-05-25	Grayson Monahan PhD	grayson.monahan.phd@geemail.com	Las Vegas	Nevada	869983242487351783	5184d169ad345ec1d4ef3b376bf78a2c	VISA 13 digit	36.2492961933005589	-115.181988327132899
26811	2020-05-25 05:28:25	2020-05-25	Ruby Haley	ruby.haley@woohoo.com	Lansing	Michigan	4252912700421	ee4c018efe0912c232fb7894bc4e427b	Diners Club / Carte Blanche	42.722822444497794	-84.6102956933092258
26812	2020-05-25 06:11:58	2020-05-25	Madelene Casper	madelene.casper@geemail.com	Cleveland	Ohio	3001112958531933	215a29bdd474a82e0ed81aae4a263896	Discover	41.5593387926314008	-81.6032014464266666
26813	2020-05-25 06:12:46	2020-05-25	Ryker Bednar	ryker.bednar@geemail.com	Chicago	Illinois	6011521094846623778	3010d19881943a65a82a23b64815210c	Discover	41.7697016025729511	-87.6484146282106593
26814	2020-05-25 06:14:55	2020-05-25	Miss Marleigh Torp	miss.marleigh.torp@warmmail.com	Oakland	California	52704248178372466	40572a2de153a59ff16a5e9142fdc4f2	Maestro	37.8296398412162986	-122.271187498995005
26815	2020-05-25 06:16:14	2020-05-25	Ewing Bosco	ewing.bosco@geemail.com	Houston	Texas	3337256809592547058	ee8c091df2b48b7503677565d861931a	VISA 16 digit	29.8814147571180015	-95.3194254044923923
26816	2020-05-25 06:17:11	2020-05-25	Alexandra Pacocha	alexandra.pacocha@geemail.com	Los Angeles	California	3112548923300465046	0d67982833f5f3fb043f6fb2cc9a69f1	Mastercard	34.0448275757353755	-118.388098136008892
26817	2020-05-25 06:27:14	2020-05-25	Kianna O'Hara-Steuber	kianna.o'hara.steuber@warmmail.com	Oakland	California	180052024946499461	1cc916523251b19ee706a032f13e4df3	JCB 16 digit	37.7887448074298504	-122.284088561631279
26818	2020-05-25 06:34:27	2020-05-25	Dr. Alline Barton	dr.alline.barton@geemail.com	Knoxville	Tennessee	6011910521010005241	b072a03045860896ce879b3010de3722	Mastercard	36.0684929442655289	-84.0022454245231955
26819	2020-05-25 06:36:47	2020-05-25	Elmina DuBuque	elmina.dubuque@geemail.com	Madison	Wisconsin	6011811312951411154	1c3b0b908f84c8141d899d18c8c64a6b	JCB 16 digit	43.0188086320620044	-89.4018338864553783
26820	2020-05-25 06:36:55	2020-05-25	Ms. Kathryn Rowe DVM	ms.kathryn.rowe.dvm@geemail.com	Orange	California	53681712186969677	8feac16f5f4df1b3f27355e5e7f7a569	JCB 16 digit	33.8580101505741453	-117.879045592584831
26821	2020-05-25 06:43:41	2020-05-25	Glinda Anderson	glinda.anderson@geemail.com	Berkeley	California	6011295819264549681	30bc3fd0f6b5f52c7aba8236fd2df78d	Maestro	37.8731777301680737	-122.298412610904151
26822	2020-05-25 06:51:16	2020-05-25	Essie Lindgren	essie.lindgren@geemail.com	Jacksonville	Florida	52511391573462194	6e24f684a0540527d0d5862fc56572c1	Voyager	30.3686563370335847	-81.7408861718218844
26823	2020-05-25 07:08:24	2020-05-25	Dr. Baxter Balistreri	dr.baxter.balistreri@geemail.com	Plano	Texas	52769285969931219	a0074d7d91406538128ccc5ce1fadf13	JCB 16 digit	33.0365829387299712	-96.7994880287159276
26824	2020-05-25 07:08:59	2020-05-25	Casie Pfeffer	casie.pfeffer@warmmail.com	Omaha	Nebraska	4979309569559307	031f1c1a98a3423bf9824057f8ba286f	Diners Club / Carte Blanche	41.2344132976286133	-95.9860883928950983
26825	2020-05-25 07:09:48	2020-05-25	Carnell Rowe	carnell.rowe@geemail.com	Chicago	Illinois	4183082908512	39fb140e860a760072b90ce9095695bf	Maestro	41.7939105180859585	-87.7080463491410001
26826	2020-05-25 07:17:19	2020-05-25	Mrs. Julianna Denesik DDS	mrs.julianna.denesik.dds@geemail.com	New Haven	Connecticut	4877362912730417	70f230e8c6664542012d082dde6f7526	Mastercard	41.2881902870714654	-72.9594092635437761
26827	2020-05-25 07:26:11	2020-05-25	Fleeta Vandervort-Fisher	fleeta.vandervort.fisher@geemail.com	Colorado Springs	Colorado	869988077574875566	afdb4fab8cc422d5d62f1364e436a78c	Maestro	38.8381946774248021	-104.759056491047886
26828	2020-05-25 07:31:42	2020-05-25	Demetra Lakin	demetra.lakin@geemail.com	Pasadena	Texas	4828774369581558	7e6ddfb8e9d0f70b0877b554e21c4549	Voyager	29.5784227320332072	-95.2217901131551656
26829	2020-05-25 07:32:12	2020-05-25	Giselle Quitzon	giselle.quitzon@geemail.com	Sunnyvale	California	4954297259804480	719f9bc5bc3f8d8f0314a6626f5d3e6f	VISA 16 digit	37.4242424545336547	-121.974329455775404
26830	2020-05-25 07:35:27	2020-05-25	Lyric Keeling	lyric.keeling@geemail.com	Worcester	Massachusetts	210085340513037687	3fad8972dc8fa0681707a00f4277ccb3	Diners Club / Carte Blanche	42.25862823596038	-71.7308977786239268
26831	2020-05-25 07:47:07	2020-05-25	Regan Homenick	regan.homenick@geemail.com	New York	New York	4652960417394059	82046deb4944a9ba54fcebf277098e3a	VISA 16 digit	40.6368502980321651	-74.0081340863265069
26832	2020-05-25 07:47:26	2020-05-25	Chelsi Kulas	chelsi.kulas@warmmail.com	Naperville	Illinois	4657271540225573	70cd80acf27aaec2f7697618cf23110b	JCB 15 digit	41.7390295717779551	-88.0961528850141917
26833	2020-05-25 08:06:05	2020-05-25	Senora Vandervort	senora.vandervort@geemail.com	Garland	Texas	4892327230785	67bb8f68084f12250d3bc0f3756c6387	VISA 16 digit	33.0015156835086643	-96.6093869657881612
26834	2020-05-25 08:08:45	2020-05-25	Jacque Schulist	jacque.schulist@woohoo.com	Chicago	Illinois	6011004847007180524	02dbd6a309aaf8ffe66558871b2a4f38	VISA 13 digit	41.7441769942011689	-87.6731609610404803
26835	2020-05-25 08:19:30	2020-05-25	Jovani Sauer	jovani.sauer@warmmail.com	Raleigh	North Carolina	4938486412806158	b01d2a1457a92ed2bb8cb3898e1d296f	Mastercard	35.7313357066497161	-78.7323584052205092
26836	2020-05-25 08:21:51	2020-05-25	Elmore Crona-Lindgren	elmore.crona.lindgren@geemail.com	Berkeley	California	869917085783282298	9e64c7ded74bea0a4f1b901d736c9c16	Mastercard	37.8800026477832148	-122.290982119851989
26837	2020-05-25 08:30:43	2020-05-25	June VonRueden PhD	june.vonrueden.phd@geemail.com	Anaheim	California	3777414407523043	8fb3ad03557832d605b507505f132cc7	JCB 16 digit	33.7656872797589713	-117.731529695747781
26838	2020-05-25 08:30:44	2020-05-25	Luvinia Larkin	luvinia.larkin@geemail.com	El Paso	Texas	54579975818572947	205ac7ef60403fb15fbf62eadee5d9a4	Voyager	31.8371648958247171	-106.479449163375435
26839	2020-05-25 08:47:41	2020-05-25	Benard Kessler	benard.kessler@warmmail.com	Oakland	California	210027357039846749	e8a8e6bbaef1ed556693ae600e138145	JCB 16 digit	37.7868040196011563	-122.268766677992701
26840	2020-05-25 09:04:14	2020-05-25	Lenon Fisher-Hermiston	lenon.fisher.hermiston@geemail.com	Carrollton	Texas	3718966020155455	65ffebb720d3a12f8d245730f53d2618	Mastercard	33.0511339916769415	-96.8149915954425921
26841	2020-05-25 09:10:53	2020-05-25	Zayne Cormier	zayne.cormier@geemail.com	Dallas	Texas	869966744725013084	23a4f30b1cbf039d1f809c788e44d9da	JCB 16 digit	32.7842584434702999	-96.8174041635319469
26842	2020-05-25 09:13:16	2020-05-25	Malia Davis	malia.davis@geemail.com	Tulsa	Oklahoma	3096121049029722189	91059781515fcf750a73f5ae34746b70	JCB 15 digit	36.2084483434349238	-95.9119223471220579
26843	2020-05-25 09:14:22	2020-05-25	Mr. Kevan Walker	mr.kevan.walker@woohoo.com	Centennial	Colorado	3008763379427474	b6771e3449964618ecbfd046e5e0156e	JCB 16 digit	39.6363772909663652	-104.831791489700237
26844	2020-05-25 09:37:38	2020-05-25	Cathie Rath	cathie.rath@geemail.com	Fullerton	California	3426746217094372	5fd2a73db0f30eb7d2ea350749496c92	VISA 13 digit	33.903611757528779	-117.872989356584839
26845	2020-05-25 09:41:06	2020-05-25	Flor Mertz	flor.mertz@geemail.com	Centennial	Colorado	3096247456817294744	ee5cec21f777830dff0f85cd128d1168	Discover	39.6042679054237894	-104.912176156452304
26846	2020-05-25 09:51:03	2020-05-25	Gaye Von PhD	gaye.von.phd@geemail.com	Berkeley	California	4601164179734287	50982e39b8552e35a988be4683dc5772	VISA 16 digit	37.8505429574482193	-122.292150560966562
26847	2020-05-25 10:01:38	2020-05-25	Lucina Runolfsdottir	lucina.runolfsdottir@geemail.com	Baltimore	Maryland	869985518866598013	ddaac4f7651cb82b04c398dbe3f001b1	JCB 16 digit	39.3114342788234339	-76.6087469760347233
26848	2020-05-25 10:02:22	2020-05-25	Dolly Feest-Walsh	dolly.feest.walsh@geemail.com	Atlanta	Georgia	3058314073696087	f70455b28aea9a984173af58b2468d40	Voyager	33.8464303436964755	-84.5217259600337627
26849	2020-05-25 10:04:09	2020-05-25	Winford Tremblay	winford.tremblay@geemail.com	Modesto	California	6011075844446240922	abc1562d63c0f5548fb1a89c2e5eb06e	Voyager	37.7357432995922863	-121.061337551355365
26850	2020-05-25 10:04:29	2020-05-25	Jeannette Wolf	jeannette.wolf@geemail.com	San Jose	California	4005321680202517	62fb17f7d6c31a08daf478cc86436114	VISA 13 digit	37.2560503207433982	-121.813476239585881
26851	2020-05-25 10:04:58	2020-05-25	Dr. Aden Grant V	dr.aden.grant.v@geemail.com	San Diego	California	6011233755878011855	bca140233c462a07d82c2f8cdd6dc1bb	Discover	32.8157766750615068	-117.092382692769178
26852	2020-05-25 10:12:51	2020-05-25	Scotty Wisoky	scotty.wisoky@warmmail.com	New York	New York	4292908301591831	6b23dc2320cc6e1cbf0444cc5626c0ba	JCB 16 digit	40.5980047223847365	-73.896815953439841
26853	2020-05-25 10:22:12	2020-05-25	Murphy Effertz	murphy.effertz@geemail.com	Lancaster	California	4807800547950	909abf538d40c0d5e619f432798c9529	American Express	34.7307666974853788	-118.077775717524062
26854	2020-05-25 10:35:53	2020-05-25	Alecia McLaughlin	alecia.mclaughlin@woohoo.com	Garden Grove	California	6011277895216876341	cafbf7408f5310635f90c680810a750a	JCB 15 digit	33.7263795562844706	-117.990215450247746
26855	2020-05-25 10:39:34	2020-05-25	Kristal Hodkiewicz-Schowalter	kristal.hodkiewicz.schowalter@geemail.com	Hollywood	Florida	4892266504734557	c8b879cd418452f4403c523f008771e8	Mastercard	26.0026564929578434	-80.2353620951812587
26856	2020-05-25 10:53:07	2020-05-25	Wilton Boehm	wilton.boehm@geemail.com	Phoenix	Arizona	54220879778424508	385c5b79b49ee56dd46069528d7a7e7a	JCB 16 digit	33.5009165094167045	-112.023172779560468
26857	2020-05-25 10:54:30	2020-05-25	Idamae Conn	idamae.conn@geemail.com	New York	New York	3112476425137516732	b1195248940076e372c3c5e276e12b0f	Discover	40.6192806303724652	-73.8522368700604801
26858	2020-05-25 10:55:12	2020-05-25	Douglas King	douglas.king@geemail.com	Boston	Massachusetts	3029696574211534	e32bab265e3e87bd2d14e4da36175f8c	VISA 16 digit	42.331139001267033	-71.0319203901521945
26859	2020-05-25 11:02:26	2020-05-25	Anson Powlowski II	anson.powlowski.ii@geemail.com	Cary	North Carolina	4219249181688847	941a244960fbc275734d620d473dca7a	VISA 16 digit	35.8401884246725615	-78.8918532062873226
26860	2020-05-25 11:10:47	2020-05-25	Otho Emmerich	otho.emmerich@geemail.com	Oakland	California	3337467998644873599	f706c5ceb434d1c24cd082e7edadab26	Maestro	37.8054945001123386	-122.28717523863952
26861	2020-05-25 11:11:33	2020-05-25	Twyla Kunde	twyla.kunde@geemail.com	Cambridge	Massachusetts	4142233613934	23426a10cb6466dc8a9e9dbf4983caa0	JCB 15 digit	42.2934762066453658	-71.1386953892733942
26862	2020-05-25 11:18:00	2020-05-25	Sandy Ritchie	sandy.ritchie@geemail.com	Meridian	Idaho	6011872626560666361	aedc30c5042339572b0f5e3c8906f532	Diners Club / Carte Blanche	43.6168864643208636	-116.40462556373663
26863	2020-05-25 11:21:19	2020-05-25	Mahlon Green	mahlon.green@geemail.com	Clarksville	Tennessee	676188655629660	a0b2ce9db3dae4b8831ad892aba2281d	Voyager	36.582935072634001	-87.3537679680574684
26864	2020-05-25 11:22:46	2020-05-25	Caswell Koch	caswell.koch@geemail.com	Louisville	Kentucky	52408540066624142	a36d48fbf05a0fdc2bb9c50818cbafe5	JCB 16 digit	38.1168561490155753	-85.5851116589341387
26865	2020-05-25 11:26:31	2020-05-25	Mrs. Arta Bradtke	mrs.arta.bradtke@geemail.com	San Antonio	Texas	3046397805665738	f89721f013e4ad36c6ca60316999143b	JCB 15 digit	29.4897143923748288	-98.5630269467666693
26866	2020-05-25 11:33:27	2020-05-25	Ms. Cara Hudson	ms.cara.hudson@geemail.com	Boston	Massachusetts	869990329810224786	d13652522c5ac465616c1514cfb94fb0	JCB 15 digit	42.3546305716671085	-71.0195594746105456
26867	2020-05-25 11:39:59	2020-05-25	Gwen Doyle DDS	gwen.doyle.dds@woohoo.com	Atlanta	Georgia	3096969296068321754	a72a8aa45d206950cf78c9876a1ab2d1	VISA 16 digit	33.8087709833677863	-84.3800657291941434
26868	2020-05-25 12:22:50	2020-05-25	Wilbert Johns	wilbert.johns@geemail.com	Santa Ana	California	3088114628103703899	1ed6a9793923bc1a0a3ab35f6d0d1e44	VISA 13 digit	33.8122257987607284	-117.953882923202585
26869	2020-05-25 12:46:02	2020-05-25	Abelardo Williamson III	abelardo.williamson.iii@woohoo.com	Plano	Texas	3018936457968565	6397808e678215087fb7273354e0a64a	VISA 13 digit	33.0435643640898178	-96.6673412244949475
26870	2020-05-25 13:03:57	2020-05-25	Pheobe Cassin	pheobe.cassin@geemail.com	New York	New York	3789873872925882	be6850d6be81b26f3fe8334c055f4ace	JCB 16 digit	40.6233849421832716	-73.9232616299658929
26871	2020-05-25 13:28:06	2020-05-25	Dr. Dennis Paucek	dr.dennis.paucek@geemail.com	Memphis	Tennessee	210051842604376833	6e33703b4b23617e402c116addebb82c	Mastercard	35.1125028034739231	-90.0733136213175953
26872	2020-05-25 13:34:19	2020-05-25	Mr. Powell Price II	mr.powell.price.ii@geemail.com	San Francisco	California	502054534876989	dfa8ec8f0f547cf7ac5cb3dcc47d9c3c	Diners Club / Carte Blanche	37.7833745893053674	-122.455995343400986
26873	2020-05-25 13:34:57	2020-05-25	Lesley Robel	lesley.robel@geemail.com	San Francisco	California	3337725196904357340	97c6c0cbec625a2311a0108cb8beb635	JCB 15 digit	37.7748829521017981	-122.439528367744032
26914	2020-05-25 18:21:28	2020-05-25	Dr. Vonnie Lang	dr.vonnie.lang@geemail.com	Rochester	Minnesota	4237345428871697	5e7afdf6b453576d82612c154b6e24bb	American Express	43.9683919911175991	-92.4890538628332308
26874	2020-05-25 13:56:49	2020-05-25	Gretta Becker-Batz	gretta.becker.batz@geemail.com	Greensboro	North Carolina	3158286037834659671	bd8b42b2350146cb45dd830e70803dce	VISA 16 digit	36.1750738205503666	-79.7662393638845515
26875	2020-05-25 13:57:05	2020-05-25	Dario Stracke	dario.stracke@warmmail.com	Columbus	Ohio	3709310652694740	c089d0d7feca94ca502da267064ebd5b	Diners Club / Carte Blanche	39.9475212992213642	-83.0735433207128295
26876	2020-05-25 14:03:12	2020-05-25	Dr. Shelby Volkman PhD	dr.shelby.volkman.phd@woohoo.com	San Francisco	California	3467576293689005	14d56a19dc4bc5508211a8e1fcbd6559	VISA 16 digit	37.7379660235641623	-122.44951799490515
26877	2020-05-25 14:06:06	2020-05-25	Ras Hagenes	ras.hagenes@geemail.com	Philadelphia	Pennsylvania	3528208792512721145	3d5e93f4e1a793a967e951f4d2a1b547	Mastercard	40.0839244179852301	-75.1464613826379235
26878	2020-05-25 14:18:04	2020-05-25	Odile Yost	odile.yost@geemail.com	San Francisco	California	4070272730614435	489ada8f71c01d42db6da2d4d7901740	JCB 15 digit	37.7513894235439551	-122.450895252368042
26879	2020-05-25 14:32:00	2020-05-25	Dakota Windler	dakota.windler@geemail.com	Phoenix	Arizona	6011356513287435525	aad9b8f90517c7b6c34ab7f6a7c8da92	VISA 13 digit	33.6674423630282291	-112.166536483347798
26880	2020-05-25 14:34:18	2020-05-25	Bernice Rutherford	bernice.rutherford@geemail.com	Charlotte	North Carolina	3096156903971501439	98aa8a91fa797cb6034b6dc48289d0a6	JCB 16 digit	35.1528139009859402	-80.8856493197791337
26881	2020-05-25 14:44:27	2020-05-25	Dr. Lorayne Effertz PhD	dr.lorayne.effertz.phd@geemail.com	El Paso	Texas	4436316885519441	64e133f60eac6201f2190a981b870eea	VISA 16 digit	31.9098458587951974	-106.491912959188227
26882	2020-05-25 14:54:39	2020-05-25	Dr. Kyree Fritsch	dr.kyree.fritsch@woohoo.com	Thousand Oaks	California	639020669196964	ee7bb1d35e0e97e7ee67daf47b39d250	JCB 16 digit	34.1637260247759542	-118.880186468400808
26883	2020-05-25 14:55:32	2020-05-25	Birdella Jacobi	birdella.jacobi@geemail.com	Charlotte	North Carolina	4151834311009293	2926b1ff9f97312ed366d79c4fc23ab7	JCB 16 digit	35.1274290015708672	-80.8575805124305163
26884	2020-05-25 15:02:07	2020-05-25	Mr. Conway Goyette	mr.conway.goyette@geemail.com	Chicago	Illinois	54108516674659285	9c5ba89bd5ef960947f5907bb6808df4	Mastercard	41.8357847453862419	-87.6599770639587206
26885	2020-05-25 15:07:38	2020-05-25	Jeannine Erdman-Parker	jeannine.erdman.parker@woohoo.com	Berkeley	California	4391818955860475	ca84fc83f69d98aafd2a8d9d2a097ab1	JCB 16 digit	37.9070073548398128	-122.351456414848968
26886	2020-05-25 15:16:53	2020-05-25	Dr. Arland Botsford I	dr.arland.botsford.i@geemail.com	Anchorage	Alaska	3034780602603980	76bff3fd2e4a186825b34d15c084d457	JCB 15 digit	61.1920430696785473	-149.232624117995812
26887	2020-05-25 15:18:10	2020-05-25	Mrs. Kaley Hettinger MD	mrs.kaley.hettinger.md@geemail.com	Corona	California	3112325155555919935	663b7caa001017479217481aa0d0a845	JCB 16 digit	33.9566940717287409	-117.488859097354108
26888	2020-05-25 15:23:54	2020-05-25	Halle Labadie MD	halle.labadie.md@geemail.com	Newport News	Virginia	869977791724759933	e02f2f649eee46e7001f28e31118e6ba	VISA 13 digit	37.001018906420839	-76.4547824092004475
26889	2020-05-25 15:25:59	2020-05-25	Callie Auer	callie.auer@woohoo.com	Killeen	Texas	4576827891832784	f9d45cd300978f22057a5c9065e46a43	American Express	31.0871015568960445	-97.828848699124535
26890	2020-05-25 15:26:11	2020-05-25	Presley Sawayn	presley.sawayn@geemail.com	Cleveland	Ohio	210073750035453176	882f66a3d41252badcbb85c23054b975	VISA 16 digit	41.4769611644875198	-81.7781142038531641
26891	2020-05-25 15:43:38	2020-05-25	Kyler Romaguera	kyler.romaguera@geemail.com	Berkeley	California	3032053251218522	6e43c4b01b0f1b273c788f4dedbf8cbe	JCB 15 digit	37.8559248769906844	-122.263131529950968
26892	2020-05-25 15:44:26	2020-05-25	Annie McClure MD	annie.mcclure.md@geemail.com	Hampton	Virginia	4521662345082686	679ed34ef9dc01d8209046fd8e62d254	Diners Club / Carte Blanche	37.0521722784284506	-76.2952174538843337
26893	2020-05-25 15:45:04	2020-05-25	Miss Reagan Kihn DVM	miss.reagan.kihn.dvm@geemail.com	South Bend	Indiana	561286793686295	624e9256a05c64efc3c84ec9b930a307	VISA 16 digit	41.6015702983509783	-86.3068505320754014
26894	2020-05-25 15:49:15	2020-05-25	Tyriq Boehm	tyriq.boehm@warmmail.com	San Jose	California	869914313247060602	ea369d4760bbb20e1254a2ccea1f7c5d	JCB 16 digit	37.376577533204852	-121.873689758659893
26895	2020-05-25 16:00:07	2020-05-25	Ms. Hedwig Cartwright PhD	ms.hedwig.cartwright.phd@geemail.com	Portland	Oregon	4560521391899	46c45da7f9f190562e52841162b4f382	JCB 16 digit	45.4910559281129352	-122.6292129286565
26896	2020-05-25 16:05:49	2020-05-25	Mrs. Kayleigh Pouros	mrs.kayleigh.pouros@geemail.com	Columbus	Ohio	502036149333977	644f5503fa4196d2cdc49b80d341ae1c	JCB 16 digit	39.9231945161752364	-83.0585609186209837
26897	2020-05-25 16:07:22	2020-05-25	Buck Konopelski-Smitham	buck.konopelski.smitham@geemail.com	Lewisville	Texas	4892759023591938	eb973bebe5ae5a23aee21c8ff0e5d558	JCB 15 digit	33.0504390025962138	-97.0522320813063573
26898	2020-05-25 16:18:25	2020-05-25	Mr. Bode Quitzon DDS	mr.bode.quitzon.dds@warmmail.com	New York	New York	210089822714720621	ee5d1965501f2ebc33be77264d0874c6	JCB 16 digit	40.6678028966523684	-73.8488668557617842
26899	2020-05-25 16:26:58	2020-05-25	Ignatz Stroman-Yost	ignatz.stroman.yost@geemail.com	San Antonio	Texas	869901007353003373	11eaefcac9009fdeceeb6baf8875d564	VISA 16 digit	29.5164630657598366	-98.4284257177099562
26900	2020-05-25 16:30:04	2020-05-25	Marina Durgan	marina.durgan@geemail.com	Chattanooga	Tennessee	3528066719025527900	8d3f0abf5ef3022b0bab3874242aedfa	Mastercard	35.0055387511234741	-85.1869990623384723
26901	2020-05-25 16:34:09	2020-05-25	Delilah Heller	delilah.heller@woohoo.com	Los Angeles	California	54446713983517103	a79b3afc8c0821993bff3f2c056a2c76	Diners Club / Carte Blanche	34.0388833258166912	-118.460995871572933
26902	2020-05-25 16:40:57	2020-05-25	Jerald Schowalter	jerald.schowalter@geemail.com	Fort Wayne	Indiana	3096263917192921143	67cfa6a477d78726fb60cd901b5b95bb	VISA 16 digit	41.0372086231380706	-85.1075377750430278
26903	2020-05-25 16:59:16	2020-05-25	Martina Littel	martina.littel@geemail.com	Rockford	Illinois	4829932255378559	03b8a1e218173c631ebc1527ea781913	Diners Club / Carte Blanche	42.250435998571291	-89.0537964441165286
26904	2020-05-25 17:12:40	2020-05-25	Ms. Regenia Reinger	ms.regenia.reinger@geemail.com	Philadelphia	Pennsylvania	3528753207689482222	56103bef5707472754e38da211aadcd6	VISA 13 digit	40.0696371513377869	-75.1315632058672662
26905	2020-05-25 17:28:21	2020-05-25	Lenore Klocko	lenore.klocko@geemail.com	McAllen	Texas	503806404818590	12fc123fe0c06a389c62341443a28d06	JCB 16 digit	26.2254344681583333	-98.1877372598588352
26906	2020-05-25 18:01:06	2020-05-25	Vinie Feil-Goodwin	vinie.feil.goodwin@geemail.com	San Antonio	Texas	3460890283356781	41e99be71779efdb3dcf826f0f6b8c98	American Express	29.452852864570545	-98.5445205944426306
26907	2020-05-25 18:01:40	2020-05-25	Danniel Hartmann	danniel.hartmann@geemail.com	Memphis	Tennessee	180061144909264220	2ba4ed01ef443702157246c5850f76a5	JCB 15 digit	35.0558632964801049	-89.9153309595562575
26908	2020-05-25 18:02:29	2020-05-25	Ms. Kaylan Gerlach	ms.kaylan.gerlach@geemail.com	Plano	Texas	3096983928061119213	c2fd8a44abd6b1c0146b94716db8d8cf	VISA 16 digit	33.0860468466851856	-96.6858581402055961
26909	2020-05-25 18:06:43	2020-05-25	Drusilla Carroll DVM	drusilla.carroll.dvm@woohoo.com	Austin	Texas	4661204358351	87f4f4454c38f5a99893203ad1b9a7f3	Mastercard	30.2060872156299638	-97.766608474520595
26910	2020-05-25 18:15:52	2020-05-25	Nathanael Donnelly	nathanael.donnelly@geemail.com	Little Rock	Arkansas	52465094851555376	acab31881937981af8338f693161a422	VISA 16 digit	34.7086125576678697	-92.4523695385888118
26911	2020-05-25 18:16:20	2020-05-25	Earnestine Hagenes	earnestine.hagenes@geemail.com	San Francisco	California	6011597808816475136	f33f38a00c8bc59a6fc64ec51e81b681	American Express	37.7787465796176676	-122.439739543450415
26912	2020-05-25 18:18:04	2020-05-25	Ambrose Harvey	ambrose.harvey@warmmail.com	Austin	Texas	180037901238908251	2472c0532e818bf8e41790a683f86e2d	Discover	30.3617048692084843	-97.8355572828795772
26913	2020-05-25 18:19:37	2020-05-25	Erna Schneider	erna.schneider@geemail.com	Richardson	Texas	3043771381030181	e0a789053ff714efc929be6e034f8a8d	Maestro	32.909356269776076	-96.7374651112820914
26915	2020-05-25 18:22:15	2020-05-25	Chris Veum-Ferry	chris.veum.ferry@geemail.com	Berkeley	California	3709493586262840	aa12bee3ba2ccb530fbc914330dcbe99	JCB 16 digit	37.8789116101388927	-122.274739374873604
26916	2020-05-25 18:40:29	2020-05-25	Malik Schneider	malik.schneider@geemail.com	Aurora	Colorado	6011837464658843401	1855aeb4258334a8adf2b1003f0c11c6	VISA 13 digit	39.765246972545981	-104.674772040837254
26917	2020-05-25 18:49:08	2020-05-25	Curley Hermiston-Huels	curley.hermiston.huels@warmmail.com	Pembroke Pines	Florida	4023822155343833	2be7a36c3b0b9362144153595ea8969e	VISA 13 digit	26.054105502836407	-80.4354855898205159
26918	2020-05-25 18:51:01	2020-05-25	Nile Wuckert	nile.wuckert@woohoo.com	Nashville	Tennessee	4393339769035	d8db2bdc379a50dedc3ef5017d92c468	VISA 16 digit	36.1196146637789894	-86.765442696809771
26919	2020-05-25 18:56:50	2020-05-25	Estefani Stroman	estefani.stroman@geemail.com	Charlotte	North Carolina	54331007247620250	a2e5886c749ba77e41de6d853b73e195	Diners Club / Carte Blanche	35.2129872200332557	-80.8479103362597584
26920	2020-05-25 19:06:43	2020-05-25	Adelina Hickle PhD	adelina.hickle.phd@woohoo.com	Columbus	Ohio	51258578065705547	17ddae5e022969d2032c4c75fab7f82c	Maestro	40.0056259730875468	-82.9478736563354744
26921	2020-05-25 19:13:30	2020-05-25	Reba Moen MD	reba.moen.md@warmmail.com	Westminster	Colorado	561242419033040	6b67be3ec48c0e219843c7c272bc7f1f	JCB 16 digit	39.8075416865132752	-105.03234287543745
26922	2020-05-25 19:20:14	2020-05-25	Bird Blanda	bird.blanda@geemail.com	Denver	Colorado	3088449797713243269	e9f678066e470a01c4d6c7ea114ffa76	American Express	39.730068395431708	-104.960923170648897
26923	2020-05-25 19:21:27	2020-05-25	Mr. Florentino Hayes	mr.florentino.hayes@geemail.com	Detroit	Michigan	4507238008712	db10e88f8caacfae9087841ddb523005	Mastercard	42.3076015436947372	-83.0830784206863484
26924	2020-05-25 19:32:41	2020-05-25	Dr. Vernell Anderson	dr.vernell.anderson@geemail.com	San Francisco	California	4502260206465992	7cb9a3384888e0129faa8c5b6f424e29	Voyager	37.7903824747318922	-122.430993593941125
26925	2020-05-25 19:55:06	2020-05-25	Jewell Ondricka-Jacobi	jewell.ondricka.jacobi@woohoo.com	Houston	Texas	4432837074107619	ece78527692f453e4cc8017c61c9c829	Mastercard	29.7329047574274234	-95.3326728938162375
26926	2020-05-25 19:59:35	2020-05-25	Sherilyn Langworth	sherilyn.langworth@woohoo.com	San Francisco	California	180058911174820182	83d54182f7677eb98cef21ba628fe893	American Express	37.7320155333918379	-122.400158294913041
26927	2020-05-25 20:09:42	2020-05-25	Thea Casper	thea.casper@geemail.com	Nashville	Tennessee	4842359388056824	f61a2c92189d17f1765a6b3b1848d042	VISA 16 digit	36.2353558279696841	-86.6998806808516349
26928	2020-05-25 20:14:00	2020-05-25	Dr. Felice Bergstrom	dr.felice.bergstrom@geemail.com	Naperville	Illinois	210034173905473760	4f79739d52e101586b78efa77d0aae4f	Discover	41.8079435915600541	-88.1865460900012437
26929	2020-05-25 20:14:58	2020-05-25	Brenna Schneider	brenna.schneider@geemail.com	El Paso	Texas	3041186103961336	360d8e993e6509e4778f1366a9ff3c00	JCB 16 digit	31.9466102296315135	-106.423319760056216
26930	2020-05-25 20:15:42	2020-05-25	Porsche Barrows	porsche.barrows@warmmail.com	Berkeley	California	6011004311640063530	432887fd73d8978b3c3805d82e06e649	Diners Club / Carte Blanche	37.8585430324104877	-122.299244044776884
26931	2020-05-25 20:19:12	2020-05-25	Pinkie D'Amore	pinkie.d'amore@woohoo.com	Berkeley	California	3112802896651576002	f70a3326366b529e31228b1fe0a2eeab	Diners Club / Carte Blanche	37.8450096952756994	-122.23952671710461
26932	2020-05-25 20:36:39	2020-05-25	Miss Karis Morissette MD	miss.karis.morissette.md@warmmail.com	Sacramento	California	54769651019733675	78058804202030e19006e5c5ff4bb4de	Maestro	38.6243207877300705	-121.488027025271577
26933	2020-05-25 20:39:18	2020-05-25	Carry Koelpin	carry.koelpin@woohoo.com	New York	New York	3049551783948279	7599160b47737807ac45454f2e3bc4a7	JCB 15 digit	40.7294619066398553	-73.9227761621482671
26934	2020-05-25 20:40:17	2020-05-25	Cecelia Schultz-Hirthe	cecelia.schultz.hirthe@geemail.com	Hayward	California	3112072595107458483	69a3150aca23ec1a45963652464079e6	Voyager	37.7020655633870518	-122.091006728985903
26935	2020-05-25 20:41:34	2020-05-25	Margarette Hegmann	margarette.hegmann@woohoo.com	Denver	Colorado	869957045811455549	4534ab35c3b84da8114300ee4721b693	VISA 16 digit	39.8264334478467674	-104.952174825944383
26936	2020-05-25 20:41:49	2020-05-25	Russell Wyman	russell.wyman@geemail.com	Carrollton	Texas	4957274069872	b04c0d9690f47e749a4a541143379e6c	VISA 16 digit	32.9870087659839513	-96.887884202725445
26937	2020-05-25 20:44:41	2020-05-25	Libby Sipes	libby.sipes@geemail.com	San Francisco	California	869998224509706148	825363a24b0276a5ca07d3bd6d7b6d55	JCB 15 digit	37.7728582965620348	-122.394124896092208
26938	2020-05-25 20:45:36	2020-05-25	Erle Barrows	erle.barrows@woohoo.com	Phoenix	Arizona	869961044959300231	8f633ef54495abee2bedd55944c68ed5	Discover	33.6393272088307924	-112.189495373556767
26939	2020-05-25 20:46:34	2020-05-25	Lambert Schmeler I	lambert.schmeler.i@warmmail.com	Columbus	Ohio	4215874089943707	b0eeb237451a54f00a96aeed551deb4a	VISA 16 digit	40.005897289705274	-82.9700699694223829
26940	2020-05-25 20:48:02	2020-05-25	Yulisa Walter-Huels	yulisa.walter.huels@geemail.com	Oakland	California	3096378743555725562	fd05a9fc259506e0deb521ff0de6592b	American Express	37.754152502322313	-122.287515415658405
26941	2020-05-25 20:52:59	2020-05-25	Roslyn Reilly	roslyn.reilly@geemail.com	Port St. Lucie	Florida	51160217201778871	0d31a1caffdf5a1794690242c62edfa0	Voyager	27.2079706545587641	-80.3069220354400528
26942	2020-05-25 21:01:59	2020-05-25	Silvia Beier	silvia.beier@geemail.com	New York	New York	6011057573754424636	55276d12e9b764c22f4d09ec0a2012b9	JCB 16 digit	40.7045704393871119	-73.8634302159201326
26943	2020-05-25 21:03:10	2020-05-25	Crissy Romaguera	crissy.romaguera@geemail.com	Syracuse	New York	51765597053592069	00651f91799a784771d5ac2e46c4d5cc	Voyager	43.0539743565339563	-76.212956358516962
26944	2020-05-25 21:09:18	2020-05-25	Jasper McCullough Jr.	jasper.mccullough.jr.@woohoo.com	Nashville	Tennessee	869984968968124591	07e2b89c3ccff78da01eb27afc4831e0	American Express	36.2054915292311463	-86.7087260894849834
26945	2020-05-25 21:10:05	2020-05-25	Dr. Haywood Krajcik Jr.	dr.haywood.krajcik.jr.@warmmail.com	Washington	District of Columbia	180031668752249539	4fcf7bd10901fd7b51c871525ee8c4f4	JCB 16 digit	38.857252447100727	-76.993156754479557
26946	2020-05-25 21:13:49	2020-05-25	Henri Rolfson	henri.rolfson@geemail.com	Sioux Falls	South Dakota	3422743023180721	2c7f77a9f4c51d0cff58a6616b639394	Diners Club / Carte Blanche	43.5671061285391445	-96.6704983973577612
26947	2020-05-25 21:15:18	2020-05-25	Ms. Marianne Rogahn PhD	ms.marianne.rogahn.phd@geemail.com	Shreveport	Louisiana	4986291270379558	d9a1bb9871e1cee2d3eed3e410654cf6	VISA 13 digit	32.4030171275377299	-93.8878496401224254
26948	2020-05-25 21:48:51	2020-05-25	Dr. Zeno Collins	dr.zeno.collins@geemail.com	Cambridge	Massachusetts	4185498830500628	1304cffb82a5bb7dba2a886ae91b3426	JCB 16 digit	42.4512634129952602	-71.1760302211705636
26949	2020-05-25 21:55:53	2020-05-25	Mr. Cason Shanahan MD	mr.cason.shanahan.md@warmmail.com	Hialeah	Florida	4298549708972	66c3426ca5cc0d7eef768133a09f4112	Diners Club / Carte Blanche	25.8437150848075774	-80.257480322559914
26950	2020-05-25 22:08:33	2020-05-25	Loretto Hamill	loretto.hamill@geemail.com	Greensboro	North Carolina	4314547261702949	7baeae0c483cd8f2a34d1a69330b536f	Discover	36.1875017601646505	-79.851859282001854
26951	2020-05-25 22:16:39	2020-05-25	Lindbergh Rath	lindbergh.rath@geemail.com	Saint Paul	Minnesota	6011858186496170986	cb5a353b0aeec914c4074641ab61316e	Voyager	45.0244337771959593	-93.1935431212451277
26952	2020-05-25 22:26:53	2020-05-25	Darryl Boyle	darryl.boyle@geemail.com	Austin	Texas	869977750011086095	7a0f8cdccd83aa125145cc2410c054df	VISA 16 digit	30.3663805380590262	-97.6872231399413238
26953	2020-05-25 22:30:41	2020-05-25	Luberta Reynolds-Casper	luberta.reynolds.casper@woohoo.com	Shreveport	Louisiana	3096476215171746349	00190f4c421e9d9aecc17d0193abcee4	VISA 16 digit	32.409271990904216	-93.8438392976045606
26954	2020-05-25 22:31:50	2020-05-25	Annamae Nolan MD	annamae.nolan.md@warmmail.com	Knoxville	Tennessee	869945715224040329	ed26352e17ef9bc7052121687ca16f89	VISA 13 digit	35.9213967758759836	-84.0093447531789508
26955	2020-05-25 22:39:57	2020-05-25	Shane Dach	shane.dach@geemail.com	San Francisco	California	210037794122716264	ebb5ffc28c2755faa4243e903237bf1b	VISA 13 digit	37.7657946365782351	-122.44381973605671
26956	2020-05-25 22:47:21	2020-05-25	Miss Eulalia Nicolas DDS	miss.eulalia.nicolas.dds@geemail.com	Philadelphia	Pennsylvania	3480439019726051	132ac99496fd02dab6b5a47f38428f88	Discover	40.0304765428841094	-75.18725425776951
26957	2020-05-25 22:48:47	2020-05-25	Lera Schinner DVM	lera.schinner.dvm@warmmail.com	Richmond	California	3096391357801607285	96e460693a81bec183b6cce1775e2a99	JCB 16 digit	37.9908731251910368	-122.427249217624222
26958	2020-05-25 22:58:11	2020-05-25	Dijon Graham I	dijon.graham.i@geemail.com	Phoenix	Arizona	55463899667539568	7b4450cf76038edc1727c2fb0e878428	VISA 16 digit	33.6424192478347592	-112.128200399682299
26959	2020-05-25 23:25:05	2020-05-25	Pam Reilly	pam.reilly@geemail.com	Charleston	South Carolina	3420987903485930	91b49f00cf36e91c19a26b90bf25379e	Voyager	32.8127689262848392	-79.9191903566624973
26960	2020-05-25 23:30:18	2020-05-25	Ashely Bailey-Cole	ashely.bailey.cole@geemail.com	Yonkers	New York	3029098816748953	b111a93e821c563fcb3fd340c612b5bb	Voyager	40.8862184977360101	-73.917412042885644
26961	2020-05-25 23:37:08	2020-05-25	Maximiliano Zulauf	maximiliano.zulauf@warmmail.com	Colorado Springs	Colorado	6011229504164362325	4460b64a7ba27a270e7768893a922257	Discover	38.8635642920669184	-104.703641596498713
26962	2020-05-25 23:40:36	2020-05-25	Mandi Ondricka	mandi.ondricka@geemail.com	Glendale	Arizona	3032960846802067	224ca446d05b818a095940e1645a5816	JCB 16 digit	33.4854617084138084	-112.150491308120635
26963	2020-05-25 23:52:09	2020-05-25	Anice Huel	anice.huel@geemail.com	Columbia	South Carolina	3420434020714850	04fcd3bcf40090eb9c3576174cd0a51e	Voyager	33.9399589184936161	-80.8637868393696806
26964	2020-05-26 00:06:18	2020-05-26	Mirtie Little	mirtie.little@geemail.com	Lakewood	New Jersey	869968271006177220	3aab9f92b1ce79b871cdf0aa7b247302	JCB 16 digit	39.9877783027760714	-74.2630030166167785
26965	2020-05-26 00:06:43	2020-05-26	Dr. Imanol Herzog II	dr.imanol.herzog.ii@geemail.com	New York	New York	3096548998837903388	5fcd9fab16498b9365dbd837c6fd6ef9	Mastercard	40.7071794290319104	-74.0207807407610119
26966	2020-05-26 00:18:43	2020-05-26	Mary Mayert MD	mary.mayert.md@geemail.com	Detroit	Michigan	869930745622198384	9253c1daf46476f3478f766f6a697038	Discover	42.2890642898548421	-83.1610451258838168
26967	2020-05-26 00:20:47	2020-05-26	Brooklynn Bauch	brooklynn.bauch@geemail.com	Oakland	California	3035787695595196	97798b48618be7c24a6a7b3bc742193a	Voyager	37.8198176922462608	-122.276102811986121
26968	2020-05-26 00:21:45	2020-05-26	Hattie Feeney	hattie.feeney@geemail.com	Indianapolis	Indiana	4531309420840152	d3e89559facecf46af97564d0cc02731	Diners Club / Carte Blanche	39.8537420595072192	-86.0965126847118114
26969	2020-05-26 00:29:06	2020-05-26	Saige Kuhlman-Beer	saige.kuhlman.beer@warmmail.com	New York	New York	503848538123059	68274186d32a7c128b44f217680c1bbf	Diners Club / Carte Blanche	40.7310020938739186	-73.9653596932895425
26970	2020-05-26 00:38:19	2020-05-26	Santo Pfannerstill-Roberts	santo.pfannerstill.roberts@geemail.com	Oakland	California	6011368582715176304	ac540f016afdbe9b4ae16a9227eedc85	Maestro	37.8020490002233061	-122.271762653022904
26971	2020-05-26 00:39:00	2020-05-26	Ferman Denesik DVM	ferman.denesik.dvm@geemail.com	Minneapolis	Minnesota	3337491720458025094	9fd84d66e83b54e4fde81bd9e298e90d	Maestro	44.991977317034447	-93.3463188153963443
26972	2020-05-26 00:41:48	2020-05-26	Dalia Gibson PhD	dalia.gibson.phd@geemail.com	Toledo	Ohio	3528288081409002154	edfd579a92da60a378febdb124bd51d9	Diners Club / Carte Blanche	41.6614238112404891	-83.6682268192857492
26973	2020-05-26 00:42:31	2020-05-26	Dillion Waters	dillion.waters@geemail.com	Evansville	Indiana	3046129463264466	1d66899d7179e042b21b9283e32cf9a9	JCB 16 digit	37.9157267999507468	-87.5852612119100939
26974	2020-05-26 00:49:49	2020-05-26	Jean Bayer-Lubowitz	jean.bayer.lubowitz@woohoo.com	San Francisco	California	6011416518764011739	84bf74b7e2d7e649e81a195d471eb5ac	American Express	37.7716609896987805	-122.408934167779549
26975	2020-05-26 00:56:44	2020-05-26	Ms. Elvia Denesik DDS	ms.elvia.denesik.dds@geemail.com	Murrieta	California	4290022154653532	66da82b97454b9691d363631596b9753	VISA 16 digit	33.6628625916879614	-117.129390386435759
26976	2020-05-26 00:57:00	2020-05-26	Jane Beier	jane.beier@geemail.com	Rialto	California	6011313439371654940	d25e2c6f90fff88829a34484e9673424	Voyager	34.1457268938172618	-117.403571788835521
26977	2020-05-26 01:14:31	2020-05-26	Crystal Brekke	crystal.brekke@geemail.com	Los Angeles	California	4256001721564820	135254fd11e3c5ebf1ed0cbf8cec7ead	VISA 16 digit	34.0384255166497027	-118.368570447060463
26978	2020-05-26 01:20:13	2020-05-26	Dwain Lemke	dwain.lemke@geemail.com	New York	New York	3740477811277583	688b5a966aedbc373227099d1b3178f0	VISA 16 digit	40.6310527609419054	-73.8623459378153058
26979	2020-05-26 01:30:05	2020-05-26	Samara Turcotte	samara.turcotte@geemail.com	Indianapolis	Indiana	4584945477797450	20d1c56cbd1fc79901fb620fb5041c9f	Diners Club / Carte Blanche	39.6880269404042494	-86.1522668129034344
26980	2020-05-26 01:30:21	2020-05-26	Kadence Wehner	kadence.wehner@geemail.com	Oklahoma City	Oklahoma	4437767731659691	0bda997ed0d31802640df4eac3369a5f	JCB 16 digit	35.524745754748956	-97.5461362108018193
26981	2020-05-26 01:45:28	2020-05-26	Moses Koepp	moses.koepp@geemail.com	Hialeah	Florida	52266230766932620	6beacf1082d32e9f64c76ecb06f7dff4	Voyager	25.9284511171258991	-80.381060102991384
26982	2020-05-26 01:47:22	2020-05-26	Sheryll Marquardt	sheryll.marquardt@geemail.com	Philadelphia	Pennsylvania	4502855590183	be8c9e775b92956a0e4360d5d61f19ce	JCB 15 digit	39.985022608885167	-75.0611202929999735
26983	2020-05-26 01:54:37	2020-05-26	Denis Corwin Sr.	denis.corwin.sr.@geemail.com	San Francisco	California	4519248934373	ab4feb40a1e779e777c7b63abb7d8217	Discover	37.7874731375462076	-122.43029753940219
26984	2020-05-26 01:58:07	2020-05-26	Gilda Harris	gilda.harris@woohoo.com	San Francisco	California	3112501965038570600	a699a25f365aef1e29f57c6dc31048e8	JCB 16 digit	37.7573492366963919	-122.415315968502
26985	2020-05-26 01:59:21	2020-05-26	Jonathan Waelchi	jonathan.waelchi@geemail.com	San Francisco	California	3088996642250665267	5bbdc0f9229d27367aa6a5e03f753413	VISA 16 digit	37.7406482506755978	-122.431533984047988
26986	2020-05-26 01:59:47	2020-05-26	Omari Ankunding	omari.ankunding@geemail.com	Berkeley	California	060480444012142	23d34f2e235ea2441ea5f6a5a42f1128	Mastercard	37.8424164360263688	-122.269325369006495
26987	2020-05-26 02:00:47	2020-05-26	Dr. Woodroe Schuster	dr.woodroe.schuster@geemail.com	New York	New York	4696497194717	e79d996e08cbd4ca8f1c2cda4f05907a	Diners Club / Carte Blanche	40.6711458635739973	-73.8754814357392462
26988	2020-05-26 02:04:35	2020-05-26	Cedric Trantow	cedric.trantow@geemail.com	Newark	New Jersey	6011574928723000293	467ef78d2477fbc5c60da7d3321a0d4b	VISA 16 digit	40.8191797786306623	-74.197232070260128
26989	2020-05-26 02:17:21	2020-05-26	Dr. Clotilde Ledner DVM	dr.clotilde.ledner.dvm@geemail.com	New York	New York	4757821297112975	892dff66855f7d149abb4c2031e412b6	Diners Club / Carte Blanche	40.7352933192849136	-74.0303545069310758
26990	2020-05-26 02:23:10	2020-05-26	Jame Eichmann	jame.eichmann@geemail.com	Boston	Massachusetts	3761179525981609	5ea2bbe5ca7444451b3a32a0d48101f1	American Express	42.3193281648848227	-71.095646164421737
26991	2020-05-26 02:24:15	2020-05-26	Garold Schuppe	garold.schuppe@geemail.com	Fremont	California	3765817775233942	e696d7be8a0e363216de2d5949215351	VISA 16 digit	37.5892939781937798	-121.900936082470039
26992	2020-05-26 02:32:46	2020-05-26	Nannie Welch	nannie.welch@geemail.com	Washington	District of Columbia	3096073621172409075	28fba83c102a42a85ebb7bf92252ba03	Maestro	38.8999395127672685	-76.9970851037863611
26993	2020-05-26 02:37:25	2020-05-26	Mrs. Marissa Gusikowski	mrs.marissa.gusikowski@geemail.com	Fort Wayne	Indiana	4615357453482060	1e72a5efda8facc917d17df5819f6678	Maestro	41.1802543318148722	-85.2175987777520021
26994	2020-05-26 02:40:08	2020-05-26	Marsh Brown	marsh.brown@warmmail.com	Beaumont	Texas	869976452369592730	757302c9f8a10185b90edd77b6842061	American Express	30.0241086436040696	-94.1909052409950647
26995	2020-05-26 02:44:51	2020-05-26	Terrie Olson	terrie.olson@warmmail.com	Clinton	Michigan	3088548760154105306	801c236dad428fb6813fe4e78d667459	Maestro	42.4916622269965671	-82.8565529759582091
26996	2020-05-26 02:48:59	2020-05-26	Zoa Gulgowski	zoa.gulgowski@geemail.com	Riverside	California	4612012210524	a24f0506a7a2a643b1ebfbbf2db55478	Maestro	33.9902118120290311	-117.323050974399592
26997	2020-05-26 02:54:16	2020-05-26	Tracey Leuschke-Koss	tracey.leuschke.koss@woohoo.com	Los Angeles	California	53235794253206655	e7354ed0f86f4ef2731954251781349d	Diners Club / Carte Blanche	34.0054476817470004	-118.422529662818832
26998	2020-05-26 02:54:42	2020-05-26	Dickie Beahan	dickie.beahan@warmmail.com	Charlotte	North Carolina	3499336881099030	1d373f608d1a2943124acd4b69a7525e	Diners Club / Carte Blanche	35.3049425548195828	-80.7562260335255502
26999	2020-05-26 02:58:02	2020-05-26	Danyelle Dare DDS	danyelle.dare.dds@geemail.com	Greensboro	North Carolina	4137733974636567	4e22a807cbf292e92325fd14af21bd67	American Express	36.0846745198242402	-79.8836807567141989
27000	2020-05-26 02:58:45	2020-05-26	Ms. Joella McLaughlin	ms.joella.mclaughlin@geemail.com	Augusta	Georgia	4456821332255	06ae8881fff63123c8fb1861763f72f4	VISA 16 digit	33.3309925989918412	-82.0460283862721269
27001	2020-05-26 03:00:57	2020-05-26	Juelz Tremblay DVM	juelz.tremblay.dvm@geemail.com	San Francisco	California	3462371515550531	38327d06272d0bb2fe7109060caa8cef	Diners Club / Carte Blanche	37.7860051366922534	-122.44203558305648
27002	2020-05-26 03:09:14	2020-05-26	Kelly Altenwerth-Littel	kelly.altenwerth.littel@geemail.com	Charlotte	North Carolina	4156665304341	0c6a6e3218d5fb29d770fd0ce4dc2c06	VISA 13 digit	35.2038022915620346	-80.923704821890226
27003	2020-05-26 03:20:30	2020-05-26	Daunte Gleason-Beahan	daunte.gleason.beahan@geemail.com	Reno	Nevada	4749589842880385	4f2fc3340c170da6d40d4217065deaa0	JCB 15 digit	39.5570236649442464	-119.884806062670052
27004	2020-05-26 03:29:14	2020-05-26	Vesta Fritsch	vesta.fritsch@geemail.com	Evansville	Indiana	3096604928016292916	bdd6714391d183ab992b2a6bb13959d9	JCB 15 digit	38.0693817964427126	-87.5738219711862484
27005	2020-05-26 03:34:57	2020-05-26	Hosea Blanda	hosea.blanda@geemail.com	Chicago	Illinois	6011767356518367262	e60a7851f9120005ef5824861f453d53	VISA 13 digit	41.9283602251973022	-87.7684591757163304
27006	2020-05-26 03:38:18	2020-05-26	Horton Bruen	horton.bruen@geemail.com	San Francisco	California	3088808114348246862	08951ae3cb682acd8d4821ba6dd879b8	American Express	37.7717918992532944	-122.443694590951793
27007	2020-05-26 03:39:50	2020-05-26	Adda O'Hara	adda.o'hara@warmmail.com	Long Beach	California	4450455141900291	8ac1ef6da37c755e3a4c1e36627ee9dd	American Express	33.8773362874805883	-118.141759933780136
27008	2020-05-26 03:50:47	2020-05-26	Tobias Okuneva	tobias.okuneva@geemail.com	College Station	Texas	3050126865607645	ec3e9432503dc39d2f55deffe22c7275	Mastercard	30.5371139408133914	-96.2268599560797213
27009	2020-05-26 03:51:21	2020-05-26	Abel Bogisich-Stiedemann	abel.bogisich.stiedemann@geemail.com	Manchester	New Hampshire	53713663889367820	db80d8a14c977d88a4a136f4ca20de00	JCB 15 digit	43.0401216551732304	-71.4739634423874435
27010	2020-05-26 04:09:15	2020-05-26	Miss Emma Reichel PhD	miss.emma.reichel.phd@geemail.com	Portland	Oregon	3050124217321072	44ebdfeddd49d600c74ce11ef7e9ac48	JCB 15 digit	45.5377219339255248	-122.666647591115918
27011	2020-05-26 04:12:16	2020-05-26	Cesar Ryan	cesar.ryan@woohoo.com	New York	New York	53701708900084260	06c431b184a3d675dce199ab7851b202	Maestro	40.7088972585964939	-73.9522575651656808
27012	2020-05-26 04:25:39	2020-05-26	Shasta O'Reilly-King	shasta.o'reilly.king@warmmail.com	New York	New York	53594005694410698	00d4cf4c03319adc10552bddae0b6881	Maestro	40.7474196051005251	-73.9366834127239798
27013	2020-05-26 04:30:52	2020-05-26	Fielding Abernathy	fielding.abernathy@geemail.com	McKinney	Texas	3770274446486017	837bcf89dd6fceae88417c5f4da1907d	JCB 15 digit	33.1100965543780532	-96.6496027831751974
27014	2020-05-26 04:33:15	2020-05-26	Stevan Rutherford-Padberg	stevan.rutherford.padberg@geemail.com	Los Angeles	California	55211073123002380	097e161dc4bea1b93cbad7a295b33164	JCB 16 digit	33.9754308943036918	-118.425507305189214
27015	2020-05-26 04:38:58	2020-05-26	Pearly Renner	pearly.renner@geemail.com	San Francisco	California	3729858165159664	bf008be8c4a8f9251a8f2cf65f0fd411	JCB 16 digit	37.7633039902138208	-122.438292021506854
27016	2020-05-26 04:42:39	2020-05-26	Atha Pagac PhD	atha.pagac.phd@geemail.com	Kenosha	Wisconsin	869901555596666604	ba4282d41b06a24780d7ad3e0865def0	Diners Club / Carte Blanche	42.5260545136246861	-87.896738580450787
27017	2020-05-26 04:45:16	2020-05-26	Shellie Tremblay	shellie.tremblay@geemail.com	New York	New York	3477549780021170	1b2536a2cf090a76221b706bd9a76373	VISA 16 digit	40.7285095094926675	-73.8803270039044264
27018	2020-05-26 04:46:31	2020-05-26	Miss Chloie Brakus DVM	miss.chloie.brakus.dvm@geemail.com	Oklahoma City	Oklahoma	3528876214031149030	b2d945bebe501fa07e2b1573736aa512	JCB 16 digit	35.5364093896843514	-97.4447853810049622
27019	2020-05-26 05:06:03	2020-05-26	Maren O'Conner	maren.o'conner@geemail.com	San Francisco	California	6011493848155642214	dad4325c16f8d706c04e38adaa65e70f	Mastercard	37.7759578918668737	-122.420087060115776
27020	2020-05-26 05:22:57	2020-05-26	Mintie Ferry DVM	mintie.ferry.dvm@geemail.com	Santa Ana	California	4612903606527815	38f0e3cf473b8ae81ce65df522c3af59	American Express	33.7248649765841648	-117.92805045004188
27021	2020-05-26 05:27:33	2020-05-26	Karel Reichert	karel.reichert@geemail.com	San Francisco	California	4117444527746341	5f7d7c2eb87e18e514f983c6cbe863a2	VISA 16 digit	37.7603789216600418	-122.474956499230629
27022	2020-05-26 05:34:08	2020-05-26	Dr. Sheldon Konopelski IV	dr.sheldon.konopelski.iv@woohoo.com	San Diego	California	3112357494076726060	cc5224acf4fbbd8403fa8887ad11a164	Voyager	32.8122925682991777	-117.099758710749455
27023	2020-05-26 05:36:25	2020-05-26	Dr. Mervin Kuhic III	dr.mervin.kuhic.iii@woohoo.com	Waterbury	Connecticut	4610230574203522	88c1051a5b45c00db1725a6e69095c37	VISA 13 digit	41.6243589123282618	-73.026675970564412
27024	2020-05-26 05:42:12	2020-05-26	Mario Abbott	mario.abbott@warmmail.com	Houston	Texas	4634145653586	ab0086c26e981af24e67cda697f7f5c9	JCB 15 digit	29.8585716218765818	-95.3429892756525419
27025	2020-05-26 05:56:14	2020-05-26	Jewell Botsford	jewell.botsford@geemail.com	Tyler	Texas	3033374800155703	35da456d7ae6a671422350ac226c1d29	Discover	32.2690444781027779	-95.3529935808494571
27026	2020-05-26 05:57:02	2020-05-26	Augustus Schinner	augustus.schinner@woohoo.com	Arlington	Texas	3443265580016556	5b6536b5854f8b47b19adda416563eac	VISA 13 digit	32.6585777552582286	-97.0325050203155826
27027	2020-05-26 06:06:31	2020-05-26	Leonore Smith-Lueilwitz	leonore.smith.lueilwitz@geemail.com	Frisco	Texas	3790328087613747	998439545e80bf2281d3e56af3540ff9	JCB 15 digit	33.1036996741309792	-96.8550362044222624
27028	2020-05-26 06:14:18	2020-05-26	Dorian Keebler-Treutel	dorian.keebler.treutel@geemail.com	San Francisco	California	869977125139988144	d5252aeef99322d5400d02bb7e17b3ad	VISA 13 digit	37.7691649569735333	-122.464973621714748
27029	2020-05-26 06:14:38	2020-05-26	Ethelyn Friesen PhD	ethelyn.friesen.phd@geemail.com	New York	New York	210063030382333756	2ba7af8fbc49850f510be932a27cd166	JCB 16 digit	40.6448353365287147	-73.9497897565726134
27030	2020-05-26 06:21:39	2020-05-26	Fronnie Abbott PhD	fronnie.abbott.phd@geemail.com	Elk Grove	California	4648731231933126	cb7b6d115c5ee23ece30d09c4d1744d4	JCB 15 digit	38.3291430997945355	-121.331060570422565
27031	2020-05-26 06:28:55	2020-05-26	Louvenia Howe	louvenia.howe@woohoo.com	Laredo	Texas	3112213976280389739	04b324d3ca637884f3d666a4d5a795df	Mastercard	27.5022525390792651	-99.5838324315853356
27032	2020-05-26 06:30:17	2020-05-26	Mrs. Sheree Becker	mrs.sheree.becker@geemail.com	Oakland	California	51676932511729839	f96ef5e82d05504846e84d41016e344c	JCB 15 digit	37.8098624419486526	-122.287529571711261
27033	2020-05-26 06:33:32	2020-05-26	Mrs. Kamora Stehr DVM	mrs.kamora.stehr.dvm@geemail.com	Providence	Rhode Island	869935896869615310	80b4f3b42ef15c7682af2c3adeb1ef02	Voyager	41.7747395124606768	-71.384574269588299
27034	2020-05-26 06:37:50	2020-05-26	Thompson Cummings	thompson.cummings@geemail.com	Mesa	Arizona	869978759268437066	82b290795a821299768c4391051fae79	VISA 13 digit	33.3306728725001165	-111.621918794966859
27035	2020-05-26 06:41:13	2020-05-26	Kazuo Huels	kazuo.huels@woohoo.com	Denver	Colorado	180005493251601763	a81a70672f98c3c86388139312ebd5f2	JCB 15 digit	39.7565484735235515	-104.938505175874013
27036	2020-05-26 07:07:03	2020-05-26	Rueben Ledner	rueben.ledner@geemail.com	Vancouver	Washington	4090824262464617	3c827e24859553932c05b26c7bd766a8	JCB 16 digit	45.5548455936439325	-122.519446408754959
27037	2020-05-26 07:22:17	2020-05-26	Jaylon Marvin	jaylon.marvin@woohoo.com	San Francisco	California	6011823748671012481	beacd2b7224178d27ac4ec4054799d62	American Express	37.7842224493804579	-122.42649631227367
27038	2020-05-26 07:32:10	2020-05-26	Chelsy Schmitt	chelsy.schmitt@geemail.com	San Francisco	California	4490451294352	87b189485aa2448eb4fb5fc204acf1ea	JCB 15 digit	37.7848594655536658	-122.42527680260244
27039	2020-05-26 07:33:06	2020-05-26	Mr. Ambers Hilpert Jr.	mr.ambers.hilpert.jr.@geemail.com	Berkeley	California	4356439260154604	69e33f9809df3a87aa40dd0f46730700	JCB 16 digit	37.8667076304109216	-122.261952453546257
27040	2020-05-26 07:33:43	2020-05-26	Manly Wehner	manly.wehner@geemail.com	San Antonio	Texas	3016477813602798	b48ecae0584f85c87363f35125d0a1cd	JCB 15 digit	29.4548203167576332	-98.4403096596546447
27041	2020-05-26 07:35:40	2020-05-26	Lafayette Schmidt Sr.	lafayette.schmidt.sr.@geemail.com	St. Petersburg	Florida	52371238583014045	f43259e11cfd182df6a06f885347d377	Diners Club / Carte Blanche	27.6621328943297264	-82.6998392050977742
27042	2020-05-26 07:43:50	2020-05-26	Katrina Heidenreich	katrina.heidenreich@woohoo.com	Phoenix	Arizona	3088650261123189962	4467e1dac0641b063238916beea2acad	JCB 16 digit	33.4751807507526138	-112.040168904412923
27043	2020-05-26 07:54:06	2020-05-26	Norita Schaden	norita.schaden@warmmail.com	Cape Coral	Florida	869968101778896311	c8eef7b8d56d906fa87d48d7944b9f68	Maestro	26.6808138783060009	-81.9554603161826662
27044	2020-05-26 07:55:35	2020-05-26	Ami Nitzsche MD	ami.nitzsche.md@geemail.com	San Francisco	California	6011680796516829876	81e5c38688f119a71685d52591669553	JCB 16 digit	37.76991487125661	-122.445894229072834
27045	2020-05-26 08:02:53	2020-05-26	Ted Roberts	ted.roberts@geemail.com	San Francisco	California	4797209677365359	1704e633b6bb91069461ebd6ec5684fc	JCB 16 digit	37.7884489931648631	-122.433036341938106
27046	2020-05-26 08:08:57	2020-05-26	Mrs. Essie Kutch	mrs.essie.kutch@geemail.com	Cincinnati	Ohio	3337978372774242219	94dfd5a4fad032f6e5b736a45221ec9e	Discover	39.1513025235615686	-84.5967717720933194
27047	2020-05-26 08:14:53	2020-05-26	Offie Wiegand-Koelpin	offie.wiegand.koelpin@woohoo.com	Kansas City	Missouri	4907867014833715	6bbddbdeedccd8ec628f0d0259809059	JCB 15 digit	39.1143468239180763	-94.5491568973511534
27048	2020-05-26 08:15:37	2020-05-26	Rod Powlowski	rod.powlowski@geemail.com	Baltimore	Maryland	3158682668743745696	2c2d34c3d23a770fcfcaadca8125621a	Mastercard	39.3214880927465842	-76.6154671625718464
27049	2020-05-26 08:28:01	2020-05-26	Dr. French Breitenberg Jr.	dr.french.breitenberg.jr.@woohoo.com	Los Angeles	California	869920243652593551	9ef59f63aa5822ef09ed361e90eef3dd	American Express	34.0673385471437129	-118.349431962332872
27050	2020-05-26 08:29:46	2020-05-26	Jazmyne Dare	jazmyne.dare@geemail.com	New York	New York	55393391070834484	4849f03e22a07517865af7674b1bca34	Voyager	40.7297432764656833	-73.9079050748039066
27051	2020-05-26 08:34:22	2020-05-26	Kinley Orn	kinley.orn@geemail.com	Plano	Texas	3096069404526974870	82071fc017a1d8287acf8a0eee632bf8	JCB 15 digit	33.0577436710327888	-96.8048026209879708
27052	2020-05-26 08:41:16	2020-05-26	Gaige Cole	gaige.cole@warmmail.com	Chicago	Illinois	3409283392339274	ee75caed554c3444a980d6f29a4b1b07	American Express	41.8713446457240721	-87.7003593044385212
27053	2020-05-26 08:43:52	2020-05-26	Alexa Keebler	alexa.keebler@geemail.com	Houston	Texas	3013024826673284	5a514de8d12168e0d1ffb0cb23d1b794	JCB 16 digit	29.7297211855728172	-95.4309347761344213
27054	2020-05-26 08:44:33	2020-05-26	Mariam Homenick	mariam.homenick@geemail.com	Los Angeles	California	4405975361099	fd12253d6e6c8daa9f78c683fba3ee1f	JCB 16 digit	33.9227687398303246	-118.325633477837954
27055	2020-05-26 08:58:52	2020-05-26	Dr. Ashby West Sr.	dr.ashby.west.sr.@geemail.com	San Antonio	Texas	4650469844393108	50d065d353b741dd14bc75fb475f8e41	Voyager	29.5502640985954557	-98.4531515172984371
27056	2020-05-26 09:10:31	2020-05-26	Mitzi Hegmann	mitzi.hegmann@warmmail.com	Irvine	California	676140278918871	5c9609335645f91e80ffa4ec5d007fa6	JCB 16 digit	33.7001377028428024	-117.733179564216357
27057	2020-05-26 09:18:51	2020-05-26	Dominick Leffler	dominick.leffler@geemail.com	Nashville	Tennessee	3031408889890137	b13cb743094c8f27ae3b3317ed04e3ee	VISA 16 digit	36.1775287920266351	-86.7572051180433448
27058	2020-05-26 09:27:09	2020-05-26	May Flatley	may.flatley@geemail.com	Nashville	Tennessee	3013960662170531	503db08a9f8850e91edd35149f5237b7	Diners Club / Carte Blanche	36.096418532368908	-86.790528449686235
27059	2020-05-26 09:43:36	2020-05-26	Amaya Hahn-Maggio	amaya.hahn.maggio@woohoo.com	Fullerton	California	869900839919268871	ecc3002903b9e1add490981c908a279f	Discover	33.7896793862495599	-117.956822747431687
27060	2020-05-26 10:01:53	2020-05-26	Courtland Champlin	courtland.champlin@geemail.com	New York	New York	6011383194084373511	95746cc2960d236726ef88605956a111	VISA 13 digit	40.5813540601395033	-74.0376357449114266
27061	2020-05-26 10:03:04	2020-05-26	Aron Kris-Tromp	aron.kris.tromp@geemail.com	Sacramento	California	869988304088157426	403fecdf239e027ca9a6d0b3fb2327e1	JCB 15 digit	38.5083579865548771	-121.384548107186703
27062	2020-05-26 10:03:24	2020-05-26	Virgel Franecki	virgel.franecki@geemail.com	Fort Worth	Texas	4507871329800769	310443bc018d851ec5f90eee208a1fe2	Discover	32.6962476342506747	-97.3016425558652713
27063	2020-05-26 10:15:16	2020-05-26	Maribel Nienow PhD	maribel.nienow.phd@geemail.com	Shreveport	Louisiana	6011657905436790295	bbff275bf9dbc228c367ae31f66fc9d5	VISA 13 digit	32.4682022234197731	-93.8514865505721332
27064	2020-05-26 10:15:52	2020-05-26	Ivanna Stoltenberg	ivanna.stoltenberg@warmmail.com	Albuquerque	New Mexico	4575102096790	6b7d8ad8a13ae02d82cb1cab7e504172	VISA 13 digit	35.1071090967994195	-106.580415346620242
27065	2020-05-26 10:24:21	2020-05-26	Prosper Rogahn	prosper.rogahn@geemail.com	Virginia Beach	Virginia	3158795922198183786	46ec784e2640a4a6772336419d35c272	VISA 16 digit	36.7077536609210071	-76.0271118986092489
27066	2020-05-26 10:27:10	2020-05-26	Blanca Nicolas	blanca.nicolas@woohoo.com	Dallas	Texas	3001055521735434	64197d0b040a099dd24d35c7a8dd792f	VISA 16 digit	32.7458724748615211	-96.7741616247184453
27067	2020-05-26 10:30:34	2020-05-26	Charolette Cronin	charolette.cronin@geemail.com	Simi Valley	California	4052804057641427	bfc9aae6b16b94fb21659652a7cff809	JCB 15 digit	34.3067705658502859	-118.792604080460976
27068	2020-05-26 10:32:28	2020-05-26	Mrs. Taniya D'Amore	mrs.taniya.d'amore@geemail.com	Seattle	Washington	869955340539274286	0edc437911886582a05283d1903be31b	VISA 16 digit	47.5375477068051708	-122.420497888877605
27069	2020-05-26 10:36:43	2020-05-26	Mrs. Shyann Prohaska PhD	mrs.shyann.prohaska.phd@geemail.com	Portland	Oregon	3707029189369863	27dffecb4ea2fd13a7299e3029147160	Diners Club / Carte Blanche	45.525965779542922	-122.551325334422302
27070	2020-05-26 10:42:32	2020-05-26	Almina Douglas DVM	almina.douglas.dvm@warmmail.com	San Francisco	California	869928273580269174	656b026cf0762cb897034999b0052a3d	VISA 16 digit	37.752063677191444	-122.445350301306462
27071	2020-05-26 10:53:07	2020-05-26	Louie Altenwerth-Wisozk	louie.altenwerth.wisozk@geemail.com	Brownsville	Texas	4474964821182	1f8e8c82ea0d1fa2042dfeb5e70a49b5	Maestro	26.0140205709341892	-97.4777136971894578
27072	2020-05-26 10:55:29	2020-05-26	Prudence Towne	prudence.towne@geemail.com	Philadelphia	Pennsylvania	3337463547713206209	25f7132253d31084cf7cab00333f2047	Maestro	40.0987864945042887	-75.2214868388038127
27073	2020-05-26 10:57:22	2020-05-26	Deborah Will PhD	deborah.will.phd@geemail.com	Montgomery	Alabama	6011689904162875364	a3ec579f34c92df3b0508e34ac0f935d	JCB 15 digit	32.317109156905488	-86.3162154221594307
27074	2020-05-26 11:11:45	2020-05-26	Cassius Hyatt-Sipes	cassius.hyatt.sipes@geemail.com	Norfolk	Virginia	869994199102903819	c9d9417b45bf4f8a49ffd4458cb90813	Discover	36.8906710082218083	-76.2675017867706799
27075	2020-05-26 11:12:16	2020-05-26	Theta Krajcik	theta.krajcik@woohoo.com	Houston	Texas	4921619429823274	63b5c9435872ae75ee4701529cf3bdab	Mastercard	29.8085869025051586	-95.486359334645428
27076	2020-05-26 11:13:42	2020-05-26	Dr. Marcelle Stiedemann PhD	dr.marcelle.stiedemann.phd@geemail.com	Fort Worth	Texas	4480018435113726	a2108346601b934b69c9913c50b65cf5	Voyager	32.7306527296602709	-97.3872345363076732
27077	2020-05-26 11:18:34	2020-05-26	Daisey Fahey	daisey.fahey@woohoo.com	New York	New York	52458843113386270	1e606271a63305931cd1cdacb522b043	JCB 15 digit	40.7196356487683957	-74.0257351681485716
27078	2020-05-26 11:21:10	2020-05-26	Delma Shields-Kulas	delma.shields.kulas@woohoo.com	Rochester	New York	3528405728277786767	f6b185a61636b29ffbc76aa3e1f213a7	Discover	43.1349776798371209	-77.6159644160658075
27079	2020-05-26 11:23:54	2020-05-26	Mr. Jude Schuster	mr.jude.schuster@geemail.com	Oceanside	California	3434549762596472	fec9cba7f769a1b0d7cd5554d1fa55db	VISA 16 digit	33.1547911750040925	-117.385507969287048
27080	2020-05-26 11:41:23	2020-05-26	Foch Schneider	foch.schneider@geemail.com	San Antonio	Texas	3112672659229274527	3d881bc49ada4ecdc1b1f18e4fa86e56	VISA 16 digit	29.5131329210080224	-98.6193764425184582
27081	2020-05-26 11:46:29	2020-05-26	Miss Leonora Parisian MD	miss.leonora.parisian.md@geemail.com	Mesquite	Texas	4616226294901	bf1618264c0fb3d16233b520c9a96837	Discover	32.7358699559509745	-96.6491524951729986
27082	2020-05-26 11:47:06	2020-05-26	Jefferey Dibbert	jefferey.dibbert@warmmail.com	Berkeley	California	210029405833896382	f7b3c7855993f9698932d937655bf8cd	JCB 16 digit	37.8788373730554966	-122.292067156481153
27083	2020-05-26 11:47:07	2020-05-26	Lena Marvin	lena.marvin@geemail.com	Nashville	Tennessee	210090213506100346	0986d5d62e7aaf972b1fbd680e8acaa6	American Express	36.109414005291832	-86.8661923001427141
27084	2020-05-26 11:51:10	2020-05-26	Mr. Skyler Kohler	mr.skyler.kohler@geemail.com	Chicago	Illinois	6011018647631651393	dfab94ee13138c238fd0074b0feacd3c	Diners Club / Carte Blanche	41.8427928381435592	-87.6140372235357745
27085	2020-05-26 11:53:19	2020-05-26	Capitola Schneider	capitola.schneider@geemail.com	New York	New York	6011865311175113823	dbe23460d755c4eb65029c85e99667d5	VISA 13 digit	40.6809535835627472	-73.9592553431995157
27086	2020-05-26 11:57:32	2020-05-26	Simona Medhurst-Murazik	simona.medhurst.murazik@warmmail.com	New York	New York	6011399363959080236	ac837bb277e7974d21008d951beb40ca	Maestro	40.651304017495363	-73.9501499166142224
27087	2020-05-26 12:03:30	2020-05-26	Ella D'Amore DVM	ella.d'amore.dvm@warmmail.com	Provo	Utah	6011099859198470776	9a71359efacd8080fb8ba6c402e2f9cf	American Express	40.253772872199491	-111.733687768331919
27088	2020-05-26 12:05:35	2020-05-26	Emiliano Bergstrom	emiliano.bergstrom@geemail.com	San Jose	California	3096404321304423983	a8c7186e4e595c226a503dd3edc30985	Mastercard	37.2978319581419271	-121.901818471191078
27089	2020-05-26 12:07:48	2020-05-26	Parker Bode	parker.bode@warmmail.com	Santa Clara	California	210019384322415362	407a3841b8c7624bd0c80d2d81ccae51	VISA 13 digit	37.3423392899617568	-122.006249573826423
27090	2020-05-26 12:15:48	2020-05-26	Ms. Althea Dietrich PhD	ms.althea.dietrich.phd@geemail.com	Charlotte	North Carolina	6011986380208280150	ee92b6f5efb388beaf8cd5929195b933	VISA 16 digit	35.1925002293914559	-80.8465139988288257
27091	2020-05-26 12:36:23	2020-05-26	Savion Ruecker III	savion.ruecker.iii@geemail.com	Syracuse	New York	6011022519142170144	781f10bb5d68d52f102a693dc2ec734f	Diners Club / Carte Blanche	42.9849937771763635	-76.071920010053006
27092	2020-05-26 12:45:16	2020-05-26	Lyda VonRueden	lyda.vonrueden@geemail.com	Baton Rouge	Louisiana	6011153458875989167	4832b2bbd3cebd0e0586723b523b1ce6	VISA 13 digit	30.5000349422197772	-91.1670838802229611
27093	2020-05-26 12:47:45	2020-05-26	Heber Kirlin	heber.kirlin@geemail.com	Cape Coral	Florida	4781960689979	cbaa1359c3474a60e1255336a5528ed7	Mastercard	26.564025612172486	-82.0749943507906039
27094	2020-05-26 12:52:50	2020-05-26	Carroll Morar	carroll.morar@geemail.com	Philadelphia	Pennsylvania	3158481348016196512	60ed7ca38b9c7e4cfc407cc9374ba4a6	JCB 15 digit	39.9556428376544233	-75.1502158000033376
27095	2020-05-26 12:54:56	2020-05-26	Eulalie Ondricka DDS	eulalie.ondricka.dds@woohoo.com	Fresno	California	210039219860147116	31213269cb159433f0a49acb4734bdf4	VISA 16 digit	36.7810167339038117	-119.779231403546035
27096	2020-05-26 13:08:13	2020-05-26	Franz Maggio-Will	franz.maggio.will@geemail.com	Indianapolis	Indiana	869962382483712763	e9e497d4618ed4ec43cf182ece6fb97c	JCB 16 digit	39.7577391790233534	-86.209328117753941
27097	2020-05-26 13:10:55	2020-05-26	Amasa Zemlak-Boehm	amasa.zemlak.boehm@warmmail.com	Worcester	Massachusetts	869960010912239775	2e4cb10ec8fe878a9b8ea4de681e7111	Voyager	42.2917849523182952	-71.8002034287221704
27098	2020-05-26 13:28:01	2020-05-26	Emmalee Tillman	emmalee.tillman@warmmail.com	Detroit	Michigan	869905010823624402	34d7452886a7a10a25798aa402921143	JCB 16 digit	42.4228407410830286	-83.1872592317525203
27099	2020-05-26 13:30:55	2020-05-26	Gia Johnston	gia.johnston@geemail.com	Long Beach	California	4850443529171053	b814a03adee0ebf00137211b4f785770	Mastercard	33.7775789980132117	-118.153785644580793
27100	2020-05-26 13:36:49	2020-05-26	Kiefer Murray	kiefer.murray@geemail.com	Kansas City	Missouri	51718259288810109	96a7f24601284e48fbd2e58e28cae62f	VISA 13 digit	39.1045388595037196	-94.6085529084540866
27101	2020-05-26 13:50:56	2020-05-26	Celestino McGlynn	celestino.mcglynn@geemail.com	Tulsa	Oklahoma	52480893032975473	bceac5f9aba668b5285637a3399d270a	American Express	36.1706398940082607	-95.9481209035918141
27102	2020-05-26 13:53:20	2020-05-26	Jacob Farrell	jacob.farrell@geemail.com	Atlanta	Georgia	869970763349678670	e0f64eed6e9d0003619bfa4fcc794a3a	VISA 16 digit	33.6987677215874228	-84.3892170764550684
27103	2020-05-26 13:58:54	2020-05-26	Effie Glover	effie.glover@geemail.com	Tampa	Florida	4690185839576	130afb30ac4503c9f3990fa8b92d65c7	VISA 13 digit	27.9155291797243059	-82.4928293227896035
27104	2020-05-26 14:10:54	2020-05-26	Natalya Trantow PhD	natalya.trantow.phd@warmmail.com	Los Angeles	California	589379133851257	a6d813fd8aab38497fe606c2b61584ec	VISA 16 digit	34.0483901435375174	-118.367630955203623
27105	2020-05-26 14:14:35	2020-05-26	Dr. Jess Runte	dr.jess.runte@geemail.com	Moreno Valley	California	53487471488942777	b565a4ecc9df82b183268e65a053c121	American Express	34.0099491801105387	-117.285085649319726
27106	2020-05-26 14:18:41	2020-05-26	Angelina Becker	angelina.becker@geemail.com	Ontario	California	51289135689170583	e84fba4119d8ae64152d2ebc34eeed7f	VISA 16 digit	34.0646659564372172	-117.636859337203958
27107	2020-05-26 14:18:44	2020-05-26	Lennie Robel	lennie.robel@geemail.com	Akron	Ohio	869933975857498293	8a3c89c2bd28feb710fc0d9f73279295	Maestro	41.1362161715347341	-81.5453101155195412
27108	2020-05-26 14:20:39	2020-05-26	Virginia Nienow-Frami	virginia.nienow.frami@geemail.com	Oklahoma City	Oklahoma	3724761507624426	65b7ff624d229db2f7f03e79936c824a	JCB 16 digit	35.4538860495112829	-97.4330449883721741
27109	2020-05-26 14:29:09	2020-05-26	Mr. Josef Hoeger	mr.josef.hoeger@geemail.com	Houston	Texas	675952891106305	085f0902ac22e09710edc9f2fce77353	Maestro	29.869506528236343	-95.4050068805009204
27110	2020-05-26 14:35:20	2020-05-26	Sonny Ankunding	sonny.ankunding@geemail.com	Concord	California	3158136702578073643	7d29d8e8a07a534bcf7d362867910971	Discover	37.978856069401651	-121.978623179363453
27111	2020-05-26 14:46:29	2020-05-26	Lige Pacocha-Bins	lige.pacocha.bins@geemail.com	San Jose	California	4653433900693444	783377b492e857dca670d332578190c3	VISA 16 digit	37.2588132957283449	-121.788282334081458
27112	2020-05-26 14:47:54	2020-05-26	Dr. Idamae Schmitt	dr.idamae.schmitt@geemail.com	Mobile	Alabama	3337019425968719250	ed2efca8dca51d18ddb6f58f1a071fc2	VISA 16 digit	30.5833843847379079	-88.1129538706641711
27113	2020-05-26 15:04:46	2020-05-26	Octavie Larkin-Waelchi	octavie.larkin.waelchi@warmmail.com	New York	New York	4085690741897934	5f3e7d2d43f1fc026a2ccf0c5f5de154	VISA 13 digit	40.7254740743190027	-74.009367951134962
27114	2020-05-26 15:06:25	2020-05-26	Chas Kling	chas.kling@geemail.com	Columbus	Ohio	4861185205593624	b218df245fa79d727c68ffcf8a9ef7d7	American Express	39.9577167366210375	-82.9027123490583193
27115	2020-05-26 15:24:44	2020-05-26	Elana Schaefer PhD	elana.schaefer.phd@geemail.com	Berkeley	California	4454212307994	d53f239b7d12bcb9654e251ebb521884	Voyager	37.8602967967755717	-122.270939191878512
27116	2020-05-26 15:26:18	2020-05-26	Layton Ullrich	layton.ullrich@geemail.com	Chicago	Illinois	3433953758893193	99e8028f2126d726340a319aa76d6ffd	Voyager	41.8690016778953407	-87.6045337779011533
27117	2020-05-26 15:37:17	2020-05-26	Arlington Kub Jr.	arlington.kub.jr.@geemail.com	Berkeley	California	501811697044524	989e8f9401bdd851481efee59d147972	JCB 16 digit	37.8881024298513651	-122.247619657764233
27118	2020-05-26 15:47:45	2020-05-26	Chantelle Schuster-Langworth	chantelle.schuster.langworth@geemail.com	Oklahoma City	Oklahoma	4716803831057	22cad55b86c1fff326e6b48148f17861	Diners Club / Carte Blanche	35.3889140910379609	-97.4533217168308852
27119	2020-05-26 15:49:43	2020-05-26	Hildegard Kling	hildegard.kling@geemail.com	Gresham	Oregon	6011972757243405718	f7cad6365162410b03bbb95ce1a9d987	JCB 16 digit	45.4666686834257092	-122.440131588073811
27120	2020-05-26 15:53:18	2020-05-26	Eugene Muller	eugene.muller@geemail.com	Spokane	Washington	561261794737611	6be7ac19348a902d7c88b530b415ff43	Diners Club / Carte Blanche	47.6779553049016727	-117.451356638725102
27121	2020-05-26 16:01:18	2020-05-26	Joe Turcotte I	joe.turcotte.i@woohoo.com	New York	New York	4936502581957	7c64eea2eb57494d2e703ada80e37c9a	Mastercard	40.6253633434176464	-73.9706860427174746
27122	2020-05-26 16:09:00	2020-05-26	Minda Gottlieb	minda.gottlieb@geemail.com	Hialeah	Florida	4649513700036436	92169b06f0991021619cfb480a271cbd	Discover	25.9159194979794343	-80.3184059572309224
27123	2020-05-26 16:17:14	2020-05-26	Delma Zieme	delma.zieme@warmmail.com	Phoenix	Arizona	4049278858540	11e08b9db085fa6517c5904d6091a2dc	VISA 13 digit	33.5285442837912626	-111.990520446367938
27124	2020-05-26 16:20:08	2020-05-26	Mr. Gage Schultz DDS	mr.gage.schultz.dds@warmmail.com	Atlanta	Georgia	210000227931421225	8e4f1306cd33c1baf9746af92e5fb2fa	Discover	33.7688094783850019	-84.4690701903820127
27125	2020-05-26 16:35:12	2020-05-26	Kaye Keebler PhD	kaye.keebler.phd@warmmail.com	New York	New York	676263644012054	c9259f20152aca1b226af9500aa20e34	Discover	40.6796482705734661	-73.8902739861410112
27126	2020-05-26 16:37:01	2020-05-26	Mitchell Bashirian	mitchell.bashirian@woohoo.com	Eugene	Oregon	4360794283544130	0a9662e6c5c31602736ae6aa07452d05	JCB 16 digit	44.0067774655956754	-123.080895761399347
27127	2020-05-26 16:37:39	2020-05-26	Brigette Marquardt-O'Reilly	brigette.marquardt.o'reilly@geemail.com	San Francisco	California	54653220651838678	aa9c96e5cc9f1501681f13b7c2203ccd	Discover	37.7858807320175814	-122.467584409165681
27128	2020-05-26 16:48:34	2020-05-26	Nakisha Steuber	nakisha.steuber@geemail.com	Raleigh	North Carolina	869932657575890222	8e60a000f69b55de94d15e9c60bafc50	VISA 16 digit	35.8853055101487755	-78.5638582075417133
27129	2020-05-26 16:56:50	2020-05-26	Carri Jacobi	carri.jacobi@woohoo.com	Chicago	Illinois	3479176758571727	f8d1458cddd61f66ebd657eb936fa46c	Mastercard	41.9304805496078004	-87.7101522452693416
27130	2020-05-26 16:57:53	2020-05-26	Dr. Noma Jast	dr.noma.jast@geemail.com	Austin	Texas	6011409438877109206	9209aee86ff2b409b9fb6c50910b45ef	JCB 16 digit	30.2220755186058554	-97.8447490556869752
27131	2020-05-26 16:58:36	2020-05-26	Miah Cummings	miah.cummings@geemail.com	New York	New York	6011820599686789362	664b4c3ec83173a750b52e64d2e37f98	American Express	40.5999059031475298	-73.934222568840525
27132	2020-05-26 17:06:25	2020-05-26	Patrica Romaguera	patrica.romaguera@geemail.com	Plano	Texas	51333821114923268	7ba4bc1cfbeb3dd8c003fb38b29c77aa	American Express	32.9749000605281495	-96.6736715919986409
27133	2020-05-26 17:17:23	2020-05-26	Ozell Sauer-Roberts	ozell.sauer.roberts@warmmail.com	Clearwater	Florida	4937413016012554	f82ee4d7fdd4e55dae90dc79a0c735e4	Discover	28.0416467969432475	-82.6675936724323748
27134	2020-05-26 17:23:31	2020-05-26	Sadie Adams DDS	sadie.adams.dds@geemail.com	McAllen	Texas	3337892239265066030	b318367b5bb1d0c5972e325988817de1	Diners Club / Carte Blanche	26.2630978670742365	-98.1991282120194171
27135	2020-05-26 17:33:15	2020-05-26	Chelsie Hilll DDS	chelsie.hilll.dds@woohoo.com	Oakland	California	4888930353147437	34fc58b1f1f45a579c6d59dcb31add9b	VISA 16 digit	37.8092168536071327	-122.254492880409245
27136	2020-05-26 17:44:38	2020-05-26	Sheree Graham-Schuster	sheree.graham.schuster@geemail.com	Joliet	Illinois	180025808540908370	cf04e17c8179721e3da4d992030c32f6	VISA 13 digit	41.5732296031758182	-88.2218632474180282
27137	2020-05-26 17:50:26	2020-05-26	Mr. Gustavo Frami V	mr.gustavo.frami.v@geemail.com	San Francisco	California	4564543088133894	4cb05b8bb39c0f8f8bd3de6712cc305b	Diners Club / Carte Blanche	37.7652310579706239	-122.409562643106284
27138	2020-05-26 18:01:22	2020-05-26	Emiliano Marks III	emiliano.marks.iii@geemail.com	Shreveport	Louisiana	869991572089623613	054f58932a6cfe28a1ceffe0cce4dc64	VISA 13 digit	32.5073970707371842	-93.8378573094706923
27139	2020-05-26 18:07:02	2020-05-26	Dr. Tracey Barton DDS	dr.tracey.barton.dds@geemail.com	Fargo	North Dakota	4066410350736254	b80425a19e8acb096aa1c82c0d90393c	JCB 16 digit	46.9259881610747414	-96.9122886962220065
27140	2020-05-26 18:07:27	2020-05-26	Echo Keebler MD	echo.keebler.md@geemail.com	Raleigh	North Carolina	180013407573416031	8e18d69956bc1739367673ad8bbe4327	Discover	35.8253597908787427	-78.5873372893717175
27141	2020-05-26 18:10:15	2020-05-26	Nira Schuster	nira.schuster@woohoo.com	Charleston	South Carolina	6011610334064432565	1a3c3abe6b7df9a82ce28d444ee6f7ac	Voyager	32.7287977328520299	-80.0265974777434081
27142	2020-05-26 18:24:31	2020-05-26	Mr. Daquan Lebsack I	mr.daquan.lebsack.i@geemail.com	Jacksonville	Florida	6011723322090592985	eba5545b9f6e8c39402105c268a21fc8	VISA 16 digit	30.2793572928342982	-81.562464067953087
27143	2020-05-26 18:26:04	2020-05-26	Karley Oberbrunner	karley.oberbrunner@geemail.com	Anchorage	Alaska	4294858829174180	0eadad34d52926de1c4b51ac8c307976	Discover	61.2597220437351666	-149.25382080200427
27144	2020-05-26 18:32:04	2020-05-26	Maxx Christiansen	maxx.christiansen@geemail.com	Vacaville	California	3158470937104301100	e0dbb2ba2b8be889b3ea396084c1bb56	Maestro	38.382970328688252	-121.903579928388083
27145	2020-05-26 18:32:47	2020-05-26	Mrs. Louisiana Jast DVM	mrs.louisiana.jast.dvm@woohoo.com	Torrance	California	51779259695749185	67d8242ed22aad9fc0430d1d5b268751	Voyager	33.7929797593411081	-118.310114459566392
27146	2020-05-26 18:36:17	2020-05-26	Alysha Fay	alysha.fay@woohoo.com	Dallas	Texas	4675493743321	d522b14f1c534af1f351b20eceb033ea	JCB 15 digit	32.7694946260463453	-96.7943198803309315
27147	2020-05-26 18:42:34	2020-05-26	Gerry Wolff	gerry.wolff@geemail.com	Wichita	Kansas	4772705273356394	0d7684d05e10015e0f40e0a9a9d85f2b	VISA 16 digit	37.7806735610932094	-97.2729981620065871
27148	2020-05-26 18:43:28	2020-05-26	Vaughn Hessel-Schneider	vaughn.hessel.schneider@geemail.com	San Francisco	California	4972934730554882	3d553077e594758bcb909ff9dd7ad8d7	JCB 16 digit	37.7561527227431384	-122.450254521420717
27149	2020-05-26 18:44:21	2020-05-26	Lenore Goodwin	lenore.goodwin@geemail.com	Springfield	Missouri	3096807221392156805	d7dc571a48fbff015e725e4423ea369e	American Express	37.2672521897319697	-93.3163111499335685
27150	2020-05-26 18:57:02	2020-05-26	Bess Bernhard	bess.bernhard@warmmail.com	Reno	Nevada	4101880096356830	4fc87e0c0bff41c75ef80d7981c0f02d	Discover	39.458680176137392	-119.897542499487855
27151	2020-05-26 19:21:31	2020-05-26	Callum Goodwin	callum.goodwin@woohoo.com	New York	New York	3096425057093756184	0ba4faeea005886bbe72d6c9e11c021d	Diners Club / Carte Blanche	40.7184205889925366	-74.0086193288106386
27152	2020-05-26 19:21:32	2020-05-26	Forest Grant	forest.grant@geemail.com	New York	New York	6011310366934848532	be04a54b6473fbd53b67d1bf7bc78bea	JCB 16 digit	40.6909255095981024	-73.8483229764632796
27153	2020-05-26 19:22:21	2020-05-26	Mr. Helmer Greenfelder	mr.helmer.greenfelder@geemail.com	Jersey City	New Jersey	3096480821746020104	1a41948f342f07955c727b1a2f6fa10e	Mastercard	40.6474535040963403	-74.0809861335393123
27154	2020-05-26 19:24:45	2020-05-26	Alvie Blick MD	alvie.blick.md@geemail.com	Hayward	California	3488954432887423	0c2cf1d8e12fad0cb2fbd65eda7641f4	VISA 13 digit	37.6785142349533757	-122.123269034156209
27155	2020-05-26 19:28:07	2020-05-26	Uriah Ankunding	uriah.ankunding@warmmail.com	Houston	Texas	4732426587810	fa1423e9f8b8ac2c94f264b894abf0f0	JCB 16 digit	29.8273607634086169	-95.3282924709390898
27156	2020-05-26 19:31:45	2020-05-26	Georgine Durgan	georgine.durgan@warmmail.com	New York	New York	4485125195269740	fa31f2aea82f9ec931dc33352da348ab	VISA 13 digit	40.6836237716246387	-73.9523456197127729
27157	2020-05-26 19:42:44	2020-05-26	Dr. Konner Weber	dr.konner.weber@geemail.com	New York	New York	3017822758085559	431e9d2fb6bcf2741362b1be7014371e	Mastercard	40.6793185648266231	-73.869424070733416
27158	2020-05-26 19:55:01	2020-05-26	Rich Donnelly	rich.donnelly@geemail.com	Kansas City	Missouri	869912241708210600	16fd5d235be6835bd8ab67c8f60243a9	JCB 16 digit	39.1474198158666553	-94.6199368013758288
27159	2020-05-26 20:00:43	2020-05-26	Harvey Kuvalis	harvey.kuvalis@geemail.com	Charlotte	North Carolina	869974879417504998	dc573791fb92d360987beb8ff056b165	VISA 16 digit	35.1225117769345658	-80.7563896750975374
27160	2020-05-26 20:34:18	2020-05-26	Mrs. Elizebeth Abshire DVM	mrs.elizebeth.abshire.dvm@geemail.com	Dallas	Texas	4262341592561295	ce7b244d5a888ed81ef4e39c3c090465	Maestro	32.8728511830598151	-96.8179380472712126
27161	2020-05-26 20:36:19	2020-05-26	Ms. Vernetta Pfeffer	ms.vernetta.pfeffer@geemail.com	San Francisco	California	869929221733120306	55e84d9a5975104a6199f58958c35c27	Mastercard	37.7528826711497345	-122.410866223693247
27162	2020-05-26 21:09:37	2020-05-26	Shelvia Crist-Keebler	shelvia.crist.keebler@geemail.com	Cape Coral	Florida	210042782540317982	c9219cd35eb82e947f62bad412ba6e42	Mastercard	26.6911116358794267	-81.922675495322423
27163	2020-05-26 21:24:05	2020-05-26	Mr. Jabari Howell III	mr.jabari.howell.iii@warmmail.com	Seattle	Washington	180006812248018980	c93741491ba69c97e9574d67d5a71ef2	JCB 15 digit	47.631414986394347	-122.280323831868913
27164	2020-05-26 21:32:12	2020-05-26	Reid Mante	reid.mante@geemail.com	Providence	Rhode Island	3528721437472325846	1b107218d3c22dae70cf0be9bda5a416	VISA 16 digit	41.8015110384527588	-71.3649102346424087
27165	2020-05-26 21:37:29	2020-05-26	Mrs. Jasmine Stamm	mrs.jasmine.stamm@geemail.com	San Diego	California	3158368813839783026	7a88d95d278f8e914e1c127f5b62a128	VISA 16 digit	32.7880639270946403	-117.081164791658523
27166	2020-05-26 21:50:37	2020-05-26	Ethelene Reichel	ethelene.reichel@geemail.com	San Francisco	California	210028863354859083	358825d31b1c3455044a11fe97bb0992	Discover	37.7704157062596835	-122.41340721699973
27167	2020-05-26 21:51:54	2020-05-26	Ms. Orpha Shields	ms.orpha.shields@geemail.com	New York	New York	6011918363694310528	2942cf096269bcc53f7085662b6c8a19	Maestro	40.6917264198176554	-73.9703265380010038
27168	2020-05-26 21:51:55	2020-05-26	Dr. Clarisa Kshlerin	dr.clarisa.kshlerin@woohoo.com	Oakland	California	869993418952230144	e7018ef3d539d872a9f62d45b6ab2677	Maestro	37.8133027856129189	-122.281751303084746
27169	2020-05-26 21:56:13	2020-05-26	Mrs. Carolee Pacocha DDS	mrs.carolee.pacocha.dds@woohoo.com	New York	New York	6011101027377370912	13bdce532ca882a8d1948d371ca36a08	VISA 13 digit	40.6481425146795772	-73.8994950469013219
27170	2020-05-26 22:09:11	2020-05-26	Tanja Lueilwitz	tanja.lueilwitz@geemail.com	Tampa	Florida	869973551751908496	0ff973a2bc721d5916fe966908d2a995	VISA 16 digit	27.9404744930680842	-82.5041770990684569
27171	2020-05-26 22:23:45	2020-05-26	Serenity Lockman	serenity.lockman@warmmail.com	Albuquerque	New Mexico	4258140014014	77a2e969e63a0676277dd3282a464f9b	Voyager	35.0222113962885047	-106.732190603071459
27172	2020-05-26 22:25:12	2020-05-26	Shaniqua Heathcote PhD	shaniqua.heathcote.phd@geemail.com	Scottsdale	Arizona	3112996526353883184	d21f1749e3b830c51076a530a2bf3c99	American Express	33.6268601202528927	-111.778022291554507
27173	2020-05-26 22:35:45	2020-05-26	Verner Jacobson-Zboncak	verner.jacobson.zboncak@warmmail.com	Lakewood	Colorado	3001063440261391	939140f58ac4571773eb984af9aeb5be	JCB 16 digit	39.7935261565201017	-105.124551212789854
27174	2020-05-26 22:41:38	2020-05-26	Irine Davis	irine.davis@geemail.com	New York	New York	501896182904613	e0362633b217077868fbc3d54261b77e	American Express	40.6247679691985226	-74.0347885068867271
27175	2020-05-26 22:48:06	2020-05-26	Beau Stehr	beau.stehr@geemail.com	San Francisco	California	3433746180394974	5f9f29eaee0c555b007e71e8104223a4	VISA 16 digit	37.7731580402273366	-122.417248552930076
27176	2020-05-26 22:48:10	2020-05-26	Jaxton Kuhn	jaxton.kuhn@warmmail.com	Anchorage	Alaska	3088993157219039093	80d9e2b7abdd5484889dcf02588c4c87	Voyager	61.1468705001503281	-149.383706904028742
27177	2020-05-26 23:19:31	2020-05-26	Mr. Eduardo Hodkiewicz	mr.eduardo.hodkiewicz@geemail.com	New York	New York	6011536812976092594	49f2c9343a43efbeac1440e86579d4b4	VISA 16 digit	40.6695715767554944	-73.8843295330542986
27178	2020-05-26 23:29:50	2020-05-26	Wayde Emmerich	wayde.emmerich@geemail.com	Denton	Texas	4840814155496670	56e68fa2d277222e99cbf2860ad1f882	JCB 15 digit	33.188007590992747	-97.2372688509184968
27179	2020-05-26 23:39:04	2020-05-26	Dr. Sudie D'Amore PhD	dr.sudie.d'amore.phd@woohoo.com	Riverside	California	501810363191007	727bb1daeac37c4c8b232f9fdb549c35	JCB 16 digit	33.8911907022301122	-117.333121492338179
27180	2020-05-26 23:41:34	2020-05-26	Mr. Olie Wolff	mr.olie.wolff@warmmail.com	Chicago	Illinois	676195639354497	e7fdf1a5a94f544bc72bd4de0c201250	VISA 16 digit	41.8536706082824637	-87.7513891462732118
27181	2020-05-26 23:50:26	2020-05-26	Mervin Homenick	mervin.homenick@geemail.com	Santa Clara	California	3052693319357406	e9a683bc124aaea6f163eaef85aa26a2	Discover	37.3558389751989424	-122.016886709071329
27182	2020-05-27 00:00:57	2020-05-27	Mrs. Lois Beer	mrs.lois.beer@warmmail.com	Anchorage	Alaska	210062838992439321	09a23dda16f046d73ff3c02d4a223e73	VISA 16 digit	61.270063424690818	-149.25965544605927
27183	2020-05-27 00:08:00	2020-05-27	Taryn McDermott-Jakubowski	taryn.mcdermott.jakubowski@geemail.com	Hollywood	Florida	3725710764168170	dd9048e258dd669113d319545a29760c	JCB 16 digit	26.0095268066450949	-80.1630626206569303
27184	2020-05-27 00:20:30	2020-05-27	Estevan Deckow DDS	estevan.deckow.dds@geemail.com	Ontario	California	6011765826265586050	b3bbbb210d2a0acf1fc17320357a1906	Maestro	34.0057119466044	-117.58768386483267
27185	2020-05-27 00:21:53	2020-05-27	Mr. Sim Jast V	mr.sim.jast.v@geemail.com	San Jose	California	3474957515120030	05954067085cb2fb2f59be527adef633	Mastercard	37.3906229434821782	-121.844675744160639
27186	2020-05-27 00:33:54	2020-05-27	Mr. Koda Blick Jr.	mr.koda.blick.jr.@geemail.com	Temecula	California	3096341495400167078	6d6119f852568020e95d0ba0be912539	VISA 16 digit	33.5324465307541146	-117.197412713869284
27187	2020-05-27 00:53:43	2020-05-27	Dr. Kourtney Kshlerin MD	dr.kourtney.kshlerin.md@geemail.com	San Francisco	California	6011024907489106029	5a58d54072e5312aac3b7ed5004ad534	JCB 16 digit	37.7340762922965496	-122.435364653511186
27188	2020-05-27 01:01:29	2020-05-27	Harlan Rutherford Jr.	harlan.rutherford.jr.@geemail.com	Des Moines	Iowa	4201842483771236	e99996bd1d249ab6e54f8f5f2327a196	VISA 13 digit	41.4863420890387147	-93.6341803290926009
27189	2020-05-27 01:02:40	2020-05-27	Kortney Hansen-Dickens	kortney.hansen.dickens@geemail.com	Waco	Texas	4333039915052738	67d22a1f8d769e2a6f588d6e681584ff	JCB 16 digit	31.6045172016810625	-97.2214658621829102
27190	2020-05-27 01:08:02	2020-05-27	Jonnie O'Connell-Dickens	jonnie.o'connell.dickens@geemail.com	New York	New York	54763355617698910	02004974927f91ce673c341f5973199e	Mastercard	40.644323992658407	-73.9143882999092341
27191	2020-05-27 01:12:06	2020-05-27	Ms. Shaquana Stiedemann MD	ms.shaquana.stiedemann.md@geemail.com	Oakland	California	4323577370586148	b466093c984fe50d0d0ce6dc799fe3a2	JCB 16 digit	37.7835068384897284	-122.267546967392988
27192	2020-05-27 01:15:05	2020-05-27	Miss Miley Blick DVM	miss.miley.blick.dvm@geemail.com	Stamford	Connecticut	869926543339058660	10ab9fef5f76049f09a6624aa7041e57	VISA 16 digit	41.0643857305288336	-73.5608010283242919
27193	2020-05-27 01:18:59	2020-05-27	Brandt Farrell-Wisoky	brandt.farrell.wisoky@geemail.com	Nashville	Tennessee	3337425294529827525	00f22bb3d223378fd1c31f8f1e585831	American Express	36.1032537869300683	-86.8461566039267865
27194	2020-05-27 01:22:12	2020-05-27	Ridge Lehner	ridge.lehner@geemail.com	New York	New York	4391813695416944	3430c260bc1af220025c7ad7ed522a99	Discover	40.7270975097306049	-74.0333180391125296
27195	2020-05-27 01:24:01	2020-05-27	Mr. Rahul Smith	mr.rahul.smith@geemail.com	Santa Ana	California	503847563015131	00f66819dcb07e9e839ad3f9806b6bbe	JCB 16 digit	33.8265737392578245	-117.946948964560406
27196	2020-05-27 01:36:36	2020-05-27	Jeryl McClure	jeryl.mcclure@geemail.com	Oklahoma City	Oklahoma	630458506848801	be1346ecd6225cc7e40bd2f97547039c	American Express	35.4814823439721039	-97.4471731048438699
27197	2020-05-27 01:36:59	2020-05-27	Rollin Spencer III	rollin.spencer.iii@warmmail.com	New York	New York	4497970603652474	641fec38b4e913dc92b91994222bb0a3	Mastercard	40.7439163080174467	-73.9480316039536092
27198	2020-05-27 01:44:34	2020-05-27	Miley Batz	miley.batz@geemail.com	San Francisco	California	3436932303859724	8e89d2516fd301d64c90fc1d877cd9f0	VISA 13 digit	37.8044988396817061	-122.455605006997772
27199	2020-05-27 01:44:42	2020-05-27	Sharee Mosciski-Hodkiewicz	sharee.mosciski.hodkiewicz@geemail.com	Mesa	Arizona	210074154062852377	e8575b04b89432aa2f45aea3af4ec22f	JCB 16 digit	33.319143913002307	-111.777930398506669
27200	2020-05-27 01:45:46	2020-05-27	Mr. Zack Stracke	mr.zack.stracke@geemail.com	Santa Clara	California	3088295052819455275	692ab2d721ec9f13503eb23db6a041a2	Mastercard	37.4156202423203794	-122.043057564599067
27201	2020-05-27 01:50:15	2020-05-27	Cary Connelly MD	cary.connelly.md@warmmail.com	Philadelphia	Pennsylvania	3777029508883482	657533b17227102f882309ea8f3d7c0d	Mastercard	39.921799567663669	-75.1840361452095323
27202	2020-05-27 02:01:58	2020-05-27	Dr. Lilie Schoen	dr.lilie.schoen@geemail.com	Henderson	Nevada	3758423480877310	715c65f913b1ee41452fbaba13a95b68	VISA 16 digit	35.9823959587540472	-115.064255724862974
27203	2020-05-27 02:02:01	2020-05-27	Son Sauer	son.sauer@woohoo.com	Daly City	California	210089990195778820	55e81945d87278a65f8d3c5acc0b44f1	JCB 16 digit	37.6121355643883319	-122.386121633378792
27204	2020-05-27 02:14:45	2020-05-27	Geraldine Murray	geraldine.murray@warmmail.com	Los Angeles	California	4065262555285210	8ac0fee70c9be2651c00e1450fc0b443	JCB 15 digit	34.0459005306340714	-118.439030083733797
27205	2020-05-27 02:21:23	2020-05-27	Mr. Loring Greenfelder	mr.loring.greenfelder@geemail.com	New York	New York	53904898772588285	a32a74b866c5037118f233d2cf31215f	Mastercard	40.6913895671479366	-73.9254202252615187
27206	2020-05-27 02:30:36	2020-05-27	Dr. Blanchie Daugherty	dr.blanchie.daugherty@geemail.com	Cleveland	Ohio	210075617750540511	8000259ddc1e563abf5113f5d1f80138	American Express	41.3795335071477979	-81.7762292328529128
27207	2020-05-27 02:47:19	2020-05-27	Rusty Johns IV	rusty.johns.iv@geemail.com	Waco	Texas	55060069685675581	9377aa7c79bffc76f5a611bb313a77cf	American Express	31.5733657116744659	-97.2751952280420937
27208	2020-05-27 02:51:57	2020-05-27	Dr. Lester Emmerich III	dr.lester.emmerich.iii@woohoo.com	New York	New York	4034796394339918	12997fdc6602e3bee4577e09dafd29be	JCB 15 digit	40.6100949150267994	-73.9521642818011316
27209	2020-05-27 03:06:46	2020-05-27	Mr. Shaun Turcotte	mr.shaun.turcotte@woohoo.com	San Francisco	California	3088510411391993658	a8dd66645bd9e231a132d1028c51785f	JCB 16 digit	37.7670849911591162	-122.441002936707605
27210	2020-05-27 03:15:39	2020-05-27	Kian Kihn	kian.kihn@geemail.com	Berkeley	California	3088924363266194427	743b6817629bb842db74946fe7857aac	JCB 16 digit	37.8942085264007531	-122.307112647573817
27211	2020-05-27 03:16:12	2020-05-27	Rayfield Blick	rayfield.blick@geemail.com	San Francisco	California	4528472482280	5a897fd166f46a42974f89c05b721cd8	Voyager	37.7914278221332438	-122.415062477673303
27212	2020-05-27 03:16:52	2020-05-27	Terence Bruen DDS	terence.bruen.dds@geemail.com	Columbus	Ohio	4468896433894876	6377b5678b4ca49185c50af8667f3b0e	JCB 16 digit	40.0748028146613393	-83.06520963602253
27213	2020-05-27 03:27:32	2020-05-27	Ronan Zieme PhD	ronan.zieme.phd@geemail.com	Lexington	Kentucky	869927498131498516	9191e24866459e8e71d6edbe408eb402	Voyager	38.0152602275710549	-84.3859599529664877
27214	2020-05-27 03:28:10	2020-05-27	Gino Koss	gino.koss@woohoo.com	Chicago	Illinois	6011545231652140180	324f8a37d0a962b6477f4c3f00f19287	VISA 16 digit	41.9337543010547762	-87.6611595298658983
27215	2020-05-27 03:29:49	2020-05-27	Nikita Beier DVM	nikita.beier.dvm@warmmail.com	New York	New York	639055313457982	12a175edb790881549ecef624a949e0a	JCB 16 digit	40.6020353101417442	-74.0115695371653857
27216	2020-05-27 03:33:11	2020-05-27	Raiden Buckridge-Labadie	raiden.buckridge.labadie@warmmail.com	Dallas	Texas	3096135903947591114	c110deb258b4b460ee97b26d075a542b	JCB 16 digit	32.8418307551454802	-96.7640173841230506
27217	2020-05-27 03:41:55	2020-05-27	Redden Franecki	redden.franecki@geemail.com	Oxnard	California	3112369874053657873	7fb6d45818317b6d8ac7162aa59ff1e2	VISA 16 digit	34.1787895270578588	-119.178842421146484
27218	2020-05-27 03:45:17	2020-05-27	Sarina Tremblay	sarina.tremblay@geemail.com	Irving	Texas	4510867384321035	4e41be15c07291c0f3e2f2437234d64f	JCB 15 digit	32.8606332398902623	-97.0253707574028539
27219	2020-05-27 03:49:09	2020-05-27	Shellie Feeney	shellie.feeney@geemail.com	Memphis	Tennessee	3088502693595134391	98dc6318edef79fdc4a638ee2c83d7c1	Diners Club / Carte Blanche	35.1808123597476623	-89.8933706223756133
27220	2020-05-27 04:04:30	2020-05-27	Harlan Aufderhar	harlan.aufderhar@geemail.com	Columbus	Ohio	51450713029492678	38a7da01149ee3453c151c59c47c381c	VISA 13 digit	40.0070110755551624	-83.0129135533470759
27221	2020-05-27 04:10:37	2020-05-27	Kyrie Cormier	kyrie.cormier@geemail.com	New York	New York	3112419728815684841	bc0add956cb2621ad3cdd5acedcd6ff7	VISA 13 digit	40.6080082534104605	-73.9522073343757569
27222	2020-05-27 04:13:27	2020-05-27	Cosmo Franecki	cosmo.franecki@geemail.com	Kansas City	Missouri	4122841251939	c7100cbf63ee15950459330fd45cc119	JCB 16 digit	39.0386621088091346	-94.6344494476206677
27223	2020-05-27 04:22:26	2020-05-27	Mr. Easton Wiza	mr.easton.wiza@geemail.com	Kent	Washington	4161047864195256	eb11e42cd8c288e0d0d7bcd89a63ce8a	Maestro	47.2900385864656414	-122.200908890333764
27224	2020-05-27 04:22:38	2020-05-27	Miles Denesik V	miles.denesik.v@woohoo.com	Omaha	Nebraska	869965982303125067	283e5248425bc8da7e31c987b8765a2c	JCB 16 digit	41.2534067171305452	-96.0229638621326558
27225	2020-05-27 04:22:55	2020-05-27	Asberry Halvorson DDS	asberry.halvorson.dds@geemail.com	San Francisco	California	4435267123620387	70c9d63d60d1992ead9956001f65cf5b	JCB 16 digit	37.7711277893476876	-122.444736006789952
27226	2020-05-27 04:43:26	2020-05-27	Jo Schmidt	jo.schmidt@warmmail.com	New York	New York	589328668088173	3c45013f6b52f9bd21d41aa9645b1361	VISA 13 digit	40.666538405999539	-73.9669801466993988
27227	2020-05-27 04:45:09	2020-05-27	Verona Hand MD	verona.hand.md@geemail.com	Pittsburgh	Pennsylvania	3528761446388093530	a23d12d233fe2694e6b99bf70af79181	JCB 16 digit	40.351553656249493	-79.9221516084563035
27228	2020-05-27 04:48:48	2020-05-27	Tabitha Aufderhar	tabitha.aufderhar@woohoo.com	Anchorage	Alaska	675975330301435	49370486362020903ec4a20e751a60bd	VISA 16 digit	61.0818165772344912	-149.282577912708007
27229	2020-05-27 05:00:48	2020-05-27	Mrs. Janette Lindgren DVM	mrs.janette.lindgren.dvm@woohoo.com	Toledo	Ohio	676270667738309	c47cd7224c25e99d05b55f3355c76eac	JCB 16 digit	41.5897999078672385	-83.5019410289224311
27230	2020-05-27 05:05:49	2020-05-27	Pollie Fadel	pollie.fadel@geemail.com	Chicago	Illinois	3112997117427009789	9b4cc305d6811298d302a14bd84cc0ec	Voyager	41.7379404709976214	-87.7121085159044611
27231	2020-05-27 05:06:27	2020-05-27	Meredith Stamm-Beahan	meredith.stamm.beahan@woohoo.com	New York	New York	53163337056090573	27d1b151d277695db664cb0d5d5e1c05	Mastercard	40.702664086850362	-74.0037416827294976
27232	2020-05-27 05:10:44	2020-05-27	Eulah Bernhard	eulah.bernhard@geemail.com	West Palm Beach	Florida	869951229922436509	f5419172558d81023128c466e7877f22	Discover	26.7201333607859937	-80.0818246566526568
27233	2020-05-27 05:19:42	2020-05-27	Mena Frami	mena.frami@woohoo.com	Boston	Massachusetts	6011361259384314311	5f869d2be5b2e76fe091d136c40a6a57	VISA 16 digit	42.376201886840164	-71.0932777054559466
27234	2020-05-27 05:29:33	2020-05-27	Mrs. Savilla Bartoletti DVM	mrs.savilla.bartoletti.dvm@geemail.com	St. Petersburg	Florida	6011144942079631529	826f8e658bdccaf36ae2384c89faaa10	JCB 16 digit	27.8262830055207004	-82.6259106040824207
27235	2020-05-27 05:30:10	2020-05-27	Kris Kunze	kris.kunze@geemail.com	Atlanta	Georgia	4214216684840766	1f7f1cc6f9190dde9484600ea69625e2	Discover	33.7944168236847986	-84.4418162677481803
27236	2020-05-27 05:30:16	2020-05-27	Elenor Schmeler	elenor.schmeler@geemail.com	Frisco	Texas	3337840478320956339	5a688e6c4d2573ec5909bf7a4ab44532	JCB 16 digit	33.1026884121816636	-96.8144629680760147
27237	2020-05-27 05:30:53	2020-05-27	Ms. Danna Skiles	ms.danna.skiles@geemail.com	New York	New York	6011561756394491318	2b0e107d4dba3800eb73993d5424b2f6	American Express	40.7044173885360365	-74.0276398094266597
27238	2020-05-27 05:32:27	2020-05-27	Mr. Jeremie Anderson	mr.jeremie.anderson@warmmail.com	Phoenix	Arizona	210061294074160404	851cfc794b8ce4789b94bce268d3d304	Maestro	33.5032688273515546	-112.177454865111415
27239	2020-05-27 05:39:10	2020-05-27	Sebrina Runolfsdottir	sebrina.runolfsdottir@geemail.com	Dallas	Texas	3528859108299178387	234066eb8113916d93f39faca6c81f03	VISA 13 digit	32.7398719685889787	-96.6989954067822453
27240	2020-05-27 05:42:31	2020-05-27	Mr. Canyon Veum V	mr.canyon.veum.v@geemail.com	Beaumont	Texas	3744191158254891	81bae8f13d6deab732c4372d89513458	VISA 13 digit	30.0278249981418277	-94.2437602998942197
27241	2020-05-27 05:43:11	2020-05-27	Jaden Kovacek	jaden.kovacek@geemail.com	Tempe	Arizona	4271396216575369	cb92da1c3777bc5ed19ea206ccd6b90a	VISA 16 digit	33.32262418278642	-111.911698906871678
27242	2020-05-27 05:54:51	2020-05-27	Luciana Abbott	luciana.abbott@geemail.com	Tucson	Arizona	4560863922596005	00cac301c4df9bb3d1e38501dd850e75	VISA 16 digit	32.1274228528182988	-110.924242027219748
27243	2020-05-27 05:56:28	2020-05-27	Hugo Parisian	hugo.parisian@warmmail.com	New York	New York	6011678799192426904	f04013929b668d376d13eea5bab882d5	JCB 15 digit	40.5776955531667909	-73.9504863322608088
27244	2020-05-27 06:00:38	2020-05-27	Mrs. Lillis Spinka DDS	mrs.lillis.spinka.dds@geemail.com	San Antonio	Texas	52515971935744060	3efe26af57ecd5be9d4a2af3b911884d	Mastercard	29.4266420768644679	-98.5830393999651022
27245	2020-05-27 06:03:42	2020-05-27	Andrea Skiles	andrea.skiles@geemail.com	Chesapeake	Virginia	869950646624137740	f82a8500b1ade882494c9e7ebc216edb	Diners Club / Carte Blanche	36.5988987748283918	-76.3649322314031451
27246	2020-05-27 06:21:32	2020-05-27	Tricia Adams	tricia.adams@geemail.com	Boise	Idaho	4084015901007895	cd857d96a8dc2a2888a934cec18deb9b	JCB 16 digit	43.6129748150844136	-116.274265361550079
27247	2020-05-27 06:43:51	2020-05-27	Victory Roob	victory.roob@geemail.com	Santa Ana	California	3096277803025634836	589d8eb5ca8a853c96e0e724b7e5c674	Diners Club / Carte Blanche	33.7352469851832808	-117.895821383774276
27248	2020-05-27 06:45:26	2020-05-27	Iva Stiedemann	iva.stiedemann@woohoo.com	Chula Vista	California	3468185757268170	1a7cbbfb764407875aa124e79aafa57b	American Express	32.5668565693076673	-116.927502972283207
27249	2020-05-27 06:49:30	2020-05-27	Dr. Keshawn D'Amore	dr.keshawn.d'amore@woohoo.com	New York	New York	3088924925534054474	5832cf57898231ac0a6d97b3ae8613d1	Mastercard	40.652701091043653	-73.9431282360933722
27250	2020-05-27 06:50:41	2020-05-27	Cori Mills	cori.mills@geemail.com	Oakland	California	210067373652663973	4b5985b34466a883028e79f7edab3bba	Voyager	37.8264345601724727	-122.262431889088802
27251	2020-05-27 06:51:39	2020-05-27	Miss Opha Will PhD	miss.opha.will.phd@geemail.com	Springfield	Illinois	3032313235580896	8664d57be444997b284c02e628192625	JCB 16 digit	39.8560688342120528	-89.5830236485231666
27252	2020-05-27 07:01:53	2020-05-27	Ashlee Von	ashlee.von@woohoo.com	Spokane	Washington	3458054591152408	d6d4f7311e5fc144aa13089e3aaa3ab9	VISA 16 digit	47.7018662102293192	-117.500143210859221
27253	2020-05-27 07:07:26	2020-05-27	Jolene Monahan	jolene.monahan@geemail.com	Cincinnati	Ohio	4347646586087308	82df28105ad34a7eea09b90a55c36320	VISA 16 digit	39.103381019993499	-84.5319028778273491
27254	2020-05-27 07:12:39	2020-05-27	Dee Murazik	dee.murazik@geemail.com	Los Angeles	California	869955607110674393	ff1157384c53bd2d5ed77df1bc15e76d	VISA 16 digit	34.0848438254889103	-118.47198566025979
27255	2020-05-27 07:13:23	2020-05-27	Evertt Larkin-Schaefer	evertt.larkin.schaefer@geemail.com	Las Cruces	New Mexico	54868820082251424	52541be6e4c9adb568eb31d387f71150	Mastercard	32.4251350096926103	-106.739432401408251
27256	2020-05-27 07:32:52	2020-05-27	Mr. Ahmad Walsh DVM	mr.ahmad.walsh.dvm@warmmail.com	Indianapolis	Indiana	3706365606776376	f7d35463b900cd3f253474a0b2bb005e	Diners Club / Carte Blanche	39.8255842541351868	-86.0954154220610803
27257	2020-05-27 07:36:38	2020-05-27	Claus Morar	claus.morar@warmmail.com	San Francisco	California	3034370624346485	59b159d8117ed732151b2e76fa1250a5	Voyager	37.7904339316796651	-122.445802155792649
27258	2020-05-27 07:50:51	2020-05-27	Dr. Kaycee Kassulke DDS	dr.kaycee.kassulke.dds@geemail.com	Miami	Florida	180003092284910191	3f27e37d41cd7d0f477bcc81dd15b6d8	JCB 16 digit	25.8223379255875969	-80.2356664114970783
27259	2020-05-27 08:02:33	2020-05-27	Isaac Emard II	isaac.emard.ii@geemail.com	Clarksville	Tennessee	3042527212321079	5915bb65a4cb8181f5ef0801a53a6127	JCB 16 digit	36.5417843059763356	-87.4205231515176706
27260	2020-05-27 08:05:13	2020-05-27	Jacque Howe	jacque.howe@geemail.com	Chicago	Illinois	3158896559296184932	77b4a1c6562dd65b9b4f74f5d6a5ffff	Discover	41.7607867275666464	-87.6029682118941082
27261	2020-05-27 08:40:32	2020-05-27	Everette Trantow IV	everette.trantow.iv@geemail.com	Arlington	Texas	869923380300148763	2fd712b85b4b1cccd65d72aad38d2a07	VISA 16 digit	32.6627170726906471	-97.1241588644243876
27262	2020-05-27 08:48:57	2020-05-27	Mr. Isaak Terry PhD	mr.isaak.terry.phd@geemail.com	Winston–Salem	North Carolina	6011471612403165428	f9954862510cbc74da727d1cfb449f12	VISA 16 digit	36.121976280701162	-80.3027118886951286
27263	2020-05-27 09:01:19	2020-05-27	Tammy Mante	tammy.mante@geemail.com	Lansing	Michigan	3418146716973558	0e1609e0f2ce96d2fe83cb81288d8ea4	VISA 16 digit	42.6911591658212259	-84.4783431624185255
27264	2020-05-27 09:05:45	2020-05-27	Boss Tremblay	boss.tremblay@geemail.com	Orlando	Florida	6011562651725135834	93f3c3dddb6f1b060be90e11cc61852d	JCB 16 digit	28.5039376377858211	-81.2577718203388173
27265	2020-05-27 09:06:30	2020-05-27	Aarav Connelly	aarav.connelly@geemail.com	Baltimore	Maryland	589303192534190	0a3e0ca1b403edc33198da4c9df2961b	VISA 13 digit	39.2711735702585401	-76.5910421003140556
27266	2020-05-27 09:15:23	2020-05-27	Tex Lockman	tex.lockman@geemail.com	Raleigh	North Carolina	55204748240665131	ba334d8c7b7c994b30878d417782c7e7	VISA 16 digit	35.8785873507283597	-78.7214103716827935
27267	2020-05-27 09:36:41	2020-05-27	Ms. Jaylen Schmitt	ms.jaylen.schmitt@warmmail.com	Detroit	Michigan	3048941495072446	6e01fe00b47a37a19b548a3a272d964a	JCB 15 digit	42.4684848662856993	-83.1103690317019783
27268	2020-05-27 09:58:03	2020-05-27	Dionte Haag II	dionte.haag.ii@geemail.com	Fayetteville	North Carolina	3016176196415246	d7f8fbb170172747d7fba198912faef9	VISA 16 digit	35.1605992195449772	-78.8917657790835989
27269	2020-05-27 09:58:07	2020-05-27	Mr. Arlo Senger	mr.arlo.senger@woohoo.com	Wichita	Kansas	501821113288290	6792ab5ac769b110424daa412f7f449f	VISA 16 digit	37.6600719845265175	-97.2646254889402542
27270	2020-05-27 09:58:46	2020-05-27	Porsche O'Reilly-Weimann	porsche.o'reilly.weimann@geemail.com	Denver	Colorado	3416127556402207	bb670dee831de70dba356e3dced85832	VISA 16 digit	39.6897164215851532	-104.950079361467061
27271	2020-05-27 10:00:03	2020-05-27	Mr. Hence Gleichner	mr.hence.gleichner@woohoo.com	Irving	Texas	3767569151976341	cf007e893a3afc4f661ba7e6e8a47342	JCB 15 digit	32.8805353579528656	-96.9526555169187532
27272	2020-05-27 10:05:44	2020-05-27	Luisa Bayer DDS	luisa.bayer.dds@geemail.com	Santa Ana	California	4928188640452621	ae243e82a418b79acc123e75e9f84b59	VISA 16 digit	33.8240800203859777	-117.89684585560299
27273	2020-05-27 10:14:14	2020-05-27	Courtney Bahringer	courtney.bahringer@geemail.com	McAllen	Texas	53064840116601768	784a5058161a188352d4a1e312c2178d	Voyager	26.166762413999809	-98.2040326451729868
27274	2020-05-27 10:15:58	2020-05-27	Sarrah Weber	sarrah.weber@geemail.com	Kenosha	Wisconsin	3030508304177969	22cfd90eb63502ffdcadff83f8628b58	VISA 16 digit	42.5759898539006727	-87.8368643907591746
27275	2020-05-27 10:18:06	2020-05-27	Donna Larkin	donna.larkin@warmmail.com	Sacramento	California	180048202063064212	76c65a7ec7576140be8bef7f6ef71166	JCB 16 digit	38.5342543378736835	-121.412410734199355
27276	2020-05-27 10:21:56	2020-05-27	Raquan Lynch	raquan.lynch@geemail.com	Palmdale	California	180060014716782279	76a9265ebdeada3e6a707e3a6d9335a7	JCB 15 digit	34.6362441496774593	-118.105779836512738
27277	2020-05-27 10:27:24	2020-05-27	Mr. Waverly Glover	mr.waverly.glover@warmmail.com	Houston	Texas	3719191718060862	2c5929e3f3ff8e39ea1f76f1f9f2b93c	Voyager	29.7440441785924143	-95.3067037554938423
27278	2020-05-27 10:38:27	2020-05-27	Mrs. Virdie Brakus DDS	mrs.virdie.brakus.dds@geemail.com	San Francisco	California	3158189366643485368	a81eab15eef018a6dc6b7feb7b257358	Voyager	37.7542236845210297	-122.444155481953757
27279	2020-05-27 10:49:43	2020-05-27	Dr. Love Collier	dr.love.collier@geemail.com	Los Angeles	California	3477002733366516	78771afe492ad151d9ef910519435eae	Diners Club / Carte Blanche	34.0351461087219391	-118.362760788806895
27280	2020-05-27 10:58:03	2020-05-27	Miss Ellamae Kub	miss.ellamae.kub@warmmail.com	Plano	Texas	3797695358961374	7eb1235952bc12a0ba77caf31fef7b15	VISA 16 digit	33.0717573725238481	-96.6952104034084812
27281	2020-05-27 11:01:09	2020-05-27	Lashunda Padberg DDS	lashunda.padberg.dds@warmmail.com	Oakland	California	3096338498698606968	731d65b93fbfd86634f1ba9a92585ffb	Maestro	37.8035448914874976	-122.245208394071739
27282	2020-05-27 11:05:25	2020-05-27	Javier Howell	javier.howell@geemail.com	Buffalo	New York	4699364291899769	3b09e9fb01c7d8688c183579565b1a4c	VISA 16 digit	42.833267241921277	-78.8512288255084286
27283	2020-05-27 11:06:15	2020-05-27	Alwilda O'Hara	alwilda.o'hara@woohoo.com	San Francisco	California	6011702186083008019	2cb188e2c7207ce60967da084c0ee8f7	Mastercard	37.7557281696949332	-122.38644993054163
27284	2020-05-27 11:20:16	2020-05-27	Ryan McDermott	ryan.mcdermott@geemail.com	San Diego	California	4207380991626687	3e5afc643f0d795b77fb8e32f1fc446e	VISA 16 digit	32.8957281568154727	-117.149358143555006
27285	2020-05-27 11:36:09	2020-05-27	Arley Prohaska	arley.prohaska@warmmail.com	New York	New York	4593286620311413	e49529079e3aa203fef8da35012bc231	Diners Club / Carte Blanche	40.6287786081191129	-73.9408693754009931
27286	2020-05-27 11:43:42	2020-05-27	Ms. Marlyn Hoppe	ms.marlyn.hoppe@geemail.com	Daly City	California	3492833423216509	517edf326dc396b1fb7537fca21821f3	Mastercard	37.7074944322384837	-122.540498566124597
27287	2020-05-27 11:55:22	2020-05-27	Thos Reinger I	thos.reinger.i@geemail.com	Colorado Springs	Colorado	589350977861454	ecebecce905feb54c6e569108fa86d60	American Express	38.9631529682364288	-104.804720658452069
27288	2020-05-27 12:07:58	2020-05-27	Gannon Stanton	gannon.stanton@geemail.com	Detroit	Michigan	53636110794640507	105261c2e64f3651100aef9a41b2d672	Discover	42.3855824710261118	-83.0054326838001515
27289	2020-05-27 12:13:14	2020-05-27	Mrs. Shirlie Buckridge	mrs.shirlie.buckridge@geemail.com	San Jose	California	4055884820504539	d0ba672bbddd422488ed710614ba0e2b	Mastercard	37.2571199841618537	-121.8093849756509
27290	2020-05-27 12:19:41	2020-05-27	Carmen Braun	carmen.braun@geemail.com	Los Angeles	California	4455460868611	49aa79e26129b6ee77fd1c9ea7a5dd24	VISA 16 digit	34.070169423367453	-118.3819477831006
27291	2020-05-27 12:26:08	2020-05-27	Miss Karel Ernser DDS	miss.karel.ernser.dds@geemail.com	New York	New York	4189580637394226	f66d8dc7bcd73506a870028820c9eea9	American Express	40.7209099175631977	-73.854182083987439
27292	2020-05-27 12:42:56	2020-05-27	Robby Sipes	robby.sipes@geemail.com	Plano	Texas	210064889823108278	a7de27cc25a85ce01c29f1f671620548	American Express	32.9900331582028414	-96.825364817697178
27293	2020-05-27 12:47:03	2020-05-27	Scott Heaney	scott.heaney@warmmail.com	Reno	Nevada	3337907270589075483	c97acf1f0cacc5135f5368e0ecf9fd62	JCB 16 digit	39.5209685706146061	-119.810261333377667
27294	2020-05-27 12:47:35	2020-05-27	Cloyd Nicolas	cloyd.nicolas@geemail.com	Detroit	Michigan	3112950211392557552	038e6d8c62fdeea05640972d6f0a99cd	Mastercard	42.3631023246254799	-83.1487884517878229
27295	2020-05-27 12:51:36	2020-05-27	Caitlynn Gislason MD	caitlynn.gislason.md@geemail.com	Indianapolis	Indiana	4587594270161394	8cd530b1931c03a24c7f5366bb0ee200	VISA 16 digit	39.8034735450062911	-86.2330081511024389
27296	2020-05-27 12:52:29	2020-05-27	Claudia Muller	claudia.muller@geemail.com	Long Beach	California	4133920411708	f974c331e98aa0b5b241d59558d30870	VISA 13 digit	33.7161316402543321	-118.189573479552934
27297	2020-05-27 12:54:38	2020-05-27	Leandra Rosenbaum	leandra.rosenbaum@geemail.com	Green Bay	Wisconsin	3112771671656810939	df6ac54495de20f7e4098a2e648cf2de	Diners Club / Carte Blanche	44.5688962849851649	-87.9622042426660613
27298	2020-05-27 12:56:48	2020-05-27	Bobbie Kemmer	bobbie.kemmer@geemail.com	Irving	Texas	210042712068390723	410a468cebe91fce8c8acadfce33de1e	JCB 16 digit	32.9272302663370979	-97.0012882429920182
27299	2020-05-27 12:56:54	2020-05-27	Deonta Reichert	deonta.reichert@geemail.com	San Francisco	California	4983457079979285	0feb0c34a008f71e959399c2744982cb	Diners Club / Carte Blanche	37.7676386093082712	-122.437160044058388
27300	2020-05-27 13:04:52	2020-05-27	Hjalmar Hettinger	hjalmar.hettinger@geemail.com	Thornton	Colorado	869961885263995243	a96a15378ceec7194f6f20a9b17fe844	VISA 16 digit	39.9766920834180013	-104.951133380799746
27301	2020-05-27 13:07:40	2020-05-27	Harvey Franecki	harvey.franecki@geemail.com	Seattle	Washington	3761234546471633	87b0c0193a3c2ac882daa38a687f585c	American Express	47.7146169031430034	-122.364526369833939
27302	2020-05-27 13:16:24	2020-05-27	Ira Ebert	ira.ebert@geemail.com	Pittsburgh	Pennsylvania	54751833750969433	4d9f150b002e5b7679cf0c2657279a4e	VISA 13 digit	40.3871730273544784	-80.063550021283703
27303	2020-05-27 13:22:14	2020-05-27	Dr. Wilhelm McLaughlin	dr.wilhelm.mclaughlin@geemail.com	San Francisco	California	3735272840289114	1f138d0c1f1ec39abe559e656b0a7830	JCB 15 digit	37.7369376963823981	-122.454529794498882
27304	2020-05-27 13:28:27	2020-05-27	Elmira Purdy	elmira.purdy@geemail.com	San Francisco	California	6011925428369869008	c2d87f34ef29986b75f32232d4375363	Voyager	37.7801509020212691	-122.419743223597308
27305	2020-05-27 13:32:30	2020-05-27	Gerald Lubowitz	gerald.lubowitz@woohoo.com	Dayton	Ohio	4545389514058253	00da2999c673dd2bf9f726182073c3ed	JCB 16 digit	39.7599056691654056	-84.1166380479190536
27306	2020-05-27 13:32:33	2020-05-27	Alethea Satterfield MD	alethea.satterfield.md@woohoo.com	Los Angeles	California	6011470014006965091	f8302c02823ef357f87e5bdb8e9df7d0	VISA 13 digit	33.9664377578865739	-118.474207350657508
27307	2020-05-27 13:49:03	2020-05-27	Enola Schmeler-Simonis	enola.schmeler.simonis@geemail.com	Columbus	Georgia	4710863230305163	05c74ddf93c075791ba546842050a068	Diners Club / Carte Blanche	32.5608727248895917	-84.8629713739898079
27308	2020-05-27 13:52:56	2020-05-27	Wayland Feeney	wayland.feeney@geemail.com	Long Beach	California	3337890699843178171	e57de864f615f0b37c649171eb2de38b	JCB 16 digit	33.9040661458212824	-118.073000240807602
27309	2020-05-27 13:53:06	2020-05-27	Franco Buckridge-Zulauf	franco.buckridge.zulauf@geemail.com	West Jordan	Utah	3409287766703080	c9b8aad2d1f382425e00401ea0b3cbfe	Mastercard	40.5433844100475369	-112.091689217192311
27310	2020-05-27 13:57:41	2020-05-27	Dr. Merry Denesik DVM	dr.merry.denesik.dvm@geemail.com	New York	New York	6011205172757239009	6b9207a28a08d1b1b75c1ad7496bea34	VISA 16 digit	40.7591353858113266	-73.9951270054455819
27311	2020-05-27 14:01:35	2020-05-27	Tallie Nikolaus	tallie.nikolaus@geemail.com	San Francisco	California	589369320513190	00972969efc9462008c5b522ec54be5d	VISA 16 digit	37.7440872594278076	-122.411631845206117
27312	2020-05-27 14:02:31	2020-05-27	Williams Heathcote PhD	williams.heathcote.phd@geemail.com	Rialto	California	3528765433094453196	2eb859ee6337644f54bd58c1552ce325	JCB 16 digit	34.2003258979164073	-117.441828027795253
27313	2020-05-27 14:05:33	2020-05-27	Catina Nitzsche	catina.nitzsche@geemail.com	Cambridge	Massachusetts	6011758288601106045	bf2430efc10ced9b055afcdc9a3f2934	VISA 16 digit	42.420480249052865	-71.1984163687180711
27314	2020-05-27 14:24:11	2020-05-27	Carl Shanahan	carl.shanahan@geemail.com	Chicago	Illinois	4274289081521765	bc4695161b9d67e8a090fa6f4bae575b	JCB 16 digit	41.8549254270572249	-87.640043871713047
27315	2020-05-27 14:24:32	2020-05-27	Herschel Medhurst	herschel.medhurst@geemail.com	Miami	Florida	675959725254086	c629a9fefc9104203a5ca1d641ff7ea6	Mastercard	25.6934582176756123	-80.234218369039155
27316	2020-05-27 14:27:06	2020-05-27	Kaycee D'Amore	kaycee.d'amore@geemail.com	San Francisco	California	4235969351164	ac34849049bae48507e918f7317874a8	JCB 16 digit	37.7726894017085826	-122.422968950849807
27317	2020-05-27 14:49:58	2020-05-27	Mr. Tyler Durgan Sr.	mr.tyler.durgan.sr.@warmmail.com	Chicago	Illinois	676378327486474	8913ac7f173835f22d0b560e8dcec692	Diners Club / Carte Blanche	41.9164357083685744	-87.5952037739597245
27318	2020-05-27 14:56:50	2020-05-27	Miss Hildegarde Ratke	miss.hildegarde.ratke@warmmail.com	San Francisco	California	060474890119824	7b86ff5786aef0705d38c14ad034b9fe	Discover	37.8081539590272371	-122.460637275776918
27319	2020-05-27 15:02:18	2020-05-27	Leighton Shields	leighton.shields@geemail.com	Berkeley	California	51798419436972986	67810a8d56688b8e0bcbbb8371ab09f0	Diners Club / Carte Blanche	37.8921348791628105	-122.252966201003346
27320	2020-05-27 15:03:10	2020-05-27	Stewart Bednar	stewart.bednar@geemail.com	Frisco	Texas	3458263308647499	68bd1148008ad675f8767546c47a3048	JCB 16 digit	33.183298896019906	-96.8746606013946234
27403	2020-05-28 00:28:13	2020-05-28	Winnifred Koss-Lesch	winnifred.koss.lesch@geemail.com	Houston	Texas	869998313210843041	bbb2ea0c02475714a681cf3b4d090250	Discover	29.8858895163130001	-95.3144262203496027
27321	2020-05-27 15:05:52	2020-05-27	Meaghan Jerde-Hudson	meaghan.jerde.hudson@geemail.com	San Francisco	California	4059468454603126	47023255edc6395aaf56113b56d7eec9	JCB 16 digit	37.7790722883505552	-122.420747886475908
27322	2020-05-27 15:15:11	2020-05-27	Jose Murray	jose.murray@geemail.com	El Paso	Texas	3008574651897247	f3c9d238d41f21a6a2f8317694eb37a5	JCB 15 digit	31.8264362927354902	-106.481560718778525
27323	2020-05-27 15:15:25	2020-05-27	Mr. Douglas Greenholt DVM	mr.douglas.greenholt.dvm@woohoo.com	Yonkers	New York	4898369662465776	bfdd1f8b6c623c762c571c3ab5ff6799	JCB 15 digit	40.9609464199483426	-73.9521356576006923
27324	2020-05-27 15:20:07	2020-05-27	Mr. Ewald Pagac	mr.ewald.pagac@geemail.com	Chandler	Arizona	4680365048718	810bf46d0326cbbaf6f45500972de716	American Express	33.3046620762530665	-111.921848987636722
27325	2020-05-27 15:20:19	2020-05-27	Dr. Kendal Towne PhD	dr.kendal.towne.phd@geemail.com	Elgin	Illinois	869994542562341642	89db21091d4ae84f6b076fd7ca759b32	Maestro	42.1333861462589354	-88.2807482618194115
27326	2020-05-27 15:37:59	2020-05-27	Ceylon Crona III	ceylon.crona.iii@geemail.com	New York	New York	3337821228828649933	baf597928a2e30a693fc4b3d7d4d0703	VISA 13 digit	40.7521452764738328	-73.9514685591112766
27327	2020-05-27 15:42:10	2020-05-27	Stephenie Rice-Stoltenberg	stephenie.rice.stoltenberg@woohoo.com	Sunnyvale	California	6011472459184265046	8018c4beaa41b793094b9dc83503b73c	American Express	37.3637496802948448	-121.993630099409458
27328	2020-05-27 15:43:34	2020-05-27	Carli Swaniawski	carli.swaniawski@geemail.com	San Francisco	California	4180562206045	9184e89f8f1e786adb3e06b1fbd9e4c9	Maestro	37.7794655273449109	-122.454462472896736
27329	2020-05-27 16:04:59	2020-05-27	Tennie Goodwin-Quitzon	tennie.goodwin.quitzon@geemail.com	Chicago	Illinois	4824793428324663	f3db9b5ab72c7adbed7f7102020bbddd	VISA 16 digit	41.9113947566434746	-87.6565464765328812
27330	2020-05-27 16:08:27	2020-05-27	Roman Labadie V	roman.labadie.v@geemail.com	Bakersfield	California	6011819766836381761	e3e92ae6f2b61459c3122fed60d45980	JCB 16 digit	35.3014477549761523	-118.963802809947353
27331	2020-05-27 16:10:27	2020-05-27	Hermon Collier	hermon.collier@warmmail.com	Shreveport	Louisiana	4489318307028171	9aa894aaa879d83fcd6ff059ff5e7b4c	Mastercard	32.509932974004748	-93.6927236567929356
27332	2020-05-27 16:15:17	2020-05-27	Mr. Pinkney Yost	mr.pinkney.yost@geemail.com	San Francisco	California	6011075531040500211	55aff3a3631d17334bcd584117e9887d	Maestro	37.8115377920385001	-122.451350077657054
27333	2020-05-27 16:21:01	2020-05-27	Tera Heidenreich	tera.heidenreich@warmmail.com	Houston	Texas	54667598918882504	bd8754ba4d5cdb90d34a40378d228d40	Mastercard	29.8771468869954333	-95.4262355465456835
27334	2020-05-27 16:21:50	2020-05-27	Gaven Boyer	gaven.boyer@woohoo.com	Edison	New Jersey	3528347223520822107	543c89dd89a0752735419d4ebdd8a014	Voyager	40.4338302339389912	-74.4390264662034866
27335	2020-05-27 17:26:16	2020-05-27	Meggan McGlynn	meggan.mcglynn@geemail.com	Houston	Texas	3489385644085044	fae69a1421022a6dff711056ef275247	VISA 16 digit	29.827775950225444	-95.2938507867060594
27336	2020-05-27 17:28:58	2020-05-27	Misti King-Lynch	misti.king.lynch@woohoo.com	Tampa	Florida	3789066820642259	03650d2650075d620432e8f0e2a75da9	Discover	27.9591834204386913	-82.4413850369144114
27337	2020-05-27 17:34:32	2020-05-27	Fleet Schmidt	fleet.schmidt@geemail.com	Thornton	Colorado	210075269703926700	827a0247c377a69cfb24c00fa783f6e3	Voyager	39.8538044032041014	-104.904708615613359
27338	2020-05-27 17:36:30	2020-05-27	Delphin Feeney-Muller	delphin.feeney.muller@geemail.com	San Jose	California	3026752913192613	e88907909ff8e98d53185d9e747bf6f2	VISA 16 digit	37.3918287934090969	-121.726563092901927
27339	2020-05-27 17:39:30	2020-05-27	Jovita Schinner MD	jovita.schinner.md@geemail.com	Frisco	Texas	4240717511325234	fe8be8441ba2a9fecc44ec27d163c8a6	American Express	33.1174295996312082	-96.8388328363396198
27340	2020-05-27 17:40:38	2020-05-27	Osbaldo Hammes V	osbaldo.hammes.v@warmmail.com	Raleigh	North Carolina	501800962612735	83a9e3bf60777242b5a6a98b5f1dccc0	Diners Club / Carte Blanche	35.7396994455851598	-78.5476138539083308
27341	2020-05-27 17:56:27	2020-05-27	Kameron Padberg-Lueilwitz	kameron.padberg.lueilwitz@geemail.com	Phoenix	Arizona	3096110363387087025	ab8a6658b8020347049fa8bb60dd88f5	VISA 13 digit	33.6101344068933301	-112.130793857148291
27342	2020-05-27 18:04:48	2020-05-27	Jajuan Becker	jajuan.becker@geemail.com	Joliet	Illinois	3528227619175121148	b3ef536aa792b606519a3e003087498a	Discover	41.5299086475603261	-88.2132362153485303
27343	2020-05-27 18:15:35	2020-05-27	Kenley Sporer PhD	kenley.sporer.phd@geemail.com	Hayward	California	675945968310081	ee00be6f4589084dc198f83675bbc8ea	JCB 15 digit	37.5747581963881885	-122.164353892512253
27344	2020-05-27 18:53:59	2020-05-27	Madison Casper	madison.casper@warmmail.com	Santa Rosa	California	210090721005112265	85a9b05f0d99b161c58c64f914ef1c0f	JCB 16 digit	38.5369853980496586	-122.800298008906097
27345	2020-05-27 19:01:52	2020-05-27	Tomeka Davis	tomeka.davis@geemail.com	Gresham	Oregon	3096164885655757249	01830a29ac060def750cf4287723361f	Diners Club / Carte Blanche	45.4373211058277633	-122.454867811108372
27346	2020-05-27 19:10:06	2020-05-27	Ted Doyle	ted.doyle@geemail.com	Oklahoma City	Oklahoma	6011819598736074299	cd6a90a9dc6bddff87819f21580889cd	VISA 13 digit	35.5089909331317983	-97.5402339299105137
27347	2020-05-27 19:21:25	2020-05-27	Rogelio Reynolds	rogelio.reynolds@warmmail.com	Ventura	California	53703757098931335	f5c9ed5adf08d0840fa612e5a4172af2	Mastercard	34.2144391373425734	-119.277854976906255
27348	2020-05-27 19:23:26	2020-05-27	Blanch Eichmann	blanch.eichmann@warmmail.com	Chicago	Illinois	180055437093502365	0373ca464e1f6e6976358cfe15abf5bc	VISA 16 digit	41.8239963918294748	-87.5935468902375476
27349	2020-05-27 19:39:20	2020-05-27	Lynn Hartmann	lynn.hartmann@geemail.com	Odessa	Texas	180091398725814394	44fb5d1121c45143cd497a2b8c16e52d	Diners Club / Carte Blanche	31.9589475174445674	-102.362400061466175
27350	2020-05-27 19:45:36	2020-05-27	Loran Mohr	loran.mohr@geemail.com	Charlotte	North Carolina	3008601965193656	0bdd6be7bd0e88ef20252a4e9e156756	Maestro	35.1983519849155115	-80.7312374339383183
27351	2020-05-27 19:50:38	2020-05-27	Miss Alysia O'Connell	miss.alysia.o'connell@geemail.com	Miami	Florida	3158092358528684039	010a137ab4faab9628d0f77a687e0132	JCB 16 digit	25.803621655017885	-80.2199099879585305
27352	2020-05-27 19:54:19	2020-05-27	Ms. Kiyoko Krajcik	ms.kiyoko.krajcik@warmmail.com	Houston	Texas	3427547932926032	c7023edb6dac5dda38a3c045451d619b	VISA 13 digit	29.8337450418233878	-95.3050581373754966
27353	2020-05-27 19:55:52	2020-05-27	Bud Larson	bud.larson@geemail.com	New York	New York	54884775699655641	e951e001cfa6ee44c3b21a6e6fec9a1f	Diners Club / Carte Blanche	40.7559880669452212	-73.9012976770184906
27354	2020-05-27 20:08:36	2020-05-27	Ansel Ward-Treutel	ansel.ward.treutel@woohoo.com	Santa Clarita	California	55416805979987005	5f46639430c54b03fb4b28a36bc5763b	Mastercard	34.425792368661611	-118.540851793308548
27355	2020-05-27 20:09:16	2020-05-27	Elliana Ferry-Buckridge	elliana.ferry.buckridge@geemail.com	Mesquite	Texas	3033405771502273	c80b2cb556c95da65ce137e6b1a8625d	Voyager	32.6880069301273721	-96.5735163543105131
27356	2020-05-27 20:11:14	2020-05-27	Vikki Murphy-Kuhic	vikki.murphy.kuhic@warmmail.com	San Francisco	California	3729381491445558	b7a91b016b8cf31fb4d0da06f7382ca9	Diners Club / Carte Blanche	37.751232387913106	-122.428504389837641
27357	2020-05-27 20:12:06	2020-05-27	Caiden Little-Stracke	caiden.little.stracke@geemail.com	Fairfield	California	4348066354205363	71780b80e3ec711c9c6e7890b8916ebc	VISA 16 digit	38.2585183849215511	-122.105749170994756
27358	2020-05-27 20:18:24	2020-05-27	Hanna Lueilwitz	hanna.lueilwitz@geemail.com	South Bend	Indiana	3112318543152290751	1fce61e2d1c3e049150db7c74cf96ad0	JCB 15 digit	41.6952077125810092	-86.2684083804544173
27359	2020-05-27 20:23:50	2020-05-27	Jewell Legros-Kassulke	jewell.legros.kassulke@warmmail.com	Atlanta	Georgia	503821717287193	068249de4a8395bde999549bb5efccf1	VISA 13 digit	33.7463333844948608	-84.5024374856192679
27360	2020-05-27 20:26:04	2020-05-27	Darrel Hand	darrel.hand@geemail.com	Los Angeles	California	869994112361469794	bcf07febe2f8cbdbcbc1120b1e883013	American Express	34.0605953363567551	-118.447028819703675
27361	2020-05-27 20:27:59	2020-05-27	Garvin Graham	garvin.graham@warmmail.com	Shreveport	Louisiana	55308697191093493	e6c1752de8d13d80297be452b5918b0b	Mastercard	32.4575410123221602	-93.7629744168117583
27362	2020-05-27 20:41:38	2020-05-27	Otis Pfeffer-Boyle	otis.pfeffer.boyle@geemail.com	Los Angeles	California	4100351332057294	d9ac3dc92ca8cd9cbba4a090a1d2d985	VISA 16 digit	33.9751711583096494	-118.408175617129729
27363	2020-05-27 20:53:55	2020-05-27	Mrs. Maryann Yost DVM	mrs.maryann.yost.dvm@warmmail.com	Phoenix	Arizona	3096639477889351796	346f13ce66ebcae337c70a2346f66a4b	Voyager	33.5034181744258888	-112.018535667883611
27364	2020-05-27 20:54:41	2020-05-27	Murphy Heller	murphy.heller@warmmail.com	Richmond	Virginia	4487817565617882	f5d4e3aa12761d0d26b823f0b9ed4fee	JCB 16 digit	37.6307852439336443	-77.4026640017740419
27365	2020-05-27 20:55:01	2020-05-27	Dante Nitzsche	dante.nitzsche@geemail.com	Chula Vista	California	52800870650643628	559055c4a4e1c90d62424ba824615876	VISA 16 digit	32.684081642911579	-116.9685350976184
27366	2020-05-27 20:55:39	2020-05-27	Dona Price	dona.price@geemail.com	Bridgeport	Connecticut	4239907207165	30a6bf7a467931536435bde1219c9566	JCB 16 digit	41.1882193313144143	-73.2473047668945156
27367	2020-05-27 20:56:22	2020-05-27	Gasper Berge	gasper.berge@geemail.com	Chula Vista	California	3158152899154025655	d5a35b192bca63d37d2d932b08008585	VISA 16 digit	32.6894132645100299	-117.045974371279399
27368	2020-05-27 20:59:02	2020-05-27	Jamiya Hodkiewicz	jamiya.hodkiewicz@woohoo.com	New York	New York	869984899858042512	142be14fec893d4e677f04d942cdd882	Maestro	40.57226510599628	-73.9246676483552818
27369	2020-05-27 21:07:03	2020-05-27	Merwin Rogahn-Gerhold	merwin.rogahn.gerhold@geemail.com	Fargo	North Dakota	4684893865619	1e31a3a5e8f4a49a70ccee96e16f26bc	Discover	46.9584292135898025	-96.7321344959512288
27370	2020-05-27 21:15:10	2020-05-27	Kellen Rohan	kellen.rohan@geemail.com	Charlotte	North Carolina	53183752824640077	d2a35904f85e2a0c663b02acdc8fff34	Voyager	35.267034296297652	-80.7482359235119134
27371	2020-05-27 21:15:54	2020-05-27	Ernesto Treutel	ernesto.treutel@geemail.com	Concord	California	3009482546118580	490409a72e19bc55e98ab11e5839447c	VISA 16 digit	37.9099805116120763	-122.093527599022167
27372	2020-05-27 21:22:00	2020-05-27	Miss Kamryn Emmerich	miss.kamryn.emmerich@geemail.com	Arlington	Texas	676188492051193	a2ae26c535837fc23c43d6b178b10630	Discover	32.6180603862524023	-97.1320185400571745
27373	2020-05-27 21:22:39	2020-05-27	Madie Hyatt	madie.hyatt@warmmail.com	New York	New York	53656879831066562	08b239e21f865dcdfbc1107bf5296ae5	VISA 16 digit	40.7295893162246756	-74.0270686789311441
27374	2020-05-27 21:23:25	2020-05-27	Neha Lang	neha.lang@geemail.com	San Francisco	California	4244237559889	6d4868c0ffa3c1e34b0c08749762788b	Diners Club / Carte Blanche	37.7825467989848605	-122.438150858889841
27375	2020-05-27 21:23:55	2020-05-27	Jaeden Wolf	jaeden.wolf@geemail.com	Durham	North Carolina	4148663273944478	c4bcfb3e47658e9d287fc02e58460fef	JCB 16 digit	35.985309496872496	-79.0006004476357333
27376	2020-05-27 21:31:40	2020-05-27	Mrs. Gillie Stokes	mrs.gillie.stokes@geemail.com	New York	New York	6011088653373653451	1ea218835dc778ea1d635462d26e3bac	JCB 16 digit	40.5660395689532152	-73.9990303018026054
27377	2020-05-27 21:34:53	2020-05-27	Sharif Lockman-Gleichner	sharif.lockman.gleichner@warmmail.com	Little Rock	Arkansas	869967109676164055	5df388e049e6bbed85d87579aeae2f78	VISA 13 digit	34.7235015389785175	-92.3509679117113365
27378	2020-05-27 21:40:39	2020-05-27	Burnett Ernser PhD	burnett.ernser.phd@geemail.com	San Francisco	California	3096299781070318105	a6e963daec96eafa2fcfb9353dd320b7	JCB 16 digit	37.7795819402951309	-122.433282608897073
27379	2020-05-27 22:02:45	2020-05-27	Affie Kuhn	affie.kuhn@warmmail.com	Cleveland	Ohio	501890940828602	b409e4085425a589c13c3a76dec999a8	Voyager	41.4343143033646015	-81.6728366253670259
27380	2020-05-27 22:05:24	2020-05-27	Maia Schultz	maia.schultz@woohoo.com	San Bernardino	California	4632423761865	7b6ebeea7e0a88258740640e1b941827	American Express	34.0504082143571196	-117.300902343007181
27381	2020-05-27 22:13:36	2020-05-27	Yancy Mertz	yancy.mertz@geemail.com	Jacksonville	Florida	4819167385094121	dd8c01121ec792f6d179db447a31c643	American Express	30.3729367529559866	-81.621527708422775
27382	2020-05-27 22:16:36	2020-05-27	Allisson Koch	allisson.koch@geemail.com	Honolulu	Hawaii	52039313271066096	784b288ca736f612345c2c047bf817a1	Discover	21.2639746315527702	-157.927861369887751
27383	2020-05-27 22:25:31	2020-05-27	Geralyn Emard	geralyn.emard@warmmail.com	Los Angeles	California	676341818676615	3b9f90ec25302d4888845bf13c1668e1	Diners Club / Carte Blanche	34.0515930183097666	-118.323399544040853
27384	2020-05-27 22:26:01	2020-05-27	Iris Thiel	iris.thiel@geemail.com	Milwaukee	Wisconsin	6011926279474626737	117eaafb1fa138f9c9adad415a429688	Mastercard	43.1095701274547736	-88.0140956526722817
27385	2020-05-27 22:29:07	2020-05-27	Dakotah Nienow Jr.	dakotah.nienow.jr.@geemail.com	Boston	Massachusetts	3528395857664501356	0de339cdee0898a4e7a9d6b26c0678ef	JCB 16 digit	42.3933973872270471	-70.9841578022994071
27386	2020-05-27 22:38:54	2020-05-27	Katheryn Oberbrunner	katheryn.oberbrunner@geemail.com	Memphis	Tennessee	4611691688091	ea3b30c584651c0d85e49010a75a9060	Diners Club / Carte Blanche	35.0519085232235525	-89.9210229476705223
27387	2020-05-27 22:56:37	2020-05-27	Tawny Hodkiewicz	tawny.hodkiewicz@geemail.com	Dallas	Texas	4074941354527968	031b566198900edac431a46cbf57ac6b	Maestro	32.7791896213118008	-96.7634547892920551
27388	2020-05-27 23:00:51	2020-05-27	Taurean Wolf	taurean.wolf@warmmail.com	Columbus	Ohio	3045997875762694	1a2ac1b2dd30d116ebc20e902110ad7e	JCB 16 digit	40.0354030166797301	-82.997118512098865
27389	2020-05-27 23:09:44	2020-05-27	Shena Prohaska MD	shena.prohaska.md@geemail.com	Stamford	Connecticut	3451281986632176	f3819876dce16efce53deee04613bf8d	Voyager	41.12434131939672	-73.5470479338001581
27390	2020-05-27 23:34:20	2020-05-27	Ottie Trantow	ottie.trantow@warmmail.com	Sparks	Nevada	4846638547386	571445c52f27de6915579bb1f754b468	Maestro	39.557591466908903	-119.725129926609256
27391	2020-05-27 23:38:08	2020-05-27	Lea Yost-Olson	lea.yost.olson@woohoo.com	Berkeley	California	869970468868854278	cb8e391cfc7f5b53206e09765aca0090	VISA 16 digit	37.8693260810282766	-122.263109140741719
27392	2020-05-27 23:39:05	2020-05-27	Kristyn Runte-Price	kristyn.runte.price@geemail.com	Kansas City	Kansas	51669560043508022	843767a4f2e32e9717176ceaa5991b06	Voyager	39.2157244662195481	-94.6674867282558239
27393	2020-05-27 23:44:17	2020-05-27	Anahi Stracke	anahi.stracke@warmmail.com	Phoenix	Arizona	4798048856368969	742ad41d75f7106509b322c830c461e6	Maestro	33.5547804426334793	-112.090017621864007
27394	2020-05-27 23:44:40	2020-05-27	Jazlene Johns-Spinka	jazlene.johns.spinka@geemail.com	Worcester	Massachusetts	3158717084304144551	9d4ec16b9c00a8d373cb1a8bdc435e81	Mastercard	42.2064318482931711	-71.8778089031364829
27395	2020-05-27 23:46:06	2020-05-27	Mrs. Glynda Nicolas	mrs.glynda.nicolas@geemail.com	New York	New York	4775525225923	685b5c03223fb12ad76893356420bcc4	JCB 16 digit	40.6764140318371332	-74.0089735294587854
27396	2020-05-27 23:56:11	2020-05-27	Dr. Lorene Padberg DVM	dr.lorene.padberg.dvm@geemail.com	Glendale	Arizona	3158511416033127218	0b09dbc74f07e278f3ac42ee20d1a545	VISA 13 digit	33.4992124992184301	-112.26657322331107
27397	2020-05-27 23:58:18	2020-05-27	Destinee Flatley MD	destinee.flatley.md@geemail.com	New York	New York	3033042727101650	e3a5aff1d5dd6190d0177f6922e1b62b	Discover	40.60486341032572	-74.0370242909889669
27398	2020-05-28 00:05:25	2020-05-28	Florencio Hamill	florencio.hamill@geemail.com	Norfolk	Virginia	180028061530807296	3efdef28c7e23f1cd333a999f6477a7e	JCB 16 digit	36.953028317356484	-76.3068432943433521
27399	2020-05-28 00:13:39	2020-05-28	Rudolph Gutkowski	rudolph.gutkowski@geemail.com	Seattle	Washington	3428149910442576	c71fd726cc2f4de775d875e2dddda0a0	JCB 16 digit	47.5318138269167392	-122.417980874135708
27400	2020-05-28 00:16:29	2020-05-28	Luda Greenholt MD	luda.greenholt.md@geemail.com	Los Angeles	California	210010269369753784	3810e81cc171ebe8d5c59ef82e6dbd3c	Maestro	34.083940221914645	-118.413661142298196
27401	2020-05-28 00:19:59	2020-05-28	Hana Glover	hana.glover@geemail.com	Chicago	Illinois	4613325160940110	e7b63808e41553ac119f9a5529701705	Diners Club / Carte Blanche	41.829140113929661	-87.5912173072837277
27402	2020-05-28 00:24:15	2020-05-28	Sullivan Schaefer	sullivan.schaefer@geemail.com	Richmond	California	502079626532513	b2a527af0a9326118a711fd34d9f7759	JCB 16 digit	38.0481110940642679	-122.346835355818655
27404	2020-05-28 00:29:08	2020-05-28	Tyquan Daniel	tyquan.daniel@geemail.com	Cape Coral	Florida	4639920639831997	f4081760b693b4c0078a35ba063c18ca	VISA 16 digit	26.6245238537404703	-82.0691432362027484
27405	2020-05-28 00:31:17	2020-05-28	Zed Dibbert DVM	zed.dibbert.dvm@geemail.com	Fort Worth	Texas	3096186425495457264	6106e11986acc1c9674f12ef2f718823	JCB 16 digit	32.7484130034279062	-97.3748350784469352
27406	2020-05-28 00:39:35	2020-05-28	Dorothy Labadie DDS	dorothy.labadie.dds@geemail.com	San Francisco	California	3337015046582346652	4ccb8ab674387b0624cd1c2c77fd1920	American Express	37.780203582104086	-122.401385202102958
27407	2020-05-28 00:47:13	2020-05-28	Dessa Klein-Jacobson	dessa.klein.jacobson@geemail.com	Sioux Falls	South Dakota	3494265335660201	01bb1493aae0aff3242482e604b2491d	Mastercard	43.5701649963941406	-96.6528525039721274
27408	2020-05-28 00:48:39	2020-05-28	Ron Grady	ron.grady@geemail.com	San Francisco	California	52007176212910153	3589bf98a8e7af8d8856dc407992c875	VISA 16 digit	37.7495231544522269	-122.455647361116291
27409	2020-05-28 00:54:51	2020-05-28	Una Bauch	una.bauch@woohoo.com	Richmond	California	4965007077690	e34866af4b887fe2185084633d03f421	Diners Club / Carte Blanche	37.9248397825706789	-122.382630550334611
27410	2020-05-28 00:56:32	2020-05-28	Patrick Klein	patrick.klein@geemail.com	Indianapolis	Indiana	54521330179968681	593adaf7f09b52951ca0187a34445b8c	Maestro	39.7984107311356823	-86.231599161048976
27411	2020-05-28 00:58:05	2020-05-28	Regina Nolan	regina.nolan@woohoo.com	Clarksville	Tennessee	4895014172475	62d33198c662e5b0a3f6ff05e6594a8e	VISA 16 digit	36.6213397416878479	-87.344285824145004
27412	2020-05-28 01:04:05	2020-05-28	Krystin Little DVM	krystin.little.dvm@geemail.com	Little Rock	Arkansas	502027650024311	bed3d19180e66e43c90aaf3fc3ba421d	JCB 15 digit	34.7398220340065649	-92.2599124338816807
27413	2020-05-28 01:10:29	2020-05-28	Mrs. Laurette Nitzsche DVM	mrs.laurette.nitzsche.dvm@woohoo.com	Berkeley	California	6011910925825923730	2bc1ce819641982c131d3f0d67647f58	Mastercard	37.8767119976938247	-122.277769129390293
27414	2020-05-28 01:13:02	2020-05-28	Sebastian West-McGlynn	sebastian.west.mcglynn@warmmail.com	Edison	New Jersey	3400283925385470	fba2cba1e0d4f6225472c8ad5f0b476f	Maestro	40.5178821361120782	-74.279238430788368
27415	2020-05-28 01:15:27	2020-05-28	Caren Gulgowski	caren.gulgowski@geemail.com	New York	New York	180063210321447046	5dc780768ba8d36c67da4d428b6f8ee0	JCB 15 digit	40.7142893136236808	-74.0185183946404521
27416	2020-05-28 01:45:46	2020-05-28	Rosie Jakubowski PhD	rosie.jakubowski.phd@warmmail.com	El Paso	Texas	54993285998270074	e260ff642a3d93c3a8dee051092f6dcc	VISA 16 digit	31.8423854473341272	-106.410470370899887
27417	2020-05-28 01:52:44	2020-05-28	Gus Kohler	gus.kohler@warmmail.com	Irving	Texas	4418978234585	6acf8cd1b3845c3c7adef94e822efc7d	VISA 16 digit	32.9474860650438828	-96.8907354659214661
27418	2020-05-28 01:53:28	2020-05-28	Delmas Lakin	delmas.lakin@geemail.com	West Covina	California	4841698556520405	11583d95b69a76f7cdb766d980eb0e88	JCB 16 digit	34.0558718397390123	-117.861765899376564
27419	2020-05-28 01:57:30	2020-05-28	Lucinda Schultz	lucinda.schultz@geemail.com	Austin	Texas	4268887522525	69409a66801ee2d0e0731ed1b39febe2	Discover	30.3315998866349439	-97.816905915015937
27420	2020-05-28 02:06:50	2020-05-28	Dr. Jesus Sipes	dr.jesus.sipes@warmmail.com	San Francisco	California	210028183874729074	bd720b4778e7a36610a208857e8c1c85	VISA 13 digit	37.7639401062715265	-122.420248593899402
27421	2020-05-28 02:07:09	2020-05-28	Abdullah Heidenreich	abdullah.heidenreich@geemail.com	Shreveport	Louisiana	3337026517731743848	863271021a278c6ecdfab94642a5347b	VISA 13 digit	32.4630439143400693	-93.85953130114153
27422	2020-05-28 02:53:01	2020-05-28	Leisa Feil DVM	leisa.feil.dvm@geemail.com	Chicago	Illinois	3053061399994242	9d31f6f635cc2c6bd73b91740b1ec1c3	Maestro	41.9293766881175358	-87.6033294283814712
27423	2020-05-28 02:54:38	2020-05-28	Jarett Simonis	jarett.simonis@woohoo.com	San Francisco	California	6011220941901022417	87a6968667a36a1a01760add0217c956	Diners Club / Carte Blanche	37.7852698764218076	-122.413615504184904
27424	2020-05-28 03:02:51	2020-05-28	Bradley Renner-Reinger	bradley.renner.reinger@geemail.com	Renton	Washington	4717539777243768	49a1bf6c9dc8c22332e754ac3d4ecf5e	JCB 16 digit	47.4345965917747492	-122.137275561930608
27425	2020-05-28 03:08:22	2020-05-28	Ms. Maci Brakus	ms.maci.brakus@warmmail.com	San Francisco	California	6011095267857975495	4d1d295197262c6f8a847c0e05902b12	Diners Club / Carte Blanche	37.7748697706487633	-122.431494548289351
27426	2020-05-28 03:12:13	2020-05-28	Casey Greenfelder	casey.greenfelder@warmmail.com	Chicago	Illinois	52813237639263826	4fa26192de3abe88aa828f3018d11438	Discover	41.8218175458557937	-87.667308553171523
27427	2020-05-28 03:17:27	2020-05-28	Kenton Jacobi	kenton.jacobi@geemail.com	Columbus	Ohio	4681582630338	98ef333b63c7d3a39522b1c04c724554	American Express	39.9474491603251565	-82.9756795071300246
27428	2020-05-28 03:27:25	2020-05-28	Courtland Lubowitz	courtland.lubowitz@geemail.com	New York	New York	4435283905709	0d1e3f96179581a730ad52264cc20258	VISA 16 digit	40.6980514055807134	-73.8895348951581781
27429	2020-05-28 03:40:45	2020-05-28	Hollis Pagac	hollis.pagac@woohoo.com	San Francisco	California	3096461328777091932	7d9f62a9d031aba6f3b6adef77a7cbc3	Maestro	37.7676838396847074	-122.4187431642749
27430	2020-05-28 03:45:31	2020-05-28	Weaver Kub I	weaver.kub.i@geemail.com	Glendale	Arizona	6011071906488153166	aab1ee21478e411b1fa2e295f3653196	Maestro	33.5308697801310558	-112.112264851273594
27431	2020-05-28 03:51:23	2020-05-28	Mr. Ricci Rosenbaum II	mr.ricci.rosenbaum.ii@geemail.com	San Francisco	California	4892283718563003	3b35083f9d8be6fe291c7cbd7bc0ecae	American Express	37.7807309930097688	-122.421275495276731
27432	2020-05-28 03:53:54	2020-05-28	Ines Hagenes	ines.hagenes@geemail.com	Alexandria	Virginia	180064822523591170	52e965a143343061205a305ce7e427b7	Discover	38.8481622617341529	-77.1454149854354654
27433	2020-05-28 03:57:10	2020-05-28	Lorean Nienow-Hills	lorean.nienow.hills@geemail.com	Fayetteville	North Carolina	4443197392709	ca8889dac6b693729cb68a422949eb59	VISA 16 digit	35.0564505666282002	-78.9261373310945942
27434	2020-05-28 04:00:12	2020-05-28	Dr. Laurel Johns PhD	dr.laurel.johns.phd@geemail.com	Los Angeles	California	675911670902227	43f049f4b216eb3f91388004f18c165f	VISA 16 digit	34.0025802916247386	-118.416916514792661
27435	2020-05-28 04:02:22	2020-05-28	Dr. Elmina Paucek	dr.elmina.paucek@geemail.com	Austin	Texas	52074648797211726	bf1007366815e9afdac2042d966a8e1d	JCB 16 digit	30.3445968459952624	-97.6818180381558818
27436	2020-05-28 04:03:08	2020-05-28	Viva Lakin	viva.lakin@geemail.com	Houston	Texas	869979167770405176	87aad872b8a17d5ad42c49f954b68104	Mastercard	29.8765263849481926	-95.4583944509286511
27437	2020-05-28 04:03:19	2020-05-28	Llewellyn Littel PhD	llewellyn.littel.phd@geemail.com	Baton Rouge	Louisiana	55034751506427580	b7a0e6d2158c1260f3a7223b1c6d021a	Voyager	30.4742029837545019	-91.1418081696253211
27438	2020-05-28 04:33:25	2020-05-28	Cortney Goodwin	cortney.goodwin@geemail.com	Independence	Missouri	3034321452465996	6aca3908e510b4efb5ca856e0b7f9756	VISA 16 digit	39.0487087408565046	-94.3887363110952009
27439	2020-05-28 04:37:28	2020-05-28	Dr. Talan Hermiston I	dr.talan.hermiston.i@geemail.com	Sacramento	California	4871893195689	6357573854da2d195d3816c76ba9a7d2	American Express	38.4942477379258747	-121.484263092723111
27440	2020-05-28 04:42:44	2020-05-28	Selene Stark MD	selene.stark.md@geemail.com	San Jose	California	180068470158954770	de00e31a55def049b86d935cdf577afb	VISA 16 digit	37.3058355686541674	-121.897660825283822
27441	2020-05-28 04:56:16	2020-05-28	Helmer Cronin	helmer.cronin@geemail.com	Grand Prairie	Texas	3158120239379256588	3d0c92063a538101efe731762becc791	Diners Club / Carte Blanche	32.7865303067076965	-97.1128016367893707
27442	2020-05-28 05:13:59	2020-05-28	Tinie Lebsack	tinie.lebsack@geemail.com	Henderson	Nevada	52424628103842189	188eac2f0211b88b81b36c8c74a54237	VISA 13 digit	36.0681778943564737	-114.939843385589128
27443	2020-05-28 05:20:54	2020-05-28	Tarsha Bode	tarsha.bode@geemail.com	Los Angeles	California	4815131201122	58c0b5f7c5a3577d35fbd7a9a4360bc5	JCB 16 digit	33.943254576144362	-118.369404090940208
27444	2020-05-28 05:31:15	2020-05-28	Benton Satterfield	benton.satterfield@woohoo.com	Sacramento	California	3039571217722843	86ea40fbcf4e6d4477dec413f9ce9856	JCB 16 digit	38.6565594745598773	-121.447034521751476
27445	2020-05-28 05:44:53	2020-05-28	Kerwin Block-Pacocha	kerwin.block.pacocha@geemail.com	Baltimore	Maryland	3088898017408142395	323eb9cbdac237368ddc57a687e7cd4c	VISA 16 digit	39.2021479172166423	-76.673066915480419
27446	2020-05-28 05:49:08	2020-05-28	Mrs. Vertie Schmitt PhD	mrs.vertie.schmitt.phd@woohoo.com	Chicago	Illinois	869932791293165227	efee21ecc3ee44711e850e57fe31fafd	JCB 15 digit	41.9346760861877357	-87.7786509571161133
27447	2020-05-28 05:52:07	2020-05-28	Mr. Primus McCullough DDS	mr.primus.mccullough.dds@geemail.com	Los Angeles	California	3013930048576552	c4c0dfb073e6139cf036f5ce6c2fc754	American Express	33.9766919598314914	-118.442478300676868
27448	2020-05-28 06:05:59	2020-05-28	Forest Bruen	forest.bruen@geemail.com	Phoenix	Arizona	3088948393070856210	7d37ad09942102def94bdaf69f57fe94	Diners Club / Carte Blanche	33.587911945202201	-112.101170084013049
27449	2020-05-28 06:12:28	2020-05-28	Kaye Nienow-Swift	kaye.nienow.swift@woohoo.com	Irvine	California	3096244334425147062	e3d0f009302655eaf377f111db6162f2	JCB 16 digit	33.5961058494184215	-117.863034571335831
27450	2020-05-28 06:15:53	2020-05-28	Asberry Douglas	asberry.douglas@geemail.com	Austin	Texas	3010947294540010	2a0d8e39c1b0ddf890beecfc00c7fa6e	Diners Club / Carte Blanche	30.2090590329036104	-97.791335965670271
27451	2020-05-28 06:22:17	2020-05-28	Eber Morissette	eber.morissette@geemail.com	Omaha	Nebraska	3458524556015063	028418f5665a380158dff9311f2b1808	JCB 15 digit	41.3438651073403705	-95.9647849403902882
27452	2020-05-28 07:01:32	2020-05-28	Tiara Cronin	tiara.cronin@geemail.com	San Antonio	Texas	6011668737363803503	b7d5600cdae40bf1f30a27f937301d2a	VISA 16 digit	29.5412773815520104	-98.6153017029002257
27453	2020-05-28 07:06:16	2020-05-28	Erasmo Ryan DDS	erasmo.ryan.dds@warmmail.com	San Francisco	California	51464976658453816	012ab6652434a05cf5cc8d92a314d060	VISA 16 digit	37.7949025234816034	-122.459701827087144
27454	2020-05-28 07:21:39	2020-05-28	Miss Bev Deckow MD	miss.bev.deckow.md@geemail.com	Portland	Oregon	4249252006153	ff26de67040058bef5c740d0ccaff222	JCB 16 digit	45.5155690260119741	-122.714612733945259
27455	2020-05-28 07:21:58	2020-05-28	Mrs. Shalonda Stark MD	mrs.shalonda.stark.md@geemail.com	Greeley	Colorado	3051145946950187	93f99cf16e7a904fe36096bbfbd01208	Discover	40.4392782539196318	-104.713374676399681
27456	2020-05-28 07:31:13	2020-05-28	Hideo Jakubowski IV	hideo.jakubowski.iv@geemail.com	Tucson	Arizona	4779136242902899	629fa74aff3ffd21c15b89904c65d6c0	JCB 15 digit	32.230441525396337	-110.817124206781756
27457	2020-05-28 07:35:14	2020-05-28	Deirdre Prosacco	deirdre.prosacco@geemail.com	Houston	Texas	4394525309113223	104e88343f4a2a3700ba63327a464016	Diners Club / Carte Blanche	29.8659011323548853	-95.4793472365491169
27458	2020-05-28 08:15:16	2020-05-28	Elvia Jaskolski-Metz	elvia.jaskolski.metz@warmmail.com	Lubbock	Texas	51592276010147932	339f8aeacc67a12ccf997cb76f469d76	VISA 16 digit	33.5642448921263252	-101.938536112886666
27459	2020-05-28 08:18:33	2020-05-28	Charlottie Nader MD	charlottie.nader.md@geemail.com	Oakland	California	210095727057325817	785ec4a3441f3daf5ea4ffcbe23f4d2c	American Express	37.7822688145990995	-122.252538974166626
27460	2020-05-28 08:19:09	2020-05-28	Shatara Douglas	shatara.douglas@warmmail.com	Rochester	New York	6011735871063317180	38b3cc3157474361e70036a38f0acf0b	Voyager	43.2117473841156823	-77.5555424371507058
27461	2020-05-28 08:32:46	2020-05-28	Coleman Morar V	coleman.morar.v@geemail.com	Fayetteville	North Carolina	060476758473565	530e52322f97fe57faba5f67e9fb9258	Voyager	35.1306999064769556	-79.0456975787542717
27462	2020-05-28 08:39:47	2020-05-28	Shellie Schaefer	shellie.schaefer@woohoo.com	San Francisco	California	639077199954163	80bd77cc494bc1ad44e5fb032f35546f	American Express	37.77432134176739	-122.429207770655481
27463	2020-05-28 08:46:22	2020-05-28	Cali McClure MD	cali.mcclure.md@geemail.com	Lexington	Kentucky	503809388239643	82e19f8b975bfc6df0df7927cd2922d8	Mastercard	38.0728955956053028	-84.4051747869133919
27464	2020-05-28 08:49:10	2020-05-28	Markus Hyatt	markus.hyatt@warmmail.com	Yonkers	New York	4130265722566	007be13516f4f6f23ff08f19f33411ea	VISA 16 digit	41.0393961902443323	-73.9230946565397176
27465	2020-05-28 08:56:44	2020-05-28	Olar Ondricka	olar.ondricka@geemail.com	Milwaukee	Wisconsin	3528199939932208259	431d18ff42c01186686571befe1bd17e	VISA 16 digit	43.0960537851408105	-88.0343974973175705
27466	2020-05-28 09:08:48	2020-05-28	Ms. Jacque Dooley DDS	ms.jacque.dooley.dds@woohoo.com	Phoenix	Arizona	3096742413402750432	a844acb613c89d09be0be177a7c9a2c2	VISA 16 digit	33.5152574981961422	-111.99115252377689
27467	2020-05-28 09:18:00	2020-05-28	Cecelia Abernathy	cecelia.abernathy@geemail.com	Baltimore	Maryland	6011094251766206326	f12ad41b9381ed4d2914c3eb89a3dddc	Maestro	39.3017448396887588	-76.6958447148110736
27468	2020-05-28 09:22:14	2020-05-28	Stone Kessler DDS	stone.kessler.dds@geemail.com	Chesapeake	Virginia	210062968946690867	d64d82b60ab8769f7af1e0896196dfc6	VISA 16 digit	36.7576725750934372	-76.3498816256720545
27469	2020-05-28 09:41:54	2020-05-28	Ms. Carleen Schiller	ms.carleen.schiller@woohoo.com	Garland	Texas	210081940451602634	77f94c427ff45df617a499c3498b0a1e	VISA 16 digit	32.9633377703141406	-96.5536851994853578
27470	2020-05-28 10:08:24	2020-05-28	Ciarra Beahan	ciarra.beahan@geemail.com	Irving	Texas	3713103772607740	94e9d186a408385724d4bebe5f4d45a4	Maestro	32.8665131821248693	-96.8839713079668599
27471	2020-05-28 10:31:10	2020-05-28	Dr. Abel Volkman III	dr.abel.volkman.iii@geemail.com	Hampton	Virginia	639044788588836	444b9b24e6d4fe87c0668b3afa7f2a0a	American Express	37.0077831284161647	-76.2443571793012325
27472	2020-05-28 10:42:55	2020-05-28	Algernon Carroll	algernon.carroll@geemail.com	San Francisco	California	3337375830640832769	644d5620bf2d921c38be0d1f3c8e2b5e	Discover	37.7721640623595363	-122.4316232982288
27473	2020-05-28 10:43:50	2020-05-28	Teressa Klocko DVM	teressa.klocko.dvm@geemail.com	Buffalo	New York	4706332609588250	b3b8c740e9f769e4d869401cdd48b430	VISA 16 digit	42.9089563661441176	-78.9424535366173927
27474	2020-05-28 10:45:51	2020-05-28	Merlin Turner	merlin.turner@geemail.com	Surprise	Arizona	6011783168513638658	16f526fa72fa601fbf9f2223ba4b1989	VISA 13 digit	33.6005866016022878	-112.427151939389105
27475	2020-05-28 10:46:25	2020-05-28	Weston Franecki IV	weston.franecki.iv@geemail.com	Garland	Texas	3158596661314470948	633eb85f015396c115cba365a59a16a6	VISA 16 digit	32.8227312949255108	-96.612215547605615
27476	2020-05-28 10:49:18	2020-05-28	Tasha McGlynn	tasha.mcglynn@geemail.com	Tampa	Florida	4411536224408639	120f334e420ed5ca377f64dc1b3eca8e	American Express	27.9592296111512901	-82.4678823612842677
27477	2020-05-28 10:55:08	2020-05-28	Miss Dolly Weissnat	miss.dolly.weissnat@geemail.com	San Antonio	Texas	3056502333861580	f1c99cc468f3a4cc762c2e2b796d9562	Voyager	29.468336668384822	-98.4315247425179933
27478	2020-05-28 11:14:10	2020-05-28	Mrs. Zeta Streich	mrs.zeta.streich@geemail.com	Oakland	California	3046332689982792	76309f97b3a59c38406826ea8f08b2ea	Mastercard	37.8187841125856394	-122.278395678681974
27479	2020-05-28 11:20:11	2020-05-28	Wylie Gerlach	wylie.gerlach@geemail.com	Miami	Florida	589306585481267	07cd0c5388da80db9ab610faec4c10d4	VISA 16 digit	25.8692240622498097	-80.2062115199271659
27480	2020-05-28 11:25:46	2020-05-28	Kori Luettgen-Lebsack	kori.luettgen.lebsack@geemail.com	West Valley City	Utah	3742359714058955	6f5eda585d47578744bcdfaaa1f7a6cf	American Express	40.7561839803811168	-111.924258869814864
27481	2020-05-28 11:39:29	2020-05-28	Gwyneth Luettgen PhD	gwyneth.luettgen.phd@woohoo.com	Boston	Massachusetts	3759402670537115	46b12a09699d0d5d4710d0e1d6407ec6	VISA 13 digit	42.4307886997405461	-71.1021428518414496
27482	2020-05-28 11:44:32	2020-05-28	Rebecca Reynolds DVM	rebecca.reynolds.dvm@woohoo.com	Indianapolis	Indiana	51396943142068637	1f77ffdecac00bd3a409f4d57483d08d	Voyager	39.7581326668158184	-86.217800410763914
27483	2020-05-28 11:44:38	2020-05-28	Montrell Thiel MD	montrell.thiel.md@warmmail.com	Elizabeth	New Jersey	3012281918294004	30cf33b0175db08a77036b2b4b584827	VISA 16 digit	40.6785622272301524	-74.2582750013042272
27484	2020-05-28 11:50:44	2020-05-28	Clark Mosciski	clark.mosciski@geemail.com	Grand Prairie	Texas	3158548180351251805	8491b8462d37544f841b651733dd994d	Diners Club / Carte Blanche	32.7553006325434879	-97.0732742556709809
27485	2020-05-28 11:51:12	2020-05-28	Marquez Crooks	marquez.crooks@geemail.com	Huntsville	Alabama	4329735987574832	b1a8208075876655374de86357fea2d4	JCB 15 digit	34.6648140398561964	-86.6973577043991526
27486	2020-05-28 11:57:59	2020-05-28	Shaquana D'Amore	shaquana.d'amore@geemail.com	Modesto	California	3528416248042218704	6148fe200603cfa5a04125cc08598d1e	Voyager	37.7286496733315317	-120.905228117175398
27487	2020-05-28 12:15:48	2020-05-28	Mrs. Dagny Crist	mrs.dagny.crist@geemail.com	Wichita	Kansas	180050588943211105	35df40cb14f3b587d9e368bd18457f6b	Voyager	37.6795149945065404	-97.2886985772956194
27488	2020-05-28 12:18:59	2020-05-28	Robt Durgan	robt.durgan@woohoo.com	Berkeley	California	3096385230311789232	cb83e2b60f34b34eaf0690a9c7a1db78	VISA 16 digit	37.9146996423486797	-122.297710897424807
27489	2020-05-28 12:21:09	2020-05-28	Noble Bartoletti	noble.bartoletti@geemail.com	Lafayette	Louisiana	180097480015609512	e6b6b6e6492fe9148431bbd7c717adf5	Maestro	30.124745046438278	-92.103398445792493
27490	2020-05-28 12:22:56	2020-05-28	Dr. Pryor Hintz	dr.pryor.hintz@geemail.com	Chandler	Arizona	210042077718195082	4bf24fc7a80b7e5d221b4a3488896aeb	JCB 16 digit	33.3349903984084719	-111.890648862335453
27491	2020-05-28 12:23:52	2020-05-28	Rubye Wiza	rubye.wiza@geemail.com	Houston	Texas	3528565420459699549	d0039d90ffd9dc42eb1c5ae228d38af8	Diners Club / Carte Blanche	29.7754732435647398	-95.4078757675379592
27492	2020-05-28 12:28:18	2020-05-28	Kazuko Rempel	kazuko.rempel@geemail.com	Pittsburgh	Pennsylvania	502046965390514	58e23e0bc479ad79aae6eb79d5325050	VISA 16 digit	40.5052456238262337	-80.0690172024708318
27493	2020-05-28 12:30:58	2020-05-28	Ailene Reinger	ailene.reinger@geemail.com	Dallas	Texas	4701497493216	61d716d42fca2adba62ae41277355bc9	Mastercard	32.7588369466636351	-96.7583167636729655
27494	2020-05-28 12:32:27	2020-05-28	Mr. Blas Heathcote DVM	mr.blas.heathcote.dvm@geemail.com	Newark	New Jersey	4379206300108905	51e8e363749fa9bc4a681bbe50d7b80b	JCB 16 digit	40.7718774181239354	-74.1501624520145413
27495	2020-05-28 12:36:48	2020-05-28	Citlalli Swaniawski	citlalli.swaniawski@warmmail.com	Frisco	Texas	4970858598745963	fdb129c9d5dba94847ac158c3615e4ea	VISA 16 digit	33.0792698703236852	-96.8518179197072868
27496	2020-05-28 12:37:04	2020-05-28	Kelley Lang Jr.	kelley.lang.jr.@woohoo.com	New York	New York	3528726879709742852	b70a52cab59530370f96a69cc2564e99	Discover	40.619437027605251	-73.9110414382897289
27497	2020-05-28 12:44:49	2020-05-28	Mr. Loyd Will II	mr.loyd.will.ii@woohoo.com	Sterling Heights	Michigan	3337860096204933730	c02a4880eb8acf507d1d6e02a6a5d9a5	JCB 15 digit	42.5904767596710485	-83.049850172565499
27498	2020-05-28 13:19:08	2020-05-28	Jean Luettgen	jean.luettgen@warmmail.com	Milwaukee	Wisconsin	4412601369041154	34ad6a4a7012c59aad949d03d040cc69	VISA 16 digit	42.9729990591846374	-87.912209766880423
27499	2020-05-28 13:23:04	2020-05-28	Yandel Bosco Sr.	yandel.bosco.sr.@woohoo.com	Irving	Texas	6011102997520665708	a9b790e9c547af6f4b553559fe515ea7	Maestro	32.835919236712904	-96.9878470327053179
27500	2020-05-28 13:42:09	2020-05-28	Fleda Kiehn	fleda.kiehn@warmmail.com	El Paso	Texas	210003358674413769	e9550dc8aab264621277c248c030fc24	VISA 16 digit	31.8880961262449638	-106.463968861846254
27501	2020-05-28 13:45:30	2020-05-28	Johnna Littel	johnna.littel@warmmail.com	Columbus	Ohio	869981903419014615	8423d9668329f1fb6480f20384e8fad6	Voyager	40.0780971623536217	-82.8883938495304449
27502	2020-05-28 13:46:44	2020-05-28	Clarabelle Torphy DDS	clarabelle.torphy.dds@geemail.com	San Diego	California	4036139707313825	1f20c36b15b8d7f2f87a47450e39e40a	Mastercard	32.8146650819174965	-117.230957762608313
27503	2020-05-28 13:51:13	2020-05-28	Faye White	faye.white@geemail.com	Lubbock	Texas	869958009409133875	fd9da3c39a54efd6084cd6e338ee7a26	Maestro	33.568874527797476	-101.801166223726057
27504	2020-05-28 13:52:28	2020-05-28	Rex Gorczany	rex.gorczany@warmmail.com	Columbus	Ohio	6011110160096668347	9986b1e78fd65649914e5d6469fe9dee	VISA 13 digit	40.0678056570746008	-83.079169589723648
27505	2020-05-28 13:58:27	2020-05-28	Nena Maggio	nena.maggio@woohoo.com	Pittsburgh	Pennsylvania	4482620743257596	2d0e70649bf412a767b59f1438108238	VISA 16 digit	40.3619391686703963	-79.9702746910214444
27506	2020-05-28 13:58:51	2020-05-28	Versa Senger-Lang	versa.senger.lang@geemail.com	Kent	Washington	4582221256374156	c17fc9c87e820d00a427f643ccfc4527	JCB 15 digit	47.3516540651787068	-122.261795692066471
27507	2020-05-28 14:32:36	2020-05-28	Maryann Crona	maryann.crona@geemail.com	Washington	District of Columbia	3750929185371720	9c60295f116b4cf29cd1b88a7cf978f3	Diners Club / Carte Blanche	38.8111202404633175	-76.9592326982159136
27508	2020-05-28 14:47:11	2020-05-28	Trevon Lueilwitz	trevon.lueilwitz@geemail.com	Oxnard	California	4041608572248954	a2b7b541bfbdb34633dba44201384b72	Mastercard	34.2458871363151829	-119.272448895164203
27509	2020-05-28 15:00:35	2020-05-28	Valentine Considine	valentine.considine@geemail.com	San Francisco	California	3112109576194284492	317be951d221637e673c9947cad48d79	Mastercard	37.7634674148549223	-122.411870262374364
27510	2020-05-28 15:13:58	2020-05-28	Mrs. Opha Streich	mrs.opha.streich@warmmail.com	Aurora	Colorado	589399995360098	3975aea5a2c66e11e26e6762210c0775	Voyager	39.7794780991151953	-104.703633593640106
27511	2020-05-28 15:17:56	2020-05-28	Daria Gerhold	daria.gerhold@warmmail.com	Aurora	Illinois	503808873820826	477ae0719c735d348186d5c040d38137	JCB 15 digit	41.7970441873408873	-88.3327712003070786
27512	2020-05-28 15:21:42	2020-05-28	Miss Sommer Mitchell MD	miss.sommer.mitchell.md@geemail.com	San Francisco	California	3088399731051629284	77bdd74f7cd472ba0280d4e81d23634a	JCB 16 digit	37.8018251951277975	-122.444870165201948
27513	2020-05-28 15:44:01	2020-05-28	Huy Kuhic	huy.kuhic@warmmail.com	Indianapolis	Indiana	3088006937686307585	2c337bfbcd932a465c0cdfb85a9b0cd8	Voyager	39.8760754581548227	-86.0714137469153826
27514	2020-05-28 15:51:35	2020-05-28	Tim Kris	tim.kris@geemail.com	Bridgeport	Connecticut	3158049458307383250	6b6ad2c811f5e55cfafcc45a4906d6cd	VISA 16 digit	41.1361732259090971	-73.2769585108283934
27515	2020-05-28 15:55:51	2020-05-28	Abelardo Terry	abelardo.terry@warmmail.com	Norwalk	California	3096922437651885955	b684918ab2ef8ec4f77e11359ca141d7	Maestro	33.8731628170352437	-118.133593323551125
27516	2020-05-28 16:09:31	2020-05-28	Ben Bergnaum	ben.bergnaum@geemail.com	Fort Worth	Texas	3435649726462453	419f0311ebabbfba31ee5a79b25e2e26	VISA 16 digit	32.8683609579745664	-97.4218225073821884
27517	2020-05-28 16:20:12	2020-05-28	Darold Littel-Cartwright	darold.littel.cartwright@warmmail.com	Baton Rouge	Louisiana	6011015582315428599	50bb3542f6816b87ebf672c21f8c3767	Maestro	30.519058554314821	-91.2301624355480101
27518	2020-05-28 16:23:30	2020-05-28	Dr. Hester O'Keefe MD	dr.hester.o'keefe.md@geemail.com	Louisville	Kentucky	3158877078513308102	fa816a38878eece7b9b1f5b6197a0f2a	VISA 13 digit	38.0761963833492203	-85.7021348611988145
27519	2020-05-28 16:46:53	2020-05-28	Ananias Medhurst	ananias.medhurst@woohoo.com	Wichita	Kansas	4863969840850	ae749d6a7c8909760c9e2264a4936b06	JCB 15 digit	37.7400893931154187	-97.2653838650059015
27520	2020-05-28 17:15:48	2020-05-28	Tamiko Cronin MD	tamiko.cronin.md@warmmail.com	Seattle	Washington	180009366267082580	55ef0ab5f5b73c6007c26125642828ac	Diners Club / Carte Blanche	47.7096672679688751	-122.277423974630977
27521	2020-05-28 17:17:51	2020-05-28	Aliana Muller	aliana.muller@geemail.com	Houston	Texas	4987291784818454	396f9eee65a7cf0a45b1aeb00f7b1e14	Discover	29.7194386982902898	-95.3310263696141504
27522	2020-05-28 17:19:20	2020-05-28	Dr. Wilfrid Braun	dr.wilfrid.braun@geemail.com	Indianapolis	Indiana	3337739212943511500	b6bb3cd2e230884b0f1a5b2ba1c7ac3e	VISA 13 digit	39.8601455394186033	-86.065706446554131
27523	2020-05-28 17:43:39	2020-05-28	Marlin Cremin	marlin.cremin@geemail.com	Plano	Texas	3434299130483470	fe1100da2633bfe87544bea973c32b67	Maestro	32.9825740003112742	-96.6962744087163344
27524	2020-05-28 17:48:17	2020-05-28	Georgiana Grimes	georgiana.grimes@woohoo.com	Indianapolis	Indiana	630414927848037	f4c9232ebad0a2d3ec34f4f854766155	Maestro	39.8210916472606371	-86.1824896827541238
27525	2020-05-28 17:51:38	2020-05-28	Ashby Senger	ashby.senger@geemail.com	Hayward	California	4978635633149	552987eba9bff101791eafd9962807e0	JCB 16 digit	37.5421209973737646	-122.14968295397945
27526	2020-05-28 18:05:07	2020-05-28	Jessy Bayer	jessy.bayer@geemail.com	New York	New York	6011492174368707673	f36af0f5ced0c5c361ccd7d79e3d04ac	Diners Club / Carte Blanche	40.6651199088655417	-73.9045862270880463
27527	2020-05-28 18:08:33	2020-05-28	Micky Renner	micky.renner@geemail.com	Fort Worth	Texas	210020693349858280	64a5d62bcf7673e6d9ac61bea03607a4	Mastercard	32.6952444328051044	-97.3395847791161373
27528	2020-05-28 18:21:10	2020-05-28	Donnie Runolfsdottir	donnie.runolfsdottir@woohoo.com	Charleston	South Carolina	180093071747519139	cf7702d3708e5bceb04868370c4a1a29	American Express	32.7461073412556232	-79.8826037538852631
27529	2020-05-28 18:29:37	2020-05-28	Corliss Schimmel DVM	corliss.schimmel.dvm@geemail.com	Jacksonville	Florida	6011892679415070087	ffed2dadd865c84bffa65d5e4614bdab	Diners Club / Carte Blanche	30.2474384014081217	-81.7150923906903728
27530	2020-05-28 18:30:51	2020-05-28	Dow Kreiger	dow.kreiger@warmmail.com	San Francisco	California	4670962819161951	859079a67a708cda3140316f96f04639	VISA 13 digit	37.835149551868831	-122.413501570550608
27531	2020-05-28 18:39:24	2020-05-28	Rayshawn Hyatt-Daniel	rayshawn.hyatt.daniel@woohoo.com	Gilbert	Arizona	4943281116454741	044848baf5c44c5a2f88f330eb62d4ea	VISA 13 digit	33.2862286646265488	-111.686045303721357
27532	2020-05-28 18:49:21	2020-05-28	Miesha Moore DDS	miesha.moore.dds@geemail.com	Stockton	California	3528899331572269739	bdd7b1db3a2d8c91b7789e16b5cf7a9e	Mastercard	37.9444393695063908	-121.297091746571652
27533	2020-05-28 18:57:15	2020-05-28	Aili Welch-Jenkins	aili.welch.jenkins@geemail.com	New York	New York	180007960431157443	771dd69933dad2240130b6be038f5cbc	Maestro	40.6172538172211475	-73.8775044513761969
27534	2020-05-28 19:02:05	2020-05-28	Mrs. Ami Heathcote	mrs.ami.heathcote@woohoo.com	Lexington	Kentucky	6011775839996791723	255ac26323538356a57d85df43d61bea	VISA 16 digit	38.03212862465233	-84.3670208456359774
27535	2020-05-28 19:06:13	2020-05-28	Omer Dibbert-Schmeler	omer.dibbert.schmeler@geemail.com	Tampa	Florida	6011513599368730850	27e98e96717910ad5777b179d02d1f78	Diners Club / Carte Blanche	27.9509647105935954	-82.4327717338435235
27536	2020-05-28 19:44:19	2020-05-28	Jovany Quitzon-Ernser	jovany.quitzon.ernser@warmmail.com	Aurora	Colorado	4592995429886158	80bf06b92116ad77733863f5c15f5d1c	VISA 13 digit	39.7363454371802547	-104.647412575374176
27537	2020-05-28 19:56:08	2020-05-28	Archibald Shanahan DVM	archibald.shanahan.dvm@geemail.com	Phoenix	Arizona	3459769745081224	b4d1ce4d659ece6fb68100454fff0db2	VISA 16 digit	33.6690530640006074	-112.135521438431368
27538	2020-05-28 20:03:33	2020-05-28	Kaitlyn Schuppe	kaitlyn.schuppe@geemail.com	San Francisco	California	6011483998133517319	a3467f28b5eba9bacb3709d6766a3464	Mastercard	37.7698337436663252	-122.432331331492662
27539	2020-05-28 20:07:27	2020-05-28	Julian Ratke	julian.ratke@geemail.com	Charlotte	North Carolina	4849981539575163	f23c58e3ea121836468b82e5c06272ec	JCB 16 digit	35.302458270105717	-80.7876693815402689
27540	2020-05-28 20:09:45	2020-05-28	Jair Kshlerin	jair.kshlerin@woohoo.com	Santa Ana	California	4728519128900248	0dd3779cc81d46ed636e9350cf1fadbe	Maestro	33.7090047385647864	-117.956299714690076
27541	2020-05-28 20:10:57	2020-05-28	Germaine Hills V	germaine.hills.v@geemail.com	San Francisco	California	4301975347380544	967f76f9c86830544df33e0aea707bbd	VISA 16 digit	37.7486832544933435	-122.435111061080249
27542	2020-05-28 20:27:28	2020-05-28	Dr. Mable Volkman DVM	dr.mable.volkman.dvm@geemail.com	San Antonio	Texas	6011625102913655824	6947ca2101ea3cee1eabff1dcd3b761b	JCB 15 digit	29.5044930890738968	-98.5831401193816106
27543	2020-05-28 20:29:44	2020-05-28	Leora Beier	leora.beier@geemail.com	Rochester	New York	4392285996626	f11398477087df7cc945e0ade0bfbaa7	JCB 16 digit	43.101982164753224	-77.6771740888018201
27544	2020-05-28 20:48:35	2020-05-28	Mr. Tyrik McGlynn	mr.tyrik.mcglynn@geemail.com	San Francisco	California	4429528083266414	9dfc9a2bd327e12e208757d76cf56dcd	American Express	37.8025732985899339	-122.433065799259325
27545	2020-05-28 20:54:11	2020-05-28	Hezzie Stroman	hezzie.stroman@woohoo.com	Chicago	Illinois	869977189287150139	43b7a7cb5057ccd4769a08ba5a7b7a7f	Diners Club / Carte Blanche	41.7393238031141465	-87.6476300862647548
27546	2020-05-28 20:58:23	2020-05-28	Miss Ardis Kautzer PhD	miss.ardis.kautzer.phd@geemail.com	San Francisco	California	3088409979034271496	7afb1ae977b67f775d3449e9d6932d99	Discover	37.7764475022669117	-122.452164760781685
27547	2020-05-28 21:03:04	2020-05-28	Dr. Amelie Cassin	dr.amelie.cassin@warmmail.com	Cleveland	Ohio	4412407127972320	d45b261575af92f4b82fecc9d744c954	Mastercard	41.4614501858912377	-81.639067253494261
27548	2020-05-28 21:09:15	2020-05-28	Sabastian Schumm	sabastian.schumm@woohoo.com	Baton Rouge	Louisiana	3158321332961898227	c38787d2f2d3b339858a8e0d1c0dc958	VISA 16 digit	30.3970856536857781	-91.1537216543793676
27549	2020-05-28 21:10:31	2020-05-28	Mr. Blane Dicki II	mr.blane.dicki.ii@geemail.com	Overland Park	Kansas	3096112443090698553	8287856a9216e4a0a815fe0385677277	JCB 16 digit	38.9241044951938093	-94.7682973788160865
27550	2020-05-28 21:15:49	2020-05-28	Lola Kris	lola.kris@geemail.com	Chicago	Illinois	4338389427449566	d2086184ce3089e04776d20185e98486	VISA 16 digit	41.7722184508409384	-87.7000805265299874
27551	2020-05-28 21:59:41	2020-05-28	China Mosciski	china.mosciski@geemail.com	Phoenix	Arizona	3470495976233418	b024793d8ae333e467133e2829931bd9	Voyager	33.6085432552199848	-112.088792128527913
27552	2020-05-28 22:17:22	2020-05-28	Dr. Jaden Stehr DDS	dr.jaden.stehr.dds@geemail.com	Westminster	Colorado	55524809982909039	43dd7da1af0d57806d80373c041f78c7	Discover	39.8507482467524667	-104.992761755190429
27553	2020-05-28 22:18:51	2020-05-28	Stuart Hoppe PhD	stuart.hoppe.phd@woohoo.com	New York	New York	4850346892868157	ec35fdc69417f36263a5adc5498dbbc3	JCB 16 digit	40.5643470511063953	-73.8609213490866097
27554	2020-05-28 22:37:01	2020-05-28	Donnell Simonis-Gutmann	donnell.simonis.gutmann@woohoo.com	Houston	Texas	3707875166168599	44d447c95ac6512f109087dfa422ebee	Mastercard	29.7824540730178349	-95.4327692519888302
27555	2020-05-28 22:45:17	2020-05-28	Brianne Turcotte	brianne.turcotte@geemail.com	Oakland	California	639089493121548	c0c4aabf0eaa3f33e024f2566f3ac757	Diners Club / Carte Blanche	37.7733482782525556	-122.304695416864419
27556	2020-05-28 22:52:25	2020-05-28	Arlyn Altenwerth	arlyn.altenwerth@warmmail.com	Los Angeles	California	4811888903274055	2d66c6a3b3557b0ef2a5effece945cac	American Express	34.0903060785826284	-118.347379748056824
27557	2020-05-28 22:56:30	2020-05-28	Mr. Hillary Berge DDS	mr.hillary.berge.dds@geemail.com	San Francisco	California	4042674411954243	93686e8d3aba19251d5533f8bfb3069e	Voyager	37.7825394227856037	-122.434317300948095
27558	2020-05-28 23:00:12	2020-05-28	Solomon Hahn	solomon.hahn@warmmail.com	Lansing	Michigan	4317610535224749	1498dc5154ab71797d276017f5576a82	Voyager	42.7803879226401449	-84.5853237510781639
27559	2020-05-28 23:07:48	2020-05-28	Claudie Macejkovic-Wintheiser	claudie.macejkovic.wintheiser@geemail.com	Chicago	Illinois	3096006886031672765	5a47363c391bee6022ea8d669717526e	American Express	41.7641025591477799	-87.6408482171159164
27560	2020-05-28 23:09:26	2020-05-28	Carlene Konopelski	carlene.konopelski@geemail.com	New York	New York	561205876567602	bd4e9872c775adc55ef3fba7f3b27798	VISA 13 digit	40.5775105768572502	-73.9949041321769272
27561	2020-05-28 23:12:42	2020-05-28	Mr. Dalvin Fay	mr.dalvin.fay@geemail.com	Omaha	Nebraska	3096080765661393653	8cebe5f5a9d2486f8871f12413752a0c	JCB 15 digit	41.2711191071808372	-96.0137239963863038
27562	2020-05-28 23:24:52	2020-05-28	Mr. Clive Ziemann	mr.clive.ziemann@geemail.com	San Antonio	Texas	3024223303649317	b52f9f7b8c02fe9a466729c098a044d1	Maestro	29.4003910984914754	-98.4841533397160447
27563	2020-05-28 23:42:16	2020-05-28	Georgiann Erdman	georgiann.erdman@geemail.com	Pomona	California	54134320224315706	c821b058c7369885817a734a9c846497	VISA 13 digit	34.1476411304939589	-117.819956673538684
27564	2020-05-28 23:45:51	2020-05-28	Ms. Alaya Kihn	ms.alaya.kihn@geemail.com	Honolulu	Hawaii	3711977773206194	ce9daeafbf558b776c75c30563aa850b	VISA 16 digit	21.2579975053418444	-157.861177036606136
27565	2020-05-28 23:48:06	2020-05-28	Helyn Funk	helyn.funk@geemail.com	Dallas	Texas	3112833127372537013	ba2c857869ea56eac7253f643d260b44	VISA 13 digit	32.8377164713844678	-96.6983963619880313
27566	2020-05-28 23:52:41	2020-05-28	Mr. Lucious Kunze	mr.lucious.kunze@geemail.com	Baltimore	Maryland	3459935870558829	2d175c7f3a3328bb3f49a1c1b229cbcf	Voyager	39.2000161363743231	-76.7049004078861287
27567	2020-05-28 23:53:58	2020-05-28	Jamel Spencer	jamel.spencer@warmmail.com	Chula Vista	California	4794146181432841	915e1604c550af0f6c6b74f05c0be7e1	VISA 13 digit	32.6047001397933798	-116.930502628884085
27568	2020-05-28 23:55:31	2020-05-28	Rohan Ryan	rohan.ryan@geemail.com	San Francisco	California	3528150115913152546	8eb23e19d1972fa6426e443536e17e34	VISA 16 digit	37.7921449804799749	-122.428682079157468
27569	2020-05-28 23:57:49	2020-05-28	Altha Stokes	altha.stokes@warmmail.com	New York	New York	6011113317132856420	e135f004a18e951af2f6b18b3347709d	Maestro	40.6491905759777836	-73.9128385266650412
27570	2020-05-29 00:23:21	2020-05-29	Markel Cronin-Smitham	markel.cronin.smitham@geemail.com	Reno	Nevada	6011667705906391113	64b639a01ccf50dff3b3c45694273427	American Express	39.6069736814204632	-119.89417814781666
27571	2020-05-29 00:26:55	2020-05-29	Miss Anabella Halvorson PhD	miss.anabella.halvorson.phd@geemail.com	Chicago	Illinois	4653168286008730	b19f6f117a8dc2444487cce3ad6e79ff	JCB 16 digit	41.9160806435462092	-87.7399787060014802
27572	2020-05-29 00:29:26	2020-05-29	Major Doyle-Toy	major.doyle.toy@woohoo.com	Beaumont	Texas	52212753573164892	49ab5749fa0decccbccb02d431e6c249	VISA 13 digit	30.0158679219033573	-94.2433598471127567
27573	2020-05-29 00:39:10	2020-05-29	Pauletta Lebsack PhD	pauletta.lebsack.phd@geemail.com	Spokane	Washington	3499311134936338	ec42599c0ff170dc704ee3f96200c9c7	JCB 16 digit	47.6404695753246514	-117.492159916636723
27574	2020-05-29 00:43:26	2020-05-29	Tristan Langosh	tristan.langosh@warmmail.com	El Cajon	California	180011597404532782	887233f39b702e9b08f92c0d84a46a7b	Mastercard	32.8351980833809804	-116.916088225245105
27575	2020-05-29 01:15:57	2020-05-29	Timmie Padberg-Christiansen	timmie.padberg.christiansen@geemail.com	San Diego	California	3096633304753967786	c82424890eff39f6944e09492f56de95	American Express	32.9013863717272912	-117.154302129559227
27576	2020-05-29 01:17:12	2020-05-29	Vernell Hyatt	vernell.hyatt@geemail.com	Chicago	Illinois	060479234785156	7c9a5afacae51dcf95d9ba89d3eeb7de	JCB 15 digit	41.8978177301887413	-87.671330196553086
27577	2020-05-29 01:35:41	2020-05-29	Natasha Schroeder	natasha.schroeder@geemail.com	San Francisco	California	6011537145246441385	94056837a9edf93ece1a079851bde287	Mastercard	37.760477318138598	-122.407334645506822
27578	2020-05-29 01:38:36	2020-05-29	Loria Littel-Witting	loria.littel.witting@woohoo.com	Des Moines	Iowa	3088219299652935359	33c814594f8cc3d00f999ee3dab176fe	Discover	41.5584298668637899	-93.575183630971992
27579	2020-05-29 01:55:26	2020-05-29	Mrs. Nelie Walsh	mrs.nelie.walsh@geemail.com	Manchester	New Hampshire	3112306381696730493	793f473d7ce2849255820d9be8ee86bf	American Express	43.0174391914229872	-71.4954228775933416
27580	2020-05-29 02:02:27	2020-05-29	Milo Strosin	milo.strosin@geemail.com	Oakland	California	4300991640370	a89101cbc3efae9117eaf944aa087968	Voyager	37.7969876334318187	-122.274978003394395
27581	2020-05-29 02:08:14	2020-05-29	Asha Olson	asha.olson@geemail.com	Pittsburgh	Pennsylvania	210091760695235639	2fab43147afcd4c4c8e185f671ccc2ee	Voyager	40.5342809369277219	-80.0028933114543577
27582	2020-05-29 02:13:52	2020-05-29	Orlo Veum III	orlo.veum.iii@woohoo.com	Boston	Massachusetts	180018748500562354	c877db764b7f60748629c0e6ca94c0af	Voyager	42.267549064259974	-70.995357149229207
27583	2020-05-29 02:13:53	2020-05-29	Melbourne Nikolaus	melbourne.nikolaus@geemail.com	Everett	Washington	869922490322004224	f1a84c1eb1b0e28c415b53e838f14021	VISA 16 digit	47.8595568847268851	-122.100939581881832
27584	2020-05-29 02:17:29	2020-05-29	Jerimy Streich	jerimy.streich@geemail.com	Milwaukee	Wisconsin	869945381027309203	3bb02740795eb6473f14b66bce36637f	VISA 13 digit	43.103057351111616	-87.997572407089919
27585	2020-05-29 02:18:05	2020-05-29	Redden Leffler	redden.leffler@geemail.com	San Francisco	California	53636404394598185	f71a93f4e922a5e038200b4153f086de	Discover	37.7838228417745441	-122.449199340417877
27586	2020-05-29 02:22:50	2020-05-29	Mercy Weimann DVM	mercy.weimann.dvm@geemail.com	Omaha	Nebraska	180072788483173996	35885aec8036634dfe7d493f7a9e8beb	VISA 13 digit	41.2598426323063663	-95.989022683643185
27587	2020-05-29 02:35:23	2020-05-29	Miss Delora Kihn DDS	miss.delora.kihn.dds@geemail.com	Amarillo	Texas	4223722811316561	bec2a6b8d0acbc83e3152d3a9b73be8b	JCB 16 digit	35.2609596341546592	-101.80143684473336
27588	2020-05-29 02:40:47	2020-05-29	Maxim Wiza	maxim.wiza@woohoo.com	San Francisco	California	210099017774960245	fd364f57f0a5299a3d9046f9253b42b8	Diners Club / Carte Blanche	37.8009442617210993	-122.401423929540158
27589	2020-05-29 02:54:25	2020-05-29	Christi Hyatt	christi.hyatt@geemail.com	San Francisco	California	3714459923486379	e06906f35cc7e62361cc8d9a68236e62	American Express	37.7880578904401006	-122.407263725016179
27590	2020-05-29 02:54:56	2020-05-29	Tricia Russel	tricia.russel@geemail.com	Oakland	California	4804102986162883	454546bf80ca5db779bb4df53e955e8d	JCB 15 digit	37.8321603442422472	-122.260736935450112
27591	2020-05-29 03:01:20	2020-05-29	Dr. Lisandro Kuhlman	dr.lisandro.kuhlman@woohoo.com	San Francisco	California	4614873569584	51f95a81e41838fdc44a4d50051879b9	VISA 16 digit	37.8112545568385485	-122.428757376878409
27592	2020-05-29 03:10:05	2020-05-29	Verl Friesen	verl.friesen@geemail.com	New York	New York	589381299346874	6855dfa6e81c7263e44ff9c903a66275	Mastercard	40.6274920222107312	-73.8769218753919006
27593	2020-05-29 03:12:49	2020-05-29	Candy Green	candy.green@geemail.com	Houston	Texas	3049638376205090	091dec497f23c88acd9f2331d7c4186e	Voyager	29.6993182954922332	-95.34283095305004
27594	2020-05-29 03:44:15	2020-05-29	Alfredo O'Keefe	alfredo.o'keefe@warmmail.com	Indianapolis	Indiana	501850538175014	fbe5636419abf1eb234adf7e70b6aa6b	JCB 15 digit	39.8403958015616979	-86.2285279032975467
27595	2020-05-29 03:59:01	2020-05-29	Shad Williamson Sr.	shad.williamson.sr.@geemail.com	Fargo	North Dakota	4317616118356113	411a20cb716dd679c98b9c38ac28a182	VISA 16 digit	46.8168680894419538	-96.8935348578691418
27596	2020-05-29 04:11:14	2020-05-29	Sharon Feil PhD	sharon.feil.phd@geemail.com	Seattle	Washington	3088979548378531870	c2da5972fbf6ca5fcc08c27de9c28cc2	JCB 16 digit	47.6541114846635594	-122.297666178682448
27597	2020-05-29 04:20:53	2020-05-29	Kristoffer Murphy-Zieme	kristoffer.murphy.zieme@geemail.com	Sterling Heights	Michigan	3158617139098172563	e0fc71aa408ae0d1a07f9583805dcc4b	VISA 16 digit	42.5221183702431631	-82.9536702128753092
27598	2020-05-29 04:33:22	2020-05-29	Lee Williamson	lee.williamson@geemail.com	New York	New York	589332328733483	41ed3dfb7a9defb2de938d1f0b81635d	Maestro	40.7522814073357722	-73.8704519344389468
27599	2020-05-29 04:42:14	2020-05-29	Shannon Kozey	shannon.kozey@woohoo.com	Murrieta	California	52028254844931270	0339b772325f218eb650190dd89774ce	JCB 16 digit	33.5154897831477214	-117.204014732166755
27600	2020-05-29 05:03:59	2020-05-29	Dr. Drew Herzog	dr.drew.herzog@geemail.com	Los Angeles	California	3337075855179700247	db3596b60a5a53e0205496f6338578a0	VISA 13 digit	34.0496436436526437	-118.419380077160142
27601	2020-05-29 05:08:41	2020-05-29	Kandice Bosco	kandice.bosco@warmmail.com	Montgomery	Alabama	4285786859289308	2337e69633f9870b751f4b8c27041790	VISA 16 digit	32.3703413912493758	-86.2247572053842219
27602	2020-05-29 05:13:43	2020-05-29	Janice Mills	janice.mills@woohoo.com	New Haven	Connecticut	6011066762122695535	d855a2f40914d3665ba853ce1bc857a6	VISA 16 digit	41.3199842262074384	-72.9918489981908323
27603	2020-05-29 05:14:30	2020-05-29	Ms. Katlin Corwin DVM	ms.katlin.corwin.dvm@geemail.com	Phoenix	Arizona	3467824069480955	0e8dc97a05038e8b4cbcff591101ffa1	Voyager	33.5620401256650709	-112.094435624817763
27604	2020-05-29 05:17:07	2020-05-29	Dr. Rosey Zieme	dr.rosey.zieme@warmmail.com	Austin	Texas	3018704601638090	9bdb45d76676009534ce8b81050c6385	Mastercard	30.2094478048976498	-97.844715901115535
27605	2020-05-29 05:18:12	2020-05-29	Roxy Lang-Mante	roxy.lang.mante@geemail.com	Glendale	Arizona	51829970363035752	3048b3a66ecf3b110505ec689e69b657	Mastercard	33.5122509675793339	-112.106854605560741
27606	2020-05-29 05:24:43	2020-05-29	Lavonda Goodwin	lavonda.goodwin@geemail.com	San Francisco	California	676392550201898	2e30969634bc9cd9415e16c11329ea68	VISA 16 digit	37.8107819399597176	-122.462350334402259
27607	2020-05-29 05:35:22	2020-05-29	Damian Morar Jr.	damian.morar.jr.@geemail.com	Odessa	Texas	52661211570589732	734838cf2aee56a28bf0ce4bf69b759f	VISA 16 digit	31.9212851041007788	-102.249647651907424
27608	2020-05-29 05:37:36	2020-05-29	Ms. Breanna Fritsch DVM	ms.breanna.fritsch.dvm@geemail.com	Aurora	Illinois	3019542826212005	aa6572f04a7de5c90cf91b45cfbca080	Voyager	41.7775958746895171	-88.319676352797444
27609	2020-05-29 05:55:10	2020-05-29	Brennon Bahringer Sr.	brennon.bahringer.sr.@geemail.com	Detroit	Michigan	180020986151237787	4ef974e959ac9d8358ca948ee99d9fef	VISA 13 digit	42.3774550685118925	-83.0974401299029495
27610	2020-05-29 06:05:30	2020-05-29	Marylee Hettinger	marylee.hettinger@woohoo.com	Fort Worth	Texas	54865575290603575	4b7f6242e48b8c98092e7ccf2658f123	Voyager	32.6920058785527985	-97.2521730242118281
27611	2020-05-29 06:09:12	2020-05-29	Mr. Roddy Runte Jr.	mr.roddy.runte.jr.@geemail.com	San Francisco	California	3056184091062386	eeb36878c7785df242713377ae291b8d	VISA 13 digit	37.7574342213704739	-122.400825529679508
27612	2020-05-29 06:11:23	2020-05-29	Valentine Medhurst III	valentine.medhurst.iii@geemail.com	San Francisco	California	6011943733569425578	ef93416f0b76b33d9f0dbdbb99bb0ae3	Discover	37.7439566805946924	-122.444711907753813
27613	2020-05-29 06:12:16	2020-05-29	Paralee Streich DDS	paralee.streich.dds@geemail.com	Chicago	Illinois	4727287915457902	256128c98219128f025d6b807e8b90a9	Mastercard	41.8154618341311846	-87.6570817086409733
27614	2020-05-29 06:12:18	2020-05-29	Ms. Jorja Hyatt	ms.jorja.hyatt@geemail.com	Nashville	Tennessee	4869973570142537	c03362724fa0a57e96b6deaa3e1a8c6c	VISA 13 digit	36.0799296319607592	-86.7245849726628535
27615	2020-05-29 06:25:53	2020-05-29	Benjiman Reichert-Torp	benjiman.reichert.torp@geemail.com	Detroit	Michigan	4035551335306	8bcbd2466f8b15f45ade3a573f8694a0	JCB 16 digit	42.3758642694838343	-83.1467589593145959
27616	2020-05-29 06:29:42	2020-05-29	Lacy Harber	lacy.harber@geemail.com	San Antonio	Texas	53322579400669077	e670dd166c781b2548ef6f0c587cd842	VISA 16 digit	29.4278295258130882	-98.4725401612300431
27617	2020-05-29 06:32:40	2020-05-29	Laurine Wyman-Christiansen	laurine.wyman.christiansen@geemail.com	Everett	Washington	3791105220808072	654f6431cf647009218e926def69e55e	JCB 15 digit	47.9434417705874907	-122.091426493333287
27618	2020-05-29 06:36:18	2020-05-29	Yadira Balistreri	yadira.balistreri@geemail.com	Toledo	Ohio	54317227219097976	fa2eedef72ca2623a8ef22cf26dfd45e	Maestro	41.6051317908972464	-83.5013703207817031
27619	2020-05-29 06:40:12	2020-05-29	Elberta Emmerich	elberta.emmerich@geemail.com	San Francisco	California	4126147570983	dba1dacdd2642e13ee07d47cd93f7043	Discover	37.7778761116255026	-122.449807882896835
27620	2020-05-29 06:53:29	2020-05-29	Geraldine Reichel	geraldine.reichel@geemail.com	Los Angeles	California	55567221578295476	2876b2170f4b889ea392b8c6d6621096	JCB 16 digit	34.0036177174985355	-118.507880171108241
27621	2020-05-29 07:04:27	2020-05-29	Dr. Emily Johns MD	dr.emily.johns.md@geemail.com	El Paso	Texas	869934170802482399	404d49c158cf0f863d58ae42739427ee	JCB 15 digit	31.8528328719843188	-106.37476799399407
27622	2020-05-29 07:06:44	2020-05-29	Maryjo Cole	maryjo.cole@warmmail.com	Charlotte	North Carolina	4850248912192966	002eec81912414ae6d6e7493a214b10e	JCB 16 digit	35.2084157368421558	-80.8191433575414209
27623	2020-05-29 07:12:12	2020-05-29	Donnie Braun	donnie.braun@woohoo.com	Lubbock	Texas	503832308855637	7e8abf3dc918af3244414f8e8413bbb9	American Express	33.6549185575027039	-101.960184655795629
27624	2020-05-29 07:17:06	2020-05-29	Kaden Simonis	kaden.simonis@warmmail.com	San Francisco	California	4678690073721457	fe4469b37cabee5fe2013b07c8ed79be	JCB 15 digit	37.7619386064335743	-122.424959255262365
27625	2020-05-29 07:27:31	2020-05-29	Elian Gleichner-Will	elian.gleichner.will@geemail.com	Phoenix	Arizona	4818836314927	85d29dc2adb20643cdbe5fc9c6983e36	Mastercard	33.537763286002729	-112.101123647384725
27626	2020-05-29 07:31:06	2020-05-29	Mozell Reinger PhD	mozell.reinger.phd@geemail.com	Albuquerque	New Mexico	4997477796880206	cda423c6b5ed6c4b97bae35819674b83	JCB 16 digit	35.1320077785890561	-106.668628988049562
27627	2020-05-29 08:00:42	2020-05-29	Brendan Sporer-Ryan	brendan.sporer.ryan@warmmail.com	San Antonio	Texas	4041689349094	7b8fc3d350fac707dc4b7d91d589ce4c	Maestro	29.3788863784704368	-98.5336396410431661
27628	2020-05-29 08:09:30	2020-05-29	Destini Prosacco-Goyette	destini.prosacco.goyette@geemail.com	Laredo	Texas	4962501543798	170f5a88c45a1003f482a0b9c494ef82	Discover	27.5565659721098868	-99.527872625925383
27629	2020-05-29 08:12:12	2020-05-29	Emery Cummings	emery.cummings@geemail.com	Mobile	Alabama	180090684151673045	184c1028ba0b1e1ba25787faa6083907	Diners Club / Carte Blanche	30.6356761349938793	-88.1047415577944406
27630	2020-05-29 08:16:38	2020-05-29	Skyler Moore	skyler.moore@geemail.com	San Francisco	California	4180396326070277	053437104d4c3b9db2089f884d8cba1c	Diners Club / Carte Blanche	37.7635308510722467	-122.433388167441379
27631	2020-05-29 08:17:59	2020-05-29	Kandy Kuphal	kandy.kuphal@geemail.com	Las Vegas	Nevada	4060584622195063	e49c2c989f56c4bdc1c1e143869505f7	Maestro	36.3122841885413976	-115.32412553762309
27632	2020-05-29 08:29:28	2020-05-29	Brisa Weber	brisa.weber@geemail.com	Columbia	South Carolina	3088137392874651422	40bccab9d19f5bf8c796684a23e5bada	VISA 13 digit	33.9898780524995203	-80.9268859657477577
27633	2020-05-29 08:38:34	2020-05-29	Wendi Stoltenberg	wendi.stoltenberg@woohoo.com	Kansas City	Kansas	060452883384225	0ee452330112f73576c464a3f31c4931	Voyager	39.1716656547877946	-94.6903963325016207
27634	2020-05-29 08:39:44	2020-05-29	Audley Reilly	audley.reilly@geemail.com	Aurora	Colorado	4583427344882352	0977d05df1ad227429fc09b360ce39bb	JCB 15 digit	39.7738210231643166	-104.660379516065873
27635	2020-05-29 08:39:55	2020-05-29	Gary Wyman	gary.wyman@geemail.com	Glendale	California	4294979849972	6f33110f37c7900e3c4096931d278156	Discover	34.1997094274252618	-118.343806474319848
27636	2020-05-29 08:40:23	2020-05-29	Raymon Wolf	raymon.wolf@warmmail.com	Cambridge	Massachusetts	3158679168369886630	ef4cb98866d103d4a3ffd9189331ddc7	VISA 13 digit	42.44275466774031	-71.1440224861342472
27637	2020-05-29 08:42:40	2020-05-29	Eddy Kshlerin	eddy.kshlerin@geemail.com	Berkeley	California	3735472042623074	cd90acf3404184ffefe8ad1848157d37	Mastercard	37.859234651302387	-122.252920411861169
27638	2020-05-29 08:52:48	2020-05-29	Nathaniel Hamill	nathaniel.hamill@geemail.com	Chicago	Illinois	54558514907014464	b28d2d69041b466c5e082c62276055f7	JCB 16 digit	41.8463501058820668	-87.6266207143228399
27639	2020-05-29 08:56:01	2020-05-29	Candice Kunde	candice.kunde@geemail.com	Oakland	California	4636652761017	390724a7e739e004736bed91e43c2826	Mastercard	37.7870057105143076	-122.259957534516332
27640	2020-05-29 09:02:17	2020-05-29	Jeptha Champlin	jeptha.champlin@geemail.com	Los Angeles	California	4526159298498717	1c695d4fda83b08a1bfdca4c42f43d0c	VISA 16 digit	34.0383651334658239	-118.445884969643501
27641	2020-05-29 09:02:32	2020-05-29	Chaim Lakin	chaim.lakin@warmmail.com	Worcester	Massachusetts	4030874521642506	e05d7a74efe70d97da4d66fe9d494394	VISA 16 digit	42.2840610510371633	-71.7221142210319584
27642	2020-05-29 09:03:12	2020-05-29	Miss Tiffanie Greenfelder DVM	miss.tiffanie.greenfelder.dvm@geemail.com	Berkeley	California	6011997516136105335	ac115f9e39140c97bf3bb8e7bb390878	Diners Club / Carte Blanche	37.8804857239438348	-122.254879233258023
27643	2020-05-29 09:17:37	2020-05-29	Rikki Stoltenberg-Okuneva	rikki.stoltenberg.okuneva@geemail.com	New York	New York	4165424881756459	3e54e91445d1aa7a51c9507f7e83abfa	Maestro	40.6253123152758917	-73.8741624965228141
27644	2020-05-29 09:19:05	2020-05-29	Miss Olivine Hodkiewicz	miss.olivine.hodkiewicz@woohoo.com	Vancouver	Washington	869937850968508957	53433805c76e7591ffc464ffe12949f8	Mastercard	45.6052112965449723	-122.668996053102234
27645	2020-05-29 09:26:42	2020-05-29	Reed Dibbert	reed.dibbert@geemail.com	San Francisco	California	869954039177441303	fbda668d602aee9b388dcea976800425	Mastercard	37.7773441081924801	-122.395920206783103
27646	2020-05-29 09:28:27	2020-05-29	Mr. Albin Wilkinson	mr.albin.wilkinson@geemail.com	Fontana	California	869942214948875908	e9669862c489b95fc91c26d8f163c8ca	JCB 16 digit	34.0957654758971174	-117.396166012929385
27647	2020-05-29 09:40:10	2020-05-29	Olene Schoen-Herzog	olene.schoen.herzog@geemail.com	Los Angeles	California	4101375413705777	ce872433ce2c51fe4107baf45abe32f8	Discover	33.926629129970074	-118.352314842584718
27648	2020-05-29 09:57:35	2020-05-29	Veva Moore	veva.moore@warmmail.com	New York	New York	3019554238911140	626ba9c8950267a571351ee4dfcb0bd5	VISA 16 digit	40.7307163282055384	-73.9078969008184998
27649	2020-05-29 09:59:48	2020-05-29	Emmer Parisian	emmer.parisian@geemail.com	Sacramento	California	060404964920039	91297c117f7f4aa88c3124bc6de5de1d	JCB 15 digit	38.5924501265198003	-121.380973712006949
27650	2020-05-29 10:03:42	2020-05-29	Vernal Larson	vernal.larson@geemail.com	Tacoma	Washington	51130566570192610	de64adbf08dd10e023a07d06b29800d8	Discover	47.3371238923285205	-122.466421430208911
27651	2020-05-29 10:03:49	2020-05-29	Somer Bode	somer.bode@geemail.com	Aurora	Colorado	3440799808469315	8e8271d975195ba71be7365426f34e43	Voyager	39.6951408784482638	-104.614041126997023
27652	2020-05-29 10:05:38	2020-05-29	Beckham Kunze	beckham.kunze@geemail.com	Memphis	Tennessee	51079239467206504	7cb97941064014e914af650d34b6b736	Maestro	35.1630221510373104	-89.8995339117735597
27653	2020-05-29 10:13:10	2020-05-29	Clovis Wehner	clovis.wehner@geemail.com	Ann Arbor	Michigan	3528146409498580701	aa0caca3cff7bbc87d40e6a5c1ae484b	Mastercard	42.2931806100126337	-83.6529892297569688
27654	2020-05-29 10:16:35	2020-05-29	Miss Keisha Parker DVM	miss.keisha.parker.dvm@woohoo.com	St. Petersburg	Florida	4324110663893713	b0b42982e3574876156de3d913582bca	Discover	27.6685516478847724	-82.6457776216216331
27655	2020-05-29 10:18:09	2020-05-29	Martina Gutmann DVM	martina.gutmann.dvm@geemail.com	San Francisco	California	869915070029194483	188c85e4789b235d92154a25ee178f33	Voyager	37.7668181935338012	-122.422088532924633
27656	2020-05-29 10:30:42	2020-05-29	Mirtie Zieme-Grant	mirtie.zieme.grant@warmmail.com	Mobile	Alabama	869916138369580550	ba753094030defa50a829c257676e50f	Maestro	30.6107640756867809	-88.0269001238185922
27657	2020-05-29 10:30:50	2020-05-29	Victoria Lakin	victoria.lakin@geemail.com	Moreno Valley	California	6011895623245164907	d17ccd58df0928e7226e606ab621619b	VISA 16 digit	33.9010344425674504	-117.121058282066869
27658	2020-05-29 10:36:13	2020-05-29	Philomene Kovacek	philomene.kovacek@geemail.com	Chicago	Illinois	869989407166530155	3891a7bc4abed9a2749e42a889975600	Diners Club / Carte Blanche	41.8265473629184115	-87.7226631679601923
27659	2020-05-29 10:45:44	2020-05-29	Rosina Bartoletti	rosina.bartoletti@geemail.com	Lancaster	California	51655103379499015	1ac197a76dc42147a0883353b2f6320c	JCB 16 digit	34.7845667474683395	-118.240966739456354
27660	2020-05-29 10:46:24	2020-05-29	Brandan Stiedemann	brandan.stiedemann@geemail.com	Montgomery	Alabama	869922999839595896	fb4fd62d7865c63a568939ccf2133d53	Mastercard	32.3959563816364877	-86.1933083338350059
27661	2020-05-29 11:04:31	2020-05-29	Garner Macejkovic	garner.macejkovic@geemail.com	San Francisco	California	4630796162336995	e945a8184830f2fc0e3ab81148d8cd54	VISA 16 digit	37.7937001220634059	-122.422023255110432
27662	2020-05-29 11:06:33	2020-05-29	Gabriela Borer	gabriela.borer@woohoo.com	Madison	Wisconsin	3158893492349020064	9a4ba8fda2dab69f4e65a9469523273e	Maestro	43.0247667664170308	-89.3517848960008507
27663	2020-05-29 11:23:00	2020-05-29	Vere Collins Jr.	vere.collins.jr.@geemail.com	Macon	Georgia	4562593787151558	277c83c4bf01faa8b1831d867994ebc0	VISA 16 digit	32.8022363734908353	-83.5970844915330389
27664	2020-05-29 11:25:17	2020-05-29	Jocelyne Mills	jocelyne.mills@geemail.com	Pittsburgh	Pennsylvania	3158908276536052185	1908de0b2f9bc78af38d6f3560039f35	Mastercard	40.3953313490331141	-79.9148895843591589
27665	2020-05-29 11:34:53	2020-05-29	Isom Denesik	isom.denesik@geemail.com	Hialeah	Florida	3088316294040799965	b515520f022f4a60995557a4cbaa4536	VISA 16 digit	25.7852781073167918	-80.2944692888665941
27666	2020-05-29 11:39:04	2020-05-29	Vander Stiedemann-Lang	vander.stiedemann.lang@woohoo.com	San Francisco	California	53784463191740028	f8ea8754589af36341c98f3f5051a509	VISA 13 digit	37.7784707974728988	-122.445077517109439
27667	2020-05-29 11:40:42	2020-05-29	Mrs. Myranda Bode PhD	mrs.myranda.bode.phd@geemail.com	San Diego	California	3158477641936916597	4ba189c5210879a369b3c6a97aeff726	Voyager	32.8642217418246005	-117.109198686564341
27668	2020-05-29 11:41:13	2020-05-29	Myrle Harris	myrle.harris@geemail.com	Bakersfield	California	869927863262100381	7624f789d0453e73c1c8ed9de1d69200	VISA 16 digit	35.3927401843190168	-118.996603761407727
27669	2020-05-29 11:52:38	2020-05-29	Miss Marilou Beer	miss.marilou.beer@geemail.com	New York	New York	4763423736555	4da4889a9181d857ac7449b148f25f86	American Express	40.7419656161442418	-73.9879968298029098
27670	2020-05-29 12:01:26	2020-05-29	Elvie Harris	elvie.harris@geemail.com	New York	New York	6011613226539733832	d02baac2a6b2e1cbc4410e977cde36cb	Mastercard	40.7453436229135804	-73.8427621087420647
27671	2020-05-29 12:04:09	2020-05-29	Kadin Boyer	kadin.boyer@woohoo.com	Honolulu	Hawaii	869934058306953272	811504fd4a43d849cd1b1ceb270e1068	American Express	21.2286750765267769	-157.824050725877669
27672	2020-05-29 12:08:56	2020-05-29	Shannon Olson-Schultz	shannon.olson.schultz@geemail.com	Berkeley	California	869954306535596023	2b3c40a22d898f77165e6c6dbc792d02	VISA 16 digit	37.8762331681018338	-122.25382584229385
27673	2020-05-29 12:29:12	2020-05-29	Rena Crist	rena.crist@warmmail.com	Chicago	Illinois	3528379042012745613	5a4f839c3e0ff3c2687d1339fa6d0759	VISA 13 digit	41.8382691493559662	-87.7680603512126964
27674	2020-05-29 12:39:07	2020-05-29	Clement Toy	clement.toy@woohoo.com	Greensboro	North Carolina	4027796340626920	2f4e060a78db4f37033f906681b21aef	Maestro	36.172746424900744	-79.748575374156232
27675	2020-05-29 12:39:33	2020-05-29	Abie Ferry	abie.ferry@geemail.com	Oakland	California	210056319574216013	c02da03d1cbdc89370113459cd8f8ade	Discover	37.7681350897351606	-122.304825445873419
27676	2020-05-29 12:45:29	2020-05-29	Jovan Schmidt	jovan.schmidt@geemail.com	Bridgeport	Connecticut	869943998612500185	346aad6dec092ce2832f3c26c1b186a1	Maestro	41.2728232633952032	-73.196455136816212
27677	2020-05-29 12:48:50	2020-05-29	Pearley Altenwerth IV	pearley.altenwerth.iv@woohoo.com	Tucson	Arizona	3158144246860963525	aa0448ad9958adf56e801701a396ae53	VISA 13 digit	32.1978953732218613	-110.804165071923649
27678	2020-05-29 13:03:17	2020-05-29	Marlyn Homenick	marlyn.homenick@woohoo.com	Tampa	Florida	6011543837724656821	b6de951a5db05eb49747a3c7b11b0121	Mastercard	28.0498040215227746	-82.5322408490560946
27679	2020-05-29 13:04:47	2020-05-29	Reinaldo Hand MD	reinaldo.hand.md@woohoo.com	Charlotte	North Carolina	503817963452994	a63a1449c1610c4d3fa6a5ee7afc2543	Maestro	35.2589765387374925	-80.8443008758537474
27680	2020-05-29 13:11:54	2020-05-29	Obed Kuvalis	obed.kuvalis@geemail.com	New York	New York	4348068719648147	ec852f7612ba68a17c779498b4b37611	Diners Club / Carte Blanche	40.7163453486505915	-73.9648067064013333
27681	2020-05-29 13:15:57	2020-05-29	Dr. Cyrus Harber	dr.cyrus.harber@woohoo.com	Madison	Wisconsin	3112472564419425735	2f7570a3dd883b25e3e09e42cff93567	Maestro	43.0894941909212648	-89.390092956216634
27682	2020-05-29 13:38:40	2020-05-29	Leyla Pfannerstill	leyla.pfannerstill@warmmail.com	Houston	Texas	210008924911245317	276c1f982cc304fbd917d348ea015c71	Maestro	29.8812857444010689	-95.3925662651673036
27683	2020-05-29 13:39:35	2020-05-29	Kris Treutel	kris.treutel@geemail.com	Sacramento	California	3499538230880693	7a0e34a232e3391042e369772a07e4b1	Mastercard	38.5789006444890035	-121.532246636251358
27684	2020-05-29 13:40:59	2020-05-29	Mitchel Hoeger DDS	mitchel.hoeger.dds@geemail.com	San Francisco	California	3096018313913334816	4e1f4f0e39132be3836d28c29af41c8e	American Express	37.7820945751074859	-122.416953905922128
27685	2020-05-29 13:48:57	2020-05-29	Chestina Pagac	chestina.pagac@geemail.com	San Francisco	California	4074949751817	ac97815f65bd2ea4896114892c6a3c25	Discover	37.7238883340261069	-122.44984487592825
27686	2020-05-29 13:52:11	2020-05-29	Miss Audrina Schumm MD	miss.audrina.schumm.md@geemail.com	Elk Grove	California	3112175984729588438	71f0547f4020a81a6253daf70ba6939f	VISA 16 digit	38.4806191567614704	-121.395481857229029
27687	2020-05-29 14:09:39	2020-05-29	Mrs. Emerson Kohler	mrs.emerson.kohler@geemail.com	Glendale	Arizona	4034691501094581	cef1aa939224e50fa3cfbc2d37a04ef6	VISA 16 digit	33.456806284957004	-112.144498891176283
27688	2020-05-29 14:13:14	2020-05-29	Mr. Khalil Pollich III	mr.khalil.pollich.iii@geemail.com	San Antonio	Texas	6011898314336295274	d29fb1189289e8124e5d3c1992b91530	JCB 15 digit	29.3983004527237277	-98.430865467090527
27689	2020-05-29 14:23:49	2020-05-29	Miss Tanika Nienow	miss.tanika.nienow@warmmail.com	Simi Valley	California	6011782878650416210	c4ec37133c423dcda721e7855443e677	JCB 15 digit	34.2370696876902159	-118.799606435153635
27690	2020-05-29 14:25:41	2020-05-29	Dr. Jaheim Powlowski	dr.jaheim.powlowski@warmmail.com	Knoxville	Tennessee	3442134005342735	c4c467dd6a9b36b4fa9e5c34506a6408	JCB 16 digit	36.043683310325072	-84.0425418785989251
27691	2020-05-29 14:39:37	2020-05-29	Levi Cummings	levi.cummings@warmmail.com	Tacoma	Washington	3046760999015137	a480023da59c067f39876753ed308d88	VISA 13 digit	47.1864601011507219	-122.446127899107708
27692	2020-05-29 14:46:54	2020-05-29	Elfie Roberts	elfie.roberts@geemail.com	Meridian	Idaho	180094085094934807	471641cb66dd86208e51f63cbcfe22ba	Discover	43.5241112971220119	-116.319665626803044
27693	2020-05-29 14:48:47	2020-05-29	Makenzie Koss-Hansen	makenzie.koss.hansen@woohoo.com	Chicago	Illinois	3528695225742045787	1b24d4aa84c13213d15d91f44765c881	VISA 16 digit	41.905554818205907	-87.6357335205685359
27694	2020-05-29 14:57:50	2020-05-29	Ms. Willie Nienow MD	ms.willie.nienow.md@geemail.com	Houston	Texas	4192151395790	0b34fbbe05f9f62f706ea0fd36b5dafb	JCB 16 digit	29.7822503559369594	-95.4826329556308764
27695	2020-05-29 14:58:36	2020-05-29	Mr. Rickey Homenick	mr.rickey.homenick@geemail.com	San Francisco	California	4348972673927712	cb20e186c1385539898f48a919e1169e	Discover	37.7723324720613789	-122.435668318012617
27696	2020-05-29 15:09:38	2020-05-29	Dr. Elissa Medhurst	dr.elissa.medhurst@geemail.com	San Bernardino	California	6011656626984057223	4bd1a048cc9b2999029d8886ff25cc02	American Express	34.0954450237363531	-117.222527690209816
27697	2020-05-29 15:15:35	2020-05-29	Dr. Shania Kub	dr.shania.kub@warmmail.com	New York	New York	3112201941540419027	5335f9751a85ef55d71b3fafd7c5e3c2	JCB 16 digit	40.6820276928823432	-73.919807030622664
27698	2020-05-29 15:17:01	2020-05-29	Dr. Ardelle Hane	dr.ardelle.hane@geemail.com	Norman	Oklahoma	4959515288038720	06ef036d84220066e863558d7f7ff001	Voyager	35.1875047469086937	-97.2510799002155579
27699	2020-05-29 15:22:54	2020-05-29	Forrest Kreiger	forrest.kreiger@warmmail.com	Columbus	Ohio	6011215290519327108	aa861fe273e9e0ad3fc47570bfb908ad	JCB 15 digit	39.9087223617404661	-83.0414838587634279
27700	2020-05-29 15:24:00	2020-05-29	Dr. Fernando White V	dr.fernando.white.v@geemail.com	San Francisco	California	561278800940765	cabfb89f525900db91a5c9b745d5dc3d	Voyager	37.7453552216588051	-122.42705594855633
27701	2020-05-29 15:43:10	2020-05-29	Lydia Pagac PhD	lydia.pagac.phd@geemail.com	Los Angeles	California	869914591244197119	f857f98aa63f204acf85cce3612fa90e	VISA 16 digit	33.9736655588127618	-118.374753788066272
27702	2020-05-29 15:47:15	2020-05-29	Gorden Kunze	gorden.kunze@warmmail.com	Brownsville	Texas	3088623391308762541	8bfe70611d4afe22070e6715b8ce8eaa	Discover	25.9471577703099676	-97.4509803495090381
27703	2020-05-29 15:49:11	2020-05-29	Jodie Rosenbaum	jodie.rosenbaum@warmmail.com	Phoenix	Arizona	3755629835988494	23c85b59f5deefd4b06d82baaa585e78	JCB 16 digit	33.5497728755164886	-112.052105609786139
27704	2020-05-29 15:58:48	2020-05-29	Barron Corwin	barron.corwin@geemail.com	Indianapolis	Indiana	4793164854575425	416f147ce674ee406ad72f1cebcbfae4	Mastercard	39.7829222036067378	-86.0823907197188589
27705	2020-05-29 15:59:20	2020-05-29	Mr. Faron Koss DVM	mr.faron.koss.dvm@geemail.com	Newark	New Jersey	3003446250165992	858e792f300171cd2c3c53229074fd11	Maestro	40.7238025595814008	-74.2005497180134057
27706	2020-05-29 16:01:25	2020-05-29	Erykah Quitzon	erykah.quitzon@warmmail.com	Durham	North Carolina	55256996901260893	b9033526da022ed27d1daa23a766bbe4	JCB 16 digit	35.9522426052730495	-78.864312293743339
27707	2020-05-29 16:10:50	2020-05-29	Sophia Funk	sophia.funk@geemail.com	Topeka	Kansas	210028628637861770	802a68eb279a30a9d6f04c694381977d	Maestro	39.0497052879005651	-95.7063245311554596
27708	2020-05-29 16:16:27	2020-05-29	Euphemia Crooks	euphemia.crooks@geemail.com	Oklahoma City	Oklahoma	4970055398738310	b1f82d65fdf996585c50fb5a60707e84	VISA 16 digit	35.4030684775117805	-97.5893513214670065
27709	2020-05-29 16:30:00	2020-05-29	Talan Torphy	talan.torphy@geemail.com	New York	New York	4608517705943	f08da74a2f3797e695b4dc90eec8efa9	American Express	40.661989688057453	-73.9290952626045765
27710	2020-05-29 16:48:00	2020-05-29	Dr. Acey Crooks	dr.acey.crooks@geemail.com	Plano	Texas	54684914456334403	1bd3e80cc5ae1e8d9b435efbc7635d81	VISA 16 digit	33.0377922490790539	-96.819771786704294
27711	2020-05-29 16:53:35	2020-05-29	Dr. Philo Bahringer DDS	dr.philo.bahringer.dds@geemail.com	Tulsa	Oklahoma	060482529652065	589ef037c614632e5707d255d86772d0	VISA 13 digit	36.0658027151037004	-95.9375593235671431
27712	2020-05-29 16:57:31	2020-05-29	Benjamin Altenwerth Sr.	benjamin.altenwerth.sr.@geemail.com	Riverside	California	3444898656927469	b4de326e88d27273b15e540ddb18b691	Maestro	33.9319413064461202	-117.299249980549135
27713	2020-05-29 17:01:51	2020-05-29	Tessie O'Conner	tessie.o'conner@warmmail.com	Yonkers	New York	869959017158706451	fb44a417f8b852581caec9acadc2d963	Discover	40.9346168826535362	-73.8358672291856237
27714	2020-05-29 17:13:22	2020-05-29	Maebell Stokes-Christiansen	maebell.stokes.christiansen@geemail.com	Oceanside	California	3158671567000536553	84ad7dc602dd5957a4e4def7cd5f1a8c	Mastercard	33.1384021892100549	-117.373732845586545
27715	2020-05-29 17:22:17	2020-05-29	Jeanine Jerde	jeanine.jerde@geemail.com	Sterling Heights	Michigan	869923844571350630	81ab98c5ba3d9e1c29e0c6dc460eb8a3	VISA 13 digit	42.5351023592602502	-82.9595146259918721
27716	2020-05-29 17:24:16	2020-05-29	Kunta Greenholt	kunta.greenholt@warmmail.com	Los Angeles	California	4888031552601843	305b596e9ce5b60b75b7c85fc6a24dde	VISA 16 digit	33.9844176745839377	-118.319228883878509
27717	2020-05-29 17:28:55	2020-05-29	Anona Huels	anona.huels@warmmail.com	Charleston	South Carolina	3022884844648134	751a0c6ddc704a4a05587c76641fbcc2	JCB 16 digit	32.8599027513522657	-79.9855862545464191
27718	2020-05-29 17:31:47	2020-05-29	Dr. Marisol Cruickshank	dr.marisol.cruickshank@woohoo.com	Dallas	Texas	676168285920168	fe38c865a539f5885722126d0335240b	JCB 16 digit	32.7900514987569309	-96.7643240184485904
27719	2020-05-29 17:41:37	2020-05-29	Rhonda Parisian	rhonda.parisian@geemail.com	Dallas	Texas	51618864191521163	8d4e6ceaa251f89348f30fed25cac48e	VISA 16 digit	32.6991851546607961	-96.7092801578305625
27720	2020-05-29 17:42:05	2020-05-29	Fidelia Lowe	fidelia.lowe@warmmail.com	McAllen	Texas	3112201249320904246	09b7691aa54eed48df730a55308c1dfd	Voyager	26.3179767351902996	-98.3183186753500138
27721	2020-05-29 18:00:07	2020-05-29	Arminta Nader MD	arminta.nader.md@geemail.com	Boston	Massachusetts	869913675753688633	7e71a8e456daa0cc055eef205948e4d1	JCB 16 digit	42.2327163807749741	-71.094791794423756
27722	2020-05-29 18:01:40	2020-05-29	Dr. Shaina Mann	dr.shaina.mann@geemail.com	San Diego	California	4790211278239402	477990161e4fd26dd7be4f717a4ad151	Maestro	32.8227741903692518	-117.188023681184276
27723	2020-05-29 18:23:42	2020-05-29	Rena Jacobson	rena.jacobson@warmmail.com	Sacramento	California	3158088828643519639	d7198b8a1175e9f874ee56a0371a6b2f	JCB 15 digit	38.6517864769589181	-121.432379676612456
27724	2020-05-29 18:28:39	2020-05-29	Racheal Deckow	racheal.deckow@geemail.com	Clarksville	Tennessee	3112411413238875783	d020e95ab57033c460c5a012d144c533	VISA 13 digit	36.5584113742351562	-87.3514534154392805
27725	2020-05-29 19:00:45	2020-05-29	Ham Kreiger-Walker	ham.kreiger.walker@geemail.com	Portland	Oregon	3112746354230217903	0badb2a3d7587a7243655d72383cbc06	VISA 16 digit	45.5955706816520561	-122.609030383778745
27726	2020-05-29 19:03:55	2020-05-29	Ms. Halie Donnelly DVM	ms.halie.donnelly.dvm@geemail.com	Norman	Oklahoma	4466928193576369	f21998a986210fe42daf1a68de3c6b14	VISA 16 digit	35.2082111782435305	-97.296023263621322
27727	2020-05-29 19:09:41	2020-05-29	Dennie Schultz	dennie.schultz@woohoo.com	Gilbert	Arizona	180000436295210849	1498297689995a197bedc5998d1b3d4a	JCB 16 digit	33.2804007703319158	-111.806081057073925
27728	2020-05-29 19:09:42	2020-05-29	Mrs. Terra Schinner PhD	mrs.terra.schinner.phd@geemail.com	San Francisco	California	869915810061202235	61492d47bfb7096227e76ef70fa488ca	Mastercard	37.8024691448899475	-122.405827489379277
27729	2020-05-29 19:19:59	2020-05-29	Mrs. Ethie Dibbert	mrs.ethie.dibbert@geemail.com	San Francisco	California	3040580509231123	b222808ba577350b3c74fd92e8a47ea6	VISA 16 digit	37.7472289347697156	-122.455156600783425
27730	2020-05-29 19:24:04	2020-05-29	Bo Langworth	bo.langworth@warmmail.com	San Francisco	California	3705083573064186	286ec69e6feb2bdf2f4fa31876dbb230	VISA 16 digit	37.8143146250162587	-122.429442540183175
27731	2020-05-29 19:26:14	2020-05-29	Xena Konopelski	xena.konopelski@geemail.com	New York	New York	4760094173985	7e32a1c48ad7df7628ca5ac9affa21b0	Voyager	40.7356193437464498	-73.9796186787903309
27732	2020-05-29 19:40:20	2020-05-29	Sal Goodwin	sal.goodwin@geemail.com	Elk Grove	California	4883614513538	5251dc1bc22cc5695df9393bd2e11138	Diners Club / Carte Blanche	38.3965830722175525	-121.343315509557726
27733	2020-05-29 19:44:23	2020-05-29	Eusebio Stokes	eusebio.stokes@woohoo.com	Fort Lauderdale	Florida	6011376838669344896	9f4a764920a348e00b2368786069a9d6	Mastercard	26.1337083232577889	-80.0701746554866389
27734	2020-05-29 19:47:18	2020-05-29	Ashleigh Lebsack	ashleigh.lebsack@geemail.com	Wichita	Kansas	4248635596558374	6f3ecc49e99994c0fab423baedda5a6d	Maestro	37.7188078099738817	-97.4429808743964827
27735	2020-05-29 19:52:37	2020-05-29	Maura Raynor	maura.raynor@geemail.com	Milwaukee	Wisconsin	4523678217131938	1ad1eb041ec64b87349e4e859f5e7007	VISA 13 digit	43.1368594503581519	-87.9182110536944208
27736	2020-05-29 19:56:21	2020-05-29	Ms. Tanesha Hartmann DDS	ms.tanesha.hartmann.dds@woohoo.com	New York	New York	676399498490723	d22a00880c7df1c5b37620dec892ac59	JCB 16 digit	40.7059608769360892	-73.8427157034527539
27737	2020-05-29 20:01:00	2020-05-29	Violet Okuneva	violet.okuneva@geemail.com	San Francisco	California	561290108496291	4e733aef45a9959bbdbeb229b5d57d73	JCB 16 digit	37.750347798207379	-122.434946272560083
27738	2020-05-29 20:04:59	2020-05-29	Deward Renner I	deward.renner.i@geemail.com	Chicago	Illinois	4112733001997	e8692b00cb9e30e882584152edb54b34	Mastercard	41.8070244507234534	-87.6580075275182651
27739	2020-05-29 20:05:25	2020-05-29	Shelli McGlynn-Crooks	shelli.mcglynn.crooks@geemail.com	Los Angeles	California	3047079001113064	d84b2c4829b77a1a3615e79811d860d3	Discover	34.0934018330048758	-118.454932165471092
27740	2020-05-29 20:35:50	2020-05-29	Denver Emard	denver.emard@geemail.com	New York	New York	3790857749824607	d08fdfbf571cbee58fda956e14f54957	VISA 16 digit	40.673612441610544	-74.0272417365934672
27741	2020-05-29 20:38:03	2020-05-29	Kai Purdy	kai.purdy@geemail.com	Los Angeles	California	210095998339132962	952288485ddf1f6ecbc90534917b6a25	VISA 16 digit	33.9777536073565471	-118.391438620071114
27742	2020-05-29 20:40:15	2020-05-29	Shaquita Hilpert	shaquita.hilpert@geemail.com	Columbus	Ohio	3439168127926061	8d8b7a52687883041f29f0462f79f5ac	JCB 16 digit	39.9179243118546907	-82.9394204146929184
27743	2020-05-29 21:06:57	2020-05-29	Kasandra Schmitt	kasandra.schmitt@geemail.com	Little Rock	Arkansas	676111829863221	94c5664dcedc07f12dcc742e7be4221f	Mastercard	34.6402079495411357	-92.4442711647938893
27744	2020-05-29 21:07:19	2020-05-29	Giselle Durgan-Gorczany	giselle.durgan.gorczany@geemail.com	Green Bay	Wisconsin	676367694025999	a1fe814c40351e9026f0412f39e517db	Mastercard	44.5154316543199116	-87.9886682929758024
27745	2020-05-29 21:14:13	2020-05-29	Virdie Mohr PhD	virdie.mohr.phd@geemail.com	Lubbock	Texas	869932786352633180	fbe11dd512fb1abf2edf7d9941b76649	JCB 16 digit	33.5001293621998286	-101.857826677235593
27746	2020-05-29 21:33:11	2020-05-29	Merrill Von I	merrill.von.i@geemail.com	San Francisco	California	54395596932704083	6dec9bbd8bb953a5768cf53fe94d0e93	Discover	37.7647278525822188	-122.421237167211657
27747	2020-05-29 21:57:57	2020-05-29	Jeannette Langworth	jeannette.langworth@geemail.com	Hialeah	Florida	3337167807407143467	95802ba05c53c49a51395323da7fc175	JCB 15 digit	25.8340561274416771	-80.2165317307595132
27748	2020-05-29 22:05:02	2020-05-29	Dr. Yadiel Legros DVM	dr.yadiel.legros.dvm@warmmail.com	Kansas City	Missouri	53332124191562302	012aaa8172302af56456237fbabd5482	JCB 16 digit	39.0720357276335406	-94.5696369827948473
27749	2020-05-29 22:15:23	2020-05-29	Vita Rau-Pacocha	vita.rau.pacocha@warmmail.com	Pearland	Texas	4866668484300	d308465b22ecda6a517ac588abd2b986	JCB 15 digit	29.5755190579492613	-95.2572546026524094
27750	2020-05-29 22:27:57	2020-05-29	Brien Legros	brien.legros@geemail.com	San Antonio	Texas	4755154366789016	dc842407e4127c43a8c238b4733ea128	VISA 13 digit	29.5568064781907935	-98.492422534229604
27751	2020-05-29 22:31:32	2020-05-29	Marcelle Cronin PhD	marcelle.cronin.phd@geemail.com	Joliet	Illinois	3772729569414284	ed5e70f67e8863059962e6de1f88869d	Voyager	41.4630237828798585	-88.158251242536295
27752	2020-05-29 22:34:48	2020-05-29	Ulises Bernier-Jacobi	ulises.bernier.jacobi@geemail.com	Austin	Texas	180070804146071964	33e8030134a0c6509b269dd8667e8a20	Diners Club / Carte Blanche	30.3935706932224328	-97.6615318580768985
27753	2020-05-29 22:36:30	2020-05-29	Mr. Philip Schulist	mr.philip.schulist@geemail.com	Murfreesboro	Tennessee	3088135962038818737	621e862f589f79d2541cfa329b96d874	VISA 16 digit	35.8118214910503525	-86.4901585182957291
27754	2020-05-29 22:37:06	2020-05-29	Dr. Kaiden McClure	dr.kaiden.mcclure@geemail.com	Thousand Oaks	California	6011495005727596554	d3202210d746a8170b0411d3a8582367	JCB 15 digit	34.1775029141727842	-118.927447164376076
27755	2020-05-29 22:38:01	2020-05-29	Mr. Boone Bayer II	mr.boone.bayer.ii@geemail.com	San Francisco	California	3046777768660232	5106eb74c3a8849a9e100b54493aa809	JCB 15 digit	37.788560780443305	-122.455093660451467
27756	2020-05-29 23:01:07	2020-05-29	Jennings Roob	jennings.roob@geemail.com	Los Angeles	California	53192411405498624	f98efedf24770182d265cb35eadced84	Maestro	33.9362036058079397	-118.473761779301981
27757	2020-05-29 23:03:38	2020-05-29	Arden Zemlak	arden.zemlak@geemail.com	Philadelphia	Pennsylvania	4494132992038	2fdf46265a0a019c725bdff94c7def55	Mastercard	39.9327241877518588	-75.0946122635055389
27758	2020-05-29 23:08:55	2020-05-29	Dr. Nikita Mitchell	dr.nikita.mitchell@geemail.com	Vista	California	869919123613402808	6fac068393dee50f7a092e12d4dfe838	Discover	33.1204809652157124	-117.293113311432677
27759	2020-05-29 23:19:06	2020-05-29	Daijah O'Reilly	daijah.o'reilly@geemail.com	Colorado Springs	Colorado	869925578476179045	5aca407f71b648f8a9138cd35b651adb	JCB 16 digit	38.895485123018922	-104.795327830376849
27760	2020-05-29 23:19:33	2020-05-29	Ms. Nikia Kuhn PhD	ms.nikia.kuhn.phd@geemail.com	Richmond	California	180007898986972396	5f7a185515e673b314035a546848eca4	Discover	37.9856200374152522	-122.341535736838736
27761	2020-05-29 23:31:55	2020-05-29	Mrs. Pluma Kunde PhD	mrs.pluma.kunde.phd@geemail.com	Tulsa	Oklahoma	4583746659444569	5b844b3eb22d3bd7d89f396b1a8ba836	Voyager	36.1616374244350922	-95.9931851641695886
27762	2020-05-29 23:34:30	2020-05-29	Tishie Fisher MD	tishie.fisher.md@woohoo.com	Memphis	Tennessee	503821461307288	38cd5ad0f087b6caef48300c3dc84420	Voyager	35.0468625136252498	-89.9704634530261131
27763	2020-05-29 23:36:26	2020-05-29	Cary Schmidt	cary.schmidt@geemail.com	Hollywood	Florida	54548349358226389	685c2ffbb8fa69fc5edad59bdb10a41b	JCB 15 digit	26.0462292673010367	-80.1771525096896909
27764	2020-05-29 23:38:05	2020-05-29	Lori Denesik	lori.denesik@geemail.com	Lexington	Kentucky	639070782524923	50fbf9e439aac7afe8a240e6d5d696f1	Voyager	38.0374560107819732	-84.4856156017996369
27765	2020-05-29 23:48:31	2020-05-29	Juelz Schumm	juelz.schumm@warmmail.com	San Francisco	California	3780778781467455	0f79c58d01e0e0fbfaf8c8c8410b590f	Mastercard	37.7795900245186473	-122.423468154119831
27766	2020-05-29 23:54:59	2020-05-29	Drew Mann-Robel	drew.mann.robel@geemail.com	Scottsdale	Arizona	4203120569272	7ad08ca501b900b14083808ce7122825	Voyager	33.6521234025370362	-111.85332771185449
27767	2020-05-29 23:57:22	2020-05-29	Hans Cremin DDS	hans.cremin.dds@geemail.com	Los Angeles	California	639037419559978	d90a546d172064d1bd1921d442652916	Discover	34.1005782993841891	-118.402187438774106
27768	2020-05-30 00:02:58	2020-05-30	Hasel Jaskolski	hasel.jaskolski@warmmail.com	Arvada	Colorado	210099039755136470	18adc2e47f34454067132169239d8944	JCB 15 digit	39.8209027135919769	-105.128975012290482
27769	2020-05-30 00:40:09	2020-05-30	Alcie Boehm-Bashirian	alcie.boehm.bashirian@geemail.com	Miami	Florida	4645631497411	936898a80d60f7708c9405bed5490b2e	Mastercard	25.8111984702430668	-80.1302723209712724
27770	2020-05-30 00:44:30	2020-05-30	Bryce Wilderman	bryce.wilderman@woohoo.com	Raleigh	North Carolina	3337299768230799795	de67e765e491193e758c00a9a2671a34	Voyager	35.7600029359705687	-78.7151505467418673
27771	2020-05-30 00:52:55	2020-05-30	Burnell Morar	burnell.morar@geemail.com	Baltimore	Maryland	589376794537035	b079d38065d63c710663b8e4e9582f67	VISA 16 digit	39.3307557499967473	-76.5285173768661906
27772	2020-05-30 00:54:46	2020-05-30	Mr. Zachary Huel	mr.zachary.huel@geemail.com	San Francisco	California	6011793671724564512	412c465b73749e70d49988765c0ff0de	Mastercard	37.7554709986767776	-122.400824276283146
27773	2020-05-30 00:56:54	2020-05-30	Dr. Shay McClure IV	dr.shay.mcclure.iv@geemail.com	Beaumont	Texas	6011553631120922821	66f3114f3fcfa6b84f3c5c6899a8b949	Voyager	30.1506957131508742	-94.0932340584017339
27774	2020-05-30 01:04:50	2020-05-30	Albina Feest	albina.feest@warmmail.com	Peoria	Illinois	3088727668453066025	f3c81054006314a7558a712a8d801434	VISA 13 digit	40.8138299355618628	-89.6185340065393632
27775	2020-05-30 01:11:22	2020-05-30	Marge Johnston-Rutherford	marge.johnston.rutherford@geemail.com	San Francisco	California	210049185917273452	edacc83a10d1c28b96149f9c4b2ad8c7	Diners Club / Carte Blanche	37.7557126616630612	-122.437872151742312
27776	2020-05-30 01:21:32	2020-05-30	Manuel Crist DVM	manuel.crist.dvm@geemail.com	Las Vegas	Nevada	869907979097873374	9fe66d26258cc87e69ba6571d700e58a	JCB 16 digit	36.31204096759744	-115.267859013865134
27777	2020-05-30 01:22:35	2020-05-30	Miss Harriett Smith MD	miss.harriett.smith.md@geemail.com	San Francisco	California	4313065850411	b7f6dc5147056188bdae761ed6b5e5de	Discover	37.7411845510292636	-122.427066837546903
27778	2020-05-30 01:22:49	2020-05-30	Vickie Cruickshank	vickie.cruickshank@geemail.com	Sacramento	California	6011117256929341525	bac558d8b70e3409a13e4911277b91e6	VISA 13 digit	38.6343345403935743	-121.368816198572887
27779	2020-05-30 01:36:44	2020-05-30	Harmon Corkery	harmon.corkery@geemail.com	Los Angeles	California	869931184919699863	65f1f8e733957822db7df64dd74e0248	Maestro	34.0257466049265105	-118.454185846866295
27780	2020-05-30 01:44:10	2020-05-30	Miss Julie Lemke	miss.julie.lemke@woohoo.com	Indianapolis	Indiana	3096635924766111789	fa019745c8bece49f588eea54034962f	VISA 13 digit	39.6795668890707205	-86.2291804260775478
27781	2020-05-30 01:45:08	2020-05-30	Miss Yulisa Tromp DDS	miss.yulisa.tromp.dds@woohoo.com	New York	New York	4356227367215208	527658148fc6937d55e2e88a5ef745f2	JCB 16 digit	40.7489466622695318	-74.0290374619316225
27782	2020-05-30 01:48:16	2020-05-30	Dr. Desmond Bernhard III	dr.desmond.bernhard.iii@geemail.com	Indianapolis	Indiana	210053560155375693	d6eb93c86ff5d340f24c245e61c0d0f3	VISA 16 digit	39.7292066304486227	-86.1656094612289252
27783	2020-05-30 01:53:45	2020-05-30	Shanita Franecki	shanita.franecki@geemail.com	Vancouver	Washington	4305929189095591	2ab247214cbaace9ffb7e46ba13acded	Maestro	45.6414509338863184	-122.621044196474173
27784	2020-05-30 02:03:11	2020-05-30	Manly Pouros	manly.pouros@geemail.com	Virginia Beach	Virginia	4826508567888	f017eaeec756b1a08720445ee29cf1e7	Diners Club / Carte Blanche	36.7480571573786463	-76.0127674782786471
27785	2020-05-30 02:18:54	2020-05-30	Lemmie Hickle	lemmie.hickle@geemail.com	Los Angeles	California	3088517271763996207	6056cfde18e0bb46aceacbbf55a461ef	Discover	34.0896134237159032	-118.311539765539763
27786	2020-05-30 02:20:25	2020-05-30	Sal Ullrich-Botsford	sal.ullrich.botsford@geemail.com	Eugene	Oregon	210084008468430584	18bf6e40b9ebd92d14297cf51c7b3e48	JCB 15 digit	44.1066690943863264	-123.084496578153974
27787	2020-05-30 02:23:32	2020-05-30	Ona Lockman-Bartell	ona.lockman.bartell@woohoo.com	Birmingham	Alabama	4628629420799726	5624c0ff527a42878494e4da3ff3d206	Mastercard	33.4862601279072436	-86.8096522860936943
27788	2020-05-30 02:25:33	2020-05-30	Naoma Bradtke DDS	naoma.bradtke.dds@woohoo.com	New Orleans	Louisiana	4459005465875	caa3aa1954e79102f71d8920ad230bf6	VISA 16 digit	30.136711391016469	-89.8426631768960533
27789	2020-05-30 02:29:08	2020-05-30	Mrs. Martha Keebler PhD	mrs.martha.keebler.phd@geemail.com	Denver	Colorado	4862639352684	10219cc1c037711220deff9891e590db	Maestro	39.857098264205824	-104.942459624611217
27790	2020-05-30 02:31:04	2020-05-30	Elza Dietrich Sr.	elza.dietrich.sr.@geemail.com	Chicago	Illinois	3337643715378306217	84c749015cbe8438cd7755f878c7ba64	Discover	41.7589736154604694	-87.7627974453411923
27791	2020-05-30 02:36:12	2020-05-30	Dr. Thor Rosenbaum Sr.	dr.thor.rosenbaum.sr.@geemail.com	Phoenix	Arizona	3088613657276537970	f0713760629f172410610421cbbc80a4	American Express	33.6410023022376024	-112.126917163880918
27792	2020-05-30 02:38:38	2020-05-30	Mozella Cummings	mozella.cummings@woohoo.com	South Bend	Indiana	869945818302716206	e0d00b2fc12940571765dfab9829fa42	JCB 15 digit	41.6422223603032577	-86.2746149598676766
27793	2020-05-30 02:44:43	2020-05-30	Corrine Gerhold	corrine.gerhold@woohoo.com	San Francisco	California	4012192874081178	282e6b9d11aef9f648a1de87b3df4456	Maestro	37.7792360376470029	-122.43445353972136
27794	2020-05-30 02:45:20	2020-05-30	Raymond Haley	raymond.haley@woohoo.com	Anchorage	Alaska	676102223067915	df405e0e32dd37e08dbb4a22387a0c0f	Discover	61.135606928470736	-149.300400968513628
27795	2020-05-30 02:45:42	2020-05-30	Rosetta Skiles MD	rosetta.skiles.md@geemail.com	Kansas City	Kansas	55122007725314569	4b0c59f8f563152b96493821c01977ab	Voyager	39.157295984346419	-94.7371205327969079
27796	2020-05-30 02:56:54	2020-05-30	Bradley Denesik	bradley.denesik@woohoo.com	Mesa	Arizona	869911217599271647	bc22617a517b9f28635e85d82e1db92f	VISA 16 digit	33.3108637699536985	-111.810596435878054
27797	2020-05-30 02:57:24	2020-05-30	Bria Collins	bria.collins@geemail.com	Denver	Colorado	6011728841773025091	848a40b837d5d4330243ece2f7714682	VISA 16 digit	39.841728830529	-104.979071899667758
27798	2020-05-30 03:01:23	2020-05-30	Mortimer Wuckert Jr.	mortimer.wuckert.jr.@warmmail.com	Stamford	Connecticut	3528511277892130564	28c59468f82bb51dc1e6fa82b48b92a7	American Express	41.0299133038498454	-73.5555884714275692
27799	2020-05-30 03:04:43	2020-05-30	Malissie Schneider	malissie.schneider@warmmail.com	Denver	Colorado	3000576862916227	8f55fd4b8eedb24e6681927288993db7	Diners Club / Carte Blanche	39.7197910191543357	-104.822351875786111
27800	2020-05-30 03:05:56	2020-05-30	Thornton Emard	thornton.emard@geemail.com	Oakland	California	3702950319083600	6747a3a9593357488976b4f34e2e0de3	American Express	37.8042728754768262	-122.287414004476943
27801	2020-05-30 03:14:34	2020-05-30	Ms. Bea Beahan DDS	ms.bea.beahan.dds@geemail.com	Richmond	California	3765530279782021	8c5a69b9ee6cc25e4206b5e334cd7059	JCB 15 digit	37.9322267126712944	-122.424345964923873
27802	2020-05-30 03:21:40	2020-05-30	Sigurd Bernhard	sigurd.bernhard@geemail.com	Mesa	Arizona	869920150721923430	619570aae40d4380aa026f53633efe6d	VISA 16 digit	33.3050397005077414	-111.740312119561807
27803	2020-05-30 03:29:32	2020-05-30	Alecia Mayert	alecia.mayert@geemail.com	Milwaukee	Wisconsin	4730494136437	31ebcb8b46f5451f15c1366700e870f6	JCB 16 digit	42.9777486887380462	-87.8675652718272033
27804	2020-05-30 03:33:33	2020-05-30	Mrs. Margarita Robel DDS	mrs.margarita.robel.dds@geemail.com	San Francisco	California	4909475991040	17a0b769428fcd930e0d1e9817381a88	American Express	37.7460991808758877	-122.440093426201187
27805	2020-05-30 03:36:35	2020-05-30	Jennifer Mayer DDS	jennifer.mayer.dds@geemail.com	Berkeley	California	4956749331149	e5047d3dca5722db0914e3fe0f904308	Maestro	37.8943721822032984	-122.284343839390203
27806	2020-05-30 03:36:37	2020-05-30	Maryam Rohan	maryam.rohan@warmmail.com	Springfield	Missouri	51535749072652627	62e2008c6a56a1d7f65885952bfe0469	JCB 16 digit	37.2122495754815645	-93.2520306436635593
27807	2020-05-30 03:38:12	2020-05-30	Cena Pacocha	cena.pacocha@geemail.com	Chicago	Illinois	180063891996774846	265bc4c7a67de343d0abe0e4bb1f29d1	JCB 16 digit	41.9140035786036407	-87.7696044453449531
27808	2020-05-30 03:38:22	2020-05-30	Emmy Robel	emmy.robel@geemail.com	New York	New York	3022959832432798	305aad04c5c59f20b6b1c722a50b6a53	JCB 16 digit	40.5684812123645102	-74.0246616838861229
27809	2020-05-30 03:38:48	2020-05-30	Mrs. Teri Erdman DDS	mrs.teri.erdman.dds@geemail.com	Long Beach	California	561217877644413	bf8164f25759106393a704dc31ca624a	VISA 13 digit	33.7391474658444466	-118.177764824933561
27810	2020-05-30 03:55:31	2020-05-30	Dora Ryan	dora.ryan@geemail.com	Anchorage	Alaska	3476117709170436	33dbdcbbaae6146f0fa25abc16a1b612	VISA 16 digit	61.1555399005983062	-149.286490124150362
27811	2020-05-30 04:09:45	2020-05-30	Lim Sporer	lim.sporer@geemail.com	San Francisco	California	180020229083841941	412c29f662378b00960e6bdddc17f53a	Mastercard	37.7683040054688632	-122.436852985282712
27812	2020-05-30 04:22:19	2020-05-30	Cheryl Murray	cheryl.murray@woohoo.com	Joliet	Illinois	869982706310781888	b9bebf70fea40bada7c1133664a15e23	JCB 16 digit	41.4757965208355301	-88.2261457785602659
27813	2020-05-30 04:37:49	2020-05-30	Eunice O'Kon	eunice.o'kon@woohoo.com	Dallas	Texas	3761794972057206	4f4c736ffe59d45096c8914633ec06d2	American Express	32.7456331743665032	-96.7778387871533567
27814	2020-05-30 04:46:45	2020-05-30	Jamarion Kris Sr.	jamarion.kris.sr.@geemail.com	Scottsdale	Arizona	6011827296449804975	9692d4914d6c7dbfb3475191fe706233	JCB 15 digit	33.7362933545030685	-111.928025136325871
27815	2020-05-30 04:47:11	2020-05-30	Mckayla Ferry	mckayla.ferry@geemail.com	San Francisco	California	4877196605553615	d062919770e17e4fa62977cb294f1e7d	JCB 15 digit	37.8239822364560041	-122.431841640871028
27816	2020-05-30 04:48:26	2020-05-30	Arley Crona	arley.crona@geemail.com	Durham	North Carolina	210058175008554991	fbc789c66b763c78dbf8ee3796f8a772	Discover	35.9842650662422159	-78.9006044158149535
27817	2020-05-30 04:51:04	2020-05-30	Cyrus Balistreri Jr.	cyrus.balistreri.jr.@geemail.com	Miami	Florida	869981960199875847	1f3f4380c87aab49100f9fe02974de12	VISA 13 digit	25.7753161240972588	-80.1351319603960945
27818	2020-05-30 04:57:10	2020-05-30	Erby O'Keefe-Leffler	erby.o'keefe.leffler@woohoo.com	New York	New York	210004727710041462	c6641f4e24dc746bd54a97ba6243a3c4	VISA 16 digit	40.5697482350040204	-73.9478515387408351
27819	2020-05-30 04:57:48	2020-05-30	Dr. Philo Nader III	dr.philo.nader.iii@geemail.com	Phoenix	Arizona	869975665518627278	5e2fdfdcc195d0073b0f42254bb0ecc0	VISA 16 digit	33.5555003219217056	-112.036021847224248
27820	2020-05-30 05:07:50	2020-05-30	Raquel Gorczany-O'Kon	raquel.gorczany.o'kon@geemail.com	San Francisco	California	630422524488636	5fe4599f4ea7e2292338c0d4455ae2b8	JCB 15 digit	37.7657005260054106	-122.432500624820022
27821	2020-05-30 05:23:32	2020-05-30	Alston Ledner III	alston.ledner.iii@warmmail.com	Columbus	Ohio	51748121012745122	0d26c1bdfd6ac38274bef2d3182185e5	Mastercard	39.9096694183580567	-82.9144441894024737
27822	2020-05-30 05:41:41	2020-05-30	Chaz Braun-Heaney	chaz.braun.heaney@geemail.com	Chicago	Illinois	51685012004671944	72d36ce97f541b582c5e061fc0d4d6e3	VISA 13 digit	41.7397687313448671	-87.7133528404433207
27823	2020-05-30 05:49:38	2020-05-30	Mathilde Upton MD	mathilde.upton.md@warmmail.com	Yonkers	New York	180051105809345742	a6c7d473ca83969920c2d0e9f2a17407	Mastercard	40.8978006903749005	-73.9563845088124339
27824	2020-05-30 06:04:56	2020-05-30	Cash Klocko-Romaguera	cash.klocko.romaguera@geemail.com	Manchester	New Hampshire	6011998747056884885	c8bfdcf9bf5caa240440e964b74af817	Discover	42.9069675676595423	-71.5081709695871979
27825	2020-05-30 06:38:24	2020-05-30	Christine Hayes	christine.hayes@geemail.com	Henderson	Nevada	6011564702211961304	b8072fca89928d490a6f32d10c1ccdfa	JCB 16 digit	36.0707929323826022	-115.032342128610992
27826	2020-05-30 06:46:35	2020-05-30	Stephanie Spinka	stephanie.spinka@geemail.com	San Francisco	California	4463015058672500	3736508fe911a82c351e869fe7cd12b2	VISA 16 digit	37.7930328024464544	-122.45985046800223
27827	2020-05-30 06:47:11	2020-05-30	Michael Aufderhar-Pacocha	michael.aufderhar.pacocha@geemail.com	Savannah	Georgia	4947014270248922	c365b88785fc07889cc97e388be414b6	Mastercard	32.0589587975852197	-81.0880390334095722
27828	2020-05-30 06:55:18	2020-05-30	Jayla Haley	jayla.haley@warmmail.com	Detroit	Michigan	4403521189190422	beb91f7975c6965101e4fc658c3350ec	Diners Club / Carte Blanche	42.3322903928738086	-83.0189056541424151
27829	2020-05-30 06:55:53	2020-05-30	Ms. Sarrah Welch DDS	ms.sarrah.welch.dds@geemail.com	Lowell	Massachusetts	3337466803499027278	4c30e08a983895b6514f30615497466d	JCB 16 digit	42.7013061487451253	-71.3928675312887862
27830	2020-05-30 06:56:04	2020-05-30	Jenniffer Barton	jenniffer.barton@geemail.com	Athens	Georgia	3088117941135278583	c3c9704850cc7a9e47ec575eb8267161	Discover	34.0272262280531166	-83.2945938966818034
27831	2020-05-30 07:03:33	2020-05-30	Mr. Elvin Crona I	mr.elvin.crona.i@woohoo.com	Los Angeles	California	3042663770660770	b11f801f57ddb1d574878a724cf94fb8	VISA 16 digit	34.0423465512093131	-118.346536399982114
27832	2020-05-30 07:06:34	2020-05-30	Mr. Branden Metz II	mr.branden.metz.ii@geemail.com	North Las Vegas	Nevada	4541256752282255	7c9cfd861a5e19733467c16b7e183638	Diners Club / Carte Blanche	36.288323564004898	-115.008222233991702
27833	2020-05-30 07:18:08	2020-05-30	Dione Bartoletti	dione.bartoletti@warmmail.com	New York	New York	3112383586878972293	67ba168cad1847f36c9311bba9d1342f	Voyager	40.5803176027480532	-73.9926966296870177
27834	2020-05-30 07:20:25	2020-05-30	Fielding Davis	fielding.davis@geemail.com	Oakland	California	869957105003402343	939304ee2123518bb47454715e670a31	Mastercard	37.8045007722852944	-122.255518003586886
27835	2020-05-30 07:29:55	2020-05-30	Ms. Adalynn Mueller DDS	ms.adalynn.mueller.dds@geemail.com	Oakland	California	869928079259635177	894b792253f68a00923700328ae37be8	JCB 15 digit	37.7994152415816842	-122.221083474492389
27836	2020-05-30 07:41:05	2020-05-30	Joelle Pfannerstill	joelle.pfannerstill@geemail.com	San Jose	California	51774051551835793	1b350449dcef03c6ee61491583ed6e22	American Express	37.2219540869638337	-121.836269448207318
27837	2020-05-30 07:42:12	2020-05-30	Merilyn Kuphal	merilyn.kuphal@geemail.com	Oakland	California	4662216744183915	906c355cddcc74fdf3ea5c4cdf2765c1	VISA 16 digit	37.8181649064996961	-122.293068953638894
27838	2020-05-30 07:58:41	2020-05-30	Ms. Serenity Gusikowski	ms.serenity.gusikowski@geemail.com	Corpus Christi	Texas	54688060435032563	21233aad56a6cecd568814a72daa3573	VISA 13 digit	27.7384057084966464	-97.2613306771792452
27839	2020-05-30 08:01:23	2020-05-30	Miss Janey Hamill	miss.janey.hamill@geemail.com	Cincinnati	Ohio	3088691175037596552	2f9424f0263ab7847713cd1bb3ddece9	JCB 15 digit	39.2375539032507703	-84.5213237029772131
27840	2020-05-30 08:01:55	2020-05-30	Lennie Lebsack	lennie.lebsack@warmmail.com	Las Cruces	New Mexico	4091953646654087	96de361101780625892d8df9208ce971	Maestro	32.3407162798602101	-106.799781731760874
27841	2020-05-30 08:06:02	2020-05-30	Caitlin Roob-Rempel	caitlin.roob.rempel@geemail.com	Atlanta	Georgia	210019677681271403	7bee7e5a623c2a20e467b1f3fcd434f9	Maestro	33.7509082684103419	-84.4513532481200997
27842	2020-05-30 08:07:17	2020-05-30	Telly Zemlak	telly.zemlak@woohoo.com	Worcester	Massachusetts	3096641738586177081	dadd4f5a00caa35afc01a25796037735	VISA 16 digit	42.2298843837510773	-71.7172715606421178
27843	2020-05-30 08:11:40	2020-05-30	Stonewall Schinner	stonewall.schinner@geemail.com	Nashville	Tennessee	6011595905353585392	5fb78114850142306cea4ffd77add1ea	VISA 16 digit	36.2316450654651945	-86.8086119271255967
27844	2020-05-30 08:21:05	2020-05-30	Stoney Wunsch	stoney.wunsch@geemail.com	Oakland	California	3769561064300576	b37c2cf9d5570a4340389da44dbf70d6	Diners Club / Carte Blanche	37.8216335902517145	-122.284565231361995
27845	2020-05-30 08:23:18	2020-05-30	Dr. Spurgeon Trantow	dr.spurgeon.trantow@geemail.com	Nashville	Tennessee	3012886067996165	04c106365298de654fd80ca11aae941d	VISA 16 digit	36.2280263072933977	-86.8319014390371677
27846	2020-05-30 08:23:25	2020-05-30	Felipe Lesch V	felipe.lesch.v@geemail.com	Dallas	Texas	4928463466675146	5a0ed40805b306728d66a41bcc7903bb	Maestro	32.7955115791216514	-96.7791987298019194
27847	2020-05-30 08:34:00	2020-05-30	Sandy Bednar	sandy.bednar@geemail.com	Tuscaloosa	Alabama	6011768873110840164	d3708a64f4201919eb7baa2f1c84193e	JCB 15 digit	33.2159203601125625	-87.6185341070968633
27848	2020-05-30 08:35:10	2020-05-30	Aydin Schumm	aydin.schumm@geemail.com	Saint Paul	Minnesota	53297486254771366	708270d6c195eeefd969103cbc0a56ff	Maestro	44.9376012881226856	-93.0727443463899249
27849	2020-05-30 08:37:21	2020-05-30	Amasa Feest-Dietrich	amasa.feest.dietrich@geemail.com	Houston	Texas	4145914969000288	8747bf7eb878da23eb26e36a50583f6e	VISA 16 digit	29.8440992616195224	-95.4898932934753617
27850	2020-05-30 08:50:26	2020-05-30	Mr. Wiliam Windler	mr.wiliam.windler@warmmail.com	El Paso	Texas	3040547145216065	43ff787b4cf555004505ae1cd52bd1d2	VISA 16 digit	31.8773634929038607	-106.382979985138405
27851	2020-05-30 08:55:34	2020-05-30	Lavonda Champlin DVM	lavonda.champlin.dvm@geemail.com	Olathe	Kansas	503888680281701	c4287e19c3bef750681a307e3f222e6c	Mastercard	38.8174116080284151	-94.9155828403010986
27852	2020-05-30 08:58:04	2020-05-30	Berton Hauck	berton.hauck@woohoo.com	Chicago	Illinois	210024195427352612	1039c92ac8e5ec06607f09aa381e9900	Voyager	41.8664133060559678	-87.6874465726811394
27853	2020-05-30 08:58:26	2020-05-30	Mr. Davin Schumm	mr.davin.schumm@geemail.com	Los Angeles	California	3408829985610389	e504fba9a5922c45cbe08d4b27c863f0	American Express	34.0830135644745056	-118.488119309394804
27854	2020-05-30 09:02:02	2020-05-30	Dr. Shepherd Toy II	dr.shepherd.toy.ii@geemail.com	San Francisco	California	4564183896486075	55e17da5acd504398f96083f2ce16c00	VISA 16 digit	37.7774084629857967	-122.462235000113694
27855	2020-05-30 09:08:46	2020-05-30	Abdiel Jaskolski	abdiel.jaskolski@woohoo.com	Pittsburgh	Pennsylvania	561259644076750	b1c01a22ef4dde9e87780eeaee95f1da	American Express	40.3921492225445817	-79.9138400907334017
27856	2020-05-30 09:23:04	2020-05-30	Tamatha Olson-Thiel	tamatha.olson.thiel@geemail.com	Durham	North Carolina	4555620642457471	b4a322db1d16fcb2bee5456811982d55	JCB 16 digit	35.8950573606662431	-78.8432039611410431
27857	2020-05-30 09:26:42	2020-05-30	Rene Gutkowski	rene.gutkowski@geemail.com	Macon	Georgia	3088373431219288236	c0e889793bab76f6f4b3f9ac77ee98cb	Mastercard	32.8100147552333752	-83.7609777011170991
27858	2020-05-30 09:42:37	2020-05-30	Dr. Grady Terry	dr.grady.terry@geemail.com	Indianapolis	Indiana	52011807940970432	7611b1e37f41215c763a544a10b1a585	American Express	39.8634604263126846	-86.1556742142621346
27859	2020-05-30 09:43:03	2020-05-30	Blaine Kulas	blaine.kulas@warmmail.com	Berkeley	California	3038784163357578	7b3afde0fa6c255d12413e5c682ff2ec	VISA 16 digit	37.8516133551880216	-122.255553048268339
27860	2020-05-30 10:00:36	2020-05-30	Zettie Sauer	zettie.sauer@geemail.com	Pompano Beach	Florida	55842950319273866	0e156245e1c3df45b055042d1a4b7bc0	JCB 16 digit	26.2882408417560143	-80.1110345048211485
27861	2020-05-30 10:39:09	2020-05-30	Todd Fadel	todd.fadel@geemail.com	San Francisco	California	630448314928325	8a69da6f5701ed80ea1034321851eba3	JCB 16 digit	37.7387057157745431	-122.417401228335791
27862	2020-05-30 10:42:23	2020-05-30	Roby Schmidt Sr.	roby.schmidt.sr.@warmmail.com	Oakland	California	4266204535206319	63aadddfb1c657ccc036d8a26b9a98bc	Voyager	37.8077590161286921	-122.273795191274118
27863	2020-05-30 10:46:19	2020-05-30	Destiny Tromp	destiny.tromp@geemail.com	San Francisco	California	3337957919037002650	cc36adebfef270153cb83e9a68dc7d31	Maestro	37.7888596877419189	-122.453892368660462
27864	2020-05-30 10:49:37	2020-05-30	Casimir Pollich-McLaughlin	casimir.pollich.mclaughlin@woohoo.com	Houston	Texas	52603553000481860	751de4025e2fd090dbe57429caff13f1	American Express	29.7748698634173721	-95.412133250293877
27865	2020-05-30 10:52:16	2020-05-30	Maryjane Gulgowski	maryjane.gulgowski@geemail.com	Arlington	Texas	4925569943051	8459488425d880a4b2334855c00532d1	VISA 16 digit	32.6580417069856068	-97.1610782995380475
27866	2020-05-30 10:59:20	2020-05-30	Reginal Batz	reginal.batz@geemail.com	San Francisco	California	4052657315671747	6e081dc3f5bd9743a90f67a9c14a4f74	JCB 16 digit	37.7885788220291445	-122.405827586793009
27867	2020-05-30 11:01:53	2020-05-30	Lizette Smitham-Ward	lizette.smitham.ward@warmmail.com	Tuscaloosa	Alabama	4750079957872753	f63e0bb1d463cece75b3d18b30796146	JCB 16 digit	33.1162954847384228	-87.602479328643895
27868	2020-05-30 11:12:27	2020-05-30	Sigrid Hintz	sigrid.hintz@geemail.com	Houston	Texas	6011165885847530214	f0d2e36dc2f71df03fdc8e5fcfcc19a5	JCB 16 digit	29.8263819829639054	-95.3856246315889109
27869	2020-05-30 11:17:26	2020-05-30	Mrs. Muriel Crona	mrs.muriel.crona@geemail.com	Fort Wayne	Indiana	869941875307509048	81872ec4cb678f4697a5b7722d7ac649	American Express	41.0340963836077606	-85.2225266667302748
27870	2020-05-30 11:23:04	2020-05-30	Alton Ward-Prosacco	alton.ward.prosacco@geemail.com	San Francisco	California	6011259674393845441	09a6ced148cd68902eaf4707b9db7c64	Mastercard	37.7467697328130001	-122.450709505288842
27871	2020-05-30 11:42:28	2020-05-30	Miss Keyla Daniel PhD	miss.keyla.daniel.phd@woohoo.com	San Antonio	Texas	4343279729107421	60b07f6f478480a30f29c79c5c87dcfa	Diners Club / Carte Blanche	29.4947764280322957	-98.6031993121676038
27872	2020-05-30 11:47:20	2020-05-30	Whit Crooks	whit.crooks@woohoo.com	Milwaukee	Wisconsin	4479096973834609	9c8d94ce271238ec973f4f02417c7689	VISA 16 digit	43.0607740383215258	-87.9606115470740946
27873	2020-05-30 11:52:47	2020-05-30	Jiles VonRueden-Mraz	jiles.vonrueden.mraz@geemail.com	Irvine	California	6011882737124737727	2b0cbc08d830d6a5267a6075001d0b1e	Discover	33.7548206285588464	-117.846239779471603
27874	2020-05-30 11:52:54	2020-05-30	Mr. Darwin Stokes	mr.darwin.stokes@warmmail.com	Irving	Texas	51652853650849394	5b940657b674395e177ff25e9b2ca8ef	JCB 15 digit	32.8024528202086714	-97.0495452983118554
27875	2020-05-30 12:03:42	2020-05-30	Neppie Osinski	neppie.osinski@geemail.com	Glendale	Arizona	180017459313786138	5e5199e2c7608fd52467d7eec8762daf	Diners Club / Carte Blanche	33.445582153438032	-112.111514458411932
27876	2020-05-30 12:17:02	2020-05-30	Dr. Barbie Stiedemann DDS	dr.barbie.stiedemann.dds@warmmail.com	San Diego	California	180074642882760101	a00d95ca03c4f4f236bc4bb84a42aea4	VISA 16 digit	32.7435350292894967	-117.159314320599663
27877	2020-05-30 12:20:08	2020-05-30	Tierra Considine	tierra.considine@geemail.com	Allen	Texas	3096069252400955220	a77cb2ee01d67ee70e1335b0f6fc0104	VISA 16 digit	33.0981279717318699	-96.7551939967967627
27878	2020-05-30 12:23:10	2020-05-30	Alver Kilback-Ledner	alver.kilback.ledner@geemail.com	San Francisco	California	3112904869272907440	8f1d9ef2a713a94b96eb1dc9d17ea012	American Express	37.7993809150680065	-122.417025959684366
27879	2020-05-30 12:24:54	2020-05-30	Ms. Zoa Leffler DVM	ms.zoa.leffler.dvm@geemail.com	Toledo	Ohio	3112494864981912928	bb9f2920b88444bb9c70b8f7145ccd93	Diners Club / Carte Blanche	41.6887802969370043	-83.4864704924967214
27880	2020-05-30 12:27:36	2020-05-30	Ericka Sanford	ericka.sanford@geemail.com	Los Angeles	California	3058682363898823	ad5cd269181a138769cbc74fe0ba621e	Diners Club / Carte Blanche	34.0428124499373084	-118.431507277161998
27881	2020-05-30 12:31:41	2020-05-30	Ed Kozey II	ed.kozey.ii@geemail.com	Houston	Texas	54392156186984627	2ab2419a2b87c52ffd5439d499410b1a	JCB 16 digit	29.7700008375648402	-95.4274223554428715
27882	2020-05-30 12:36:28	2020-05-30	Gussie Muller	gussie.muller@geemail.com	Chicago	Illinois	4850814607299190	68bc9315993f1e3accbffb657faee8b6	Mastercard	41.7858933650724609	-87.5958542468987389
27883	2020-05-30 12:44:22	2020-05-30	Therman Schiller-Beier	therman.schiller.beier@woohoo.com	Laredo	Texas	3009230482239880	6cf586af79054d1291195eb4f67834e4	VISA 16 digit	27.618362523074822	-99.5829218919862029
27884	2020-05-30 12:44:52	2020-05-30	Salena Runolfsson	salena.runolfsson@geemail.com	Tucson	Arizona	3528850434074260185	5a53911f5a5f6486fbb9c45255b0e542	VISA 16 digit	32.1335118548985577	-110.86285269732997
27885	2020-05-30 12:47:15	2020-05-30	Mahala Dickinson	mahala.dickinson@geemail.com	Bakersfield	California	3027116394133521	68d1216e390108fd7a87fbe6f77094fe	American Express	35.308070026495308	-119.11141109455302
27886	2020-05-30 12:52:04	2020-05-30	Dr. Vincent Fadel Sr.	dr.vincent.fadel.sr.@warmmail.com	New York	New York	3034140992889766	fb3a817fc05714fd4152cd50cf367d6a	JCB 16 digit	40.7536683631353043	-73.8701690812956571
27887	2020-05-30 12:53:29	2020-05-30	Linsey Jacobs	linsey.jacobs@geemail.com	San Francisco	California	55959381525407412	3930cbad0b0f735c5247383112f8adb2	Diners Club / Carte Blanche	37.7387159955409217	-122.442818265500691
27888	2020-05-30 12:57:07	2020-05-30	Francis Towne	francis.towne@geemail.com	Fremont	California	6011188748049271362	97fb3cb5e0073fe49519b5d0c8069ba1	Discover	37.5781292908061317	-121.854868148592104
27889	2020-05-30 13:05:02	2020-05-30	Shaniqua Heaney	shaniqua.heaney@warmmail.com	Phoenix	Arizona	3498137660403117	936d73edd60260fd74c36d43f3e29352	American Express	33.5698720473263421	-112.160651126869396
27890	2020-05-30 13:23:50	2020-05-30	Elden Sipes	elden.sipes@geemail.com	Wichita	Kansas	4274354328495	45e10fe7ed22fff7f086982777649518	JCB 16 digit	37.7492467084310945	-97.3859259515736255
27891	2020-05-30 13:27:33	2020-05-30	Kimberly Lynch-Mohr	kimberly.lynch.mohr@geemail.com	Allen	Texas	4021643107824353	d75c487ba8f1b883b4f556ba1f83886e	VISA 13 digit	33.0780965928014368	-96.743537753768635
27892	2020-05-30 13:31:00	2020-05-30	Dr. Elise O'Reilly	dr.elise.o'reilly@warmmail.com	Norfolk	Virginia	639033764102084	fe1ed7fdc1870d1a54c1345985268b38	JCB 16 digit	36.9344116306416694	-76.2010825703389969
27893	2020-05-30 13:35:52	2020-05-30	Vernice Collier DDS	vernice.collier.dds@geemail.com	Albuquerque	New Mexico	3088303285879696533	24c7871af4bc89281cceaa8c99726045	VISA 16 digit	35.1996286856610325	-106.645650977136199
27894	2020-05-30 13:36:46	2020-05-30	Deborah Gutkowski	deborah.gutkowski@geemail.com	Chicago	Illinois	3712998082581902	f86d08e5c7f6d41f0df061433019cecb	Voyager	41.8937071095988145	-87.6959299889422965
27895	2020-05-30 13:50:15	2020-05-30	Elisha Tromp-Hickle	elisha.tromp.hickle@woohoo.com	Boston	Massachusetts	3112304244525589716	efbdd946ebd510ba9600b3683824df4b	VISA 16 digit	42.4197195718698197	-71.1135001267723794
27896	2020-05-30 13:52:39	2020-05-30	Mitchel Kuhlman	mitchel.kuhlman@geemail.com	Phoenix	Arizona	3749485570601225	40c015ab444ada9d654a8dc635df8f68	Mastercard	33.5770566428944477	-112.008477566151328
27897	2020-05-30 13:55:17	2020-05-30	Darwin Abshire	darwin.abshire@warmmail.com	Fort Lauderdale	Florida	869984305835981681	4d94491bd57fe9d96753be196a6ea986	Maestro	26.0434102004382773	-80.0479710019014732
27898	2020-05-30 13:57:12	2020-05-30	Clarnce Lehner DDS	clarnce.lehner.dds@geemail.com	Fort Worth	Texas	53315911076494275	fb6db7094035f18b9cdf65a44c0a5bf6	VISA 16 digit	32.7593301490005118	-97.2782898727159875
27899	2020-05-30 14:06:08	2020-05-30	Mr. Bilal Crooks	mr.bilal.crooks@geemail.com	New York	New York	3000777389432082	57cce6ea139c133faae26e572a6d6b9c	Diners Club / Carte Blanche	40.7374477116614599	-73.9371410157427107
27900	2020-05-30 14:21:44	2020-05-30	Vito Kessler	vito.kessler@geemail.com	El Paso	Texas	3010498668300805	01fc9abdc985deded6046a334d359556	VISA 16 digit	31.8105677196118997	-106.382943160969774
27901	2020-05-30 14:30:55	2020-05-30	Mr. Christop Shanahan Jr.	mr.christop.shanahan.jr.@geemail.com	Oakland	California	630453273801778	9998a74a30e265771a2d0176b51fb236	American Express	37.8195110268872625	-122.290371669321701
27902	2020-05-30 14:39:47	2020-05-30	Darrick Kuhic	darrick.kuhic@geemail.com	Mesquite	Texas	180059591891574103	d5146b3d0f554ddde877ea139d2d7f8d	VISA 13 digit	32.6838099662024533	-96.5529755183693084
27903	2020-05-30 14:58:35	2020-05-30	Joesph Dickinson	joesph.dickinson@geemail.com	Aurora	Illinois	3742149319240110	b2362feae5995222b9e8b5060814e2a9	JCB 16 digit	41.7508499418608849	-88.3731320627428545
27904	2020-05-30 15:24:05	2020-05-30	Mr. Javion Cummings Sr.	mr.javion.cummings.sr.@geemail.com	Palm Bay	Florida	3112816624524913630	9ea78d6fd3ca8a751a2b984490e96375	Mastercard	27.9370987498521828	-80.702847306087989
27905	2020-05-30 15:28:01	2020-05-30	Dr. Orson Ebert I	dr.orson.ebert.i@geemail.com	Olathe	Kansas	180027332892222825	43d39a663b2ca6a167838936f8137371	Voyager	38.9504372886504981	-94.9141585583500671
27906	2020-05-30 15:32:29	2020-05-30	Dr. Amit Green	dr.amit.green@geemail.com	Charlotte	North Carolina	639047329118906	e7150e7b19dd0710a834f1daf9dbb8d1	JCB 16 digit	35.2627269270617489	-80.779180002439773
27907	2020-05-30 15:33:48	2020-05-30	Brea Zieme	brea.zieme@warmmail.com	Santa Ana	California	4077305177211902	579a96126d5ed504c164e79ba7eaf570	JCB 15 digit	33.7034874519437579	-117.92060700086131
27908	2020-05-30 15:34:23	2020-05-30	Candyce Beatty DVM	candyce.beatty.dvm@warmmail.com	Miami	Florida	4751669479231428	e4537cd2b23c4951c2c21eb416888867	Diners Club / Carte Blanche	25.7617964639466273	-80.173855969017751
27909	2020-05-30 15:34:51	2020-05-30	Jaquelin Bayer	jaquelin.bayer@geemail.com	San Francisco	California	3096456794543992843	eeb2f585024807baa3e3fc4b31f3196a	Discover	37.7687650543127873	-122.457990692864271
27910	2020-05-30 15:44:02	2020-05-30	Arland Langosh	arland.langosh@geemail.com	Arlington	Texas	210016548618731871	ca2fe18ea31603b050dd9e5b2a95bc2d	VISA 13 digit	32.655540261815112	-97.114083547799666
27911	2020-05-30 15:49:03	2020-05-30	Andrea Ledner	andrea.ledner@warmmail.com	Washington	District of Columbia	4156861349660	a03b52d167b982531c8faced12e78872	Diners Club / Carte Blanche	38.8827982285790128	-77.0328486656982534
27912	2020-05-30 15:56:08	2020-05-30	Madonna Nitzsche	madonna.nitzsche@warmmail.com	New York	New York	869938929265836888	932858cf6f610f47981187d723461277	JCB 15 digit	40.66226878205687	-73.9510572244308833
27913	2020-05-30 15:57:05	2020-05-30	Elon Parisian DDS	elon.parisian.dds@geemail.com	Washington	District of Columbia	3493309425204701	2de32ea1be5c5e412157644d2d08f04a	American Express	38.8853016433570531	-76.9193900940686461
27914	2020-05-30 16:19:52	2020-05-30	Ms. Azul Wilkinson	ms.azul.wilkinson@geemail.com	San Francisco	California	53589533632937479	b3089e51fbfdc0e24e76dd8f7be00637	Diners Club / Carte Blanche	37.7712458901455364	-122.436992118254565
27915	2020-05-30 16:31:52	2020-05-30	Ms. Anais Bernhard	ms.anais.bernhard@warmmail.com	Mobile	Alabama	4744979588266052	f4c9abea815d2d871ff9cf36b2effe69	VISA 13 digit	30.6711435793541369	-88.0909627232372827
27916	2020-05-30 16:31:57	2020-05-30	Amir Veum-Cummerata	amir.veum.cummerata@warmmail.com	Chattanooga	Tennessee	3337710786682276857	3a25a02260895da5249cb92923de4314	JCB 15 digit	35.135604680268095	-85.2071317371275256
27917	2020-05-30 16:34:15	2020-05-30	Allen Adams	allen.adams@geemail.com	Akron	Ohio	4747007018225	95bc786e0c0606e03227beafeb62e879	Mastercard	41.1003012847453348	-81.5072667406719233
27918	2020-05-30 16:35:31	2020-05-30	Weldon Lowe	weldon.lowe@geemail.com	New York	New York	52068996639202017	de84f015002a2d1dd923632b2a12ab91	VISA 16 digit	40.6064295449983348	-73.9637075445976109
27919	2020-05-30 16:50:29	2020-05-30	Mariyah Gislason	mariyah.gislason@geemail.com	Mesa	Arizona	4535120387019862	820d20d93b47aee7992fbacfd48b9908	VISA 16 digit	33.3604061150603002	-111.773103185778112
27920	2020-05-30 17:09:47	2020-05-30	Dr. Hardin Koss	dr.hardin.koss@geemail.com	San Francisco	California	4846358717665418	7b2a4916879634a63d169fd67251a37a	JCB 16 digit	37.7707700351074536	-122.430313920903771
27921	2020-05-30 17:12:26	2020-05-30	Adalynn Beer	adalynn.beer@geemail.com	Indianapolis	Indiana	3474056400657105	f2cae89eab85ddb8dc65276281f69398	Mastercard	39.8081574679359775	-86.0805535957884018
27922	2020-05-30 17:14:16	2020-05-30	Norita Batz	norita.batz@geemail.com	Lubbock	Texas	3039348310686633	b224192159c52547e969eac92a8a1268	Mastercard	33.5009772727772628	-101.796501384247847
27923	2020-05-30 17:18:28	2020-05-30	Mont Walter	mont.walter@geemail.com	Surprise	Arizona	3038551165954227	7b3a944b17a9cfaf45f82e39219032d8	Maestro	33.6334599626477839	-112.449671962228408
27924	2020-05-30 17:29:08	2020-05-30	Tahj Yundt	tahj.yundt@woohoo.com	Oklahoma City	Oklahoma	4138562489994271	0813fea28ff6a6d559b42f70a0ebba16	VISA 16 digit	35.53521371394433	-97.4774096575461328
27925	2020-05-30 17:32:20	2020-05-30	Concha Kuhlman	concha.kuhlman@warmmail.com	Gilbert	Arizona	3708290529780313	00f1d378bdbe9d8d740579aa5bc79030	VISA 16 digit	33.3787900605119745	-111.835308536854015
27926	2020-05-30 18:06:28	2020-05-30	Makhi Friesen II	makhi.friesen.ii@geemail.com	New York	New York	676180070852357	e36607cabef065891e4d32c8c41e29f5	Mastercard	40.5905007391460231	-73.9473511685978622
27927	2020-05-30 18:08:32	2020-05-30	Rayne Buckridge	rayne.buckridge@geemail.com	Lubbock	Texas	3761739093899218	25382558f1aa54129594b98dbdd1a185	Diners Club / Carte Blanche	33.5803135043516789	-101.950150026046487
27928	2020-05-30 18:11:23	2020-05-30	Esco Hettinger I	esco.hettinger.i@geemail.com	Corona	California	869939491524533409	07e2cff227c764d4d66060bbc06020aa	Voyager	33.8741206298004869	-117.575027545189485
27929	2020-05-30 18:15:07	2020-05-30	Mr. Mathews Glover DDS	mr.mathews.glover.dds@geemail.com	San Francisco	California	210084861838415234	9e442910f8a4317aedea742aefe7f71f	American Express	37.7334811958884657	-122.401063354589041
27930	2020-05-30 18:32:52	2020-05-30	Shawnna Lockman	shawnna.lockman@geemail.com	Durham	North Carolina	4394129867454895	cae94100f0fd75360d918173195d72f0	VISA 16 digit	35.9672635312903637	-78.9649400323998236
27931	2020-05-30 18:45:53	2020-05-30	Orlin Bosco	orlin.bosco@geemail.com	Denver	Colorado	4470860217518065	d46068006eee2872d49e607d8a9b9baf	VISA 16 digit	39.8357884869031551	-104.797532360420007
27932	2020-05-30 18:46:48	2020-05-30	Ardell Schinner	ardell.schinner@geemail.com	Fresno	California	3528053364773097734	c601366d299e694c639552f3ca721108	JCB 16 digit	36.8622734040826572	-119.807703890243175
27933	2020-05-30 18:53:10	2020-05-30	Kris Sipes	kris.sipes@geemail.com	Austin	Texas	3158665085899902594	1bf468f5cad00a69026b590e3ae5d3a0	Mastercard	30.3275446952912944	-97.7532774960860706
27934	2020-05-30 18:53:20	2020-05-30	Torrance Stroman-Boyle	torrance.stroman.boyle@geemail.com	Los Angeles	California	210030601701032905	b8d99a3a846b34bf26977a7386d31b9c	Voyager	34.0433616957958733	-118.478500763233001
27935	2020-05-30 19:14:32	2020-05-30	Andrew Quigley-Kessler	andrew.quigley.kessler@geemail.com	Tucson	Arizona	4300916678505	1274f8553b626e5b36a0a6aae1e2e64e	VISA 13 digit	32.1570270039647852	-110.957398076052215
27936	2020-05-30 19:17:15	2020-05-30	Titus Nader	titus.nader@geemail.com	Phoenix	Arizona	676158528667676	704d9868fbdfe7b38b3f13fb4a966279	Diners Club / Carte Blanche	33.6474166579011822	-112.056564192559946
27937	2020-05-30 19:32:57	2020-05-30	Joslyn Nader	joslyn.nader@geemail.com	Laredo	Texas	53120882789374168	02d99b0b0b497ce3c361c44a4c6b765a	Maestro	27.5221992354556946	-99.5332674523822902
27938	2020-05-30 19:39:57	2020-05-30	Jiles Reinger	jiles.reinger@geemail.com	Los Angeles	California	3036176685745392	bd351fc7b816326fa921b88424617403	Diners Club / Carte Blanche	33.9701664137985517	-118.359712200517947
27939	2020-05-30 19:41:41	2020-05-30	Dr. Stanley Homenick IV	dr.stanley.homenick.iv@geemail.com	Glendale	Arizona	3406802688537011	5a42be238b58cdc930096977b297a777	Discover	33.598770042717824	-112.225882390539709
27940	2020-05-30 19:46:31	2020-05-30	Jonatan Marks	jonatan.marks@geemail.com	Dallas	Texas	3096809480259421540	3cc358a590acc5cd344cb7f1342373dc	JCB 16 digit	32.8530340400796419	-96.7728363795168605
27941	2020-05-30 19:48:07	2020-05-30	Chastity Kunde	chastity.kunde@geemail.com	Berkeley	California	210087735340139002	296def01022b1c59ce5793c84c1fd0a5	VISA 13 digit	37.8927226542478621	-122.288265019523237
27942	2020-05-30 20:05:43	2020-05-30	Mrs. Shelley Nienow	mrs.shelley.nienow@woohoo.com	Fort Worth	Texas	4180278666674084	408d1385ab56b27bad0985f22569e075	VISA 13 digit	32.7583874451052424	-97.2957729884244458
27943	2020-05-30 20:19:08	2020-05-30	Jamiya Mann	jamiya.mann@geemail.com	Gilbert	Arizona	3528890650671548282	8fd64f8f6b3688a8f1a8871ae4e73da5	Maestro	33.238175599265098	-111.658103276010976
27944	2020-05-30 20:31:31	2020-05-30	Mr. Adlai Windler	mr.adlai.windler@geemail.com	Wichita	Kansas	501879629554126	21eac1bc3d4f247702588eb515c82521	JCB 16 digit	37.6689702380325642	-97.4145644654720968
27945	2020-05-30 20:36:15	2020-05-30	Clabe Ruecker-Collins	clabe.ruecker.collins@geemail.com	Pearland	Texas	4759942094294	4b39497153524f078a328368a44ecc0b	VISA 13 digit	29.6554537634171567	-95.3813718235440575
27946	2020-05-30 20:46:11	2020-05-30	Armstead Cummerata	armstead.cummerata@warmmail.com	Long Beach	California	4104125055051809	61d3e57617f5c1b1fb3001b05951da36	JCB 16 digit	33.8470093303646848	-118.1181850437235
27947	2020-05-30 20:49:20	2020-05-30	Mr. Arne Heaney	mr.arne.heaney@geemail.com	Antioch	California	3753669336901226	a867bd5cc743fc2f468a068266f964cd	VISA 16 digit	38.0368882757876108	-121.866400662082057
27948	2020-05-30 20:50:33	2020-05-30	Aretha Blanda	aretha.blanda@woohoo.com	Milwaukee	Wisconsin	3047070025141009	196eaad956a2a120671dd10a55d2b295	American Express	43.1469619346868214	-88.0629737840600342
27949	2020-05-30 20:52:39	2020-05-30	Mr. Jessie Waelchi II	mr.jessie.waelchi.ii@geemail.com	Fort Worth	Texas	501817405914239	724889cc10ce538931da483f49157fa3	VISA 13 digit	32.7863991806339499	-97.3225345538750304
27950	2020-05-30 20:54:26	2020-05-30	Fenton Bode-Quitzon	fenton.bode.quitzon@warmmail.com	Louisville	Kentucky	3112096041476577274	033943f18e71c38ed0a8a575ab2d3d81	Discover	38.1299498202647982	-85.6632171758055705
27951	2020-05-30 20:55:16	2020-05-30	Florentino Brown	florentino.brown@geemail.com	Lincoln	Nebraska	501866787601419	e58b35830b01a5a9b3be6d6e5b8f3182	Mastercard	40.8012307217828933	-96.7768481066610633
27952	2020-05-30 20:59:26	2020-05-30	Aurelio Langworth-Moen	aurelio.langworth.moen@woohoo.com	Wichita Falls	Texas	4411414650515865	5d1d4a7825d0d0dd9c1b341b638c7de9	Maestro	34.0058815983317828	-98.4460413458678829
27953	2020-05-30 21:16:14	2020-05-30	Kyara Flatley	kyara.flatley@geemail.com	Omaha	Nebraska	4902688787081	00b39181af23ca80f551d1d083be5f98	VISA 13 digit	41.2187426331132656	-96.0807756328139533
27954	2020-05-30 21:21:43	2020-05-30	Author Runte	author.runte@geemail.com	Columbia	Missouri	3088146707688767420	a33e8827382d28f1004aabeadadbd626	JCB 16 digit	38.9882200225137723	-92.242424550005893
27955	2020-05-30 21:22:02	2020-05-30	Lafe McClure	lafe.mcclure@woohoo.com	Oakland	California	561206675631789	ec21a46ea2090c765b27f5fd61dfa550	Mastercard	37.8152308289651131	-122.242466557702528
27956	2020-05-30 21:25:07	2020-05-30	Clemens Metz	clemens.metz@geemail.com	Colorado Springs	Colorado	4617388356509244	de5a006f003ced60b6d74015340dff12	JCB 15 digit	38.8377512050375344	-104.843491698956868
27957	2020-05-30 21:26:41	2020-05-30	Amy Jacobson	amy.jacobson@geemail.com	Toledo	Ohio	4181884648620886	59c8d62f5ae19a2e534115d746d41e9f	Maestro	41.7223404556684159	-83.4939844066143024
27958	2020-05-30 21:26:54	2020-05-30	Enrico Robel	enrico.robel@geemail.com	Lexington	Kentucky	4054575295958	3d969cabaf2230eef08ce3e69520dcad	JCB 16 digit	37.9942761783365199	-84.3711957884851813
27959	2020-05-30 21:30:55	2020-05-30	Mr. Mamie Eichmann DDS	mr.mamie.eichmann.dds@geemail.com	Escondido	California	6011570192473949928	3b8676078fdc98885aafc405ad57aba7	JCB 16 digit	33.1509216623608012	-117.127209903696553
27960	2020-05-30 21:32:35	2020-05-30	Permelia Hodkiewicz	permelia.hodkiewicz@geemail.com	Memphis	Tennessee	6011680071501782690	b510f32cb822b2da9b3fe59d0d909c86	Discover	35.188053789834683	-89.8988193207211879
27961	2020-05-30 21:45:35	2020-05-30	Areli O'Reilly	areli.o'reilly@geemail.com	San Francisco	California	4678928100731531	5db63e6091cbde73d1586deb35a39bec	American Express	37.7572287044839641	-122.413572910011482
27962	2020-05-30 22:02:23	2020-05-30	Lilian Littel-Denesik	lilian.littel.denesik@geemail.com	Honolulu	Hawaii	3337133835928564946	dea3ebe43b4371199512414142f99a90	JCB 16 digit	21.232519810761513	-157.75545171524621
27963	2020-05-30 22:05:10	2020-05-30	Gladstone Murphy	gladstone.murphy@geemail.com	Seattle	Washington	3008889647057692	63a970d65209173c9cb0a775d4cace44	JCB 16 digit	47.6657411812730132	-122.294830246820666
27964	2020-05-30 22:09:01	2020-05-30	Charlottie Bruen	charlottie.bruen@geemail.com	Washington	District of Columbia	3422841674679528	91279bb1aa339a0249703916618521c2	Diners Club / Carte Blanche	38.8400183116815967	-77.0344511701006525
27965	2020-05-30 22:12:13	2020-05-30	Chaya Powlowski	chaya.powlowski@geemail.com	San Francisco	California	561264304188192	5f4166252057539a9f9d7a571dd77671	Discover	37.7775698767648436	-122.425249262470643
27966	2020-05-30 22:17:15	2020-05-30	Ms. Lucina Nolan PhD	ms.lucina.nolan.phd@geemail.com	Vancouver	Washington	6011602743397301117	b84b34f30098aa8f8afba99a113e28cb	JCB 15 digit	45.7123239994585546	-122.677096742025384
27967	2020-05-30 22:23:10	2020-05-30	Corrine Leannon	corrine.leannon@geemail.com	Milwaukee	Wisconsin	4955548660179	2ef2f586eb61a75c948603dfdec6607b	VISA 16 digit	43.0268973280761386	-87.9188670162677823
27968	2020-05-30 22:24:59	2020-05-30	Florance Hirthe	florance.hirthe@geemail.com	Augusta	Georgia	869945168922666351	a7dda8f76854658481f9f5a02847b901	Maestro	33.3404687777832152	-82.0938683852847788
27969	2020-05-30 22:38:06	2020-05-30	Drew Runolfsdottir	drew.runolfsdottir@geemail.com	Naperville	Illinois	6011153811176754443	d3f071727c29e9a745f606d39a41101a	VISA 16 digit	41.7936304930977514	-88.14483279705793
27970	2020-05-30 22:47:42	2020-05-30	Dirk Herman	dirk.herman@geemail.com	New York	New York	6011379856333306171	ad09960b95fea4b3f4dc6ed54d2bc797	Maestro	40.659687630761411	-73.9635786310199563
27971	2020-05-30 23:01:06	2020-05-30	Dr. Macey Boyer PhD	dr.macey.boyer.phd@geemail.com	San Francisco	California	6011957986459222306	435eb5e793488891ef02731fed5c32d8	VISA 13 digit	37.7704892184412273	-122.416760359714672
27972	2020-05-30 23:11:04	2020-05-30	Armstead Leannon	armstead.leannon@geemail.com	Detroit	Michigan	6011300586737608567	f58c5d3a891f06ba6d7ba9b04778c3f7	JCB 16 digit	42.4739271198324886	-83.0260092706073038
27973	2020-05-30 23:13:26	2020-05-30	Kyleigh Nader	kyleigh.nader@geemail.com	Tucson	Arizona	52045809787306779	bd0756d8c05f9bca3c5ad04d2ba5a0de	American Express	32.1089092463295955	-110.928975203330069
27974	2020-05-30 23:17:24	2020-05-30	Dr. Kaye Williamson	dr.kaye.williamson@geemail.com	New York	New York	3406141100030689	29fbe74ece3ff68f55285768e47db5d7	Diners Club / Carte Blanche	40.742824323171746	-74.0228564045753359
27975	2020-05-30 23:18:43	2020-05-30	Ross Bruen	ross.bruen@geemail.com	Port St. Lucie	Florida	55719214436822083	ab835020bcba713cdeffdd74b3b39a0a	VISA 13 digit	27.1988406022213383	-80.4381926860280316
27976	2020-05-30 23:37:58	2020-05-30	Carli Stehr	carli.stehr@woohoo.com	Winston–Salem	North Carolina	4958565639489016	197ec78b4c7a2d2b57de10462d0df777	JCB 16 digit	36.0472908309891835	-80.2571646866518904
27977	2020-05-30 23:53:31	2020-05-30	Nedra Lang	nedra.lang@geemail.com	Tulsa	Oklahoma	869959654899477339	84d1c002f5d06550d16c17fbef0d50e9	Mastercard	36.1114030764806984	-95.839396511386326
27978	2020-05-30 23:54:37	2020-05-30	Ms. Jaylene Heaney DVM	ms.jaylene.heaney.dvm@geemail.com	Detroit	Michigan	55769777116967567	152a86b259425ca21d8acd092ea43220	American Express	42.4600850940141825	-83.180991782492768
27979	2020-05-30 23:58:27	2020-05-30	Jose Olson	jose.olson@geemail.com	Davenport	Iowa	869994485574615738	761166902fc9ca20aa9531284793d04b	Diners Club / Carte Blanche	41.5144075683582585	-90.5937162370383788
27980	2020-05-31 00:01:15	2020-05-31	Aretha Lesch	aretha.lesch@warmmail.com	San Antonio	Texas	3023518496087881	2151f3bc5cf5c22bc7e9dd7d4c60dd32	American Express	29.5183057552274306	-98.5680574511945196
27981	2020-05-31 00:15:08	2020-05-31	Ace Gottlieb	ace.gottlieb@geemail.com	New Orleans	Louisiana	6011657234794260522	53ebfd7607f41ecd666b5103fd0e1a41	American Express	30.0145796693876399	-90.0014864018913414
27982	2020-05-31 00:15:32	2020-05-31	Mitch Reilly	mitch.reilly@geemail.com	Naperville	Illinois	210079795631284289	adc743a2b87d7de103e5f753832149f8	JCB 16 digit	41.7673764245964634	-88.2077402419764667
27983	2020-05-31 00:38:10	2020-05-31	Harold Zboncak	harold.zboncak@geemail.com	Tucson	Arizona	3455946086474788	754761996216639a9567bdbfd40aeb7f	Mastercard	32.1649980772793285	-110.882656574225422
27984	2020-05-31 00:48:17	2020-05-31	Akeelah Daugherty	akeelah.daugherty@geemail.com	New York	New York	53785347203895277	65ae6b9a86fc1728336fff16635f7280	JCB 16 digit	40.5826757528111344	-73.895413311746708
27985	2020-05-31 01:11:27	2020-05-31	Winfield Hand I	winfield.hand.i@geemail.com	Fresno	California	3096666864154165058	6f76c94893156138a44890d33e4aae55	American Express	36.7421803341120494	-119.758087149459499
27986	2020-05-31 01:17:16	2020-05-31	Dr. Cayla Beer DDS	dr.cayla.beer.dds@geemail.com	Madison	Wisconsin	869936265851816758	fd8baaa648427498a2acd8e6ce753891	VISA 16 digit	43.023752429054305	-89.3921862827498472
27987	2020-05-31 01:20:04	2020-05-31	Jennifer Crist	jennifer.crist@geemail.com	Torrance	California	3528148887706319335	d4cf8d11ce893eecfa9c75a42c7c1f7a	JCB 16 digit	33.8436892311926911	-118.37667034283615
27988	2020-05-31 01:33:35	2020-05-31	Willam Rutherford	willam.rutherford@geemail.com	Chula Vista	California	4649514871916	b1f6fa5b5d06ae83d35dc36a8bfc9b00	VISA 16 digit	32.7119761323321612	-117.048851494653888
27989	2020-05-31 01:40:56	2020-05-31	Marlie Murray-Hermann	marlie.murray.hermann@geemail.com	Arlington	Texas	676118136298397	7683073daf562f6250bc1b99cc0ec5fe	JCB 15 digit	32.6639855126168541	-97.198210640021415
27990	2020-05-31 01:42:21	2020-05-31	Ellis Lynch	ellis.lynch@geemail.com	Chicago	Illinois	676139403219965	4e4911ec69d522eb30c5c1acce8482ee	Maestro	41.827747576248278	-87.7718203893426789
27991	2020-05-31 02:09:00	2020-05-31	Nadine Howe	nadine.howe@geemail.com	Riverside	California	3055948847651465	0e40f89b2f90d51b5f194b27e6397111	Mastercard	34.0083737512998283	-117.374225807932007
27992	2020-05-31 02:15:37	2020-05-31	Carri Glover	carri.glover@geemail.com	Berkeley	California	3088225000108695239	24dcb79f4aadb1209d29b8884d0d12d5	Discover	37.8815003353707738	-122.254946928809701
27993	2020-05-31 02:17:05	2020-05-31	Dorathea Mueller	dorathea.mueller@warmmail.com	Mobile	Alabama	060445290205199	aa2dc6a49f8dc9efbaeba95e25175246	Voyager	30.7243240951202807	-88.1332545231699953
27994	2020-05-31 02:19:03	2020-05-31	Mr. Whit Veum PhD	mr.whit.veum.phd@geemail.com	New York	New York	54198950755096367	8038858e8374ad818efc09e675ede726	VISA 16 digit	40.755843157157301	-73.9461999800883234
27995	2020-05-31 02:19:50	2020-05-31	Miss Arabella Adams MD	miss.arabella.adams.md@geemail.com	Jacksonville	Florida	4034150873585	814694716314940d4a9cebc9241dcadb	Voyager	30.3543343528226011	-81.6292443031057786
27996	2020-05-31 02:41:42	2020-05-31	Dr. Lida Harvey	dr.lida.harvey@geemail.com	Richardson	Texas	3337907030491601366	55fecc79fd75b898716794ffc202bdc1	Mastercard	32.9799619240920947	-96.7701266518555627
27997	2020-05-31 02:50:07	2020-05-31	Emmanuel Schaefer	emmanuel.schaefer@woohoo.com	New York	New York	3528913610578774749	b284ebabba0abd25f3cffcf9a2f8237d	VISA 16 digit	40.6203175852764389	-74.0248658051609993
27998	2020-05-31 02:51:17	2020-05-31	Brayden Kling	brayden.kling@geemail.com	Scottsdale	Arizona	3043552110301592	2032aba8b2a16c4ee8f52ed25af8997a	Discover	33.7665749346960311	-111.906259429311746
27999	2020-05-31 02:53:51	2020-05-31	Isabella Goodwin MD	isabella.goodwin.md@geemail.com	San Francisco	California	4427535718659	99b4a2ae59f4f8fc82f784b00af5d00e	JCB 15 digit	37.7558067166780305	-122.449098427192041
28000	2020-05-31 02:59:10	2020-05-31	Tara Krajcik	tara.krajcik@geemail.com	San Antonio	Texas	6011962947693786715	29e9e94ed4b730d86028a8e3e6308f24	JCB 15 digit	29.5294939184166481	-98.4901011072400934
28001	2020-05-31 03:14:04	2020-05-31	Trumaine Weimann I	trumaine.weimann.i@geemail.com	Tampa	Florida	3112492346771719822	0865c597f05de0b660ec13c005347480	Voyager	27.9254402313031242	-82.5100975251503286
28002	2020-05-31 03:23:24	2020-05-31	Dr. Dwane Oberbrunner	dr.dwane.oberbrunner@geemail.com	Nashville	Tennessee	3007395347406628	ce4028c1e4b911f72d245b22422a464f	JCB 16 digit	36.2468997733790417	-86.7534406118001726
28003	2020-05-31 03:31:27	2020-05-31	Orvis Keeling III	orvis.keeling.iii@geemail.com	Houston	Texas	210035889023690261	80e723b44a66627345cd211cfc26bb9a	JCB 16 digit	29.8176840117279447	-95.3415691600196027
28004	2020-05-31 03:41:22	2020-05-31	Gilda Shields	gilda.shields@woohoo.com	Portland	Oregon	210060457160029038	25b667f41e35ab7cc1dcf9820c6c9e89	Voyager	45.4749856954328706	-122.637100456794727
28005	2020-05-31 03:59:38	2020-05-31	Hoover Sporer	hoover.sporer@warmmail.com	San Francisco	California	3005601740374202	513c443294434428c4d4fc6c480e2809	JCB 15 digit	37.7902851733025429	-122.387854480651896
28006	2020-05-31 04:01:28	2020-05-31	Dr. Julien Schamberger Sr.	dr.julien.schamberger.sr.@geemail.com	Montgomery	Alabama	589350196881275	6d45d829b5537f54280865e8293bac37	American Express	32.3035805379904843	-86.2770396260697368
28007	2020-05-31 04:06:33	2020-05-31	Jacquelyn Wilderman MD	jacquelyn.wilderman.md@geemail.com	Macon	Georgia	3041869539313665	fb1a87993097b5571b733bce9648b1ea	Maestro	32.7321619923237677	-83.6615359346110381
28008	2020-05-31 04:08:47	2020-05-31	Miss Maleah Maggio DVM	miss.maleah.maggio.dvm@geemail.com	San Francisco	California	3158070501448196305	84d495e559dc9e58a81f6b6cd69c5bff	VISA 13 digit	37.7684814953303629	-122.41876185596692
28009	2020-05-31 04:30:27	2020-05-31	Mrs. Maritza West	mrs.maritza.west@woohoo.com	Berkeley	California	3754783737012340	b39a9bce91d214f126d47c77426dd7f9	American Express	37.8833026430658819	-122.269052961752621
28010	2020-05-31 04:31:49	2020-05-31	Tamara Hand MD	tamara.hand.md@woohoo.com	Oakland	California	3408665602371058	eca03c643a2edc7aa252e2b081432958	JCB 16 digit	37.7919858093739265	-122.290261547354234
28011	2020-05-31 04:38:00	2020-05-31	Jaye Donnelly	jaye.donnelly@geemail.com	Philadelphia	Pennsylvania	4021167146790	ccff57cdf5c84686bbc4bf6b04f6142d	VISA 16 digit	39.9895422876305844	-75.1601897939939079
28012	2020-05-31 04:49:37	2020-05-31	Dr. Helaine Lebsack	dr.helaine.lebsack@geemail.com	Rockford	Illinois	6011924209305985806	b78438a875e9bb6cff08cad5dac977f9	American Express	42.2576332971930526	-89.1623423411328275
28013	2020-05-31 05:03:03	2020-05-31	Elon Hartmann I	elon.hartmann.i@warmmail.com	Las Vegas	Nevada	4421660140125263	7c5e93b7b3d5ec737620612df3f69eb9	JCB 16 digit	36.2493547767035622	-115.283948064243788
28014	2020-05-31 05:03:50	2020-05-31	Wanita Block PhD	wanita.block.phd@geemail.com	Chandler	Arizona	3337185250579756477	1f6fae9cf76a59facccf29756af34613	JCB 16 digit	33.366210687635089	-111.845919654367123
28015	2020-05-31 05:42:15	2020-05-31	Malorie Zemlak DVM	malorie.zemlak.dvm@geemail.com	Sugar Land	Texas	210068408784228995	e675a3e7eb9529a6cba043a40d2153fe	VISA 13 digit	29.6990428227517747	-95.5733821748297601
28016	2020-05-31 05:45:25	2020-05-31	Latisha Langworth	latisha.langworth@geemail.com	Houston	Texas	54684752585532202	5649d29c09c934b3e570904070819adc	VISA 13 digit	29.7830792063925429	-95.4177159649334925
28017	2020-05-31 06:27:53	2020-05-31	Dr. Rashad Rice IV	dr.rashad.rice.iv@geemail.com	Pearland	Texas	3046830240196497	da8387bc4bf44baf4aa63e1431d8f49b	Voyager	29.5996778322655736	-95.2936702674109455
28018	2020-05-31 06:32:46	2020-05-31	Merrie Mayer	merrie.mayer@geemail.com	San Francisco	California	3337345677488030056	2603b8b414264c2edf2c44194507a41d	Diners Club / Carte Blanche	37.7824088797689441	-122.477078105542205
28019	2020-05-31 06:36:34	2020-05-31	Mr. Marsh Rogahn II	mr.marsh.rogahn.ii@geemail.com	New York	New York	3112510038579745152	325187659dada501c98553febc46fac6	VISA 16 digit	40.7369912551008184	-73.9943185658089817
28020	2020-05-31 06:37:11	2020-05-31	Dr. Rae Schulist IV	dr.rae.schulist.iv@geemail.com	Dallas	Texas	4693987047223359	7f36e29c35738360b4b0daee83bdb612	American Express	32.8555378791216768	-96.8270880248360299
28021	2020-05-31 06:41:47	2020-05-31	Melva Grimes	melva.grimes@woohoo.com	Paterson	New Jersey	4579189281408	0cbaf6f25b6bf82f1ffd05fcea1e5762	Discover	40.8405280438672733	-74.2118788458846552
28022	2020-05-31 06:42:41	2020-05-31	Holland Schinner	holland.schinner@warmmail.com	New York	New York	3096984521870525172	0d7730b6404fde8eb28a5d77775ebb24	Mastercard	40.5875774614270739	-74.0138079970039371
28023	2020-05-31 06:44:44	2020-05-31	Ever Koelpin DVM	ever.koelpin.dvm@geemail.com	New York	New York	3088596883390177441	bb560e1a51e9fa5d88b7b038c1d708ac	Voyager	40.6801290989611317	-74.0282098421256904
28024	2020-05-31 06:56:29	2020-05-31	Myra Lockman	myra.lockman@geemail.com	Orlando	Florida	4996171768046	e26b1376ac402e011aff73437ee620bd	JCB 16 digit	28.3648741029467431	-81.3258332585416781
28025	2020-05-31 07:12:11	2020-05-31	Jennette Wolff	jennette.wolff@geemail.com	New York	New York	4473874058414	1af88e0a3ed05e1a3a32b33f147c771e	Discover	40.6888808614332191	-73.9036211412295643
28026	2020-05-31 07:15:29	2020-05-31	Frankie Williamson-Lang	frankie.williamson.lang@geemail.com	Lakewood	Colorado	869952011280939426	7242905badb18c48653ab8660e91f7c9	JCB 16 digit	39.6157759143445674	-105.065616492882739
28027	2020-05-31 07:25:08	2020-05-31	Tori O'Hara	tori.o'hara@warmmail.com	Amarillo	Texas	676148399612349	c92839a81974d71e82d8571ebc1aed18	Voyager	35.1537127758074561	-101.736718327631067
28028	2020-05-31 07:29:25	2020-05-31	Juwan Bruen	juwan.bruen@geemail.com	Arlington	Texas	4583106861045	c39f8544b3736a8bcd3b4400f97c5711	JCB 16 digit	32.7027396493840925	-97.1730819824643532
28029	2020-05-31 07:34:26	2020-05-31	Donnell Schmeler-Goodwin	donnell.schmeler.goodwin@geemail.com	Ontario	California	676296870783022	7e6f3375cb2d0dc21875ba9dc2b672c3	American Express	34.102625112203512	-117.589557747599486
28030	2020-05-31 07:38:37	2020-05-31	Commodore Koepp	commodore.koepp@geemail.com	San Francisco	California	210048948880648237	da1e46bec025cc546754f09561f9382f	American Express	37.7750700994099233	-122.430327767549656
28031	2020-05-31 07:45:52	2020-05-31	Dr. Honora Dietrich	dr.honora.dietrich@geemail.com	Los Angeles	California	4131809820520431	da07e653836c3458ea0bcdf692329bba	Maestro	33.9418838462658172	-118.326271879811955
28032	2020-05-31 07:47:11	2020-05-31	Jonell Lemke	jonell.lemke@geemail.com	Virginia Beach	Virginia	54261543293990696	0d43bcb21298f996970cc743f00c4740	Mastercard	36.7895963644329456	-76.0457539337359378
28033	2020-05-31 08:00:07	2020-05-31	Dr. Alford Hoeger	dr.alford.hoeger@geemail.com	Los Angeles	California	4653350467391	5f96b8dbd6219f17f03f191dd8380742	Mastercard	34.0580597329750603	-118.428996840770537
28034	2020-05-31 08:00:31	2020-05-31	Mrs. Shawnna Torphy	mrs.shawnna.torphy@geemail.com	Louisville	Kentucky	4129738461055122	52137aaa2d11f153aa4da8da27991783	VISA 13 digit	38.1456334700711039	-85.6256144439872457
28035	2020-05-31 08:08:09	2020-05-31	Miss Chynna Raynor DDS	miss.chynna.raynor.dds@woohoo.com	Laredo	Texas	3158702075428668936	f8a31da97ca4508e0ceac4b8bc2ed158	VISA 13 digit	27.5917433819450437	-99.4678382761783837
28036	2020-05-31 08:16:46	2020-05-31	Marco Waelchi	marco.waelchi@warmmail.com	Saint Paul	Minnesota	676191438102120	573dd1a8e3557a0aafa408d3df93b000	JCB 16 digit	45.0122138453587937	-93.032529839294412
28037	2020-05-31 08:31:17	2020-05-31	Dema Kuhn	dema.kuhn@geemail.com	Denver	Colorado	4230688726617016	63a5fdd1d477c5e2a7c10d8bc9bf6ab2	VISA 16 digit	39.7212818410765323	-104.843041694840792
28038	2020-05-31 08:35:16	2020-05-31	Dr. Alvy Weimann DVM	dr.alvy.weimann.dvm@geemail.com	Charleston	South Carolina	4475859567604975	febec9d7a04978ebab1908f75b1d022d	Discover	32.8970595607995975	-79.8622195081468647
28039	2020-05-31 08:36:38	2020-05-31	Baxter Grimes	baxter.grimes@woohoo.com	New York	New York	6011820978413709358	3d161969623673f35b050fb1555eb7ff	Maestro	40.6235392800755761	-73.9200183923251899
28040	2020-05-31 08:44:53	2020-05-31	Cornelia Kub-Hilpert	cornelia.kub.hilpert@geemail.com	New York	New York	4770136682052790	8505142ea8fe78416be42e57ad70f5a7	Mastercard	40.7335613311957587	-74.0251472662098706
28041	2020-05-31 08:54:13	2020-05-31	Kelsie Lang-Johnson	kelsie.lang.johnson@geemail.com	Boston	Massachusetts	676248101221066	dad1e2dfbbb7d8e515d665afcfa991d1	Maestro	42.3241810345724261	-70.973886359431603
28042	2020-05-31 09:02:46	2020-05-31	Blain Jakubowski	blain.jakubowski@geemail.com	Houston	Texas	3771868543188381	c8ef65d433077b4ff7edb19df6892f06	Discover	29.8522295401975519	-95.3436090746443767
28043	2020-05-31 09:02:57	2020-05-31	Emogene Witting	emogene.witting@geemail.com	San Francisco	California	180093011325299373	09150409d2ad42ca0bd962d6151cee02	VISA 16 digit	37.793305222505154	-122.416099816782264
28044	2020-05-31 09:07:18	2020-05-31	Verdie Walsh DVM	verdie.walsh.dvm@geemail.com	Arvada	Colorado	4360818754002	297b3c5802fb8d949b395d407f9e1c8c	JCB 16 digit	39.8563603066548708	-105.19294255282469
28045	2020-05-31 09:29:26	2020-05-31	Christiana Kemmer	christiana.kemmer@warmmail.com	Fort Worth	Texas	3337335257918045479	6acdf5adc26011a1a5f36b0e4f9ccd35	VISA 16 digit	32.8625111031867547	-97.3899291623204988
28046	2020-05-31 09:35:52	2020-05-31	Solon Hamill	solon.hamill@warmmail.com	New York	New York	3337481175040560516	b6f856bb8e9cdfc951cc55ae03d85eb7	Mastercard	40.6230672694500541	-73.8405620260059834
28047	2020-05-31 09:50:55	2020-05-31	Lissette Kovacek	lissette.kovacek@woohoo.com	Oakland	California	6011739588458999101	2f3e4d63ea3505defff0f92afe3d7837	Voyager	37.7943225369173064	-122.264890815190867
28048	2020-05-31 09:57:23	2020-05-31	Dr. Patricia Carroll	dr.patricia.carroll@woohoo.com	Salt Lake City	Utah	869922479830653606	958ced0c2635c43985138f4c2e6ae7a5	JCB 16 digit	40.7505692033242397	-111.895658352639529
28049	2020-05-31 10:09:49	2020-05-31	Georgiann Hackett-Bahringer	georgiann.hackett.bahringer@warmmail.com	Dallas	Texas	4448402570218345	2bfae0b7f7c0cac2125f1958cf191180	JCB 15 digit	32.7189908867973855	-96.8325934857558366
28050	2020-05-31 10:22:06	2020-05-31	Mrs. Noretta Harris DDS	mrs.noretta.harris.dds@geemail.com	Detroit	Michigan	4931401668790870	380334c38cb82b64b53c886961005fd7	Maestro	42.4235096776783465	-83.0079058294303707
28051	2020-05-31 10:35:28	2020-05-31	Christion Rippin	christion.rippin@woohoo.com	Las Vegas	Nevada	6011180674598438004	e173aea3852d606c136d4cb809d6f3e0	Mastercard	36.3251759852848934	-115.236351251995558
28052	2020-05-31 10:35:54	2020-05-31	Lesli McClure	lesli.mcclure@woohoo.com	New York	New York	3009406511960122	4a332babe362785993baba6a418456d9	Discover	40.6326008743830016	-73.8600835087604821
28053	2020-05-31 10:43:05	2020-05-31	Erna Rice	erna.rice@geemail.com	Seattle	Washington	869937746875054137	4372bbd4ccf90916afb88cc66c6570f1	JCB 16 digit	47.5620169721003592	-122.303046013453596
28054	2020-05-31 10:45:30	2020-05-31	Mr. Elvis Williamson MD	mr.elvis.williamson.md@warmmail.com	Oakland	California	3017130986667846	86ff191ada0bb4c2929f2e84c8eafc24	Maestro	37.8214597023088999	-122.273733184714303
28055	2020-05-31 10:46:05	2020-05-31	Jed Von-Powlowski	jed.von.powlowski@warmmail.com	New York	New York	503840927124194	56f54f7d2bf0c55c9a85650b31510bf2	Diners Club / Carte Blanche	40.5796578739993237	-73.8409198130376581
28056	2020-05-31 10:56:26	2020-05-31	Connor Mueller	connor.mueller@geemail.com	San Francisco	California	55974901463460395	156827a99fdc734e1d06154d62f9509d	VISA 13 digit	37.7588301058688245	-122.44290856627083
28057	2020-05-31 10:56:47	2020-05-31	Arnett Macejkovic II	arnett.macejkovic.ii@woohoo.com	Houston	Texas	869930678097896259	558c7827f1b303f7fbe3e100f05d55d3	Voyager	29.8057883575171232	-95.318366728305449
28058	2020-05-31 11:06:43	2020-05-31	Mrs. Consuela Ruecker PhD	mrs.consuela.ruecker.phd@woohoo.com	Rialto	California	3528062215656468377	4bc1f99f7b0be3b1a18b27dd99fcfeca	JCB 15 digit	34.1919204430870707	-117.360076413777847
28059	2020-05-31 11:08:08	2020-05-31	Oney Lockman	oney.lockman@geemail.com	San Francisco	California	180081681022231384	39cee04ae95dc75b7185786bdd147ae1	American Express	37.7563779027938935	-122.464306202354521
28060	2020-05-31 11:08:59	2020-05-31	Mrs. Deedee Padberg DVM	mrs.deedee.padberg.dvm@woohoo.com	North Charleston	South Carolina	676245423160113	b944b272f8938a183b7de50f44f8c64b	Mastercard	32.8528011279340859	-80.1594338124711072
28061	2020-05-31 11:21:29	2020-05-31	Ruby Murray	ruby.murray@geemail.com	Knoxville	Tennessee	6011353979264924547	1b95ed5329b2f93e2b88256d0be981c9	Mastercard	35.9177138811040706	-84.0345602975908577
28062	2020-05-31 11:24:55	2020-05-31	Claudia Price-Stokes	claudia.price.stokes@geemail.com	Vacaville	California	4524461376948	207de61d0b88ba38be71157f02a528a9	VISA 16 digit	38.3543346726927936	-121.961400398181013
28063	2020-05-31 11:27:42	2020-05-31	Hal Dickens	hal.dickens@geemail.com	San Francisco	California	4123142220984480	a731b4fdb82483f920567c917218dc21	VISA 16 digit	37.7930911477857805	-122.424393033018163
28064	2020-05-31 11:54:46	2020-05-31	Carey Eichmann	carey.eichmann@geemail.com	Cleveland	Ohio	180050120550221357	5d437fa7494032a1164970cf3ec78f8e	Diners Club / Carte Blanche	41.4450177771821586	-81.7171690135501336
28065	2020-05-31 12:07:36	2020-05-31	Mr. Kenya Kassulke Jr.	mr.kenya.kassulke.jr.@geemail.com	San Francisco	California	3337253960072713430	3fff29d8539d0e4683d76f787cf75aaa	Voyager	37.739488826151991	-122.416018028126743
28066	2020-05-31 12:30:35	2020-05-31	Ferd Rath DVM	ferd.rath.dvm@geemail.com	New York	New York	210086248077783548	6b34397589add66dfb206d56ddbf61a1	VISA 16 digit	40.6264681653808779	-73.9394802602835028
28067	2020-05-31 12:31:28	2020-05-31	Cristina Gorczany-Spinka	cristina.gorczany.spinka@woohoo.com	Kansas City	Missouri	3088449569798358191	0ff603e88f9feef2cce4a15aa24f24e0	American Express	39.1711172438994097	-94.4582355876211039
28068	2020-05-31 12:33:45	2020-05-31	Ernest Herman	ernest.herman@geemail.com	San Jose	California	3088601260809170692	2a02ee080e93b1f216020a907c9148ab	VISA 16 digit	37.3379776981946065	-121.830654911253234
28069	2020-05-31 12:40:22	2020-05-31	Dr. Von Sipes IV	dr.von.sipes.iv@geemail.com	New York	New York	6011612681710256386	21f0d99edd63582b1398d9b24a753a3a	Voyager	40.6140171806551535	-73.862665212097383
28070	2020-05-31 12:47:54	2020-05-31	Teela Schneider	teela.schneider@geemail.com	Madison	Wisconsin	3088516831158421334	ef3b1a80a60f3880d08ba9f76c4c0ae7	Voyager	43.0028408346205993	-89.5037553374540096
28071	2020-05-31 12:53:51	2020-05-31	Christin Cormier	christin.cormier@geemail.com	Jackson	Mississippi	54273245087396157	f561a14c0c96d3403dee73924cac8cfc	Voyager	32.3536592396155029	-90.2038563873592807
28072	2020-05-31 13:01:28	2020-05-31	Karrie Schoen DDS	karrie.schoen.dds@geemail.com	New York	New York	3337761847847049239	dcb7ff06c0288f7fda408bc049944832	Discover	40.6163805916663279	-73.9979129140160978
28073	2020-05-31 13:23:41	2020-05-31	Margeret Swaniawski	margeret.swaniawski@warmmail.com	Baltimore	Maryland	55043809823648277	457cae8d4fbba8202ebe965989ef491d	Voyager	39.2069778739474657	-76.623472943391647
28074	2020-05-31 13:27:51	2020-05-31	Dorthey Conroy	dorthey.conroy@geemail.com	San Francisco	California	3779250391569784	1a46e06b66636b6c0fd590526ecf2a84	Discover	37.7636978172289233	-122.431949374759625
28075	2020-05-31 13:29:48	2020-05-31	Harlon Gaylord	harlon.gaylord@geemail.com	San Francisco	California	3037473451313557	6eaf4b9a93d219cc38d1cae3c2f85345	JCB 16 digit	37.7844080335275905	-122.394871518822313
28076	2020-05-31 13:41:30	2020-05-31	Therman Larkin-Tromp	therman.larkin.tromp@geemail.com	San Francisco	California	3528174527156215701	2096f62b1229b1f2580792d5b7f30826	Diners Club / Carte Blanche	37.7682340962589862	-122.460706917776392
28077	2020-05-31 13:43:02	2020-05-31	Dominque Barton DDS	dominque.barton.dds@warmmail.com	Pasadena	California	3528587329303478014	07a387e6a5a0ac6e9d0cbab493eb1fc9	JCB 16 digit	34.1012885292846732	-118.215107876230405
28078	2020-05-31 13:54:21	2020-05-31	Wells Schinner	wells.schinner@woohoo.com	Houston	Texas	6011534449728195565	bed3ce036dac55fd3879c1c65bad730b	JCB 15 digit	29.7700651119075701	-95.439451187803968
28079	2020-05-31 13:56:06	2020-05-31	Zavier Thiel	zavier.thiel@warmmail.com	Houston	Texas	4211617784232262	3b03e8eb3afd48b7059764234c388b7a	Mastercard	29.6925854899533093	-95.3752148818239647
28080	2020-05-31 13:57:18	2020-05-31	Niles Hickle-Heidenreich	niles.hickle.heidenreich@woohoo.com	Cape Coral	Florida	4234496399030376	b0ce067147bc9070f557e00346872b9d	Mastercard	26.6299654489818955	-82.0784654680244614
28081	2020-05-31 14:24:22	2020-05-31	Sunny Schneider	sunny.schneider@geemail.com	Boston	Massachusetts	51736525657364284	efda40484610c3e9aa6900b7a7197808	JCB 16 digit	42.4052105856295682	-70.9736405679907705
28082	2020-05-31 14:36:56	2020-05-31	Brion Dickinson	brion.dickinson@geemail.com	Worcester	Massachusetts	3096984615666181685	695bed19830912ee861eadfa13d8c1d4	VISA 13 digit	42.2927701471075395	-71.8125510557808013
28083	2020-05-31 14:43:43	2020-05-31	Adrianne Hickle	adrianne.hickle@woohoo.com	San Francisco	California	53633827712860809	b2fe0da2f96f23d386cb95c8e111833c	VISA 16 digit	37.7449528314484013	-122.4181045068201
28084	2020-05-31 14:47:52	2020-05-31	Urban Hirthe III	urban.hirthe.iii@geemail.com	Olathe	Kansas	4100164519926	68e06542819f8fb43bc68aacd69f408a	Voyager	38.807586738200115	-94.8736427782736769
28085	2020-05-31 15:04:33	2020-05-31	Kaitlynn Cormier PhD	kaitlynn.cormier.phd@geemail.com	St. Louis	Missouri	869983234577596765	d268ac12ebeb22177b1d9bdfd4375135	JCB 15 digit	38.5653647312119574	-90.1505014236554558
28086	2020-05-31 15:08:34	2020-05-31	Mrs. Josefita Moore	mrs.josefita.moore@geemail.com	Atlanta	Georgia	4542126844381	145893b50293519b3f673d9bc249d3ef	Diners Club / Carte Blanche	33.8548237339403499	-84.4176801348149866
28087	2020-05-31 15:10:19	2020-05-31	Ms. Jakayla O'Reilly	ms.jakayla.o'reilly@woohoo.com	Houston	Texas	3112157728328943268	d4d692b172a1b79a89b306ff76d5897b	Diners Club / Carte Blanche	29.7035249491300419	-95.4843513585176282
28088	2020-05-31 15:20:32	2020-05-31	Brook Cruickshank	brook.cruickshank@geemail.com	Los Angeles	California	869953348084284784	116aee737be4b699935806ceec5ee44e	American Express	34.0277920986391607	-118.489808343908933
28089	2020-05-31 15:37:46	2020-05-31	Dr. Caiden Ernser	dr.caiden.ernser@geemail.com	Los Angeles	California	3096006534357962606	75e61a9b93a2f29a3124d6680bf9092c	JCB 15 digit	33.9942271066695412	-118.487681218701596
28090	2020-05-31 15:42:52	2020-05-31	Miss Mozell Boyle DDS	miss.mozell.boyle.dds@geemail.com	Austin	Texas	4464287005118	b044eb9d4bbd62390f91bed5f435f124	Voyager	30.238214316697416	-97.8139120458863687
28091	2020-05-31 15:46:42	2020-05-31	Lorine DuBuque	lorine.dubuque@geemail.com	Oakland	California	4543951557759	3410a0d266987f874c297c85ede73a5b	Diners Club / Carte Blanche	37.8051155430888954	-122.286647830756877
28092	2020-05-31 15:47:17	2020-05-31	Joye Goyette	joye.goyette@warmmail.com	Bakersfield	California	3088230169447655130	b1d88eb8638fd753783060fd3d88d2bd	Discover	35.2670281250670499	-118.980526889003059
28093	2020-05-31 15:58:07	2020-05-31	Mr. Donte Boyle V	mr.donte.boyle.v@warmmail.com	Fayetteville	North Carolina	180046605863926046	560f3ddeaa2568ec383e62ebb2258f36	VISA 16 digit	35.1021111841566835	-78.9774997141808228
28094	2020-05-31 15:59:13	2020-05-31	Quinten Kertzmann	quinten.kertzmann@geemail.com	Omaha	Nebraska	51141617905719663	565fe49ed5b21997596d3c801891b3bd	Voyager	41.3142974252026534	-96.1036101724136671
28095	2020-05-31 16:02:20	2020-05-31	Rossie Hodkiewicz	rossie.hodkiewicz@warmmail.com	Charleston	South Carolina	52157268764160168	9917b47bb9c2fcb74267063ff9483d95	Mastercard	32.7526912421915668	-79.936598466956994
28096	2020-05-31 16:18:38	2020-05-31	Diya Kutch-Lang	diya.kutch.lang@woohoo.com	New York	New York	3051868688790483	e840a89d1ef8038e834d8ff6cd6502bc	Mastercard	40.7372233947962528	-74.0360128143232288
28097	2020-05-31 16:26:11	2020-05-31	Rico Macejkovic	rico.macejkovic@geemail.com	San Francisco	California	561262481014199	e20bfeb1e3510c07aa5b01f47243f358	JCB 15 digit	37.7809398145008686	-122.409380250145119
28098	2020-05-31 17:21:09	2020-05-31	Ervin Moen	ervin.moen@geemail.com	New York	New York	676198896302043	ff02e55e1e86da88e34357f4a85cfa62	JCB 15 digit	40.7598125700131035	-73.8954713911179368
28099	2020-05-31 17:30:52	2020-05-31	Allyson Gottlieb	allyson.gottlieb@geemail.com	San Francisco	California	501860848947663	23fca6b7bcbc4c3ee45f0414dd03c1a6	JCB 16 digit	37.7835253118831815	-122.434792697820825
28100	2020-05-31 17:39:31	2020-05-31	Clabe Towne	clabe.towne@geemail.com	New York	New York	6011950107879111808	226e22f4bda1b17d27f5510dd47bb375	American Express	40.7386869906205646	-73.8989945399004995
28101	2020-05-31 17:40:43	2020-05-31	Clemente Lind	clemente.lind@warmmail.com	Buffalo	New York	3158381579377011715	e1d632ad305b5bf51d4bb84d3ed9e7a7	Mastercard	42.9724160629976524	-78.8948783480495308
28102	2020-05-31 17:40:53	2020-05-31	Zayden Purdy	zayden.purdy@geemail.com	Kansas City	Missouri	55698072582604803	468897de3f318dc12c30bd4d92d0f724	Diners Club / Carte Blanche	39.1521125832874333	-94.5861416597608553
28103	2020-05-31 17:41:59	2020-05-31	Clemie Oberbrunner	clemie.oberbrunner@geemail.com	Omaha	Nebraska	3112654685521043551	72069ece1188687cde8726b71ffffa91	JCB 16 digit	41.2284418153256169	-96.094720982166379
28104	2020-05-31 17:44:07	2020-05-31	Dr. Horace Heathcote DDS	dr.horace.heathcote.dds@geemail.com	San Francisco	California	3041801032666042	4dc9c49f6c25c9c1a23d202dfd794ece	Maestro	37.767600562694966	-122.435361547733493
28105	2020-05-31 17:55:03	2020-05-31	Kirstin Hansen	kirstin.hansen@warmmail.com	Hollywood	Florida	4106194583352	c873e532183eaeb87da85ec9d2e70075	Maestro	25.9762806741464871	-80.2386983431227492
28106	2020-05-31 17:57:44	2020-05-31	Loyce Casper	loyce.casper@geemail.com	New York	New York	3010499510266079	c68ed0282a98dd82c0fc5049b92397c6	Diners Club / Carte Blanche	40.6338966746106749	-73.8688308277528733
28107	2020-05-31 18:01:52	2020-05-31	Fidel Schmeler	fidel.schmeler@woohoo.com	Jacksonville	Florida	3006152971710465	a433f23fe5699673d23c57cd9027ad5a	VISA 16 digit	30.3040146763022982	-81.7273916940283129
28108	2020-05-31 18:08:52	2020-05-31	Dr. Donnie Prohaska MD	dr.donnie.prohaska.md@geemail.com	Los Angeles	California	6011543353506088647	ee89a42a41080c8403113c834d30ed27	JCB 16 digit	34.0941793419286583	-118.48391031967401
28109	2020-05-31 18:12:23	2020-05-31	Miah Toy	miah.toy@geemail.com	Lakewood	New Jersey	3088313515181681221	636132b8f5c4d14203e1d687c13df34b	JCB 15 digit	40.1100474424943343	-74.2400522767841835
28110	2020-05-31 18:16:31	2020-05-31	Shardae Effertz	shardae.effertz@geemail.com	Chandler	Arizona	55334860300903790	39a5e94a598ca31029961b695e5d012a	JCB 16 digit	33.3040299770977342	-111.825709265319261
28111	2020-05-31 18:18:18	2020-05-31	Leticia Stamm	leticia.stamm@woohoo.com	Hialeah	Florida	4879624044647	1332357c54ce583d3a1a22ba56eafa1c	Discover	25.9061917281221596	-80.3662059043437154
28112	2020-05-31 18:26:12	2020-05-31	Dr. Tracy Will MD	dr.tracy.will.md@geemail.com	Philadelphia	Pennsylvania	869914631475293284	bfc7269a4bde38704b33698035a0c06c	JCB 16 digit	39.9656081902287923	-75.2116034877851689
28113	2020-05-31 18:27:14	2020-05-31	Addisyn Jakubowski	addisyn.jakubowski@geemail.com	San Francisco	California	869932559043077624	dfed370365d3ee54cf81dd9559c6b92f	Discover	37.7690184160390672	-122.438189084160186
28114	2020-05-31 18:33:29	2020-05-31	Miss Shaylee Welch	miss.shaylee.welch@warmmail.com	Berkeley	California	210066372785835137	9e41f71b173716f339d187c057076357	Mastercard	37.8204898609064841	-122.28404824536679
28115	2020-05-31 18:40:11	2020-05-31	Gabriela Kuhlman	gabriela.kuhlman@woohoo.com	Newport News	Virginia	3763105529828981	2616ab2709665c798a95f2e10133c9a1	VISA 13 digit	37.1699356878537657	-76.4305917493328479
28116	2020-05-31 18:46:31	2020-05-31	Amparo Russel DDS	amparo.russel.dds@warmmail.com	Downey	California	3401722102489281	d0d52ccb8d41e94b32464f954548684f	American Express	33.9501161118753245	-118.093306857684254
28117	2020-05-31 18:59:27	2020-05-31	Nena Krajcik	nena.krajcik@geemail.com	Saint Paul	Minnesota	55159550681148386	5d8dceefa1e6ef72a9afbc708c1efa97	JCB 16 digit	44.9744096341948989	-93.0689432645481105
28118	2020-05-31 19:07:19	2020-05-31	Cas Kuhlman	cas.kuhlman@geemail.com	San Francisco	California	3035309457838035	511e33a838b5bca43ba86e4127aac41c	JCB 16 digit	37.8006802312445345	-122.46134625570788
28119	2020-05-31 19:08:35	2020-05-31	Deanna Witting DVM	deanna.witting.dvm@geemail.com	San Antonio	Texas	210075461538609250	76bb650e72fe0f1e0ad0c2947bd037be	VISA 13 digit	29.4874204580277208	-98.4312979729682098
28120	2020-05-31 19:14:07	2020-05-31	Genoveva Witting DDS	genoveva.witting.dds@geemail.com	Richardson	Texas	210064137666298396	95e33986c1dfa5547e2514a60bfe0fa3	Discover	32.9501288347180932	-96.7640729019179986
28121	2020-05-31 19:14:22	2020-05-31	Stevan Wisozk	stevan.wisozk@geemail.com	Philadelphia	Pennsylvania	6011797225094530417	391e720f441db78efe91aa19ee00a498	JCB 15 digit	40.0826350911479423	-75.0804214157063541
28122	2020-05-31 19:14:24	2020-05-31	Glennie Armstrong	glennie.armstrong@geemail.com	Fort Lauderdale	Florida	3096392364814982688	1d0c28f95f39b7e7f31bf02625881dd9	JCB 15 digit	26.1110276095557978	-80.1248229108571905
28123	2020-05-31 19:27:40	2020-05-31	Jackie Grant	jackie.grant@geemail.com	Tacoma	Washington	3490860695269595	37dc528d50e7cfca973886cc38877bd6	Mastercard	47.2208789919156615	-122.382092304132129
28124	2020-05-31 19:33:19	2020-05-31	Miss Delta Mann	miss.delta.mann@geemail.com	San Francisco	California	6011005211716835531	97dc668df8ad39f211cee8becc9aa61d	VISA 16 digit	37.7941603806344233	-122.432078876104029
28125	2020-05-31 19:37:50	2020-05-31	Goebel Lowe	goebel.lowe@geemail.com	Phoenix	Arizona	3014768027509718	1692ac8099c12b2a6adb2e944e530516	VISA 16 digit	33.5911600633457326	-112.02067441278362
28126	2020-05-31 19:46:45	2020-05-31	Channing Jenkins	channing.jenkins@geemail.com	Sunnyvale	California	180007694644851985	f10829ef3ce5584260d55b002701ed53	JCB 16 digit	37.4833840652827206	-121.943116869098702
28127	2020-05-31 19:52:35	2020-05-31	Shemar Mann	shemar.mann@geemail.com	Chandler	Arizona	3096881867731857401	f568c3deb96882827f3a531de4a36d74	JCB 16 digit	33.2557283563163111	-111.819761092995847
28128	2020-05-31 20:00:35	2020-05-31	Kyler Halvorson	kyler.halvorson@woohoo.com	San Jose	California	55305786450260605	d5a5c2288d7e36e156083ec8ed2a4bc1	Diners Club / Carte Blanche	37.3654955923378509	-121.720945476669442
28129	2020-05-31 20:08:43	2020-05-31	Algie Yost DDS	algie.yost.dds@geemail.com	Elgin	Illinois	52702840526903950	4347f60b78fece8e1e8702fdd3d20370	Discover	42.0324293570876151	-88.2917449788011623
28130	2020-05-31 20:22:01	2020-05-31	Brenton Greenholt	brenton.greenholt@geemail.com	Sacramento	California	3112046003841345945	b366c177d7e741c4b81404a049995c44	JCB 16 digit	38.4978581723090301	-121.550334101474277
28131	2020-05-31 20:35:11	2020-05-31	Clement Keeling	clement.keeling@geemail.com	Macon	Georgia	51523860019165252	499fe60a6638cda810d9db39d7171b88	Maestro	32.7781547444418067	-83.6828177140288005
28132	2020-05-31 20:38:00	2020-05-31	Holden Gleason	holden.gleason@geemail.com	New York	New York	3088366966225496124	96e34107e5796847b0cdb7f1339692ec	Voyager	40.579502722643312	-73.8402219742897898
28133	2020-05-31 20:44:58	2020-05-31	Kris Littel	kris.littel@geemail.com	Costa Mesa	California	3774903923689901	1d55818d111d45df5e1d6ccd35ff4dd8	American Express	33.6996742253206705	-117.998036187919979
28134	2020-05-31 20:46:37	2020-05-31	Djuna Rogahn PhD	djuna.rogahn.phd@warmmail.com	New Orleans	Louisiana	4856341960479	2397e94767f67488302e1b8dfd78ac7e	JCB 15 digit	30.084402113502474	-89.9490979732740641
28135	2020-05-31 20:58:54	2020-05-31	Severt Walter	severt.walter@woohoo.com	Corona	California	4505524169212999	42dd8c5b4d194ecc7d802229976ef2ef	JCB 16 digit	33.9425416830815365	-117.579787036377937
28136	2020-05-31 21:11:40	2020-05-31	Isaac Connelly	isaac.connelly@woohoo.com	Dallas	Texas	3096459981617745572	60de13e6ed63b2aa12d4a26089456eef	American Express	32.8166950008172549	-96.7806164924949286
28137	2020-05-31 21:14:40	2020-05-31	Deja Flatley	deja.flatley@geemail.com	Berkeley	California	869942936134521819	af9beb6b087da33c04aba3662f3c88a7	Discover	37.8984739498410192	-122.293201692065296
28138	2020-05-31 21:15:09	2020-05-31	Chanie Goodwin	chanie.goodwin@geemail.com	Columbus	Ohio	3415032184054803	0655b3fbf6bd0dd63f834826f575d1cc	VISA 13 digit	39.9851340871814642	-83.0573089927669628
28139	2020-05-31 21:46:24	2020-05-31	Dr. Javen Zboncak V	dr.javen.zboncak.v@geemail.com	New York	New York	6011827241070506002	c81cfa7916adafaa60399297e082e6ad	JCB 15 digit	40.7362734378539031	-74.0216928079154286
28140	2020-05-31 22:10:19	2020-05-31	Braedon Lesch-Kohler	braedon.lesch.kohler@geemail.com	Rochester	Minnesota	3528256383920999613	e7ca2cb1dd3790c39eab3e053f64da0a	JCB 16 digit	44.0613268688224267	-92.3914073058523257
28141	2020-05-31 22:16:55	2020-05-31	Sydni Cartwright	sydni.cartwright@geemail.com	Jacksonville	Florida	4026787687867	e2c6e0a6d1dd036bd88d7fcd16ade972	Diners Club / Carte Blanche	30.4009259504783884	-81.6480134937990556
28142	2020-05-31 22:17:29	2020-05-31	Betha Boehm	betha.boehm@geemail.com	Miami	Florida	060488589387823	f9d696722932e0407cccf13a49960ae4	Voyager	25.8131488286562281	-80.1094959012571763
28143	2020-05-31 22:18:33	2020-05-31	Chaney Bechtelar DVM	chaney.bechtelar.dvm@geemail.com	Cape Coral	Florida	6011584106810729078	cacc44723a4b7838b67a9d447ffdba7a	Discover	26.581423532726987	-81.9435466958746304
28144	2020-05-31 22:27:21	2020-05-31	Lesley Olson	lesley.olson@geemail.com	San Francisco	California	3088168571751456896	3d7a657ca9810e3429c9f85df852c725	Discover	37.8198688721087137	-122.436081032463065
28145	2020-05-31 22:46:32	2020-05-31	Jimmy Beer	jimmy.beer@geemail.com	Colorado Springs	Colorado	4525593589452671	2cf1c248ab5501d2148d7fb2fa774b25	Maestro	38.8867149094168099	-104.760219259016964
28146	2020-05-31 22:53:34	2020-05-31	Randolf Orn	randolf.orn@geemail.com	Gilbert	Arizona	180023286006836488	4577b13a4c9efb9c879ea406dae38040	VISA 16 digit	33.2258761729925851	-111.838989469282694
28147	2020-05-31 23:04:41	2020-05-31	Charlene Quitzon	charlene.quitzon@geemail.com	Lincoln	Nebraska	3528361214212207633	12086e31d21f6e5cecca3da07fdf2418	VISA 16 digit	40.8840323930159215	-96.6698186563488093
28148	2020-05-31 23:09:47	2020-05-31	Rich Stiedemann	rich.stiedemann@geemail.com	Fresno	California	676152187566238	96dbabd23c31d45fdfe538711c0ab20d	Diners Club / Carte Blanche	36.6857072289906441	-119.827883836498117
28149	2020-05-31 23:17:29	2020-05-31	Mrs. Cheryl Fadel DDS	mrs.cheryl.fadel.dds@geemail.com	Corpus Christi	Texas	3528794399828897328	e348bb8f52c0a273dcf6cf14763d9caf	JCB 15 digit	27.7605023159116513	-97.1022159451447493
28150	2020-05-31 23:41:16	2020-05-31	Burney Crona	burney.crona@geemail.com	Fayetteville	North Carolina	6011887429357374932	8180e7e09b095ab81880bdece1c49b96	JCB 15 digit	35.0605063935995105	-78.9748061746954875
28151	2020-05-31 23:43:15	2020-05-31	Tyrone Spinka Jr.	tyrone.spinka.jr.@geemail.com	San Francisco	California	4627652305083447	edd44c7aec32f19376a974d7937e2399	American Express	37.7874923662787339	-122.409900023635302
28152	2020-05-31 23:44:39	2020-05-31	Vella Cummerata DVM	vella.cummerata.dvm@woohoo.com	New York	New York	3420072231886644	02650aef8b5f3498e603a96fbda901c1	Mastercard	40.5635548590440322	-73.9603151340864571
28153	2020-05-31 23:58:35	2020-05-31	Lovell Streich	lovell.streich@geemail.com	San Francisco	California	55913530006632394	61dd1c7d7b5917df4480107425fbe730	JCB 16 digit	37.7602931782524749	-122.421027335821975
28154	2020-06-01 00:00:48	2020-06-01	Justyn Kunze V	justyn.kunze.v@warmmail.com	Albuquerque	New Mexico	6011094445750679932	019e8dabfba543c3d8c0a6abeba83606	Diners Club / Carte Blanche	35.1695737104531432	-106.604802336504321
28155	2020-06-01 00:03:34	2020-06-01	Pluma Dickens	pluma.dickens@geemail.com	Durham	North Carolina	4887649682903	37808452c6634a22bb54d2f7d0049571	JCB 15 digit	35.9349771244697251	-78.8424761501509721
28156	2020-06-01 00:07:47	2020-06-01	Arbie Hegmann	arbie.hegmann@woohoo.com	Lubbock	Texas	4003805756651	1cc89e4a28436290d4cd165cdbc2b50f	VISA 16 digit	33.5396887081716244	-101.852225815729057
28157	2020-06-01 00:08:25	2020-06-01	Annamae Aufderhar-Bernier	annamae.aufderhar.bernier@geemail.com	Plano	Texas	3038486922188464	dc2d30ddc5d7169cc280e5e5750a9c62	Discover	33.1183605417694906	-96.8036839024811968
28158	2020-06-01 00:18:41	2020-06-01	Mrs. Ara Turcotte DDS	mrs.ara.turcotte.dds@woohoo.com	Oakland	California	4762554088926807	d5b4094b0ad0d9bbfbdf646f33dbc6e2	Voyager	37.8164009975768138	-122.28818871598267
28159	2020-06-01 00:27:27	2020-06-01	Alcee Schmitt	alcee.schmitt@warmmail.com	Berkeley	California	3158556847910468547	1479030fa9e9ab95fb2f88e7b33874b2	Discover	37.8772202926149646	-122.246042909641801
28160	2020-06-01 00:41:00	2020-06-01	Delvin Schiller	delvin.schiller@woohoo.com	Lancaster	California	3004949149200861	ff63cc071d0257b6128888cdc44e3587	VISA 13 digit	34.5937290454529247	-118.146942021089785
28161	2020-06-01 00:44:28	2020-06-01	Baylie Dickens MD	baylie.dickens.md@geemail.com	Garland	Texas	503816974197473	7a55995df176f48789f71543c040942c	JCB 15 digit	32.8612263454359024	-96.7220670881375781
28162	2020-06-01 00:49:03	2020-06-01	Williams Ernser Sr.	williams.ernser.sr.@geemail.com	Athens	Georgia	4835625615112682	7abd5e841355ce3839553432bc3a0231	JCB 16 digit	33.8759504504226143	-83.3755308246821158
28163	2020-06-01 00:54:49	2020-06-01	Mrs. Charissa Graham	mrs.charissa.graham@geemail.com	Peoria	Illinois	4320878072224	ee1655ad347f8fd5228d773f21217997	Voyager	40.6700038282535985	-89.6343360962230804
28164	2020-06-01 01:04:05	2020-06-01	Jasmin Medhurst	jasmin.medhurst@geemail.com	Los Angeles	California	3528620888292974712	cedf1b8727afe3932c751bb13516baac	VISA 13 digit	34.0596646019123455	-118.344028569617493
28165	2020-06-01 01:16:11	2020-06-01	Ms. Chelsi Schroeder DDS	ms.chelsi.schroeder.dds@geemail.com	Jackson	Mississippi	869902558644889466	53cedcd5682d3aefc69bbbfca64bd3bb	VISA 16 digit	32.29832497497015	-90.2984162783689754
28166	2020-06-01 01:18:24	2020-06-01	Jaida Von	jaida.von@geemail.com	Knoxville	Tennessee	6011554844831487393	27bf9337b00950bf21acc0a760488a7d	Mastercard	36.0450151956237832	-83.9579068141274121
28167	2020-06-01 01:23:06	2020-06-01	Sarrah Fadel PhD	sarrah.fadel.phd@warmmail.com	Oakland	California	676378580126072	92960e77fa73b87541eec4c2cd53b6b5	JCB 16 digit	37.8095773123107577	-122.256456617977236
28168	2020-06-01 01:50:12	2020-06-01	Izetta Rosenbaum-Bayer	izetta.rosenbaum.bayer@geemail.com	New York	New York	676184486776606	7d32d142c756b1f3277bf3e64300d8e3	American Express	40.5812317794412394	-73.9533162929944723
28169	2020-06-01 01:50:43	2020-06-01	Aleena Wisozk	aleena.wisozk@warmmail.com	New York	New York	4958657024548504	a046f27b5d20f83bb96b89fe1b14fed1	Mastercard	40.7231337848808579	-73.9259021210845475
28170	2020-06-01 01:51:49	2020-06-01	Ewin Sanford DDS	ewin.sanford.dds@geemail.com	Lubbock	Texas	210004132982104272	4ecc77d9915adec24804503b9324af46	JCB 16 digit	33.6262812536716496	-101.879247546280553
28171	2020-06-01 02:02:52	2020-06-01	Ms. Darcy Brekke	ms.darcy.brekke@geemail.com	New York	New York	3037642918273972	7f429cb1d03eeac97f9002e10b704b22	Voyager	40.6259244756996623	-73.853160161654273
28172	2020-06-01 02:11:03	2020-06-01	Iza Jast	iza.jast@warmmail.com	San Francisco	California	51021730242468525	4cf4c7514785d0aaab7d6a82f7db624f	Maestro	37.7889460246573279	-122.458648051641646
28173	2020-06-01 02:12:32	2020-06-01	Madison Abernathy	madison.abernathy@geemail.com	New York	New York	869985281367394180	ef99fd528e3b6026fd14e67b413e124e	Maestro	40.6200502414479843	-73.9979619027011069
28174	2020-06-01 02:14:21	2020-06-01	Erling Spencer DDS	erling.spencer.dds@geemail.com	Corpus Christi	Texas	55241757249611827	0677fd274d605bfa49321d28757e8e7e	Discover	27.8318770686101189	-97.1586225920185456
28175	2020-06-01 02:17:06	2020-06-01	Adam Simonis	adam.simonis@geemail.com	Tampa	Florida	3044351701669551	333c574427bb667768902c656be6dd5e	Voyager	27.9646984489750103	-82.4787863057784705
28176	2020-06-01 02:24:44	2020-06-01	Wendi Denesik	wendi.denesik@woohoo.com	Fullerton	California	4453001548016237	6a6d6a88cc2848b7288a1ec9e0f3bafd	American Express	33.8880768941406174	-118.004504824543375
28177	2020-06-01 02:34:51	2020-06-01	Dr. Elton Kub I	dr.elton.kub.i@woohoo.com	Louisville	Kentucky	589335064263920	1ab2a5b0832376b440de9a0d5ee34c53	JCB 16 digit	38.2172086512107398	-85.6382973754849388
28178	2020-06-01 02:34:55	2020-06-01	Dr. Ciji Aufderhar	dr.ciji.aufderhar@geemail.com	San Francisco	California	3710371970077007	4c38628b4a4e52aaf517c2d20d0bab9e	American Express	37.7698571673523276	-122.411704362934017
28179	2020-06-01 02:39:01	2020-06-01	Lissette Parker	lissette.parker@woohoo.com	Glendale	Arizona	4121000904296	76f2cf0c83df1ebd97b41d926d909947	VISA 16 digit	33.4810353658389275	-112.167174146536354
28180	2020-06-01 02:42:13	2020-06-01	Shiela Tremblay PhD	shiela.tremblay.phd@geemail.com	San Francisco	California	6011409119841292795	9e065e9bbebde55cc25a014d1d209ab4	Maestro	37.7670175461535607	-122.432606664055101
28181	2020-06-01 02:45:18	2020-06-01	Ramon Roberts	ramon.roberts@warmmail.com	San Jose	California	869996313425488345	38163d6d147300b4e359c4e5f27e014d	Maestro	37.2566084059242186	-121.820437243649366
28182	2020-06-01 02:46:04	2020-06-01	Bertha Reilly	bertha.reilly@geemail.com	St. Petersburg	Florida	4320584374440085	a91ff5c4fe06c0c5563b36749191cc3d	VISA 16 digit	27.7076656415015457	-82.6343806963305809
28183	2020-06-01 02:59:50	2020-06-01	Ardella Boyle-Effertz	ardella.boyle.effertz@geemail.com	New York	New York	3337209342977186100	5b5bc5b632fa5806b773e4251752131b	VISA 16 digit	40.7101918640304348	-73.9416358568601311
28184	2020-06-01 03:11:26	2020-06-01	Georgette Stark-Borer	georgette.stark.borer@geemail.com	Providence	Rhode Island	3112427411332435571	4bca030e114afd35ed123b3b7c49ed47	Discover	41.7900973822310533	-71.4964936872396635
28185	2020-06-01 03:14:33	2020-06-01	Dr. Elton Morissette PhD	dr.elton.morissette.phd@geemail.com	Miami	Florida	3096854263829797787	b725294ce567fc88c6b2587f136c74ab	Diners Club / Carte Blanche	25.7819161616869295	-80.1873986801937235
28186	2020-06-01 03:17:42	2020-06-01	Nash Strosin	nash.strosin@geemail.com	Austin	Texas	180097300183839974	29ecfd494a8a6f7ddda8adc8c683eca4	Maestro	30.2109867273956532	-97.8415416102163533
28187	2020-06-01 03:18:31	2020-06-01	Miss Val Mosciski	miss.val.mosciski@geemail.com	Provo	Utah	3158228614782264208	90f7972699f29a682992d9ff82aba919	Mastercard	40.2946192969821411	-111.61536585419924
28188	2020-06-01 03:22:35	2020-06-01	Dannie Mante	dannie.mante@woohoo.com	Provo	Utah	3158606106849608123	7efe47cf6b77918616654bfc03e40473	Diners Club / Carte Blanche	40.2028910905841741	-111.561444534002987
28189	2020-06-01 03:45:41	2020-06-01	Gavin King	gavin.king@geemail.com	New York	New York	55744759427956547	efc47df2a7f0cdea8660d70f7831a967	VISA 16 digit	40.6813523433394693	-73.8991921445250455
28190	2020-06-01 03:48:48	2020-06-01	Dr. Kyara Thompson	dr.kyara.thompson@geemail.com	Corpus Christi	Texas	210063941933877747	96be2f8913a9399720dfc2bf5671412d	Maestro	27.70997587548867	-97.2477644428905137
28191	2020-06-01 03:55:22	2020-06-01	Ms. Breanna Windler DDS	ms.breanna.windler.dds@geemail.com	San Francisco	California	869910768321658486	0f84cadfb9641789dfd495d8b82b7e69	Discover	37.7437782061793712	-122.435575553153058
28192	2020-06-01 03:57:48	2020-06-01	Ms. Adyson Muller DVM	ms.adyson.muller.dvm@woohoo.com	San Francisco	California	210061205127106335	cb52cf210c71dc53b850109950ff28f7	VISA 16 digit	37.8073105484121825	-122.420893548433696
28193	2020-06-01 03:58:23	2020-06-01	Dorla Beahan	dorla.beahan@warmmail.com	New York	New York	3048639109121308	75e76df6f56f1f24fdc77c3642c32e0c	JCB 16 digit	40.6939680646397193	-73.857495155314723
28194	2020-06-01 04:01:23	2020-06-01	Victorine Rogahn	victorine.rogahn@woohoo.com	Los Angeles	California	6011514520958274801	477cd77913ee64b4fab6cc20409f3bfa	Voyager	33.9568355293344695	-118.338590665160865
28195	2020-06-01 04:03:37	2020-06-01	Erie Kling-Johnston	erie.kling.johnston@geemail.com	San Francisco	California	3337621349086037108	9d9b36523a94bb13a439fb9dc04e87a5	JCB 16 digit	37.7804976376334665	-122.45394472221372
28196	2020-06-01 04:19:59	2020-06-01	Hank Witting-Ryan	hank.witting.ryan@geemail.com	Temecula	California	210013159486967937	5ecb97944b14e65e73a4651030b5c7d6	Diners Club / Carte Blanche	33.4163883016578822	-117.08042258142568
28197	2020-06-01 04:35:33	2020-06-01	Raymundo Quigley	raymundo.quigley@geemail.com	Austin	Texas	3088511574371661568	73faed0c53b35a52ade688febbbe5d23	JCB 16 digit	30.2525887782346459	-97.6820960088871431
28198	2020-06-01 04:39:12	2020-06-01	Paulo Johnston	paulo.johnston@geemail.com	Akron	Ohio	3401988420775640	5389f234b3f473e3d869c372ebd455e9	JCB 16 digit	41.0719274720475056	-81.5454881974808927
28199	2020-06-01 04:54:41	2020-06-01	Tristen Robel	tristen.robel@geemail.com	Portland	Oregon	4163411458003359	5eb6003ed3707977d65af6721c93d1f2	Voyager	45.5551699978187656	-122.641229229280725
28200	2020-06-01 04:56:08	2020-06-01	Mr. Iva Gulgowski	mr.iva.gulgowski@geemail.com	Round Rock	Texas	3528556662628826195	6b3dcb63d3c5eea559fa41082c44ed30	Voyager	30.4487209383070478	-97.7032662373352707
28201	2020-06-01 04:58:15	2020-06-01	Bernardine Strosin	bernardine.strosin@geemail.com	New York	New York	4205392064773454	e1c9561e9de218ae700bf81a31e13929	Maestro	40.6643747153915456	-73.9331228163920287
28202	2020-06-01 05:18:39	2020-06-01	Mr. Jeremey Wiegand	mr.jeremey.wiegand@woohoo.com	San Francisco	California	4146348711250728	e7441e59abf9983debed5465a04ef4d9	American Express	37.7875335867558775	-122.42186443595169
28203	2020-06-01 05:22:34	2020-06-01	Zilpah Orn-Pollich	zilpah.orn.pollich@woohoo.com	Newark	New Jersey	4164499347132876	173cf650419c0fdd7e270278fe7357e1	JCB 16 digit	40.6748696933414848	-74.0875381966330195
28204	2020-06-01 05:31:51	2020-06-01	Emilio Hammes	emilio.hammes@geemail.com	Denton	Texas	180092797208071225	4cd84583f3716ab93e35da195bb817f7	JCB 15 digit	33.307126534151287	-97.1045311368197304
28205	2020-06-01 05:34:38	2020-06-01	Shantell Osinski-Parisian	shantell.osinski.parisian@geemail.com	Tulsa	Oklahoma	180029564719724389	450117d697d2ce34bc7813c3b12f9b6f	Discover	36.1203495306331632	-95.9836164587132572
28206	2020-06-01 05:39:07	2020-06-01	Alysha Rosenbaum	alysha.rosenbaum@warmmail.com	Houston	Texas	869917528084357632	d20711e4dab0777a1506394c6b815639	American Express	29.7087249575726702	-95.3800375997103771
28207	2020-06-01 05:52:55	2020-06-01	Michal Leuschke	michal.leuschke@warmmail.com	Vallejo	California	4822807452963	d53953b01e891976129b4f23ce596d80	VISA 16 digit	38.1557466061409585	-122.324180266946556
28208	2020-06-01 05:53:25	2020-06-01	Mr. Bryan Turcotte	mr.bryan.turcotte@geemail.com	McKinney	Texas	3405740038619454	5a8c6f6cb9d3d88f8ef01b6e21812319	VISA 16 digit	33.1470156259965165	-96.6140117355454748
28209	2020-06-01 05:56:24	2020-06-01	Ginger Kilback	ginger.kilback@geemail.com	San Diego	California	180020631933520668	bf91cb94760e683eb9570fe2c97cf106	Maestro	32.8701571202904006	-117.116391638237985
28210	2020-06-01 05:59:39	2020-06-01	Alonzo Olson	alonzo.olson@geemail.com	Victorville	California	3337320454450879590	07c55f1b23e95ddc03d07f6564c359f2	VISA 13 digit	34.5840712073490053	-117.265393904518703
28211	2020-06-01 06:00:01	2020-06-01	Dr. Elvis Gleichner	dr.elvis.gleichner@geemail.com	Albuquerque	New Mexico	3002927283993733	5db10351787b4a4108fbfee6541e8363	VISA 16 digit	35.2041464572906548	-106.718023660506688
28212	2020-06-01 06:03:25	2020-06-01	Marge Orn	marge.orn@geemail.com	Waco	Texas	4628706691952703	14e3ab0adf4aec310f3a937ea416f681	VISA 16 digit	31.5424944127187104	-97.1546406956985606
28213	2020-06-01 06:32:57	2020-06-01	China Ebert	china.ebert@geemail.com	Los Angeles	California	4245649481050481	3494433c59646c838d2e742cce373184	American Express	33.9831445461936283	-118.389233041647074
28214	2020-06-01 06:35:18	2020-06-01	Brenton Veum-Rippin	brenton.veum.rippin@geemail.com	New York	New York	4192929485865	c419ad32fe4e8a2f7c0c549d8ce1b5f7	Mastercard	40.6258336933087563	-74.0071987381566316
28215	2020-06-01 06:48:55	2020-06-01	Madisyn Huel	madisyn.huel@geemail.com	Phoenix	Arizona	4847026212664157	00d8004543bc1ce8a8dea7dc5da4bea6	VISA 13 digit	33.5720298007529223	-112.123666958643497
28216	2020-06-01 06:50:20	2020-06-01	Tiffany Lueilwitz	tiffany.lueilwitz@geemail.com	Fort Collins	Colorado	3337508045628950778	a0d7622cc9f16ba825120f846b3be84c	JCB 16 digit	40.4711658297728789	-105.05451498021857
28217	2020-06-01 06:56:48	2020-06-01	Mr. Ceylon Crooks	mr.ceylon.crooks@woohoo.com	Kent	Washington	3337605709185508616	51d61a15159264c4ce8659e0a5535a62	JCB 16 digit	47.3326522754617045	-122.302649087891723
28218	2020-06-01 07:08:04	2020-06-01	Hilario Mills	hilario.mills@geemail.com	San Diego	California	676247239563902	bffdfc24dbf8aebe7ad0249ae2c6f21a	VISA 16 digit	32.7838316378716357	-117.066121205259122
28219	2020-06-01 07:11:36	2020-06-01	Janelle Kuphal-Carter	janelle.kuphal.carter@geemail.com	San Francisco	California	630460531869679	e61ecabde2a450e42ce29dfe6b97ce5c	JCB 16 digit	37.7835168185902077	-122.449060885984807
28220	2020-06-01 07:12:56	2020-06-01	Briley Nolan	briley.nolan@geemail.com	Baltimore	Maryland	4063661830880988	b813f1899ede6187b2621a27dabeff08	JCB 16 digit	39.3622971132863313	-76.660491915095605
28221	2020-06-01 07:33:30	2020-06-01	Shantel McKenzie	shantel.mckenzie@geemail.com	Norman	Oklahoma	3528122931080636185	0f64548351697c09f121b427fc3946ad	Diners Club / Carte Blanche	35.2064814090769715	-97.3434177286710565
28222	2020-06-01 07:37:09	2020-06-01	Red Price	red.price@geemail.com	Oklahoma City	Oklahoma	4351186247722756	fd226f73ebc2897663a29a11aef118cb	Discover	35.4111914951730569	-97.4362261235144018
28223	2020-06-01 07:38:15	2020-06-01	Fitzgerald Carter	fitzgerald.carter@warmmail.com	Ontario	California	4983937270900479	ffe7f7df90edf11b76ce3fc7d8c7c82d	JCB 16 digit	33.949010816370695	-117.645596477352839
28224	2020-06-01 07:42:46	2020-06-01	Dwaine Ziemann	dwaine.ziemann@geemail.com	Memphis	Tennessee	210088709893259581	ac560f1a1ceb117c20b0a19eeff2b846	Mastercard	35.0782732965491704	-90.0177456315398246
28225	2020-06-01 07:50:53	2020-06-01	Orla Sawayn IV	orla.sawayn.iv@geemail.com	Berkeley	California	180096797250180102	f4ea164c8a24a27156b473d3879b1be8	Maestro	37.8725400446707425	-122.255211937580157
28226	2020-06-01 07:56:19	2020-06-01	Wm Hilll	wm.hilll@woohoo.com	San Francisco	California	53450485829666674	9192bb4496f704dcbf045ef34c84c1a6	Voyager	37.7624039181781654	-122.444071543200607
28227	2020-06-01 08:05:37	2020-06-01	Jame Zieme	jame.zieme@geemail.com	Bellevue	Washington	6011031141330716437	29cd988b3530f9e3ddee007ae3ad507b	Diners Club / Carte Blanche	47.6184299255438148	-122.083322373550374
28228	2020-06-01 08:06:08	2020-06-01	Mr. Tristen Volkman	mr.tristen.volkman@geemail.com	New York	New York	4603994139997	5f51901c854731d6f6ac5c54d3409324	Discover	40.5709572904966791	-73.9857309951342614
28229	2020-06-01 08:14:43	2020-06-01	Moses Harris	moses.harris@geemail.com	Indianapolis	Indiana	869909739258731185	665df1105f3db6137e17f5f6f7436480	JCB 16 digit	39.8291719522334589	-86.1935578115951273
28230	2020-06-01 08:16:53	2020-06-01	Melany Johnson	melany.johnson@geemail.com	San Francisco	California	3158701838760955216	ea0709f2cf9907e76af6466278450692	JCB 15 digit	37.7718983998466271	-122.446430192710352
28231	2020-06-01 08:29:16	2020-06-01	Jorge Carroll	jorge.carroll@geemail.com	New York	New York	6011044055672772342	eda006f7e5b7ee43d169c91dc2fec9d5	American Express	40.6029147053826591	-73.9022135936085078
28232	2020-06-01 08:57:15	2020-06-01	Miss Thyra O'Kon PhD	miss.thyra.o'kon.phd@woohoo.com	Las Vegas	Nevada	3454912461575400	42cf20603d4801753534b13041f4a2da	Mastercard	36.2306550438150765	-115.21961534542254
28233	2020-06-01 09:11:04	2020-06-01	Clytie Wiegand	clytie.wiegand@geemail.com	San Angelo	Texas	3158660577991761477	a3cfbd3475602ba62a4de35428b552b8	JCB 16 digit	31.387695467720178	-100.372767229342841
28234	2020-06-01 09:20:59	2020-06-01	Miss Zula Volkman MD	miss.zula.volkman.md@geemail.com	San Francisco	California	6011489059328576000	3346a05eaf16ecec8dd130ffa81af786	VISA 16 digit	37.7609756377143881	-122.416587497007342
28235	2020-06-01 09:21:58	2020-06-01	Dr. Lula Jaskolski	dr.lula.jaskolski@geemail.com	Montgomery	Alabama	3732983218132743	39130c10fc4a7262e242dbc7f60a52fe	VISA 13 digit	32.3530291429653758	-86.3169821897208607
28236	2020-06-01 09:26:01	2020-06-01	Kelsi Effertz	kelsi.effertz@geemail.com	Columbus	Ohio	869956424211536854	31eac0f50d76736b931952f5e29c4f07	JCB 16 digit	39.9418015587653983	-83.0436667033240212
28237	2020-06-01 09:34:46	2020-06-01	Sydnee Dickens	sydnee.dickens@woohoo.com	Anchorage	Alaska	3029511570971686	5da77f5c91938034df6bb8e50d3d704d	Maestro	61.0767359154049316	-149.372962594789641
28238	2020-06-01 09:41:39	2020-06-01	Glennie Gleichner	glennie.gleichner@woohoo.com	New York	New York	3158833820882904455	8d523a9b0b6180e7d5119e88f3c70011	Mastercard	40.7178598744086884	-73.8502455870516599
28239	2020-06-01 09:44:35	2020-06-01	Maurine Walker-Rosenbaum	maurine.walker.rosenbaum@woohoo.com	Sacramento	California	3528479291372814001	65850efd9351758326555719c327ddf5	VISA 16 digit	38.5467490357611311	-121.551420404367519
28240	2020-06-01 09:54:50	2020-06-01	Finley Price	finley.price@woohoo.com	San Bernardino	California	3030083709989376	ddeb0aeccf192eb06b813a854ac615e9	Mastercard	34.1994074869234055	-117.372610250605646
28241	2020-06-01 10:12:12	2020-06-01	Gage Rempel	gage.rempel@warmmail.com	Peoria	Illinois	869978253764965184	14ca41849a00253b23319b1ec62f496c	American Express	40.8040672009214731	-89.6475497824955738
28242	2020-06-01 10:23:11	2020-06-01	Mr. Kane Nienow	mr.kane.nienow@geemail.com	Los Angeles	California	4595965054837229	11f35783f45cc9206f0597ba20f9a5cc	Discover	34.0837563483376016	-118.444390901363633
28243	2020-06-01 10:31:15	2020-06-01	Arvid Bayer-Bogan	arvid.bayer.bogan@warmmail.com	San Francisco	California	3096826604464589986	6a60712573c3af42fdc6b41e9a92f498	Mastercard	37.7884551335503787	-122.438081135042381
28244	2020-06-01 10:33:41	2020-06-01	Alwina Schuppe MD	alwina.schuppe.md@warmmail.com	Honolulu	Hawaii	4583500648819328	5aaceaae794644eb70b2b91ad673d8d5	JCB 15 digit	21.3568694037601361	-157.916648704532918
28245	2020-06-01 10:35:26	2020-06-01	Bart Schimmel	bart.schimmel@geemail.com	San Jose	California	4764011719045	b86b0e20caa04ebd28b16ae3c76a01af	Diners Club / Carte Blanche	37.295940584438668	-121.84973609165624
28246	2020-06-01 10:43:42	2020-06-01	Elianna Johns	elianna.johns@geemail.com	Austin	Texas	55962137676400142	3a563d16c443fc9f9042b8e68bc28ab3	VISA 13 digit	30.2386971767187092	-97.8051221385371008
28247	2020-06-01 10:46:09	2020-06-01	Amirah Schamberger	amirah.schamberger@geemail.com	Rancho Cucamonga	California	3737807569936300	bb6f46c00fde35c45e735ef6620bbfa8	VISA 16 digit	34.1421627250958224	-117.617689844314754
28248	2020-06-01 10:54:16	2020-06-01	Mr. Mayo Lindgren	mr.mayo.lindgren@geemail.com	West Covina	California	3005242010808098	c1be9ff3ad08abe9acb1b950f759f138	Maestro	34.1170149472650124	-118.0017379810173
28249	2020-06-01 11:05:08	2020-06-01	Zoe Jerde	zoe.jerde@warmmail.com	Hialeah	Florida	3797407864960357	ece8c0c4c23e282f1aa7cbd3703abe45	VISA 16 digit	25.9680386295054113	-80.2435584217678723
28250	2020-06-01 11:09:11	2020-06-01	Alan Mayer	alan.mayer@woohoo.com	Wichita	Kansas	4218022181947484	d8a714d06e0e92bdb044427bced452a6	Voyager	37.6728594071108844	-97.3904287648588394
28251	2020-06-01 11:11:20	2020-06-01	Mrs. Dorcas Cremin	mrs.dorcas.cremin@warmmail.com	Minneapolis	Minnesota	3088071905602628616	77dc7d9a7cbc54991e658c6e6c10ce92	JCB 16 digit	45.0277966299645556	-93.3572175220392637
28252	2020-06-01 11:13:45	2020-06-01	Joselin Ratke	joselin.ratke@geemail.com	San Francisco	California	869999175190657868	18fb4fef2b03e0fc0135ca0c3545ccdf	Diners Club / Carte Blanche	37.7863910730922683	-122.381995073024669
28253	2020-06-01 11:32:50	2020-06-01	Gilda Murphy	gilda.murphy@geemail.com	Boston	Massachusetts	4613765132288223	1b4f20b69bad0bd544d3ecd15c59f798	VISA 13 digit	42.430217730922628	-71.0430110569063658
28254	2020-06-01 11:52:03	2020-06-01	Ras Lang	ras.lang@geemail.com	Macon	Georgia	6011691821675593399	aeeb92ee6e876e5403d1921fe0ad3d62	VISA 16 digit	32.8710519320808316	-83.671927166377003
28255	2020-06-01 12:01:07	2020-06-01	Dr. Paloma Oberbrunner PhD	dr.paloma.oberbrunner.phd@geemail.com	Lubbock	Texas	3782165043531369	b6b57e8ee8c0721e72f6f81b843dd91f	Mastercard	33.6196536708664198	-101.846605423177408
28256	2020-06-01 12:04:00	2020-06-01	Glennis Thompson	glennis.thompson@warmmail.com	Mesa	Arizona	3337812187898238103	f065b6b9736b14ab775bd02c6f6ad583	Voyager	33.3243650985561288	-111.762959163019062
28257	2020-06-01 12:20:16	2020-06-01	Maynard Botsford	maynard.botsford@geemail.com	New York	New York	3043725662020816	f614eb9648a1ff2fc9f8157e012befa7	VISA 16 digit	40.6438287415299584	-73.9249962584476918
28258	2020-06-01 12:21:20	2020-06-01	Rolf Schultz	rolf.schultz@geemail.com	Los Angeles	California	3112486082820499631	12fd70e0970fa71a921cfb439a6116c7	American Express	33.9782219458702954	-118.413030337262143
28259	2020-06-01 12:25:44	2020-06-01	Bliss Kertzmann-Ledner	bliss.kertzmann.ledner@warmmail.com	Baton Rouge	Louisiana	180013210261973135	98d28751a5cd81c725d8c8142942f3a2	VISA 13 digit	30.3646270588718359	-91.1697116658199604
28260	2020-06-01 12:32:11	2020-06-01	Asha McKenzie	asha.mckenzie@geemail.com	Renton	Washington	3494803373690126	1cb91e2d84e92b0b2d1c967bdab0bbf1	Maestro	47.3886122166704382	-122.124509878324332
28261	2020-06-01 12:34:02	2020-06-01	Neta Considine	neta.considine@woohoo.com	Wichita	Kansas	3031420008191560	01938b9d961951bdd0fc9ed501572370	Discover	37.6348200452391026	-97.310537879608205
28262	2020-06-01 12:37:43	2020-06-01	Ms. Mindy Veum PhD	ms.mindy.veum.phd@geemail.com	San Diego	California	3337830538412623212	033a67ea122f1b69ef566e218d779c42	JCB 16 digit	32.8830349361591061	-117.058348355572676
28263	2020-06-01 12:38:52	2020-06-01	Doloris Schamberger	doloris.schamberger@warmmail.com	Vacaville	California	3337928075441806313	5088a6225d7a29e4349528ff30ed8292	Discover	38.3130704586986468	-122.008837702020259
28264	2020-06-01 12:45:18	2020-06-01	Dr. Luanne Franecki	dr.luanne.franecki@woohoo.com	Frisco	Texas	3719258154762044	74a90eb31b23d9482a67d90a9cea3d6b	Maestro	33.2163253138303745	-96.7418708566319197
28265	2020-06-01 12:47:08	2020-06-01	Evelyn Koch	evelyn.koch@geemail.com	Lakewood	Colorado	4991646731506805	40332431e336b30ba73ac7d5e4c6d1d3	American Express	39.6912097312450456	-105.147761085538562
28266	2020-06-01 12:53:22	2020-06-01	Marla Hahn	marla.hahn@geemail.com	San Francisco	California	3020315002808105	6f0e095f156de9385a07bd155e83b246	JCB 16 digit	37.7893829474763407	-122.414985239836227
28267	2020-06-01 13:16:44	2020-06-01	Rohan Price	rohan.price@geemail.com	Glendale	Arizona	4772645616504633	9b3f238d68aa0c56ee598f382f904f73	Maestro	33.5963296964991827	-112.238776615427426
28268	2020-06-01 13:28:18	2020-06-01	Ladarius Bogisich	ladarius.bogisich@geemail.com	Madison	Wisconsin	676355076832884	55b9926f8afacf829f795227619676fb	VISA 16 digit	43.0952458337388933	-89.3382449880126899
28269	2020-06-01 13:32:23	2020-06-01	Dr. Alison Wuckert	dr.alison.wuckert@geemail.com	Antioch	California	3003888143408784	67c13cf4dd0819f44f381b618e645cf3	JCB 15 digit	37.9971422816425601	-121.803741275024407
28270	2020-06-01 14:05:40	2020-06-01	Miss Aliyah Crist DDS	miss.aliyah.crist.dds@geemail.com	Houston	Texas	630409042543729	39e057656c990dc9a188c0df43281702	American Express	29.7629557339552804	-95.3293986978489869
28271	2020-06-01 14:13:33	2020-06-01	Alphonsus Robel	alphonsus.robel@geemail.com	Durham	North Carolina	3158689376164447379	8caa38fe29a25b3763515c14b3ca4b73	Diners Club / Carte Blanche	35.8833231482900672	-78.8379526869297109
28272	2020-06-01 14:27:51	2020-06-01	Welton Runolfsson	welton.runolfsson@geemail.com	San Diego	California	3096420934756964666	c45e012e15f629b5f9d4c8c4d3684a18	VISA 16 digit	32.7172531173631569	-117.089254809720444
28273	2020-06-01 14:36:42	2020-06-01	Alida Pfannerstill MD	alida.pfannerstill.md@woohoo.com	Los Angeles	California	3158298996998493191	d9be3b3dcf42ad4895e3457e32cdb0e1	JCB 16 digit	34.016479348424447	-118.434190041710806
28274	2020-06-01 14:37:09	2020-06-01	Dr. Orren Marks	dr.orren.marks@geemail.com	New York	New York	180072027253167783	bd03ad380fc07939c144ba6085c2711d	Voyager	40.7536117779314537	-74.0087476490426752
28275	2020-06-01 14:40:25	2020-06-01	Anaya Konopelski	anaya.konopelski@geemail.com	San Francisco	California	210043750799530588	68ee1d28163e329fc0fe2036c0db6342	American Express	37.7692979677583693	-122.426263422898714
28276	2020-06-01 14:42:38	2020-06-01	Squire Reichel I	squire.reichel.i@warmmail.com	Wichita Falls	Texas	6011621390433392895	62fab86d6718f781c7b45a2bc255519e	JCB 16 digit	33.9717194963440292	-98.6172261665496848
28277	2020-06-01 14:48:09	2020-06-01	Samiyah Stanton	samiyah.stanton@geemail.com	Miramar	Florida	53864832547842865	7fdaa676f886bb037a64d0748bad6f94	Discover	26.004413189178333	-80.4332602838512543
28278	2020-06-01 14:51:19	2020-06-01	Orlin Wolf	orlin.wolf@warmmail.com	San Francisco	California	4020407949137312	cd8950c8dfbfa656f8ba9924cb05c07f	JCB 16 digit	37.7579955626659185	-122.432841123932022
28279	2020-06-01 15:05:30	2020-06-01	Hayley Kuvalis	hayley.kuvalis@geemail.com	San Francisco	California	3158132430476739800	535269f22e4c54b6f56d92bce613a98e	Diners Club / Carte Blanche	37.747222228408944	-122.459905159700639
28280	2020-06-01 15:07:45	2020-06-01	Alexandria Borer	alexandria.borer@geemail.com	Chicago	Illinois	3337444469849342374	f9bd2d8bea3270d1a15bc963d7ff6e2b	VISA 16 digit	41.7865956029690793	-87.7696737481776523
28281	2020-06-01 15:11:41	2020-06-01	Melody Morissette-Smitham	melody.morissette.smitham@warmmail.com	Los Angeles	California	4357556482188182	1323c3cc585d661aecf65268d2f56344	Maestro	33.9371034427411828	-118.499459888086832
28282	2020-06-01 15:12:37	2020-06-01	Mr. Hermann Schmeler	mr.hermann.schmeler@geemail.com	Long Beach	California	3096817331590482537	e9047125ecc042e675eb378261323191	VISA 16 digit	33.7320779584169372	-118.222095907774943
28283	2020-06-01 15:29:54	2020-06-01	Johanna Leffler	johanna.leffler@geemail.com	San Francisco	California	3158551572538610156	adb3a59bec58fbf46507117303cad32c	JCB 15 digit	37.7769526103185314	-122.395632707714697
28284	2020-06-01 15:33:23	2020-06-01	Adron Cummings	adron.cummings@geemail.com	El Paso	Texas	4934859293722	78ad9d50d7886f7d0174c81fa6b839d8	Voyager	31.8727376052007081	-106.403157004106802
28285	2020-06-01 15:36:15	2020-06-01	Mr. Antwan Rogahn MD	mr.antwan.rogahn.md@warmmail.com	Little Rock	Arkansas	4560830995381995	a73963f5248b09910b8774020820e654	Discover	34.6640039262637529	-92.4042450921483294
28286	2020-06-01 15:48:03	2020-06-01	Ms. Mossie Turcotte	ms.mossie.turcotte@geemail.com	Birmingham	Alabama	3158523667051546574	65b5071bbc9cef281c4ee36d1a88d7c3	VISA 13 digit	33.4483473926108346	-86.782028195658711
28287	2020-06-01 15:52:57	2020-06-01	Phillis Morissette	phillis.morissette@warmmail.com	Baton Rouge	Louisiana	4930092605094251	a1d016ccfe7788558bbf4bf537cb2459	Diners Club / Carte Blanche	30.3710706593681117	-91.0786208089083402
28288	2020-06-01 15:59:57	2020-06-01	Anwar Steuber	anwar.steuber@geemail.com	Louisville	Kentucky	4848169851914	3e8dc839730820e5f059cf6a951b55e1	Diners Club / Carte Blanche	38.1525491909492729	-85.6364878526028264
28289	2020-06-01 16:01:50	2020-06-01	Henriette Stark MD	henriette.stark.md@woohoo.com	San Francisco	California	3022301583227533	448c2df7b68210bc47b3a12af363b5c6	VISA 16 digit	37.7890780574433123	-122.432347185185932
28290	2020-06-01 16:03:04	2020-06-01	Dr. Tamisha Wilderman DVM	dr.tamisha.wilderman.dvm@geemail.com	Indianapolis	Indiana	210085469171773463	854f4519e07f705befc9fab978f99aff	JCB 16 digit	39.7556368801750253	-86.1789038271378729
28291	2020-06-01 16:06:52	2020-06-01	Octa Kris	octa.kris@geemail.com	New York	New York	3158330992441229837	c1aa8a2f7892818ce8d3c8c841bd5c96	Maestro	40.7569157433453952	-73.855540843064702
28292	2020-06-01 16:12:24	2020-06-01	Destiney Wisozk	destiney.wisozk@geemail.com	Philadelphia	Pennsylvania	3096878251895807889	c06382eafefc5d59a3d6dee513bfbe05	American Express	40.0659114882774645	-75.1529654058992946
28293	2020-06-01 16:14:03	2020-06-01	Sussie Dibbert-Herzog	sussie.dibbert.herzog@geemail.com	San Francisco	California	6011260937708065691	baf9f6923256da8254173439f317f726	VISA 16 digit	37.7512163795316766	-122.429854266706485
28294	2020-06-01 16:23:13	2020-06-01	Chelsey Rau	chelsey.rau@geemail.com	Des Moines	Iowa	3337752848356643074	652684b7db74b098c6615ba93f792f44	VISA 13 digit	41.5135280834719538	-93.5678575061306361
28295	2020-06-01 16:25:23	2020-06-01	Esmeralda Bruen	esmeralda.bruen@woohoo.com	Columbus	Ohio	6011757297874189605	e36caf3dea5a8adbc1357b12e9c8bc1d	Diners Club / Carte Blanche	39.8975412872664634	-83.0640613483034116
28296	2020-06-01 16:36:21	2020-06-01	Mrs. Angeline Hessel PhD	mrs.angeline.hessel.phd@geemail.com	Chicago	Illinois	210071139232212472	a2b41c69f0ee7e790357817207b8c22b	JCB 16 digit	41.8722438531298238	-87.7547113032109962
28297	2020-06-01 16:40:35	2020-06-01	Lea Schmidt PhD	lea.schmidt.phd@geemail.com	El Monte	California	180055757471152396	cacff5da78c43890c2f7a013e505b326	Maestro	34.1078882548216669	-118.064100272979957
28298	2020-06-01 16:41:26	2020-06-01	Eulalie Heidenreich	eulalie.heidenreich@woohoo.com	Nashville	Tennessee	4915952049167436	c693ba0f3dd392e775dd11060d075923	Voyager	36.1385304836679211	-86.7651332253031455
28299	2020-06-01 16:49:37	2020-06-01	Joetta Klocko	joetta.klocko@geemail.com	Baltimore	Maryland	6011355717646845842	3135534773cc71ed1583739424770656	JCB 15 digit	39.2243532573804217	-76.539540565434848
28300	2020-06-01 17:30:36	2020-06-01	Rogelio Grant	rogelio.grant@geemail.com	League City	Texas	3088601790988510722	81d33c0a35c9f98df2497041f71a13c3	Discover	29.4835494206216211	-95.1640605915788598
28301	2020-06-01 17:39:57	2020-06-01	Fed Kuhlman	fed.kuhlman@geemail.com	Memphis	Tennessee	180086580366324372	ddb50632940f51339d70eff30afd76c7	Mastercard	35.0297265737850267	-90.0460006920877873
28302	2020-06-01 17:41:37	2020-06-01	Ruffus Powlowski	ruffus.powlowski@warmmail.com	Westminster	Colorado	676204182878902	ddd8e90f9dcb58a5ba68d14279deb620	Discover	39.8961977520331743	-105.07152705776096
28303	2020-06-01 17:48:56	2020-06-01	Alyssa Wolf DDS	alyssa.wolf.dds@geemail.com	Fremont	California	180042643133315793	303fcebf8061abece6fb4b67471f804b	JCB 16 digit	37.4176424760539135	-122.040628749317293
28304	2020-06-01 17:50:22	2020-06-01	Casimer Zemlak	casimer.zemlak@woohoo.com	Seattle	Washington	3040034946937686	807bf0038d1ba32278c747be6a1e9736	Voyager	47.6145974951721698	-122.306637386737009
28305	2020-06-01 17:59:46	2020-06-01	Loring Treutel	loring.treutel@geemail.com	Berkeley	California	869971583300018263	19ddc559224adf36f09a56b850ea34b3	Diners Club / Carte Blanche	37.9051157214157612	-122.28092133673556
28306	2020-06-01 18:22:08	2020-06-01	Erland Harber	erland.harber@geemail.com	Reno	Nevada	3337186606611687088	01c1c3a6755816bffcb630f91b4a26d6	American Express	39.4755605142641812	-119.944809857073807
28307	2020-06-01 18:34:13	2020-06-01	Vester Blanda-Douglas	vester.blanda.douglas@geemail.com	New York	New York	3002617919687342	300f867edcf433adbb52fb694bc1467d	VISA 13 digit	40.6647695562094427	-74.0334473077103468
28308	2020-06-01 18:48:44	2020-06-01	Towanda Schneider	towanda.schneider@geemail.com	Dallas	Texas	4587919162756	aa706746ea6548d915cf8654e8565801	VISA 13 digit	32.8619947883106818	-96.7679326997101299
28309	2020-06-01 18:49:30	2020-06-01	Flem Mitchell-Howell	flem.mitchell.howell@geemail.com	Columbia	South Carolina	4149870502929894	6116b41e935af4dc8edfb17b31d4fee9	American Express	34.0315165491107834	-80.9590252710524965
28310	2020-06-01 18:50:43	2020-06-01	Verle Reichel	verle.reichel@geemail.com	New Orleans	Louisiana	502096375572755	4edc5390c42a03ef916af413668808e7	Maestro	30.0204160977635546	-90.0032346368096796
28311	2020-06-01 18:55:10	2020-06-01	Ayanna Nienow	ayanna.nienow@warmmail.com	Surprise	Arizona	3429313078659541	4006a0391a39e68a7f6b3491f44bba8d	JCB 15 digit	33.5833925895620169	-112.381957480427616
28312	2020-06-01 19:01:47	2020-06-01	Shawanda Bogan	shawanda.bogan@geemail.com	Tallahassee	Florida	3402798747552781	d78b94bebd903ae2cac712be527190bb	Voyager	30.5137756342556337	-84.154904138112073
28313	2020-06-01 19:08:08	2020-06-01	Louisa Marquardt	louisa.marquardt@woohoo.com	Syracuse	New York	4602717294484606	58f3b7a16a765b1e20fc0eeeaca70aac	Discover	43.0151950378287538	-76.0741074074771291
28314	2020-06-01 19:09:49	2020-06-01	Bernhard Hickle	bernhard.hickle@geemail.com	Chesapeake	Virginia	3112480221377447686	3d131073f7a217a01c2cb62d5b2070a8	Mastercard	36.7685270766500381	-76.3226582842256818
28315	2020-06-01 19:25:25	2020-06-01	Mikel Kohler-Dooley	mikel.kohler.dooley@geemail.com	Pomona	California	6011859585371685191	a42f5981c084214f42fdfbcc40d7a200	JCB 16 digit	33.9881102460939459	-117.703844374182069
28316	2020-06-01 19:33:56	2020-06-01	Jolene Lueilwitz DDS	jolene.lueilwitz.dds@geemail.com	Berkeley	California	3057377116241998	d99eab997138b906de1e68ea94f3eff9	Voyager	37.8710733191290387	-122.278516873391013
28317	2020-06-01 19:35:29	2020-06-01	Emmons Predovic	emmons.predovic@warmmail.com	Greensboro	North Carolina	3528771593892008732	8a4e428195f7a9e8f7a4dee59863c7c0	Maestro	36.099985449633003	-79.8552073460053577
28318	2020-06-01 20:00:20	2020-06-01	Lindsay Schuster	lindsay.schuster@geemail.com	League City	Texas	3743888808121625	d83df0768c499fd4f31eeece76e03d8b	VISA 16 digit	29.4793300405539576	-95.065123984961204
28319	2020-06-01 20:06:16	2020-06-01	Eusebio Krajcik	eusebio.krajcik@geemail.com	San Francisco	California	3158242159427042256	b390fa75e40a51d139ef6d9f53f79e3b	VISA 16 digit	37.7684132801342614	-122.417655355787545
28320	2020-06-01 20:12:12	2020-06-01	Altha Bauch	altha.bauch@warmmail.com	Lakeland	Florida	4027508521705443	100889f7190ac254964af77fb553eb6b	Diners Club / Carte Blanche	28.1018072416838258	-81.9393504415057521
28321	2020-06-01 20:18:15	2020-06-01	Darion Rath	darion.rath@geemail.com	Nashville	Tennessee	4391794868374708	9f366637e3f4a51bc4d03290069222c9	Mastercard	36.2546422570135434	-86.8162281553633477
28322	2020-06-01 20:21:03	2020-06-01	Krystin Christiansen	krystin.christiansen@warmmail.com	Kansas City	Missouri	3337119896359292199	6a00a8cf1e8ccbd0f2462c75f0721aa2	Mastercard	39.18664317646288	-94.5960894741341463
28323	2020-06-01 20:25:27	2020-06-01	Christian Kunze	christian.kunze@woohoo.com	Las Vegas	Nevada	3528730973948132902	43ec67a6d3faf03645f1b72a9420dfa5	VISA 16 digit	36.2467431620795253	-115.314058970773957
28324	2020-06-01 20:37:17	2020-06-01	Minta Gibson	minta.gibson@woohoo.com	St. Louis	Missouri	3484381599053678	92a2d4d9da64fe916f5e444b0335b506	VISA 16 digit	38.6442660286247701	-90.3111169627405701
28325	2020-06-01 20:45:01	2020-06-01	Adriane Botsford	adriane.botsford@geemail.com	Los Angeles	California	4306113624119	5ab0481742017264801ea086b2793491	Mastercard	34.0393898994062098	-118.401973711419103
28326	2020-06-01 20:45:07	2020-06-01	Dr. Addie Daugherty PhD	dr.addie.daugherty.phd@geemail.com	Seattle	Washington	54306362221479467	88b282cde925d4a85359372a0c7c41fd	Diners Club / Carte Blanche	47.5542439295835777	-122.361569704014428
28327	2020-06-01 20:52:19	2020-06-01	Miss Ayanna Thompson MD	miss.ayanna.thompson.md@geemail.com	Fort Worth	Texas	869921983237600087	15f5d64629484dca7c72330af9673d6b	Maestro	32.7580381514094796	-97.3647087623186422
28328	2020-06-01 20:54:38	2020-06-01	Dr. Marilee Gulgowski PhD	dr.marilee.gulgowski.phd@geemail.com	San Francisco	California	4821744317792	904a88811a7cc21a39c8295ab6a92d4c	JCB 15 digit	37.7939792534484909	-122.417568582014184
28329	2020-06-01 20:54:56	2020-06-01	Alexander Beatty	alexander.beatty@geemail.com	Rancho Cucamonga	California	4444745664777764	28bb89136a7d0dedc0282f99ec4f55cb	JCB 16 digit	34.1489769133266066	-117.488248628332087
28330	2020-06-01 21:04:19	2020-06-01	Iliana Auer	iliana.auer@geemail.com	Winston–Salem	North Carolina	3717948061769429	46403b6189baa57486b668ff7016f165	Discover	36.0436095458220649	-80.3423340227119525
28331	2020-06-01 21:24:45	2020-06-01	Eunice Weimann	eunice.weimann@geemail.com	San Francisco	California	4271363555189012	35c356b31f49b37694abc8de222513e3	VISA 13 digit	37.75898903563575	-122.450012219209654
28332	2020-06-01 21:25:05	2020-06-01	Andon Jacobi PhD	andon.jacobi.phd@geemail.com	Virginia Beach	Virginia	4961650494856072	6fea108f9b27d8989af4ba17efde51d5	VISA 13 digit	36.8361227930709703	-75.9384453371770718
28333	2020-06-01 21:32:34	2020-06-01	Verona Cummerata-Schiller	verona.cummerata.schiller@geemail.com	Coral Springs	Florida	4483325506218	e07e629be4af9d2e5ff9af3596430508	VISA 13 digit	26.2318200251150877	-80.1754486529279404
28334	2020-06-01 21:32:39	2020-06-01	Mr. Trenton Kiehn PhD	mr.trenton.kiehn.phd@geemail.com	Hollywood	Florida	4385031826017238	644859c1d53575e9e558aac76c980940	VISA 13 digit	25.9734318044446404	-80.1908075453530955
28335	2020-06-01 21:39:12	2020-06-01	Dr. Archie Connelly MD	dr.archie.connelly.md@geemail.com	San Diego	California	869972176895078468	25fa8c74edbfb397ef8a359bc1e30555	VISA 13 digit	32.7458780850816495	-117.109256769847136
28336	2020-06-01 21:53:29	2020-06-01	Elam Fay MD	elam.fay.md@warmmail.com	Greensboro	North Carolina	869944618894528980	cc7b7f816faf3a4a668e977b69fd2f18	VISA 16 digit	36.1120176032301075	-79.768665453929458
28337	2020-06-01 21:56:30	2020-06-01	Rayburn Rodriguez	rayburn.rodriguez@geemail.com	Oklahoma City	Oklahoma	4152350163594166	33d11e4e9cee294dd449e997eff45629	Discover	35.4068811694070718	-97.4200168815802812
28338	2020-06-01 22:19:33	2020-06-01	Ms. Lera Mraz DVM	ms.lera.mraz.dvm@geemail.com	Corpus Christi	Texas	503892289204783	0f4a92c7d6be00d39e5a0112384fd512	Maestro	27.749867317493262	-97.1683617887847078
28339	2020-06-01 22:21:16	2020-06-01	Clementine Kutch DVM	clementine.kutch.dvm@geemail.com	Baltimore	Maryland	3410581445136291	172efeabc1113f367e308406b0b3c76b	VISA 16 digit	39.3810763536486732	-76.6111298722699274
28340	2020-06-01 22:37:48	2020-06-01	Darleen Robel DDS	darleen.robel.dds@geemail.com	Downey	California	3528520004790648979	52d458c79dd00086a370d974a15f8a1f	JCB 15 digit	33.9463243165303012	-118.133950281386817
28341	2020-06-01 22:37:57	2020-06-01	Elam Dibbert-Pouros	elam.dibbert.pouros@woohoo.com	Arvada	Colorado	55423654676775631	837d5e9b31c75f1aad49d72a84ce2574	JCB 16 digit	39.8291324400983768	-105.20625782967285
28342	2020-06-01 22:51:42	2020-06-01	Kadeem Ryan PhD	kadeem.ryan.phd@geemail.com	Virginia Beach	Virginia	3337683147300672956	0e9500ca282051851d44a8c8c3e06f53	JCB 16 digit	36.8321774199325631	-76.1027622688233834
28343	2020-06-01 23:03:57	2020-06-01	Sandie Lockman	sandie.lockman@geemail.com	West Valley City	Utah	4821553792913282	8c6194bd0b11241a2b5fc97814bcd94a	VISA 13 digit	40.7529325649365788	-112.103709612296143
28344	2020-06-01 23:08:59	2020-06-01	Myranda Lang	myranda.lang@geemail.com	New York	New York	4022798724921328	eff4e4eb0e44a1a2cd2a57425e2d2a43	Discover	40.5985897363387025	-74.0349597118690639
28345	2020-06-01 23:12:58	2020-06-01	Dr. Heber Hoeger	dr.heber.hoeger@geemail.com	Naperville	Illinois	3406779906157386	e1288ee0892a2013df8d82c376d85ff6	VISA 13 digit	41.6801058099985156	-88.2583678136467995
28346	2020-06-01 23:17:52	2020-06-01	Ms. Jasmyne Herzog	ms.jasmyne.herzog@geemail.com	El Paso	Texas	180047107532646104	dfaad576aad992c4aea34a29ea9e8d23	VISA 13 digit	31.8851105478886545	-106.418286112042153
28347	2020-06-01 23:21:43	2020-06-01	Sheilah Trantow	sheilah.trantow@geemail.com	Dallas	Texas	869991034302096804	7c725dbf2756b59759d628b0e7501faf	VISA 16 digit	32.8041036299236168	-96.8449057186916349
28348	2020-06-01 23:28:11	2020-06-01	Reinhold Wolf Jr.	reinhold.wolf.jr.@geemail.com	Santa Ana	California	54933679211091593	cf3927f7ae626b8b0c566675535c9c61	Maestro	33.7660880203928784	-117.837344803467388
28349	2020-06-01 23:53:36	2020-06-01	Stacia Walsh	stacia.walsh@woohoo.com	Bakersfield	California	3337951446803494586	00398fbf61d1be10f985e5a4dd3fec32	Maestro	35.3438273955311573	-118.959325610826909
28350	2020-06-02 00:01:47	2020-06-02	Dr. Zillah Pagac DVM	dr.zillah.pagac.dvm@geemail.com	San Antonio	Texas	3010088018768981	66dde9e2d891e069f26f86c950da0577	JCB 15 digit	29.5154083279032271	-98.5563612199224508
28351	2020-06-02 00:12:09	2020-06-02	Tanesha Gibson	tanesha.gibson@geemail.com	Los Angeles	California	869969279501111536	1cc607113a3b7c3e6fa13f26fe6375ae	JCB 15 digit	33.9297213411290173	-118.477328967674822
28352	2020-06-02 00:32:40	2020-06-02	Miss Luana Gutmann DVM	miss.luana.gutmann.dvm@geemail.com	Santa Clarita	California	3096999563785394982	bdaf7da699ae61297e77d219d0bc73e3	VISA 13 digit	34.4504425258580582	-118.533626295775917
28353	2020-06-02 00:43:43	2020-06-02	Minoru Daugherty-Berge	minoru.daugherty.berge@geemail.com	Columbus	Ohio	3158453155755191644	7698725069e87b2cf428152b83e0d5c2	VISA 13 digit	39.9475958881944422	-83.023138837353514
28354	2020-06-02 00:51:10	2020-06-02	Dollie O'Conner	dollie.o'conner@geemail.com	Santa Clara	California	210042751301982169	5c0b0a68279e052d8a27722cc816cdb4	VISA 13 digit	37.3047205506175814	-121.898295628605041
28355	2020-06-02 01:01:40	2020-06-02	Greggory Denesik DVM	greggory.denesik.dvm@warmmail.com	Los Angeles	California	55272982731970935	79075c2deb6d17fc755e08006045bfc8	JCB 16 digit	33.9525555204000327	-118.4976902072776
28356	2020-06-02 01:13:39	2020-06-02	Chauncey Schimmel	chauncey.schimmel@geemail.com	San Diego	California	4016808908707	1cf5e8dd6eb2ea46bf64455bb06af590	American Express	32.7932195788782082	-117.203731769127771
28357	2020-06-02 01:17:23	2020-06-02	Ambers Stanton	ambers.stanton@geemail.com	Oakland	California	3158509734775481955	06ca9594095cd668f1aa6d80ddda7e8b	Discover	37.8191550623518324	-122.294264554906093
28358	2020-06-02 01:24:51	2020-06-02	Lovisa Rath	lovisa.rath@geemail.com	Garden Grove	California	3088930483158208648	e9aea5a14beb71e8279c8b6300c0ce9b	VISA 16 digit	33.6807372063223269	-117.94976280150189
28359	2020-06-02 01:40:02	2020-06-02	Maddox Kulas	maddox.kulas@geemail.com	New York	New York	3337284332009465687	3232b7706e95f48444f0aad2c97bef81	VISA 13 digit	40.638334296386688	-73.9021128971490953
28360	2020-06-02 01:41:00	2020-06-02	Effie Huels	effie.huels@geemail.com	Fresno	California	3088273448527360136	8beced80bd9f612a91f8a1e24374680e	JCB 15 digit	36.820265956908834	-119.854103085549184
28361	2020-06-02 01:47:35	2020-06-02	Karolyn Kuhn	karolyn.kuhn@geemail.com	San Francisco	California	630461910245689	9877f4163f7a26901a8755918607d211	VISA 13 digit	37.7962947210569595	-122.470099055226996
28362	2020-06-02 01:51:45	2020-06-02	Dr. Montel Bernhard II	dr.montel.bernhard.ii@warmmail.com	Garland	Texas	180035059197195022	6da99c70a56af365e9f2c8da194ab049	JCB 16 digit	32.8217559595361337	-96.5674366505045469
28363	2020-06-02 01:52:40	2020-06-02	Ras Krajcik	ras.krajcik@geemail.com	Irving	Texas	6011555800593978374	8e283ed648c3d377c66957e7300e6fe1	JCB 16 digit	32.9369929756455164	-96.9008580912649649
28364	2020-06-02 01:59:45	2020-06-02	Ella Braun	ella.braun@geemail.com	Oakland	California	6011537888203028220	aceaaf3cec0a5557ef01027a1e828541	VISA 13 digit	37.8089613560474476	-122.308237360434305
28365	2020-06-02 02:03:58	2020-06-02	Corey Prosacco	corey.prosacco@woohoo.com	New York	New York	3528470429203400728	5b162499ccaa57dd6bf577068b3204dd	JCB 15 digit	40.7233821520339703	-74.0236288723897218
28366	2020-06-02 02:17:37	2020-06-02	Dr. Cari Predovic	dr.cari.predovic@woohoo.com	Augusta	Georgia	3088404247663233020	8353711930ef761266777a1120af79a6	VISA 16 digit	33.2842873143702747	-82.1378551353063528
28367	2020-06-02 02:27:52	2020-06-02	Dr. Evelyn Langosh	dr.evelyn.langosh@geemail.com	San Francisco	California	4528791305115427	ec0e37b5e370c526b39e3d3023faee53	Discover	37.7561117947243261	-122.416956352127286
28368	2020-06-02 02:29:09	2020-06-02	Joslyn Prohaska-Sawayn	joslyn.prohaska.sawayn@geemail.com	North Charleston	South Carolina	4527708146412	488f65d7a460c8bfce7961fab8594d33	Discover	32.9317326511882271	-80.0226805419754186
28369	2020-06-02 02:36:09	2020-06-02	Ms. Renata Terry DVM	ms.renata.terry.dvm@woohoo.com	Athens	Georgia	3088728452602534152	60c457ff000b0e1886ff08baf2ef7f63	Diners Club / Carte Blanche	33.9095952851422098	-83.392197529983136
28370	2020-06-02 02:41:39	2020-06-02	Magen Schinner DDS	magen.schinner.dds@geemail.com	St. Petersburg	Florida	3008229918466738	13b55ce0eb7209708cd9b5f4ee99afb8	Discover	27.7684456365071242	-82.6061569748338229
28371	2020-06-02 02:42:06	2020-06-02	Payton Barton DVM	payton.barton.dvm@woohoo.com	Wichita	Kansas	3454072273966089	12f9be735cb107a4ade9934b1c7bc3d1	Diners Club / Carte Blanche	37.7159956732641888	-97.2472385236263221
28372	2020-06-02 02:43:08	2020-06-02	Laisha Gerhold-Oberbrunner	laisha.gerhold.oberbrunner@warmmail.com	Philadelphia	Pennsylvania	3495510755585084	f9a6d56af0238ba1a4f965b148d72e3c	Mastercard	40.0791204523719813	-75.2151334773182896
28373	2020-06-02 02:55:36	2020-06-02	Socorro Kuhn-Lubowitz	socorro.kuhn.lubowitz@warmmail.com	Detroit	Michigan	210065365485364193	cefe0ef9dcac38ed5d54d3cc57e27fc0	VISA 13 digit	42.3719233678113696	-83.003102061630031
28374	2020-06-02 03:10:01	2020-06-02	Stewart Pouros	stewart.pouros@warmmail.com	Meridian	Idaho	869986878043832282	bf5647c04894299caf9c0fc696a4d951	Diners Club / Carte Blanche	43.6044874884195579	-116.350727337034044
28375	2020-06-02 03:22:06	2020-06-02	Harman Stoltenberg	harman.stoltenberg@woohoo.com	Philadelphia	Pennsylvania	210025931173265049	c6fd454e5fb550ac938f7107edf93575	American Express	40.0332848698325421	-75.0574001161746764
28376	2020-06-02 03:32:44	2020-06-02	Hermann Breitenberg	hermann.breitenberg@geemail.com	Woodbridge	New Jersey	4813290194958231	0141d7e897b56c833597cab3a36ec23b	JCB 16 digit	40.6345423190079629	-74.2797099388528608
28377	2020-06-02 03:47:17	2020-06-02	Joy Emard III	joy.emard.iii@geemail.com	Berkeley	California	53143888181087632	fef20bd05f7a89514ede253d03f0c84a	Mastercard	37.8385795199645756	-122.279270111732075
28378	2020-06-02 03:48:52	2020-06-02	Augustina Thompson	augustina.thompson@warmmail.com	Downey	California	060492023383810	7e16a765911bcb0ad7fb78fed43ff109	JCB 16 digit	33.8690848349843208	-118.161599246749276
28379	2020-06-02 03:51:52	2020-06-02	Brinda Effertz	brinda.effertz@geemail.com	Phoenix	Arizona	3013091858498526	bb6bb8a7d554db6bcf80ce49b407fcc1	Discover	33.5133091074813194	-111.993928359162439
28380	2020-06-02 04:14:32	2020-06-02	Kathyrn Konopelski	kathyrn.konopelski@woohoo.com	Downey	California	6011138221243207138	3a4985fb1251f349cb136937b7f55dc5	JCB 16 digit	33.8800928979430367	-118.086476165532687
28381	2020-06-02 04:27:26	2020-06-02	Rashaad Considine-Torphy	rashaad.considine.torphy@geemail.com	Gresham	Oregon	3158798422063800397	43dad0ccb1ebf61e1dd37b42d42db3f6	VISA 13 digit	45.5141044240400205	-122.383954274867094
28382	2020-06-02 04:42:28	2020-06-02	Mr. Landin Daugherty MD	mr.landin.daugherty.md@woohoo.com	New York	New York	4292557842961746	c79e2bc71db3c107e14e64c147e45bd6	Diners Club / Carte Blanche	40.7493367007225729	-74.0213441545505049
28383	2020-06-02 04:45:20	2020-06-02	Acie Jacobs IV	acie.jacobs.iv@geemail.com	Indianapolis	Indiana	180034187143212798	4621d886841ccb66b8b813208a1c65df	Voyager	39.8062541744213547	-86.1535195604167825
28384	2020-06-02 04:49:09	2020-06-02	Miss Theresa Bruen	miss.theresa.bruen@geemail.com	Independence	Missouri	3337480603954337531	020bf5910b09cd160d29717f81095d3e	American Express	39.0543435541931601	-94.2850521727748117
28385	2020-06-02 04:56:46	2020-06-02	Stanford Smith	stanford.smith@geemail.com	St. Louis	Missouri	3112299619692731638	7197a98b9f772ba73def3b11d4531724	VISA 13 digit	38.6584832733653485	-90.3131893374960981
28386	2020-06-02 05:05:42	2020-06-02	Mr. Abdullah Mertz	mr.abdullah.mertz@geemail.com	Hayward	California	4675040091283580	2227380a6651bbe5b7be759c9ea3ada8	VISA 13 digit	37.5462142494495978	-122.201671906493232
28387	2020-06-02 05:10:46	2020-06-02	Omie Waters	omie.waters@geemail.com	Fort Worth	Texas	4240511594159325	44f2e06c45645bb19b5051db1ea327db	JCB 15 digit	32.7730115643758353	-97.2737511599257516
28388	2020-06-02 05:24:01	2020-06-02	Alex Koepp	alex.koepp@geemail.com	San Francisco	California	210069390446073762	ad347bf2a61c6c357afb6cf2a84d7e60	Mastercard	37.7862705826662904	-122.431332002097946
28389	2020-06-02 05:28:14	2020-06-02	Hans O'Kon	hans.o'kon@geemail.com	New York	New York	561270430625502	066f5d3ba85966d2f612f68941becebc	Mastercard	40.6950427459776378	-73.9816341840092093
28390	2020-06-02 05:32:46	2020-06-02	Guido Kunde PhD	guido.kunde.phd@geemail.com	Augusta	Georgia	3016303270699467	beac89b6b1badcacf805cde311784f76	JCB 16 digit	33.4636961966957855	-82.0607690407723283
28391	2020-06-02 05:49:09	2020-06-02	Ednah Ward	ednah.ward@geemail.com	Carrollton	Texas	55976934239514920	ca24f23cde58814b7cac782026339b11	Voyager	32.9885111252233401	-96.9424862697117078
28392	2020-06-02 06:06:19	2020-06-02	Marin Hartmann	marin.hartmann@geemail.com	Indianapolis	Indiana	210080424717234087	939c1e8a7b2e57be1da0f24d7a4aeb47	Maestro	39.863308252394944	-86.2117933595288548
28393	2020-06-02 06:32:30	2020-06-02	Mr. Reubin Veum Jr.	mr.reubin.veum.jr.@geemail.com	San Francisco	California	3015269057648889	c2a898e93196d3106f42a1c2d788272c	Voyager	37.7776549304404128	-122.454061751638378
28394	2020-06-02 06:50:18	2020-06-02	Kinte Kunde	kinte.kunde@geemail.com	Seattle	Washington	639028289706617	0a7ad0a97f626bc6f18b51766bed119a	JCB 16 digit	47.568065657878293	-122.347213307480885
28395	2020-06-02 06:51:32	2020-06-02	Delle Zulauf	delle.zulauf@warmmail.com	Ann Arbor	Michigan	676163512599679	266cfb0fa52e961c29ad08dbedf51629	Voyager	42.2457850909851516	-83.7534436159409665
28396	2020-06-02 06:56:26	2020-06-02	Abbie Schultz	abbie.schultz@geemail.com	Los Angeles	California	210040361173759737	0c002fe81e2abe925133ea630e9e53fc	JCB 16 digit	34.0915273515839132	-118.447321502537648
28397	2020-06-02 06:59:42	2020-06-02	Mrs. Inger Murphy DVM	mrs.inger.murphy.dvm@geemail.com	League City	Texas	3019482118735613	c504aedd78f658f9722d238f0523a19c	JCB 16 digit	29.487092546040568	-95.1544347776550836
28398	2020-06-02 07:10:04	2020-06-02	India Koss	india.koss@geemail.com	Augusta	Georgia	3760609857420751	d176eb0301d801f5a84a7ad87bb544d8	Discover	33.2832811087574783	-82.0071301878258652
28399	2020-06-02 07:14:55	2020-06-02	Kacie Hane	kacie.hane@warmmail.com	Jacksonville	Florida	3112851965748320771	83b0a2e7f6082d7bac05b1b2254a4a2f	Voyager	30.3175357690133147	-81.6167221279893198
28400	2020-06-02 07:15:42	2020-06-02	Geoff Casper	geoff.casper@geemail.com	Jacksonville	Florida	4861023611224692	59f7f92212247a5037f17f2dc4508424	VISA 13 digit	30.2560091342363506	-81.6050730913024438
28401	2020-06-02 07:31:11	2020-06-02	Rosina Abernathy-Wyman	rosina.abernathy.wyman@geemail.com	San Francisco	California	3445283602966938	286ebd1a9a01e8d64290903496ff7834	VISA 13 digit	37.765289539749439	-122.406443461125221
28402	2020-06-02 07:40:31	2020-06-02	Miss Aubrey Torphy DDS	miss.aubrey.torphy.dds@geemail.com	Cleveland	Ohio	4424225426040	be31d455320e401d0ee43b1e3681452a	JCB 16 digit	41.523836883747947	-81.6725562988087574
28403	2020-06-02 07:41:10	2020-06-02	Maliyah King	maliyah.king@geemail.com	Omaha	Nebraska	561243072345689	a2e0b35268c1882c0e6029e4221cfa08	Diners Club / Carte Blanche	41.2879278629232189	-95.9807332047376889
28404	2020-06-02 08:17:18	2020-06-02	Dr. Doc Simonis MD	dr.doc.simonis.md@geemail.com	Nashville	Tennessee	4545796786052808	2bb2022b57dfdd20c2778596924bca0e	American Express	36.0975448162417862	-86.8407926349341892
28405	2020-06-02 08:22:10	2020-06-02	Towanda Reynolds	towanda.reynolds@geemail.com	Pittsburgh	Pennsylvania	3044639769316184	e5b1cb08974f1279c26ab97fd964236b	JCB 15 digit	40.4765461701389384	-79.9673734205480713
28406	2020-06-02 08:27:26	2020-06-02	Margrett Rosenbaum	margrett.rosenbaum@geemail.com	San Francisco	California	4530568026196183	3ff9501b321ca2cd6396ac01dadabff5	Discover	37.7744704853841071	-122.445003263979117
28407	2020-06-02 08:31:22	2020-06-02	Dr. Ernest Ritchie	dr.ernest.ritchie@geemail.com	San Francisco	California	3096790738802597087	8a0e1ef4311436709634f5ecd944fb71	VISA 13 digit	37.7708410048760044	-122.41805574776599
28408	2020-06-02 08:52:09	2020-06-02	Bill Kunze	bill.kunze@geemail.com	Albuquerque	New Mexico	3528260100712630378	8feb9c8f61efcba08d717518135af655	Diners Club / Carte Blanche	35.1042016198992783	-106.548637958204012
28409	2020-06-02 09:02:10	2020-06-02	Humphrey Beahan	humphrey.beahan@geemail.com	Riverside	California	676163653593101	1aac6cdfe2fbd9806283274c689549d1	JCB 16 digit	33.9438327570393668	-117.399368190995219
28410	2020-06-02 09:05:57	2020-06-02	Littie Stark-Feil	littie.stark.feil@geemail.com	Oakland	California	3088680940060362591	ca934779e1ca4ee1be73955b4c4afb69	Discover	37.8135746717567471	-122.256321431412914
28411	2020-06-02 09:06:12	2020-06-02	Dr. Cristopher Lemke I	dr.cristopher.lemke.i@geemail.com	San Antonio	Texas	3031902626017004	7c14dc0cb47eb3ba99ea58b9dfeeb5c2	Mastercard	29.5292824664223943	-98.5501477546825981
28412	2020-06-02 09:06:31	2020-06-02	Ebert Romaguera-Blick	ebert.romaguera.blick@geemail.com	Springfield	Missouri	589396804170262	be162514af14cdb310632509d750e085	VISA 13 digit	37.1676607468824827	-93.2397126059804151
28413	2020-06-02 09:07:56	2020-06-02	Stanley Gulgowski	stanley.gulgowski@geemail.com	Fresno	California	3439013221424482	4129c38f3ccd7c7a9a50d0d17a792aea	Diners Club / Carte Blanche	36.8103863801680475	-119.768863493494322
28414	2020-06-02 09:09:24	2020-06-02	Jenni Conroy-Shields	jenni.conroy.shields@geemail.com	New York	New York	4877309476555	1095c8614d04b452d6a1a47e23518bed	Mastercard	40.6171274760030201	-73.8500169454503776
28415	2020-06-02 09:24:24	2020-06-02	Zadie Lowe	zadie.lowe@geemail.com	Escondido	California	51046410518528812	5ad2c68357dbd12b5fc1ea852c1fc03a	Diners Club / Carte Blanche	33.1414248964510847	-117.053889577394344
28416	2020-06-02 09:28:06	2020-06-02	Cary Altenwerth-Gutmann	cary.altenwerth.gutmann@geemail.com	Fayetteville	North Carolina	4476140211411011	1b7fa44ef6388a2955bda62ff636c1d7	Discover	35.0803100841373166	-79.0400862354449885
28417	2020-06-02 09:34:27	2020-06-02	Lenore Ritchie-Kris	lenore.ritchie.kris@geemail.com	San Francisco	California	53748084492317574	6cd610a2f1e5f0375a46ed8e7558332c	JCB 16 digit	37.7673826301650948	-122.431042302532163
28418	2020-06-02 09:38:43	2020-06-02	Halie Wiza	halie.wiza@geemail.com	San Francisco	California	3708459571578806	5cea527ee25d3ff69b6bdb8cb2c8ebc6	VISA 13 digit	37.7883794368082633	-122.427420921055514
28419	2020-06-02 09:45:58	2020-06-02	Mrs. Darcy Lueilwitz PhD	mrs.darcy.lueilwitz.phd@geemail.com	San Francisco	California	3112075174485568599	c76542e1dd349834184192fcf7936402	Discover	37.7779227727995703	-122.430846445410694
28420	2020-06-02 09:48:42	2020-06-02	Theodis Legros	theodis.legros@geemail.com	New York	New York	3027219135626249	dd53a0740f1e7b53c7aba95596d17188	JCB 16 digit	40.6995855150036476	-73.9473866808123859
28421	2020-06-02 09:52:46	2020-06-02	Miss Kacy Heller	miss.kacy.heller@geemail.com	Overland Park	Kansas	4412998804905013	b9bd1146a458f88fc09c2a942852d0ce	American Express	38.8096091308966322	-94.6429764291312523
28422	2020-06-02 10:05:01	2020-06-02	Edw Kutch	edw.kutch@geemail.com	Charlotte	North Carolina	869953366907004320	b387c47851550754e5877275af737d52	American Express	35.1192675568416703	-80.7517059536594957
28423	2020-06-02 10:06:00	2020-06-02	Dr. Rohan Bruen	dr.rohan.bruen@geemail.com	Austin	Texas	3337180866517234049	cd922a275a9d5ac2f9f09bf1c6e8eb3d	American Express	30.3986956935036901	-97.7640103721298317
28424	2020-06-02 10:06:13	2020-06-02	Dr. Raphael Howell I	dr.raphael.howell.i@woohoo.com	San Francisco	California	210083947348645195	c589396fa3b27dd5afb593f5b862a693	Mastercard	37.7730785022819973	-122.441142714704583
28425	2020-06-02 10:15:58	2020-06-02	Jewel Hagenes DVM	jewel.hagenes.dvm@geemail.com	Davie	Florida	3438141840758278	74fa855b2be1fd4d64d94c20adf1e2f4	JCB 16 digit	26.008385673703998	-80.2176812392566347
28426	2020-06-02 10:37:04	2020-06-02	Evonne Toy	evonne.toy@geemail.com	Honolulu	Hawaii	4082763783214301	24496fb16b335edf2f33851ddcd4574a	JCB 16 digit	21.2887861673004934	-157.780299522143224
28427	2020-06-02 10:46:14	2020-06-02	Chance Farrell	chance.farrell@geemail.com	Baltimore	Maryland	52597163971300186	193ce7fbffca7778553bd0919b8a66e5	JCB 16 digit	39.2599666909780325	-76.5885484175775275
28428	2020-06-02 10:48:38	2020-06-02	Vernon Goyette	vernon.goyette@woohoo.com	Cincinnati	Ohio	4111738964043	62cfa810dc188db0225eb9b22ae80e1c	VISA 16 digit	39.0434739378511892	-84.5197748801477218
28429	2020-06-02 11:00:58	2020-06-02	Lemma Lehner	lemma.lehner@warmmail.com	Lakeland	Florida	3050968870878228	5b2975b3e0b8ef861ebeb9eb2645ad24	VISA 16 digit	28.066123082937672	-82.043159382126845
28430	2020-06-02 11:02:46	2020-06-02	Allene Schultz	allene.schultz@geemail.com	Oceanside	California	3528270739895492383	d10cb12164e45a8120c5a0bcdc55f4a1	Voyager	33.1379526676032654	-117.291617647706346
28431	2020-06-02 11:12:37	2020-06-02	Luverne Dare DVM	luverne.dare.dvm@geemail.com	Berkeley	California	3158161826617855492	0b6cd0c3bcd0db6105251ee37a3fb1ec	Mastercard	37.8916977738830951	-122.24584191322991
28432	2020-06-02 11:16:00	2020-06-02	Mrs. Rory Champlin	mrs.rory.champlin@geemail.com	Oklahoma City	Oklahoma	6011941404401127812	39c946ddab3fd70ce6455ba3de2f32d9	JCB 16 digit	35.381286534425243	-97.5555141373898778
28433	2020-06-02 11:26:33	2020-06-02	Lyndon Welch	lyndon.welch@geemail.com	Long Beach	California	4443000275972581	4a3fc190ce5f96a28994f67c8e9d4b55	Voyager	33.8001798727370755	-118.231028708645326
28434	2020-06-02 11:30:50	2020-06-02	Mr. Geno Becker Sr.	mr.geno.becker.sr.@geemail.com	Cleveland	Ohio	3337966022024199271	142541e2e8bdfbe89d1fd70f4e14abc9	American Express	41.4817195591833396	-81.642830250436063
28435	2020-06-02 11:34:58	2020-06-02	Ms. Shirley Kirlin DDS	ms.shirley.kirlin.dds@geemail.com	Cleveland	Ohio	3337385901072470473	aa3fd2dcc67b7c00065ebad54a89ba39	JCB 15 digit	41.4766834102421953	-81.649651655392347
28436	2020-06-02 11:37:08	2020-06-02	Meggan Strosin	meggan.strosin@geemail.com	Richardson	Texas	3158854837820131821	348ee20a460566cad4ec10a74de90217	VISA 16 digit	32.9026935681469723	-96.7429285818938212
28437	2020-06-02 11:49:45	2020-06-02	Welton Welch	welton.welch@geemail.com	Long Beach	California	3740597583213647	e4411d3e5db2656d040d26369fc2dd57	Mastercard	33.8169751126140312	-118.138006168480217
28438	2020-06-02 11:50:12	2020-06-02	Armani Walter	armani.walter@geemail.com	Lincoln	Nebraska	3401175121005135	74ba25cb732bec34318572aadea82e98	JCB 15 digit	40.8583385191876403	-96.7642081434998715
28439	2020-06-02 11:55:56	2020-06-02	Mrs. Shawnee Schmidt	mrs.shawnee.schmidt@geemail.com	Sacramento	California	3051075124069098	4ff156a2dfb891a2b114904082d4af02	JCB 16 digit	38.6068399712242183	-121.541121516215057
28440	2020-06-02 12:06:11	2020-06-02	Miss Marva Lindgren	miss.marva.lindgren@geemail.com	Oakland	California	4929756384111	5d55a67ae2309e198156bb4b213671fd	JCB 16 digit	37.8146857102175389	-122.278439495062429
28441	2020-06-02 12:09:38	2020-06-02	Cambria O'Keefe	cambria.o'keefe@geemail.com	San Jose	California	6011438274595197560	6e75f3a45f424a220cf734818163d0fd	VISA 16 digit	37.2415702068533747	-121.731499854031583
28442	2020-06-02 12:16:51	2020-06-02	Cori Blick	cori.blick@woohoo.com	San Francisco	California	3337303828285037774	d1d9d28c1901bc328a086eac1bc60e1d	JCB 15 digit	37.7925346924713708	-122.456923437396753
28443	2020-06-02 12:20:36	2020-06-02	Corie Mante DVM	corie.mante.dvm@geemail.com	San Francisco	California	676235901174538	4bab9f160c271acb64d71f72f87663c2	JCB 15 digit	37.7857567434293458	-122.42741865021614
28444	2020-06-02 12:28:53	2020-06-02	Jan Boyle	jan.boyle@woohoo.com	Jacksonville	Florida	4121786468516	94b0b908f086acd919b488d58761efcd	Maestro	30.2944629234313965	-81.5988321511618864
28445	2020-06-02 12:30:07	2020-06-02	Ardith Hirthe	ardith.hirthe@geemail.com	Saint Paul	Minnesota	4880919005533852	80d8177d00c64a75c2d28aa9e1a63a53	VISA 16 digit	44.883804837468638	-93.0468834082394807
28446	2020-06-02 12:38:56	2020-06-02	Dr. Sydnie Fadel MD	dr.sydnie.fadel.md@geemail.com	Berkeley	California	4863575117172	d2b98f999eef76dbd5a376a45f47c759	American Express	37.8675617260620569	-122.245007618934252
28447	2020-06-02 12:51:35	2020-06-02	Jayleen Simonis	jayleen.simonis@woohoo.com	Los Angeles	California	3112171219752631241	0eeb66fa2f0090e4f599efad010c4cd5	Diners Club / Carte Blanche	34.0898914388246794	-118.379451377316556
28448	2020-06-02 12:57:50	2020-06-02	Lawton Rohan	lawton.rohan@woohoo.com	Lexington	Kentucky	3158817270495687255	c657c8a1b4fb0ff6606fb4a5c8f162f5	Discover	37.9880899859469423	-84.361027017551649
28449	2020-06-02 13:00:07	2020-06-02	Arden Ondricka-Gulgowski	arden.ondricka.gulgowski@geemail.com	Vancouver	Washington	3112381122901021080	193850ca7ac6b351b4bb04be9f8b795a	Voyager	45.6740476388555052	-122.600356415432685
28450	2020-06-02 13:04:14	2020-06-02	Lessie Koch	lessie.koch@warmmail.com	Jurupa Valley	California	3028086131832678	0f6479da813090bfb102ca450a578804	VISA 16 digit	33.9633423138339055	-117.539347815608977
28451	2020-06-02 13:05:32	2020-06-02	Max Huel	max.huel@geemail.com	Huntsville	Alabama	4455993225446	214b2c3f5fefa3cad8b9e4e3d79c362b	VISA 13 digit	34.6105590173285407	-86.6020542856790172
28452	2020-06-02 13:18:52	2020-06-02	Dr. Troy Hand	dr.troy.hand@geemail.com	San Antonio	Texas	639047233478727	9cc01b1c4b4bc0b44390722cec88a39f	JCB 15 digit	29.5723158973805624	-98.4989981791306235
28453	2020-06-02 13:24:17	2020-06-02	Glinda Rodriguez	glinda.rodriguez@woohoo.com	Baltimore	Maryland	51338498732617542	8ae07d91c2c561dcd5c806cc9a2dee36	Maestro	39.292523206537588	-76.5270741776581929
28454	2020-06-02 13:26:29	2020-06-02	Mr. Harrie Kovacek Sr.	mr.harrie.kovacek.sr.@geemail.com	Grand Rapids	Michigan	060468045633556	a28f344cb6a5b5188dcc6b5b0312d149	JCB 15 digit	42.9704269808985302	-85.6787364969629834
28455	2020-06-02 13:27:12	2020-06-02	Ozella West	ozella.west@woohoo.com	Berkeley	California	180082180769322422	1b6b36ac5ebd446a958397a359dac1a7	JCB 15 digit	37.8966891153269145	-122.29575865180162
28456	2020-06-02 13:42:33	2020-06-02	Bailey Reynolds	bailey.reynolds@geemail.com	San Francisco	California	52144942528163520	5bad283e4d47d02fdd980f81575641c4	VISA 16 digit	37.7674983658837817	-122.455163730528213
28457	2020-06-02 13:50:04	2020-06-02	Mr. Trenton Gutmann	mr.trenton.gutmann@geemail.com	Roseville	California	3015028235359102	9b18be9d04d7a672139f43499ff017aa	Voyager	38.8417140656206712	-121.259995153475174
28458	2020-06-02 14:10:44	2020-06-02	Elfreda Weissnat	elfreda.weissnat@geemail.com	Mesquite	Texas	4907100920890508	40a187e2adfe335f0d02f5e7cffd2196	VISA 16 digit	32.7190441478319514	-96.5916138441499328
28459	2020-06-02 14:23:03	2020-06-02	Darrin Watsica	darrin.watsica@geemail.com	Riverside	California	3088422058390916615	e3895e3ad811c1d115ec982f58732795	Diners Club / Carte Blanche	33.8849923707026974	-117.48190666301808
28460	2020-06-02 14:25:25	2020-06-02	Natalee Goyette	natalee.goyette@warmmail.com	Birmingham	Alabama	869935227066123983	c902337aac6bb19d95da9d907896816d	Mastercard	33.6091385746166083	-86.7482023572325716
28461	2020-06-02 14:35:34	2020-06-02	Terese Bradtke	terese.bradtke@woohoo.com	Columbus	Ohio	869936576456289880	b07f0a2e42279aa0e6b2bc86c765c1c4	Maestro	40.0266942729752486	-82.9004340104993531
28462	2020-06-02 15:04:52	2020-06-02	Mima Anderson	mima.anderson@geemail.com	Oklahoma City	Oklahoma	3112921757659939988	2e04371e73ae53c2b0c83eea82f612b0	Diners Club / Carte Blanche	35.3932461182031801	-97.443388498983154
28463	2020-06-02 15:12:03	2020-06-02	Lanette Miller	lanette.miller@geemail.com	Boston	Massachusetts	4370811525432	c73eb1e2e5bbcc9ecfce632d9682e0a7	VISA 16 digit	42.2990513272751159	-71.0379714046556501
28464	2020-06-02 15:12:42	2020-06-02	Orelia Koss	orelia.koss@geemail.com	Fairfield	California	4934401419820262	3642ff465710c56ac4c1f59834b6c628	Mastercard	38.2468725138001204	-122.105803210102394
28465	2020-06-02 15:14:22	2020-06-02	Jeraldine Keeling	jeraldine.keeling@geemail.com	Ventura	California	4402895823308	55af539b9c1544382f520c9d96e846a4	Voyager	34.1687410534519742	-119.284870586554334
28466	2020-06-02 15:30:45	2020-06-02	Aurelio Wyman	aurelio.wyman@geemail.com	Madison	Wisconsin	869995911189137593	60f8af034f2021e414241a6ab4350af4	Voyager	43.0012419959504157	-89.5178041225183847
28467	2020-06-02 15:35:46	2020-06-02	Rueben Wisoky	rueben.wisoky@geemail.com	Norfolk	Virginia	3096222173975624294	be5eaff6791dfe0c08398979f90076c0	VISA 16 digit	36.9946284672729675	-76.1996884016323861
28468	2020-06-02 15:41:10	2020-06-02	Rella Davis MD	rella.davis.md@woohoo.com	Salem	Oregon	4265384676618893	e4df02edd60bd672624237a2c3ffef06	VISA 16 digit	44.9317400859937024	-123.076170079053199
28469	2020-06-02 16:08:32	2020-06-02	Jordon Haley	jordon.haley@woohoo.com	New York	New York	210035062723472600	e681fdcc195456e0747910cfd6a8d517	JCB 15 digit	40.6147104073539396	-73.9094971180789173
28470	2020-06-02 16:18:07	2020-06-02	Mike Stroman	mike.stroman@geemail.com	Jackson	Mississippi	4002874214865	c016fa2667110dda4b2847feb4fef44c	JCB 15 digit	32.3092139211662115	-90.168892848628758
28471	2020-06-02 16:22:45	2020-06-02	Augustina Halvorson-Cole	augustina.halvorson.cole@geemail.com	Memphis	Tennessee	3112533001951152630	12ae5dac0104e4b1a1107b80a674d8c4	Voyager	35.0975343000210813	-89.9900244409009815
28472	2020-06-02 16:29:21	2020-06-02	Glennis Hermann	glennis.hermann@woohoo.com	Syracuse	New York	869911859650527548	52e7f30cf96dd8bba88ec525bb24e46f	American Express	42.9566479871366127	-76.2292407893821604
28473	2020-06-02 16:45:08	2020-06-02	Serina Hudson	serina.hudson@warmmail.com	Phoenix	Arizona	869900715985252991	48e3b7ff071b325b33df4d926e3ff5ff	Voyager	33.4924121052891053	-112.034633343520028
28474	2020-06-02 16:50:42	2020-06-02	Lavenia Daniel	lavenia.daniel@geemail.com	Miami	Florida	3088959806624052289	b93f600f287950dbd10a63ff0e62c07f	JCB 15 digit	25.7151055635556602	-80.1854178121652552
28475	2020-06-02 16:51:49	2020-06-02	Connor Denesik-Homenick	connor.denesik.homenick@geemail.com	San Francisco	California	3029131487467148	6f3cdb9f4e3b67754da4bca5e28e9b11	VISA 16 digit	37.7813619881419456	-122.413318877219297
28476	2020-06-02 16:54:55	2020-06-02	Louis Wisoky	louis.wisoky@geemail.com	Columbus	Ohio	51985722002069134	5e5c199f4bd1d8a07ad309824af359c5	Discover	39.9548943135466388	-82.9875821889147289
28477	2020-06-02 17:00:39	2020-06-02	Dr. Leander Bogisich	dr.leander.bogisich@geemail.com	Clovis	California	210048889291824738	f7e8624b7b32361cdfb47d38fb4f8540	JCB 16 digit	36.7739214236725118	-119.743960080861669
28478	2020-06-02 17:13:52	2020-06-02	Linwood Stracke	linwood.stracke@geemail.com	Washington	District of Columbia	675985918774770	501eaed76af737f0de9c7bf7d18d34c3	VISA 16 digit	38.8664117126990121	-77.1014661163769688
28479	2020-06-02 17:38:04	2020-06-02	Dr. Derald Upton MD	dr.derald.upton.md@geemail.com	Philadelphia	Pennsylvania	4599320189655029	4075d170624bbff8a6401922be551079	VISA 16 digit	40.0039518956053968	-75.1436110224939995
28480	2020-06-02 17:39:24	2020-06-02	Verdie Ruecker	verdie.ruecker@geemail.com	San Francisco	California	4080573105862238	f915dfb428e8330591ef7a5bedfc766e	Voyager	37.7981811983026432	-122.443057978111497
28481	2020-06-02 17:47:59	2020-06-02	Miss Mintie Johnston	miss.mintie.johnston@warmmail.com	New York	New York	4260318664468130	5dead060d917281e4cacafeb93d7686f	Discover	40.673252335213121	-73.9625310612272386
28482	2020-06-02 17:50:41	2020-06-02	Pamela Nicolas	pamela.nicolas@geemail.com	Chicago	Illinois	51186682461623911	5bb712d53aa52aec3a7d9d24ab35974a	Maestro	41.7578075809705993	-87.6352367451909942
28483	2020-06-02 17:51:00	2020-06-02	Rocco Huel II	rocco.huel.ii@geemail.com	San Diego	California	6011154261090755481	ae792a824c49afb98bd444f449885cb5	Diners Club / Carte Blanche	32.8931456948697587	-117.047141902698215
28484	2020-06-02 17:55:55	2020-06-02	Lovell Borer-Beahan	lovell.borer.beahan@woohoo.com	Coral Springs	Florida	4498547891852252	751b7c5a269016358922c083115a5457	JCB 16 digit	26.2344006089556991	-80.1864664132829716
28485	2020-06-02 17:58:20	2020-06-02	Brooklynn Armstrong	brooklynn.armstrong@geemail.com	Los Angeles	California	3024409514881720	03754d9ed0039995d337dbc20da64050	Diners Club / Carte Blanche	33.996717412290721	-118.440798869495467
28486	2020-06-02 18:08:46	2020-06-02	Gardner Lindgren I	gardner.lindgren.i@geemail.com	San Francisco	California	4698235674205108	ae936d01b48dfe32ca6d713e70d0d8b0	Discover	37.7744462235529355	-122.428659638478351
28487	2020-06-02 18:21:09	2020-06-02	Justina Herman	justina.herman@geemail.com	San Francisco	California	3158774249887114038	d09436341cf669476e82aa03f6bf4236	JCB 16 digit	37.7592851602778268	-122.424449249373438
28488	2020-06-02 18:36:35	2020-06-02	Babe Botsford	babe.botsford@woohoo.com	Fort Lauderdale	Florida	3337510288464953326	3ac601a56faecb4287b9a03175c3d52e	Mastercard	26.0496368726238607	-80.1459136328015376
28489	2020-06-02 18:44:57	2020-06-02	Armond Kautzer	armond.kautzer@geemail.com	Fort Wayne	Indiana	4909661490010288	21fefbdb4fe40334ae811c67898f00b1	Maestro	41.0543698224954312	-85.1169137895792716
28490	2020-06-02 18:54:22	2020-06-02	Raelyn Stark PhD	raelyn.stark.phd@geemail.com	Worcester	Massachusetts	4918888811443315	d6519e2e20b0059cedf5c1f6f9ec3337	American Express	42.190039002586154	-71.8889876398045544
28491	2020-06-02 19:05:05	2020-06-02	Dr. Admiral Daugherty	dr.admiral.daugherty@geemail.com	Cincinnati	Ohio	4821827176997479	e25665000e6facde0ab1a4563d105b77	Diners Club / Carte Blanche	39.1007771993286894	-84.563261007125675
28492	2020-06-02 19:38:57	2020-06-02	Miss Oney Quigley PhD	miss.oney.quigley.phd@geemail.com	Richmond	California	3031303154596925	ab744e955f7b21af8936ef991d652659	Mastercard	37.9277701517522345	-122.423540455228093
28493	2020-06-02 19:40:39	2020-06-02	Alyce Mosciski	alyce.mosciski@woohoo.com	Fort Worth	Texas	3002147109852423	21cc0802988a25be3ff120ae547db013	JCB 16 digit	32.8537738771233734	-97.4095867044579222
28494	2020-06-02 19:56:45	2020-06-02	Farris Huels	farris.huels@geemail.com	Charlotte	North Carolina	589355506399181	9862c642b434978ec69870e2399af33f	JCB 16 digit	35.2115730674725	-80.9115031389929413
28495	2020-06-02 20:07:40	2020-06-02	Parrish Mitchell	parrish.mitchell@warmmail.com	Corpus Christi	Texas	3337245785591277356	40a878891a8c140dd605343d2557fa20	VISA 16 digit	27.7529925001256181	-97.2070440645158271
28496	2020-06-02 20:09:14	2020-06-02	Mr. Curley Nader V	mr.curley.nader.v@woohoo.com	Oxnard	California	3725532878073033	63201a1293d1bc27a1653ade904a6922	VISA 13 digit	34.1352788741190025	-119.256497751493384
28497	2020-06-02 20:14:05	2020-06-02	Hilary Lakin	hilary.lakin@geemail.com	St. Petersburg	Florida	630413598461609	d24fb6dd4ef2d353a02ae61780979866	JCB 16 digit	27.8297257115021353	-82.6413356782294812
28498	2020-06-02 20:19:28	2020-06-02	Wells Hirthe	wells.hirthe@warmmail.com	Chula Vista	California	675973178915531	be8ca5e4804e4b764714199a74f71252	VISA 13 digit	32.6892967589896131	-117.101329083670663
28499	2020-06-02 20:22:53	2020-06-02	Mrs. Lee Ward	mrs.lee.ward@warmmail.com	Lakewood	Colorado	675952875891740	a408287df963625345a4102b75056480	American Express	39.7985936590410816	-105.195356361104544
28500	2020-06-02 20:25:14	2020-06-02	Miss Helene Bernhard PhD	miss.helene.bernhard.phd@geemail.com	Santa Clarita	California	4016097061945	29270b62585495d4b4326da815b823ab	Diners Club / Carte Blanche	34.3976605473291102	-118.44195166198611
28501	2020-06-02 20:27:37	2020-06-02	Dimple Ortiz	dimple.ortiz@geemail.com	Berkeley	California	210015684166057574	16c51addbb386fe6254a84795a94be86	JCB 16 digit	37.8847736050711958	-122.274908949812044
28502	2020-06-02 20:28:51	2020-06-02	Ms. Marley Lakin PhD	ms.marley.lakin.phd@warmmail.com	Portland	Oregon	869916628728977968	36d7fbb8566f69eed30ac30928620c6f	JCB 15 digit	45.5889323869608347	-122.693852364737552
28503	2020-06-02 20:33:56	2020-06-02	Illya Halvorson-Terry	illya.halvorson.terry@geemail.com	Sacramento	California	3112222253003424501	1dee96b2bed9a1a98710faf7664ae55d	Discover	38.5493565235551472	-121.3956395675674
28504	2020-06-02 20:37:04	2020-06-02	Dr. Kianna Wisozk	dr.kianna.wisozk@warmmail.com	New York	New York	54226059570804629	6a586efd6fe1bf16d752f3172a040c23	Voyager	40.7484090872798106	-73.8653859364695791
28505	2020-06-02 20:50:36	2020-06-02	Cindy Effertz	cindy.effertz@geemail.com	New York	New York	3038003483883225	96ca65cc7113b9bfb5b5c0d264a10863	JCB 15 digit	40.5972766851298488	-74.0259508537955497
28506	2020-06-02 20:58:17	2020-06-02	Dr. Dionte Wolff	dr.dionte.wolff@geemail.com	Escondido	California	869950256321640838	f366a6bfe1b4eb233747309320925c08	VISA 16 digit	33.1821518431644904	-117.117734167236833
28507	2020-06-02 21:08:45	2020-06-02	Mrs. Corean Botsford DVM	mrs.corean.botsford.dvm@woohoo.com	Salt Lake City	Utah	210002195140618238	3ccc1f5286abe6edf8f3e7903e975498	VISA 13 digit	40.861967016026	-111.956768365571278
28508	2020-06-02 21:13:01	2020-06-02	January Metz	january.metz@geemail.com	New York	New York	6011196830121322063	bd55b7babc6005a0a1c81dd4d64319f8	American Express	40.6508898476362219	-73.9966552656039624
28509	2020-06-02 21:25:37	2020-06-02	Less Hammes	less.hammes@geemail.com	Garden Grove	California	3410601211690642	1e4a4adcbe6f8636123b23303e2f153a	JCB 16 digit	33.7795078921422345	-117.96542961392737
28510	2020-06-02 21:28:06	2020-06-02	Evonne Kirlin	evonne.kirlin@warmmail.com	Fort Wayne	Indiana	3088871877427905796	4052e6d1b227fc654d71f552bfe17b7d	JCB 16 digit	41.0580999326676164	-85.2001359517905854
28511	2020-06-02 21:37:19	2020-06-02	James Abbott	james.abbott@warmmail.com	Kansas City	Missouri	210021464848509066	33393f75454085d8d831124af8d6d370	JCB 15 digit	39.2001113357324158	-94.5598309352286179
28512	2020-06-02 21:45:08	2020-06-02	Dean Cruickshank	dean.cruickshank@geemail.com	Huntsville	Alabama	3421112038322788	1146d4076240da05b68fb3e7ef3f4c9b	VISA 16 digit	34.631421014411373	-86.6613015036582937
28513	2020-06-02 21:49:39	2020-06-02	Norton Upton	norton.upton@geemail.com	Riverside	California	589305884738112	0a789a59d7a38dd359dec031da1934f3	Voyager	33.8963885889802086	-117.35107958106957
28514	2020-06-02 21:54:03	2020-06-02	Dr. Luc Considine	dr.luc.considine@woohoo.com	Berkeley	California	3158514683558553667	06edc3723b89074afcb91aa56505c657	VISA 13 digit	37.8829247659587338	-122.252529898615947
28515	2020-06-02 21:59:07	2020-06-02	Elden Fay	elden.fay@warmmail.com	San Francisco	California	210060700005359353	534dcab070d6cd98ce755f186a3bad43	Voyager	37.7602896849792984	-122.43550691205968
28516	2020-06-02 22:03:02	2020-06-02	Demetrius Kshlerin	demetrius.kshlerin@geemail.com	Orlando	Florida	4137825339103786	5ff42cda1429aa262cf0d11af68d4991	JCB 15 digit	28.3924861370384676	-81.3023898533046321
28517	2020-06-02 22:03:31	2020-06-02	Werner Kuhlman	werner.kuhlman@geemail.com	San Francisco	California	3528557445707207589	c5c8a9d49a71d391a1c5080ab6a750de	VISA 13 digit	37.8099308048364335	-122.451470021829692
28518	2020-06-02 22:05:01	2020-06-02	Mellisa Turner	mellisa.turner@geemail.com	Austin	Texas	180045358668412579	a849e1d490781593d17de8d9634e99fc	VISA 13 digit	30.2857297968246044	-97.8189821439568021
28519	2020-06-02 22:10:25	2020-06-02	Dr. Mercer Lubowitz I	dr.mercer.lubowitz.i@geemail.com	Philadelphia	Pennsylvania	3412987120390632	8be668efb9f952158f213063e77f8ad3	Diners Club / Carte Blanche	40.0493841290432968	-75.1554795266959843
28520	2020-06-02 22:11:57	2020-06-02	Garland Purdy	garland.purdy@woohoo.com	Lincoln	Nebraska	4093398609732967	a778522fd03e8e179ae40574b56e9c51	VISA 16 digit	40.7724253974873534	-96.6881942826017706
28521	2020-06-02 22:21:18	2020-06-02	Violeta Willms	violeta.willms@geemail.com	Washington	District of Columbia	4540109940840123	383d2e36b15d72fc8a0991bdc589f859	JCB 16 digit	38.8227610234901306	-77.0975933587390898
28522	2020-06-02 22:22:50	2020-06-02	Mr. Elmo Block V	mr.elmo.block.v@geemail.com	San Francisco	California	3719031385327535	6dd15b41202058506c98b8a035445373	JCB 16 digit	37.7430045630369335	-122.495681549142972
28523	2020-06-02 22:31:56	2020-06-02	Isaak Murray	isaak.murray@woohoo.com	Torrance	California	210072581720587593	7ae5b0aff07cfdf368913e658a773f08	JCB 16 digit	33.9195861359033728	-118.404144301091875
28524	2020-06-02 22:46:10	2020-06-02	Ireland Dicki	ireland.dicki@geemail.com	Milwaukee	Wisconsin	675949055248071	40e98027d1d15d2897e9d17f84fc081e	JCB 15 digit	43.0008108256470365	-88.0383778889298441
28525	2020-06-02 22:47:49	2020-06-02	Monte Kreiger IV	monte.kreiger.iv@geemail.com	Mesa	Arizona	6011055456429474354	6cc22bb9e2bad8369e728c287b04a998	Voyager	33.3922494987636753	-111.763554767693947
28526	2020-06-02 23:06:41	2020-06-02	Cyril Lockman-Tremblay	cyril.lockman.tremblay@warmmail.com	Sacramento	California	54797325805065552	e9677f7ec93f54250cc2a6884cc8101f	VISA 16 digit	38.5724647207915794	-121.39138022663667
28527	2020-06-02 23:23:00	2020-06-02	Deangelo Collier	deangelo.collier@geemail.com	Anchorage	Alaska	53038467157652683	b7233f823250145f21db37b9979e31e5	VISA 16 digit	61.0798050593335233	-149.248721738171952
28528	2020-06-02 23:32:04	2020-06-02	Cole DuBuque	cole.dubuque@geemail.com	New York	New York	4239086583306065	bfe873b23720a8357fea82e8de654782	Diners Club / Carte Blanche	40.7244797828830798	-73.9263623008865807
28529	2020-06-02 23:36:52	2020-06-02	Ronnie Koelpin	ronnie.koelpin@geemail.com	Milwaukee	Wisconsin	6011906045367041654	cb906bda294cdbb1e437143d563aa565	Maestro	43.0185807611878914	-88.0014956866491644
28530	2020-06-02 23:49:27	2020-06-02	Marius Kris	marius.kris@geemail.com	Houston	Texas	3739606830282116	e60cd684f11cc6e09a0c65ab95e94d30	JCB 15 digit	29.7059228492047644	-95.4522317857496461
28531	2020-06-03 00:06:04	2020-06-03	Grayce Collins	grayce.collins@warmmail.com	Colorado Springs	Colorado	51179903821428794	9e56e3a259544ebd00ba008c73e465b3	Diners Club / Carte Blanche	38.9474900730002673	-104.76529535415284
28532	2020-06-03 00:07:03	2020-06-03	Dr. Santa Kris	dr.santa.kris@geemail.com	San Francisco	California	180061673875696932	1f887e6a143f855c8a8d5a5d84d36c83	VISA 16 digit	37.8018312197267718	-122.44981640765306
28533	2020-06-03 00:25:14	2020-06-03	Kiya Stokes	kiya.stokes@woohoo.com	Riverside	California	210034403317259782	0b7754259128d31110e80e05b3138563	Mastercard	33.9351330959185944	-117.436706052065631
28534	2020-06-03 00:31:27	2020-06-03	Krystina Mills	krystina.mills@geemail.com	San Diego	California	3040761854380620	c906958d49aa860af3e31ad9be9dda3e	Mastercard	32.7518810780320351	-117.182265136335047
28535	2020-06-03 00:34:05	2020-06-03	Mr. Silver Kerluke	mr.silver.kerluke@woohoo.com	Bellevue	Washington	51189772124957512	b6f39063dff63cdcb403766cafd54b7b	VISA 13 digit	47.6697887408263981	-122.107271899521351
28536	2020-06-03 00:47:13	2020-06-03	Dr. Phoenix Bauch	dr.phoenix.bauch@geemail.com	San Francisco	California	3528499971347727323	bb87829949e8a018840679796839b918	JCB 15 digit	37.7589373448907608	-122.434237659928115
28537	2020-06-03 00:53:12	2020-06-03	Rayfield Predovic MD	rayfield.predovic.md@warmmail.com	Peoria	Arizona	6011889503840281876	ff7d85ff08003d6b1049051338a386a1	VISA 13 digit	33.7762938506703847	-112.255473423089839
28538	2020-06-03 01:05:01	2020-06-03	Sophia Schumm	sophia.schumm@geemail.com	Virginia Beach	Virginia	869907910385083285	89b5c0ee5a8dd802be591641eb2d4858	Diners Club / Carte Blanche	36.8713327164947984	-76.0168492683347239
28539	2020-06-03 01:06:42	2020-06-03	Ms. Iliana King DDS	ms.iliana.king.dds@warmmail.com	Scottsdale	Arizona	3025740730545742	7dbe3ade004f24c6db70267a52153a05	Diners Club / Carte Blanche	33.5994012168265854	-111.960851704093059
28540	2020-06-03 01:12:53	2020-06-03	Sylvester Predovic II	sylvester.predovic.ii@warmmail.com	New York	New York	4230331374295021	7d4072fc27f7e807ac199c40259b079f	VISA 13 digit	40.7597630089372416	-73.8397340335313146
28541	2020-06-03 01:13:24	2020-06-03	Leroy Parisian-Waelchi	leroy.parisian.waelchi@geemail.com	New York	New York	3478532680680690	9613d27297822aaf9b4d4ef91c1c4239	VISA 13 digit	40.7440474244989446	-73.9247500113107208
28542	2020-06-03 01:20:16	2020-06-03	Haiden Dare	haiden.dare@geemail.com	Gresham	Oregon	4199988628729086	017c673ceacd1ed4007ab694c8040ec0	American Express	45.4358717202164186	-122.504471836265537
28543	2020-06-03 01:22:17	2020-06-03	Marcus Williamson III	marcus.williamson.iii@geemail.com	Los Angeles	California	6011485284176100190	8f84dc6ad5103d290b7907fee9f1c113	JCB 16 digit	34.0715400641184303	-118.3657952241592
28544	2020-06-03 01:23:43	2020-06-03	Keaton Renner	keaton.renner@geemail.com	Elk Grove	California	4008327201290680	706edbd484d49b27778d5a0214f01b96	JCB 16 digit	38.458670159737018	-121.46321190450341
28545	2020-06-03 01:34:14	2020-06-03	Lenora Hudson	lenora.hudson@warmmail.com	San Jose	California	3006442859146324	e962696b6a0f98e904c3ba8efbbadbaf	JCB 15 digit	37.221121445652841	-121.849230346571275
28546	2020-06-03 01:38:48	2020-06-03	Miss Felice Hoppe	miss.felice.hoppe@geemail.com	Santa Ana	California	210001051719254569	d4c43f6eb188de2edf2580f0b295d362	Voyager	33.8218269428342566	-117.904664734603827
28547	2020-06-03 01:41:45	2020-06-03	Lorine Block	lorine.block@geemail.com	Hillsboro	Oregon	4562202345833281	cb07599851cef821c46a8aabcb73db0f	JCB 16 digit	45.6223895173259066	-122.858530914845687
28548	2020-06-03 01:43:50	2020-06-03	Neoma Ankunding DVM	neoma.ankunding.dvm@warmmail.com	Round Rock	Texas	869925051132222856	d9cd09077572471ae3fea8e1ba7a311a	VISA 16 digit	30.4648319223567867	-97.6880998860895602
28549	2020-06-03 01:52:13	2020-06-03	Arlis Hermann III	arlis.hermann.iii@geemail.com	Phoenix	Arizona	6011824060623406368	3425fa6141bcfa232bbcc23eb3b6604a	JCB 15 digit	33.6157074475128255	-112.016665719814981
28550	2020-06-03 02:01:23	2020-06-03	Robbin Ankunding	robbin.ankunding@geemail.com	San Francisco	California	3112670289246813552	4769dce779300487ecad2dc960727fcc	JCB 15 digit	37.7791621603572452	-122.444574324617093
28551	2020-06-03 02:02:28	2020-06-03	Kingston Ankunding	kingston.ankunding@geemail.com	San Francisco	California	676137130014378	1c2e9e6c9a45ade548caf7a50b9cbee4	VISA 16 digit	37.7871136501296334	-122.434243955604799
28552	2020-06-03 02:04:53	2020-06-03	Kyree Mayert-Ebert	kyree.mayert.ebert@geemail.com	San Francisco	California	3004251712919849	8835da8a3572f61cc5ad7cd2b71c641e	Mastercard	37.7720975535910597	-122.426604172229588
28553	2020-06-03 02:06:52	2020-06-03	Raphael Spencer MD	raphael.spencer.md@geemail.com	Dallas	Texas	869948490611301299	d8ec0369d992a1720de23dd518528b15	JCB 15 digit	32.8761233581967645	-96.7954647480007253
28554	2020-06-03 02:23:39	2020-06-03	Mrs. Consuelo Heathcote	mrs.consuelo.heathcote@geemail.com	Temecula	California	4902391766562575	82fbf9466987cef1b8c843f9aea93397	Diners Club / Carte Blanche	33.5764585340063988	-117.178393834522737
28555	2020-06-03 02:26:45	2020-06-03	Gail Hyatt	gail.hyatt@geemail.com	Jersey City	New Jersey	4127429213795304	c3bf2c4bc36d8b45a04a7fcab3c1d56d	Mastercard	40.6436215863503492	-73.9987886649977469
28556	2020-06-03 02:44:27	2020-06-03	Stevie Bosco-Hermiston	stevie.bosco.hermiston@geemail.com	Indianapolis	Indiana	869940409400981028	3742000fc0a8cdac382d8148156f007f	JCB 16 digit	39.7256268124103542	-86.2281047966066723
28557	2020-06-03 03:18:26	2020-06-03	Lesia Simonis	lesia.simonis@geemail.com	Houston	Texas	3049431395118324	b13c279cb86f58d342f9e41198c33f71	VISA 16 digit	29.8596993462726488	-95.4115574493553567
28558	2020-06-03 03:28:47	2020-06-03	Lambert Jacobson	lambert.jacobson@geemail.com	Boston	Massachusetts	3158062149854977923	8cd3a5af8cb5726ee6175d5d7049abae	JCB 16 digit	42.3474977912548951	-71.0263985410749967
28559	2020-06-03 03:30:57	2020-06-03	Buford Schmeler DDS	buford.schmeler.dds@geemail.com	Sioux Falls	South Dakota	3158336137397154811	fc5d26eec0e02e8c8b9a70848f423079	JCB 16 digit	43.540772217567266	-96.7289452934339664
28560	2020-06-03 03:32:12	2020-06-03	Avie Huel	avie.huel@geemail.com	Birmingham	Alabama	3473450452577850	cce73ce559201f9a0844e7c97473b06b	JCB 16 digit	33.4438275079034284	-86.779124280182657
28561	2020-06-03 03:44:30	2020-06-03	Collin Tillman	collin.tillman@warmmail.com	Memphis	Tennessee	51493897739309469	7469df4e500cf2dd939a4fd294979d6e	JCB 15 digit	35.1071530405964722	-90.0698754699226498
28562	2020-06-03 03:52:12	2020-06-03	Raymon Parisian	raymon.parisian@woohoo.com	El Cajon	California	676246863859875	aa1b1973b11eb37f8f28386b760ab405	JCB 15 digit	32.8186909966643867	-117.021806712839393
28563	2020-06-03 03:52:58	2020-06-03	Doreen Lowe-Pfannerstill	doreen.lowe.pfannerstill@geemail.com	Fontana	California	3043498208637127	7592f8eecb57fbc4fb576698949f68eb	VISA 16 digit	34.0472306084968181	-117.481247683362668
28564	2020-06-03 03:53:31	2020-06-03	Mrs. Taylor Runte DDS	mrs.taylor.runte.dds@warmmail.com	Rochester	New York	3088918243260190498	21541c1855af4541904262d492c21e1c	JCB 15 digit	43.2515865057684437	-77.5305639508418807
28565	2020-06-03 03:58:49	2020-06-03	Nada Predovic MD	nada.predovic.md@geemail.com	Baton Rouge	Louisiana	4461334148286896	38600b2132987158097bf775b9fc3d1d	Maestro	30.4952419856309902	-91.1832760333191601
28566	2020-06-03 04:03:10	2020-06-03	Dr. Rosella Hintz DVM	dr.rosella.hintz.dvm@woohoo.com	Pomona	California	4690124107409180	810202a774edf65982fb8525ca0e6815	Maestro	33.9699610413555106	-117.809496559245886
28567	2020-06-03 04:04:51	2020-06-03	Judith Emard PhD	judith.emard.phd@geemail.com	Springfield	Missouri	3051030277869844	f50c0042a565059cf9a3af8bfebf8088	Voyager	37.2254834944576061	-93.2281424864951589
28568	2020-06-03 04:28:30	2020-06-03	Zelpha Blanda DDS	zelpha.blanda.dds@geemail.com	Des Moines	Iowa	869929967896299101	ee32d4a011e5fd24f43992f15ceb41bf	JCB 15 digit	41.5758843970227971	-93.6449244195640205
28569	2020-06-03 04:37:09	2020-06-03	Dr. Deegan Gibson Jr.	dr.deegan.gibson.jr.@geemail.com	New York	New York	6011983633549279874	772de21ca82a34fbd9596eab8388d544	American Express	40.6239076696094088	-73.9346261246491139
28570	2020-06-03 04:56:44	2020-06-03	Alice Abernathy	alice.abernathy@woohoo.com	New York	New York	3337340184453184344	312380789fe1fe022402be01a5eaf80c	Maestro	40.60028953903727	-73.8539237194590186
28571	2020-06-03 04:57:15	2020-06-03	Marcie Bergnaum	marcie.bergnaum@warmmail.com	Surprise	Arizona	4701213293718491	881d41f8b59d6e5156fb3e60dd0155fe	American Express	33.6118311005406056	-112.46251776313855
28572	2020-06-03 04:57:39	2020-06-03	Sylvanus Gislason	sylvanus.gislason@woohoo.com	Chicago	Illinois	503843291533669	22ea5869582cad69b30ecd970d72217a	JCB 16 digit	41.9375639587011193	-87.6648694328993514
28573	2020-06-03 04:59:55	2020-06-03	Cleva Towne	cleva.towne@geemail.com	Los Angeles	California	4803839410801963	25556f73f6698ef223f88d91a71d04d2	JCB 15 digit	34.0131116910237807	-118.430818302462995
28574	2020-06-03 05:04:11	2020-06-03	Bennie Emmerich	bennie.emmerich@woohoo.com	San Diego	California	52890241741631199	f583353182a7c6a36a2002b39a81c3c7	JCB 15 digit	32.7877240883253549	-117.170086307395252
28575	2020-06-03 05:08:17	2020-06-03	Leighton Klocko MD	leighton.klocko.md@warmmail.com	Oxnard	California	4085571244834014	f7108caeb6c9567413052fb248a41fbb	VISA 16 digit	34.2039154025215666	-119.126613939265155
28576	2020-06-03 05:12:55	2020-06-03	Caydence Crooks	caydence.crooks@geemail.com	Berkeley	California	630439958761361	594caf0e96ceebe14dea31462f296b1b	VISA 16 digit	37.8713506614860549	-122.277598411376587
28577	2020-06-03 05:21:20	2020-06-03	Christopher Stoltenberg	christopher.stoltenberg@geemail.com	Temecula	California	869930718389115586	c1404dc54cdd36a377b18c4f43e6c9aa	VISA 16 digit	33.5548869006935462	-117.158965421813349
28578	2020-06-03 05:56:53	2020-06-03	Mr. Dwayne Hills IV	mr.dwayne.hills.iv@geemail.com	New York	New York	54509226557715999	a24d9fdf8b16e23083b2cfd887d58a03	JCB 16 digit	40.5674907207246846	-73.9155460290972144
28579	2020-06-03 06:22:14	2020-06-03	Avery Raynor DVM	avery.raynor.dvm@geemail.com	Wichita	Kansas	869942476620064602	c81a8aafc7db3ece5aae6320f36a8a47	Mastercard	37.654688745352253	-97.3062452239651208
28580	2020-06-03 06:37:42	2020-06-03	Mrs. Lara Borer PhD	mrs.lara.borer.phd@geemail.com	Los Angeles	California	51741827473088946	78eaa10be8d6e5bbd782af9e41bac7f8	VISA 16 digit	34.1150228770781254	-118.416114092151815
28581	2020-06-03 06:58:10	2020-06-03	Henrietta DuBuque PhD	henrietta.dubuque.phd@geemail.com	San Jose	California	4450844175108964	cda52933a7e7b29a2aa8cd96b0a7065b	Voyager	37.3901620013926177	-121.856497369588908
28582	2020-06-03 07:01:57	2020-06-03	Cris Hane	cris.hane@geemail.com	Oakland	California	3749332391102399	6660d6cfee1766ee229f51d29bb722ce	Discover	37.8099231185840097	-122.288304941452012
28583	2020-06-03 07:14:26	2020-06-03	Leone Okuneva	leone.okuneva@geemail.com	Houston	Texas	3491106948550202	e689a59262915ee335a7e7edee688abc	VISA 13 digit	29.8104032890018082	-95.3412002091776571
28584	2020-06-03 07:26:54	2020-06-03	Estel Schroeder-Rutherford	estel.schroeder.rutherford@geemail.com	Memphis	Tennessee	869921240763815344	ecf12e728823bed4e52dd7eebd3c9d24	VISA 16 digit	35.0869911423951422	-89.9495371712163063
28585	2020-06-03 07:29:26	2020-06-03	Casper Boyle	casper.boyle@geemail.com	Pasadena	Texas	6011053754777181585	8cbf96d9521f5acd21df5e84bf8e5149	Voyager	29.747178433729708	-95.2417402708850744
28586	2020-06-03 07:29:48	2020-06-03	Tamica Koch	tamica.koch@warmmail.com	Oakland	California	869959741033362889	6d20f3ab3cb95fdd81572c2994753b14	Voyager	37.8075198358509965	-122.240577063881119
28587	2020-06-03 07:42:02	2020-06-03	Rudolf D'Amore	rudolf.d'amore@warmmail.com	Chicago	Illinois	4232738972040	c1ceebfa666554cfb03a6d4e9d94bb62	VISA 13 digit	41.8578325232327018	-87.7362604694005057
28588	2020-06-03 07:50:54	2020-06-03	Hilma Pacocha-Cummerata	hilma.pacocha.cummerata@warmmail.com	Columbus	Ohio	4704237478844	87e4a9b6e94b9263e48293ceb36d7e81	JCB 15 digit	39.8870511722330008	-83.0379811787281312
28589	2020-06-03 07:58:33	2020-06-03	Mrs. Araceli Nader PhD	mrs.araceli.nader.phd@warmmail.com	Virginia Beach	Virginia	3043477942430916	d0961062906169d767373f095cfb6e87	Maestro	36.8642657789587957	-76.078915218557043
28590	2020-06-03 08:02:11	2020-06-03	Glennie Erdman	glennie.erdman@warmmail.com	Santa Clarita	California	4876796212225886	749cfd0b0d34bb52e123968d5152b22d	Mastercard	34.3214241843409837	-118.56811646564006
28591	2020-06-03 08:07:48	2020-06-03	Cedrick Hessel	cedrick.hessel@warmmail.com	Davie	Florida	3701387783284995	44ba69c018a5dc8cfa91a985407f717b	VISA 13 digit	26.0489196998797361	-80.3679366255551599
28592	2020-06-03 08:09:35	2020-06-03	Mr. Junious Sauer PhD	mr.junious.sauer.phd@geemail.com	Oakland	California	52073878241042630	ebfd5c68af6526f8be753bbe14994985	JCB 15 digit	37.7686030875145207	-122.264162276085514
28593	2020-06-03 08:09:56	2020-06-03	Peggy Herman	peggy.herman@warmmail.com	Denver	Colorado	3038237423945385	de5fe5960691b51a28e99fdea0b0e2f3	JCB 16 digit	39.739496885105595	-104.910764946999407
28594	2020-06-03 08:12:01	2020-06-03	Shaniece Dare	shaniece.dare@geemail.com	Rochester	New York	869947279104341818	d7f846ddb9eac51c1a114f1c7d73e50b	VISA 16 digit	43.2087163601979611	-77.5203856820479018
28595	2020-06-03 08:28:07	2020-06-03	Truman Dare	truman.dare@geemail.com	Topeka	Kansas	4687346276749998	3a97bb642ba3d54b2c473cbd06b95018	JCB 16 digit	39.0247778551120348	-95.7487808047037561
28596	2020-06-03 08:43:07	2020-06-03	Georgiann Bartoletti	georgiann.bartoletti@geemail.com	New York	New York	3337482693288216988	b196f2bf83b2db7292cce7bd63cada45	VISA 16 digit	40.6173392522837986	-73.8978510792262853
28597	2020-06-03 08:47:01	2020-06-03	Michelle Konopelski	michelle.konopelski@warmmail.com	New York	New York	4637206928392749	5c77e4049f3cb9ae6a6e5dc8adac86e6	JCB 15 digit	40.7312480965852757	-74.0384003994416418
28598	2020-06-03 08:53:01	2020-06-03	Mrs. Sherie Schaden	mrs.sherie.schaden@geemail.com	Yonkers	New York	3528257078279598870	36cf831da08a960b512ce3eb90812c98	Voyager	40.9597611235190229	-73.8461516301963456
28599	2020-06-03 08:53:01	2020-06-03	Miss Caryl Torphy PhD	miss.caryl.torphy.phd@geemail.com	Aurora	Illinois	4205781047953193	622229147da42cc6765db7050e2d75cb	Voyager	41.815251698460429	-88.2825151557031944
28600	2020-06-03 09:06:05	2020-06-03	Williams Gaylord	williams.gaylord@warmmail.com	Nashville	Tennessee	6011373305115506034	08fac374f8fc81bbb3f457e37c07dfa6	VISA 13 digit	36.119961704698575	-86.7788006537966368
28601	2020-06-03 09:25:44	2020-06-03	Ginny Torphy	ginny.torphy@geemail.com	Los Angeles	California	4321378888644806	0f9567b4847cdca798413d0685de8016	Discover	33.9275131695769687	-118.441301542007551
28602	2020-06-03 09:33:22	2020-06-03	Ellwood Pollich-Rolfson	ellwood.pollich.rolfson@geemail.com	San Francisco	California	4964934372567150	b45dbe007767f0aad42899705568cfa4	Maestro	37.743186719564747	-122.406162747750159
28603	2020-06-03 09:33:43	2020-06-03	Kareen Romaguera	kareen.romaguera@geemail.com	Los Angeles	California	869939151144398829	8b4bd50383d707ef7d43c9dda6cc8351	VISA 16 digit	33.9456418727856075	-118.425123516795409
28604	2020-06-03 09:34:09	2020-06-03	Pamella Bartell-Moen	pamella.bartell.moen@geemail.com	Los Angeles	California	4483117526372832	44d0ee800bd97fe51928ae80f1e29784	VISA 16 digit	33.9431438744399685	-118.503000911883262
28605	2020-06-03 09:45:42	2020-06-03	Sandi Ebert	sandi.ebert@geemail.com	Oakland	California	3096725166035422735	1d70f02edb78f716de3c75db83365717	Mastercard	37.8164892858197206	-122.26703251279433
28606	2020-06-03 09:55:07	2020-06-03	Michial Orn	michial.orn@warmmail.com	San Francisco	California	180006610201755535	611fa41a9f10fae80962c3921f7c5a3f	Discover	37.7542217517390313	-122.449837410226664
28607	2020-06-03 10:01:31	2020-06-03	Rashawn Prosacco	rashawn.prosacco@geemail.com	Bellevue	Washington	180086582417703968	4de70bb8183804f2c39a5146092bf727	Mastercard	47.6610417558062878	-122.146359712962052
28608	2020-06-03 10:17:19	2020-06-03	Ambers Huels-Hilll	ambers.huels.hilll@geemail.com	Berkeley	California	4562959985952	eb3665674f344487ef10a3f501ebc177	JCB 16 digit	37.8611179776365745	-122.263215987494775
28609	2020-06-03 10:17:32	2020-06-03	Dr. Vernelle McKenzie PhD	dr.vernelle.mckenzie.phd@warmmail.com	Greeley	Colorado	3528063125079167812	587c8d3fc708b20d86e7b9cb38878efc	VISA 13 digit	40.4770738027591293	-104.827682978178188
28610	2020-06-03 10:20:27	2020-06-03	Kristofer Medhurst-Trantow	kristofer.medhurst.trantow@geemail.com	Los Angeles	California	3088479323619069329	e71b28d48464e02afa8510d63f32cfa8	JCB 15 digit	33.9822495055716445	-118.500377095443383
28611	2020-06-03 10:32:55	2020-06-03	Gaylord Kling	gaylord.kling@geemail.com	Oakland	California	3427667909896545	9e07b3b7a295f92b7df0d406c10d96db	Discover	37.8057789131468098	-122.265339313835895
28612	2020-06-03 10:34:36	2020-06-03	Ireland Volkman	ireland.volkman@geemail.com	New York	New York	180023491794380869	cdb040ba99ad477acc24ad7e6f9cb45a	JCB 16 digit	40.5992316203415413	-73.9745667103107962
28613	2020-06-03 10:37:33	2020-06-03	Dr. Jettie Upton IV	dr.jettie.upton.iv@geemail.com	Baltimore	Maryland	3158661188853078932	f6066beeb948344db1e7a12733c76e71	JCB 16 digit	39.2244798636063905	-76.5549034030661062
28614	2020-06-03 10:38:56	2020-06-03	Tori Hyatt DDS	tori.hyatt.dds@geemail.com	Sugar Land	Texas	3337960695911719537	b8221531d9105421e218eb79ebcb176d	Discover	29.6085770600061871	-95.5964893783450123
28615	2020-06-03 10:55:42	2020-06-03	Dr. Hazelle Schowalter PhD	dr.hazelle.schowalter.phd@geemail.com	Oakland	California	3470236583005223	b3e004abbb896f8fcbe3427d7adfabb3	Maestro	37.7798032460499229	-122.303222078782028
28616	2020-06-03 10:56:44	2020-06-03	Ethan Morar	ethan.morar@geemail.com	Memphis	Tennessee	3337581818475735900	3020171dd16eb9bbab0a61255dd8cbd3	Voyager	35.1080512101363382	-89.9762449566531899
28617	2020-06-03 10:58:57	2020-06-03	Miss Jeanine Kozey	miss.jeanine.kozey@woohoo.com	Austin	Texas	4467550284835808	09cc26bcef81dac46dbffbb4a7c0cb2e	Discover	30.2511282461822013	-97.8400284230481816
28618	2020-06-03 10:59:20	2020-06-03	Mr. Ruffin Keebler	mr.ruffin.keebler@geemail.com	Winston–Salem	North Carolina	4202239119565	ab95ad2f6c5efb4a9734a4ad74c1d849	Diners Club / Carte Blanche	36.027646602806449	-80.1977623845580894
28619	2020-06-03 11:08:33	2020-06-03	Ms. Valorie Buckridge	ms.valorie.buckridge@geemail.com	Oklahoma City	Oklahoma	869948364348535455	47cbd37933727a6fc7dc39801bfa56b9	Diners Club / Carte Blanche	35.4244824130930027	-97.4660462165612671
28620	2020-06-03 11:16:13	2020-06-03	Daisha Gorczany	daisha.gorczany@warmmail.com	Abilene	Texas	55293095219348741	7f20cdb236a585c1fe488c8b8ea079d3	Maestro	32.536625707063827	-99.8340717951249417
28621	2020-06-03 11:32:25	2020-06-03	Dr. Lala Bergnaum DVM	dr.lala.bergnaum.dvm@geemail.com	Santa Rosa	California	51670132568124895	54a200548932976812322790f38c5ed4	Voyager	38.3495369142510043	-122.766011898802972
28622	2020-06-03 11:37:52	2020-06-03	Leonardo Donnelly	leonardo.donnelly@geemail.com	Augusta	Georgia	4481350237450892	dbcd6647cb46d80624bfa1b1e7e92203	VISA 16 digit	33.3517760476302314	-82.0515655674800399
28623	2020-06-03 11:40:04	2020-06-03	Ibrahim Pouros-Cassin	ibrahim.pouros.cassin@geemail.com	Greensboro	North Carolina	3158047419664526065	bc4246e8e695b7518b53a8391471a22f	Voyager	36.0709621529210409	-79.8391237982064439
28624	2020-06-03 11:49:32	2020-06-03	Rocco Wuckert	rocco.wuckert@warmmail.com	Concord	California	676133958899701	b5b680fd157fe0593967dc267f1a520f	Voyager	37.895608809630204	-122.071506877726307
28625	2020-06-03 11:59:09	2020-06-03	Sue Thiel	sue.thiel@geemail.com	New York	New York	3158973128811991670	0b7e509348f7a675a4af8fc34d2a8558	Discover	40.6823170528505003	-73.9032798032637714
28626	2020-06-03 12:01:01	2020-06-03	Clinton Kris	clinton.kris@geemail.com	Chicago	Illinois	3778497724777078	23c1ee290d8027a25fac875ec9fac854	JCB 16 digit	41.7750547746498171	-87.66684437794909
28627	2020-06-03 12:01:26	2020-06-03	Mr. Thaddeus Emard PhD	mr.thaddeus.emard.phd@warmmail.com	Oklahoma City	Oklahoma	3112875351115522624	0b4047a045276a32a9e4655c10cea3f5	Diners Club / Carte Blanche	35.3883518195621676	-97.6041516361188144
28628	2020-06-03 12:03:34	2020-06-03	Miss Sallie Gleichner	miss.sallie.gleichner@woohoo.com	San Francisco	California	52558837243340719	af15e1c4afadf86ac07ff27dd3729176	Mastercard	37.7861383922174028	-122.421859888722707
28629	2020-06-03 12:11:56	2020-06-03	Ira Koch	ira.koch@geemail.com	San Francisco	California	3528716373542141409	24f9849e7d1d40c9344261976f6e0933	VISA 16 digit	37.7946225114730652	-122.453591865492115
28630	2020-06-03 12:20:16	2020-06-03	Pink Wunsch-Collier	pink.wunsch.collier@geemail.com	Cedar Rapids	Iowa	3158921720980564552	954919f99af6d048816b781b769d5542	VISA 13 digit	41.9991155538782479	-91.6153514684245067
28631	2020-06-03 12:30:22	2020-06-03	Kennedi Johns	kennedi.johns@geemail.com	Lafayette	Louisiana	561254896974844	5407ac1ad4bd355531a30892ca454d2f	Diners Club / Carte Blanche	30.2578524068906916	-91.9327185685131667
28632	2020-06-03 12:31:32	2020-06-03	Mrs. Latisha Price DDS	mrs.latisha.price.dds@geemail.com	Chesapeake	Virginia	4444289790917	0f55d321d294d8024f6074c61beb56d9	Mastercard	36.603748933016881	-76.2583428012516293
28633	2020-06-03 12:51:06	2020-06-03	Damian Hoppe I	damian.hoppe.i@geemail.com	Chicago	Illinois	676198514085095	9bdf71466c1e271e42b90dabb6940894	Diners Club / Carte Blanche	41.931873382937539	-87.623497205882515
28634	2020-06-03 12:53:05	2020-06-03	Mrs. Lashunda Yost	mrs.lashunda.yost@geemail.com	San Francisco	California	4243097880332500	280de8483849b9c684f80d8c6839d7de	Mastercard	37.7503452811381024	-122.418673554078666
28635	2020-06-03 13:02:47	2020-06-03	Shellie Schuster-Trantow	shellie.schuster.trantow@geemail.com	Tacoma	Washington	3088083047166532151	ca06b4a84d607759340602298c6261f8	Mastercard	47.2058309932358569	-122.467635611281921
28636	2020-06-03 13:05:13	2020-06-03	Kian Anderson	kian.anderson@geemail.com	Miami Gardens	Florida	54447534837434645	d0d615e69f63ed6a0bfd535214cc4af2	VISA 16 digit	25.9406555436491963	-80.2167950848363347
28637	2020-06-03 13:09:56	2020-06-03	Dr. Ned Streich III	dr.ned.streich.iii@woohoo.com	Fresno	California	4834527142664055	fa5909977a6f9b7c7d855902c0f6521f	Diners Club / Carte Blanche	36.8179818804714856	-119.864470746146154
28638	2020-06-03 13:19:16	2020-06-03	Mariano Hintz	mariano.hintz@warmmail.com	Durham	North Carolina	3770718195877917	dc80223877fa94a61bc3606d3190b70b	Diners Club / Carte Blanche	35.9212421420741777	-78.8083734637495184
28639	2020-06-03 13:20:19	2020-06-03	Charleen Homenick	charleen.homenick@geemail.com	San Francisco	California	3701714579110862	8f014b46b446e76d1e34982e72d332b3	JCB 16 digit	37.7615117820602322	-122.402982630094428
28640	2020-06-03 13:21:46	2020-06-03	Salomon Rosenbaum	salomon.rosenbaum@geemail.com	Anaheim	California	210046194385653156	83fc6a557d24b8f3103548e179fd5678	Maestro	33.9340600369796164	-117.859726015964895
28641	2020-06-03 13:23:38	2020-06-03	Kyra Ondricka	kyra.ondricka@geemail.com	New York	New York	4238760454081111	c6a4109495640e56d7d4b4749fe78042	JCB 16 digit	40.6037293503284431	-73.8467094628036023
28642	2020-06-03 13:30:38	2020-06-03	Miss Kelsie Hettinger	miss.kelsie.hettinger@warmmail.com	Visalia	California	3088449653381559207	a2aa8089409b30bd872f0c7b77047abc	Voyager	36.4202204484447876	-119.403781365755577
28643	2020-06-03 13:33:16	2020-06-03	Iliana Mills	iliana.mills@geemail.com	Los Angeles	California	3096807309160948360	41ff7ebdaccd0df42555aa4370772e0f	Discover	33.9855059414502207	-118.381434599216277
28644	2020-06-03 13:48:14	2020-06-03	Roma Kris	roma.kris@geemail.com	New York	New York	210020228364685225	a82fd7a9bea1a1a1a6a92b9d126ad46b	Mastercard	40.6441591098662443	-73.8669973634544732
28645	2020-06-03 13:51:29	2020-06-03	Elfreda Cronin	elfreda.cronin@geemail.com	Chicago	Illinois	6011525315419260490	14a5258b3674966471153b1d91e645f5	VISA 16 digit	41.8397296753082415	-87.6625064337655857
28646	2020-06-03 13:57:46	2020-06-03	Miss Aylin Wolf MD	miss.aylin.wolf.md@geemail.com	High Point	North Carolina	4733596646344680	40594fb21d64c1c4d2cc8ab58b252701	JCB 16 digit	35.9028776124678544	-80.0565456092562471
28647	2020-06-03 13:58:36	2020-06-03	Taniyah McLaughlin	taniyah.mclaughlin@geemail.com	Tulsa	Oklahoma	3096904437666858593	a12ad0e1635ff35fe178d05405b9e6ad	Maestro	36.1838163080994022	-95.983059307090187
28648	2020-06-03 14:00:15	2020-06-03	Marco Parker-Hammes	marco.parker.hammes@geemail.com	Oakland	California	4718760641889904	add3c5c8b036f2be69257d4aaab64014	Maestro	37.7921978821141735	-122.264414846161515
28649	2020-06-03 14:01:32	2020-06-03	Bedford Reichert	bedford.reichert@geemail.com	New York	New York	4282606121360	a0fd44ef02417759115f77c5ff4c0d49	JCB 16 digit	40.6128006109725703	-74.0301504502899945
28650	2020-06-03 14:20:41	2020-06-03	Linette Welch-Hoeger	linette.welch.hoeger@woohoo.com	St. Louis	Missouri	4192467737260272	733bd76378061d63f10ad8a0086a2ffe	Mastercard	38.6510829575050607	-90.2394687882162714
28651	2020-06-03 14:30:15	2020-06-03	Bradyn Pollich	bradyn.pollich@geemail.com	Anaheim	California	53913203190124509	a95b1eca16a47995068ba21a86c1bfa5	JCB 16 digit	33.9448032291904056	-117.71595339181124
28652	2020-06-03 14:35:57	2020-06-03	Erykah Dickens	erykah.dickens@geemail.com	San Francisco	California	4086335314142545	47cd163edec4713940eec81b79e3576d	American Express	37.7682308747578759	-122.407181204060393
28653	2020-06-03 14:49:52	2020-06-03	Jude Huels	jude.huels@geemail.com	El Monte	California	210023167115763872	b475311a2726bac948b8056484b6c603	Diners Club / Carte Blanche	33.9829092692308095	-117.951942360008502
28654	2020-06-03 14:59:48	2020-06-03	Sydney Beatty V	sydney.beatty.v@geemail.com	Wichita Falls	Texas	869947136514590816	7f1a4a35d5a16087fe485676ccf27731	JCB 15 digit	33.9705702899683288	-98.5914735715758042
28655	2020-06-03 15:00:38	2020-06-03	Oneida Volkman	oneida.volkman@geemail.com	San Francisco	California	4043901148403742	897f0745da11f689d246c780329a4d50	VISA 13 digit	37.7988526984521087	-122.431619243153392
28656	2020-06-03 15:06:29	2020-06-03	Raynard Stanton	raynard.stanton@geemail.com	New York	New York	4960976541328349	7f99012c6f52edcd642b20e9187b9df0	JCB 16 digit	40.5847215183768384	-73.8649814311776254
28657	2020-06-03 15:15:16	2020-06-03	Isadora Miller	isadora.miller@woohoo.com	Chicago	Illinois	51404724824229832	4aab069a7cbe90efdcb27af3a939f1b7	Maestro	41.8833244818098862	-87.7773188224557686
28658	2020-06-03 15:23:43	2020-06-03	Pierre Pfeffer	pierre.pfeffer@woohoo.com	Fremont	California	6011215117482979047	d408abcf34be0ff527f841d87137139b	American Express	37.5247622583694778	-121.995002084457127
28659	2020-06-03 15:25:23	2020-06-03	Isis Barton	isis.barton@warmmail.com	San Antonio	Texas	630478498594270	02ee15b42bfef0e30762b5786d5290dc	VISA 16 digit	29.4565889949981141	-98.535435707757614
28660	2020-06-03 15:26:56	2020-06-03	Ms. Carra Brakus	ms.carra.brakus@geemail.com	San Francisco	California	4238726342534819	6505e675431f4523d926854b023c2728	JCB 16 digit	37.7763395040619443	-122.42108512730745
28661	2020-06-03 15:36:35	2020-06-03	Dr. Ronin Stoltenberg	dr.ronin.stoltenberg@geemail.com	Houston	Texas	4498000640616297	54e8ebaad6faa9b3b924d542c4aeef32	American Express	29.772426751217246	-95.3748055787306299
28662	2020-06-03 15:44:14	2020-06-03	Miss Junia Mayert DDS	miss.junia.mayert.dds@geemail.com	Pembroke Pines	Florida	4569430604714	feb20e64aea070fd0a63383971f1c502	JCB 15 digit	26.0238659353498392	-80.403760901502892
28663	2020-06-03 15:54:27	2020-06-03	Haven Lowe	haven.lowe@geemail.com	Las Vegas	Nevada	3112334639018035123	ac3486f99209d6c894915c21f37d2cd8	JCB 16 digit	36.2452461409483107	-115.176051384836796
28664	2020-06-03 16:09:15	2020-06-03	Mr. Desean Osinski	mr.desean.osinski@warmmail.com	San Francisco	California	3112767111998102246	8f58c493f29492acd2edcee1fd825cbc	VISA 16 digit	37.8087760619991471	-122.449785085187315
28665	2020-06-03 16:22:12	2020-06-03	Tamera Ledner	tamera.ledner@warmmail.com	Indianapolis	Indiana	4493663897368	5cd71a8ab29ccbb4f487dc4ae5822116	JCB 16 digit	39.8237638471189896	-86.0769205111280087
28666	2020-06-03 16:22:55	2020-06-03	Corie Gorczany-Ward	corie.gorczany.ward@woohoo.com	Chesapeake	Virginia	3088704808997528828	9985fa43df1fbb915329c6012115e2a5	Discover	36.7275757565401477	-76.2916758519440918
28667	2020-06-03 16:25:35	2020-06-03	Sandy Schaden	sandy.schaden@geemail.com	San Diego	California	869982454743328767	1041291799af3e721cd93f4c3c1b4aa1	Mastercard	32.7542905533287652	-117.134787675309937
28668	2020-06-03 16:26:40	2020-06-03	Dr. Mike Steuber DVM	dr.mike.steuber.dvm@geemail.com	San Francisco	California	180070689487520020	fb0e93e1548db654c488b21cc470a5a5	Maestro	37.7764830850410362	-122.45630141893335
28669	2020-06-03 16:31:09	2020-06-03	Ms. Adriene Gorczany	ms.adriene.gorczany@warmmail.com	Las Vegas	Nevada	3158093298280503739	53d7ff2a746eb008f5407fb5aff520d5	American Express	36.2288842659078512	-115.314774181435254
28670	2020-06-03 16:48:47	2020-06-03	Starr Robel	starr.robel@warmmail.com	New York	New York	3528728111918598091	df71c73654b11d98d0e345857e9db9a1	Maestro	40.6649920105692004	-73.927861620847878
28671	2020-06-03 17:01:38	2020-06-03	Malorie Boyle	malorie.boyle@geemail.com	Brownsville	Texas	3050843575843084	aedfb27e5121de03112adc58706208eb	JCB 16 digit	25.9738000712901353	-97.4457979213166965
28672	2020-06-03 17:10:12	2020-06-03	Oneta Macejkovic	oneta.macejkovic@geemail.com	San Bernardino	California	210043407174432118	6378ae8e6019a2f1f2e02908cf3f60d7	VISA 13 digit	34.1135752097036686	-117.252662433848158
28673	2020-06-03 17:10:48	2020-06-03	Violet Yundt	violet.yundt@warmmail.com	Dallas	Texas	4171668723652258	78f5658d84a314aefe243ab63e3738d1	American Express	32.8400697032261633	-96.6873837094251058
28674	2020-06-03 17:11:13	2020-06-03	Genevieve Leuschke	genevieve.leuschke@geemail.com	Indianapolis	Indiana	501864434353963	65d21affa9767ed5375ffd6272832e2c	VISA 13 digit	39.7356186306111496	-86.0531592607699309
28675	2020-06-03 17:12:28	2020-06-03	Dock Cassin	dock.cassin@woohoo.com	Las Vegas	Nevada	180050840276025846	16b74753a0381262c3ff0b27cffe7408	JCB 16 digit	36.1838064541209476	-115.235016009604919
28676	2020-06-03 17:28:49	2020-06-03	Tobin Schneider	tobin.schneider@warmmail.com	Olathe	Kansas	4839861980046876	0c951168b61c31b074c5d2d09e5daf2c	JCB 16 digit	38.8614102142520252	-94.9137038041073851
28677	2020-06-03 17:29:41	2020-06-03	Brittney Metz	brittney.metz@geemail.com	Indianapolis	Indiana	54541038761967195	8b29f8c77d9f79c12f8096e9c512902e	Voyager	39.8094224253211166	-86.1881011139802666
28678	2020-06-03 17:31:39	2020-06-03	Ethyl Orn	ethyl.orn@geemail.com	Henderson	Nevada	4454051688336407	b723b5c77b7f78a34c36bee7ef62d308	Discover	36.0229995429448806	-115.061578933165222
28679	2020-06-03 17:38:16	2020-06-03	Coy Walter	coy.walter@geemail.com	Phoenix	Arizona	3528230180096037132	0a0e644ed5173846f875a56cc341a46d	Discover	33.6645747707623997	-112.082678877182687
28680	2020-06-03 17:42:29	2020-06-03	Miss Audie Doyle PhD	miss.audie.doyle.phd@geemail.com	Tampa	Florida	676309592545504	cded8198fd8ad583abc038f81e582a4d	Mastercard	27.9023865686845021	-82.4801482115618825
28681	2020-06-03 17:49:50	2020-06-03	Santos Schoen	santos.schoen@geemail.com	Meridian	Idaho	3733204988606603	a0fc60217ddddcb18e33e390abaea5a6	American Express	43.6749820416800674	-116.339972855703536
28682	2020-06-03 17:54:04	2020-06-03	Evelyne Cruickshank	evelyne.cruickshank@woohoo.com	McKinney	Texas	55179437289271586	8eafb016ae7e1349eef4e9891654a62e	VISA 13 digit	33.1684773249682081	-96.7614035054408106
28683	2020-06-03 17:59:09	2020-06-03	Grayson Gibson	grayson.gibson@geemail.com	Temecula	California	3337711671110661913	b0555c2eca7739f4323b87c6c4cbe257	VISA 16 digit	33.4022932931449219	-117.143579454599688
28684	2020-06-03 18:00:51	2020-06-03	Eliseo Hermann	eliseo.hermann@geemail.com	San Antonio	Texas	6011154881047325656	ac8cc02019e2f0787562df92ea9b546b	Diners Club / Carte Blanche	29.5066857482843119	-98.4630716326482514
28685	2020-06-03 18:01:44	2020-06-03	Tommy Turner DDS	tommy.turner.dds@warmmail.com	Albuquerque	New Mexico	210073415432671339	e8f835bda8b8117b36ef502ec3b99a90	VISA 16 digit	35.0505337187688824	-106.654277226987858
28686	2020-06-03 18:29:46	2020-06-03	Andres Kemmer	andres.kemmer@geemail.com	San Antonio	Texas	6011020784384091299	3f6bffa3c939d052c205733bbe107ac8	Voyager	29.5030198826991032	-98.5572926167234726
28687	2020-06-03 18:52:37	2020-06-03	Dr. Ferrell O'Keefe III	dr.ferrell.o'keefe.iii@geemail.com	Philadelphia	Pennsylvania	3337402088512702357	72d342bc3832196c4572a4b0343c1c78	American Express	39.9640414131764317	-75.1100178695648992
28688	2020-06-03 19:05:05	2020-06-03	Acie Auer	acie.auer@geemail.com	Spokane	Washington	6011053545767371065	5ca8e15b8a3f1e70c21d090dda2ebaf3	Discover	47.6566490371949953	-117.529567712861308
28689	2020-06-03 19:18:25	2020-06-03	Cyndi Hane	cyndi.hane@warmmail.com	Wichita	Kansas	3030001010017695	86e34506b0cce161e40bb125500e0097	VISA 16 digit	37.7031652847182031	-97.3052048671260508
28690	2020-06-03 19:20:39	2020-06-03	Aryana Windler-Pagac	aryana.windler.pagac@geemail.com	Philadelphia	Pennsylvania	3038358127911836	32716ae158966e5a61627331c7543604	VISA 16 digit	40.0795848205644631	-75.2185757897693748
28691	2020-06-03 19:28:42	2020-06-03	Etha D'Amore	etha.d'amore@geemail.com	San Diego	California	210016115044855862	e2985548dee8b08584c2bb56d39378aa	American Express	32.769414466533064	-117.112812212426221
28692	2020-06-03 19:29:35	2020-06-03	Hung Bayer	hung.bayer@warmmail.com	Columbus	Ohio	3158688182687773262	ccd8cadfa29d4f3b0b830cdd7fb4afd2	Voyager	40.0186775533992787	-82.9302293992836042
28693	2020-06-03 19:37:46	2020-06-03	Dr. Arlin Wintheiser PhD	dr.arlin.wintheiser.phd@geemail.com	Oklahoma City	Oklahoma	53585083489272848	1c6ee5d800577bd3f2dee3f5ff251b22	JCB 16 digit	35.5443777240723406	-97.4923735718138573
28694	2020-06-03 19:47:09	2020-06-03	Ms. Pauline Russel DVM	ms.pauline.russel.dvm@geemail.com	New York	New York	210075105883064864	847aa44369fa788f3b047cf458906097	Voyager	40.6503364620488128	-73.9700152518588965
28695	2020-06-03 19:56:26	2020-06-03	Margarette Greenfelder	margarette.greenfelder@woohoo.com	San Diego	California	54295320874266535	a54c3fa42d33871897d6fe4a5d833603	Diners Club / Carte Blanche	32.8636826357405667	-117.103316269945353
28696	2020-06-03 19:58:37	2020-06-03	Mr. Durwood Farrell DVM	mr.durwood.farrell.dvm@warmmail.com	Oceanside	California	869979040262225313	47c62d33c82edc7902866129256d1f4c	VISA 13 digit	33.2907542745470977	-117.337211167913679
28697	2020-06-03 20:04:43	2020-06-03	Estella Marks	estella.marks@geemail.com	Oklahoma City	Oklahoma	53347213300945996	1c6aec8178dd40253d0056896129a9c8	American Express	35.3922242206897621	-97.5289473161462723
28698	2020-06-03 20:13:45	2020-06-03	Kamron Armstrong	kamron.armstrong@geemail.com	Norfolk	Virginia	3528874428691992016	b2c3b6a1165834b347ffdbc314d274dd	VISA 16 digit	36.8918458250369881	-76.2113636557016605
28699	2020-06-03 20:15:34	2020-06-03	Dayton Wuckert	dayton.wuckert@geemail.com	Dallas	Texas	675920340304656	a49411aae57e1b46ab84f6ac2837942f	American Express	32.7293849592369099	-96.8384923786818916
28700	2020-06-03 20:15:58	2020-06-03	Channing Huels	channing.huels@geemail.com	Lewisville	Texas	3479123409860190	bffaf863d6be4ea8b127156208e8c798	JCB 16 digit	33.0298760907243931	-97.0132004444982954
28701	2020-06-03 20:27:53	2020-06-03	Eris Reynolds-Schuppe	eris.reynolds.schuppe@woohoo.com	San Francisco	California	4399680931272	3501d6b4ee1a99dec57f6263af7dd55d	VISA 16 digit	37.7764084273669525	-122.404796116591314
28702	2020-06-03 20:33:30	2020-06-03	Azul Predovic-Corkery	azul.predovic.corkery@geemail.com	Knoxville	Tennessee	503842201447879	0f932ac4fb169b158e7e0dc85010daec	VISA 16 digit	35.913861065783351	-83.8815688905056476
28703	2020-06-03 20:34:08	2020-06-03	Mr. Erasmus Hickle MD	mr.erasmus.hickle.md@geemail.com	Dallas	Texas	3713621451621393	c68ab67c680c015cf525a8324193eded	VISA 13 digit	32.8103309599023305	-96.6799155638981489
28704	2020-06-03 20:35:48	2020-06-03	Hillary Hammes	hillary.hammes@geemail.com	Lexington	Kentucky	3158973481532798969	e2a1061a311be8580f9dda838f4e3b43	JCB 16 digit	38.0024344362195592	-84.4867069351851825
28705	2020-06-03 20:54:23	2020-06-03	Daunte Barrows	daunte.barrows@geemail.com	San Francisco	California	6011575166275355372	99879c9f5582d0affdc3fc15704c6ce4	JCB 16 digit	37.7368660701809944	-122.414493126940457
28706	2020-06-03 21:00:18	2020-06-03	Werner Romaguera	werner.romaguera@geemail.com	Toledo	Ohio	3528816503464662698	5bd79034108dc982e1fb09ee6e33b8c3	Maestro	41.6732244088020138	-83.611366536734252
28707	2020-06-03 21:01:24	2020-06-03	Mr. Schley Wisozk	mr.schley.wisozk@geemail.com	Daly City	California	3003597489738387	5130eed4ca8868f3773d4bd9304eed8b	Diners Club / Carte Blanche	37.6648668602962005	-122.409334060559047
28708	2020-06-03 21:24:27	2020-06-03	Dr. Amin Abernathy	dr.amin.abernathy@geemail.com	West Jordan	Utah	3158151107284608270	ea241543c5c09f7fd99a99405d862dba	Voyager	40.5654297209136203	-111.999365754760049
28709	2020-06-03 21:27:32	2020-06-03	Beatriz Brown	beatriz.brown@warmmail.com	Salinas	California	589319516598174	3aec7c18245a53f7aec6bef99b7aee2b	American Express	36.6762139082185925	-121.594146272604178
28710	2020-06-03 21:35:40	2020-06-03	Lacie Auer	lacie.auer@geemail.com	Tulsa	Oklahoma	4142569414188	40f73b6213fca97fd318b401041dd966	VISA 13 digit	36.176961771528795	-95.9461405229710067
28711	2020-06-03 21:36:51	2020-06-03	Caydence Hettinger	caydence.hettinger@geemail.com	Chicago	Illinois	3112715488941759295	aeed53916dd83a51168819608000f386	JCB 16 digit	41.7729817195631554	-87.650809194243692
28712	2020-06-03 21:40:20	2020-06-03	Mrs. Kasey Terry	mrs.kasey.terry@geemail.com	San Francisco	California	3041628276581870	d3067c32dbf730566990799103603260	JCB 16 digit	37.7594566171756298	-122.424227953724696
28713	2020-06-03 22:00:24	2020-06-03	Miss Arvilla Swaniawski PhD	miss.arvilla.swaniawski.phd@warmmail.com	Plano	Texas	4609222791375848	9c4bb841ab653c8d1f533e2c172786a3	JCB 15 digit	33.0181791870940486	-96.7786477844879016
28714	2020-06-03 22:03:24	2020-06-03	Jon Daniel	jon.daniel@geemail.com	Garden Grove	California	3055793760562137	c60a996c135a137879eafaaeb14aca94	VISA 16 digit	33.8679277556307596	-117.993333760185166
28715	2020-06-03 22:09:59	2020-06-03	Stephani Gaylord	stephani.gaylord@geemail.com	New York	New York	4325261805591068	79618a8120ea491258040230fefc2f25	Mastercard	40.7500290421992517	-73.8531237491302193
28716	2020-06-03 22:18:19	2020-06-03	Sammie Goodwin	sammie.goodwin@warmmail.com	Miramar	Florida	503859023399435	b4ebc42c04f9ce4fcf187ca3d8920a6d	JCB 15 digit	25.9290357506815354	-80.3089876844074695
28717	2020-06-03 22:30:43	2020-06-03	Mohammad Osinski DDS	mohammad.osinski.dds@geemail.com	Boston	Massachusetts	210045720968623678	2298325987bb3c497876c32df294030c	VISA 16 digit	42.2776740760244465	-70.9740204910233672
28718	2020-06-03 22:37:52	2020-06-03	Mrs. Vira Stokes DVM	mrs.vira.stokes.dvm@geemail.com	Bridgeport	Connecticut	4069072351899338	d1ff5dc87501df9fb6290c663410cd44	VISA 16 digit	41.2723443473387448	-73.2733378342252308
28719	2020-06-03 22:39:37	2020-06-03	Mrs. Karlie Lemke	mrs.karlie.lemke@geemail.com	Pasadena	Texas	6011579163605402236	404c777257cce485a309b9c90d461f17	JCB 16 digit	29.677607166475056	-95.1527253216080311
28720	2020-06-03 22:41:16	2020-06-03	Jeffery Pagac	jeffery.pagac@geemail.com	Detroit	Michigan	869918149143255946	464968f77f0e9934a9562d982b098205	Discover	42.3417079820688826	-83.005174120061838
28721	2020-06-03 22:50:44	2020-06-03	Esteban Bailey-Langworth	esteban.bailey.langworth@geemail.com	Thornton	Colorado	3010635230525076	35271e79c51833be65a96843f5451dd8	American Express	39.8712664945848303	-105.036241415298733
28722	2020-06-03 22:55:21	2020-06-03	Miss Leana Stiedemann	miss.leana.stiedemann@woohoo.com	Wichita	Kansas	630445946916074	84be59e067a4a243724199be7f45e923	Discover	37.6340524972759169	-97.3206537302318964
28723	2020-06-03 22:58:20	2020-06-03	Mr. Leroy Kunze MD	mr.leroy.kunze.md@geemail.com	Austin	Texas	869964784888774462	aaa1afd35c1c4211c609e36d1cc87016	American Express	30.2409889845769833	-97.823265598086266
28724	2020-06-03 22:58:35	2020-06-03	Eusebio Emmerich	eusebio.emmerich@geemail.com	San Diego	California	3019426055000432	829e4f10dbc7dac51b4075f468e7bb22	VISA 16 digit	32.8869090049129014	-117.082046110127123
28725	2020-06-03 23:01:05	2020-06-03	Mr. Jesus Kautzer	mr.jesus.kautzer@warmmail.com	Richmond	Virginia	3003427569276399	c8766c9854a584f59d3cc89d574b589f	Maestro	37.6142211289364852	-77.4539920460656219
28726	2020-06-03 23:02:36	2020-06-03	Lindsey Stracke	lindsey.stracke@woohoo.com	New York	New York	52045155886718393	5a518e7cef814c715a1ad63a64226752	JCB 16 digit	40.7517501984946406	-73.9175147599901976
28727	2020-06-03 23:05:45	2020-06-03	Paisley Senger	paisley.senger@geemail.com	Houston	Texas	3088533110747368747	8020a2f0dbee514b272467f5b38c9e06	JCB 16 digit	29.7229282527774572	-95.4702600042350582
28728	2020-06-03 23:24:10	2020-06-03	Lige Homenick-Grant	lige.homenick.grant@geemail.com	New York	New York	4987021285869171	d34d474a1757d05275e852f6ecaa4eba	VISA 13 digit	40.6665297120101741	-73.9363132543757473
28729	2020-06-03 23:37:15	2020-06-03	Chadwick Strosin-Mosciski	chadwick.strosin.mosciski@geemail.com	Richmond	Virginia	53293340461668259	9e5a0275df3e7e5affe48a4d67f017f5	VISA 16 digit	37.5296289052102665	-77.5499228610880635
28730	2020-06-03 23:38:49	2020-06-03	Arthor Smith	arthor.smith@geemail.com	Houston	Texas	52291621674900015	2fa00c308bc83b930fe6d1c72896874b	VISA 16 digit	29.7894570736292756	-95.3733362174142201
28731	2020-06-03 23:40:02	2020-06-03	Bettie Stroman	bettie.stroman@woohoo.com	Akron	Ohio	210014626504589454	29980ab3762bcd1a56c6bf6696cd32bf	Diners Club / Carte Blanche	41.1449617274403607	-81.5316175811771302
28732	2020-06-03 23:43:30	2020-06-03	Lenny Von	lenny.von@geemail.com	Jacksonville	Florida	4317651386570384	b450a46c06e7287dcc405e669aa01304	JCB 16 digit	30.3226140436302884	-81.5840989878013829
28733	2020-06-03 23:44:32	2020-06-03	Concha Johns	concha.johns@warmmail.com	San Francisco	California	6011353458797222950	ac27cdb91b32332581257649753bccea	Mastercard	37.7942883854776284	-122.436539095122257
28734	2020-06-04 00:14:28	2020-06-04	Scottie Lesch III	scottie.lesch.iii@geemail.com	Chicago	Illinois	3445577436053775	8764d3886c163e3353594a213adb8853	VISA 13 digit	41.8049174561001351	-87.6154710940580799
28735	2020-06-04 00:19:02	2020-06-04	Darryn Daugherty III	darryn.daugherty.iii@warmmail.com	New York	New York	060408813805127	6e8607cce54ce94afecac3ffad709a0c	American Express	40.6377242987733354	-73.9088944444794151
28736	2020-06-04 00:20:40	2020-06-04	Dr. Belle Boehm MD	dr.belle.boehm.md@geemail.com	Baltimore	Maryland	51588762418926114	e4b507c63272106011e5969cb87b3489	Maestro	39.2524655767250792	-76.6663507455978532
28737	2020-06-04 00:20:54	2020-06-04	Derrick Collier	derrick.collier@geemail.com	Corpus Christi	Texas	3528293113462616902	48701c6013ea988f79863cb0f1d2075c	Mastercard	27.7706907252252115	-97.2137329949826068
28738	2020-06-04 00:27:17	2020-06-04	Dion Abernathy	dion.abernathy@geemail.com	Charlotte	North Carolina	869929892137894215	cd07525bc00f7975ed1fc3e199082528	VISA 13 digit	35.1559125550810236	-80.8672985723652005
28739	2020-06-04 00:30:03	2020-06-04	Dr. Jones Zieme DVM	dr.jones.zieme.dvm@geemail.com	Memphis	Tennessee	561298984241608	9dd16453eb04a2a8d1d41d98251fadaf	JCB 16 digit	35.1628491722580065	-90.0733060647990555
28740	2020-06-04 00:38:39	2020-06-04	Erland Bartell V	erland.bartell.v@geemail.com	Worcester	Massachusetts	3158007512227157176	2150df90ff35dfa0c76c231d47602228	JCB 16 digit	42.2418876529838911	-71.7806922396898273
28741	2020-06-04 00:45:06	2020-06-04	Ms. Mathilde Quigley	ms.mathilde.quigley@geemail.com	San Antonio	Texas	52634589358552772	c312cca460eb27c478389dcd77422a19	JCB 16 digit	29.5241763180658232	-98.4258969771511829
28742	2020-06-04 01:01:21	2020-06-04	Miss Alisha Nitzsche PhD	miss.alisha.nitzsche.phd@geemail.com	St. Louis	Missouri	4906563620008872	ac4012325e9de6bbd47216afe16562cc	Diners Club / Carte Blanche	38.6347070681553362	-90.1688697958368834
28743	2020-06-04 01:01:54	2020-06-04	Aimee Heidenreich-Dibbert	aimee.heidenreich.dibbert@geemail.com	Los Angeles	California	6011153916759128418	625bb72afa58fcc7bf0ddbc3164acbab	Voyager	34.0759129096619731	-118.457710989470769
28744	2020-06-04 01:03:28	2020-06-04	Brittnie Ullrich DDS	brittnie.ullrich.dds@woohoo.com	Beaumont	Texas	4339240805045493	9d78b9c142fa37aaf00d12f717307ef6	American Express	29.9896337779309619	-94.0894194433718951
28745	2020-06-04 01:28:55	2020-06-04	Lloyd Beier	lloyd.beier@warmmail.com	Lansing	Michigan	3408058800592883	4cca93b766b725cc231bb8b3092f2506	Maestro	42.6381223583903193	-84.486651907407861
28746	2020-06-04 01:31:57	2020-06-04	Burnell O'Connell-Koch	burnell.o'connell.koch@warmmail.com	Surprise	Arizona	869938441320861034	28c570f44e2e1e66e3253c2e77310202	VISA 13 digit	33.6637663352996128	-112.532466578366979
28747	2020-06-04 01:46:57	2020-06-04	Chastity Wilkinson MD	chastity.wilkinson.md@geemail.com	Boston	Massachusetts	6011295762582989579	b4c7b5557eac82b3e76dd84fffe3a236	JCB 16 digit	42.358652513304726	-70.9918240037698354
28748	2020-06-04 01:56:29	2020-06-04	Jaylene Schmitt	jaylene.schmitt@geemail.com	Fort Lauderdale	Florida	3795635158953140	9ee35d7d2632c8369c0b0d9f4d170b8e	JCB 16 digit	26.1976837760757668	-80.1579000081222404
28749	2020-06-04 02:00:51	2020-06-04	Fayette Boehm PhD	fayette.boehm.phd@geemail.com	Anaheim	California	3035541687519767	d06219c66746a46697bba92e8a23ba7a	Mastercard	33.7627765173390486	-117.743227486659208
28750	2020-06-04 02:12:54	2020-06-04	Alfonso McLaughlin	alfonso.mclaughlin@geemail.com	Chicago	Illinois	3033799630844953	b1467f0bd9bdc7802fc09e2db9ddd0d3	Maestro	41.7869074108846519	-87.7739845228876874
28751	2020-06-04 02:17:42	2020-06-04	Destin Murray	destin.murray@geemail.com	Des Moines	Iowa	3337832303940841879	29bb8e070282f166c9336a5fc96e4a86	VISA 13 digit	41.5194064065556958	-93.5924666001971843
28752	2020-06-04 02:24:30	2020-06-04	Ms. Zoie Harvey DDS	ms.zoie.harvey.dds@geemail.com	Oakland	California	3000759093014208	a13ccff1262dcd5682589d17e7ec70cc	VISA 16 digit	37.8044317501960379	-122.254338828797586
28753	2020-06-04 02:25:59	2020-06-04	Yuliana Cormier	yuliana.cormier@woohoo.com	Portland	Oregon	4544529624803210	00b8a0542b59af07b1ffb2abed9528f2	JCB 16 digit	45.4407576840724801	-122.573078491399073
28754	2020-06-04 02:31:23	2020-06-04	Mr. Calvin Hoppe IV	mr.calvin.hoppe.iv@geemail.com	Saint Paul	Minnesota	4556012092464109	44b40edb88093b7f22055428d05a62e1	Mastercard	44.8908365230482076	-93.0943795529458669
28755	2020-06-04 02:36:52	2020-06-04	Kendell Cruickshank II	kendell.cruickshank.ii@geemail.com	Escondido	California	53915715749143431	30f24f6c7eb254df5214b194107cfc7a	Maestro	33.1248409069836143	-117.136201318051661
28756	2020-06-04 02:40:41	2020-06-04	Reece Jacobi	reece.jacobi@geemail.com	Nashville	Tennessee	3034927045085974	2a06fdb3443876d19b7fade76c3cf71b	Maestro	36.0805663159240027	-86.7913243713229861
28757	2020-06-04 02:43:50	2020-06-04	Miss Lurana Schumm PhD	miss.lurana.schumm.phd@geemail.com	Ontario	California	3466902523061560	8b833caebf17db8e72be320a37b045b0	JCB 16 digit	34.1232872794061919	-117.513837835156181
28758	2020-06-04 02:58:38	2020-06-04	Dr. Kiana Gerhold DVM	dr.kiana.gerhold.dvm@geemail.com	Anchorage	Alaska	502092096121634	21d9aa0a6835aca9a40e959a9e59c95b	Diners Club / Carte Blanche	61.2483698666311795	-149.326051658311115
28759	2020-06-04 03:06:58	2020-06-04	Malorie Aufderhar	malorie.aufderhar@geemail.com	Philadelphia	Pennsylvania	3528833481058077848	d93b88963818cc14831aee4358bbf837	Diners Club / Carte Blanche	40.081526273624597	-75.0815264182530342
28760	2020-06-04 03:09:08	2020-06-04	Jaylan Gleichner	jaylan.gleichner@geemail.com	San Francisco	California	180033395989094706	d32f2cd70a4538f534c064df2d5c78fb	Diners Club / Carte Blanche	37.7557615965566882	-122.447897238250164
28761	2020-06-04 03:22:03	2020-06-04	Volney Aufderhar	volney.aufderhar@geemail.com	Austin	Texas	3481221326371923	36d29b4a2bbeb79537a80612a67b646d	VISA 16 digit	30.2865369699090721	-97.8528805928077645
28762	2020-06-04 03:25:10	2020-06-04	Ms. Selene Hoeger	ms.selene.hoeger@geemail.com	Richmond	Virginia	4449068167098686	8824dff6e1c8531a04892930099938fc	JCB 16 digit	37.5416993624284814	-77.3887981285098903
28763	2020-06-04 03:42:41	2020-06-04	Cayla Purdy DVM	cayla.purdy.dvm@geemail.com	Berkeley	California	53563181524431613	6ca6f43525f189083e530580eeb805b2	Diners Club / Carte Blanche	37.8213379758439956	-122.261272571599903
28764	2020-06-04 03:47:21	2020-06-04	Dr. Red Barton III	dr.red.barton.iii@warmmail.com	Wichita Falls	Texas	3013864699849325	5378e2cfd59e3e76757c66f02aff0825	Mastercard	33.8361148987159126	-98.4366535511720855
28765	2020-06-04 03:55:39	2020-06-04	Sheldon Nikolaus	sheldon.nikolaus@geemail.com	New York	New York	52793988721283965	2bf218485ce4f1f99e1bde31753c6fd6	Diners Club / Carte Blanche	40.7236027046330236	-73.8448136397998809
28766	2020-06-04 03:56:19	2020-06-04	Larissa Jenkins	larissa.jenkins@geemail.com	San Antonio	Texas	3158646105793657344	2186790b4c93a4cbb31cbee881f2c6d7	VISA 16 digit	29.541554331786557	-98.5261158492717897
28767	2020-06-04 04:00:30	2020-06-04	Ashton Corkery-Ullrich	ashton.corkery.ullrich@geemail.com	Long Beach	California	869924452218391816	13aa1700d5c7c378f67ccea86ba7aba4	JCB 16 digit	33.7807966722462325	-118.061605235391482
28768	2020-06-04 04:06:36	2020-06-04	Marisa Runte	marisa.runte@geemail.com	North Charleston	South Carolina	869921537041282548	60f3158e4424a73a09b36ee509b13d44	JCB 15 digit	32.9123175236091043	-80.1159329942986318
28769	2020-06-04 04:20:20	2020-06-04	Will Deckow	will.deckow@geemail.com	Reno	Nevada	180081293502231205	6bce150a49f510b7cbe6ad07cd04492d	American Express	39.6192312917284681	-119.806394373595353
28770	2020-06-04 04:21:51	2020-06-04	Chiquita Little DVM	chiquita.little.dvm@geemail.com	Orange	California	4208253593049	bf08cd1e18ed42e96bbd934f4dafb869	Mastercard	33.7910320483967652	-117.813616039288419
28771	2020-06-04 04:31:11	2020-06-04	Eliza Mitchell	eliza.mitchell@geemail.com	Pasadena	California	4401422293864675	2df016cbeb613397f1cca15ae1225947	American Express	34.1579821673076651	-118.21134908113666
28772	2020-06-04 04:56:00	2020-06-04	Missouri Ritchie	missouri.ritchie@woohoo.com	Salinas	California	6011301559405299562	63c4a3a8d0aa531a07630de7fe4eafb8	JCB 16 digit	36.6458736053898875	-121.618715823366131
28773	2020-06-04 05:00:34	2020-06-04	Mrs. Shyla Mitchell MD	mrs.shyla.mitchell.md@geemail.com	Anaheim	California	4137690849369743	a7f15feca9bd6f3999ea0b5905949c4f	Voyager	33.948135051067915	-117.844415402666101
28774	2020-06-04 05:02:53	2020-06-04	Caleb Wilderman	caleb.wilderman@woohoo.com	Chicago	Illinois	3088824666278900222	ac0b30e637f421948d81662673a044b9	Diners Club / Carte Blanche	41.7793849245015565	-87.6747858237970519
28775	2020-06-04 05:08:58	2020-06-04	Vinnie Gaylord	vinnie.gaylord@geemail.com	New York	New York	6011017627140091563	719144d7912ac136380c52f821d04490	Diners Club / Carte Blanche	40.7541191851012385	-73.9530920690286848
28776	2020-06-04 05:12:57	2020-06-04	Dudley Abshire	dudley.abshire@geemail.com	Houston	Texas	6011283587015135266	49aa9303f8a0341f8cf9ec6a06b37273	VISA 13 digit	29.7934763176444903	-95.3258138661753378
28777	2020-06-04 05:14:24	2020-06-04	Denese Brakus	denese.brakus@geemail.com	San Francisco	California	4784113520837777	c478a6c11f94d9613aac1bdf124e3a36	VISA 16 digit	37.7373589176088373	-122.441151917469469
28778	2020-06-04 05:28:01	2020-06-04	Dejon Huel III	dejon.huel.iii@geemail.com	Denver	Colorado	3088294257080507818	1d63bb2f2c0e53f126098d6d37e8bd67	JCB 15 digit	39.7432604601658852	-104.787905535312746
28779	2020-06-04 05:40:35	2020-06-04	Iliana Ferry-Marks	iliana.ferry.marks@geemail.com	Modesto	California	869952587852233512	b2aa25fad2de47928a3813bedf53dce0	Maestro	37.6636954173445702	-121.038299635212866
28780	2020-06-04 05:45:41	2020-06-04	Leann Gleichner	leann.gleichner@woohoo.com	Lakewood	Colorado	4080074204751604	1aa2970de67a47e2164e116b983ccb93	JCB 15 digit	39.7259111410412942	-105.096077854141967
28781	2020-06-04 05:48:16	2020-06-04	Dicie Leuschke	dicie.leuschke@geemail.com	Milwaukee	Wisconsin	180071724934037580	f9b392a9667a6688389727ea791bd7cc	Voyager	42.9649461594961579	-87.9557591873787317
28782	2020-06-04 05:51:40	2020-06-04	Tamika Glover	tamika.glover@geemail.com	Saint Paul	Minnesota	210066791588099965	6a582f92aa3fd253bdf93bd17df811fd	Mastercard	44.8522672455232581	-93.1824641660120392
28783	2020-06-04 05:52:25	2020-06-04	Dr. Marchello Okuneva	dr.marchello.okuneva@geemail.com	San Francisco	California	3468443314602500	73db1e630f52709ae3b1db74bce11933	JCB 16 digit	37.7847934012227	-122.427380868338219
28784	2020-06-04 05:53:22	2020-06-04	Kelsi Torp	kelsi.torp@geemail.com	Hayward	California	3337004891900905751	2e4b5dabfbb6442605c93d08000bf4dd	JCB 16 digit	37.5650058879040216	-122.186617328019437
28785	2020-06-04 06:07:53	2020-06-04	Demarco Rodriguez	demarco.rodriguez@geemail.com	Hillsboro	Oregon	4885267422361837	b7416364d199ee28e18b46353abd1fd6	Diners Club / Carte Blanche	45.6230271849054816	-122.852950862903896
28786	2020-06-04 06:09:11	2020-06-04	Mr. Amare Wolf	mr.amare.wolf@geemail.com	Arlington	Texas	6011205386954451593	63fd87b063a244c581586b81fb5ac7cd	VISA 13 digit	32.6057188298337124	-97.0941159408099992
28787	2020-06-04 06:12:03	2020-06-04	Algot Conn	algot.conn@geemail.com	San Francisco	California	4619744351211	57f4f1da25822db4029b3cb2bff01714	JCB 16 digit	37.7967863242128388	-122.427690898830676
28788	2020-06-04 06:27:05	2020-06-04	Ms. Lakisha Murray MD	ms.lakisha.murray.md@geemail.com	Louisville	Kentucky	210052561597068046	31f25438c530690e0a304bfcf984160c	VISA 16 digit	38.205097707025331	-85.6430901705358281
28789	2020-06-04 06:31:50	2020-06-04	Nathalia Adams	nathalia.adams@geemail.com	Sandy Springs	Georgia	3088477611738605409	09d8d64d1d2e2f67820204ea31dd0e4e	VISA 16 digit	33.9765805167201904	-84.2773797152180322
28790	2020-06-04 06:50:42	2020-06-04	Mrs. Lockie Feest	mrs.lockie.feest@warmmail.com	Newark	New Jersey	869962001920294694	f286d9f9e7ce2ffee7a05f1b305a972c	JCB 16 digit	40.6425364635333466	-74.2585320781659419
28791	2020-06-04 07:02:01	2020-06-04	Dianna Olson	dianna.olson@geemail.com	Oklahoma City	Oklahoma	502086683022718	1098d33c2e0decfe8d7d9742c8d30ab9	Mastercard	35.4638585089150808	-97.4384571590356501
28792	2020-06-04 07:03:51	2020-06-04	Landyn Smitham	landyn.smitham@woohoo.com	Washington	District of Columbia	561236209888126	5617295684c5ddae9b3a6b6a826d8f7e	Diners Club / Carte Blanche	38.8849543301187452	-77.058040572165325
28793	2020-06-04 07:05:04	2020-06-04	Dilan Hoppe	dilan.hoppe@geemail.com	Las Vegas	Nevada	869953069844007162	4f540221a21d6a4fec36e046ccae5ceb	Voyager	36.1316001780431719	-115.347035335816813
28794	2020-06-04 07:06:19	2020-06-04	Mr. Winifred Flatley	mr.winifred.flatley@geemail.com	Providence	Rhode Island	3337084563560831568	641afe59688102f9a34393789fb918b0	Voyager	41.7359741442225811	-71.3555096349597022
28795	2020-06-04 07:26:23	2020-06-04	Ms. Giselle Ritchie	ms.giselle.ritchie@geemail.com	San Francisco	California	6011130063514732743	98a33e20a1ba0cecbb93cb9db676c49d	VISA 13 digit	37.7970547215215333	-122.438299855794043
28796	2020-06-04 07:28:31	2020-06-04	Marianita Dach	marianita.dach@warmmail.com	Minneapolis	Minnesota	3112208530962306524	b44db4e265e1d7089fc6612c01f3efd8	Discover	44.9126550091981827	-93.3380158111724967
28797	2020-06-04 07:29:32	2020-06-04	Ms. Davina Witting	ms.davina.witting@geemail.com	Stockton	California	3112121635090159655	ab1c8c1ce84c1945724a03c7d4b953a4	Voyager	37.9010594536282142	-121.334058562907572
28798	2020-06-04 07:32:08	2020-06-04	Miss Earline Bernier PhD	miss.earline.bernier.phd@geemail.com	Albuquerque	New Mexico	54048668895376612	b06b96aeedb7d58221a10d1db222582b	VISA 13 digit	35.0789823067974353	-106.666943741364037
28799	2020-06-04 07:54:12	2020-06-04	Ms. Martine Hoppe	ms.martine.hoppe@woohoo.com	Tallahassee	Florida	54626560921049125	a8f9003321b80c5f43a6f47887f66156	Discover	30.3858830222416678	-84.2922045121915602
28800	2020-06-04 07:54:53	2020-06-04	Dr. Herb Roberts V	dr.herb.roberts.v@woohoo.com	Round Rock	Texas	3337764430463609300	5ddb68359da5da37bfa9bfe080f32dc4	JCB 16 digit	30.5811209484141351	-97.6862741857618033
28801	2020-06-04 07:58:24	2020-06-04	Roswell Kirlin	roswell.kirlin@warmmail.com	Salt Lake City	Utah	3528920844436673204	8a0c0b811c68b60903ef9fcce95e810b	VISA 13 digit	40.6963055711850501	-111.863999378163371
28802	2020-06-04 08:00:33	2020-06-04	Mr. Fletcher Tremblay Jr.	mr.fletcher.tremblay.jr.@geemail.com	Chandler	Arizona	4561872469104270	df52fc6bc4479a41027d2a0fc342525a	JCB 15 digit	33.2419070351492607	-111.847435682907332
28803	2020-06-04 08:11:49	2020-06-04	Clarice Raynor	clarice.raynor@woohoo.com	Atlanta	Georgia	210019630230269147	ff545faaef1814496734c64fef3ee539	Mastercard	33.6938232353698481	-84.4307044265836595
28804	2020-06-04 08:14:38	2020-06-04	Mireya Collier	mireya.collier@geemail.com	Dallas	Texas	3026259900886157	e8c4592e6bd7c0af0cd4fcfe936d301b	VISA 16 digit	32.798056706254556	-96.7943384701814438
28805	2020-06-04 08:19:34	2020-06-04	Ruie Zboncak DVM	ruie.zboncak.dvm@woohoo.com	North Charleston	South Carolina	4659501331469	1ed05d2dfdd1cb65f12d0d2be68730d8	VISA 16 digit	32.90023041583337	-80.0282158814929403
28806	2020-06-04 08:24:30	2020-06-04	Epifanio Purdy	epifanio.purdy@geemail.com	Boston	Massachusetts	3528569319596802873	124e8b62869d25956d786d984c0f0cb2	Voyager	42.2893789274785661	-70.9735696430269627
28807	2020-06-04 08:35:51	2020-06-04	Kelton Glover	kelton.glover@geemail.com	Lexington	Kentucky	180022682169994976	a0091a15a0e7570221c9ab2ad46762ad	VISA 16 digit	38.1200191400356587	-84.4531621897492499
28808	2020-06-04 08:37:33	2020-06-04	Mrs. Aylin Will	mrs.aylin.will@geemail.com	Green Bay	Wisconsin	54724548670892622	f0788529b301d5fe982ae3efa72999ea	Diners Club / Carte Blanche	44.5480137617390568	-88.0102324655100716
28809	2020-06-04 08:47:33	2020-06-04	Jaidyn Dicki	jaidyn.dicki@geemail.com	Frisco	Texas	6011020073930954402	1a397d77a2e4ff467455f241459f4dc8	JCB 15 digit	33.1773598334748314	-96.8314972131256013
28810	2020-06-04 09:31:20	2020-06-04	Mr. Tavion Franecki III	mr.tavion.franecki.iii@geemail.com	New York	New York	4520129447153139	be72b53cdd3ba921e48154329db2fcca	Diners Club / Carte Blanche	40.6089100445844196	-74.0355752458225851
28811	2020-06-04 09:36:01	2020-06-04	Noel Purdy	noel.purdy@warmmail.com	Dallas	Texas	6011055295188110738	c793b9a7510c7f20316fadfcc666237c	VISA 16 digit	32.7734013862714164	-96.7112294897399778
28812	2020-06-04 09:39:01	2020-06-04	Ms. Anjelica Beahan DDS	ms.anjelica.beahan.dds@geemail.com	San Mateo	California	3088384565746770062	620cb9b546fe914d0176a356bc12b959	JCB 16 digit	37.5841108504097861	-122.321468783947068
28813	2020-06-04 09:40:32	2020-06-04	Mrs. Celie Davis	mrs.celie.davis@geemail.com	Tulsa	Oklahoma	3096886477513070838	7089d7aae206a0a77c6ab64333bf54c3	VISA 16 digit	36.1993599433820634	-95.8330604399044006
28814	2020-06-04 09:41:51	2020-06-04	Ocie Durgan	ocie.durgan@geemail.com	New York	New York	4824143592940	1d5f7e96951a57cb9c65d3fbad7323a0	VISA 13 digit	40.6093319952711482	-73.9356814698677454
28815	2020-06-04 09:49:21	2020-06-04	Lavina Bins	lavina.bins@woohoo.com	Los Angeles	California	3112174238212866590	7a8e799aeb4a5060c5659cde9222572e	JCB 16 digit	34.1035003747656944	-118.507826421269399
28816	2020-06-04 10:16:12	2020-06-04	Laverne Dach	laverne.dach@geemail.com	Corpus Christi	Texas	869994859130310481	fe3c2b15610740d5863a43c515f06a7d	Discover	27.6741524239473051	-97.18699910173342
28817	2020-06-04 10:20:47	2020-06-04	Saige Murazik	saige.murazik@geemail.com	Des Moines	Iowa	180051226906934574	bab5aab0872e75733da9a5af32c14c2c	American Express	41.5456059480760231	-93.5936349614568144
28818	2020-06-04 10:31:37	2020-06-04	Erin Kuphal	erin.kuphal@geemail.com	Pompano Beach	Florida	3096404071455594112	d0c4dc7bb16ffee29623a52a3ba00975	Voyager	26.3110345626514395	-80.0397156536891998
28819	2020-06-04 10:36:31	2020-06-04	Dr. Lea Erdman	dr.lea.erdman@woohoo.com	Miami	Florida	210028876484432704	dc29d6d1fc0ed9e2a5a4a81fb913a94c	JCB 16 digit	25.7883570036057392	-80.2713583671361306
28820	2020-06-04 10:43:08	2020-06-04	Alyson Beier	alyson.beier@geemail.com	San Francisco	California	4506069603632567	3090b697828df063eab88f0892425197	Maestro	37.7931993636502597	-122.376473994314395
28821	2020-06-04 10:56:49	2020-06-04	Ms. Lynsey Runolfsdottir MD	ms.lynsey.runolfsdottir.md@geemail.com	Phoenix	Arizona	6011675034962761345	740092ae03e8f0aa1e0ca0aac49ada59	Maestro	33.5992351025275937	-112.132838783825193
28822	2020-06-04 11:02:30	2020-06-04	Dr. Raekwon Quitzon	dr.raekwon.quitzon@warmmail.com	Los Angeles	California	3037197841810549	22b0da0b302ddd7cc78801a4c1e1d910	VISA 13 digit	33.9436231497075411	-118.418759334691984
28823	2020-06-04 11:07:04	2020-06-04	Izaiah Connelly	izaiah.connelly@warmmail.com	Riverside	California	55125568572849673	fa047a1a7131798cb911b7b6adecba8b	Maestro	33.9624360089603812	-117.396188634025677
28824	2020-06-04 11:07:26	2020-06-04	Miss Paulette Sanford	miss.paulette.sanford@warmmail.com	Berkeley	California	4022400432401012	f92a474e68f33cb20e8f2e5a4a75d6a8	VISA 16 digit	37.8742056074642335	-122.285675772198815
28825	2020-06-04 11:13:18	2020-06-04	Milas Ritchie MD	milas.ritchie.md@geemail.com	Chesapeake	Virginia	676394882537510	d4d070e24b76ad7469ebe062b3f716a1	VISA 16 digit	36.7708290357846792	-76.3090406457271371
28826	2020-06-04 11:13:21	2020-06-04	Claus Kerluke	claus.kerluke@geemail.com	Austin	Texas	4434263123118119	9403db5110aea6d3310c6e7a8f96d998	JCB 15 digit	30.2178565895777176	-97.6621074595261405
28827	2020-06-04 11:16:36	2020-06-04	Carlyle Bode	carlyle.bode@geemail.com	Berkeley	California	3003970601265003	721f3cdf407bff952d04695f877e92e9	VISA 16 digit	37.8938591534252041	-122.257436570786354
28828	2020-06-04 11:25:33	2020-06-04	Bridgett Brakus	bridgett.brakus@geemail.com	Irvine	California	210058131683473312	8bef0b36780e26c7a2f6cde3749d8030	VISA 13 digit	33.66622052812167	-117.676500122762462
28829	2020-06-04 11:29:02	2020-06-04	Yolanda Kshlerin	yolanda.kshlerin@geemail.com	Tacoma	Washington	3112092760948420599	7a4ea2ab05b12f5984c408e505915fee	Diners Club / Carte Blanche	47.2641745742995312	-122.554645509435986
28830	2020-06-04 11:30:17	2020-06-04	Orval Towne-Bayer	orval.towne.bayer@geemail.com	Los Angeles	California	52213062757543023	65fe527766979dd162d5443a465a9382	Voyager	33.9217920340929169	-118.490803794468931
28831	2020-06-04 11:30:40	2020-06-04	Miss Florence Zulauf DDS	miss.florence.zulauf.dds@woohoo.com	Fontana	California	4150082268221872	9712d40e84f97ac88dc5cf4b1537a9c8	Mastercard	34.1262218753024982	-117.479443859522789
28832	2020-06-04 11:35:34	2020-06-04	Dimitrios Graham	dimitrios.graham@warmmail.com	Sacramento	California	210068194435816228	a747ee9cf743908b75934f3a687e0f45	Diners Club / Carte Blanche	38.6107129893064496	-121.551414053446052
28833	2020-06-04 11:43:03	2020-06-04	Marcelina Maggio	marcelina.maggio@geemail.com	Los Angeles	California	3441608756520368	8165b51a3ad9143068a9f9a1e24c8e53	American Express	33.9899227597150926	-118.503512586931876
28834	2020-06-04 12:05:37	2020-06-04	Mrs. Tatia Schuppe DDS	mrs.tatia.schuppe.dds@geemail.com	New York	New York	3337912950503954516	a94283c7978ae54f3890f27dbced53db	Discover	40.7366785615440463	-73.9287975994765674
28835	2020-06-04 12:10:55	2020-06-04	Dr. Manford Wiegand I	dr.manford.wiegand.i@geemail.com	San Francisco	California	3053756744284419	5dcd3e67418347bc2f7ca60993bd3c2f	JCB 16 digit	37.7440973114938743	-122.415196317008181
28836	2020-06-04 12:17:45	2020-06-04	Hassan Kozey	hassan.kozey@warmmail.com	Athens	Georgia	53758274710537171	0f346d18b7097db6442a6f4f7b138c62	Voyager	34.0091540252514122	-83.4342914617270139
28837	2020-06-04 12:30:00	2020-06-04	Malik Bosco	malik.bosco@geemail.com	Kansas City	Missouri	3011640141850885	487085f71a6e639156fac622ad653d5c	Diners Club / Carte Blanche	39.1907788423191761	-94.561352941509341
28838	2020-06-04 12:32:55	2020-06-04	Ms. Junie Kerluke	ms.junie.kerluke@warmmail.com	Nashville	Tennessee	3528135577896016420	e2a3a21547a6f8ff989df771d22f8518	JCB 16 digit	36.0753989965777819	-86.7519580678455497
28839	2020-06-04 12:36:24	2020-06-04	Mrs. Missie Jast	mrs.missie.jast@woohoo.com	New York	New York	4168695715138025	0b34f177ee7363fa7014693ea372f382	Diners Club / Carte Blanche	40.6437234623115486	-73.9717645940732211
28840	2020-06-04 12:45:09	2020-06-04	Ana Roberts	ana.roberts@geemail.com	San Mateo	California	869944504418777024	8c7a8d68435b4bda51988b0cc644be23	American Express	37.4812905974566917	-122.381545899980139
28841	2020-06-04 12:49:01	2020-06-04	Alvin Gulgowski DDS	alvin.gulgowski.dds@woohoo.com	San Francisco	California	4624491451168188	22a6d0a7fdfa386a9a9a7a12d56ca9e1	VISA 16 digit	37.7843278578278401	-122.429483919589003
28842	2020-06-04 13:02:34	2020-06-04	Antionette O'Kon-Hauck	antionette.o'kon.hauck@geemail.com	Santa Ana	California	4095599625282	baa3731bd430a6071126dac9753a0b0d	JCB 16 digit	33.78803780913465	-117.871350946549327
28843	2020-06-04 13:12:43	2020-06-04	Gustie VonRueden	gustie.vonrueden@geemail.com	San Francisco	California	4099342181015	7873b2525d0eaa85836ad8e593b3cc91	VISA 16 digit	37.7283579598360816	-122.41986844205293
28844	2020-06-04 13:15:44	2020-06-04	Ora Pollich	ora.pollich@woohoo.com	Oakland	California	6011063749540357452	82f276a06553354f222717b58187f3f4	JCB 16 digit	37.7818670004481163	-122.297275543648155
28845	2020-06-04 13:23:21	2020-06-04	Philo Rohan-Blanda	philo.rohan.blanda@geemail.com	San Jose	California	4267054902204127	a090ecc712849c3eb5d0266d0cbfd3f4	VISA 16 digit	37.2470153628669678	-121.767245258273178
28846	2020-06-04 13:55:04	2020-06-04	Violetta Braun	violetta.braun@geemail.com	Reno	Nevada	4064484945817	57ba897bf56d7bcbadc1f4d6cb63b728	Voyager	39.5849031244482887	-119.913338237318769
28847	2020-06-04 13:58:09	2020-06-04	Rush Barrows	rush.barrows@geemail.com	Anaheim	California	210075334299005663	0b4dca38d23fd3c9a493c1dcdfb5f977	Diners Club / Carte Blanche	33.7864274221770486	-117.769729859821865
28848	2020-06-04 14:00:36	2020-06-04	Jaymes Schmeler	jaymes.schmeler@geemail.com	Phoenix	Arizona	4038709100754	7bbbb24bdbb7d1c88c11f0f930cf8a70	JCB 16 digit	33.6576359603021302	-112.174237441217912
28849	2020-06-04 14:16:12	2020-06-04	Dr. Gertie Kutch PhD	dr.gertie.kutch.phd@geemail.com	Houston	Texas	6011926899732036906	fb6c9156c4334ab832a393bfa363161e	JCB 16 digit	29.8240213850591331	-95.4699171066299073
28850	2020-06-04 14:25:02	2020-06-04	Stella Hoeger	stella.hoeger@geemail.com	San Francisco	California	4071208531211	956f843d0c3c58ce06976276591723cf	VISA 16 digit	37.791463851030521	-122.44656446248888
28851	2020-06-04 14:30:47	2020-06-04	Ximena Doyle-Schowalter	ximena.doyle.schowalter@geemail.com	Amarillo	Texas	180074122123359807	20e84130f0fbc21c0c27ec5c92a898dd	Discover	35.105655458353084	-101.768001372446122
28852	2020-06-04 14:39:12	2020-06-04	Gaetano Davis PhD	gaetano.davis.phd@warmmail.com	Dallas	Texas	210086899389247166	dc42c26083b66d886ce4b4f55ac5c6b2	VISA 13 digit	32.7383810506939881	-96.6977697176355804
28853	2020-06-04 14:39:42	2020-06-04	Cannie Yundt	cannie.yundt@geemail.com	Clovis	California	55213855935185231	3ae7b56610f88993a841008d4140fe79	Mastercard	36.7682845856405791	-119.679706658243759
28854	2020-06-04 14:40:58	2020-06-04	Jodi Welch	jodi.welch@warmmail.com	San Francisco	California	3337512883252863584	091a07a2740aa572e0afbc70389025f1	VISA 16 digit	37.797692272682994	-122.430615349518845
28855	2020-06-04 14:41:48	2020-06-04	Brodie Schneider	brodie.schneider@warmmail.com	Dallas	Texas	676377558314942	0e1d8018e049d5d574f9762b32c4b86a	VISA 16 digit	32.7566183177094956	-96.7624074104204652
28856	2020-06-04 14:54:51	2020-06-04	Nasir Ankunding	nasir.ankunding@geemail.com	El Paso	Texas	4536203807154	32a725b3deb603d9d48c7a8fd2db4738	VISA 13 digit	31.8169274309478709	-106.429377774892387
28857	2020-06-04 14:55:30	2020-06-04	Lurline Steuber	lurline.steuber@geemail.com	Nashville	Tennessee	3021367024932008	0292020782ca2d86f5b4c919f308a6e4	VISA 16 digit	36.2405719424255182	-86.8799301373679214
28858	2020-06-04 15:07:15	2020-06-04	Texie Weimann	texie.weimann@woohoo.com	San Francisco	California	210070693355827673	6519fc93b2e0efcc14b71611fae32c73	VISA 16 digit	37.7837810681505175	-122.433590388792055
28859	2020-06-04 15:12:35	2020-06-04	Cortez Muller	cortez.muller@geemail.com	Grand Rapids	Michigan	4858578056305277	b3e1cbc0d4dff929a38ca3320b213c9e	VISA 16 digit	43.0451071686845239	-85.7226546909794251
28860	2020-06-04 15:35:20	2020-06-04	Franco Raynor	franco.raynor@geemail.com	Salem	Oregon	4734360814881661	a613e0c306d7ce0ba9aebddac5af5fe1	JCB 15 digit	44.8561952671304311	-123.111330445778378
28861	2020-06-04 15:42:03	2020-06-04	Regis Hahn	regis.hahn@geemail.com	Centennial	Colorado	55389574610879178	875cd35c00e5c2e3bda5e0d711acdee0	JCB 16 digit	39.5528690938878853	-104.917423602741593
28862	2020-06-04 15:52:48	2020-06-04	Juluis Leffler-Wiegand	juluis.leffler.wiegand@geemail.com	New York	New York	4781779654685449	b9e6746545b06df97473a2c7a6f8ea12	Diners Club / Carte Blanche	40.595365521613509	-73.839390750870848
28863	2020-06-04 16:05:01	2020-06-04	Kortney Watsica	kortney.watsica@geemail.com	Abilene	Texas	210038699517288515	e1fb9fed58e337ab5923a71fac1e62bb	VISA 16 digit	32.387597443869339	-99.6470151202701118
28864	2020-06-04 16:22:22	2020-06-04	Mr. Kipp Hayes DVM	mr.kipp.hayes.dvm@geemail.com	Austin	Texas	630440179206954	cc04a3db50b93c28292c06d4b489be9b	Diners Club / Carte Blanche	30.3844296598933639	-97.6973406301584077
28865	2020-06-04 16:24:36	2020-06-04	Tiffany Mertz	tiffany.mertz@geemail.com	San Francisco	California	4612463931537	e0063bf850fabf101f33a17549ace258	JCB 15 digit	37.7718497007310816	-122.440632108561871
28866	2020-06-04 16:27:23	2020-06-04	Jaylee Beer	jaylee.beer@woohoo.com	Columbus	Ohio	4297125885129889	f6a54764c642df97b833180d9e28a818	VISA 16 digit	39.9773185154933444	-82.9907716221876512
28867	2020-06-04 16:35:34	2020-06-04	Bell Ryan	bell.ryan@geemail.com	Tuscaloosa	Alabama	4208908111890	57997b138972c1c881946a67a4a2769c	Voyager	33.155475362954661	-87.5424878621570741
28868	2020-06-04 16:40:04	2020-06-04	Tena Sawayn	tena.sawayn@geemail.com	Las Vegas	Nevada	4994558285596495	cbd92d780aec81511954a35f5b5099b7	Discover	36.1336961226172733	-115.294336618923012
28869	2020-06-04 16:42:14	2020-06-04	Jovan Will	jovan.will@geemail.com	Portland	Oregon	3042287503778186	2eb423c6bed98da3fefa3794e4b924cf	Diners Club / Carte Blanche	45.5411061072610295	-122.690742600802338
28870	2020-06-04 17:11:31	2020-06-04	Ms. Rayne Reinger MD	ms.rayne.reinger.md@geemail.com	Los Angeles	California	869965930569964877	2e7a5fdb7a9128a744476d501e968e53	Voyager	34.0882793644309032	-118.353932043536744
28871	2020-06-04 17:12:30	2020-06-04	Mr. Ah Cormier II	mr.ah.cormier.ii@warmmail.com	San Francisco	California	3158210066958023209	7f80c80b178fa4846bda70919739e432	VISA 13 digit	37.8120172263668977	-122.412220702544971
28872	2020-06-04 17:12:39	2020-06-04	Harman Huels-Kautzer	harman.huels.kautzer@geemail.com	Joliet	Illinois	180038327959833925	407482d44781bb6d03c233c782a29d3b	VISA 16 digit	41.4738751263216088	-88.0518085937119963
28873	2020-06-04 17:13:28	2020-06-04	Icy Kshlerin	icy.kshlerin@woohoo.com	Los Angeles	California	4235376486918916	7f1a6a25511b4a9e49a9836599afef54	JCB 16 digit	34.0083719035010787	-118.394921495671568
28874	2020-06-04 17:15:02	2020-06-04	Jeffry Harvey	jeffry.harvey@geemail.com	Tempe	Arizona	54603305040292603	76ef0bcb107c9f1d425b714a01e3f2b5	JCB 15 digit	33.4572336757011684	-111.856808249189697
28875	2020-06-04 17:24:22	2020-06-04	Myrl Moore	myrl.moore@geemail.com	Chandler	Arizona	3013708137236498	2d55b5368d4836823a7017182944f961	Discover	33.245522441072012	-111.755377322004733
28876	2020-06-04 17:24:34	2020-06-04	Sal Feest	sal.feest@geemail.com	San Francisco	California	3088925041924164201	15f980ff24c67e5375861e3cf1d5af4a	Discover	37.7653964930984785	-122.454146068500677
28958	2020-06-05 02:28:57	2020-06-05	Fabiola Kunde	fabiola.kunde@geemail.com	Little Rock	Arkansas	4588214791666818	65c8100865b94c8781daf9821925507f	Maestro	34.7110726134661576	-92.4583495107352746
28877	2020-06-04 17:25:52	2020-06-04	Roseann Halvorson-Turcotte	roseann.halvorson.turcotte@geemail.com	Chicago	Illinois	4422184617040102	20dae9ad006782ae634c3b8ab9e8adbb	VISA 16 digit	41.8198917387355138	-87.6990619098797453
28878	2020-06-04 17:26:05	2020-06-04	Gaynell Harber	gaynell.harber@geemail.com	Burbank	California	3088044033966039223	6eb8ee13fa3db60724aa3263f9bfc934	Maestro	34.1163654851190756	-118.390906537700076
28879	2020-06-04 17:28:41	2020-06-04	Marrion Vandervort	marrion.vandervort@warmmail.com	Huntsville	Alabama	6011091054330071280	4c018dff054abe17b646ce391bd096fc	Voyager	34.6073291588816758	-86.5820811589267123
28880	2020-06-04 17:57:22	2020-06-04	Phyllis Feest	phyllis.feest@geemail.com	Durham	North Carolina	180096567239632816	c4d2ae49791b1b0dfb298978a2d90d69	Diners Club / Carte Blanche	36.0573224789243199	-78.9836491483632557
28881	2020-06-04 18:03:39	2020-06-04	Dr. Glenda Pouros	dr.glenda.pouros@woohoo.com	Santa Clara	California	3528970614829255276	eafc9623cd8ecde61bf6bc24915b607b	VISA 13 digit	37.3339027382716537	-122.057578280660877
28882	2020-06-04 18:06:35	2020-06-04	Mr. Kristen Bartoletti MD	mr.kristen.bartoletti.md@geemail.com	Montgomery	Alabama	3780724733089468	cedfa73722e7bcb927f16bfc23b0e239	JCB 15 digit	32.3682134864784814	-86.3648189209088599
28883	2020-06-04 18:18:11	2020-06-04	Dagny Mills-Goldner	dagny.mills.goldner@warmmail.com	Boston	Massachusetts	869957616107649043	3f7ffd5c5541c1082605b6323adee815	Voyager	42.4085898599289379	-71.0893116498783257
28884	2020-06-04 18:20:57	2020-06-04	Marsh Rau Sr.	marsh.rau.sr.@geemail.com	San Francisco	California	3096076096859355072	98faa8929296566b49fb61de754337e8	Voyager	37.7758917851896214	-122.435742893874831
28885	2020-06-04 18:22:58	2020-06-04	Parley Haag	parley.haag@geemail.com	Grand Rapids	Michigan	51211699246163111	b876e01b2bbd2b93691a7383985c4741	American Express	42.8811817076325426	-85.7366775460209709
28886	2020-06-04 18:42:00	2020-06-04	Joana Mertz	joana.mertz@geemail.com	Oklahoma City	Oklahoma	4280868816248	9a2995303f9f68fa5f7df2d6473b5af4	JCB 15 digit	35.3846644031260169	-97.5176101717993618
28887	2020-06-04 18:57:04	2020-06-04	Bertrand Altenwerth-Kilback	bertrand.altenwerth.kilback@geemail.com	Berkeley	California	4224474578529916	e00ebeaa2161f3b81b7fa6d9f7143dfe	VISA 16 digit	37.8784897614192246	-122.23442278568595
28888	2020-06-04 19:05:55	2020-06-04	Bertrand Gulgowski	bertrand.gulgowski@geemail.com	Olathe	Kansas	3762425546317243	a0ac6b0d6b625dc468e2d6b49a111e9c	JCB 16 digit	38.9315010598052353	-94.8748027564194132
28889	2020-06-04 19:07:29	2020-06-04	Johnathon Kuphal	johnathon.kuphal@woohoo.com	Jacksonville	Florida	589362646130310	f005e552c068fa1addba460bd570bf80	JCB 16 digit	30.2836220233287676	-81.6794098397795238
28890	2020-06-04 19:10:56	2020-06-04	Dr. Cordell Konopelski DVM	dr.cordell.konopelski.dvm@warmmail.com	Chicago	Illinois	4032198210371088	d717b31ea20231d1d3459c298f55e9df	VISA 13 digit	41.8808266622316125	-87.6943379307195556
28891	2020-06-04 19:13:53	2020-06-04	Desi Johnston	desi.johnston@geemail.com	Indianapolis	Indiana	3017912352518889	db14690f902f2615587a72ee9bc35c10	JCB 16 digit	39.8726269029088272	-86.2089228609777933
28892	2020-06-04 19:30:09	2020-06-04	Leandra Welch	leandra.welch@geemail.com	Boston	Massachusetts	180086681748924515	1a3b308641e2238454c70ebbfba1d3f2	Diners Club / Carte Blanche	42.3860118747856447	-70.9682439482722458
28893	2020-06-04 19:51:25	2020-06-04	Xzavier Emard IV	xzavier.emard.iv@geemail.com	Pittsburgh	Pennsylvania	6011964224325951838	d97cd2d7558fc60aac679bdee48a1c15	VISA 13 digit	40.4848344951357646	-79.8801694897174883
28894	2020-06-04 19:54:39	2020-06-04	Tammi Gerhold	tammi.gerhold@geemail.com	Charlotte	North Carolina	4986286397711816	5e5de816ae9cbf858f8f21dcb845c20f	Voyager	35.2440131240311985	-80.9199810332562777
28895	2020-06-04 20:07:07	2020-06-04	Carlee Lockman	carlee.lockman@geemail.com	Berkeley	California	3158265975671894130	bf661c91e269378b839ff8d799239754	Mastercard	37.8794045524110459	-122.260770865377623
28896	2020-06-04 20:08:12	2020-06-04	Miss Jada Tromp DVM	miss.jada.tromp.dvm@geemail.com	Berkeley	California	3088848468905674763	0d22c3aff0f61a2ce484f5f803fe7431	Voyager	37.8772563715333064	-122.256537099418665
28897	2020-06-04 20:08:27	2020-06-04	Toshio Howell	toshio.howell@geemail.com	Philadelphia	Pennsylvania	4052470603483589	c00ec204ced0a6cee52bb9e6833d893a	Discover	40.074189310004563	-75.0913963679589358
28898	2020-06-04 20:09:05	2020-06-04	Yael Schoen-Hodkiewicz	yael.schoen.hodkiewicz@geemail.com	Philadelphia	Pennsylvania	503883929265755	25e6afe0d438d6f47541a91076f90ad7	JCB 16 digit	40.0910573703195894	-75.1157029517825805
28899	2020-06-04 20:10:23	2020-06-04	Jeremie Schuppe	jeremie.schuppe@geemail.com	Boston	Massachusetts	3528150673946773183	bc2bfd6aa78418d4bf4774fe61ce6582	VISA 16 digit	42.2554845932107455	-70.9389296232208579
28900	2020-06-04 20:21:37	2020-06-04	Ephram O'Conner	ephram.o'conner@geemail.com	New York	New York	4452023058613782	ce1cd73000f68833fb9b429f2f93a2ea	JCB 15 digit	40.6076402387339641	-73.9681527575373678
28901	2020-06-04 20:22:05	2020-06-04	Dr. Jovany Sporer Jr.	dr.jovany.sporer.jr.@woohoo.com	San Antonio	Texas	4759394270411234	5be58215d46764a3b5616e258bc3b8fa	JCB 15 digit	29.4837266308326278	-98.4689246482983123
28902	2020-06-04 20:23:18	2020-06-04	Rosario Boyer	rosario.boyer@geemail.com	Hillsboro	Oregon	54497936282221659	fe8dd0b0cf7273eae84168b9d0a4d33a	Diners Club / Carte Blanche	45.5683425061143907	-123.009876639085633
28903	2020-06-04 20:33:13	2020-06-04	Jayden Tillman	jayden.tillman@geemail.com	San Francisco	California	3719831488961100	4c9e11d9d2a0738af9b97c2a70482ab6	JCB 16 digit	37.8141391693006597	-122.443600462299855
28904	2020-06-04 20:36:44	2020-06-04	Broderick Parisian	broderick.parisian@geemail.com	Albuquerque	New Mexico	6011683217009575626	4549faee8df93b8643ec557d6770160a	Voyager	35.0370551960211287	-106.597683053331082
28905	2020-06-04 20:41:56	2020-06-04	Coralie Stoltenberg-Borer	coralie.stoltenberg.borer@geemail.com	San Jose	California	4555934242770	603d081e3c12bd7bec617a58c1bca26f	Maestro	37.3165992457240847	-121.844482945672794
28906	2020-06-04 20:45:47	2020-06-04	Odin Kertzmann	odin.kertzmann@geemail.com	Fort Worth	Texas	4170431510099	6f5757b34f9fae84ee0e24eb3d32caee	American Express	32.8136157526224892	-97.2539012720629614
28907	2020-06-04 21:06:15	2020-06-04	Leaner Hartmann	leaner.hartmann@geemail.com	Berkeley	California	4634532962193435	6315f5011ae3150b153aaa14d3f5a7b1	JCB 16 digit	37.8847535095866377	-122.280852317142632
28908	2020-06-04 21:08:49	2020-06-04	Ms. Brooklyn Quigley	ms.brooklyn.quigley@warmmail.com	San Diego	California	51692622556179756	3766ac19af2d8e38dfcc1e2363ae507e	VISA 16 digit	32.8136480540569906	-117.071781789455571
28909	2020-06-04 21:09:41	2020-06-04	Fred Anderson	fred.anderson@geemail.com	Detroit	Michigan	54508609055385228	99f88f55e54591a180c4fc578b8cc4e9	VISA 13 digit	42.4078994694091378	-83.0985020826224172
28910	2020-06-04 21:10:05	2020-06-04	Merritt Oberbrunner	merritt.oberbrunner@warmmail.com	Nashville	Tennessee	3427478439557932	072f6bc4e409c38a1941f01efb009ad6	Maestro	36.1926011730108357	-86.7326585663389409
28911	2020-06-04 21:24:29	2020-06-04	Adrain Sanford	adrain.sanford@warmmail.com	Houston	Texas	3158743440950015610	8f508c89386e838d7c986bc36ebda0a7	JCB 16 digit	29.8694111928422004	-95.4434424065999707
28912	2020-06-04 21:28:51	2020-06-04	Mariann Buckridge-Kovacek	mariann.buckridge.kovacek@warmmail.com	Detroit	Michigan	3445665425152730	ae161c8249577bea5cce25191364703b	Discover	42.4735501396860968	-83.0889777200415693
28913	2020-06-04 21:43:00	2020-06-04	Marlin Sporer	marlin.sporer@geemail.com	Washington	District of Columbia	3484109039368111	68202c2f2182a5ed02941e7a1dc402e4	Mastercard	38.8373114409655358	-77.087243648174038
28914	2020-06-04 21:43:26	2020-06-04	Dr. Ben Lang	dr.ben.lang@geemail.com	Los Angeles	California	639087074303691	bd61db7920e2c11ed622ce7aa4183510	VISA 16 digit	34.0116659992240358	-118.428327313949538
28915	2020-06-04 21:50:05	2020-06-04	Dr. Alex Walter	dr.alex.walter@warmmail.com	Milwaukee	Wisconsin	3096585767122809665	b4a29620409449cbfc895ee3bcef5e8c	VISA 16 digit	43.000808985446767	-87.9140430898040535
28916	2020-06-04 22:01:22	2020-06-04	Mr. Tyreek Hodkiewicz	mr.tyreek.hodkiewicz@warmmail.com	San Jose	California	503815286216161	538379a1e84c0812e01b288675a2ba59	VISA 16 digit	37.3449381731271757	-121.74972418013364
28917	2020-06-04 22:02:14	2020-06-04	Mr. Loren Franecki	mr.loren.franecki@geemail.com	Grand Prairie	Texas	3112817119858985972	eb40a1964fe883513bd1bfcb45bc329c	JCB 16 digit	32.6037122651055498	-97.0552561682522281
28918	2020-06-04 22:08:43	2020-06-04	Dr. Adin Mayert I	dr.adin.mayert.i@warmmail.com	Los Angeles	California	180086623151409071	7ec7d4905f4f279d80277f8507089a1c	JCB 16 digit	34.033851801404353	-118.460721340122817
28919	2020-06-04 22:12:10	2020-06-04	Ms. Macel Gibson PhD	ms.macel.gibson.phd@geemail.com	Dallas	Texas	6011466237117107305	61bfbe2cb80e1bec0a580bfeabdb406a	JCB 16 digit	32.7994374189332163	-96.8598637381065544
28920	2020-06-04 22:31:29	2020-06-04	Hazel Rohan	hazel.rohan@warmmail.com	Los Angeles	California	4904176905779430	3f00a08dabdd8199038ef69ae1bdf922	Discover	34.0477287600614105	-118.370519574823973
28921	2020-06-04 22:36:11	2020-06-04	Alonso Hermiston Jr.	alonso.hermiston.jr.@warmmail.com	San Francisco	California	180073453491479450	c25aa4d16aa6b95e8c9c507953fed032	JCB 15 digit	37.7813641064369889	-122.418468914387034
28922	2020-06-04 22:42:38	2020-06-04	Jaleel Sauer	jaleel.sauer@geemail.com	McAllen	Texas	3112827481750498340	05c058d4518ab194ce8887438246526b	Mastercard	26.1790001169618201	-98.1790828868128358
28923	2020-06-04 22:59:34	2020-06-04	Mr. Denny Little	mr.denny.little@geemail.com	Wilmington	North Carolina	6011880159592783004	ce22aa06776109ffa872c2012656a19f	Discover	34.2632116049814996	-77.8848321056917285
28924	2020-06-04 23:06:50	2020-06-04	Rae Miller MD	rae.miller.md@geemail.com	Provo	Utah	4852547024251	5b493911144fa751c8cb34a350a06a36	Discover	40.2964748852673935	-111.553589950655777
28925	2020-06-04 23:15:19	2020-06-04	Mr. Talmadge Reilly II	mr.talmadge.reilly.ii@geemail.com	Lincoln	Nebraska	3337255600408758802	d16d134daf7131bef57edfb336a42de3	American Express	40.8913473315089888	-96.6630325051184798
28926	2020-06-04 23:25:02	2020-06-04	Desi O'Kon MD	desi.o'kon.md@warmmail.com	New York	New York	869979503266593366	bea338334b0af997fc2c6e4ebd0d5564	JCB 16 digit	40.7166968726310898	-73.8630370391428386
28927	2020-06-05 00:05:11	2020-06-05	Soren Dare	soren.dare@woohoo.com	Berkeley	California	3406718514405878	45913ae56509fe87632bacb8b65e55fe	Voyager	37.8637731654637832	-122.27986679925634
28928	2020-06-05 00:08:15	2020-06-05	Darien Bartoletti	darien.bartoletti@warmmail.com	Glendale	California	060458788636247	d7356921faa758f451b56ee43bde7afe	Discover	34.2666328339591573	-118.153593255383157
28929	2020-06-05 00:15:36	2020-06-05	Affie Brown-Fahey	affie.brown.fahey@geemail.com	San Francisco	California	4281492790575251	5c55db156c3769f2bd2cc0faebe0e147	Voyager	37.7527017269449487	-122.432930835097395
28930	2020-06-05 00:16:27	2020-06-05	Rayan Vandervort	rayan.vandervort@warmmail.com	Fort Wayne	Indiana	4177507412057482	1a8ee3e042038d61bf72cfd7ddda6243	VISA 16 digit	40.9907777698960132	-85.1664916620343888
28931	2020-06-05 00:18:07	2020-06-05	Kati Kassulke	kati.kassulke@geemail.com	Killeen	Texas	4056768020119	900fd783b1d58bde7480d71e4e15564e	VISA 13 digit	30.9981020714387299	-97.7268447022587026
28932	2020-06-05 00:21:31	2020-06-05	Dr. Elida Dickens PhD	dr.elida.dickens.phd@woohoo.com	Rancho Cucamonga	California	4290002869764287	e694582a3ee3b7246cddc95594b3dea1	VISA 16 digit	34.0666459413237845	-117.602380287228897
28933	2020-06-05 00:25:53	2020-06-05	Shianne Rolfson-Tillman	shianne.rolfson.tillman@geemail.com	San Jose	California	3789712984699516	81ae16b63936c5a5988eb516f2f50ca9	JCB 16 digit	37.2223578699685618	-121.78056018713265
28934	2020-06-05 00:30:45	2020-06-05	Crockett Smitham PhD	crockett.smitham.phd@geemail.com	Salinas	California	180031687503873595	bdedb4e107d93629a6e02795e7b9de4b	Diners Club / Carte Blanche	36.7005464397136123	-121.725487040745847
28935	2020-06-05 00:32:25	2020-06-05	Iza Hickle	iza.hickle@geemail.com	Vancouver	Washington	3036250320822690	394dde1f5bfde150d317456b72cfbbe8	VISA 16 digit	45.5896535267192888	-122.498060802888858
28936	2020-06-05 00:40:48	2020-06-05	Mrs. Carey Greenfelder MD	mrs.carey.greenfelder.md@geemail.com	Tulsa	Oklahoma	3048125975764348	d669b94d896c63b68ac28a9c05bf8847	Mastercard	36.1814826799925413	-95.9316464133981555
28937	2020-06-05 00:41:28	2020-06-05	Isa Lakin	isa.lakin@geemail.com	Costa Mesa	California	4344446697592665	de251c04ec80a847ea9e9f7155356754	VISA 13 digit	33.6612186105005478	-117.843647124138855
28938	2020-06-05 01:00:18	2020-06-05	Miss Sidney Hoeger MD	miss.sidney.hoeger.md@warmmail.com	Miami	Florida	676333695698432	d1c671ae7ec5f7f7dcf2b6d625da063a	JCB 16 digit	25.6950483243118981	-80.145514433352659
28939	2020-06-05 01:03:57	2020-06-05	Dollye Metz	dollye.metz@woohoo.com	El Paso	Texas	180077593594379820	c6dd665ca8ca80a150d734f7c55c69bf	Discover	31.8048092461951093	-106.376211477441714
28940	2020-06-05 01:04:15	2020-06-05	Bethzy Hauck	bethzy.hauck@geemail.com	Spokane	Washington	180009555752411227	96e27af960136d662a1ef3f0a9130ab4	American Express	47.6733242613501815	-117.516245837546137
28941	2020-06-05 01:05:48	2020-06-05	Ramon Stroman	ramon.stroman@geemail.com	Sacramento	California	3441406371584509	3cb12e3e4263fc07392abd7fb5efd8aa	Mastercard	38.6395022141546036	-121.421648393130297
28942	2020-06-05 01:09:06	2020-06-05	Miss Latricia Schulist	miss.latricia.schulist@warmmail.com	Houston	Texas	6011851922853112576	e8a33ea7658167cd7cc52878c84af929	American Express	29.8375782686829574	-95.3299427114907729
28943	2020-06-05 01:12:08	2020-06-05	Macel Mosciski	macel.mosciski@geemail.com	Chesapeake	Virginia	869990903837662960	b59b2202ae76e09952b55dd45a0143c1	VISA 16 digit	36.6156770289182703	-76.3306860997185055
28944	2020-06-05 01:24:23	2020-06-05	Dr. Ethen Beahan	dr.ethen.beahan@warmmail.com	Pembroke Pines	Florida	869935862240153785	137aa7b18f7d199bdb043184db721261	Diners Club / Carte Blanche	25.9439855085257456	-80.3135528268661432
28945	2020-06-05 01:28:15	2020-06-05	Treasure Erdman-Quigley	treasure.erdman.quigley@geemail.com	Manchester	New Hampshire	4571677291234825	6f767d5cb8e1fd0627ab0f1d061fb9bc	VISA 16 digit	42.9613585957862441	-71.4370401610977979
28946	2020-06-05 01:29:49	2020-06-05	Bose Hane-Renner	bose.hane.renner@geemail.com	Seattle	Washington	4120271671196	997aab177a21a8bff50a195d31be3dce	VISA 13 digit	47.691980118855831	-122.288051606893163
28947	2020-06-05 01:33:33	2020-06-05	Roswell Von	roswell.von@geemail.com	Portland	Oregon	4680512788696970	57fab5f8de63c3cf4709d5cf56227f21	JCB 15 digit	45.4762181326169497	-122.60933943972924
28948	2020-06-05 01:46:36	2020-06-05	Audrina Barton	audrina.barton@geemail.com	Everett	Washington	3112796511707083691	15428111a94ebdecd8831a62daa7410b	JCB 16 digit	47.8731594715625093	-122.229085294589026
28949	2020-06-05 01:51:45	2020-06-05	Kody Ledner	kody.ledner@geemail.com	New Orleans	Louisiana	3096909279447762495	5b047a01cf873b3f4ad1cb87048ed9a0	Mastercard	29.9670013743001959	-89.8483127618469268
28950	2020-06-05 01:52:53	2020-06-05	Darleen Senger MD	darleen.senger.md@geemail.com	Chicago	Illinois	3112709152230660949	8f1cd0778fad6ec5183b91a6f96c3a41	Mastercard	41.7966346103999769	-87.7295515097707437
28951	2020-06-05 01:58:05	2020-06-05	Buddie Armstrong	buddie.armstrong@geemail.com	Hayward	California	3008302477415048	dfde7ed663c6515b5787b148c02d0cb1	JCB 16 digit	37.6545865304756902	-122.157876837512106
28952	2020-06-05 01:58:21	2020-06-05	Linden Boyle	linden.boyle@woohoo.com	Berkeley	California	589339896732144	d53c83a97653df55cb3b2735ad26de62	Mastercard	37.8678817023739356	-122.219833747216043
28953	2020-06-05 02:09:09	2020-06-05	Bina Dibbert-Sipes	bina.dibbert.sipes@geemail.com	League City	Texas	180017488328702301	c54844e3224bb6f80604d43dd4d8ec76	Mastercard	29.5762921169795128	-95.0146145569611349
28954	2020-06-05 02:15:40	2020-06-05	Donell Russel I	donell.russel.i@woohoo.com	Waco	Texas	4702971986048075	63ba5cbe75a4cbd6bc32eaf4432c4015	VISA 13 digit	31.6090239803049684	-97.1562212037518691
28955	2020-06-05 02:22:24	2020-06-05	Kanye Jakubowski V	kanye.jakubowski.v@geemail.com	Macon	Georgia	675917804828113	7423ca0b7cb1ee72244933ed4f6adcca	Discover	32.7743704367905835	-83.7382202045720021
28956	2020-06-05 02:23:16	2020-06-05	Maryanne Gleason-Hagenes	maryanne.gleason.hagenes@geemail.com	Chesapeake	Virginia	180033458130085880	65f698e58e0de6d5e4e8ef0739d11138	Mastercard	36.6671225597389068	-76.2679676913499804
28957	2020-06-05 02:24:01	2020-06-05	Melinda Koss-Jast	melinda.koss.jast@geemail.com	New York	New York	4615916051027	e0f2ef8f44b9cf54acb2f7a49cae1a1e	VISA 16 digit	40.6197173949554582	-73.943974685891348
28959	2020-06-05 02:29:50	2020-06-05	Ryley Abshire-Haag	ryley.abshire.haag@geemail.com	Berkeley	California	3088189864305266563	0a852335767a7f1d1d46dfb3ae7094bf	VISA 16 digit	37.908675591003032	-122.274368537825339
28960	2020-06-05 02:36:32	2020-06-05	Ms. Edris Crooks DVM	ms.edris.crooks.dvm@geemail.com	San Francisco	California	6011899944961949727	f34accce00cee8df63a9bb0fd603c53c	Maestro	37.8035973332440278	-122.431796860824207
28961	2020-06-05 02:41:37	2020-06-05	Jeanna Borer DVM	jeanna.borer.dvm@woohoo.com	Las Vegas	Nevada	4707486776917	27b925838db780e5297ee15ba6d9505f	Mastercard	36.3191020988494131	-115.261674448868632
28962	2020-06-05 02:54:12	2020-06-05	Derik Streich DVM	derik.streich.dvm@geemail.com	Albuquerque	New Mexico	4975368099412175	5fc2536964a9450376c8f03fc3df09d0	Voyager	35.1155360735621329	-106.745394006657975
28963	2020-06-05 02:58:18	2020-06-05	Corbin Dicki	corbin.dicki@geemail.com	Oakland	California	4782090105746	217246b2ebeb762026e85137b402f7a6	American Express	37.8057971748297135	-122.242149935854854
28964	2020-06-05 03:10:58	2020-06-05	Dr. Amit Kulas	dr.amit.kulas@geemail.com	New York	New York	4455419963425725	74f0839ff8a5b2f739b097bd05db9379	VISA 16 digit	40.7627870460730009	-73.9982411476213429
28965	2020-06-05 03:18:57	2020-06-05	Miss Aja Blanda	miss.aja.blanda@warmmail.com	Houston	Texas	3337471950728913316	49d2f2fa207d8e46608cad243cbffb9e	Voyager	29.8724070633374161	-95.4848026742707958
28966	2020-06-05 03:20:28	2020-06-05	Davion Gerlach	davion.gerlach@geemail.com	Berkeley	California	4429828821760334	b25757c193bdb769c5c937fb6ac48984	JCB 16 digit	37.9030451352286732	-122.241744021101354
28967	2020-06-05 03:28:51	2020-06-05	Clementine Lebsack	clementine.lebsack@geemail.com	Columbus	Ohio	869956616852605993	a11e365422b41726f9d85aacd3ba5673	Mastercard	40.0657694838985776	-82.9169572582237464
28968	2020-06-05 03:29:15	2020-06-05	Mr. Dwight Jacobs V	mr.dwight.jacobs.v@geemail.com	Minneapolis	Minnesota	4383997746338726	a5e9d4422a9dea7340a6e918c3a6b054	Discover	44.9533064505636659	-93.3618322036500956
28969	2020-06-05 03:29:34	2020-06-05	Jeremie Fadel	jeremie.fadel@geemail.com	New York	New York	3158082028060769413	d3d8eafc1936f7b3e039c8c68a51c157	Discover	40.7633206251766538	-73.841848628910995
28970	2020-06-05 03:31:47	2020-06-05	Amberly Hintz	amberly.hintz@geemail.com	Pomona	California	55031259836525126	bccce0ae5b10131b2a900f53467f6c80	Mastercard	34.1444357384499213	-117.84014339306988
28971	2020-06-05 03:41:41	2020-06-05	Dr. Adaline Batz DVM	dr.adaline.batz.dvm@geemail.com	Berkeley	California	869945011988632729	cf2692ae9d99fcf14fdc3337d9b8dff4	JCB 15 digit	37.8973223620586808	-122.26989198121926
28972	2020-06-05 03:42:56	2020-06-05	Delmer Welch	delmer.welch@geemail.com	Colorado Springs	Colorado	3528872222671833973	82dea02068fb5a69057451cb42b84c7f	Maestro	38.8803245702341229	-104.721569762441149
28973	2020-06-05 03:46:56	2020-06-05	Braedon Armstrong	braedon.armstrong@geemail.com	San Francisco	California	4887081016644	d78760be8f9113a88f54c933fd81595d	American Express	37.7863743824425811	-122.421223981464635
28974	2020-06-05 03:54:06	2020-06-05	Margarito Braun IV	margarito.braun.iv@geemail.com	Pearland	Texas	869917398435152821	fa0baf10e29cf4dfc6dc3a43f70d7b9b	JCB 15 digit	29.5421114695530385	-95.3859078111447332
28975	2020-06-05 03:57:05	2020-06-05	Ms. Kacie Koepp PhD	ms.kacie.koepp.phd@geemail.com	Houston	Texas	4149130684116	f28bbf5941ea44788bfb82fdea691f5c	VISA 16 digit	29.8698204607781008	-95.3203583276379902
28976	2020-06-05 04:06:37	2020-06-05	Mr. Jermaine Satterfield	mr.jermaine.satterfield@geemail.com	New York	New York	4007813408871159	32854189f6af96113b3bf68cedc1ea3a	VISA 13 digit	40.676976305641233	-73.9783034752950073
28977	2020-06-05 04:14:40	2020-06-05	Goebel Prosacco	goebel.prosacco@woohoo.com	Plano	Texas	3096227039131863263	ff7fbe5218223fbb4a85fdcbdeab9b26	VISA 16 digit	33.0862649198241527	-96.7560210020929645
28978	2020-06-05 04:16:17	2020-06-05	Mrs. Dominga Schowalter	mrs.dominga.schowalter@woohoo.com	Phoenix	Arizona	210047689828870266	f6ec8ccd78a3fed42c16ac396ae5e8f6	VISA 16 digit	33.4973985239796335	-112.086561843047292
28979	2020-06-05 04:22:03	2020-06-05	Oleta Powlowski	oleta.powlowski@geemail.com	Athens	Georgia	869910846697346447	618b2206474d46bf6ed4b5fd0013b683	JCB 16 digit	33.908193083033332	-83.3732263456679874
28980	2020-06-05 04:51:15	2020-06-05	Kenji Lynch-Funk	kenji.lynch.funk@geemail.com	San Antonio	Texas	4453599839789651	afc27b83cc9a28b492476502851b7d7a	JCB 16 digit	29.4144723047107455	-98.491938658694167
28981	2020-06-05 04:53:41	2020-06-05	Annemarie Welch	annemarie.welch@geemail.com	Los Angeles	California	3452796634875900	602d0be98f2a077dcd4b23478fe3b6ea	JCB 16 digit	33.9596256695087959	-118.368810465186087
28982	2020-06-05 05:02:15	2020-06-05	Tyra Ullrich DDS	tyra.ullrich.dds@woohoo.com	Gainesville	Florida	4549630387385	47b1d7b7e75921aba999080435a48570	American Express	29.6985564974427199	-82.382869545730216
28983	2020-06-05 05:02:56	2020-06-05	Mrs. Byrd Conn MD	mrs.byrd.conn.md@geemail.com	Murfreesboro	Tennessee	6011653646683821417	41c6394123d47ae8d299ea0eb58161a8	VISA 16 digit	35.8633351917032215	-86.492843573898071
28984	2020-06-05 05:30:07	2020-06-05	Delmer Fisher	delmer.fisher@geemail.com	Laredo	Texas	4731119364347	963e8825c36f10936b07651e348f1e0d	Voyager	27.4863021129459142	-99.5268323687378285
28985	2020-06-05 05:37:59	2020-06-05	Ireland Kub MD	ireland.kub.md@woohoo.com	Kenosha	Wisconsin	3158868342340842365	9a877e3ea4f3385da51b2a0b889ab84a	Diners Club / Carte Blanche	42.5795095268942418	-87.7808905552368657
28986	2020-06-05 05:39:45	2020-06-05	Lourdes Halvorson	lourdes.halvorson@geemail.com	Spokane	Washington	3703321827836641	7dcf849221a8c60bef82f3d3f7cafd5d	Mastercard	47.5772499514516412	-117.462581655047089
28987	2020-06-05 05:44:54	2020-06-05	Kristofer Wisozk-Heller	kristofer.wisozk.heller@geemail.com	Oklahoma City	Oklahoma	53436194227007692	1e9ed77ae2dea998fffdaaf1f122ef0c	JCB 16 digit	35.5578016905024654	-97.5216506306443307
28988	2020-06-05 05:59:07	2020-06-05	Lakesha Mante	lakesha.mante@geemail.com	Oakland	California	3158041218858337529	085753cb79fd46673be0db5767fe9106	VISA 16 digit	37.802329783781758	-122.301035655243311
28989	2020-06-05 05:59:46	2020-06-05	Elsworth O'Hara	elsworth.o'hara@warmmail.com	Atlanta	Georgia	3795523357326906	4e2f432305d57c937ee342d2a3bcd408	Mastercard	33.7162070532605043	-84.5125188983555944
28990	2020-06-05 06:04:12	2020-06-05	Drucilla Effertz-Koepp	drucilla.effertz.koepp@woohoo.com	Billings	Montana	3413303199355952	4ca83f127e5d1fabdebdc5d6fe4d5937	Maestro	45.8357538882400846	-108.577609288010365
28991	2020-06-05 06:13:15	2020-06-05	Durward Kutch	durward.kutch@geemail.com	Sandy Springs	Georgia	869916277162546697	50b9af388852991082cc09acd70087c3	Maestro	33.8731000605560837	-84.320054006258772
28992	2020-06-05 06:31:16	2020-06-05	Griffith Hilll	griffith.hilll@geemail.com	Cambridge	Massachusetts	503866936361253	9bf5f1d9f915d16be67932da1035f36a	Maestro	42.4098610110804444	-71.1734860077582283
28993	2020-06-05 06:43:14	2020-06-05	Elyse Tromp	elyse.tromp@geemail.com	Fresno	California	55260193526034259	697705eae2d9efb66ef1761a8e33c4f7	Mastercard	36.7283308940812958	-119.886677232768022
28994	2020-06-05 06:44:08	2020-06-05	Mrs. Verne Thompson	mrs.verne.thompson@geemail.com	Rancho Cucamonga	California	6011506770055790270	3b99ea8f4bd188504f2a428739873e40	Mastercard	34.1523482522454103	-117.48599248207249
28995	2020-06-05 06:45:26	2020-06-05	Josie Nolan PhD	josie.nolan.phd@geemail.com	Fort Worth	Texas	4370856195783706	e585be8f658428b855c6f8c5422cbb12	Diners Club / Carte Blanche	32.8263946023359878	-97.2666445702601266
28996	2020-06-05 06:50:00	2020-06-05	Joseph Beier	joseph.beier@geemail.com	Charlotte	North Carolina	3725287815116110	571cc291f5c2d4e3c21fe96b84e2d0fb	Diners Club / Carte Blanche	35.1086011148776862	-80.8763861502930581
28997	2020-06-05 06:52:32	2020-06-05	Khadijah Ebert-Daugherty	khadijah.ebert.daugherty@woohoo.com	Los Angeles	California	6011261796786087772	d453d95800fb04d56b2030c2414ed74f	JCB 16 digit	34.1142652866762077	-118.485177848301078
28998	2020-06-05 06:55:36	2020-06-05	Kinte Marquardt	kinte.marquardt@warmmail.com	Louisville	Kentucky	4432048080011304	8808bea58b7a212f3877867c3ce9d292	Voyager	38.244125192928685	-85.7087828233908908
28999	2020-06-05 07:07:26	2020-06-05	Makala Reynolds	makala.reynolds@geemail.com	San Francisco	California	3112735555360724889	cc066cf52ab24a3aa20d071df1d1167f	VISA 16 digit	37.7877641859451714	-122.439713604814116
29000	2020-06-05 07:08:38	2020-06-05	Armand Sawayn	armand.sawayn@geemail.com	Los Angeles	California	3337728458644827447	4679f540fc9fe93679f00b0737fea46b	Diners Club / Carte Blanche	34.1171418926078829	-118.402139577920735
29001	2020-06-05 07:20:38	2020-06-05	Sawyer Streich	sawyer.streich@geemail.com	San Francisco	California	3112742803716064258	2b990fb229bbb8ac7f666aa7c9e21537	VISA 16 digit	37.7691051968651621	-122.440387573791526
29002	2020-06-05 07:33:04	2020-06-05	Marina Hackett	marina.hackett@geemail.com	Phoenix	Arizona	3003012474153089	8e666c6b6211a2ee631eb28ce2824b28	Diners Club / Carte Blanche	33.5668895704139061	-112.168727125686047
29003	2020-06-05 08:01:23	2020-06-05	Levie Torphy	levie.torphy@geemail.com	Topeka	Kansas	3112197664486902972	736baf63ceeb7558a5e5687f4c02af2f	American Express	39.1186225539006287	-95.6547846463218434
29004	2020-06-05 08:05:30	2020-06-05	Miracle Graham	miracle.graham@woohoo.com	Fort Collins	Colorado	4690967502373892	0bbe23be8ee3a162a28b4c39d9d4f129	Maestro	40.6143992734763799	-105.110101298191779
29005	2020-06-05 08:15:10	2020-06-05	Miss Ivanna Pfannerstill	miss.ivanna.pfannerstill@geemail.com	Chattanooga	Tennessee	6011318341633153486	e2bd03110c8733d4721b8e9eb449b0df	VISA 13 digit	35.1364796026460837	-85.1678282774813482
29006	2020-06-05 08:18:17	2020-06-05	Nickolas Feeney	nickolas.feeney@geemail.com	Oklahoma City	Oklahoma	6011414739923063468	d277269d124bc582e4dfbed114caec4d	Discover	35.4012602189000702	-97.4884858861461225
29007	2020-06-05 08:23:05	2020-06-05	Elayne Marvin PhD	elayne.marvin.phd@woohoo.com	Shreveport	Louisiana	6011226807082339223	4e3c1892a62729defe4c93253a4fa494	Discover	32.5460400974150801	-93.8318009810734424
29008	2020-06-05 08:25:51	2020-06-05	Dr. Amparo Haley DVM	dr.amparo.haley.dvm@geemail.com	Chicago	Illinois	3088894480268774885	bedeb8b4984132136e86813d8cc53be6	Discover	41.8202467221602845	-87.6103266078077212
29009	2020-06-05 08:29:54	2020-06-05	Jaret D'Amore	jaret.d'amore@geemail.com	Chandler	Arizona	3430623414372931	4a4e45d10d4e4b5ba63411f437c5623e	Mastercard	33.3050165541559409	-111.895009303127978
29010	2020-06-05 08:32:40	2020-06-05	Antonio Schmitt	antonio.schmitt@geemail.com	San Francisco	California	501885610386196	2badea43d2fe0388fbbeb5ad7ba22f2e	VISA 13 digit	37.7837261147620893	-122.421988123887061
29011	2020-06-05 08:36:05	2020-06-05	Kevon Deckow PhD	kevon.deckow.phd@geemail.com	Cincinnati	Ohio	3472015887913193	2588925dc39dcbc2995a5d67c42bf573	Voyager	39.0581343652445838	-84.4881608372826065
29012	2020-06-05 08:36:24	2020-06-05	Dr. Anderson Bahringer	dr.anderson.bahringer@geemail.com	Buffalo	New York	4548767102062414	e87e9f5b18974f092938ce9863282158	Discover	42.8089064005482953	-78.8409254531774764
29013	2020-06-05 08:36:31	2020-06-05	Cary Schowalter	cary.schowalter@warmmail.com	San Francisco	California	3158215941425635501	8689ce6848370077c16d7e4b77ea9155	Voyager	37.7840417231743047	-122.436877115893068
29014	2020-06-05 08:50:37	2020-06-05	Wylie Sporer	wylie.sporer@woohoo.com	San Francisco	California	869943278244257250	e08274a2473cdb7f98dc391e16bf96c9	JCB 16 digit	37.7726524705674649	-122.420570954680926
29015	2020-06-05 08:56:20	2020-06-05	Harley Connelly MD	harley.connelly.md@geemail.com	Cleveland	Ohio	3026088713856440	b1969b56f411d2c076c497399afb68a1	VISA 16 digit	41.5006034650690836	-81.6269487528368813
29016	2020-06-05 09:06:07	2020-06-05	Alexande Ritchie	alexande.ritchie@warmmail.com	Gainesville	Florida	4574455020660975	31b183a61b091e7db0b9285eb741f669	JCB 16 digit	29.7230024841438976	-82.2605571817014436
29017	2020-06-05 09:08:56	2020-06-05	Mr. Santiago O'Kon III	mr.santiago.o'kon.iii@geemail.com	New York	New York	53916692291743653	3756eb9f7b8a90de75c0e6b94b830f01	American Express	40.6176708628181373	-73.8596187979344307
29018	2020-06-05 09:16:39	2020-06-05	Zigmund Adams Jr.	zigmund.adams.jr.@geemail.com	New Orleans	Louisiana	3022869752135356	27de3f008b96428225c2b66c7d32f40d	Diners Club / Carte Blanche	30.0021121710553764	-90.0151380708236246
29019	2020-06-05 09:23:23	2020-06-05	Amado Torphy	amado.torphy@woohoo.com	San Diego	California	55872828960411857	64fcb58d54c7c2767b881c14b217c2fd	VISA 13 digit	32.7234109299324487	-117.133167273029684
29020	2020-06-05 09:26:07	2020-06-05	Devaughn Konopelski-Bradtke	devaughn.konopelski.bradtke@geemail.com	Macon	Georgia	3112480481094550499	131d4cfbd041b95bf8dd15cafb136b26	VISA 13 digit	32.835471297615392	-83.6611398804195119
29021	2020-06-05 09:31:49	2020-06-05	Norberto McDermott	norberto.mcdermott@warmmail.com	San Francisco	California	4420282069913	5cac30d41386447f9d7e4e4708cc3a5a	Mastercard	37.7775746819140892	-122.419696605984626
29022	2020-06-05 09:36:03	2020-06-05	Nealy Doyle	nealy.doyle@geemail.com	Los Angeles	California	869934496938549060	9700d38fc9d2864ae7bb03dd307b7907	Mastercard	34.0234131349582185	-118.492332034557307
29023	2020-06-05 09:45:12	2020-06-05	Jackson Gleason-Hamill	jackson.gleason.hamill@geemail.com	Visalia	California	51386589078249824	a3a89a453289fc94c59523ff31636820	JCB 16 digit	36.3712609772525752	-119.329391441832854
29024	2020-06-05 09:51:38	2020-06-05	Rodolfo Dicki	rodolfo.dicki@geemail.com	San Francisco	California	4945628081180	0459edd0a76e7179edce4565195e2805	VISA 13 digit	37.798515952042635	-122.44868078047088
29025	2020-06-05 09:55:20	2020-06-05	Vito Dickens	vito.dickens@geemail.com	Athens	Georgia	6011097104015278819	52d541cb0c8b67c1b964157f092c14f8	Discover	33.9303291515171495	-83.4033687158137553
29026	2020-06-05 10:00:17	2020-06-05	Mittie Wintheiser	mittie.wintheiser@geemail.com	Baltimore	Maryland	4894152583957	66c3f4339b94739b5b3e74c5e2d0d77c	Mastercard	39.3627925748936818	-76.6327482230979911
29027	2020-06-05 10:02:41	2020-06-05	Clementina Hoeger	clementina.hoeger@geemail.com	Independence	Missouri	3096306159938776106	de7016fadcf4a6565ce05a3234067901	VISA 16 digit	39.0716666724085826	-94.326870767893638
29028	2020-06-05 10:08:32	2020-06-05	Codi Johnson	codi.johnson@geemail.com	New York	New York	869939356231266793	d315b9d1ed84f95fa0983d4552a00958	JCB 16 digit	40.6544053621813646	-73.9927937493089587
29029	2020-06-05 10:11:19	2020-06-05	Chris McClure	chris.mcclure@geemail.com	San Francisco	California	501810068958171	f4459aaebf51e4034269dce84790e01c	JCB 16 digit	37.7693477255378696	-122.411631505978633
29030	2020-06-05 10:17:34	2020-06-05	Katina Connelly	katina.connelly@warmmail.com	Houston	Texas	55441208305291029	6b656d931b1e9bd041aa0f3331fcf535	Voyager	29.8172325754616416	-95.4099831155050566
29031	2020-06-05 10:35:08	2020-06-05	Dr. Woodie Heller DDS	dr.woodie.heller.dds@geemail.com	Arlington	Texas	3337886328445090586	7ff20ed5e85e3e6992624f961d93e466	Maestro	32.7948813008859759	-97.0719451334353636
29032	2020-06-05 10:41:13	2020-06-05	Nunzio Gibson	nunzio.gibson@warmmail.com	New York	New York	3158456743631097015	09fb3fb6cb4537adb6899cf11ed476fa	JCB 15 digit	40.6793968471456324	-73.9751581469446364
29033	2020-06-05 10:45:24	2020-06-05	Dr. Chace Krajcik MD	dr.chace.krajcik.md@warmmail.com	New York	New York	4632269964061565	5c97776ca984e59cdcfb102913686514	VISA 13 digit	40.7166566731631718	-73.9259400781605365
29034	2020-06-05 10:50:52	2020-06-05	Deacon Lubowitz	deacon.lubowitz@geemail.com	Denver	Colorado	3088057319596278362	caced1a9bbacab189e3560b2eb0335bf	JCB 16 digit	39.7934466200467156	-104.839041002724699
29035	2020-06-05 10:56:19	2020-06-05	Tamiko Hagenes DDS	tamiko.hagenes.dds@woohoo.com	Oklahoma City	Oklahoma	4963569810353531	70dcbfa3842ea1e5fbb568c4fdc3d617	JCB 16 digit	35.3880760047029739	-97.6009306272387533
29036	2020-06-05 11:07:49	2020-06-05	Mrs. Mayra Kunze	mrs.mayra.kunze@woohoo.com	San Francisco	California	4170914006599	136f7104fcc583561147468582761ae5	American Express	37.7639572129212127	-122.431274183318621
29037	2020-06-05 11:08:48	2020-06-05	Lesley Cronin V	lesley.cronin.v@geemail.com	Santa Maria	California	180019271889980534	6ff844143603f30526eafd8a5d1b78d0	Mastercard	34.9155272310197375	-120.418698321228092
29038	2020-06-05 11:14:15	2020-06-05	Sofia Lang	sofia.lang@woohoo.com	Honolulu	Hawaii	210027108219950730	9411ef126db76d22a07cbf11bf7df9d6	VISA 13 digit	21.3374454655900614	-157.756205882665142
29039	2020-06-05 11:22:55	2020-06-05	Franklyn Denesik	franklyn.denesik@warmmail.com	Memphis	Tennessee	4680394084546815	aeb12cc7da895050c738172e28b52891	JCB 16 digit	35.1094392536275137	-89.9456033283170342
29040	2020-06-05 11:27:58	2020-06-05	Arizona Waters	arizona.waters@geemail.com	Greeley	Colorado	869942067859270059	eadd6ae4d2281d1ef35336bfe579ded9	VISA 13 digit	40.3870194923665409	-104.861384571420771
29041	2020-06-05 11:31:24	2020-06-05	Dr. Carmen Hills	dr.carmen.hills@geemail.com	Lansing	Michigan	3112979873500315269	8dbd25eefdfd174d634e72c2b3ccc748	Maestro	42.6252120969660595	-84.6202083929564708
29042	2020-06-05 11:32:57	2020-06-05	Durell Farrell	durell.farrell@warmmail.com	Berkeley	California	6011695052552426497	f2162a2dafdc4e6e663856c98a783c3b	Maestro	37.8848720676629966	-122.296129838411829
29043	2020-06-05 11:42:44	2020-06-05	Edsel Ledner	edsel.ledner@woohoo.com	Toledo	Ohio	4587369508713435	3656c9e82075a780115ee747805d75d3	JCB 15 digit	41.5868177300024726	-83.567232461865629
29044	2020-06-05 11:43:03	2020-06-05	Jaydin Gerhold	jaydin.gerhold@geemail.com	League City	Texas	3738335796106751	e76ec17c0849f9a0936e456fce43fd5f	Mastercard	29.4558085832208398	-95.1846366240628043
29045	2020-06-05 11:57:01	2020-06-05	Cheyanne Greenholt	cheyanne.greenholt@geemail.com	Worcester	Massachusetts	3158315387152422789	40ada8078f6d3c0fb7032194cddc0d91	Discover	42.2087003573011614	-71.8817337586332172
29046	2020-06-05 12:04:10	2020-06-05	Cindy Reichert-Hodkiewicz	cindy.reichert.hodkiewicz@woohoo.com	Philadelphia	Pennsylvania	3003202177575759	f218004a705585c2fd0d647bb7ea95bf	Mastercard	40.0045423601247379	-75.1100153314314838
29047	2020-06-05 12:09:27	2020-06-05	Noretta Haley-Schaden	noretta.haley.schaden@geemail.com	Grand Rapids	Michigan	51070667349332784	9411e55f0d881ab2538b4441de902661	Mastercard	42.8828362189501533	-85.5953225714754353
29048	2020-06-05 12:11:30	2020-06-05	Guilford Ratke-Wisozk	guilford.ratke.wisozk@geemail.com	New York	New York	3774556165400948	972185b2cc6499235615a796cb10d953	JCB 15 digit	40.6938409401792995	-73.8476665927458527
29049	2020-06-05 12:28:14	2020-06-05	Myrtle Murphy	myrtle.murphy@warmmail.com	Berkeley	California	3337725254856033326	c3a5ba5171e8b0d7413e2e1efc4ea6af	Discover	37.8895750510685687	-122.249363719812905
29050	2020-06-05 12:29:57	2020-06-05	Hadassah Balistreri	hadassah.balistreri@geemail.com	New York	New York	6011780874452915816	1e5794222d5f9bf45ef6a559c0e1658e	JCB 16 digit	40.6904127758685519	-73.9211106393847643
29051	2020-06-05 12:31:14	2020-06-05	Montie Haag	montie.haag@geemail.com	Dayton	Ohio	180051142957261314	588314ca442050cf6161b540d615aa9a	VISA 16 digit	39.7770078695636258	-84.1661640894789258
29052	2020-06-05 12:45:18	2020-06-05	Dr. Tinie Wyman MD	dr.tinie.wyman.md@woohoo.com	Oakland	California	4202160914466709	8ec79b75927b71b5e6fff751a105f094	American Express	37.7807172917686174	-122.25302956585513
29053	2020-06-05 12:47:24	2020-06-05	Horacio Rempel-Hyatt	horacio.rempel.hyatt@woohoo.com	Chicago	Illinois	4813595817981349	c1a86904b0d22afcb0cc6c711b309710	Diners Club / Carte Blanche	41.828001365980505	-87.6699622147280735
29054	2020-06-05 12:49:03	2020-06-05	Gerardo Bradtke	gerardo.bradtke@geemail.com	Seattle	Washington	3004680234301278	9cd62442ece948b16f0783ad15c75cab	JCB 16 digit	47.626803120823574	-122.324197132458536
29055	2020-06-05 12:50:11	2020-06-05	Clide Larson	clide.larson@geemail.com	New York	New York	3414464118565805	ee27603eef6e6980e4421ba295298ee4	JCB 15 digit	40.6452059267312293	-73.8692071271490249
29056	2020-06-05 12:52:40	2020-06-05	Deanne Marvin	deanne.marvin@geemail.com	Midland	Texas	3158607841001524747	12cf39319ad857d4aa61d24fbb36964e	Discover	32.0383135364115219	-102.132798538146545
29057	2020-06-05 12:55:01	2020-06-05	Kortney Weimann	kortney.weimann@warmmail.com	Houston	Texas	4976662873059	2646e8d94c1439553f02e955d8c59e2f	JCB 16 digit	29.7662916957478956	-95.2958015106167693
29058	2020-06-05 13:01:46	2020-06-05	Miss Denisha Zemlak	miss.denisha.zemlak@geemail.com	New York	New York	3050533437819618	c09d9afefa5960d6599d4d2e99cbe8ac	Voyager	40.7529575720187296	-73.867699873576683
29059	2020-06-05 13:06:51	2020-06-05	Mr. Sean Medhurst	mr.sean.medhurst@geemail.com	Philadelphia	Pennsylvania	869914343040354928	8c1d9ce52040aca389dc01e221864a58	Mastercard	39.9440795475576067	-75.1249271325200851
29060	2020-06-05 13:11:07	2020-06-05	Elaina Connelly-Lebsack	elaina.connelly.lebsack@geemail.com	Portland	Oregon	3439573840563101	92334b5d21552987e23513d89a9faa03	VISA 16 digit	45.5591847299952022	-122.578114293701958
29061	2020-06-05 13:28:05	2020-06-05	Clayton Trantow IV	clayton.trantow.iv@geemail.com	Colorado Springs	Colorado	6011491093166444985	89546299ada1cb1660162d48356ed8c0	JCB 16 digit	38.9405286826241763	-104.737161159298196
29062	2020-06-05 13:34:03	2020-06-05	Finnegan Kihn	finnegan.kihn@geemail.com	Oklahoma City	Oklahoma	4961086700658	fb5aae68a57db0d62dc1dc4b290a917f	JCB 15 digit	35.4461022029541439	-97.521418863571057
29063	2020-06-05 13:39:05	2020-06-05	Camryn Grimes	camryn.grimes@woohoo.com	Tuscaloosa	Alabama	3096707959730634030	99c74d26e1cecc93f11c0d867b03e5b6	JCB 16 digit	33.2587153541445701	-87.5492623204927867
29064	2020-06-05 13:47:30	2020-06-05	Mrs. Lizette Reichert DVM	mrs.lizette.reichert.dvm@geemail.com	Oakland	California	210016022037321557	52ac34ef0400fdbcd5ef21fe2401acb1	Voyager	37.7912761153867507	-122.305288426078619
29065	2020-06-05 13:49:20	2020-06-05	Buena Adams	buena.adams@geemail.com	Oakland	California	4548458805858	25cfe2f5c718f31fb188e755d421b7e5	JCB 16 digit	37.8101723358148263	-122.256354627116309
29066	2020-06-05 13:52:13	2020-06-05	Lucio Bradtke	lucio.bradtke@geemail.com	Austin	Texas	180019622785090945	0ce1238e054f1e56af9cfeeeea5f7e92	VISA 13 digit	30.3428343688264484	-97.723404045240585
29067	2020-06-05 13:57:35	2020-06-05	Therman Ruecker-Ledner	therman.ruecker.ledner@woohoo.com	New York	New York	3096625890438902123	d7e96e2faf0c71107bb581c52ac5bacd	JCB 16 digit	40.6276233220230765	-73.8653916379332571
29068	2020-06-05 13:58:45	2020-06-05	Ailene Wilkinson	ailene.wilkinson@warmmail.com	Los Angeles	California	6011612245727651466	ed98b3fa18901a917bae71bc21675687	VISA 13 digit	34.010963079459593	-118.387256910558037
29069	2020-06-05 13:59:20	2020-06-05	Rosita O'Keefe	rosita.o'keefe@geemail.com	Irvine	California	51655110406650411	0b6c138e3e8fdb340f7359699966f03a	Voyager	33.6363439815599534	-117.789379919042062
29070	2020-06-05 13:59:58	2020-06-05	Bradford Schumm	bradford.schumm@woohoo.com	Midland	Texas	4694368353538	453e3601dfa84243f6c7e7335ca53795	VISA 13 digit	32.1061887267235662	-102.168619621986522
29071	2020-06-05 14:03:32	2020-06-05	Arnett Lowe	arnett.lowe@geemail.com	Ann Arbor	Michigan	4533190184960	46c14244140a428fa5f8bbe7de36dcf0	Mastercard	42.2872113261431437	-83.6829569971762623
29072	2020-06-05 14:06:08	2020-06-05	Karina Crooks	karina.crooks@geemail.com	Warren	Michigan	51552486814383165	467bbdbc1d2b4292dbfdbbb6c79807fb	Voyager	42.5420346187889535	-83.0452101160306597
29073	2020-06-05 14:07:12	2020-06-05	Carra Ziemann PhD	carra.ziemann.phd@geemail.com	Pembroke Pines	Florida	4951644234632614	126ac3ebafa81bd22676a687e887839f	Discover	25.9438713221382358	-80.3513856562223339
29074	2020-06-05 14:07:23	2020-06-05	Noreta Wintheiser-Kreiger	noreta.wintheiser.kreiger@geemail.com	Honolulu	Hawaii	3740027014513274	4cbc4ca92d3bcc0bf034a60e05638993	VISA 16 digit	21.3076274249918782	-157.863244723968592
29075	2020-06-05 14:10:52	2020-06-05	Jaylah Collins	jaylah.collins@geemail.com	Riverside	California	54694281002505003	b91053f4356ce90affd671d14d294f0e	Maestro	33.9885417016170877	-117.304420268066963
29076	2020-06-05 14:15:32	2020-06-05	Milan Torphy	milan.torphy@geemail.com	Saint Paul	Minnesota	3053221069748183	69f775e30b2f10fb1214bf357161bea0	American Express	44.9831996975407051	-93.0745514961224103
29077	2020-06-05 14:23:52	2020-06-05	Alaya Ward	alaya.ward@geemail.com	St. Louis	Missouri	210031592066146134	b60746289891734d143f935740e51d4f	VISA 16 digit	38.5703117850858703	-90.2543506469115613
29078	2020-06-05 14:26:32	2020-06-05	Devan Larkin	devan.larkin@geemail.com	Mesquite	Texas	53416918288417240	f246274588f629f8e944f0d353f4b637	Maestro	32.7203555468279887	-96.6300717766128514
29079	2020-06-05 14:29:14	2020-06-05	Wilma Kertzmann PhD	wilma.kertzmann.phd@geemail.com	Milwaukee	Wisconsin	3456576286120805	49384afc12c3b6dd718a19b27d018a3e	Voyager	43.1463648357048584	-87.885245194901529
29080	2020-06-05 14:30:53	2020-06-05	Maryjane Flatley	maryjane.flatley@geemail.com	Victorville	California	4525390837687368	4f636c2af8223b4b43b2032252ddac93	VISA 13 digit	34.4485349461201622	-117.412442205768457
29081	2020-06-05 15:08:49	2020-06-05	Mr. Williams Corkery	mr.williams.corkery@geemail.com	New York	New York	4402482449660392	1feaa50884fe18f4a7d2e91ed3fe4380	VISA 16 digit	40.6217435114309211	-74.0174400987464907
29082	2020-06-05 15:16:36	2020-06-05	Ellery Stroman-Beatty	ellery.stroman.beatty@geemail.com	Chula Vista	California	060493363941357	1db72e447843ee879ea750e2bf78138b	Mastercard	32.6521861593935583	-116.989870420167961
29083	2020-06-05 15:18:02	2020-06-05	Ofelia Lehner	ofelia.lehner@geemail.com	New York	New York	502048310438428	0ee6621673c974b9681df755aef3b35a	VISA 16 digit	40.6531196355111888	-74.0349599669583114
29084	2020-06-05 15:19:09	2020-06-05	Dr. Nicholaus Mertz	dr.nicholaus.mertz@geemail.com	Berkeley	California	3000060001254154	d5dadc9be02c4c3f3a4cf1e85f248482	JCB 15 digit	37.8612260668619598	-122.262085630332649
29085	2020-06-05 15:19:35	2020-06-05	Tavian Zemlak	tavian.zemlak@woohoo.com	Dallas	Texas	3112598015634907675	c0cad5831e632347eedeb9b723302fa2	VISA 13 digit	32.7425908105254209	-96.827574990686017
29086	2020-06-05 15:21:18	2020-06-05	Dr. Garnett Barton DDS	dr.garnett.barton.dds@geemail.com	Woodbridge	New Jersey	4215082125612	4d30d5f4e2f9790a1c35d484946bc321	Maestro	40.607043833347781	-74.3858140719447221
29087	2020-06-05 15:30:47	2020-06-05	Dr. Lorrie Towne	dr.lorrie.towne@geemail.com	San Bernardino	California	54034647570747954	307c8d15b918ab73173053c7d0b5e7b2	Maestro	34.0647668115127829	-117.387543174928425
29088	2020-06-05 15:32:41	2020-06-05	Sanai Wunsch	sanai.wunsch@geemail.com	Philadelphia	Pennsylvania	3464745784700406	d034bd6906b074d87992200a7ad286d7	Voyager	40.1008056471083307	-75.1437591268580434
29089	2020-06-05 15:35:51	2020-06-05	Ashanti O'Keefe-Reynolds	ashanti.o'keefe.reynolds@geemail.com	Denver	Colorado	4812076228561302	63f76a72eccc5c8ee29308351dda9f50	Mastercard	39.7960171920765191	-104.902182515968008
29090	2020-06-05 15:38:22	2020-06-05	Branch Lang	branch.lang@geemail.com	Houston	Texas	3337621213560853564	b67f06d2930dcb1ef7f5789f086e13eb	Voyager	29.7805365289639674	-95.3339451269261531
29091	2020-06-05 15:40:10	2020-06-05	Fabiola Stroman	fabiola.stroman@geemail.com	Stamford	Connecticut	869924612538040910	901a5a33c1da5bb82e86d7eb8a3daa7f	JCB 15 digit	40.9947270255420406	-73.4599582410454843
29092	2020-06-05 15:46:15	2020-06-05	Fairy Stroman	fairy.stroman@geemail.com	Seattle	Washington	3042512543192563	39ca6bb9c2fadef89a96d3214594904a	Voyager	47.5639529579710185	-122.261614050382377
29093	2020-06-05 15:46:42	2020-06-05	Marc Kshlerin	marc.kshlerin@woohoo.com	San Francisco	California	6011512825215975393	4a241b33fe9d49d41ddf3d35f358b46a	Voyager	37.7945247011772949	-122.427231776910446
29094	2020-06-05 15:49:47	2020-06-05	Dr. Nikhil Metz	dr.nikhil.metz@geemail.com	San Antonio	Texas	4254142662862716	ec1d1952235a27cdda1c84a98776227e	VISA 16 digit	29.5703358518961821	-98.5860860425814991
29095	2020-06-05 16:00:39	2020-06-05	Dr. Tyson Cartwright V	dr.tyson.cartwright.v@geemail.com	Fort Worth	Texas	4804923801981037	05795a6d50d72b8be8d0cddda85cc6a0	VISA 16 digit	32.8599926853608366	-97.2532634521190005
29096	2020-06-05 16:02:12	2020-06-05	Banks Stoltenberg	banks.stoltenberg@woohoo.com	Henderson	Nevada	210050296464199267	ba441c60821b69322f996bc82d08c27f	VISA 16 digit	35.9388998774744621	-115.02855233691335
29097	2020-06-05 16:06:55	2020-06-05	Christiana Dare-Schroeder	christiana.dare.schroeder@geemail.com	Jacksonville	Florida	4872559265584	f976fb6af1b3bdfcf712992087fb5793	Maestro	30.2379604260955013	-81.6136193441305409
29098	2020-06-05 16:07:54	2020-06-05	Dr. Napoleon Trantow	dr.napoleon.trantow@geemail.com	St. Louis	Missouri	210034646868369687	7903e8b1d4099d083ce582f332923b86	American Express	38.6924154317628606	-90.2089075488973435
29099	2020-06-05 16:08:35	2020-06-05	Mills Hayes	mills.hayes@woohoo.com	Seattle	Washington	3528100508783254965	e3ee2a4e709e3a7fc98eb02116005e19	Mastercard	47.5858590126894399	-122.369995602678131
29100	2020-06-05 16:15:06	2020-06-05	Dr. Rayan Kris	dr.rayan.kris@warmmail.com	Sacramento	California	3714977304450334	3c86bb18d77feb5f422eda91bfc242cc	Discover	38.6197534446869071	-121.482813080145419
29101	2020-06-05 16:28:23	2020-06-05	Rayburn Altenwerth	rayburn.altenwerth@geemail.com	Alexandria	Virginia	3414899730969630	c86ca98324b13e18d2309a1594ac946c	VISA 16 digit	38.8543843528371298	-77.0007082017589397
29102	2020-06-05 16:28:49	2020-06-05	Latrice Mayert	latrice.mayert@geemail.com	Memphis	Tennessee	869963144522265768	cc5958ff8ea472207a91ac7d60ad2927	VISA 16 digit	35.0979099780388211	-89.9073350962042781
29103	2020-06-05 16:37:02	2020-06-05	Dr. Raymon Mante	dr.raymon.mante@warmmail.com	Sunnyvale	California	4586078183520	bd2c04a7a405f0972718c5a4cf9ce2fd	American Express	37.4345112584523889	-122.036077077659968
29104	2020-06-05 16:49:43	2020-06-05	Gianna Lemke	gianna.lemke@geemail.com	Corpus Christi	Texas	639025837479879	7e1a29935797026eafcd89be5cce8087	Discover	27.8409513298358782	-97.1557716664686808
29105	2020-06-05 16:50:47	2020-06-05	Eliot Schiller	eliot.schiller@geemail.com	Baton Rouge	Louisiana	55397603761027202	d4ff9c67b1b011af85a068b094eb232e	VISA 16 digit	30.4078883130315702	-91.1221169859278888
29106	2020-06-05 16:56:56	2020-06-05	Dr. Dusty Tremblay	dr.dusty.tremblay@geemail.com	El Paso	Texas	4714559434986	fe06f230c87553f1b2d98115a5911820	Maestro	31.8924431008115441	-106.415903061300526
29107	2020-06-05 17:10:35	2020-06-05	Thalia Swaniawski-Farrell	thalia.swaniawski.farrell@geemail.com	New York	New York	3158961709466774281	ee2518be6868ef33836af4cfdd695152	Discover	40.6778620145972809	-73.888490067318827
29108	2020-06-05 17:26:10	2020-06-05	Jaron Block	jaron.block@warmmail.com	Honolulu	Hawaii	4769048122247869	2ef6fb7655f6315af557bd39ceaceea3	Maestro	21.275112312215569	-157.891928773813333
29109	2020-06-05 17:33:18	2020-06-05	Ms. Deanne Corkery PhD	ms.deanne.corkery.phd@warmmail.com	Athens	Georgia	55125613469921332	d3f32f41828b1644a656cc5e7fefdfae	Voyager	33.9586353940147845	-83.440129518753281
29110	2020-06-05 17:55:59	2020-06-05	Jordin Rohan-Greenfelder	jordin.rohan.greenfelder@geemail.com	Norwalk	California	3027645721969579	b8e155e2ec13a156ff730337e9fa1ecc	Maestro	33.9355711386654519	-118.066566295878957
29111	2020-06-05 18:05:59	2020-06-05	Heber Schimmel	heber.schimmel@geemail.com	Columbus	Ohio	4703289267117199	f3ae3d5a396a0ae4925ee72bad16d071	Discover	39.9576383351393005	-82.9927612397588916
29112	2020-06-05 18:07:21	2020-06-05	Jeanmarie Walker	jeanmarie.walker@warmmail.com	Olathe	Kansas	4605660906981147	8ab7bcbb3ac65fc474c00bf525a78c7f	VISA 16 digit	38.9601128148503619	-94.9188459902238151
29113	2020-06-05 18:23:14	2020-06-05	Baron Weimann	baron.weimann@geemail.com	Tulsa	Oklahoma	869921214885570608	ee9eed61fef476ba9e57733820188850	Discover	36.1311967341132458	-95.9949031285431147
29114	2020-06-05 18:27:37	2020-06-05	Sanders Vandervort	sanders.vandervort@geemail.com	New York	New York	869949801408596884	f15c83697be151c0da9af3c6c4a898b7	JCB 16 digit	40.5833465657420476	-73.9117410841759295
29115	2020-06-05 18:33:48	2020-06-05	Mrs. Gustie Dooley	mrs.gustie.dooley@woohoo.com	Orlando	Florida	3112420012579855575	889bda319915121a5f1b55680c071076	Mastercard	28.4388549308091392	-81.2295811438899449
29116	2020-06-05 18:41:34	2020-06-05	Rosalee Carter	rosalee.carter@woohoo.com	Philadelphia	Pennsylvania	4821202955824890	84eef2f34aa2108e9c9a420949715943	Mastercard	39.9774398990400144	-75.0475308349255528
29117	2020-06-05 18:41:35	2020-06-05	Ms. Lara O'Reilly	ms.lara.o'reilly@geemail.com	Chicago	Illinois	51071011698012805	8df594a87e17eb71a9d1b88ea413e80a	Diners Club / Carte Blanche	41.9216177159290808	-87.645992728232585
29118	2020-06-05 18:44:07	2020-06-05	Delano Hilll	delano.hilll@geemail.com	Athens	Georgia	4484697663468005	f3964d6975735018f8ad867b4ea95801	Diners Club / Carte Blanche	33.9693883200831692	-83.4283364373840328
29119	2020-06-05 18:44:54	2020-06-05	Cailyn Predovic	cailyn.predovic@geemail.com	Syracuse	New York	4471340451062582	94077b75dda7643ca61214a31c86ad1d	American Express	43.0169515855927003	-76.1717288149766745
29120	2020-06-05 18:46:58	2020-06-05	Duke Zulauf	duke.zulauf@geemail.com	Meridian	Idaho	676172536161044	5e20018678f1563760839abc0f243244	JCB 16 digit	43.5883680820472534	-116.403609899285811
29121	2020-06-05 18:47:02	2020-06-05	Miss Dulce Koss	miss.dulce.koss@warmmail.com	Riverside	California	4234772008775324	c2971b1eeeb19d9df59782cda569c154	American Express	33.9315696219861493	-117.330803105604645
29122	2020-06-05 18:58:38	2020-06-05	Mateo Armstrong	mateo.armstrong@geemail.com	Houston	Texas	060449862534143	fe7eb9e88e7e93e58c5a606c88716f08	VISA 16 digit	29.8004298100326217	-95.3791305664010309
29123	2020-06-05 19:00:13	2020-06-05	Ellar Jerde MD	ellar.jerde.md@geemail.com	Columbus	Ohio	4182595917208000	dce80448a403d1509ac90d08054fad87	Voyager	39.9591382932893922	-82.9589003473289353
29124	2020-06-05 19:08:10	2020-06-05	Verne Runolfsson	verne.runolfsson@geemail.com	Chicago	Illinois	676140409839509	38332432ae9b048ea767a9b113b5a949	VISA 16 digit	41.9056187211371949	-87.615625575979422
29125	2020-06-05 19:16:31	2020-06-05	Alline Rice	alline.rice@geemail.com	Charlotte	North Carolina	180009939689734440	263ff36489c823a224ff5d125be97096	VISA 13 digit	35.1770421486601208	-80.8041983979232583
29126	2020-06-05 19:17:51	2020-06-05	Alissa Leuschke-Wiza	alissa.leuschke.wiza@geemail.com	Jacksonville	Florida	3468005136350814	6152b407ae1f83a51243af1ab8fe3b14	VISA 16 digit	30.3068564600363359	-81.7450022173658084
29127	2020-06-05 19:20:05	2020-06-05	Ebenezer Roob	ebenezer.roob@geemail.com	San Francisco	California	180065144307163590	85e0f2f303ad579b5855b8b3188771e4	Discover	37.764464847789732	-122.438220493103358
29128	2020-06-05 19:27:42	2020-06-05	Pratt Bosco	pratt.bosco@geemail.com	Arlington	Texas	4131689704440827	00a7075ce03cb330c4f7ef882be44d87	VISA 13 digit	32.7663538835726627	-97.2060092310447317
29129	2020-06-05 19:30:48	2020-06-05	Barrie Wunsch	barrie.wunsch@warmmail.com	Provo	Utah	54104017605565604	14d66e450fe43912df69b80255737f8c	VISA 16 digit	40.2235403062097703	-111.654953935756538
29130	2020-06-05 19:38:16	2020-06-05	Will Will Sr.	will.will.sr.@geemail.com	Houston	Texas	3708592017385475	ed7b78d0557cb7050353e38b8e788293	Voyager	29.8718555140852935	-95.3472084816094565
29131	2020-06-05 19:39:38	2020-06-05	Jann Kihn	jann.kihn@geemail.com	San Francisco	California	6011083836621612644	215038abd86ac54bc83cdf279f01379d	VISA 16 digit	37.7871533876107009	-122.414567063369688
29132	2020-06-05 19:45:29	2020-06-05	Mickey Langworth-Greenholt	mickey.langworth.greenholt@warmmail.com	Miramar	Florida	3051674901638198	41d30ed89e5a6d188181c7287230578a	American Express	25.9523554504364746	-80.2368101252701251
29133	2020-06-05 19:56:28	2020-06-05	French Goyette-Sauer	french.goyette.sauer@warmmail.com	Fort Worth	Texas	51776240589701170	b354f6c050411ddb2ffb82215a406c9e	Maestro	32.7983807369191211	-97.3716714420176999
29134	2020-06-05 19:57:36	2020-06-05	Mr. Harl Ziemann	mr.harl.ziemann@geemail.com	Berkeley	California	51180614357277409	89fa92eace349c16d554c315f4863449	VISA 16 digit	37.8292040609619846	-122.287720436730297
29135	2020-06-05 19:58:35	2020-06-05	Chet Pfannerstill	chet.pfannerstill@geemail.com	Atlanta	Georgia	501885295877451	8ee64d230e352b11728afc19317ea8d1	JCB 16 digit	33.8149349292084622	-84.4319651607003152
29136	2020-06-05 20:02:18	2020-06-05	Sharde Zieme	sharde.zieme@geemail.com	Berkeley	California	501869049945145	bdf3e68c5a4943f288eda0edd330d902	VISA 16 digit	37.8890025206670913	-122.256240588745868
29137	2020-06-05 20:14:07	2020-06-05	Mrs. Glendora Quigley DDS	mrs.glendora.quigley.dds@geemail.com	Norman	Oklahoma	869960943758267908	d42d52a6ad2bfeeb9a179fe9097ed1b8	Mastercard	35.1955079410731813	-97.3772423582870488
29138	2020-06-05 20:28:31	2020-06-05	Dr. Mirtie Leffler	dr.mirtie.leffler@woohoo.com	Tucson	Arizona	55980738005353692	232adf45e095155fe06ec9f3f140fa6b	JCB 15 digit	32.0826195975806598	-110.802782805426418
29139	2020-06-05 20:37:10	2020-06-05	Sumner Herzog	sumner.herzog@geemail.com	San Antonio	Texas	54427485001630308	bd225d6de0a07e329081d28c7afb0af8	Voyager	29.4023906275700782	-98.5757051931995818
29140	2020-06-05 20:40:33	2020-06-05	Harper Prohaska	harper.prohaska@geemail.com	San Francisco	California	869975676002851910	8788aa9e3ece1c17d3111ae88c5c1539	JCB 15 digit	37.7609317966812696	-122.414543849155734
29141	2020-06-05 20:45:42	2020-06-05	Adam Feest	adam.feest@geemail.com	Berkeley	California	4964312739336611	bdd5567c668d0c9f8ddf47534740b362	Voyager	37.863987741933478	-122.250788304478164
29142	2020-06-05 21:02:49	2020-06-05	Yadiel Ortiz	yadiel.ortiz@geemail.com	Syracuse	New York	3701150831324241	dd3a3dae44a362a076b5f16d11ce3267	VISA 16 digit	42.9816208438333121	-76.1073378743384126
29143	2020-06-05 21:02:50	2020-06-05	Delaney O'Reilly	delaney.o'reilly@geemail.com	Tallahassee	Florida	180096655739220602	89c97073faeeee8a061924305c819f32	JCB 16 digit	30.5082102083157771	-84.3238795930068932
29144	2020-06-05 21:04:36	2020-06-05	Andrae Kris	andrae.kris@geemail.com	Hayward	California	869910412720970057	75638026f7f6a129fec6ed287c7cbc3e	American Express	37.7119119477447171	-122.066494158774248
29145	2020-06-05 21:06:35	2020-06-05	Lilburn Heathcote	lilburn.heathcote@geemail.com	Dallas	Texas	3112087639650119390	bd4df29b1e35f30f8d642ef5e1dc2585	VISA 16 digit	32.850396862420439	-96.851157911770045
29146	2020-06-05 21:12:12	2020-06-05	Needham Paucek	needham.paucek@geemail.com	Austin	Texas	3528265690265248466	70ec171fa01996f355d5f8a683845ff1	VISA 16 digit	30.3838674222245793	-97.8128679031278949
29147	2020-06-05 21:13:19	2020-06-05	Antony Mertz	antony.mertz@geemail.com	New York	New York	3424938558145978	854ba2b2fcea75671e55fb2306c03d5c	Mastercard	40.6749778586197621	-73.8921406103193732
29148	2020-06-05 21:19:43	2020-06-05	Syble Hudson	syble.hudson@geemail.com	New York	New York	4161168698916871	463a9c3e9df988b38d12bf5d0260ed4d	American Express	40.619127290531992	-73.8663112689636563
29149	2020-06-05 21:21:05	2020-06-05	Kamryn Dooley DDS	kamryn.dooley.dds@geemail.com	Fresno	California	51598099407528876	e3bc272128c187cf54293ce14e50239c	Maestro	36.7399638073392225	-119.825638291250542
29150	2020-06-05 21:29:18	2020-06-05	Penny McKenzie	penny.mckenzie@woohoo.com	Fremont	California	3337287989056908732	62fb0077f6b8e473bb2d9aecc2e75084	Voyager	37.4230856907255998	-121.891709636942295
29151	2020-06-05 21:41:24	2020-06-05	Dr. Keaton Skiles	dr.keaton.skiles@geemail.com	Boston	Massachusetts	3786157244931114	19a52974675fb47018c58142ff9ad64a	American Express	42.2321046381890781	-71.0269997329402685
29152	2020-06-05 21:45:28	2020-06-05	Andres Kulas	andres.kulas@geemail.com	Los Angeles	California	676137714822709	90ebd74bd3fbe1bbcaf9ece6655876a6	Voyager	33.9820180640887415	-118.477371906488386
29153	2020-06-05 21:46:35	2020-06-05	Clemens Smitham-Ryan	clemens.smitham.ryan@warmmail.com	Oakland	California	6011968948469499149	ccac3201b12c06ec5b967e37b51f8f8c	VISA 16 digit	37.8147991677183413	-122.296210091739567
29154	2020-06-05 21:56:52	2020-06-05	Jalyn Mayer MD	jalyn.mayer.md@geemail.com	Philadelphia	Pennsylvania	210091943061993870	3bbdf661d433c64d163f4c52b3c79f48	Diners Club / Carte Blanche	40.0430636720225195	-75.0943916540492324
29155	2020-06-05 22:07:31	2020-06-05	Elbert Roob V	elbert.roob.v@geemail.com	Phoenix	Arizona	4926271015635798	3cd2a680a705b06d673e15f00dc77b32	American Express	33.6037988463349677	-112.019292535812042
29156	2020-06-05 22:09:41	2020-06-05	Kiley Kub	kiley.kub@geemail.com	South Bend	Indiana	4878169085536	3637fb4011a4fd21700778b80235338f	Maestro	41.755364150009683	-86.2521020652782227
29157	2020-06-05 22:18:05	2020-06-05	Mr. Kaleb Boehm	mr.kaleb.boehm@geemail.com	Kansas City	Missouri	3010527477907861	9802b9bd481136c126511df9526ddd5c	JCB 15 digit	39.1552159459166234	-94.4819979457408152
29158	2020-06-05 22:21:12	2020-06-05	Marlyn Roberts	marlyn.roberts@geemail.com	New York	New York	55630602972752613	b6e8b4cc40809fed607ffba27ab6224c	Diners Club / Carte Blanche	40.6484236295558503	-73.8796808487165748
29159	2020-06-05 22:33:26	2020-06-05	Norman Leannon	norman.leannon@geemail.com	Norman	Oklahoma	3088663805499125029	d18ea8a9de713d2a3a54549d8750c776	Diners Club / Carte Blanche	35.1922454200726023	-97.3493309136267726
29160	2020-06-05 22:37:03	2020-06-05	Jenifer Abshire MD	jenifer.abshire.md@geemail.com	Carlsbad	California	52088663184844694	ba316ab789d5517a28c530e12f9821b5	American Express	33.0781180212680255	-117.254410797476012
29161	2020-06-05 22:46:49	2020-06-05	Gayla Hudson	gayla.hudson@geemail.com	Oakland	California	3528960734406308512	a1d6c35ad56c1db97b31fe46b006b409	American Express	37.7975707839764112	-122.255408863533376
29162	2020-06-05 22:59:20	2020-06-05	Wilson Nicolas	wilson.nicolas@geemail.com	Albuquerque	New Mexico	3727734485408945	6674d91141d4abe7a415d07297cc589e	JCB 15 digit	35.0549228020146515	-106.693656430260845
29163	2020-06-05 23:00:21	2020-06-05	Patrica Harvey	patrica.harvey@woohoo.com	Virginia Beach	Virginia	3030808165342896	6217cb935fbed9219dacfbe1d96b786d	Discover	36.8140826744213712	-76.0689458797823619
29164	2020-06-05 23:11:28	2020-06-05	Miss Darleen Wisoky PhD	miss.darleen.wisoky.phd@geemail.com	Gilbert	Arizona	3009489347735751	8dce5dcc9b925ae02278eab3137d7d37	JCB 16 digit	33.2627761166889186	-111.722649658857279
29165	2020-06-05 23:13:17	2020-06-05	Bradly McDermott	bradly.mcdermott@geemail.com	Berkeley	California	503830222598861	614988564beef3dc1195eea4a75b93c5	JCB 15 digit	37.8890295209639945	-122.26794374031428
29166	2020-06-05 23:14:17	2020-06-05	Gwen Crist DDS	gwen.crist.dds@geemail.com	San Diego	California	54310817583385804	f9e060a12c8fde99f3f0e18bc9969dce	JCB 16 digit	32.9017327012095606	-117.06296235210263
29167	2020-06-05 23:20:35	2020-06-05	Dandre Ruecker	dandre.ruecker@geemail.com	Charleston	South Carolina	3158521401405151671	2f16393e90e5b6e3e8689f1e0198d08c	JCB 16 digit	32.7208879445675791	-79.8736652203984647
29168	2020-06-05 23:33:39	2020-06-05	Dominga Greenfelder	dominga.greenfelder@geemail.com	San Francisco	California	3337311091540344218	c750f792dfeb83c3b027f0d2388471ad	Maestro	37.7732460219272284	-122.443178478053312
29169	2020-06-05 23:39:17	2020-06-05	Nello Rempel	nello.rempel@geemail.com	Dayton	Ohio	180017876912607748	4a584e048896d3a0b45405a619ade028	Diners Club / Carte Blanche	39.8626659574709805	-84.2188149843555038
29170	2020-06-05 23:42:59	2020-06-05	Benny Keeling	benny.keeling@woohoo.com	Charlotte	North Carolina	3088063490600669573	6e3065d510819a748760bc6ff17b36a5	JCB 15 digit	35.1388092115774739	-80.7574036444015775
29171	2020-06-05 23:47:56	2020-06-05	Sandi Schimmel PhD	sandi.schimmel.phd@warmmail.com	San Francisco	California	3442278802912396	ed747bccf66b9aa9ee0509ee6673e176	Maestro	37.719654011076365	-122.406538338964694
29172	2020-06-05 23:54:50	2020-06-05	Tiara Metz	tiara.metz@geemail.com	New York	New York	869917666006477433	a13e8cfa5140def82fcbf0de992c1ec7	Diners Club / Carte Blanche	40.613496225303038	-73.8749874026875943
29173	2020-06-06 00:02:26	2020-06-06	Mayra Macejkovic	mayra.macejkovic@woohoo.com	Boston	Massachusetts	210064429385385277	0ddd2266fbdd16d220a591c38e1fdf70	VISA 16 digit	42.2994852136056849	-70.9637101602692155
29174	2020-06-06 00:04:32	2020-06-06	Paisley Ortiz DVM	paisley.ortiz.dvm@geemail.com	Buffalo	New York	4807670838448	739a006344a42f0e62fd607a7438a043	JCB 15 digit	42.8598619732726362	-78.8089931834887807
29175	2020-06-06 00:09:29	2020-06-06	Marie Murphy-Schmidt	marie.murphy.schmidt@warmmail.com	San Francisco	California	869979340322817723	ede3daf3f9b0d741d61989473dc63b1d	VISA 16 digit	37.783057796261609	-122.462263633702847
29176	2020-06-06 00:16:18	2020-06-06	Mr. Elby Hirthe MD	mr.elby.hirthe.md@geemail.com	Chicago	Illinois	676138693702904	b6383cd6e0e6768793fb8b5277fe3304	JCB 16 digit	41.8502167498994666	-87.7711910213839275
29177	2020-06-06 00:23:13	2020-06-06	Mrs. Zandra Schowalter	mrs.zandra.schowalter@warmmail.com	Richmond	Virginia	3723991665261205	314869449a4fb73f1205246300b0be6e	JCB 15 digit	37.4901049824651338	-77.4218855655044251
29178	2020-06-06 00:31:46	2020-06-06	Littleton Zemlak	littleton.zemlak@geemail.com	Fort Worth	Texas	6011844648305876712	59802134ecd1f9f7a28a476969dcd2a7	American Express	32.8195573846865472	-97.3011977112673208
29179	2020-06-06 00:32:36	2020-06-06	Dr. Vicente Walker V	dr.vicente.walker.v@geemail.com	San Francisco	California	4140023076474488	59a093b94fd961011e5784fc8a21ecb2	Discover	37.7581478916441569	-122.421113908163306
29180	2020-06-06 00:37:09	2020-06-06	Dr. Kennth Hodkiewicz III	dr.kennth.hodkiewicz.iii@geemail.com	Shreveport	Louisiana	3112896781737777740	a476fa5f04b22cd4cc6b5f829f241bd9	JCB 16 digit	32.5490252776309887	-93.88120817777029
29181	2020-06-06 00:42:54	2020-06-06	Mrs. Nikki Beatty	mrs.nikki.beatty@woohoo.com	Chicago	Illinois	4767948204076312	20a026a07330108684f9001422c5a655	VISA 13 digit	41.8804924481850165	-87.6293603807717574
29182	2020-06-06 00:49:12	2020-06-06	Dr. Dolores Kunze DVM	dr.dolores.kunze.dvm@geemail.com	Oklahoma City	Oklahoma	180007627633515096	77afdbe6841bf39a2e6a1fe7fd571cf2	Maestro	35.419028483182565	-97.5478757773421705
29183	2020-06-06 00:53:51	2020-06-06	Mr. Mykel Von PhD	mr.mykel.von.phd@geemail.com	Boston	Massachusetts	3001296905232545	8184f85f81a11b058dd77c94b2d430c8	VISA 13 digit	42.3249514064919197	-70.9212241206269738
29184	2020-06-06 01:19:19	2020-06-06	Delila Carter DDS	delila.carter.dds@geemail.com	Spokane	Washington	3057284542621365	e9ac4733357b25b0219d0bf3d28051db	Diners Club / Carte Blanche	47.6141908297553655	-117.475765274455028
29185	2020-06-06 01:32:20	2020-06-06	Mr. Kristofer Heaney	mr.kristofer.heaney@geemail.com	San Francisco	California	869997691625900147	9bad9aeeb48a4f87fb9532b34a320b4e	VISA 13 digit	37.7927704617423217	-122.426436533751229
29186	2020-06-06 01:46:40	2020-06-06	Dr. Hassan Douglas DDS	dr.hassan.douglas.dds@geemail.com	New York	New York	52256143424153137	15c9e538820771d3f1575f0aa501855a	American Express	40.588826810777185	-73.9345193110767696
29187	2020-06-06 02:08:13	2020-06-06	Dr. Stonewall Nienow	dr.stonewall.nienow@geemail.com	San Francisco	California	55547982776346750	6e0c6b558315a479096a1c6595380d63	JCB 15 digit	37.7716692488065888	-122.442105000701048
29188	2020-06-06 02:13:26	2020-06-06	Dr. Shauna Rogahn DDS	dr.shauna.rogahn.dds@geemail.com	Miami Gardens	Florida	210012458621628334	8be239480b6058af20505d3bcaa0dcc4	Voyager	25.9152712399080372	-80.3002480986774003
29189	2020-06-06 02:18:57	2020-06-06	Gerold Grimes DDS	gerold.grimes.dds@woohoo.com	Santa Ana	California	3158022004359099831	13e9e08482b3773069c894fecbc7da4d	Diners Club / Carte Blanche	33.7523415493883192	-117.938124529311423
29190	2020-06-06 02:20:16	2020-06-06	Ola Schuster	ola.schuster@geemail.com	Denver	Colorado	3463304056401938	c9b7499e28064af7ac1b6807e979f07b	VISA 16 digit	39.7419625591538832	-104.903569695238403
29191	2020-06-06 02:21:08	2020-06-06	Dr. Delores Pfeffer	dr.delores.pfeffer@geemail.com	New York	New York	639074592348143	a1325e5a23bdf45c9c47e497244e0610	Voyager	40.6885288264825959	-74.0251694473333686
29192	2020-06-06 02:23:48	2020-06-06	Dr. Beryl Murphy V	dr.beryl.murphy.v@geemail.com	San Antonio	Texas	3046179362346237	5f22be7c9dc1e81071270658b013c890	American Express	29.3926286673244093	-98.5540918716531138
29193	2020-06-06 02:24:04	2020-06-06	Keven Quitzon	keven.quitzon@woohoo.com	New York	New York	3088144952693299504	5d0d421c841cc339d399da83222403e9	VISA 16 digit	40.7380406839996567	-73.9603402374673635
29194	2020-06-06 02:27:55	2020-06-06	Cena Murphy	cena.murphy@geemail.com	Los Angeles	California	3484025351700436	dcb663491c1020eae29bead9ea9e3700	VISA 16 digit	34.0145625525020066	-118.417180896735928
29195	2020-06-06 02:30:05	2020-06-06	Georgiann Rowe	georgiann.rowe@geemail.com	Raleigh	North Carolina	4183716177495637	9afd5b4feef669c4d35f7229432f0d70	Mastercard	35.8740988263994396	-78.6130154729757464
29196	2020-06-06 02:33:20	2020-06-06	Dr. Karter Bosco	dr.karter.bosco@geemail.com	Berkeley	California	4733076490023615	7f6be1004ff30a18ea0560a7896afa08	Maestro	37.8529497112304654	-122.253224307511886
29197	2020-06-06 03:02:46	2020-06-06	Ezequiel Stiedemann	ezequiel.stiedemann@geemail.com	Los Angeles	California	3158589967361764649	83f9100e779fc814aa1ea2529a0af972	VISA 16 digit	34.0931359465565507	-118.467643211594961
29198	2020-06-06 03:08:20	2020-06-06	Rohan Kemmer	rohan.kemmer@geemail.com	Oakland	California	6011110038296283903	5241a0df7321be4be99ee2b96c8089f0	Voyager	37.8213178765663898	-122.241224495755134
29199	2020-06-06 03:08:45	2020-06-06	Dylon Olson	dylon.olson@geemail.com	San Francisco	California	4498526479882	7d977329375d25e8d9f52ff876093e52	Diners Club / Carte Blanche	37.79801220405907	-122.421757091801894
29200	2020-06-06 03:11:44	2020-06-06	Kegan Homenick	kegan.homenick@woohoo.com	Augusta	Georgia	869919467557768827	bc158d32136696a1f7c8027d6e2b8f65	JCB 15 digit	33.2896358108352857	-82.1329210311468785
29201	2020-06-06 03:16:38	2020-06-06	Con Jakubowski-Schaefer	con.jakubowski.schaefer@geemail.com	New York	New York	3096909664597635122	39ab40eb1b072a3c0488a130031943dc	VISA 16 digit	40.7156459171548448	-73.895205825370553
29202	2020-06-06 03:16:40	2020-06-06	Verner Metz I	verner.metz.i@geemail.com	San Francisco	California	4694249278615	8e845d882f80cee5878990989d16f595	Diners Club / Carte Blanche	37.7756735456161294	-122.415651689693334
29203	2020-06-06 03:27:24	2020-06-06	Jayde Schimmel-Roberts	jayde.schimmel.roberts@geemail.com	Vallejo	California	3030933246746202	86c76b8c88ca4632d532e6a87eb24941	Maestro	38.011589765417952	-122.31175779177434
29204	2020-06-06 03:38:35	2020-06-06	Zoa Hansen	zoa.hansen@warmmail.com	Chicago	Illinois	55909860834460874	33e4fdb79491cbbb3ada8762d1388b78	JCB 16 digit	41.8684419712819178	-87.745398476396872
29205	2020-06-06 03:48:11	2020-06-06	Bettye Windler DVM	bettye.windler.dvm@geemail.com	Seattle	Washington	53770323418631457	1b0412e6f77bba74a54435a3d407b8ec	Mastercard	47.5810200910009442	-122.421775590201463
29206	2020-06-06 03:52:29	2020-06-06	Mr. Layne Bashirian	mr.layne.bashirian@geemail.com	Austin	Texas	869989962100837066	6d35c33b7ffb5a355d5cf11f06b89599	Mastercard	30.2763751451052698	-97.7988408296607474
29207	2020-06-06 03:56:10	2020-06-06	Judge Goodwin	judge.goodwin@geemail.com	Green Bay	Wisconsin	869970483447820591	e6028c30ce20e6858a20f79b2b66c4fb	Voyager	44.5086768496844911	-88.0775024775702491
29208	2020-06-06 04:02:09	2020-06-06	Kiara Donnelly-Satterfield	kiara.donnelly.satterfield@geemail.com	Columbus	Georgia	639033434560141	52143ae88bb68c0ec1dcd1fc04e6c800	JCB 16 digit	32.4750035350721333	-84.8089133127290751
29209	2020-06-06 04:16:12	2020-06-06	Genie Waters III	genie.waters.iii@geemail.com	San Diego	California	4519353994318399	de37173ca82dd7878a875c5cf9b75b73	VISA 16 digit	32.7589028445139547	-117.056359497494995
29210	2020-06-06 04:20:41	2020-06-06	Ms. Felicitas Howell	ms.felicitas.howell@geemail.com	Sacramento	California	4514207659822	7b13ee191197f6ee1bfffe21c23f0c1d	JCB 16 digit	38.508603788752481	-121.539286374977223
29211	2020-06-06 04:23:36	2020-06-06	Bryn Gleichner	bryn.gleichner@woohoo.com	San Francisco	California	869979614254940806	56f0afd99b4890c7f0e98868571fff46	Voyager	37.7852518576199472	-122.451705340491245
29212	2020-06-06 04:31:06	2020-06-06	Saint Conn	saint.conn@woohoo.com	Boston	Massachusetts	869960190156307551	f806d716d626a527c24cdb8248c37fe1	Voyager	42.3897709107194132	-71.006749224564814
29213	2020-06-06 04:36:06	2020-06-06	Letha Lynch	letha.lynch@geemail.com	Long Beach	California	501816986692990	cd55af2f9f104f454c221ad90bda942c	VISA 16 digit	33.9072638239067032	-118.187803118598836
29214	2020-06-06 04:42:48	2020-06-06	Ms. Angelita Bernier	ms.angelita.bernier@geemail.com	New York	New York	6011944851255500287	95eafc3b26a3f037547f8b3538059b63	Diners Club / Carte Blanche	40.6768322753943465	-73.9818038474198403
29215	2020-06-06 04:43:31	2020-06-06	Mrs. Graciela Huel	mrs.graciela.huel@woohoo.com	Chicago	Illinois	3088726569480433678	4814cac3a2d86dd53391a01146eec8f0	Maestro	41.873620546779037	-87.6795455536369133
29216	2020-06-06 04:59:12	2020-06-06	Ms. Kattie Durgan PhD	ms.kattie.durgan.phd@geemail.com	Cape Coral	Florida	54488688881652013	1d086496b46f73dc1f344e2366c73fb4	VISA 16 digit	26.5437339254159497	-81.9718908460881579
29217	2020-06-06 05:06:00	2020-06-06	Seymour Muller	seymour.muller@geemail.com	Oklahoma City	Oklahoma	3088246665601107794	e11b8d94833a438f8be42efda9579531	VISA 13 digit	35.5070262032471646	-97.4150780157547445
29218	2020-06-06 05:06:34	2020-06-06	Liana Champlin	liana.champlin@warmmail.com	New York	New York	4131904582761594	145d7c180c83252863bd51fa8fd3c5a9	American Express	40.6957366180364062	-73.9919515889033619
29219	2020-06-06 05:11:56	2020-06-06	Alver Donnelly	alver.donnelly@geemail.com	Dallas	Texas	869974597589534797	4d12003bd4956896b61d92157f36583e	American Express	32.8279472687087974	-96.6922929045241233
29220	2020-06-06 05:26:59	2020-06-06	Shelbie Nitzsche	shelbie.nitzsche@woohoo.com	Scottsdale	Arizona	3747654112239115	c6413fcee33f45448392e0de344d2433	American Express	33.7681537675328585	-111.874139276376354
29221	2020-06-06 05:32:23	2020-06-06	Domenica Kilback	domenica.kilback@geemail.com	Nashville	Tennessee	3158502396020026196	511b0906d2c967376a14befbb7cfd797	Mastercard	36.2204430608201733	-86.8423736933060013
29222	2020-06-06 05:44:12	2020-06-06	Ken Pollich	ken.pollich@geemail.com	Baltimore	Maryland	3040235424469429	e08614f3944138bbf611f627c0427dca	JCB 15 digit	39.3762657675426411	-76.677505403060465
29223	2020-06-06 05:55:29	2020-06-06	Orin Lueilwitz	orin.lueilwitz@geemail.com	Colorado Springs	Colorado	6011855526274362136	5e497d2de51642620c8b5985bc73d5a4	JCB 16 digit	38.8145867485601457	-104.776783529312169
29224	2020-06-06 05:57:32	2020-06-06	Kalyn Volkman	kalyn.volkman@geemail.com	Pittsburgh	Pennsylvania	3088417980852818897	4a2d55e8e41ffca25041e00ff37f0766	American Express	40.5084712773516742	-80.0399504727389655
29225	2020-06-06 06:06:36	2020-06-06	Myra Spencer	myra.spencer@geemail.com	Oakland	California	3416932189269182	390d85ac73e9f42998ed9c7a662e7d6d	Maestro	37.8298057253388293	-122.264579040844069
29226	2020-06-06 06:20:43	2020-06-06	Mrs. Shakira McLaughlin DDS	mrs.shakira.mclaughlin.dds@geemail.com	San Francisco	California	675931352743590	7d011ba5640bee87aa00837ac8fa8f72	JCB 16 digit	37.7524770113489794	-122.473269873767777
29227	2020-06-06 06:28:56	2020-06-06	Leonce Farrell	leonce.farrell@woohoo.com	North Las Vegas	Nevada	4607761031915	175f0c25bca891f216bedbbe30e86445	Maestro	36.278528350514172	-115.141191732020687
29228	2020-06-06 06:38:37	2020-06-06	Dwaine Kemmer	dwaine.kemmer@woohoo.com	Los Angeles	California	4503105088486906	4af021a649eb8198f4790a70789fda31	VISA 13 digit	34.0782780121412117	-118.486507847066221
29229	2020-06-06 06:38:44	2020-06-06	Trayvon Abernathy	trayvon.abernathy@geemail.com	Memphis	Tennessee	3470188114873845	ff9895218dc5768f55fefdb237aa3f5c	Mastercard	35.2027080825131407	-89.8955496661622107
29230	2020-06-06 06:48:15	2020-06-06	Delano Herzog	delano.herzog@geemail.com	New York	New York	4370054627820342	14f9cde659ec2f2d28301ae3f8ac0267	JCB 16 digit	40.5797326964084064	-73.8757618303772006
29231	2020-06-06 06:51:47	2020-06-06	Dr. Eleanor Mann	dr.eleanor.mann@geemail.com	San Francisco	California	210055169992995594	73c0f9818bd8e0885b271034dfea5d7a	American Express	37.7484064821360477	-122.466849062648492
29232	2020-06-06 06:58:20	2020-06-06	Isabella Rempel DDS	isabella.rempel.dds@geemail.com	Roseville	California	3088263736456187021	a4945b9bca763ce2a42d5481b4a67f53	JCB 16 digit	38.7363149041831463	-121.280852993227171
29233	2020-06-06 07:05:06	2020-06-06	Britt Skiles	britt.skiles@geemail.com	Los Angeles	California	3050279451101414	4d77cf481e987c93f98b1ce0afd1adc6	VISA 16 digit	33.9935649380419349	-118.312565944901849
29234	2020-06-06 07:32:05	2020-06-06	Savannah Mayert	savannah.mayert@geemail.com	New York	New York	52963888418905801	ac8a7c3460e655959849bb1134753489	Maestro	40.7445153603088102	-73.9882474877301632
29235	2020-06-06 07:32:20	2020-06-06	Versie Hyatt	versie.hyatt@warmmail.com	Los Angeles	California	54107784027399683	f345f2a08f12d712f87d21cdf2a1675e	VISA 16 digit	34.0920029868703338	-118.459623863733555
29236	2020-06-06 07:33:24	2020-06-06	Leoma Grant DVM	leoma.grant.dvm@geemail.com	Nashville	Tennessee	4723172854620070	adf656b8334e22919ae90fd9d963003a	Diners Club / Carte Blanche	36.1450684017624653	-86.7127352300938128
29237	2020-06-06 07:47:51	2020-06-06	Eleanora Tromp	eleanora.tromp@woohoo.com	New York	New York	4501368132724282	ca87a3cfa1498f3da8e9648bdc0039b1	VISA 13 digit	40.71992808526754	-73.9106729697797391
29238	2020-06-06 08:01:23	2020-06-06	Jo Witting	jo.witting@geemail.com	Boston	Massachusetts	589336306103460	74132c8e901785131f3a694ce01540bb	VISA 16 digit	42.3209282119460397	-71.0464753631919592
29239	2020-06-06 08:18:06	2020-06-06	Keven Goodwin-Swift	keven.goodwin.swift@geemail.com	Chicago	Illinois	4942998562522561	042eb78666457c5942c69fad8ed42eee	Diners Club / Carte Blanche	41.9105538200888788	-87.6296549942374128
29240	2020-06-06 08:36:20	2020-06-06	Blane Murazik	blane.murazik@geemail.com	Los Angeles	California	630422972268613	a62e27e55ebe7baf1f4cd1f639049aec	JCB 16 digit	33.9492780337907334	-118.481779900937525
29241	2020-06-06 08:44:04	2020-06-06	Juliette Collins	juliette.collins@geemail.com	Jacksonville	Florida	3726576212839442	8d243a51fb8c9a7a369b59316bfe1159	Voyager	30.4185676121670738	-81.7394120610862984
29242	2020-06-06 08:46:03	2020-06-06	Alejandro Bergnaum	alejandro.bergnaum@geemail.com	Omaha	Nebraska	4629996940798341	cae1e2a49976e7d6e3af68b0260d185d	Discover	41.2043439158849409	-96.045275918964677
29243	2020-06-06 08:51:21	2020-06-06	Loris Carroll	loris.carroll@geemail.com	Berkeley	California	210051273559859039	c45a5209494531a8ba097c972cffad4f	JCB 16 digit	37.8699522773801291	-122.263836535069998
29244	2020-06-06 08:53:36	2020-06-06	Madge Hamill-Ebert	madge.hamill.ebert@geemail.com	Fargo	North Dakota	4255761008435934	7c8f302e295918d613188ee5337747de	VISA 13 digit	46.7860590934053064	-96.8031529126185859
29245	2020-06-06 08:56:04	2020-06-06	Debora Kutch	debora.kutch@geemail.com	Garland	Texas	180066024672247526	8903b1ef22b512c982d722d4f5d5725a	VISA 13 digit	32.9552223812557727	-96.6122362103939167
29246	2020-06-06 09:00:52	2020-06-06	Mr. Jonathon Howell MD	mr.jonathon.howell.md@geemail.com	Houston	Texas	676122608346031	b15266c6ad93d135240fe2090e471ff8	VISA 16 digit	29.7409622093275203	-95.3794779865086042
29247	2020-06-06 09:25:08	2020-06-06	Dominic Hermann	dominic.hermann@warmmail.com	Riverside	California	676335451698241	c5507de82c89c25a4b54e213a7d4bc0b	VISA 16 digit	34.0149420129548758	-117.377234764207898
29248	2020-06-06 09:31:57	2020-06-06	Janae Konopelski	janae.konopelski@geemail.com	Lakewood	New Jersey	3096576476132203635	173cba6c13380dc508d7830cdad9d789	Diners Club / Carte Blanche	40.0981262716282174	-74.2659986424535532
29249	2020-06-06 09:44:42	2020-06-06	Dr. Fenton Walker	dr.fenton.walker@geemail.com	Raleigh	North Carolina	3042720059226796	5939aac81adce8efb8fe57dcd866f513	Maestro	35.8732961143966733	-78.5427940649382776
29250	2020-06-06 10:02:56	2020-06-06	Gunnar Blanda-Cruickshank	gunnar.blanda.cruickshank@geemail.com	Los Angeles	California	4673202638643	bf4b72bcf52c1f23e0d736b26af3e1de	JCB 16 digit	33.9357267560768818	-118.405583302815629
29251	2020-06-06 10:07:52	2020-06-06	Vinson Stroman	vinson.stroman@warmmail.com	Bakersfield	California	54590853185134093	1215b7b10a578ad3b630a204757a7b6a	Diners Club / Carte Blanche	35.3964730220090544	-118.979462455426528
29252	2020-06-06 10:25:16	2020-06-06	Leeroy Douglas	leeroy.douglas@geemail.com	Berkeley	California	3112067002490201528	900e14c5ef55bc885efdc7bb0a264e36	Mastercard	37.85553066482845	-122.286097004838112
29253	2020-06-06 10:32:36	2020-06-06	Dulce Abbott	dulce.abbott@woohoo.com	Providence	Rhode Island	869941014131870828	34898a21305a6a17eb398fc72099398a	VISA 13 digit	41.8256800053030204	-71.4427756797440452
29254	2020-06-06 10:35:27	2020-06-06	Dr. Renee O'Reilly DVM	dr.renee.o'reilly.dvm@geemail.com	New Orleans	Louisiana	4238151942570065	d99815cd6c5862da987ba8e08495f2e3	Voyager	30.1274152478683739	-89.8501162023078592
29255	2020-06-06 10:50:54	2020-06-06	Hurley Moore	hurley.moore@geemail.com	Little Rock	Arkansas	3096746376110440230	89cb86827330842c0a3b9999a275521f	Maestro	34.6889822735261149	-92.4210229892622692
29256	2020-06-06 11:10:56	2020-06-06	Manuela Wintheiser	manuela.wintheiser@woohoo.com	West Jordan	Utah	3494521219978576	c32e1820d4670f688a65a1572c87ebd3	VISA 16 digit	40.6888903285168126	-112.06834161342978
29257	2020-06-06 11:21:08	2020-06-06	Mrs. Wendy Bins PhD	mrs.wendy.bins.phd@geemail.com	Dallas	Texas	4849255403127645	3e0ee95b2295857f9cac121fbddef855	Voyager	32.8057601546209341	-96.8273576540835137
29258	2020-06-06 11:26:58	2020-06-06	Claire Botsford	claire.botsford@geemail.com	New York	New York	53009696149842201	bc39fd52975c7be9af08dd755752a1ad	Voyager	40.7146235808487944	-73.8725089756201925
29259	2020-06-06 11:33:22	2020-06-06	Dario Schiller	dario.schiller@woohoo.com	Las Vegas	Nevada	4754575438074	e31f20c09ecf5e94d8e848bd5197d5d8	VISA 16 digit	36.1692766660925002	-115.190008033879465
29260	2020-06-06 11:33:47	2020-06-06	Gauge Kuhlman	gauge.kuhlman@woohoo.com	Richmond	California	180022490141464997	92b095b45a6246a4186a63ccdaf9c145	Mastercard	37.9311475810084531	-122.341207101647186
29261	2020-06-06 12:15:36	2020-06-06	Rylan Thiel	rylan.thiel@geemail.com	Chicago	Illinois	630467347149816	172a8ef42b5c13927207ac67c4f4c3bc	VISA 16 digit	41.7769658529501413	-87.7463451564807428
29262	2020-06-06 12:18:17	2020-06-06	Dorinda Davis	dorinda.davis@geemail.com	North Las Vegas	Nevada	210028011129637794	78e934314df621c4e3b29071e1f334d4	Discover	36.25591050690673	-115.153503633405649
29263	2020-06-06 12:18:37	2020-06-06	Margarette Balistreri	margarette.balistreri@geemail.com	New York	New York	55441913428453782	b0ebf63f0bebaa9b644eab7dc685e20d	JCB 16 digit	40.645419597694648	-73.8712191078707576
29264	2020-06-06 12:28:41	2020-06-06	Donia Rogahn	donia.rogahn@geemail.com	New York	New York	4514290946797	a887bf78a321c715d1a967c04bfc487c	Voyager	40.5849048645924739	-73.9985198318388342
29265	2020-06-06 12:35:57	2020-06-06	Adonis Paucek III	adonis.paucek.iii@geemail.com	Philadelphia	Pennsylvania	53926446352396408	d008a91c7a872efaa24f216300037b39	Mastercard	40.0230662634089569	-75.1885128212060891
29266	2020-06-06 12:37:19	2020-06-06	Mirtie Gutmann	mirtie.gutmann@geemail.com	Sioux Falls	South Dakota	4000427155962900	6b5640983e007950ff37568f172b44e5	Maestro	43.4531979521356533	-96.6553342351391933
29267	2020-06-06 12:37:39	2020-06-06	Denese Treutel	denese.treutel@geemail.com	New Orleans	Louisiana	676181352883144	6438441e345b8332b159865ad9cd87b3	Discover	30.0230431946009411	-89.9133140370976207
29268	2020-06-06 12:42:02	2020-06-06	Miss Suzan Larkin	miss.suzan.larkin@warmmail.com	San Francisco	California	869911161513081114	ed361fcfaa26f8bc57f1bc1eff5c7f2b	American Express	37.7551215852397348	-122.432121097118795
29269	2020-06-06 12:42:13	2020-06-06	Keshia Howe	keshia.howe@warmmail.com	Waco	Texas	3158661863654045492	a45818031e18fb8dd570d72b38712b9f	American Express	31.5645298379681982	-97.2799689977560291
29270	2020-06-06 12:46:56	2020-06-06	Mr. Gilbert Parisian I	mr.gilbert.parisian.i@geemail.com	Houston	Texas	3337717408487291782	95ed298931cc9ca177f3b183f55659b4	Mastercard	29.8373638750597827	-95.3061650033589416
29271	2020-06-06 12:54:04	2020-06-06	Louanna Wolf	louanna.wolf@geemail.com	Oakland	California	3096859049673152707	4da987aeb14a51eff619a792e9b9f785	Maestro	37.8202638000333593	-122.279148507037377
29272	2020-06-06 13:09:02	2020-06-06	Ramiro Mayert	ramiro.mayert@geemail.com	Charlotte	North Carolina	501816356079497	4a2f4cb49c1560c19563fe754b71f09e	Diners Club / Carte Blanche	35.1141285974785688	-80.9255102295838356
29273	2020-06-06 13:21:18	2020-06-06	Luz Hand DVM	luz.hand.dvm@geemail.com	Oxnard	California	3088038392627702829	f1053ab8343c4ed696032bce4b4365ef	Discover	34.1421559151683027	-119.178024442764368
29274	2020-06-06 13:23:24	2020-06-06	Matie Marquardt	matie.marquardt@geemail.com	Washington	District of Columbia	51689143652565637	89dfb147de3520e19a1edd8230cffc25	Diners Club / Carte Blanche	38.987894983755794	-77.1075003557119487
29275	2020-06-06 13:23:55	2020-06-06	Giuseppe Hudson	giuseppe.hudson@woohoo.com	Boston	Massachusetts	4473348342843605	515f2acf7802c2156ab3c199658f3b72	Maestro	42.4050644044466338	-71.0392743905492097
29276	2020-06-06 13:26:32	2020-06-06	Vashti Greenholt	vashti.greenholt@geemail.com	Tampa	Florida	51666873439633657	4304919e1c35f726562ae980f692205b	JCB 15 digit	28.0152357360929223	-82.5430633153513043
29277	2020-06-06 13:37:37	2020-06-06	Cayla Russel	cayla.russel@geemail.com	Aurora	Colorado	180080856629392190	82ae70e0a952d1ca94e694f9bb5bcb32	Voyager	39.6195931191202249	-104.764730798325317
29278	2020-06-06 13:57:25	2020-06-06	Tyrin Williamson-Walsh	tyrin.williamson.walsh@geemail.com	Denver	Colorado	6011007572133018193	09084afaf0c64415a2947ffb3cfe3e2d	Diners Club / Carte Blanche	39.74756223001107	-104.954475323927028
29279	2020-06-06 14:01:23	2020-06-06	Dwan Stamm	dwan.stamm@warmmail.com	Fullerton	California	3096077862507534569	b12bffd97730fd693f859d6e4390d337	JCB 16 digit	33.8534060686983196	-117.963982073796913
29280	2020-06-06 14:03:16	2020-06-06	Miss Alyssa Huels	miss.alyssa.huels@geemail.com	San Francisco	California	3528712420635349110	adfcdb4f30be9eb81a0d68334b10f1e7	JCB 16 digit	37.7950816866321517	-122.449744426251414
29281	2020-06-06 14:04:30	2020-06-06	Miss Unknown Weissnat	miss.unknown.weissnat@warmmail.com	Anaheim	California	3022596956845007	50e9b48a8b56fa054cb912c700bed047	Mastercard	33.9227238208819202	-117.68871479180865
29282	2020-06-06 14:07:43	2020-06-06	Scotty Kohler	scotty.kohler@geemail.com	Columbus	Ohio	869951695350008624	3e241ad61c4b4767f51fb72f1a101713	Diners Club / Carte Blanche	39.8903623656414439	-83.0721346459120582
29283	2020-06-06 14:22:35	2020-06-06	Corrine Stanton DVM	corrine.stanton.dvm@warmmail.com	Berkeley	California	676131694679353	df65f4ebd65cf6dd66ad9305a5c512bd	American Express	37.8525530128096577	-122.285495862414024
29284	2020-06-06 14:46:04	2020-06-06	Britta Wilkinson	britta.wilkinson@geemail.com	Los Angeles	California	676303843677422	5ef626978b4058ae4ce5b39480c84d58	JCB 16 digit	33.9760073304507841	-118.34028136157356
29285	2020-06-06 14:46:12	2020-06-06	Waylon Stroman	waylon.stroman@woohoo.com	Austin	Texas	3713052897269748	a67ada6d2b762e6837f7872bdbf1904e	American Express	30.233916207881272	-97.791798457247765
29286	2020-06-06 14:55:54	2020-06-06	Shayna Kutch	shayna.kutch@warmmail.com	San Jose	California	869980330798114157	1d37f6a36cafd68b5ee7fdd57480a15b	Diners Club / Carte Blanche	37.2824706489972755	-121.890286016905307
29287	2020-06-06 15:02:26	2020-06-06	Mirna Kunze	mirna.kunze@woohoo.com	Santa Ana	California	869950593049727194	2d6be560807f5d8635df3568ea7d27f0	Voyager	33.833352668780087	-117.935063285326578
29288	2020-06-06 15:09:57	2020-06-06	Stephon Zulauf DVM	stephon.zulauf.dvm@woohoo.com	San Francisco	California	54238105214287451	7588e0097a7adb48fc123d868bdc1bf4	VISA 16 digit	37.7934182012035436	-122.419127488512203
29289	2020-06-06 15:23:58	2020-06-06	Dr. Jeremey Carter I	dr.jeremey.carter.i@geemail.com	Jackson	Mississippi	4533146997813834	f0903d4ce44756440dc9b11757470968	Diners Club / Carte Blanche	32.3983632116291673	-90.2265592669110816
29290	2020-06-06 15:26:19	2020-06-06	Dr. Nery Cassin	dr.nery.cassin@geemail.com	Seattle	Washington	4908058961263	5e700c6bc3769c5559dbd66dc05eac7b	JCB 16 digit	47.5963829297497867	-122.374275623719768
29291	2020-06-06 15:26:21	2020-06-06	Drury Jaskolski	drury.jaskolski@geemail.com	Clearwater	Florida	869981418199571312	4af47ce803f7c1ff12726409068bc447	JCB 16 digit	28.0016183272596457	-82.6809857739865777
29292	2020-06-06 15:28:49	2020-06-06	Bart Collier	bart.collier@geemail.com	Oakland	California	180002244539497679	9d1f1ad01cd68a4c0c178646006bd42a	JCB 16 digit	37.7984367003725623	-122.289002626718045
29293	2020-06-06 15:31:13	2020-06-06	Mrs. Karla Maggio DDS	mrs.karla.maggio.dds@geemail.com	San Francisco	California	3096987766989282903	c90902a3e3483e0b7490ce7f75121346	JCB 16 digit	37.783688031298297	-122.451431124683083
29294	2020-06-06 15:38:15	2020-06-06	Asbury Jacobi	asbury.jacobi@geemail.com	New York	New York	3528479402782765531	1eb59e9f846fd51f3832908cd26cba15	VISA 16 digit	40.7413654729947439	-74.0144025193422976
29295	2020-06-06 15:43:22	2020-06-06	Dr. Solon Nitzsche	dr.solon.nitzsche@woohoo.com	San Francisco	California	3049377232395544	33dcc8f0839cb923997cb73770496c81	JCB 16 digit	37.7618108551372629	-122.443831981308335
29296	2020-06-06 15:45:25	2020-06-06	Mason Donnelly	mason.donnelly@geemail.com	Birmingham	Alabama	3028953484613353	327b559a55b2b06f6ea7becc854c1478	American Express	33.5399079249497518	-86.8788511062283106
29297	2020-06-06 15:46:21	2020-06-06	Miles Morar-Champlin	miles.morar.champlin@geemail.com	Houston	Texas	3096098316746277022	d61f833496bc6c7d734b5403dec0e48a	Voyager	29.8254275263831019	-95.3669837604291786
29298	2020-06-06 15:51:11	2020-06-06	Danny Walker-Marquardt	danny.walker.marquardt@woohoo.com	Sterling Heights	Michigan	6011281571309481901	00df47112664ca2bf270c8a463a28ec2	VISA 16 digit	42.4927705762058494	-83.059090657734501
29299	2020-06-06 15:59:13	2020-06-06	Henrietta Botsford DVM	henrietta.botsford.dvm@geemail.com	New York	New York	6011165765915508443	91fa3aa217aea8cb6f7aa2dd32f39094	Mastercard	40.7193971509803063	-73.9386218215700239
29300	2020-06-06 16:04:51	2020-06-06	Emilie Yost	emilie.yost@geemail.com	Overland Park	Kansas	3158562443642597498	9154776aa414558065ba41960d4704ea	Mastercard	38.8510266019832358	-94.6482916005462442
29301	2020-06-06 16:17:06	2020-06-06	Michaela Murazik	michaela.murazik@geemail.com	Pompano Beach	Florida	561244128003819	76991d11a9f13ada62874a01ba869415	JCB 15 digit	26.2762802935935547	-80.1101362269684643
29302	2020-06-06 16:24:51	2020-06-06	Arnoldo Reinger	arnoldo.reinger@warmmail.com	Sterling Heights	Michigan	3792344631793628	422d277cfed2860476abd683326e2b2b	American Express	42.5298266627907751	-83.0279414998061895
29303	2020-06-06 16:30:41	2020-06-06	Dr. Halsey Kemmer	dr.halsey.kemmer@geemail.com	Milwaukee	Wisconsin	4832407618866173	2e925d0aa4c74b789f8e83e6b9affe8d	Mastercard	43.0933000212620954	-88.061933722589913
29304	2020-06-06 16:31:52	2020-06-06	Jan Bahringer	jan.bahringer@geemail.com	Chicago	Illinois	4721558657718453	ac844bcc9a28f74a56ef1f36cfe6a8b4	Voyager	41.7847491575241108	-87.6081686930760668
29305	2020-06-06 16:32:22	2020-06-06	Fate Oberbrunner	fate.oberbrunner@geemail.com	Denver	Colorado	6011973029459166635	f1d31d746e96caf9cd68f4b68bf603f6	Maestro	39.8508220459386706	-104.904888360878829
29306	2020-06-06 16:36:07	2020-06-06	Rexford Conn	rexford.conn@geemail.com	Wichita	Kansas	060415499972410	2a54afe6a57d562aa061d36435cc68eb	American Express	37.7358841086614873	-97.343028535015506
29307	2020-06-06 16:49:21	2020-06-06	Mr. Brady Hirthe MD	mr.brady.hirthe.md@warmmail.com	New York	New York	54293003616690335	4787d323b57dc5fac6fff9fec74c2a55	Maestro	40.6236190393790579	-73.9122777875874135
29308	2020-06-06 17:03:44	2020-06-06	Mrs. Carmella O'Keefe	mrs.carmella.o'keefe@woohoo.com	Nashville	Tennessee	561214574249612	37cd5254f0f04063033f9f5f043f3eb6	American Express	36.2342070753343393	-86.8081613353826071
29309	2020-06-06 17:07:42	2020-06-06	Ms. Paralee Fadel	ms.paralee.fadel@woohoo.com	Baton Rouge	Louisiana	6011487104944654682	fe230538b4142028dee7d3780cec2bca	VISA 16 digit	30.4307872881393884	-91.2072497251551511
29310	2020-06-06 17:16:05	2020-06-06	Floy Jaskolski	floy.jaskolski@warmmail.com	Columbus	Ohio	210064878682398419	beeb65203a96325d872570d20461da91	JCB 15 digit	39.9102168336089704	-83.0274171300932835
29311	2020-06-06 17:16:06	2020-06-06	Tosha Lind	tosha.lind@geemail.com	Berkeley	California	6011031079217179297	942271be244848045ead39feab070593	VISA 16 digit	37.8786106106519966	-122.277054996381565
29312	2020-06-06 17:33:37	2020-06-06	Josie Jerde	josie.jerde@warmmail.com	Sioux Falls	South Dakota	4929255736261148	a102658572251eaf9312f25daab6725b	Discover	43.6108374683272118	-96.7694753972049853
29313	2020-06-06 17:35:38	2020-06-06	Dr. Elwyn Padberg II	dr.elwyn.padberg.ii@geemail.com	Sacramento	California	3059210108466679	851515bd21b93dab1f0a8eccc4180ddf	VISA 13 digit	38.5992017208863061	-121.409833474016182
29314	2020-06-06 17:50:01	2020-06-06	Tal Predovic	tal.predovic@geemail.com	Pasadena	Texas	869982302741230867	7877e2bbc49d4ab7ff53bc58ea611a59	JCB 15 digit	29.5605327594898633	-95.1759022765740781
29315	2020-06-06 18:15:45	2020-06-06	Jelani Harris	jelani.harris@geemail.com	Tacoma	Washington	180019881261455309	81e708dc3c3025f1352e20e046719b0b	American Express	47.2520252328485242	-122.385719249933217
29316	2020-06-06 18:25:11	2020-06-06	Tremayne Osinski	tremayne.osinski@geemail.com	Fort Wayne	Indiana	3528336941276817954	9f17395156cf6e725741efaaf50d2a71	Mastercard	41.0821023312646929	-85.1022985360339277
29317	2020-06-06 18:40:54	2020-06-06	Ms. Devyn Botsford	ms.devyn.botsford@warmmail.com	New York	New York	4455917980506	bd45d92ac6b443a36568b4220fd5e7a0	Discover	40.6895374677833175	-74.021607594041896
29318	2020-06-06 18:53:33	2020-06-06	Brandin Zieme	brandin.zieme@woohoo.com	Independence	Missouri	502051203855898	9ddf682eeac47e823f6eccc3c474ed4a	Voyager	39.0190130556952255	-94.314418524438878
29319	2020-06-06 19:04:14	2020-06-06	Mell Kling MD	mell.kling.md@geemail.com	Springfield	Missouri	180041472496168495	870cd2e211d358d92310163aaed31d0f	VISA 13 digit	37.1220001442551606	-93.372702253312994
29320	2020-06-06 19:06:50	2020-06-06	Milly Shanahan DDS	milly.shanahan.dds@woohoo.com	New Orleans	Louisiana	180083705287084424	59c8a1557cc49d3f2ec20cd0777ef9bf	JCB 15 digit	30.0459888454541577	-90.0073790835011778
29321	2020-06-06 19:09:06	2020-06-06	Dr. Prosper Wiza	dr.prosper.wiza@warmmail.com	Jacksonville	Florida	4822172995828	6e8e8417d9f62a12fa9e7e52a8180e69	Maestro	30.2789133842155351	-81.5680823204651517
29322	2020-06-06 19:12:54	2020-06-06	Milan Harber	milan.harber@geemail.com	Pomona	California	4696652583962318	a1d4c9e85659070f4e88abb6819ebc4e	VISA 13 digit	34.1476756984405228	-117.702231288651376
29323	2020-06-06 19:14:29	2020-06-06	Emry Larson	emry.larson@woohoo.com	New York	New York	630473428758731	4723b024fe63186ff52e6dc961018c8a	Diners Club / Carte Blanche	40.6148939153868724	-73.9744594838831517
29324	2020-06-06 19:17:34	2020-06-06	Eartha Ondricka	eartha.ondricka@geemail.com	Phoenix	Arizona	54025719280160835	83a61d0a6eb9a52c17a5cc8ab3d5da3b	Voyager	33.4798884115114816	-112.179500705322624
29325	2020-06-06 19:26:14	2020-06-06	Dr. Hedwig Harber PhD	dr.hedwig.harber.phd@geemail.com	Vacaville	California	3088477443183833579	06c3cf8705001ae7929a88b8337353dd	Discover	38.3803302955009045	-121.952120283699784
29326	2020-06-06 19:32:48	2020-06-06	Shyheim Maggio-Auer	shyheim.maggio.auer@geemail.com	Dallas	Texas	51189612644605557	a62cff333171fb712a7bd6dadf327496	JCB 16 digit	32.8284038038264967	-96.8462860718797884
29327	2020-06-06 19:52:01	2020-06-06	Ms. Britt Johnston	ms.britt.johnston@geemail.com	Memphis	Tennessee	4624409327157334	38ceab4fe44ab1ca878a5ace5a64c8cf	JCB 15 digit	35.0147367293547873	-90.0082928256854444
29328	2020-06-06 19:53:33	2020-06-06	Miss Carlie Cruickshank	miss.carlie.cruickshank@geemail.com	Centennial	Colorado	55517126111431739	d7c90a1b1d31ddbd5831fa64b6e5d91a	VISA 13 digit	39.65905657886006	-104.802380483633286
29329	2020-06-06 20:01:38	2020-06-06	Malaki Witting	malaki.witting@warmmail.com	Mesa	Arizona	210054312159762263	1ca19d45c4853b938b7e0d8894cc9f14	Diners Club / Carte Blanche	33.3028010813664608	-111.637983717431865
29330	2020-06-06 20:01:59	2020-06-06	Dr. Rudolfo Heathcote Jr.	dr.rudolfo.heathcote.jr.@geemail.com	Jersey City	New Jersey	3096201847881427653	9f5db95b216ea5cab02172a3712f2b35	JCB 16 digit	40.7454558787807812	-73.998976146145921
29331	2020-06-06 20:04:08	2020-06-06	Kamya Mueller PhD	kamya.mueller.phd@geemail.com	Los Angeles	California	3337924105979109899	0b144bf293089d522243d2a73df3e299	Maestro	33.9597503695968541	-118.425622065038596
29332	2020-06-06 20:20:37	2020-06-06	Sofia Steuber-McDermott	sofia.steuber.mcdermott@geemail.com	New York	New York	3004179072695644	d0753c9cf39d6b6ebe52a20f6101c912	American Express	40.7548276171777388	-73.8980047962058251
29333	2020-06-06 20:21:51	2020-06-06	Aidyn Kirlin	aidyn.kirlin@woohoo.com	Los Angeles	California	4962917050377945	bd7d4182f1b24cc4cdb07b5b0e6529bf	JCB 16 digit	34.0721201872784647	-118.3207692766089
29334	2020-06-06 20:31:25	2020-06-06	Dr. Collis Hintz	dr.collis.hintz@geemail.com	San Antonio	Texas	3088260668266500775	1e410d481db7c683421151e4791eba0f	JCB 15 digit	29.390839707020298	-98.5486939666628814
29335	2020-06-06 20:36:58	2020-06-06	Kimberley Greenholt	kimberley.greenholt@geemail.com	Sterling Heights	Michigan	6011487353394731892	ba6df1050576c5d1774a6ffb2ecf303d	VISA 16 digit	42.5225669190369544	-83.0180732967492219
29336	2020-06-06 20:45:41	2020-06-06	Amya Ortiz	amya.ortiz@woohoo.com	Sacramento	California	3337701456309279665	06a6dffba382901ec536d76828f46f92	VISA 16 digit	38.5964478041309889	-121.52899771726355
29337	2020-06-06 20:55:32	2020-06-06	Miss Jeanmarie Rice	miss.jeanmarie.rice@geemail.com	Memphis	Tennessee	6011739258790946380	8f8e23c8a43b7f065e82856804df96fb	Maestro	35.1997831250142355	-89.9681133133616271
29338	2020-06-06 21:03:23	2020-06-06	Lotta Bruen	lotta.bruen@geemail.com	San Francisco	California	3054038776298487	e0c15b77f8b6856319c44d31aea78e7b	Maestro	37.7670681056613375	-122.449592223318348
29339	2020-06-06 21:20:15	2020-06-06	Christop Kulas IV	christop.kulas.iv@geemail.com	West Jordan	Utah	3014799405510051	2196928c45bec4097d7a65db882a135c	Discover	40.6946209268901526	-111.973952959439899
29340	2020-06-06 21:21:58	2020-06-06	Arther Abbott	arther.abbott@woohoo.com	Tucson	Arizona	3158483247092700957	2cb90d47b9e5815194d8e32b9e0cf5d9	VISA 16 digit	32.2010846798349206	-110.888146207504349
29341	2020-06-06 21:27:52	2020-06-06	Dr. Hayden White PhD	dr.hayden.white.phd@geemail.com	Brownsville	Texas	3096857975360026766	9eab637cbadcc45fb2781cfa85051c19	JCB 16 digit	26.0400810541197636	-97.4173396384064034
29342	2020-06-06 21:35:52	2020-06-06	Ceasar Reinger	ceasar.reinger@geemail.com	Grand Rapids	Michigan	210022102266707361	63c66fd0f2b3a0ec205393b236cc9279	VISA 13 digit	42.8789881954237799	-85.6200424005411662
29343	2020-06-06 21:37:46	2020-06-06	Chadd Spinka	chadd.spinka@geemail.com	Aurora	Illinois	3158109284093198166	2a20abb81c49eae1c4c3391716021fb3	VISA 13 digit	41.8562066113334126	-88.2869691722955565
29344	2020-06-06 21:48:39	2020-06-06	Dr. Clemens Upton	dr.clemens.upton@warmmail.com	Phoenix	Arizona	630476646933044	322837f776853128dfa4139ce1356dce	JCB 15 digit	33.4802951184500017	-112.062161812598262
29345	2020-06-06 21:53:17	2020-06-06	Dennis Von	dennis.von@geemail.com	Virginia Beach	Virginia	4996069469983374	c8b083e03ef0618b9b31aad001b0a4b6	JCB 16 digit	36.7844608036987495	-75.9953178648509038
29346	2020-06-06 21:54:12	2020-06-06	Marget Rutherford	marget.rutherford@woohoo.com	Houston	Texas	4684992989070	d53aa8bd989811a3e56509d07014014b	JCB 16 digit	29.7864661039397127	-95.4449138693526464
29347	2020-06-06 21:56:32	2020-06-06	Dr. Victoria D'Amore	dr.victoria.d'amore@woohoo.com	San Francisco	California	501891611814558	9039062aa039c4cfc2010f67813d879b	Mastercard	37.7807921491623873	-122.447258262891722
29348	2020-06-06 21:59:39	2020-06-06	Winnie Langworth PhD	winnie.langworth.phd@geemail.com	Berkeley	California	6011063792547570966	3b2da65fb143046b69fe97022ac9248c	Discover	37.911699264458683	-122.278201301199971
29349	2020-06-06 22:01:20	2020-06-06	Littleton Blick IV	littleton.blick.iv@geemail.com	Providence	Rhode Island	6011221826823748802	a6d7d1b8b9d648b93cd7ecbe42f64504	VISA 16 digit	41.9054074496816824	-71.421393796560551
29350	2020-06-06 22:07:50	2020-06-06	Gaines Leannon Sr.	gaines.leannon.sr.@geemail.com	San Francisco	California	869970891934145993	d4bcdfbc9cdb4465ed8ea66fa03c03d9	Mastercard	37.7576522783852369	-122.422823295831535
29351	2020-06-06 22:20:23	2020-06-06	Lora Collier-Klocko	lora.collier.klocko@geemail.com	Chicago	Illinois	51992728548960414	58632da23de74bc7801126b674346e52	VISA 16 digit	41.8811986828058949	-87.7742922660924449
29352	2020-06-06 22:23:50	2020-06-06	Valentine Jakubowski	valentine.jakubowski@geemail.com	Beaumont	Texas	3096899127745868617	8a8cbd828d9f8eb8bdfb8bc8ead2606e	Voyager	30.1550351591385919	-94.1986119261264889
29353	2020-06-06 22:23:53	2020-06-06	Dr. Clare Brown DDS	dr.clare.brown.dds@geemail.com	Chula Vista	California	4014561173460	71f738542cdcb4829cbd8906daf9f60e	Voyager	32.6171137650728227	-116.926562877441569
29354	2020-06-06 22:30:11	2020-06-06	Demetrios Tromp	demetrios.tromp@geemail.com	Oklahoma City	Oklahoma	3023867728170670	85372e07e283fda406b320eff3b6a7af	JCB 16 digit	35.5253520633935977	-97.5474810219265578
29355	2020-06-06 22:30:24	2020-06-06	Handy Schaefer	handy.schaefer@geemail.com	Los Angeles	California	3528159592755063323	963b00abf6e0fef70425bec0223630a9	JCB 15 digit	34.114208654487129	-118.395123711087919
29356	2020-06-06 22:33:47	2020-06-06	Clemence Wilkinson	clemence.wilkinson@geemail.com	New York	New York	675976165109448	cfc08e217e1d3bc37b420f64897c0a08	VISA 16 digit	40.6905471516996613	-73.8539549707330707
29357	2020-06-06 22:39:10	2020-06-06	Ollie Funk	ollie.funk@geemail.com	San Francisco	California	3052001759389238	f1e5de91020d2840489d14edc7c57e71	Mastercard	37.8061286154992047	-122.408839933584645
29358	2020-06-06 22:40:38	2020-06-06	Felipa Reilly DVM	felipa.reilly.dvm@woohoo.com	New York	New York	869936972654059532	4915f1a364edaa5cc903be64cb916309	JCB 16 digit	40.6568343875687574	-73.8851284939225792
29359	2020-06-06 22:42:13	2020-06-06	Lesli Hauck	lesli.hauck@geemail.com	Oakland	California	4053414447079400	47e6bc049c25b2e963cc3fd1f0f8ec52	VISA 16 digit	37.825665764875815	-122.273579548103314
29360	2020-06-06 22:46:13	2020-06-06	Nichol Keebler DDS	nichol.keebler.dds@woohoo.com	McKinney	Texas	6011936664653388092	1a636520dc64c35fb2d6e96db83aac76	American Express	33.2420576753225205	-96.6699373456016247
29361	2020-06-06 22:58:20	2020-06-06	Savion Schuppe	savion.schuppe@geemail.com	Houston	Texas	3046412426665627	996f04e45429cae66d4e1e5c5cc42341	Mastercard	29.707606003674119	-95.3829734819956201
29362	2020-06-06 23:06:26	2020-06-06	Finley Cormier	finley.cormier@geemail.com	New York	New York	6011570240968804874	6841be9c489ea5ef12829093c3d69a00	VISA 16 digit	40.668129359953106	-73.9316286455735536
29363	2020-06-06 23:29:14	2020-06-06	Giselle Zboncak-Wyman	giselle.zboncak.wyman@woohoo.com	Los Angeles	California	3337059898830285372	a0fc52bc2c28d45eaaac16069bbee44c	VISA 16 digit	34.0580422060430053	-118.398752740956098
29364	2020-06-06 23:30:17	2020-06-06	Armida Cole-Hintz	armida.cole.hintz@warmmail.com	San Francisco	California	51858464268494094	0b74e2a5d7d40464e514ca03542ee57f	VISA 13 digit	37.7734112372316133	-122.392179780881605
29365	2020-06-06 23:38:34	2020-06-06	Olof Gibson	olof.gibson@geemail.com	San Francisco	California	4816630092780	d269e9ee2451169cc83f2c32e00952fe	American Express	37.7737092735253981	-122.438515921369728
29366	2020-06-06 23:39:33	2020-06-06	Wanda Bogan	wanda.bogan@warmmail.com	New York	New York	53578824674354241	4deb531f1784ca116f43761a970d914f	American Express	40.7535903148576608	-74.0289811128646136
29367	2020-06-06 23:46:54	2020-06-06	Sheldon Welch	sheldon.welch@geemail.com	San Francisco	California	3045259056919142	2ebfebfa5643311e069231b27f7ac06d	VISA 13 digit	37.7762282994671281	-122.463690090206541
29368	2020-06-06 23:55:27	2020-06-06	Clementine Parker-Haley	clementine.parker.haley@geemail.com	Akron	Ohio	53408866152715704	1e6cdcebfd1dde18838823337b5a62ea	VISA 16 digit	40.9838073105383671	-81.4711466519474925
29369	2020-06-06 23:57:57	2020-06-06	Mercy Purdy	mercy.purdy@warmmail.com	Los Angeles	California	210087297563711504	58dd0276738e2880cbe2e3bfdec948c8	Discover	34.041826724014804	-118.359025063085554
29370	2020-06-06 23:59:27	2020-06-06	Maribeth Grimes	maribeth.grimes@warmmail.com	San Francisco	California	3088065477174060733	c1acee1b4d166f3c691cf17e45d9f7b7	American Express	37.7550012331687697	-122.450241737947593
29371	2020-06-06 23:59:29	2020-06-06	Tilman Howell PhD	tilman.howell.phd@geemail.com	Houston	Texas	3112500363474973549	5bef06e5f7fcf1ecbb9ba35c7c5b292a	VISA 16 digit	29.8801429582837983	-95.4795600999627254
29372	2020-06-07 00:04:16	2020-06-07	Edrie Mohr	edrie.mohr@geemail.com	New York	New York	6011066637599298601	85ed499c071f2dc2438e0ffb77864ad8	JCB 16 digit	40.6628619590997715	-74.0058627634204953
29373	2020-06-07 00:04:59	2020-06-07	Lucille Wyman-Lockman	lucille.wyman.lockman@geemail.com	Elk Grove	California	3050380005261462	a2ec2467ba6f3f3b64efe5b603261059	VISA 16 digit	38.3930218557644665	-121.295104340733971
29374	2020-06-07 00:27:38	2020-06-07	Brook Toy II	brook.toy.ii@geemail.com	Aurora	Colorado	503814315394321	cb7efe3e471dc2f517e47c0998e0c080	American Express	39.7580567711144681	-104.646659971785553
29375	2020-06-07 00:32:15	2020-06-07	Jennifer Hettinger	jennifer.hettinger@geemail.com	Chicago	Illinois	3337630863534931836	8690612268167d82b2d02cf8671a4f9f	Voyager	41.8432925349868867	-87.6908951531659824
29376	2020-06-07 00:36:14	2020-06-07	Cael Herzog III	cael.herzog.iii@geemail.com	Los Angeles	California	51032311454360119	c538e996e3723ded690273a56a9b31aa	VISA 13 digit	34.0396645990997513	-118.32688909573406
29377	2020-06-07 00:43:02	2020-06-07	Ardis Sipes	ardis.sipes@geemail.com	Cincinnati	Ohio	52384675967933057	33cccce04953dedabde96f81f28a0656	JCB 15 digit	39.1639855596467825	-84.4250729852162181
29378	2020-06-07 00:47:12	2020-06-07	Sammie Tremblay	sammie.tremblay@geemail.com	Gresham	Oregon	210060271667713808	95d8637bf1e59c13d11eec97de21b7e9	Mastercard	45.4367603748992082	-122.467671098446843
29379	2020-06-07 01:30:18	2020-06-07	Beyonce Padberg	beyonce.padberg@geemail.com	Newark	New Jersey	6011878255690367288	99b5c402e0847903f35352ef71df3936	JCB 16 digit	40.8002759923141483	-74.0742593181993811
29380	2020-06-07 01:40:04	2020-06-07	Dr. Cathern Satterfield	dr.cathern.satterfield@geemail.com	San Diego	California	3417660642238739	97030996e56d75860ab234dcff6a6c81	Mastercard	32.9149885823085881	-117.053038133438676
29381	2020-06-07 01:51:54	2020-06-07	Destany Kunze	destany.kunze@geemail.com	Fremont	California	869937523667226912	275924551488ad59bbcbd368ad59ce20	Diners Club / Carte Blanche	37.5655874563083074	-122.033266318169225
29382	2020-06-07 01:59:09	2020-06-07	Mrs. Jaleesa Zemlak	mrs.jaleesa.zemlak@geemail.com	El Paso	Texas	3528329465902108496	018f9f2ebe15f8d3c477f215cfc20d93	Voyager	31.8219706342849911	-106.371659376842914
29383	2020-06-07 02:17:23	2020-06-07	Joey Will	joey.will@geemail.com	Louisville	Kentucky	6011658921954527158	83e26b5cb6fbf165e347413c4e923294	Diners Club / Carte Blanche	38.0992776603806718	-85.609046999604999
29384	2020-06-07 02:17:53	2020-06-07	Vertie Howe-Lehner	vertie.howe.lehner@geemail.com	Tempe	Arizona	4136141933780	351284cc7c750e1cd4a87b294e64fc4c	JCB 15 digit	33.3857463516216697	-111.87248428282625
29385	2020-06-07 02:22:57	2020-06-07	Sam Streich	sam.streich@geemail.com	Oakland	California	4799555731188	67ddd572087c5303ad1d2ae57ed0e730	JCB 16 digit	37.8043092057609726	-122.301400654939329
29386	2020-06-07 02:35:41	2020-06-07	Dr. Hallie Skiles DDS	dr.hallie.skiles.dds@warmmail.com	Lexington	Kentucky	869933780433794953	92e1924a4be21a28ec6ca62ed419c070	Discover	38.0873461330186558	-84.4139549447122874
29387	2020-06-07 02:52:27	2020-06-07	Santina Bernier	santina.bernier@geemail.com	Columbia	South Carolina	3763840946212860	c3e571115e1a0eb5e9efcf13474a8c5c	Mastercard	34.0662658990625289	-80.9153618583939931
29388	2020-06-07 03:04:17	2020-06-07	Levon Terry	levon.terry@geemail.com	Indianapolis	Indiana	676370856532620	09c9e318e7b67dd73986980b768d3750	Discover	39.7541565960746226	-86.0558182627629407
29389	2020-06-07 03:34:51	2020-06-07	Abdiel Leuschke	abdiel.leuschke@geemail.com	Oakland	California	3010083222018471	7c7bbdb11eb1380069ae9b5843361187	Voyager	37.7993672542535961	-122.277021932180247
29390	2020-06-07 03:38:28	2020-06-07	Burley Gaylord-Feeney	burley.gaylord.feeney@woohoo.com	New Orleans	Louisiana	3528199407997467988	5b50e7a085d41c96e48f2c008c5b4916	VISA 16 digit	30.1104226348005248	-90.0056610706988778
29391	2020-06-07 03:48:04	2020-06-07	Jorden Barrows	jorden.barrows@geemail.com	New York	New York	3158082387607587435	13bbcefdb876e12586ef9d6b3ed8d8c5	JCB 15 digit	40.6839439181368761	-73.8430769010342658
29392	2020-06-07 03:54:58	2020-06-07	Gabe Harris	gabe.harris@woohoo.com	Glendale	Arizona	4381318635914539	47b37d97a5af6c80ae814e4df08d4309	Mastercard	33.530392512841523	-112.174160907722637
29393	2020-06-07 04:11:58	2020-06-07	Fredericka Stoltenberg MD	fredericka.stoltenberg.md@woohoo.com	Phoenix	Arizona	3088995204887275274	b6e5ebfa11fad701b6d5abb106c37d37	JCB 15 digit	33.5289491088993898	-112.118996732022993
29394	2020-06-07 04:12:19	2020-06-07	Nicolette Thiel	nicolette.thiel@warmmail.com	San Francisco	California	4699615042649880	35647c5d941b8b74712b6417ee8db18b	Maestro	37.7493465969964959	-122.422277291367692
29395	2020-06-07 04:33:43	2020-06-07	Matthew Carroll	matthew.carroll@woohoo.com	San Francisco	California	4471198679980	d6ba368fafc214bf3e00cacc4ef9f72d	Mastercard	37.8118132886201792	-122.46510816444318
29396	2020-06-07 04:44:44	2020-06-07	Magdalene Durgan PhD	magdalene.durgan.phd@warmmail.com	Nashville	Tennessee	4956449688042780	7f9bd4d3ad2f280ac4f43789e0a9ce8b	JCB 16 digit	36.2280800052575742	-86.8772832976561062
29397	2020-06-07 04:46:30	2020-06-07	Janell Schimmel	janell.schimmel@geemail.com	Long Beach	California	3727565431270868	3ed14590420867b3cbb95b6960997601	Voyager	33.8589133428696485	-118.211555968008184
29398	2020-06-07 04:49:29	2020-06-07	Dr. Cinnamon VonRueden	dr.cinnamon.vonrueden@geemail.com	Tacoma	Washington	3461818850454787	32b2f4e755d0e1fcd70fe30f92fe3c5f	JCB 16 digit	47.1790372554332009	-122.411070591095097
29399	2020-06-07 05:04:04	2020-06-07	Mrs. Alisson Wiza MD	mrs.alisson.wiza.md@geemail.com	Mesquite	Texas	3435082741115072	a89641c136b0c64c24107c3385785089	Maestro	32.791586418151482	-96.5221521416876556
29400	2020-06-07 05:16:53	2020-06-07	Cassius Marquardt	cassius.marquardt@geemail.com	Aurora	Colorado	3418576027633691	403c83fc7a936e416a0c64ee7351f705	VISA 16 digit	39.6194208391588205	-104.72649691222496
29401	2020-06-07 05:17:10	2020-06-07	Mr. Jaymes DuBuque MD	mr.jaymes.dubuque.md@geemail.com	Austin	Texas	210056783081944203	359d5554bc1050fb133b638a360517b1	JCB 16 digit	30.2452502370938632	-97.8474922337807698
29402	2020-06-07 05:27:24	2020-06-07	Mr. Dillion Mitchell V	mr.dillion.mitchell.v@geemail.com	San Francisco	California	6011970673360336317	82fe069e51ede39271abcedd8c63e114	JCB 16 digit	37.7402909688272388	-122.424610380343324
29403	2020-06-07 05:32:31	2020-06-07	Son Fahey	son.fahey@geemail.com	New York	New York	54468373738553854	d2defb374fd49d61f15da69c624fc188	VISA 16 digit	40.7353374147079847	-74.0188032667979599
29404	2020-06-07 05:37:32	2020-06-07	Dr. Clemente Robel	dr.clemente.robel@geemail.com	Boston	Massachusetts	51049021392432836	77a6003127ddb3be77aecea58d517f6d	Discover	42.4206321729980402	-71.0257396984796969
29405	2020-06-07 05:39:27	2020-06-07	Marleen Kuphal	marleen.kuphal@woohoo.com	Jacksonville	Florida	630480877717365	e40dac069fcb9f667e3385f3b6e9fd44	Diners Club / Carte Blanche	30.2447888164367527	-81.6823626531832048
29406	2020-06-07 05:43:12	2020-06-07	Mr. Tyree Cruickshank DVM	mr.tyree.cruickshank.dvm@warmmail.com	San Francisco	California	3470051282346269	928d2e84539749a981d17afab25b657c	Discover	37.7883271960415357	-122.460720778468428
29407	2020-06-07 05:55:48	2020-06-07	Coleton Kuhic	coleton.kuhic@geemail.com	Hayward	California	3088394470320630170	1973eeea319e6f86957a511c1b1f2ceb	Diners Club / Carte Blanche	37.6132239320769912	-122.034128996988386
29408	2020-06-07 05:56:52	2020-06-07	Jamaal Thompson	jamaal.thompson@geemail.com	Jersey City	New Jersey	6011504592559352106	ed0aaacbc5c15a9eb67b49695ab95826	JCB 16 digit	40.7724047171823685	-73.9976265594318505
29409	2020-06-07 06:09:48	2020-06-07	Ayanna Mitchell DDS	ayanna.mitchell.dds@warmmail.com	Spokane	Washington	54776416733573711	a893a3ac8af9f311dde5db6ac9beb0b2	VISA 16 digit	47.7230397955752892	-117.440279928491634
29410	2020-06-07 06:12:28	2020-06-07	Blanchard Marquardt	blanchard.marquardt@geemail.com	San Francisco	California	180023695523401362	6cb2be42db7da51b0bb99842a3dc7d77	Mastercard	37.7582381740090938	-122.41775223460381
29411	2020-06-07 06:24:20	2020-06-07	Ms. Shannan Reilly MD	ms.shannan.reilly.md@geemail.com	Boulder	Colorado	3009058491413844	1080b6642c4b17d3e928187b00bdde64	VISA 13 digit	39.9601460963003348	-105.241585979159552
29412	2020-06-07 06:30:28	2020-06-07	Joshuah Keeling	joshuah.keeling@geemail.com	St. Louis	Missouri	3528461096079376737	fe2d01693392f9a46e7b829fcd40290f	American Express	38.5536707535542575	-90.305695976736402
29413	2020-06-07 07:05:06	2020-06-07	Tucker Hilpert	tucker.hilpert@geemail.com	Houston	Texas	3337987929394606633	995dd883727a950731f8d7bb7ad1d3de	Discover	29.8048297263294444	-95.3943229569602806
29414	2020-06-07 07:13:18	2020-06-07	Woody Feeney	woody.feeney@geemail.com	Washington	District of Columbia	4904674239974412	69e6704ed46e1ca3149b06ceac077cc0	Maestro	38.9108907549906533	-76.9801508832935326
29415	2020-06-07 07:23:29	2020-06-07	Abbott Stoltenberg	abbott.stoltenberg@geemail.com	Hayward	California	4440923093267301	16136253d5c7467faed70799eee2140a	VISA 16 digit	37.5440562910854823	-122.107013300366333
29416	2020-06-07 07:33:15	2020-06-07	Ursula Hoppe	ursula.hoppe@geemail.com	Los Angeles	California	6011252895056984980	c108ceae9c680817698fd0fee9e84973	VISA 13 digit	34.0145879255473602	-118.324516444326562
29417	2020-06-07 07:36:42	2020-06-07	Tiesha Stroman	tiesha.stroman@warmmail.com	Centennial	Colorado	4058865586573450	fcc453cc1e57e4f8bbb794b10f349511	Diners Club / Carte Blanche	39.4969315802719478	-104.96691057131477
29418	2020-06-07 07:52:53	2020-06-07	Armani Larson	armani.larson@geemail.com	Louisville	Kentucky	3096820958767990697	e956ccc8e5996223043a2e4ac653905d	JCB 15 digit	38.1624450396183832	-85.5876522358577745
29419	2020-06-07 08:14:40	2020-06-07	Jessy Watsica	jessy.watsica@geemail.com	San Francisco	California	3112742119552296676	45bb680e80e1d951faa4a2df1d164273	Diners Club / Carte Blanche	37.7911537005392262	-122.406547487353066
29420	2020-06-07 08:39:35	2020-06-07	Orval Will	orval.will@warmmail.com	Sacramento	California	3731238209726982	d382aff5bcfcbca1530b40ebf7e2bfe5	VISA 16 digit	38.5740406324420135	-121.467638715567432
29421	2020-06-07 08:48:41	2020-06-07	Lonna Lemke	lonna.lemke@geemail.com	New York	New York	4443352009947219	6fe780eb874ef89e0ef3d01cf8df34ee	Voyager	40.7479647889956809	-73.8946087044559334
29422	2020-06-07 08:51:25	2020-06-07	Buelah Roberts-Kunze	buelah.roberts.kunze@woohoo.com	Portland	Oregon	4802312489260314	e07f4c0f0ed2dbca2a85681c472f7549	Diners Club / Carte Blanche	45.5890705878734579	-122.74961261311546
29423	2020-06-07 09:01:03	2020-06-07	Bell Jones	bell.jones@warmmail.com	San Francisco	California	3158343635789984985	e09c0de0dc4d28a39f38e5c2fc2a3da6	JCB 16 digit	37.7399504123108116	-122.452024147047865
29424	2020-06-07 09:04:45	2020-06-07	Ciera Mayer	ciera.mayer@geemail.com	Los Angeles	California	4184104656272471	2e02eb66fcab2e704eec29adbe24671c	JCB 15 digit	34.1079637426748832	-118.422320473239935
29425	2020-06-07 09:12:18	2020-06-07	Lyle Lemke-Kub	lyle.lemke.kub@geemail.com	Huntington Beach	California	3468918352757068	dad36e2c6fb12ecd545deb637db98aa2	VISA 16 digit	33.6617026690900332	-118.022662597767265
29426	2020-06-07 09:13:19	2020-06-07	Greyson Schimmel PhD	greyson.schimmel.phd@geemail.com	Peoria	Arizona	4316879774933	9b88e4d2d3c2e82bbee23a3defbe6b30	American Express	33.7572652964655333	-112.266795882342393
29427	2020-06-07 09:14:11	2020-06-07	Charisse Mayer-Thiel	charisse.mayer.thiel@woohoo.com	Berkeley	California	869966367002415325	e35cd384f1aa27bc1285737e98f1c936	American Express	37.8725482488005909	-122.307160806316972
29428	2020-06-07 09:15:24	2020-06-07	Tasha Rodriguez	tasha.rodriguez@geemail.com	Anchorage	Alaska	6011672418685836810	64861727d5cb0c0e05f3ecd91939aba3	VISA 16 digit	61.1345952961344281	-149.353192119592052
29429	2020-06-07 09:16:28	2020-06-07	Ms. Jennette Wilkinson	ms.jennette.wilkinson@warmmail.com	San Francisco	California	3024317100441629	d3b3ea0599b8f58d20ec5ed09a31ac6c	JCB 15 digit	37.7561765782471639	-122.411200125631339
29430	2020-06-07 09:16:39	2020-06-07	Miss Dedra Ernser DVM	miss.dedra.ernser.dvm@geemail.com	Everett	Washington	3088274165504358862	275fcac2360f0978cf59137efae2eeed	Diners Club / Carte Blanche	48.0529829169049876	-122.165571968456362
29431	2020-06-07 09:17:24	2020-06-07	Mr. Adolphus Barrows	mr.adolphus.barrows@geemail.com	Detroit	Michigan	3774611129410952	59c3948f32d6b3ccf6366ea1362fd7d7	Discover	42.4492927486933809	-83.009576280194139
29432	2020-06-07 09:25:59	2020-06-07	Donnie Heidenreich	donnie.heidenreich@woohoo.com	Newport News	Virginia	3528447159631265373	a020a397d53f77788b29773418bc1b29	Discover	36.9771434850886465	-76.5809744208380607
29433	2020-06-07 09:27:17	2020-06-07	Dr. Susan Von PhD	dr.susan.von.phd@geemail.com	Wilmington	North Carolina	3010076916353923	ebd2370f2462cef050f1bf64be137142	Mastercard	34.1276645198751254	-77.9250753641586726
29434	2020-06-07 09:28:41	2020-06-07	Nils Gerlach-Bartell	nils.gerlach.bartell@geemail.com	Charlotte	North Carolina	3112969162757368946	a0f58c9a99810b8d1c315a68ffaf69b1	Diners Club / Carte Blanche	35.2112271015319962	-80.7618684417046637
29435	2020-06-07 09:32:33	2020-06-07	Jennings Herman	jennings.herman@geemail.com	New York	New York	639056105005567	c145c9c2f2aaef902693902cc6411e12	Voyager	40.6734126714747362	-73.8766611583892256
29436	2020-06-07 09:36:27	2020-06-07	Bob Hansen	bob.hansen@geemail.com	Pembroke Pines	Florida	676243307605782	b67bd802e96ecee58c1512363e87db64	Discover	25.9781430785115823	-80.3973243949837979
29437	2020-06-07 09:40:07	2020-06-07	Bilal Cronin	bilal.cronin@geemail.com	Madison	Wisconsin	3029877248125637	8d23267c3cfbcc0408534dd4bb3cc4fa	VISA 16 digit	43.1753827126204968	-89.4783339890535956
29438	2020-06-07 09:44:43	2020-06-07	Gavyn Hand	gavyn.hand@geemail.com	Daly City	California	4196619150226	74f0282376f890952066ddce210420b5	Discover	37.6740071934103966	-122.389669623374942
29439	2020-06-07 09:49:45	2020-06-07	Alex Denesik III	alex.denesik.iii@geemail.com	Jacksonville	Florida	3049699676622285	059eff948ca4cc9988880b071edfb099	JCB 15 digit	30.3886422969918684	-81.6305379434101326
29440	2020-06-07 09:51:34	2020-06-07	Opha Walter	opha.walter@geemail.com	San Antonio	Texas	869952122188048267	88d56f796838c959117b24cfffc21580	VISA 13 digit	29.4126884669136253	-98.5770078881945437
29441	2020-06-07 09:58:01	2020-06-07	Kennard Satterfield	kennard.satterfield@geemail.com	New York	New York	51916280024297898	57c1715b4743b46d0a724c58214e9602	VISA 16 digit	40.6610634708534917	-73.8689782321348787
29442	2020-06-07 10:04:02	2020-06-07	Adaline Sanford-Weissnat	adaline.sanford.weissnat@warmmail.com	Birmingham	Alabama	180097620635264004	3e94bcd880e663d9a6627637cabcff36	Voyager	33.4533698111098232	-86.7764111014790842
29443	2020-06-07 10:17:24	2020-06-07	Deneen Corkery	deneen.corkery@geemail.com	Huntsville	Alabama	54919311958884794	315c390b76d7fa8ed4fa7b4f56846a96	Diners Club / Carte Blanche	34.6435003341417769	-86.5963592501375814
29444	2020-06-07 10:29:15	2020-06-07	Misael Ward	misael.ward@geemail.com	Huntington Beach	California	210088105646348294	20203f396f12adddbdf5a26008c3bfd8	Discover	33.6496655683539814	-118.086903578800332
29445	2020-06-07 10:33:36	2020-06-07	Russell Greenholt	russell.greenholt@woohoo.com	Columbia	Missouri	4059797117104225	7c90e26c4928afce44cf99bc2c1497cc	Discover	39.0160656181511101	-92.3460122657527336
29446	2020-06-07 10:50:26	2020-06-07	Mrs. Jaylah Vandervort DDS	mrs.jaylah.vandervort.dds@geemail.com	Santa Clarita	California	676303079197764	e77493993b1bb9a09df55f8760c99044	JCB 16 digit	34.3442321988027501	-118.601477043992645
29447	2020-06-07 10:52:53	2020-06-07	Gordon Hackett	gordon.hackett@geemail.com	Indianapolis	Indiana	54610096697439479	2f96dbfeb731b403f6e633d2b4169861	American Express	39.7579252088449877	-86.1208242227058776
29448	2020-06-07 10:57:11	2020-06-07	Howell Brown	howell.brown@geemail.com	Los Angeles	California	869944622082707604	43d4c1737ce390190468084ea287480d	Discover	34.0188190063327554	-118.361790441208697
29449	2020-06-07 11:01:38	2020-06-07	Electa Goyette	electa.goyette@warmmail.com	New York	New York	4842455543138166	eef7cbc4f07c29a5a0798dc03efc02d0	VISA 13 digit	40.5859034864455452	-73.894861762773985
29450	2020-06-07 11:19:11	2020-06-07	Lorrayne Cruickshank	lorrayne.cruickshank@warmmail.com	Oakland	California	3046317091473969	3297fa4a4a886261f533a8c2911fb103	VISA 13 digit	37.8163072725002749	-122.300611836285995
29451	2020-06-07 11:21:42	2020-06-07	Grover Dach	grover.dach@warmmail.com	Baltimore	Maryland	3045076774074384	5a843c63e38dd8a259ad803926b14f44	VISA 16 digit	39.3694004401098923	-76.5136847487669485
29452	2020-06-07 11:32:15	2020-06-07	Mr. Demonte Bechtelar	mr.demonte.bechtelar@warmmail.com	San Francisco	California	4530642186543995	7c92482a615cb8ca536335d0d4a4f7ea	Discover	37.8011365052307653	-122.441877938804268
29453	2020-06-07 11:48:09	2020-06-07	Mordechai Johnston	mordechai.johnston@geemail.com	Houston	Texas	3096902347817292075	97157e01d735291a85a10880de1c5d08	Voyager	29.8735584232568741	-95.431014447334789
29454	2020-06-07 11:49:53	2020-06-07	Raven Schinner	raven.schinner@warmmail.com	Oakland	California	52382308241303127	e92cf36e9de4290d2415b4cb2f4134cf	VISA 16 digit	37.8498580671831277	-122.275028898059446
29455	2020-06-07 11:50:47	2020-06-07	Wylie Rowe	wylie.rowe@woohoo.com	Houston	Texas	869919151130912165	1d2cd586874412207cfcc1e851c6f3a3	Diners Club / Carte Blanche	29.8702892723105862	-95.3965070642545783
29456	2020-06-07 11:58:24	2020-06-07	Jonnie Bins-Greenfelder	jonnie.bins.greenfelder@geemail.com	Jersey City	New Jersey	6011732761479915805	5263e5e104fa2aa98378fe048512e531	VISA 16 digit	40.6286675463836602	-74.1498422458723212
29457	2020-06-07 12:10:53	2020-06-07	Jensen Nolan	jensen.nolan@warmmail.com	Memphis	Tennessee	3158098713753874032	470f7771443d93a24a49fe46496aee79	Discover	35.0706471006453029	-89.9088866458997131
29458	2020-06-07 12:12:10	2020-06-07	Dr. Jackeline Feeney	dr.jackeline.feeney@geemail.com	Berkeley	California	3528174863484690830	2fa62888e350a6cd1b5f408a230c20b2	VISA 16 digit	37.8772640108551073	-122.283728758474638
29459	2020-06-07 12:29:39	2020-06-07	Mr. Jamil Larson	mr.jamil.larson@geemail.com	Philadelphia	Pennsylvania	4389227502348	7c023020892ee85eddb761789e17e20a	Voyager	40.0612457454629265	-75.0803656463876479
29460	2020-06-07 12:33:51	2020-06-07	Euphemia Robel MD	euphemia.robel.md@geemail.com	Frisco	Texas	180019265170569048	9f6c72f7196d8ed2041f9909d0d30029	VISA 16 digit	33.1393347152505058	-96.8901598831847224
29461	2020-06-07 12:39:53	2020-06-07	Xiomara Schiller	xiomara.schiller@warmmail.com	New York	New York	180059389744555936	8cf703242bdd51ab0529f0f62c709e54	JCB 15 digit	40.7250106525830944	-73.9671873767755841
29462	2020-06-07 12:51:05	2020-06-07	Aarav Douglas	aarav.douglas@geemail.com	Hartford	Connecticut	4053339345722159	f749b8d443df31c37e7e02706d16d34b	JCB 16 digit	41.8611262436505456	-72.7198957044988958
29463	2020-06-07 12:53:52	2020-06-07	Margretta Langworth	margretta.langworth@geemail.com	Savannah	Georgia	502057931815468	c0e62ad8acb95a1fbd5f022cb54795b8	Voyager	31.9120271297730476	-81.207190016625816
29464	2020-06-07 12:53:56	2020-06-07	Wendy Parker	wendy.parker@warmmail.com	Tallahassee	Florida	3024964032477104	5b634f02530d3a5bcdf344a0088e0320	Diners Club / Carte Blanche	30.4538539652735025	-84.2389428463313692
29465	2020-06-07 12:54:54	2020-06-07	Gifford Barrows	gifford.barrows@woohoo.com	Pomona	California	6011321452895438518	bbba86efba60b55aac56b18ff992e586	JCB 16 digit	34.1095901748668453	-117.832087195661288
29466	2020-06-07 12:56:59	2020-06-07	Mrs. Chaney Nikolaus DVM	mrs.chaney.nikolaus.dvm@geemail.com	Grand Prairie	Texas	4193245442671	542fc43fe9d4ea817737d9800c5d0cae	American Express	32.7498362319130436	-97.0973630400247885
29467	2020-06-07 13:08:45	2020-06-07	Calleigh Koepp	calleigh.koepp@geemail.com	Chicago	Illinois	6011713385203857720	0e5b2e80c0fa5fbfc0fc04048d1b7632	American Express	41.918693780044471	-87.6617442247487588
29468	2020-06-07 13:28:10	2020-06-07	Roberta Hessel-Leffler	roberta.hessel.leffler@warmmail.com	Fort Lauderdale	Florida	676102699918922	444756e95862b07e72a74c88238d57b3	Diners Club / Carte Blanche	26.1635536915145828	-80.0630258118554963
29469	2020-06-07 13:29:56	2020-06-07	Braulio Zieme-Douglas	braulio.zieme.douglas@geemail.com	Lewisville	Texas	180005448092579180	26b3df0d6099fac95b501f3cf89ceb5a	VISA 16 digit	32.9666876504648485	-96.9440228099033305
29470	2020-06-07 13:41:33	2020-06-07	Briley Bosco	briley.bosco@geemail.com	Los Angeles	California	3528407342445624237	85b7673054bbd68d2c12536f9eb0b300	Maestro	34.0366757636755679	-118.424747657402605
29471	2020-06-07 13:44:19	2020-06-07	Jackeline Lynch	jackeline.lynch@geemail.com	Aurora	Colorado	3528129499417424728	4a4b662c373ce899094f2f0659d46e9d	Diners Club / Carte Blanche	39.7799387134723403	-104.613283189304923
29472	2020-06-07 13:48:20	2020-06-07	Pate Carroll	pate.carroll@woohoo.com	Washington	District of Columbia	3528174424282166638	a9dc9e64dc87846b179fefc98b40adb7	VISA 16 digit	38.9623090419251454	-76.9288338858846572
29473	2020-06-07 14:03:52	2020-06-07	Mr. Nolen Effertz III	mr.nolen.effertz.iii@geemail.com	Odessa	Texas	3528962806631828908	288f018cf870fe245bf7763e28047a5a	VISA 16 digit	31.9678462874621161	-102.330044827252991
29474	2020-06-07 14:11:26	2020-06-07	Sydney Conn	sydney.conn@woohoo.com	Detroit	Michigan	52623867570025915	3a9fa35e16520146715cf771aaa2f071	Diners Club / Carte Blanche	42.392812131337827	-83.0821677866976671
29475	2020-06-07 14:40:06	2020-06-07	Chelsey Schneider	chelsey.schneider@geemail.com	Los Angeles	California	503835825851682	cef7431979a22db054369e5d3fde1749	Maestro	34.1043535628687593	-118.330437117534871
29476	2020-06-07 14:55:32	2020-06-07	Maralyn Kuphal-Green	maralyn.kuphal.green@geemail.com	Santa Rosa	California	4825921738656693	ffae3985d500addc44130b7e7f0fbffd	American Express	38.3674230151467057	-122.7549405304961
29477	2020-06-07 14:59:11	2020-06-07	Kittie Wisozk DVM	kittie.wisozk.dvm@geemail.com	Indianapolis	Indiana	639002774037630	a12f30fba719dfc7c78e0375712191bd	American Express	39.8108631324496116	-86.2012319626487766
29478	2020-06-07 15:11:21	2020-06-07	Ms. Camilla Goldner MD	ms.camilla.goldner.md@warmmail.com	Oklahoma City	Oklahoma	3088870609205415537	d03ccfeb6315be81ec8e6fae185205af	Maestro	35.4059069252017906	-97.4230998141586753
29479	2020-06-07 15:12:35	2020-06-07	Marylyn Smith	marylyn.smith@geemail.com	Nashville	Tennessee	3088766888500065935	ab0168b540b2847146e6021788f74a92	JCB 16 digit	36.141321003169935	-86.8501570130605245
29480	2020-06-07 15:14:14	2020-06-07	Mr. Tyrone Stoltenberg III	mr.tyrone.stoltenberg.iii@geemail.com	San Francisco	California	4551634530754	0671c3822352087b8a29c832f198891c	JCB 16 digit	37.7407239740898746	-122.454267429492802
29481	2020-06-07 15:21:30	2020-06-07	Boris Lind	boris.lind@geemail.com	Pompano Beach	Florida	4430271842972	ee59a2cf91ff2154d57e6cd866f6e5f1	VISA 16 digit	26.2240479892384251	-80.1645129199452668
29482	2020-06-07 15:29:48	2020-06-07	Dr. Shay DuBuque	dr.shay.dubuque@geemail.com	Anaheim	California	869914598570467404	25f4e703c534447fdb843786fea99a5e	Maestro	33.9259058482311673	-117.771213602109242
29483	2020-06-07 15:32:33	2020-06-07	Oliva Pfannerstill	oliva.pfannerstill@geemail.com	Peoria	Arizona	53909685047198262	b2a912de09048e5b98d04532dc07288e	Discover	33.7809182614821921	-112.279826782170687
29484	2020-06-07 15:35:40	2020-06-07	Koda Gutkowski	koda.gutkowski@geemail.com	Davie	Florida	4309032182317215	0a8376f80e5e204dbb82a5841430ccac	American Express	26.132718384059519	-80.2372094430401859
29485	2020-06-07 15:36:54	2020-06-07	Leta Kihn	leta.kihn@geemail.com	San Francisco	California	3088426793593514199	40b561f8c02e1c72ffdb4f106af4a844	American Express	37.7936430169346878	-122.44003855840225
29486	2020-06-07 15:44:12	2020-06-07	Justina Beatty DVM	justina.beatty.dvm@geemail.com	Oakland	California	3096499297918706649	e0d2782297b9cef6a9f95877f53741f8	VISA 16 digit	37.8203479105281843	-122.293921861246346
29487	2020-06-07 15:57:28	2020-06-07	Donovan Cormier Sr.	donovan.cormier.sr.@geemail.com	New York	New York	869970967117636907	187630032d785b7b0f045952ba0c5f80	VISA 16 digit	40.7262859618980428	-73.9644116874214177
29488	2020-06-07 16:02:10	2020-06-07	Leland Jakubowski PhD	leland.jakubowski.phd@warmmail.com	San Antonio	Texas	4644096063046171	53b47919a9e90d2a81801e6efe9eea71	VISA 13 digit	29.4847514340724786	-98.5031704997945496
29489	2020-06-07 16:06:33	2020-06-07	Wanda Blick	wanda.blick@geemail.com	New York	New York	869906553028332379	e51a0e0bac9b7a0ae2db9efcf5082001	Diners Club / Carte Blanche	40.6306422282233797	-73.9891450374748558
29490	2020-06-07 16:15:43	2020-06-07	Peggy Osinski DVM	peggy.osinski.dvm@geemail.com	Los Angeles	California	869967317444931701	74d2061aa1f756f35fca46d5be508db0	JCB 15 digit	33.9786837323434625	-118.315678061311317
29491	2020-06-07 16:20:09	2020-06-07	Dr. Nia Stehr MD	dr.nia.stehr.md@geemail.com	Eugene	Oregon	4186124872571686	21cf92d58d93802410e4b3ac5420dc12	Diners Club / Carte Blanche	43.9914177116665996	-123.03566710948833
29492	2020-06-07 16:20:57	2020-06-07	Cassie Wyman	cassie.wyman@geemail.com	Los Angeles	California	6011991925249224220	8395519335d02a9453bbee36f8071c62	Voyager	34.094137418442962	-118.381951931211347
29493	2020-06-07 16:21:43	2020-06-07	Phylicia Bode	phylicia.bode@geemail.com	San Francisco	California	6011045793403191692	a1386a1294ca02998ecea9cb508bbf07	Maestro	37.7815007819040645	-122.475791299279379
29494	2020-06-07 16:28:17	2020-06-07	Dr. Vaughn Russel Jr.	dr.vaughn.russel.jr.@geemail.com	Cleveland	Ohio	55754825473678041	40747c14ea0c6e99e8f08d34cd601094	Maestro	41.4115234484747035	-81.6670968258060554
29495	2020-06-07 16:30:30	2020-06-07	Zina Conroy	zina.conroy@warmmail.com	San Jose	California	3337090378226001882	a3e18de6baa01700777fbed21edf0aea	American Express	37.2553152267176699	-121.742945471427959
29496	2020-06-07 16:36:01	2020-06-07	Destiny Kuhic MD	destiny.kuhic.md@geemail.com	Los Angeles	California	3088384145460455578	203aaa2fbec6f1681f49c4f5d60c31af	Diners Club / Carte Blanche	33.9203252249728848	-118.502621322822932
29497	2020-06-07 16:43:37	2020-06-07	Burnice Bins	burnice.bins@woohoo.com	San Francisco	California	6011639859092892015	7b63c06375b176c6665fccc90effa118	JCB 16 digit	37.7379221244394998	-122.436330488769912
29498	2020-06-07 16:52:05	2020-06-07	Mr. Louie Harber	mr.louie.harber@geemail.com	Oklahoma City	Oklahoma	55772548699701318	921ea01eedffaec1603c7b548bbf5e0b	VISA 13 digit	35.5601083892308196	-97.5102635430067721
29499	2020-06-07 16:53:30	2020-06-07	Ms. Sherrie Zboncak	ms.sherrie.zboncak@geemail.com	San Francisco	California	3057449635598958	ac54665e31a7a10ed2bc99ec3d91761a	Diners Club / Carte Blanche	37.7897891187166408	-122.467828256663026
29500	2020-06-07 16:57:45	2020-06-07	Ingram Bednar Jr.	ingram.bednar.jr.@geemail.com	Omaha	Nebraska	4816182880617485	5f0fa6953c0ee52345b13496899abaf5	JCB 15 digit	41.3604457188542938	-96.1087889457702715
29501	2020-06-07 17:15:03	2020-06-07	Marchello Mante-Zieme	marchello.mante.zieme@warmmail.com	Los Angeles	California	6011786437473999914	82632a9b74c57d5eeed06b0500317f51	Discover	33.9283516991749394	-118.506306265060971
29502	2020-06-07 17:21:56	2020-06-07	Dr. Barron Sanford	dr.barron.sanford@geemail.com	Chicago	Illinois	3528199438831307536	cbbe789018b142c9f3f0a67a35da291d	Discover	41.7395122325815251	-87.7460127676866932
29503	2020-06-07 17:34:42	2020-06-07	Pearley Tremblay	pearley.tremblay@woohoo.com	Elk Grove	California	869989478615082213	38f1c29faa716e83c4eb3a81d5f8e56e	VISA 16 digit	38.4274032341133776	-121.364481840645894
29504	2020-06-07 17:55:51	2020-06-07	Geraldine Mayer	geraldine.mayer@geemail.com	Vancouver	Washington	6011593171034815912	029d50901f00262e7bc976a4f524dd81	Voyager	45.5551797135338177	-122.643547279300904
29505	2020-06-07 17:57:11	2020-06-07	Kaeden Mayer	kaeden.mayer@geemail.com	Chicago	Illinois	6011805049060746652	211578d089f6a25c4671dbec04e727d3	Discover	41.7447531302295616	-87.7242307392444474
29506	2020-06-07 18:04:00	2020-06-07	Kolten Sanford	kolten.sanford@geemail.com	Boise	Idaho	3737400752043025	6905f3bd4bd471e9725b9e15168d0985	VISA 16 digit	43.616328232562914	-116.31456242671311
29507	2020-06-07 18:38:38	2020-06-07	Ms. Jalisa Thiel PhD	ms.jalisa.thiel.phd@geemail.com	Coral Springs	Florida	6011922768813528459	d5b3f2b0ee5b94644cc1098734f76714	Diners Club / Carte Blanche	26.3394632767483614	-80.1741511779960234
29508	2020-06-07 18:46:17	2020-06-07	Miner Jacobs-Mohr	miner.jacobs.mohr@geemail.com	Waco	Texas	060499562800062	7c385d7f901b6c774e9f3c1ef817a159	VISA 16 digit	31.6573906165290602	-97.1496414527893108
29509	2020-06-07 18:46:27	2020-06-07	Selena Koepp-Harris	selena.koepp.harris@geemail.com	San Francisco	California	639042105509683	9501a101a6e2b8cd7bffc3efd146e3dc	Diners Club / Carte Blanche	37.7521973351770441	-122.435513080751306
29510	2020-06-07 18:51:26	2020-06-07	Kenyon Torp	kenyon.torp@warmmail.com	Denver	Colorado	4115737621254639	e03cf4404491e90bc9967a5f51b74e6d	VISA 16 digit	39.7244451101921499	-104.916017014511311
29511	2020-06-07 18:51:35	2020-06-07	Hans Prohaska IV	hans.prohaska.iv@geemail.com	San Francisco	California	180052104646469848	f659ef5f913bbccf8d4777caa8ddd736	American Express	37.7520463521620542	-122.390975391016909
29512	2020-06-07 19:02:28	2020-06-07	Cullen Stokes	cullen.stokes@geemail.com	Miramar	Florida	3497657324054106	320154598da6f93f91457399bced60a0	Diners Club / Carte Blanche	25.9761601923014958	-80.2466639259822756
29513	2020-06-07 19:27:18	2020-06-07	Gayle Rippin	gayle.rippin@geemail.com	Miramar	Florida	869984380315252044	47f02e22cf26c8ab3393331afd3e4944	VISA 13 digit	25.9701380164809521	-80.3303966633968116
29514	2020-06-07 19:27:25	2020-06-07	Mr. Garvin Feest	mr.garvin.feest@geemail.com	Oakland	California	3088603176743428590	3d7179d898285b78f48ff8a791925803	JCB 16 digit	37.7962515112681103	-122.305431586067741
29515	2020-06-07 19:32:46	2020-06-07	Adison Kling	adison.kling@geemail.com	San Francisco	California	869954582767012497	e1e4ca8c92457c98e3f55abd92c16dff	JCB 16 digit	37.7896939514412793	-122.413352995141906
29516	2020-06-07 19:36:53	2020-06-07	Kaden Wisoky Jr.	kaden.wisoky.jr.@woohoo.com	Boise	Idaho	6011384731796981674	167af7a612b51a595e81948e8bad266c	VISA 13 digit	43.6386700542315822	-116.260119297980154
29517	2020-06-07 19:37:43	2020-06-07	Arkie Klocko	arkie.klocko@woohoo.com	San Diego	California	3419421066090033	f713e3ec6ac83c4c075f4cee23b65440	VISA 16 digit	32.8754032719016109	-117.17754994071089
29518	2020-06-07 19:57:06	2020-06-07	Dr. Harman Hauck	dr.harman.hauck@geemail.com	San Francisco	California	3096276077337903293	7893f93dbdab599d5db71d2d07868944	Voyager	37.7871635360731304	-122.435859488514467
29519	2020-06-07 19:59:27	2020-06-07	Cleon Miller DDS	cleon.miller.dds@warmmail.com	Visalia	California	869996051358578944	a33591de9144fb12f9fc7be0c4fb244a	JCB 16 digit	36.4262785195328291	-119.384301277681814
29520	2020-06-07 20:01:44	2020-06-07	Dr. Jo Spinka	dr.jo.spinka@woohoo.com	Memphis	Tennessee	3421732129678093	1232d39c9ce3147b31a5f6661b64aec5	VISA 16 digit	35.181306873827431	-90.0182734725788265
29521	2020-06-07 20:09:14	2020-06-07	Patric Simonis-Crist	patric.simonis.crist@warmmail.com	Garden Grove	California	4388155063790418	db9339c73b2f624249f5764d2bb86845	VISA 13 digit	33.7790493052743344	-117.911792974688112
29522	2020-06-07 20:13:31	2020-06-07	Paola Ortiz	paola.ortiz@woohoo.com	Orlando	Florida	210087951835819988	1810b5452af933ecfe44c514082b8809	Maestro	28.3569255529236024	-81.1920972608461966
29523	2020-06-07 20:16:48	2020-06-07	Dr. Davon Bosco	dr.davon.bosco@warmmail.com	San Francisco	California	54394810723049033	6a1c84f312148ea6f127a61140750301	JCB 15 digit	37.7426342737166962	-122.445727935666142
29524	2020-06-07 20:26:03	2020-06-07	Spurgeon DuBuque	spurgeon.dubuque@geemail.com	Newark	New Jersey	3158259184061838561	fde53eb54a89453496d4a8b12a35cd39	VISA 13 digit	40.6408478276718412	-74.206904887987676
29525	2020-06-07 20:32:11	2020-06-07	Hughey Kuhn	hughey.kuhn@geemail.com	Miami	Florida	52235742182048342	3e72ef7d8cfa9027faf92a580b141a0b	Mastercard	25.8289903120275603	-80.1909087510187248
29526	2020-06-07 20:42:07	2020-06-07	Joanna Trantow	joanna.trantow@geemail.com	Glendale	California	4241413755174798	eb897d2590a9d625ebd8745b52cfb92d	JCB 16 digit	34.1320539837457204	-118.152053972277045
29527	2020-06-07 20:43:13	2020-06-07	Elton Champlin	elton.champlin@woohoo.com	Memphis	Tennessee	4270543132525	5d1ea19d8f22054d4bc5ee623c87385a	JCB 16 digit	35.0202894545692942	-89.9300883896905958
29528	2020-06-07 20:52:42	2020-06-07	Miss Yolanda Parker	miss.yolanda.parker@warmmail.com	Portland	Oregon	4055219962663	63b2d0ebe27a1662088bb5de6e1a72c5	Maestro	45.5100518258176763	-122.73085402441211
29529	2020-06-07 20:54:06	2020-06-07	Will Crona	will.crona@geemail.com	Yonkers	New York	869917320152351659	aed01e35ddb49897cff19ff0bec6d226	American Express	41.0045606875061992	-73.8435097718495967
29530	2020-06-07 21:05:46	2020-06-07	Kolten Ledner	kolten.ledner@geemail.com	Corona	California	3096299510408049474	a96cd13b1d20c1cb31bebd04467275ff	JCB 16 digit	33.9060721364691844	-117.512342402126635
29531	2020-06-07 21:06:13	2020-06-07	Danyell Schumm-Wuckert	danyell.schumm.wuckert@geemail.com	San Francisco	California	3424627065460190	368136c78b099c52c10614433538fd9f	Discover	37.7628336982924395	-122.441624164549239
29532	2020-06-07 21:06:45	2020-06-07	Welton Turcotte	welton.turcotte@geemail.com	New York	New York	3112177481072122061	048b8806788aff35a1eb9dad02a19782	JCB 15 digit	40.6674839996956266	-73.8540238793369355
29533	2020-06-07 21:07:31	2020-06-07	Brodie Denesik	brodie.denesik@geemail.com	Milwaukee	Wisconsin	4384754030295594	63949e9c870a64e4172812e6ca7f1264	Diners Club / Carte Blanche	43.1008409387983349	-87.9103749353073596
29534	2020-06-07 21:07:34	2020-06-07	Hayden Gleichner	hayden.gleichner@warmmail.com	San Francisco	California	4693162107736	b02f693c24cd6fd5a29b6768cb2a6f15	American Express	37.7747816212316394	-122.415638191740342
29535	2020-06-07 21:07:52	2020-06-07	Erland Macejkovic	erland.macejkovic@geemail.com	Daly City	California	502061875231054	880e18fb60756a1d3d2eeaff304c1243	JCB 16 digit	37.6299964058600338	-122.409964059535412
29536	2020-06-07 21:08:42	2020-06-07	Corwin Howe	corwin.howe@warmmail.com	Dallas	Texas	4712663966267506	5a2207a116727f4c33c601b106d46f28	VISA 16 digit	32.883378435558825	-96.7445717948917263
29537	2020-06-07 21:18:59	2020-06-07	Arvo Lynch	arvo.lynch@geemail.com	Oakland	California	3008917422572591	35ef64973810ae3297cd0f90ddafa63c	Voyager	37.797535470087567	-122.262243794388212
29538	2020-06-07 21:20:55	2020-06-07	Dr. Pheobe Kunze DDS	dr.pheobe.kunze.dds@geemail.com	Lubbock	Texas	6011744515423514528	574355358e6623a2c541bf75bc161bd8	VISA 16 digit	33.5723978858482113	-101.983897061358022
29539	2020-06-07 21:35:12	2020-06-07	Jettie Wisozk PhD	jettie.wisozk.phd@woohoo.com	Akron	Ohio	6011449675711151785	b72bb7b3814d343dc1d3c198039d0635	Maestro	41.0215992219578496	-81.4709157249737501
29540	2020-06-07 21:47:38	2020-06-07	Dola Fritsch	dola.fritsch@geemail.com	San Francisco	California	869954073963813714	aa9e27e9a5ffdc561788ebeae380c9c7	American Express	37.7837451323793587	-122.404818648046131
29541	2020-06-07 21:48:50	2020-06-07	Beau Krajcik	beau.krajcik@geemail.com	San Francisco	California	869907680288033923	0074e49cec4b3d3bfde76d01703c26ab	JCB 16 digit	37.7698874267956981	-122.398472061773461
29542	2020-06-07 21:49:58	2020-06-07	Ean Bednar-Jerde	ean.bednar.jerde@geemail.com	Hillsboro	Oregon	210087964471768898	56642be15edcb352215a422c44ce1abf	VISA 16 digit	45.5543435706030593	-122.866336202543977
29543	2020-06-07 22:04:02	2020-06-07	Dr. Gust Bailey IV	dr.gust.bailey.iv@warmmail.com	Tucson	Arizona	3088295697771756381	46e145cd89fb06f7c879daf14d845ff3	Maestro	32.0692805289331844	-110.823441603755953
29544	2020-06-07 22:05:01	2020-06-07	Dr. Alonzo Doyle Jr.	dr.alonzo.doyle.jr.@woohoo.com	New York	New York	3017749088015230	353a2faa8b18844bb18c70d46f786e39	VISA 16 digit	40.6231831715200116	-73.8967679387785523
29545	2020-06-07 22:08:19	2020-06-07	Dr. Aden Kreiger PhD	dr.aden.kreiger.phd@woohoo.com	Lafayette	Louisiana	676379078628744	81a3622914cd9bec0f51d5a8c0812dc3	American Express	30.2412628784287705	-91.9813299638535824
29546	2020-06-07 22:13:01	2020-06-07	Treyvon Mayert	treyvon.mayert@geemail.com	Clarksville	Tennessee	6011430084875563128	4cf5326122ae4fd43c6782a6d710182c	Mastercard	36.6300025858111695	-87.3987357068758541
29547	2020-06-07 22:22:13	2020-06-07	Margy Armstrong	margy.armstrong@geemail.com	New York	New York	6011202962353348581	b0f0dbebc21883b249cfe6d95da8030c	Diners Club / Carte Blanche	40.71011417338066	-73.8465721261583212
29548	2020-06-07 22:25:53	2020-06-07	Rosco Braun PhD	rosco.braun.phd@geemail.com	Austin	Texas	3755726881333490	93dcf5a1ac094b697661cf2555f89ccc	JCB 16 digit	30.3916117696683834	-97.8085490748524649
29549	2020-06-07 22:27:57	2020-06-07	Mrs. Sophronia Bechtelar	mrs.sophronia.bechtelar@geemail.com	Phoenix	Arizona	4337908896992	ef2e470bfecb69298933ba76ffd57af2	Diners Club / Carte Blanche	33.5649677777130151	-112.032766036030281
29550	2020-06-07 22:34:42	2020-06-07	Latisha Ernser	latisha.ernser@geemail.com	Tulsa	Oklahoma	4352650000848859	96e96ab07e89aa97adfc71e75171005b	Maestro	36.0410382355932128	-95.8248728441029698
29551	2020-06-07 22:47:30	2020-06-07	Stacy Collins	stacy.collins@geemail.com	Long Beach	California	3456778071334456	7d2fe89c553deb169470be03eb362978	JCB 16 digit	33.7588002214960738	-118.248825601737195
29552	2020-06-07 22:49:09	2020-06-07	Dr. Patti McKenzie DVM	dr.patti.mckenzie.dvm@geemail.com	Washington	District of Columbia	3096522501611044625	b395c30785c343f8b256b5ad21010256	JCB 15 digit	38.8748559984642981	-77.0032968909226412
29553	2020-06-07 22:51:18	2020-06-07	Elianna Bergnaum MD	elianna.bergnaum.md@geemail.com	Las Vegas	Nevada	4863759433138457	c36c359abc567478bb061d6a0d340309	Discover	36.1742820193160313	-115.219146020125962
29554	2020-06-07 22:57:00	2020-06-07	Azaria Satterfield-McClure	azaria.satterfield.mcclure@warmmail.com	New York	New York	3337128234059230898	013cdd33e75ae0139b578f5f7bd1f403	VISA 13 digit	40.573204577224331	-73.9943969472207073
29555	2020-06-07 22:57:10	2020-06-07	Kevin Kovacek	kevin.kovacek@geemail.com	New York	New York	210070427377900758	729ec9e3a03f1f3ac5bc7fd549ba1871	Discover	40.6806693568583597	-73.913715477696428
29556	2020-06-07 23:01:21	2020-06-07	Charly Kessler	charly.kessler@warmmail.com	Colorado Springs	Colorado	3528776824456922330	c41a2183aae0aa3e4c143a8e9ddb4483	Voyager	38.8281029778115467	-104.681082626261556
29557	2020-06-07 23:11:33	2020-06-07	Boston Schmidt	boston.schmidt@geemail.com	Los Angeles	California	3096474285347111852	475a87960fdf5438662e63a3a73e60fd	JCB 15 digit	33.9938407250080203	-118.329691539517782
29558	2020-06-07 23:22:02	2020-06-07	Krystal Stanton	krystal.stanton@woohoo.com	Albuquerque	New Mexico	6011433918682090709	c29067e69509365d6b9c5a543d778606	American Express	35.201712951589748	-106.575729636156566
29559	2020-06-07 23:24:51	2020-06-07	Dr. Fumiko Maggio	dr.fumiko.maggio@geemail.com	Tulsa	Oklahoma	3112409251447044633	cc3d7d32ad62312a7ce436f03d9cc5a6	JCB 16 digit	36.1132294654749302	-95.9941318645562944
29560	2020-06-07 23:30:12	2020-06-07	Amiah Ratke MD	amiah.ratke.md@geemail.com	Memphis	Tennessee	4835323095546	94730754f7204a59e6a190c3017cf620	JCB 16 digit	35.0619004023328458	-89.9450245022565156
29561	2020-06-07 23:49:24	2020-06-07	Gilmore Kreiger-Terry	gilmore.kreiger.terry@geemail.com	New York	New York	55938330948886641	a3d6211e2f6f683c636319c4c1d92d95	VISA 13 digit	40.7334000355321919	-74.0150296134304284
29562	2020-06-07 23:58:03	2020-06-07	Mr. Norwood Bode	mr.norwood.bode@warmmail.com	Elk Grove	California	3528931027404305085	601785a76a86d5b6b2e1e14411ec0cca	JCB 16 digit	38.479285072237623	-121.309603433907043
29563	2020-06-08 00:11:57	2020-06-08	Mr. Ike Carroll	mr.ike.carroll@geemail.com	Plano	Texas	3088169328002881748	62fbd388ed8de932d45d52e9473b6d9b	Voyager	33.1219330723017507	-96.6667280809670757
29564	2020-06-08 00:21:04	2020-06-08	Amelie Volkman MD	amelie.volkman.md@geemail.com	Lexington	Kentucky	53134760941770586	56426a9a2d882d2e7ecba2db3860e27d	American Express	37.9873727604158233	-84.5557338794126991
29565	2020-06-08 00:21:23	2020-06-08	Danika Robel	danika.robel@geemail.com	Houston	Texas	3096013125650514623	76444349522183f0fb96c6713c5259f1	Maestro	29.7702770717520266	-95.3972915096689036
29566	2020-06-08 00:22:15	2020-06-08	Cason Cassin	cason.cassin@warmmail.com	Richardson	Texas	6011454376370909561	224f9e99e99c0b13b488ed38478ae9a5	JCB 16 digit	33.0004122025102333	-96.7966753112845169
29567	2020-06-08 00:36:26	2020-06-08	Aarav Heathcote	aarav.heathcote@geemail.com	Las Vegas	Nevada	4372763138817500	f7462c9c89027c114e79e14105740f61	JCB 15 digit	36.2421156080074596	-115.304166164083767
29568	2020-06-08 00:37:38	2020-06-08	Mark Boyle	mark.boyle@geemail.com	San Jose	California	3006649893887800	e7a344a0ce40d9937204b3913276cb76	Mastercard	37.3473996601819991	-121.901694418185954
29569	2020-06-08 01:05:49	2020-06-08	Mr. Devyn Walsh	mr.devyn.walsh@geemail.com	Moreno Valley	California	869936765862706203	dc918280820a1131c3f526d53d4377a6	JCB 16 digit	33.8761234049212163	-117.298046879513933
29570	2020-06-08 01:13:35	2020-06-08	Micaela Wehner	micaela.wehner@geemail.com	Denver	Colorado	4210703005160416	337f080e026680e3538b3eb660ebf9ae	Voyager	39.7280644584033595	-104.975573741902039
29571	2020-06-08 01:33:24	2020-06-08	Dolphus Hudson	dolphus.hudson@geemail.com	Greeley	Colorado	4208712061265	f302a1d01709e629237919970a6a5211	Diners Club / Carte Blanche	40.5098067489054046	-104.8123127938088
29572	2020-06-08 01:36:15	2020-06-08	Bertha Dickinson	bertha.dickinson@geemail.com	Boston	Massachusetts	676151436935525	48e7bd36e7e87644610fd338cf3e1166	JCB 15 digit	42.3004156749397495	-71.0622867562759666
29573	2020-06-08 01:59:50	2020-06-08	Jerald Strosin-VonRueden	jerald.strosin.vonrueden@geemail.com	Round Rock	Texas	4391023853685	b0b14ca2e7668dcb07a5aeb7510f45c7	Mastercard	30.4799650379594418	-97.7428491419032213
29574	2020-06-08 02:05:05	2020-06-08	Josephus Kulas	josephus.kulas@geemail.com	Gilbert	Arizona	3003611511106099	3f651006aa1a9e4828448d3b26b2777e	VISA 16 digit	33.387986615055425	-111.656538405329357
29575	2020-06-08 02:16:04	2020-06-08	Zela Gleichner MD	zela.gleichner.md@woohoo.com	Fresno	California	4128665482618763	d74612ea726543bc6daab813d43e1090	Voyager	36.7682053596586016	-119.821205041661486
29576	2020-06-08 02:34:31	2020-06-08	Pinkey Boehm-Kuvalis	pinkey.boehm.kuvalis@warmmail.com	Portland	Oregon	3337782754481305817	d662f2d378660cea465d15a6672c29b1	VISA 16 digit	45.5279837023355043	-122.673666865332052
29577	2020-06-08 02:51:10	2020-06-08	Zora Braun	zora.braun@geemail.com	New York	New York	4977840077357281	722267cd26befb0a66524d4951f7571c	JCB 15 digit	40.7148587035704423	-73.8414224733028561
29578	2020-06-08 03:05:04	2020-06-08	Price Bergnaum	price.bergnaum@geemail.com	Clearwater	Florida	6011680166782119164	7c3679fbe641dacd289f5857e65bc5cc	JCB 15 digit	28.0542099882975222	-82.7724887939434524
29579	2020-06-08 03:05:41	2020-06-08	Beth Ebert	beth.ebert@warmmail.com	San Antonio	Texas	3158016797442279330	e179dfbfbee3e2648073918c9e8b8b38	VISA 16 digit	29.4103120170138794	-98.5073051056660631
29580	2020-06-08 03:06:06	2020-06-08	Ike Gibson	ike.gibson@geemail.com	Austin	Texas	4770385947606482	58d56e6f1007be3a20ec46dbf5de1a59	JCB 16 digit	30.4036275542002166	-97.8279731149557961
29581	2020-06-08 03:13:05	2020-06-08	Lloyd Nicolas	lloyd.nicolas@warmmail.com	Dallas	Texas	51228178236696316	9be47555edf48e6be2daba40f795da39	Diners Club / Carte Blanche	32.7025300409451134	-96.7244845183994499
29582	2020-06-08 03:17:58	2020-06-08	Miah Bauch PhD	miah.bauch.phd@geemail.com	Fort Worth	Texas	4796496267761730	f903f87c43f301418721ff70d1e14af2	Voyager	32.7758669029977199	-97.3693152732036964
29583	2020-06-08 03:23:27	2020-06-08	Mrs. Rubie Dare	mrs.rubie.dare@geemail.com	Louisville	Kentucky	51837341998240078	9ecfecd79fb41b9be8fbcb995f6d0f95	American Express	38.223483062432706	-85.7041332720384048
29584	2020-06-08 03:30:09	2020-06-08	Haley Bogan	haley.bogan@geemail.com	Athens	Georgia	4280353071168904	fa178b7376e335e1038315c80a8c1b18	Voyager	33.885203040317073	-83.4100531298782641
29585	2020-06-08 03:37:43	2020-06-08	Mr. Junius Predovic	mr.junius.predovic@geemail.com	Raleigh	North Carolina	3751495040059610	f6906ede37a92ea165b23337f72c5bd2	JCB 15 digit	35.8048604254279255	-78.5933443984884832
29586	2020-06-08 03:41:35	2020-06-08	Dr. Dani Jacobson MD	dr.dani.jacobson.md@geemail.com	Oakland	California	4269093773297123	fe1fc0f82e80753fee7ee88896f232a3	American Express	37.774808122449933	-122.274448477589019
29587	2020-06-08 03:42:04	2020-06-08	Ninnie Haley-Cronin	ninnie.haley.cronin@geemail.com	Fort Collins	Colorado	55673226216566379	2711f06d61d18dcc717b926b61916772	Discover	40.5379115412168218	-105.091165132164221
29588	2020-06-08 03:47:40	2020-06-08	Mrs. Doretta Mayer DVM	mrs.doretta.mayer.dvm@geemail.com	Dallas	Texas	4033127804284158	18b50c7aec515bcd763ea5feeb6bbddc	Maestro	32.7975534431442668	-96.7059235866144178
29589	2020-06-08 03:51:35	2020-06-08	Foster Mayer	foster.mayer@geemail.com	San Francisco	California	3028060174582102	0cce0bcf0e31abc9e8de71bdec85ac56	Diners Club / Carte Blanche	37.7699768363682153	-122.408472372916336
29590	2020-06-08 03:57:24	2020-06-08	Latrina Bechtelar	latrina.bechtelar@geemail.com	Portland	Oregon	3019343018575683	e47ddd2551449c38774a3b3a8b95af66	VISA 13 digit	45.6181645327601544	-122.572782806027689
29591	2020-06-08 03:58:00	2020-06-08	Mrs. Jonna Schinner DDS	mrs.jonna.schinner.dds@geemail.com	Sandy Springs	Georgia	4991718927643	f8213cfda798a7343e9b4ca594613e71	Discover	34.0153966537266967	-84.3030924530781789
29592	2020-06-08 04:03:08	2020-06-08	Codey Kuhn-Reichert	codey.kuhn.reichert@geemail.com	Orlando	Florida	4805690742345361	a44022899b29cd1f8e6453b63ff37cf5	Mastercard	28.321156357348336	-81.3306445899851695
29593	2020-06-08 04:05:41	2020-06-08	Dr. Stacey Conroy PhD	dr.stacey.conroy.phd@geemail.com	Kent	Washington	51072725747554942	bdfa49a7a131eb819a000114e67c0e58	JCB 15 digit	47.4771964467242356	-122.230479244109986
29594	2020-06-08 04:09:53	2020-06-08	Shaunna VonRueden	shaunna.vonrueden@warmmail.com	New York	New York	4779031335714352	0b8bb8500664e3a3505821c16e9be6b1	Maestro	40.7623976123277103	-73.9208814193390253
29595	2020-06-08 04:34:18	2020-06-08	Lavonia Batz	lavonia.batz@geemail.com	El Paso	Texas	4008217154106910	774d762a8df794d2aef4c33976cc7840	JCB 15 digit	31.7859238739419752	-106.43885098565184
29596	2020-06-08 05:00:16	2020-06-08	Nannie Lynch	nannie.lynch@geemail.com	Des Moines	Iowa	4413913367129	c7e503f89d1b86207c25daebeff2be69	Diners Club / Carte Blanche	41.5657162751279756	-93.6727575195066748
29597	2020-06-08 05:03:07	2020-06-08	Miss Ariana Ziemann	miss.ariana.ziemann@geemail.com	Virginia Beach	Virginia	3447819968773299	7e261e725a40ee266eea076c7e126d19	JCB 16 digit	36.7240607972443129	-75.987974856016038
29598	2020-06-08 05:05:33	2020-06-08	Dr. Lewis Raynor	dr.lewis.raynor@geemail.com	San Jose	California	6011885617449660365	950739545381f25b18e52e27b61f0a0b	JCB 16 digit	37.3202646436922265	-121.876438118027153
29599	2020-06-08 05:06:35	2020-06-08	Constance Gusikowski	constance.gusikowski@geemail.com	Independence	Missouri	3009945959472470	9138197b0a8f225e8f3b9fbd7fe4b3c3	VISA 16 digit	39.1035017712991717	-94.3084615706749219
29600	2020-06-08 05:15:44	2020-06-08	Mr. Donavan Ondricka	mr.donavan.ondricka@geemail.com	Fremont	California	501835504095908	7b716eaa32377ff9459f9e124be16284	Mastercard	37.420371325517074	-121.85587520375735
29601	2020-06-08 05:17:48	2020-06-08	Christian Johns	christian.johns@geemail.com	Kent	Washington	4055154089025059	60139580772329f2b9bf0d1e07ac436f	Voyager	47.3381454760786156	-122.127892435914646
29602	2020-06-08 05:37:01	2020-06-08	Ms. Signe Glover PhD	ms.signe.glover.phd@geemail.com	Boston	Massachusetts	6011828802466858064	3193c17086090fa3de4864bc2eb9870d	Voyager	42.2495494011025912	-71.0912190621204729
29603	2020-06-08 05:45:12	2020-06-08	Emit Monahan V	emit.monahan.v@woohoo.com	Oklahoma City	Oklahoma	4038811792829828	5c16a5dd259686f903b8282028761e17	Voyager	35.4885938400313279	-97.6070776762802126
29604	2020-06-08 05:45:20	2020-06-08	Lennie Murray	lennie.murray@warmmail.com	Philadelphia	Pennsylvania	3033754103412150	744c6995ec17376f0717272e8d315ef2	American Express	39.9783501889981352	-75.1947854688756223
29605	2020-06-08 05:53:25	2020-06-08	Hildred Kessler DVM	hildred.kessler.dvm@geemail.com	Los Angeles	California	4858670586284419	6342ccdbe617ab19b6a9d35ba256e6dd	American Express	34.0485923695709545	-118.413411770387739
29606	2020-06-08 05:53:44	2020-06-08	Rahn Fadel-Breitenberg	rahn.fadel.breitenberg@warmmail.com	San Francisco	California	6011925836286427025	ca280ad7931c5d21ae75786b2899ce7c	VISA 13 digit	37.7727087971144542	-122.434382519669981
29607	2020-06-08 05:57:30	2020-06-08	Jessy Jacobson	jessy.jacobson@geemail.com	Oakland	California	4780150778083203	531698a4e200f6ec1000459b6b9e3392	VISA 16 digit	37.8147020455502272	-122.28575601388475
29608	2020-06-08 06:03:44	2020-06-08	Monroe Parker PhD	monroe.parker.phd@geemail.com	Topeka	Kansas	869933761777245711	4a9e6308751d741cb364d62483526eb6	American Express	39.0735527662027664	-95.7295858304191398
29609	2020-06-08 06:09:05	2020-06-08	Kitty Zemlak	kitty.zemlak@geemail.com	Seattle	Washington	4407132953008	f87310ec9360d46ce63f97df7f8e2729	American Express	47.5236024444382608	-122.345221850128468
29610	2020-06-08 06:14:42	2020-06-08	Markus Metz-Gaylord	markus.metz.gaylord@warmmail.com	Los Angeles	California	869976812100857124	c0d3627bfb5d08a554090717951e9f12	JCB 16 digit	33.9660577381826911	-118.333957336143769
29611	2020-06-08 06:22:13	2020-06-08	Raven Carroll	raven.carroll@geemail.com	Lafayette	Louisiana	3158438327056407231	16f8996ab7e31b2906301c46742a0a32	VISA 13 digit	30.2605690279953166	-91.9974024745020955
29612	2020-06-08 06:24:38	2020-06-08	Stacy Kerluke	stacy.kerluke@geemail.com	Phoenix	Arizona	4813124640108424	128e93e4cf97c2ed110baa054c79c771	VISA 13 digit	33.6363830250620879	-112.18659893110619
29613	2020-06-08 06:27:53	2020-06-08	Maxim Nienow	maxim.nienow@warmmail.com	Richmond	California	6011530222590917521	1663f0036785fb98f9fafa598a1aebe8	Discover	37.8968677225943651	-122.374246996347239
29614	2020-06-08 06:28:08	2020-06-08	Maribel Fay-Stamm	maribel.fay.stamm@geemail.com	Fort Worth	Texas	869919564935370753	be3f741397d0eda7215a629f9b72b879	VISA 13 digit	32.770261306600645	-97.4147102151352868
29615	2020-06-08 06:41:40	2020-06-08	Mrs. Pauletta Okuneva	mrs.pauletta.okuneva@geemail.com	Hampton	Virginia	3758742010288494	b127e7ebdf729326b0d9a0e8787fcf69	Diners Club / Carte Blanche	37.1148115397915248	-76.3164752445746188
29616	2020-06-08 06:44:33	2020-06-08	Dr. Andrea Grant PhD	dr.andrea.grant.phd@geemail.com	Honolulu	Hawaii	53369012793485434	930520650d2a9c7084fa7ee4a7383a15	VISA 16 digit	21.287605284269155	-157.945675366253028
29617	2020-06-08 06:45:08	2020-06-08	Logan Dietrich DVM	logan.dietrich.dvm@geemail.com	Houston	Texas	639042015564653	cf39a42328ea6b6bfca3aa3601627ff1	JCB 16 digit	29.7103921982537962	-95.3891269033789655
29618	2020-06-08 06:46:46	2020-06-08	Lawerence Hayes	lawerence.hayes@geemail.com	Corona	California	3780459055494281	74856c23991f1d827333038f9936b271	Voyager	33.9519128593038815	-117.479199714932591
29619	2020-06-08 06:47:10	2020-06-08	Elisha Von	elisha.von@geemail.com	Los Angeles	California	4707871473939031	7b9e52819256798e5c0a2cdbac5cadc6	VISA 16 digit	34.0118825171008652	-118.3842478503
29620	2020-06-08 07:01:19	2020-06-08	Molly Rice	molly.rice@geemail.com	San Angelo	Texas	4296955308121	62722679974901859d89a0d7ea4616a5	Discover	31.3492896965857568	-100.463780567387118
29621	2020-06-08 07:01:33	2020-06-08	Shamar Konopelski	shamar.konopelski@geemail.com	San Francisco	California	6011724448142253380	77425cabe34cd6c847de6fbb18ad83a6	JCB 15 digit	37.7337865289916721	-122.416393031325569
29622	2020-06-08 07:05:49	2020-06-08	Gino Rau	gino.rau@geemail.com	Elizabeth	New Jersey	3088340353152343846	6ad83cafd3d18b4b5937a132938a7b1a	Mastercard	40.6270766927521692	-74.2869658886399122
29623	2020-06-08 07:10:30	2020-06-08	Blanche Harber	blanche.harber@geemail.com	New York	New York	6011067485854819938	a759080f8c727627bc96b17d9b9d4762	Mastercard	40.6975576545335329	-73.9937766181200658
29624	2020-06-08 07:13:00	2020-06-08	Aden Senger	aden.senger@geemail.com	Buffalo	New York	6011383730161204275	4a22113fe26f10fbccd72157b3d409c5	VISA 16 digit	42.9732027263101202	-78.8893728303190329
29625	2020-06-08 07:14:45	2020-06-08	Mrs. Lempi Hartmann	mrs.lempi.hartmann@geemail.com	San Francisco	California	3000105672968978	424adb702eb30fe10fc11ce47732e595	VISA 16 digit	37.7691190187838828	-122.438754532072792
29626	2020-06-08 07:24:15	2020-06-08	Emilia Hahn	emilia.hahn@geemail.com	Cary	North Carolina	589307052130718	3c148faddd81182d910161b7d3a34f11	Discover	35.792791857162122	-78.7705657149750778
29627	2020-06-08 07:38:00	2020-06-08	Reino Kling	reino.kling@geemail.com	Phoenix	Arizona	3096749709246137899	b652163f4a7cb8d61f6c2b491fdc109b	JCB 16 digit	33.6567578934997371	-112.104613678383089
29628	2020-06-08 07:38:41	2020-06-08	Leonce Mayert	leonce.mayert@woohoo.com	San Francisco	California	675996308074739	e112791e65748afb42682e51aece3ba4	VISA 16 digit	37.7372584232678534	-122.448971857995602
29629	2020-06-08 07:41:58	2020-06-08	Denisha Pagac	denisha.pagac@geemail.com	Phoenix	Arizona	869921844625762667	06f66a833257a584523f0355b3833f22	JCB 16 digit	33.5692295630395421	-112.001762996793175
29630	2020-06-08 07:42:22	2020-06-08	Ellyn Spinka-Bartoletti	ellyn.spinka.bartoletti@geemail.com	San Francisco	California	3528501785158565390	4db65b1a929cd1c4d1d4b812db12cbf5	JCB 16 digit	37.7488633794202073	-122.454731583674473
29631	2020-06-08 07:45:05	2020-06-08	Mrs. Mayra Zulauf	mrs.mayra.zulauf@woohoo.com	San Antonio	Texas	3038689431784570	9c5ee1003f00205d8666cbce1f28da99	Mastercard	29.4541964559420961	-98.5635134529158421
29632	2020-06-08 07:49:49	2020-06-08	Mont Schmidt	mont.schmidt@geemail.com	Dallas	Texas	6011080394733930192	a1a4c11db31f221d42827fdc5c33cf96	Maestro	32.8633884902849829	-96.7369956752713733
29633	2020-06-08 07:50:29	2020-06-08	Shonna Jacobs	shonna.jacobs@geemail.com	New York	New York	3018945352752560	0f9078857f17debaa46a12fbe8f310b3	JCB 16 digit	40.6040355893541118	-73.8997108662862274
29634	2020-06-08 07:58:41	2020-06-08	Clay Reinger IV	clay.reinger.iv@geemail.com	Oakland	California	869985076257329233	cb56fd5a8b6ebad7f4cb9667e76682e9	JCB 15 digit	37.8583445123944955	-122.257091966051092
29635	2020-06-08 08:03:12	2020-06-08	Dr. Pate Rodriguez	dr.pate.rodriguez@geemail.com	Sparks	Nevada	55147519775296752	faf2c43927ae36e478d775e8b3749d71	JCB 15 digit	39.4921425662241887	-119.700102284070482
29636	2020-06-08 08:07:26	2020-06-08	Erby Rutherford-Eichmann	erby.rutherford.eichmann@woohoo.com	Westminster	Colorado	210049387429924800	7ee0d50a2a2cdb1954b3a9e08ab24d99	VISA 16 digit	39.8569581715229901	-105.043222605591268
29637	2020-06-08 08:25:14	2020-06-08	Murdock Ferry	murdock.ferry@geemail.com	Charlotte	North Carolina	6011595793282378448	383e752eee0194eca3d3340d35a40b21	JCB 16 digit	35.2408750563647573	-80.7349447431918321
29638	2020-06-08 08:36:58	2020-06-08	Jovanni Dibbert	jovanni.dibbert@geemail.com	San Francisco	California	210025664228753699	db98e7284b95f55ea6f704141c237ea7	Maestro	37.7659161840457216	-122.436994780170991
29639	2020-06-08 09:02:25	2020-06-08	Mr. Diego Marks MD	mr.diego.marks.md@geemail.com	Houston	Texas	4528494071405581	a9445e0d573385885d2e935d5ca98bcd	Voyager	29.8633927085049464	-95.4870047258693688
29640	2020-06-08 09:06:09	2020-06-08	Todd Lang-Stoltenberg	todd.lang.stoltenberg@woohoo.com	Indianapolis	Indiana	869995468700250454	5e9a5d518a9bf99047a814a4e6bee728	VISA 13 digit	39.8578569269746552	-86.1798958209078734
29641	2020-06-08 09:07:58	2020-06-08	Cydney Hagenes DVM	cydney.hagenes.dvm@geemail.com	Memphis	Tennessee	3013613195531865	bc0fec98f59d10ba3ee5701dc69db37b	Voyager	35.1833757188238252	-90.0409432261508016
29642	2020-06-08 09:10:39	2020-06-08	Miss Chastity Okuneva	miss.chastity.okuneva@geemail.com	Vallejo	California	3009805901204431	c43c2c5123f6494c297c3c8eca99b329	Diners Club / Carte Blanche	38.0460169252097629	-122.234057449210425
29643	2020-06-08 09:54:07	2020-06-08	Gardner Heller	gardner.heller@warmmail.com	Dallas	Texas	54555681774592576	3edbb87ceae88ab8a0352709c0a21a83	Discover	32.7829332391072086	-96.8507175018507951
29644	2020-06-08 09:56:09	2020-06-08	Cielo Prohaska	cielo.prohaska@woohoo.com	Lexington	Kentucky	3096020653385782950	f99b5a0fff808006f25c13b5f2b86931	Mastercard	38.0634383643388787	-84.5384393800880645
29645	2020-06-08 10:05:10	2020-06-08	Garret Trantow	garret.trantow@geemail.com	San Francisco	California	54051851951240666	c89c2a888503ab9f8816f9c6bdf1ee7e	American Express	37.7587796689056248	-122.446728851679083
29646	2020-06-08 10:05:20	2020-06-08	Landon Dietrich	landon.dietrich@geemail.com	Philadelphia	Pennsylvania	869935531492621209	335edeca23c7bf42bc681ac4d94915f4	Mastercard	40.0770400166470537	-75.091904636089879
29647	2020-06-08 10:21:06	2020-06-08	Lennon Becker	lennon.becker@woohoo.com	Norwalk	California	3528944372599462274	8f776319781c9872a1f3bb7688151004	JCB 16 digit	33.9235791469574011	-118.164743098014966
29648	2020-06-08 10:23:26	2020-06-08	Sinda Leuschke	sinda.leuschke@geemail.com	Abilene	Texas	55103402733618551	b0485744cf846c68e0ccfa67888fc42c	VISA 13 digit	32.5350522713810264	-99.7284209579177201
29649	2020-06-08 10:31:49	2020-06-08	Annabel Hauck	annabel.hauck@geemail.com	New York	New York	4335305323545185	c61a2295f2de4ee2ed5fdfac505381c3	VISA 16 digit	40.6747797817680947	-74.0020965180255388
29650	2020-06-08 10:35:16	2020-06-08	Adda Emmerich	adda.emmerich@warmmail.com	Indianapolis	Indiana	3528967851857624479	a47c6669f3c01aefd5f82425d7d47754	JCB 15 digit	39.690061886888742	-86.2017820117730622
29651	2020-06-08 10:45:55	2020-06-08	Friend Witting	friend.witting@geemail.com	Athens	Georgia	4352506328968946	8807fde378080748e3b5eed33a4fcee8	Diners Club / Carte Blanche	33.8595682274740142	-83.2998504597343441
29652	2020-06-08 10:48:53	2020-06-08	Jailene Hackett	jailene.hackett@geemail.com	Anaheim	California	4698425230281913	c205193b386213d835e690fdbd119cd0	VISA 13 digit	33.7951054148208314	-117.710039415883273
29653	2020-06-08 10:51:51	2020-06-08	Holli Hills	holli.hills@geemail.com	San Francisco	California	3096879197457524512	52e69f132457e8c8d393006833aa0cb4	Voyager	37.7657934853717165	-122.44030593532537
29654	2020-06-08 10:54:04	2020-06-08	Obed Metz-Gerlach	obed.metz.gerlach@geemail.com	Macon	Georgia	3337948947052756738	942c4179483252a48211bb073f6cf633	Maestro	32.8605777941189672	-83.7546881252627742
29655	2020-06-08 11:06:27	2020-06-08	Timmie Greenholt	timmie.greenholt@geemail.com	Aurora	Colorado	4640982966128048	a85573e6d4472044cf8bcd9603663b79	JCB 16 digit	39.7619743352867658	-104.750506788969787
29656	2020-06-08 11:07:28	2020-06-08	Ellar Abernathy	ellar.abernathy@geemail.com	Milwaukee	Wisconsin	4331404465222424	0ddb6f19843d8afb056669e16c280705	Maestro	43.1453974550675596	-88.029944634261355
29657	2020-06-08 11:11:54	2020-06-08	Ephram Corkery	ephram.corkery@geemail.com	Columbus	Ohio	180003216000943810	8507b1c0dfad6afbc5c9701701c2220b	Voyager	40.0741610176440304	-83.0347398305546562
29658	2020-06-08 11:12:10	2020-06-08	Jossie Lemke	jossie.lemke@geemail.com	Virginia Beach	Virginia	53484672667329560	92705caa78238178347717bdf0178029	Discover	36.732139905095103	-76.0266230085071157
29659	2020-06-08 11:14:59	2020-06-08	Shelley Emard	shelley.emard@woohoo.com	Phoenix	Arizona	3051523567683248	9fe5d6ecb071c9682185e8ef46cc4dfe	JCB 15 digit	33.5234454658281109	-111.998906224167357
29660	2020-06-08 11:15:27	2020-06-08	Orlena Altenwerth	orlena.altenwerth@geemail.com	Oklahoma City	Oklahoma	4237662566148815	37f6b44da42724c53dc4a9090157c523	JCB 16 digit	35.5185965679962194	-97.5560292860388785
29661	2020-06-08 11:18:19	2020-06-08	Venita Hickle MD	venita.hickle.md@warmmail.com	San Diego	California	180085248562107212	00c8718f3d188a84527e532c87581af2	Maestro	32.7399973684057599	-117.061189129194247
29662	2020-06-08 11:35:48	2020-06-08	Mertie Robel DDS	mertie.robel.dds@geemail.com	San Francisco	California	675931919561709	b359bccc43efb2cdc2044c680699545c	American Express	37.7561328982462285	-122.432168306334816
29663	2020-06-08 11:37:26	2020-06-08	Lucius Kuhlman	lucius.kuhlman@geemail.com	Austin	Texas	3058169213343663	7feba5573ad903c9de318b74d56bca98	American Express	30.3047584988769145	-97.8067559847381034
29664	2020-06-08 11:40:00	2020-06-08	Tyra Hammes	tyra.hammes@geemail.com	Tulsa	Oklahoma	4212372670472	3c5923a146a66b6fa37d9fffb713bb08	American Express	36.1347875869736015	-95.9355806824706434
29665	2020-06-08 11:46:38	2020-06-08	Orley Osinski	orley.osinski@geemail.com	Saint Paul	Minnesota	4284404685008287	39c660de5da81567a1532363317073cc	VISA 16 digit	44.9403864194579441	-93.1958380297556488
29666	2020-06-08 11:47:42	2020-06-08	Catharine Hansen	catharine.hansen@geemail.com	Clarksville	Tennessee	4032613998195111	24274f9ff567114516cbf3cfc0893a9b	Maestro	36.6134076311379673	-87.332944282232603
29667	2020-06-08 11:47:55	2020-06-08	Alonzo Witting	alonzo.witting@geemail.com	Winston–Salem	North Carolina	3112065141169782376	ee4ecb5471c409428f0dde6b99d94fe6	Mastercard	36.1175174912203119	-80.2160099626183438
29668	2020-06-08 11:57:15	2020-06-08	Mr. Milford Howell	mr.milford.howell@geemail.com	Indianapolis	Indiana	3158585261907090535	9434946d18dcaf0504540224e625f986	Maestro	39.7079043305952055	-86.1448093724172566
29669	2020-06-08 11:59:10	2020-06-08	Shavonne Wiegand	shavonne.wiegand@geemail.com	High Point	North Carolina	3031989726735460	40d93a15108092418cd34344164c7f14	Discover	35.9127616829797631	-79.9514460620209491
29670	2020-06-08 12:12:07	2020-06-08	Ms. Darian Boehm	ms.darian.boehm@geemail.com	Houston	Texas	3088731920870138653	8e36e93fb6afc8ad79a941fed4b89ef8	Maestro	29.7451265730507686	-95.4493292282350438
29671	2020-06-08 12:18:56	2020-06-08	Cass Bahringer	cass.bahringer@geemail.com	Bakersfield	California	180087969546913163	fb226b0db897c661baa574268100e85d	JCB 15 digit	35.3396469284955401	-119.037272751637914
29672	2020-06-08 12:21:10	2020-06-08	Rosina Lakin	rosina.lakin@geemail.com	Berkeley	California	630428272391476	649e3e7ef83f81d1ad94471468a00d79	VISA 16 digit	37.8887548225544677	-122.225162410493368
29673	2020-06-08 12:29:41	2020-06-08	Jered McCullough	jered.mccullough@geemail.com	San Francisco	California	180092735296300866	288f8f14bce172d83b9b1daeeca9364a	JCB 16 digit	37.7848156468686867	-122.419538473505142
29674	2020-06-08 12:34:58	2020-06-08	Rashaad Skiles	rashaad.skiles@geemail.com	Los Angeles	California	3528438806012534279	a00453ceb9022789860b895b8a304051	Maestro	34.112237285716084	-118.341607381728664
29675	2020-06-08 12:37:26	2020-06-08	Norah Fahey-Hayes	norah.fahey.hayes@warmmail.com	Los Angeles	California	4770794735014538	da3bb166891e9cad926bc5cc11477b2a	JCB 16 digit	34.0320417336054106	-118.440426176087186
29676	2020-06-08 12:44:26	2020-06-08	Robbie Erdman	robbie.erdman@geemail.com	Los Angeles	California	3014108149838309	7b8f7baf62427e0759a16e6528397e31	VISA 16 digit	33.9941091307304788	-118.506129979807127
29677	2020-06-08 12:52:05	2020-06-08	Nora Koelpin	nora.koelpin@geemail.com	Tuscaloosa	Alabama	180046365627648754	4a52dfe32b0962190f7a4d27287490f4	American Express	33.209969511773437	-87.5242796863991686
29678	2020-06-08 13:19:32	2020-06-08	Doreen Aufderhar	doreen.aufderhar@geemail.com	Oakland	California	4635825786366156	4cb626769b3a00fdf3d7e0806b5cd480	JCB 16 digit	37.7751267526421017	-122.248030928151394
29679	2020-06-08 13:22:27	2020-06-08	Cadence Morar	cadence.morar@geemail.com	Providence	Rhode Island	3528815547828063557	6b9bae529b3275f29990d09ad6f0ff20	JCB 15 digit	41.8142666655447286	-71.3455156096175358
29680	2020-06-08 13:31:29	2020-06-08	Lashawn Strosin	lashawn.strosin@geemail.com	New York	New York	4274884923442475	479777b42af40f57e4632eae070034fd	VISA 16 digit	40.7324751839265247	-74.0269622149772886
29681	2020-06-08 14:02:31	2020-06-08	Corwin Lueilwitz Sr.	corwin.lueilwitz.sr.@geemail.com	Philadelphia	Pennsylvania	3337401806442776212	21eff220e992d5ae9dd43946ed7029eb	Discover	40.0814805312506834	-75.0598448557212947
29682	2020-06-08 14:18:48	2020-06-08	Jesse Wunsch	jesse.wunsch@geemail.com	Fort Wayne	Indiana	3408909670678329	de8ad29f5f25e058ad9d33a927ca732e	Voyager	41.0239540464028707	-85.1295847024988461
29683	2020-06-08 14:34:12	2020-06-08	Alejandra Hintz	alejandra.hintz@geemail.com	New York	New York	3022261227653835	808176aadd2813d5736e3f24618367f7	American Express	40.7297763480562693	-73.921084988386184
29684	2020-06-08 14:45:22	2020-06-08	Robbie Yundt	robbie.yundt@warmmail.com	Indianapolis	Indiana	3484505051777172	eed52a61e76983c942a68f0f7590c45f	Voyager	39.8254581249326449	-86.1279416198112102
29685	2020-06-08 14:48:47	2020-06-08	Mr. Mohammad Kuphal	mr.mohammad.kuphal@geemail.com	San Francisco	California	4173113322555808	28c822185551052b830487417d15f7ab	JCB 15 digit	37.7801493733935274	-122.432274330596371
29686	2020-06-08 15:11:19	2020-06-08	Lyric Wilderman	lyric.wilderman@geemail.com	New York	New York	3112437956384692501	a7dba33979ffbeaf2b63f5069a102c14	VISA 13 digit	40.7173258831482343	-73.8986814943037871
29687	2020-06-08 15:12:09	2020-06-08	Dorine Steuber	dorine.steuber@warmmail.com	New York	New York	4198653241855848	bee315c67fc108efcb8e6f3ecae751d6	Diners Club / Carte Blanche	40.746886970963331	-73.8634605614364119
29688	2020-06-08 15:21:05	2020-06-08	Heber Hansen	heber.hansen@geemail.com	Newark	New Jersey	3495946374560068	359f43ac3c892b6d6e890e01033715cc	VISA 16 digit	40.7359027552332762	-74.2036090578161236
29689	2020-06-08 15:26:20	2020-06-08	Triston Mitchell-Lowe	triston.mitchell.lowe@geemail.com	Surprise	Arizona	3337772912555473927	aee6d5739ba9212c8da7f75f67a57a04	Discover	33.7568101829610754	-112.434594082250072
29690	2020-06-08 15:26:25	2020-06-08	Mr. Alva Jones	mr.alva.jones@geemail.com	Yonkers	New York	3337246176403612668	3552ed65876b9d6596605202f79fd963	VISA 16 digit	40.9180095201559411	-73.8816731616739162
29691	2020-06-08 15:29:35	2020-06-08	Texas Rempel	texas.rempel@geemail.com	New York	New York	4250462912235503	d2ea4341341e5325dbf0a0859653b20e	American Express	40.6064007981903856	-73.9229572933528516
29692	2020-06-08 15:38:17	2020-06-08	Thekla Wuckert	thekla.wuckert@geemail.com	Mesa	Arizona	6011379741586901516	7a193ac9076acd04f586ffd621a484d6	JCB 15 digit	33.3375990322470628	-111.690611881797764
29693	2020-06-08 15:40:50	2020-06-08	Mrs. Ela O'Keefe PhD	mrs.ela.o'keefe.phd@geemail.com	Philadelphia	Pennsylvania	639050586002698	9f12fe84c0aaee1fb15e574a8552637f	JCB 16 digit	40.0315898201387341	-75.1412313701950012
29694	2020-06-08 15:43:23	2020-06-08	Mickie Jerde	mickie.jerde@woohoo.com	Miami	Florida	4940849395004248	60cd4a73aeb1d048dc452a9502b7a424	VISA 13 digit	25.7405350207489008	-80.2028646477837128
29695	2020-06-08 15:45:08	2020-06-08	Owen Strosin	owen.strosin@geemail.com	San Francisco	California	3414384312356498	10bce46b1074490431685361710cb891	JCB 16 digit	37.7475254908048328	-122.413850821026031
29696	2020-06-08 16:28:03	2020-06-08	Benito Wisoky	benito.wisoky@geemail.com	Salem	Oregon	4811421503763606	39a2129c402ff159a6795ba3dd565ee2	VISA 16 digit	45.0020116503152963	-123.00041711569466
29697	2020-06-08 16:33:23	2020-06-08	Horatio Jones	horatio.jones@geemail.com	Baltimore	Maryland	3088892767405694733	98f3bc5ac4428617217333807eae72e0	VISA 16 digit	39.3700712041929322	-76.5130769239757171
29698	2020-06-08 16:47:36	2020-06-08	Mrs. Vernetta Langworth MD	mrs.vernetta.langworth.md@geemail.com	Wichita	Kansas	3158280530315038718	946165ca0063b78c3547eede47dd16bd	JCB 16 digit	37.6506269696045663	-97.2794837943945083
29699	2020-06-08 16:58:26	2020-06-08	Dr. Bronson Collier	dr.bronson.collier@warmmail.com	Oakland	California	52360623531975400	346536d283e064a4302b5b431ff32210	JCB 15 digit	37.770483469447278	-122.303642678167762
29700	2020-06-08 17:00:24	2020-06-08	Martika Hane	martika.hane@geemail.com	Buffalo	New York	3088855472764867831	729837ac97cb527c6b0b99936035dc5f	VISA 16 digit	42.9311186462361363	-78.8331146585688032
29701	2020-06-08 17:02:29	2020-06-08	Shayne Huel	shayne.huel@geemail.com	Jacksonville	Florida	54426685020314724	ad4267e9c04e0d0c5aa058b9ad3a1d33	VISA 13 digit	30.3933927195664495	-81.5958062016017749
29702	2020-06-08 17:07:22	2020-06-08	Dr. Janell Leannon	dr.janell.leannon@woohoo.com	Oakland	California	4508603094923	67c84cba45c4cb98decd90f826de42ce	JCB 16 digit	37.7888603112600379	-122.27299284072464
29703	2020-06-08 17:10:30	2020-06-08	Daunte Rodriguez III	daunte.rodriguez.iii@geemail.com	Berkeley	California	3734477263683567	b37a5d3d667fe560accc490e047af424	Maestro	37.8852590107751013	-122.266511228382583
29704	2020-06-08 17:18:08	2020-06-08	Ramiro Cummings V	ramiro.cummings.v@geemail.com	San Francisco	California	51686570265623531	6f254a03dcb8f5730ff8463a0340f8fb	JCB 16 digit	37.7577351188812216	-122.430081189525069
29705	2020-06-08 17:36:51	2020-06-08	Christina Hickle	christina.hickle@geemail.com	Glendale	California	3792893316320321	7a9f997fa6b632b5a0dbeb803b5b6d00	JCB 16 digit	34.1430447030566597	-118.269563588117435
29706	2020-06-08 17:41:00	2020-06-08	Zaiden Schoen	zaiden.schoen@geemail.com	Oklahoma City	Oklahoma	4264396333460346	8de5a38351b878cbda17875fc0a39f99	VISA 16 digit	35.3978247336022562	-97.4213927465386718
29707	2020-06-08 17:51:01	2020-06-08	Dorinda Schumm	dorinda.schumm@warmmail.com	Mesa	Arizona	4988017315249	06811bb3339c75a3befccce2b3725a24	Mastercard	33.4497176545351707	-111.692673387925694
29708	2020-06-08 18:05:17	2020-06-08	Julianne Kris PhD	julianne.kris.phd@geemail.com	Stockton	California	4398746938311675	90d48cb5806775901acd3297028fb8c6	JCB 16 digit	37.8763253615435218	-121.345285948933281
29709	2020-06-08 18:09:12	2020-06-08	Junious Cormier	junious.cormier@woohoo.com	San Francisco	California	3008380239032210	a56ee5d067af6dc22f549d9beb3240fc	VISA 16 digit	37.7659875185377985	-122.446411495065988
29710	2020-06-08 18:18:59	2020-06-08	Deonte Denesik	deonte.denesik@geemail.com	Houston	Texas	3437055973713200	81c7f987e02f7ee7a53ad5263cbf54a9	JCB 15 digit	29.7214138057626798	-95.2934696656201083
29711	2020-06-08 18:22:54	2020-06-08	Dr. Antoine Hickle	dr.antoine.hickle@geemail.com	San Francisco	California	53008819390722374	fd1ddaf77411638f966b6ed9fcd61823	Maestro	37.7961948986943312	-122.425527357288857
29712	2020-06-08 18:25:21	2020-06-08	Bob Hirthe	bob.hirthe@geemail.com	New York	New York	51697208265223765	baa4bf900d99bb4366f28c44d4022743	Discover	40.5693546480257083	-74.0293660897191614
29713	2020-06-08 18:42:30	2020-06-08	Edyth Fahey MD	edyth.fahey.md@woohoo.com	Scottsdale	Arizona	4308266803582879	d8b9358ee517489b39dbe68e2056a99e	Maestro	33.6571818598203336	-111.769799758397411
29714	2020-06-08 18:53:06	2020-06-08	Arlyn Breitenberg	arlyn.breitenberg@geemail.com	Cedar Rapids	Iowa	676264841408343	af8c79f576f85be2733dfe8378880bcb	Maestro	41.9158763902336347	-91.6744373232659058
29715	2020-06-08 18:56:55	2020-06-08	Ardyce Koss PhD	ardyce.koss.phd@geemail.com	Phoenix	Arizona	4359080964291859	96f66f12f8d52a009435f6de1a371bb4	Diners Club / Carte Blanche	33.48429510001354	-112.176118282128499
29716	2020-06-08 19:43:57	2020-06-08	Emeline Robel	emeline.robel@geemail.com	San Francisco	California	6011360491062059352	5584409019484826bacf0add0e680db5	VISA 16 digit	37.7965796253610833	-122.457827003125445
29717	2020-06-08 19:53:13	2020-06-08	Louie Schulist	louie.schulist@geemail.com	Gilbert	Arizona	53412472761782849	8c6bee5e863bafda3a661bfe488a1a99	VISA 13 digit	33.3791666920643308	-111.81571515310965
29718	2020-06-08 20:01:26	2020-06-08	Elex Erdman	elex.erdman@geemail.com	Billings	Montana	3029396579755698	9e5515ad8451d3802514b473c12a5936	Discover	45.8309381359480312	-108.572907533652696
29719	2020-06-08 20:02:10	2020-06-08	Press Anderson	press.anderson@warmmail.com	Lansing	Michigan	3457579198694809	1bdde180835491745059211e9513a5ed	VISA 13 digit	42.705667370262745	-84.6084229868493907
29720	2020-06-08 20:53:05	2020-06-08	Mrs. Kaye Johnston	mrs.kaye.johnston@woohoo.com	New York	New York	3790709673025547	07f085a1b01fa6781f4588a9f1963c13	VISA 16 digit	40.5686134234759948	-73.9612264070555483
29721	2020-06-08 20:59:08	2020-06-08	Mr. Brandy McKenzie	mr.brandy.mckenzie@geemail.com	Rochester	Minnesota	4855033783689844	9966d8dd1b7bfb4c5c71b546cc091ecc	Discover	44.1111940255291728	-92.4353667247228259
29722	2020-06-08 21:06:13	2020-06-08	Jayleen Bogisich DDS	jayleen.bogisich.dds@geemail.com	Newark	New Jersey	3023811944459988	1c71c844793a815c2a8bfdedf32d9911	JCB 16 digit	40.7310706064950736	-74.2468839023936624
29723	2020-06-08 21:08:35	2020-06-08	Mr. Kennedy Lebsack II	mr.kennedy.lebsack.ii@geemail.com	San Diego	California	4216447269123231	a1887f359738a77919ea690beabaeb58	JCB 16 digit	32.8153545518472782	-117.058805448599159
29724	2020-06-08 21:24:27	2020-06-08	Rowland Heaney PhD	rowland.heaney.phd@geemail.com	San Diego	California	869990846817836197	62688de48c993493eb3c3c26e8f57ec8	JCB 16 digit	32.9013983148217193	-117.201407252894725
29725	2020-06-08 21:42:06	2020-06-08	Ashton Emard-Schamberger	ashton.emard.schamberger@geemail.com	Phoenix	Arizona	53385693109050853	60b6932fdaa221a3886e1b87506b816e	JCB 16 digit	33.6617191659219586	-112.052191114558283
29726	2020-06-08 21:45:18	2020-06-08	Earl Batz	earl.batz@geemail.com	El Paso	Texas	3158536909348157624	bbf5b7319faf7905f4b13998cf67689a	Voyager	31.8397516076747351	-106.471081357633707
29727	2020-06-08 21:52:06	2020-06-08	Mr. Greggory Thompson DDS	mr.greggory.thompson.dds@geemail.com	San Francisco	California	3407941390925350	dcee2fbeff0c79a3d93231a258ea1abe	VISA 16 digit	37.7874398536551936	-122.424285402270201
29728	2020-06-08 21:56:11	2020-06-08	Boss Dach	boss.dach@geemail.com	Corpus Christi	Texas	3710182268769753	7d8cbad76c6876774e1ca2a7e9039863	Maestro	27.655757838667558	-97.1597945707678861
29729	2020-06-08 21:57:56	2020-06-08	Miss Leonia Leuschke	miss.leonia.leuschke@geemail.com	Cleveland	Ohio	3024498202318327	392f90c2799778cbc0c941a7e05d0a68	VISA 16 digit	41.3959639146309328	-81.703230452654509
29730	2020-06-08 22:03:24	2020-06-08	Bebe Rath-Goodwin	bebe.rath.goodwin@woohoo.com	Pittsburgh	Pennsylvania	3050604285616990	c7404b1659c7a61447d57ab9cd171867	JCB 16 digit	40.4781644126821263	-80.053148373280095
29731	2020-06-08 22:39:06	2020-06-08	Lark Glover	lark.glover@geemail.com	Phoenix	Arizona	3158398059580891121	c4ff62860e100831e6959bddc5bad04a	Discover	33.595806320703403	-112.14379129017928
29732	2020-06-08 22:42:25	2020-06-08	Stephon Balistreri	stephon.balistreri@geemail.com	Elk Grove	California	676367764603527	d57bba32726349a34e48cbe4e8bab292	Mastercard	38.3203548300363153	-121.333616561479872
29733	2020-06-08 22:47:05	2020-06-08	Tonia Weissnat	tonia.weissnat@warmmail.com	Sacramento	California	3038200224437630	7cce50e41b71796468ca83fe7070a07a	JCB 15 digit	38.5575910148475316	-121.535854103906445
29734	2020-06-08 22:47:57	2020-06-08	Tory Lynch	tory.lynch@geemail.com	Cary	North Carolina	3158381305240405391	ae2e176fff23e0752380b771fd5f81d4	VISA 16 digit	35.7028438951462519	-78.7956519560508468
29735	2020-06-08 22:51:18	2020-06-08	Mr. Fritz Lakin IV	mr.fritz.lakin.iv@geemail.com	Augusta	Georgia	869965170905950898	391f351a02bf1fae4713248add1229c0	Voyager	33.367884001482274	-82.0007950234055585
29736	2020-06-08 22:56:08	2020-06-08	Esperanza Towne	esperanza.towne@warmmail.com	San Francisco	California	3337346737164571044	349b301fb79b86a3c3de7857bc62bb86	American Express	37.7729075600664643	-122.422981555397641
29737	2020-06-08 23:05:13	2020-06-08	Mr. Syed Funk	mr.syed.funk@geemail.com	Cedar Rapids	Iowa	4500059084844373	49320de518ee5fec58b8fd981e1386cf	VISA 13 digit	42.0626017529591891	-91.673271055945392
29738	2020-06-08 23:21:28	2020-06-08	Lorena Dickens-Spencer	lorena.dickens.spencer@warmmail.com	Sacramento	California	639099691079729	48f92e65e633e5f3b1e0a1ca138d4fbf	Voyager	38.4813149587515753	-121.442466287060071
29739	2020-06-08 23:38:44	2020-06-08	Makai Krajcik V	makai.krajcik.v@woohoo.com	Chandler	Arizona	3158235101137960384	c8b44a97b037a4138501ccf184b7aaee	Voyager	33.3356944919187583	-111.789372746681423
29740	2020-06-08 23:45:24	2020-06-08	Eugene Pollich	eugene.pollich@woohoo.com	San Francisco	California	3088791761786492231	9636429bb387c4dea9366217908d1c64	JCB 16 digit	37.7799621091856821	-122.419479766443843
29741	2020-06-08 23:47:33	2020-06-08	Dr. Kaeden Roob	dr.kaeden.roob@woohoo.com	Charlotte	North Carolina	3464965181035434	715dab9f57f10a7acc6fca742f3fb871	American Express	35.1401280313517859	-80.739959465241057
29742	2020-06-08 23:49:14	2020-06-08	Quinton Collins	quinton.collins@geemail.com	Oakland	California	3088688155672233765	6186d99ead85eaa4535f891626da1d6f	Diners Club / Carte Blanche	37.7997890931177878	-122.261193346486223
29743	2020-06-08 23:59:28	2020-06-08	Dr. Whitley Baumbach MD	dr.whitley.baumbach.md@warmmail.com	Lexington	Kentucky	4687572712168	8a58824d28992ed16febbb9edd328a79	American Express	38.0738382852979029	-84.5240137306872725
29744	2020-06-09 00:18:56	2020-06-09	Shawna Dietrich	shawna.dietrich@geemail.com	Augusta	Georgia	3337611355692088106	d92432983b13445686ad759ec3337d1a	JCB 15 digit	33.2673824061844456	-82.1376018101643837
29745	2020-06-09 00:25:34	2020-06-09	Mr. Hope Walter	mr.hope.walter@geemail.com	San Diego	California	4730935680577958	52f36e2725629781094e18b9e3b9c224	Mastercard	32.7934211991794413	-117.087005424117677
29746	2020-06-09 00:26:33	2020-06-09	Jeanie Kuhn-Howe	jeanie.kuhn.howe@geemail.com	Pomona	California	210021836331841330	83a2b7f4fa4aa8886fa7d71fae32e5fc	VISA 16 digit	34.0871259176675281	-117.836550657214971
29747	2020-06-09 00:28:09	2020-06-09	Felicie Hauck	felicie.hauck@warmmail.com	Augusta	Georgia	4675381244903	34432aaeb6abe689061fce9e73c197ed	Mastercard	33.3443880805950599	-82.1229404039043942
29748	2020-06-09 00:30:17	2020-06-09	Mr. Council Maggio	mr.council.maggio@geemail.com	Los Angeles	California	4891548026188	f460a180a6832ba345c9e4a5f1bcde3d	Diners Club / Carte Blanche	34.0344592903606582	-118.503966733812533
29749	2020-06-09 00:38:11	2020-06-09	Dr. Catalina Walsh	dr.catalina.walsh@woohoo.com	New York	New York	4490132109834455	173fa8505376c823b679c6febc1d71fe	JCB 16 digit	40.7350235087089203	-73.9694822994887744
29750	2020-06-09 00:47:34	2020-06-09	Dorinda Towne-Barrows	dorinda.towne.barrows@geemail.com	Clearwater	Florida	3528124460463735693	3f04e5a8bf4a48c9310b5b0167201e13	VISA 13 digit	27.9658294395670275	-82.7587262976247757
29751	2020-06-09 00:48:03	2020-06-09	Edd Zieme-Kozey	edd.zieme.kozey@geemail.com	San Bernardino	California	4834596788395902	2f4d2665c9ca451ada108bfaf1a3e758	Voyager	34.1667533405855295	-117.281224207790942
29752	2020-06-09 00:49:18	2020-06-09	Kiley Dicki	kiley.dicki@geemail.com	Los Angeles	California	4335310936092203	6ce394ffd0a8e28f2e34e41ba7780d2d	American Express	34.0608536074269566	-118.346861438918111
29753	2020-06-09 01:05:53	2020-06-09	Davon Purdy	davon.purdy@geemail.com	Oakland	California	3798601531713566	af1e4c898ecf8831ef78645c81f17e7b	VISA 13 digit	37.8178914209688273	-122.282628374316388
29754	2020-06-09 01:07:43	2020-06-09	Sid Cartwright	sid.cartwright@woohoo.com	Madison	Wisconsin	4105072552157334	54c0f47dc7d7e9ebf714be3460c0665f	Voyager	43.0119185165476097	-89.525010162952924
29755	2020-06-09 01:21:22	2020-06-09	Mr. Maximo Wisozk DVM	mr.maximo.wisozk.dvm@geemail.com	Minneapolis	Minnesota	4730606196980	c548afa604d805d7cc020824dfceb153	JCB 16 digit	45.026376210813595	-93.3342141503274405
29756	2020-06-09 01:29:14	2020-06-09	Eartha Beahan	eartha.beahan@geemail.com	Pasadena	Texas	3033903266284464	9494c2f0620393de9b04230c1d072aff	VISA 16 digit	29.6974588442467144	-95.1309818432614236
29757	2020-06-09 01:40:22	2020-06-09	Harlen Luettgen	harlen.luettgen@geemail.com	Hialeah	Florida	639017251862078	0ce698b6ebf202061b7d4264c042b521	JCB 16 digit	25.7790874909587231	-80.2742473279960365
29758	2020-06-09 01:44:25	2020-06-09	Dr. Beulah Keebler MD	dr.beulah.keebler.md@geemail.com	San Francisco	California	4895632811363272	e6d01d90905331f2f3e35f263e7fb253	JCB 16 digit	37.7830021167951173	-122.477963364513386
29759	2020-06-09 01:54:36	2020-06-09	Kaylah Baumbach	kaylah.baumbach@warmmail.com	Philadelphia	Pennsylvania	3337202807752470314	96cf5ae01b71b5f96a77eca1ede04e78	JCB 16 digit	40.109055447946858	-75.0613327773653083
29760	2020-06-09 02:03:11	2020-06-09	Lige Torp	lige.torp@warmmail.com	Oakland	California	55572634962852202	b5d4749b32f5644bc9f4021245557a32	JCB 15 digit	37.8011291638997378	-122.263059989079238
29761	2020-06-09 02:04:44	2020-06-09	Aron Veum	aron.veum@geemail.com	Chicago	Illinois	3410105829154843	f7fff197e988f6c15386168df7b7425f	JCB 16 digit	41.9020201615359653	-87.7777089094772833
29762	2020-06-09 02:11:14	2020-06-09	Edna Gutmann PhD	edna.gutmann.phd@geemail.com	Tucson	Arizona	3727835226238762	4699e02d942f919f54a958ecba481821	Voyager	32.2134415521327426	-110.815260012377422
29763	2020-06-09 02:11:56	2020-06-09	Jill Schmeler-Kohler	jill.schmeler.kohler@geemail.com	Aurora	Colorado	3528999749006044569	520541633a249eb3268a8b099f63c47a	JCB 16 digit	39.6905426780339354	-104.727346337551992
29764	2020-06-09 02:27:11	2020-06-09	Mr. Elton Hackett	mr.elton.hackett@geemail.com	Daly City	California	3096198218200807576	fd8fd0af6e0aa9f781a552a57059929c	JCB 16 digit	37.760725745644045	-122.42965020719916
29765	2020-06-09 02:42:30	2020-06-09	Britton Sauer	britton.sauer@geemail.com	Austin	Texas	3112099781741966540	da4d520e7929e15face72b06161891ef	VISA 13 digit	30.2941112160343664	-97.8515510104835045
29766	2020-06-09 02:47:07	2020-06-09	Ms. Danna O'Connell DDS	ms.danna.o'connell.dds@warmmail.com	Berkeley	California	4194582016271085	d4c1bdfe58f5c7aef39cc168ce88f844	Mastercard	37.9102462152104707	-122.271980666478171
29767	2020-06-09 02:55:56	2020-06-09	Mr. Mel Mayert IV	mr.mel.mayert.iv@geemail.com	New Orleans	Louisiana	4262494659764094	22814bdbfc68e5660bc4bbc221581f1a	JCB 15 digit	30.1127297141604124	-89.8723756029996963
29768	2020-06-09 03:03:15	2020-06-09	Rosia Leannon	rosia.leannon@geemail.com	Columbus	Ohio	869920903638498775	c853cfe08719b55f162c490722da92a7	Mastercard	40.0218540948860309	-83.0298792833231403
29769	2020-06-09 03:10:47	2020-06-09	Mr. Winthrop Hickle	mr.winthrop.hickle@geemail.com	Pembroke Pines	Florida	3032400719519878	3749b17110be41e168110fc90d444354	Maestro	26.0040281545873739	-80.3430052372530099
29770	2020-06-09 03:11:53	2020-06-09	Kailee Barrows	kailee.barrows@geemail.com	Plano	Texas	3528390281757810522	c868d750a52b57c65256f340c952619f	Diners Club / Carte Blanche	33.0384053912565108	-96.6489602599941264
29771	2020-06-09 03:14:06	2020-06-09	Celestia Klein	celestia.klein@geemail.com	Huntington Beach	California	4463455834315257	94145f41719d13e5c1e004f95c878b11	VISA 16 digit	33.6354206458706457	-117.989129174140459
29772	2020-06-09 03:14:49	2020-06-09	Maximo Kihn	maximo.kihn@geemail.com	Moreno Valley	California	4671229423145039	657814120cb64ac365d6dea7901ac867	JCB 16 digit	33.8798840415656528	-117.256440201026194
29773	2020-06-09 03:33:48	2020-06-09	Mr. Rory Farrell PhD	mr.rory.farrell.phd@geemail.com	Oxnard	California	210082751392320213	02d2a3fc0d87eaae2b6c564dcc6e98ed	Mastercard	34.2638323325153422	-119.28700790083073
29774	2020-06-09 03:41:07	2020-06-09	Mrs. Anais Hagenes	mrs.anais.hagenes@geemail.com	Vacaville	California	502020050098910	9dc236eba0a438d34d37a52f1371f599	VISA 16 digit	38.3725066522728682	-122.021255364257101
29775	2020-06-09 03:45:06	2020-06-09	Hal Ryan DDS	hal.ryan.dds@woohoo.com	Lexington	Kentucky	4231351450054562	506ff73f00a764499acaf7601d7b6a34	VISA 13 digit	37.9546741508755829	-84.4079352774556639
29776	2020-06-09 04:00:03	2020-06-09	Beula Schaefer	beula.schaefer@woohoo.com	Thornton	Colorado	630459642104778	095502555ada1fea2ba470d37a066515	Maestro	39.8840452284883753	-104.97378249961622
29777	2020-06-09 04:01:34	2020-06-09	Miss Malaya Weimann	miss.malaya.weimann@geemail.com	Baton Rouge	Louisiana	180074482607019131	f2bae100602dce2b6a664ba821e8ccbb	Maestro	30.4039850958835345	-91.0769586818400683
29778	2020-06-09 04:03:04	2020-06-09	Hakeem Klocko	hakeem.klocko@geemail.com	Clinton	Michigan	3037203895542382	973b54d3d0c157400cdd73cafd5e7996	Discover	42.5106821226488805	-83.0125276920925899
29779	2020-06-09 04:12:20	2020-06-09	Dr. Rome Hansen	dr.rome.hansen@geemail.com	New York	New York	501856479042113	1b1d100ba89111436847831fb07b1611	Voyager	40.6868656521886578	-73.9426649205282303
29780	2020-06-09 04:16:48	2020-06-09	Eveline Jenkins	eveline.jenkins@geemail.com	New York	New York	3337021087169062132	5e5657e7ca98340f0b006aa023783df1	Diners Club / Carte Blanche	40.6710182104483238	-73.9300943859748543
29781	2020-06-09 04:27:07	2020-06-09	Gabe Cremin	gabe.cremin@geemail.com	San Francisco	California	180041223868472084	021b905c9f4c0142f8ac2ff441c64a10	Maestro	37.766861315806338	-122.430761854676732
29782	2020-06-09 04:29:19	2020-06-09	Talan Bosco-Kozey	talan.bosco.kozey@geemail.com	Santa Rosa	California	51850364169395556	4c8b7a0b3797d8dd1ba8deef3a6320c1	JCB 16 digit	38.4616702857550266	-122.762892246038106
29783	2020-06-09 04:34:05	2020-06-09	Allan Tromp IV	allan.tromp.iv@geemail.com	Chattanooga	Tennessee	676210476236855	d97b1c07f70490462c81a445a2a2f6e0	JCB 16 digit	35.0474843266736755	-85.2685493481174177
29784	2020-06-09 05:17:30	2020-06-09	Gorden Auer	gorden.auer@geemail.com	Corpus Christi	Texas	675996305138214	a15573827628f202305181a6707f4fed	Diners Club / Carte Blanche	27.6872101622104658	-97.1763194245114903
29785	2020-06-09 05:22:28	2020-06-09	Hurley Lueilwitz MD	hurley.lueilwitz.md@geemail.com	Lexington	Kentucky	3049568099217959	05ffa3d3ea76f1709decf2b6e77635cd	American Express	38.1339009621989007	-84.4271236177898885
29786	2020-06-09 05:25:50	2020-06-09	Kaelynn Keebler	kaelynn.keebler@woohoo.com	Springfield	Massachusetts	4677807921195335	558e5df530fd305ed4343505e8510f72	VISA 13 digit	42.1331020028069574	-72.6239057803619659
29787	2020-06-09 05:31:40	2020-06-09	Marcel Becker	marcel.becker@geemail.com	Beaumont	Texas	4192644327040955	d2342a48bef4914505037eb2bef2eeca	JCB 16 digit	30.1213244604948933	-94.1515994107604115
29788	2020-06-09 05:34:12	2020-06-09	Jered Frami-Bauch	jered.frami.bauch@geemail.com	Murfreesboro	Tennessee	53633083133328915	09e72df4fd3c0abf43cfc20ff2e746bd	Mastercard	35.7687629078168428	-86.3994707830566853
29789	2020-06-09 05:35:11	2020-06-09	Ismael Aufderhar	ismael.aufderhar@geemail.com	Garland	Texas	869915619840083604	b2e0e14ee5050bebe2f22d0764cecda3	JCB 16 digit	32.9557593141917096	-96.6545923306766923
29790	2020-06-09 06:20:22	2020-06-09	Mrs. Alisha Jones	mrs.alisha.jones@geemail.com	San Francisco	California	6011876093016952349	e0dd81f9309814c93e6d3145c7c06622	VISA 13 digit	37.7759125032016527	-122.424869994067564
29791	2020-06-09 06:30:11	2020-06-09	Sylvia Stoltenberg-Keebler	sylvia.stoltenberg.keebler@warmmail.com	Aurora	Colorado	4557253099159263	04b9a955ab4c4a1efaab5e18087a746a	Voyager	39.6460135402269671	-104.679797857499494
29792	2020-06-09 06:31:10	2020-06-09	Hilda Adams	hilda.adams@geemail.com	Miami	Florida	3415265250449461	87c8f1e4b09274c6174fc87f25d90d94	JCB 15 digit	25.7255834986593577	-80.3051903006028454
29793	2020-06-09 06:34:14	2020-06-09	Dr. Ethen Anderson	dr.ethen.anderson@geemail.com	New York	New York	4503630676263	791bdea2d2caa96de07b45b741cd92b8	VISA 16 digit	40.7037933703735462	-73.8478328313574224
29794	2020-06-09 06:44:19	2020-06-09	Shanell Hodkiewicz	shanell.hodkiewicz@geemail.com	Columbus	Georgia	3096763938075777480	3ea62671ea878824cec8a5361dd6a951	American Express	32.4246202015828331	-84.8910131002474486
29795	2020-06-09 06:56:11	2020-06-09	Nicolas Koss	nicolas.koss@geemail.com	San Angelo	Texas	3112052366150579748	84b4ad09e907ab0dbb5160306ac4421a	Voyager	31.3869195636980223	-100.46445931406879
29796	2020-06-09 06:57:44	2020-06-09	Eppie Legros	eppie.legros@geemail.com	Los Angeles	California	6011557241746296802	0f0a067fd25c617e3e5fb7444aa8c0c1	American Express	34.0997621846716825	-118.472129366825513
29797	2020-06-09 06:58:02	2020-06-09	Jeannette Kuhlman	jeannette.kuhlman@warmmail.com	Los Angeles	California	3773409323306766	9a20b586c00752114b5d8af5c1642ed4	VISA 16 digit	34.1188698123075014	-118.385571793419487
29798	2020-06-09 07:24:33	2020-06-09	Viviana Dicki	viviana.dicki@geemail.com	Worcester	Massachusetts	3001628876906956	f946766e0a1259f59f0837bbf9963131	Mastercard	42.3244919753801057	-71.8094130204778196
29799	2020-06-09 07:27:56	2020-06-09	Orin Toy	orin.toy@woohoo.com	Grand Rapids	Michigan	3787397848299406	7203c57c2a2458d4ed36af79178c78b9	VISA 13 digit	42.9199729779072072	-85.721380626749621
29800	2020-06-09 07:35:57	2020-06-09	Mr. Silvester Bechtelar	mr.silvester.bechtelar@woohoo.com	San Francisco	California	4069765316284666	8abcd09d0433791d7e93a622c69f25d0	American Express	37.7852770594283527	-122.425938786647706
29801	2020-06-09 07:36:07	2020-06-09	Leonore Pfannerstill	leonore.pfannerstill@geemail.com	Reno	Nevada	3112327421696808942	cb21161202567cadd23f9863f21391f6	VISA 16 digit	39.526890079219271	-119.798020709927755
29802	2020-06-09 07:42:26	2020-06-09	Darwyn Wintheiser	darwyn.wintheiser@woohoo.com	Hollywood	Florida	55977250686203829	f27cd5762ddc72dd7b1ce44414953014	Discover	26.0722334809079754	-80.200145997181906
29803	2020-06-09 07:43:52	2020-06-09	Dr. Tommy Breitenberg	dr.tommy.breitenberg@woohoo.com	Houston	Texas	180077937145613460	636fa7f73f96e86781a66f420f8584c3	Voyager	29.7798917703408748	-95.4187335356153596
29804	2020-06-09 07:45:25	2020-06-09	Theresa Kautzer	theresa.kautzer@warmmail.com	Allentown	Pennsylvania	630423296681697	16b145ed3eca00baa94cdca6ff61e78c	Discover	40.6501966930240428	-75.4612692035749433
29805	2020-06-09 07:47:53	2020-06-09	Joette Monahan-Johnson	joette.monahan.johnson@geemail.com	Chicago	Illinois	51370928254096278	aa62cdbd6dc6a2fddff0a43fddfe2587	Voyager	41.8979062180802231	-87.7186338454049093
29806	2020-06-09 08:19:39	2020-06-09	Sylvania Walker-Morar	sylvania.walker.morar@geemail.com	Cleveland	Ohio	3461919275860192	2f588373ea39428e2b55c67fa7ba3455	JCB 16 digit	41.5327487249243958	-81.5983253021963009
29807	2020-06-09 08:21:49	2020-06-09	Dr. Eusebio Gerhold	dr.eusebio.gerhold@woohoo.com	Chicago	Illinois	180026714874627645	587113d7a6220810cd6858c6dc54a9cd	Voyager	41.9326196356512639	-87.676160036682333
29808	2020-06-09 08:33:00	2020-06-09	Laura Russel	laura.russel@geemail.com	Santa Ana	California	3337554596569841296	f792002ab36ee2f881ac9e20c9a3258a	Diners Club / Carte Blanche	33.6768786390416324	-117.819494299815958
29809	2020-06-09 08:42:23	2020-06-09	Kendra Fritsch	kendra.fritsch@geemail.com	Tucson	Arizona	6011030231383366841	e547587029da563d2e673d5f789140ce	Mastercard	32.1464400837238884	-110.928512910263976
29810	2020-06-09 08:49:08	2020-06-09	Zion Becker-Windler	zion.becker.windler@woohoo.com	Vallejo	California	3337430361541065336	56bd036fb041603fb5bf190387346f97	American Express	38.0644704106353231	-122.26897980504296
29811	2020-06-09 09:01:39	2020-06-09	Roger Kuhn	roger.kuhn@warmmail.com	New York	New York	6011575341613917379	f3a97717fd1ddfe29889b615e6e761c1	VISA 16 digit	40.7600867616701876	-73.8909301963064848
29812	2020-06-09 09:03:56	2020-06-09	Teddie Langosh	teddie.langosh@warmmail.com	Chicago	Illinois	4761328974990	31eddb2c44650266b3e3532603210198	Maestro	41.7664973563816417	-87.5916824493121311
29813	2020-06-09 09:16:36	2020-06-09	Mrs. Reatha Paucek DVM	mrs.reatha.paucek.dvm@woohoo.com	Indianapolis	Indiana	869968020636903566	267dbd6cef8493e61bf1b1e09c464df1	VISA 13 digit	39.7217529634021176	-86.1505811951790008
29814	2020-06-09 09:23:23	2020-06-09	Jayne Cummerata-Bashirian	jayne.cummerata.bashirian@geemail.com	Downey	California	3751098249265267	c65c2da8b3b33603ac8067a0ef96fbd8	VISA 16 digit	33.8737090685188775	-118.057575180019811
29815	2020-06-09 09:50:29	2020-06-09	Brennan Haag	brennan.haag@geemail.com	Baltimore	Maryland	51737390941752326	64609a73f74468e20eb66cfac6cb7a92	Diners Club / Carte Blanche	39.3989789406768978	-76.6075054439268968
29816	2020-06-09 10:01:38	2020-06-09	Dorthey Jenkins PhD	dorthey.jenkins.phd@geemail.com	New York	New York	060414548260182	fd082b3eb9937cdba5358ba61cf170e8	JCB 15 digit	40.7085107048265655	-73.9340203093260442
29817	2020-06-09 10:02:48	2020-06-09	Pablo Fisher	pablo.fisher@geemail.com	Bakersfield	California	210095217922703646	acc8dce11c5cd09f9457058a420ace5e	VISA 16 digit	35.3506583292212326	-119.090629836618149
29818	2020-06-09 10:45:19	2020-06-09	Parthenia Dach	parthenia.dach@geemail.com	Corpus Christi	Texas	3786438233516060	5d00d3ac09576b388cc56e077067d097	Diners Club / Carte Blanche	27.7371175373375429	-97.114732239937041
29819	2020-06-09 10:45:48	2020-06-09	Mr. Frankie O'Kon	mr.frankie.o'kon@warmmail.com	San Bernardino	California	3036397485352946	43f5c48b3ff3ea47cd30c32cab5d9b41	Maestro	34.2172969924084782	-117.208640230378506
29820	2020-06-09 10:47:23	2020-06-09	Hildur Tremblay DVM	hildur.tremblay.dvm@woohoo.com	Lafayette	Louisiana	210050368087576294	71f3761d80a93f584fe59d29242ebf81	Maestro	30.1730849410384891	-91.9784559043906569
29821	2020-06-09 10:47:37	2020-06-09	Manie Tremblay	manie.tremblay@woohoo.com	Phoenix	Arizona	53381882916244957	09046f5a2cb8c2884d48ccc41ed1a588	Voyager	33.5365999193795048	-112.040344805868727
29822	2020-06-09 10:49:06	2020-06-09	Jaidyn Daugherty	jaidyn.daugherty@woohoo.com	Phoenix	Arizona	4688012073249645	fbd45bb1552781ed78c7461ba6e97fd6	VISA 13 digit	33.5086126243628613	-112.006103755247224
29823	2020-06-09 10:57:11	2020-06-09	Jules McKenzie DVM	jules.mckenzie.dvm@geemail.com	San Francisco	California	4072259953240871	494c8fa0c0b4f720e10f3d4e4ddcb7cd	VISA 16 digit	37.7635921320415235	-122.417843562290457
29824	2020-06-09 11:13:47	2020-06-09	Collins Yost	collins.yost@warmmail.com	Lexington	Kentucky	3004932161148218	602068825d8f6b14490939c6692b0a7b	VISA 16 digit	38.0998836576350044	-84.4604050941199063
29825	2020-06-09 11:16:23	2020-06-09	Laverne Fisher	laverne.fisher@geemail.com	Jacksonville	Florida	3112381719036470239	a00ae49839f43f53557ddfe90e601ff4	JCB 15 digit	30.4203981376305208	-81.7105105862099776
29826	2020-06-09 11:20:39	2020-06-09	Muriel Satterfield	muriel.satterfield@geemail.com	Tallahassee	Florida	54725899722566766	60831c0db480a9f6e02d43d4594c02fe	Discover	30.3744404568359272	-84.3319857207141865
29827	2020-06-09 11:21:31	2020-06-09	Dr. Saniya Lueilwitz MD	dr.saniya.lueilwitz.md@warmmail.com	Lakeland	Florida	501837608381382	4640121239767946ae490c47ffb30daa	JCB 15 digit	28.1551874248143257	-81.9630779149826623
29828	2020-06-09 11:23:02	2020-06-09	Teela Tremblay-Cummerata	teela.tremblay.cummerata@warmmail.com	Boston	Massachusetts	210040732622081560	68092b9fb2cbffd6d57c4d2104756603	JCB 16 digit	42.2443931996058666	-71.0959747562602189
29829	2020-06-09 11:26:56	2020-06-09	Jeffrey Effertz-Rippin	jeffrey.effertz.rippin@warmmail.com	San Francisco	California	54559364623648313	17db39cc8d656c2990f18d9ecbf32e2b	VISA 13 digit	37.7805808139748862	-122.439056688473613
29830	2020-06-09 11:28:34	2020-06-09	Tomika Stroman	tomika.stroman@geemail.com	San Francisco	California	4920937315249	7e3ea7c259e74f150ceec9711224f46a	VISA 16 digit	37.7882317226010969	-122.416398754067586
29831	2020-06-09 11:34:36	2020-06-09	Kraig Kuhlman-Harris	kraig.kuhlman.harris@warmmail.com	Portland	Oregon	3158805115296316824	8b5c6ee4e9639a1a683ff966244f59d6	Voyager	45.5761641170252076	-122.629255688516423
29832	2020-06-09 11:38:25	2020-06-09	Meyer Monahan	meyer.monahan@geemail.com	San Francisco	California	3044553031626132	347c9bc1604b3d4659a31b90d3dc66ad	American Express	37.7696738082786041	-122.38985977606356
29833	2020-06-09 11:38:27	2020-06-09	Golden Smitham	golden.smitham@woohoo.com	Madison	Wisconsin	4171294575211	addb2e4a2f156306d6e717a959ec7430	Diners Club / Carte Blanche	43.1864288413405433	-89.3384928611457383
29834	2020-06-09 11:40:44	2020-06-09	Vassie Stehr DVM	vassie.stehr.dvm@woohoo.com	Norwalk	California	54269703654521074	c91bd0e2892bd634c3df5485867c3b44	Discover	33.955309163604305	-117.990349281629548
29835	2020-06-09 12:01:44	2020-06-09	Liddie Hahn	liddie.hahn@geemail.com	New York	New York	3400897252249304	173be1016462a9532a60a49e16130bab	JCB 16 digit	40.6233723347298792	-73.996995054594052
29836	2020-06-09 12:12:24	2020-06-09	Dr. Chelsey Lowe DDS	dr.chelsey.lowe.dds@geemail.com	Houston	Texas	53157342932658286	df1470411ba9d645d991dfced99bc075	American Express	29.7706455392841249	-95.4434601096916992
29837	2020-06-09 12:12:25	2020-06-09	Ms. Jennifer Davis	ms.jennifer.davis@geemail.com	Irving	Texas	4059776516930877	84aff2af5c266255685efc677c8c91a0	American Express	32.8070810907471966	-96.9345617480389734
29838	2020-06-09 12:15:29	2020-06-09	Dr. Rocco Ledner	dr.rocco.ledner@woohoo.com	New York	New York	180064264260286799	8dc67e4a03476fefdc5be332fb5a1d7f	Voyager	40.6147120720930417	-73.9511206921551292
29839	2020-06-09 12:30:36	2020-06-09	Ceola Senger	ceola.senger@woohoo.com	San Antonio	Texas	4976182718096262	973e8557d3ff3858e16c325c72d32155	VISA 13 digit	29.3924127865187828	-98.5346486818812792
29840	2020-06-09 12:45:49	2020-06-09	Natalya Nikolaus	natalya.nikolaus@geemail.com	Indianapolis	Indiana	4859197461386	39ac112148a9b20fe6a116f250a35d21	VISA 13 digit	39.7682637673344459	-86.1914310821533149
29841	2020-06-09 12:46:07	2020-06-09	Kathern Hamill DDS	kathern.hamill.dds@warmmail.com	Rancho Cucamonga	California	3046050482881314	90a7e6b9df339c3cb80f4d9e45a1eba4	American Express	34.0709835400331755	-117.573165702960267
29842	2020-06-09 12:52:43	2020-06-09	Ammie Corkery	ammie.corkery@geemail.com	San Francisco	California	6011118144093748262	9a20df68273394301b92b6e23cf3bca3	JCB 15 digit	37.7857624246713399	-122.438965544130909
29843	2020-06-09 12:53:46	2020-06-09	Georgiana Bartoletti DVM	georgiana.bartoletti.dvm@geemail.com	Washington	District of Columbia	639045823903385	fc44dde10a48e6f06ec8f8e452319482	JCB 15 digit	38.9345823555983586	-77.058896423338723
29844	2020-06-09 13:00:24	2020-06-09	Shaquana Ferry	shaquana.ferry@geemail.com	Oakland	California	3709919272629611	da8cb8c581812ced0ad28a688f13d0fc	American Express	37.8034909852611207	-122.27026308228298
29845	2020-06-09 13:01:17	2020-06-09	Schley Jerde	schley.jerde@geemail.com	Kansas City	Kansas	52585786496957330	39c96444802adc2e960caaa8b1fe9978	JCB 16 digit	39.2014983450435111	-94.8343145151559241
29846	2020-06-09 13:02:43	2020-06-09	Mr. Linwood Cartwright III	mr.linwood.cartwright.iii@geemail.com	Chattanooga	Tennessee	869952340817599019	c897d526c835ef93d40a2b394025dc5b	Maestro	35.0710892879720788	-85.2248350439887474
29847	2020-06-09 13:04:19	2020-06-09	Wong Kreiger	wong.kreiger@geemail.com	Providence	Rhode Island	4829095716298	03ae8bfb6d8c7df446152afff20eb43c	Diners Club / Carte Blanche	41.7733681606449139	-71.4053248326212184
29848	2020-06-09 13:06:11	2020-06-09	Adah Sporer	adah.sporer@geemail.com	Memphis	Tennessee	6011191904214082929	f7630c7016d512aba9ae5c9cd57eee2c	American Express	35.101438517549262	-90.0310443029064658
29849	2020-06-09 13:18:55	2020-06-09	Mr. Aric Gibson II	mr.aric.gibson.ii@geemail.com	Fort Worth	Texas	53015904958693273	804acb4900a41aaa2eec2ae82d321834	VISA 16 digit	32.7896608934793647	-97.4233666613519205
29850	2020-06-09 13:29:52	2020-06-09	Teagan Champlin	teagan.champlin@warmmail.com	Lincoln	Nebraska	6011714996112481193	0e532dd128c18397decb5f0e8af22945	JCB 15 digit	40.7881769153308085	-96.6392425970800275
29851	2020-06-09 13:41:59	2020-06-09	Robt Leuschke	robt.leuschke@geemail.com	New York	New York	4298565993363707	5e9cddeb0d271dc13a785b9411b2ef0a	VISA 16 digit	40.6478926309142281	-73.9560364178277467
29852	2020-06-09 13:50:24	2020-06-09	Clarabelle Koelpin	clarabelle.koelpin@geemail.com	San Francisco	California	3088117313090851285	662fbc40eed3df4043dcb4d942c9e769	JCB 16 digit	37.7488947262802483	-122.441132277234544
29853	2020-06-09 13:51:40	2020-06-09	Agnes Mraz-Pfeffer	agnes.mraz.pfeffer@geemail.com	Los Angeles	California	561226303718287	ea8ff51e0877c930d6a5d87467bdc148	VISA 13 digit	33.9381542830128211	-118.31367752393632
29854	2020-06-09 14:02:48	2020-06-09	Darla Batz-Goldner	darla.batz.goldner@geemail.com	Charlotte	North Carolina	3112472260446122359	b58400a31165be3a427eca76cd64b00e	JCB 16 digit	35.2897197793491202	-80.8084395942688047
29855	2020-06-09 14:06:37	2020-06-09	Zaid Feeney DDS	zaid.feeney.dds@geemail.com	San Francisco	California	869955119998635587	94fcdedd0fa04f54bbb9f31fe0cc5265	Diners Club / Carte Blanche	37.7885196785990161	-122.450467490837212
29856	2020-06-09 14:14:43	2020-06-09	Devaughn Okuneva-Brown	devaughn.okuneva.brown@geemail.com	Minneapolis	Minnesota	4535360815344850	e3c27d19384202c173b9ceb63950fe94	VISA 16 digit	44.9297555684663337	-93.3656008062224743
29857	2020-06-09 14:19:38	2020-06-09	Dayana Pacocha	dayana.pacocha@geemail.com	San Francisco	California	3112721951599169861	b56612f77008795b6d7520df792b59f4	Diners Club / Carte Blanche	37.8197849114979121	-122.456187677807847
29858	2020-06-09 14:36:44	2020-06-09	Kitty Harris	kitty.harris@geemail.com	Springfield	Illinois	6011233761847770811	39c80753fab459ed474cf44eb1082dcf	Discover	39.7917112741306411	-89.7301794937815487
29859	2020-06-09 15:04:19	2020-06-09	Carie Rodriguez-Jast	carie.rodriguez.jast@warmmail.com	Irving	Texas	4691639018774363	a03388a01312736dfc524f4c6c987cb9	Mastercard	32.9548209291368721	-96.9817358827032194
29860	2020-06-09 15:24:18	2020-06-09	Ms. Frances Koelpin	ms.frances.koelpin@woohoo.com	Hampton	Virginia	869950875298866207	c2bb1263c1d18d942b934238379d663f	VISA 13 digit	37.0220028291009413	-76.3023912058308724
29861	2020-06-09 15:26:35	2020-06-09	Dave McCullough	dave.mccullough@woohoo.com	Baltimore	Maryland	3528618522546745313	f704c2e4b624ab37835b5fff477138c4	JCB 15 digit	39.3254900797735871	-76.5934653553664759
29862	2020-06-09 15:28:00	2020-06-09	Dr. Wylie Koss	dr.wylie.koss@geemail.com	Lincoln	Nebraska	869948154532698387	a3b47db204da541349ceb94b14580430	VISA 16 digit	40.7216797639634436	-96.5852396420828967
29863	2020-06-09 15:36:57	2020-06-09	Cassandra Wiza DVM	cassandra.wiza.dvm@geemail.com	Mesa	Arizona	3528982276430584902	19d81656838a61867150b38dd51e3e2c	American Express	33.3064065260492228	-111.619178824627397
29864	2020-06-09 15:47:45	2020-06-09	Darlene Dickinson	darlene.dickinson@woohoo.com	San Francisco	California	3528570712413826447	466477eab6b998984300a5c3047f6e02	VISA 16 digit	37.7646720464750842	-122.412940296239768
29865	2020-06-09 15:49:19	2020-06-09	Mr. Jacquez Hirthe	mr.jacquez.hirthe@geemail.com	Chandler	Arizona	3766349413690803	93537a86da011ea3c09acc59e8fee56a	Maestro	33.244167503630365	-111.851152077864484
29866	2020-06-09 15:51:10	2020-06-09	Jeanne Hilll	jeanne.hilll@geemail.com	Houston	Texas	4918045239122878	8641e44e5d4749472c977cd56e5c1f56	VISA 16 digit	29.7264590759839855	-95.4347727971166364
29867	2020-06-09 15:52:05	2020-06-09	Kennard Gleichner	kennard.gleichner@geemail.com	Wilmington	North Carolina	3112091165317745520	fbdbee2f712fde24ebfe4cb9b08c5bf8	Voyager	34.1605052629772601	-77.8158873528700354
29868	2020-06-09 16:07:43	2020-06-09	Trina Metz	trina.metz@geemail.com	Jersey City	New Jersey	3404031560486699	ace8ddca44b199f361413934a07693fd	Voyager	40.757184866809844	-74.092622422795003
29869	2020-06-09 16:08:38	2020-06-09	Yoshio Schneider	yoshio.schneider@geemail.com	Charleston	South Carolina	6011547292746841942	59e6bc187d5a22f86f4098c72a30e41f	JCB 16 digit	32.8455703889016064	-80.0174985801018863
29870	2020-06-09 16:14:40	2020-06-09	Dedric Wyman	dedric.wyman@geemail.com	San Francisco	California	3088328714738514141	fac89c8c98ef8b2cfc796d1b69d9c9ea	JCB 16 digit	37.7840949603606191	-122.417059758275172
29871	2020-06-09 16:18:11	2020-06-09	Carleton Considine	carleton.considine@woohoo.com	Fontana	California	3112019146115408874	dd26699d838b230c677eea555b998314	VISA 16 digit	34.1387257080674189	-117.504537994721531
29872	2020-06-09 16:19:28	2020-06-09	Crissy Hackett-Robel	crissy.hackett.robel@woohoo.com	El Paso	Texas	53593998311604274	35b78de8dcf7210a94469d013586d700	Maestro	31.8559408432632694	-106.355487011883412
29873	2020-06-09 16:32:55	2020-06-09	Verlene Willms	verlene.willms@geemail.com	Colorado Springs	Colorado	3797432898997183	b2687b8c8e27ea42799c5498fcb5bcdc	JCB 16 digit	38.9180837137673024	-104.710435739594331
29874	2020-06-09 16:45:33	2020-06-09	Tammy Herman	tammy.herman@geemail.com	Surprise	Arizona	502035425182223	e26dde6475b00a08591363a524b43e18	JCB 16 digit	33.5941153063200417	-112.547156763844924
29875	2020-06-09 16:55:40	2020-06-09	Kendell Purdy	kendell.purdy@geemail.com	Philadelphia	Pennsylvania	675935692343359	c3973b981d770ecdb4e507ed3163f95d	VISA 16 digit	40.0947174090385445	-75.1220771347537664
29876	2020-06-09 17:10:02	2020-06-09	Shaquita Jacobson-O'Hara	shaquita.jacobson.o'hara@geemail.com	Houston	Texas	4532539410797	7dd22acc481eeec0307cbbbb2db59043	Discover	29.7182520240157828	-95.3867519488573095
29877	2020-06-09 17:10:32	2020-06-09	Juliana Zemlak	juliana.zemlak@geemail.com	Oklahoma City	Oklahoma	3485715956292750	aada7e71e8833398eb8306e8a301467c	Discover	35.4198807092759793	-97.4934593255527346
29878	2020-06-09 17:21:53	2020-06-09	Broderick Hudson-Ritchie	broderick.hudson.ritchie@geemail.com	Colorado Springs	Colorado	51996338510155922	21a73cbd6ce0166162d566ea282083a3	Voyager	38.8451122240677478	-104.697987628138435
29879	2020-06-09 17:25:46	2020-06-09	Delma Brekke	delma.brekke@geemail.com	New York	New York	6011156992758466304	cb930547cdcfd10adbe6e31f19f0082e	Diners Club / Carte Blanche	40.7152721495125434	-73.9682184455346317
29880	2020-06-09 17:39:12	2020-06-09	Theda Davis-Shields	theda.davis.shields@geemail.com	Tucson	Arizona	589383196200188	d857ec6453cdfe1095145759f30fc51a	VISA 16 digit	32.1814932327758569	-110.880806056386234
29881	2020-06-09 17:50:14	2020-06-09	Dr. Leandro Green PhD	dr.leandro.green.phd@geemail.com	San Francisco	California	3112734724433955448	722078d01615c86e795ea7de114e12c7	Mastercard	37.767297490535249	-122.408820781208263
29882	2020-06-09 17:54:09	2020-06-09	Bobby Rau	bobby.rau@geemail.com	Berkeley	California	180032651151832435	0cc2db3bd65b49a60dc0ce41daea3f10	VISA 16 digit	37.8866103540797354	-122.303158147166172
29883	2020-06-09 17:56:56	2020-06-09	Mr. Ted Schmeler I	mr.ted.schmeler.i@geemail.com	Anaheim	California	52869318154528794	3d8431ef49b05eebb3b4550e201dd65a	Discover	33.9491648438218974	-117.787537994815409
29884	2020-06-09 18:00:22	2020-06-09	Wilford Walsh	wilford.walsh@geemail.com	Santa Rosa	California	3112951234830978197	7fb479e554d35b9bbd67c8eabf87f4f6	VISA 16 digit	38.350809706620133	-122.75921381635257
29885	2020-06-09 18:11:00	2020-06-09	Landan Dibbert IV	landan.dibbert.iv@woohoo.com	New York	New York	52076780648072508	7593d51430cb6ecbb75531a5e70e8c84	VISA 13 digit	40.7557750009223838	-74.0220196402527364
29886	2020-06-09 18:18:08	2020-06-09	Walt Gislason-Lynch	walt.gislason.lynch@geemail.com	Mesquite	Texas	4235139787304891	17851baab6d84456df5a8767002cf198	JCB 16 digit	32.7659632714275304	-96.5208528245996717
29887	2020-06-09 18:21:59	2020-06-09	Dr. Danial Hettinger PhD	dr.danial.hettinger.phd@geemail.com	San Francisco	California	3432996404512858	7e7f2447769c00c0dfbe96f56de3062f	Discover	37.7932381090969116	-122.433707482115835
29888	2020-06-09 18:37:24	2020-06-09	Dr. Simmie Rowe IV	dr.simmie.rowe.iv@geemail.com	Tyler	Texas	4041686443926412	b1ed94c642b80971cc4ae69f5a038016	Mastercard	32.2500860318124296	-95.2606019299585256
29889	2020-06-09 18:51:52	2020-06-09	Shan Ziemann	shan.ziemann@woohoo.com	Berkeley	California	4180427669833	f8c0ebd13cc7516da49e4a5314939bff	VISA 16 digit	37.8541563000185874	-122.261167106505482
29890	2020-06-09 19:02:36	2020-06-09	Luz Waelchi-Mohr	luz.waelchi.mohr@geemail.com	Clearwater	Florida	6011862212754396750	f0b8bf33dad866b84abc10dcf037fe68	Voyager	27.9987444672394545	-82.8101105513781306
29891	2020-06-09 19:03:56	2020-06-09	Dr. Adolfo Runte	dr.adolfo.runte@geemail.com	Sacramento	California	869916215468272170	b261d930f53ce06f5a3d78d3eb40284d	VISA 13 digit	38.4751925553925318	-121.485212207330761
29892	2020-06-09 19:06:32	2020-06-09	Lelah Murray	lelah.murray@warmmail.com	Jackson	Mississippi	4482674268270666	e58877e2a4b9114d9032ad07ccecd025	Voyager	32.3567186154138327	-90.2419106902994201
29893	2020-06-09 19:11:36	2020-06-09	Dr. Vito Pfannerstill I	dr.vito.pfannerstill.i@woohoo.com	Phoenix	Arizona	869990428578480984	f087c3083ae35118db979090ad926513	Diners Club / Carte Blanche	33.5871537476711026	-112.026860647967467
29894	2020-06-09 19:26:51	2020-06-09	Mr. Baron Runte PhD	mr.baron.runte.phd@warmmail.com	Santa Rosa	California	3096141690124674498	52b2cc05fd51273ee1ba8100fdf6a894	Diners Club / Carte Blanche	38.5004814490798921	-122.79005268409513
29895	2020-06-09 19:34:26	2020-06-09	Margarita Auer	margarita.auer@geemail.com	Hampton	Virginia	3158031196649623385	cef161b748ea968a504bbaae4aca1ac2	American Express	37.0414110477566751	-76.3604929400704862
29896	2020-06-09 19:34:32	2020-06-09	Talan Cronin	talan.cronin@woohoo.com	San Francisco	California	6011741151906674341	e7b6604457c9db214e4e9e3edff19ad0	JCB 16 digit	37.7921111320027663	-122.435242790835943
29897	2020-06-09 19:35:41	2020-06-09	Dr. Seth Barrows	dr.seth.barrows@warmmail.com	Ontario	California	52581006503761961	d7942eb3d285342a5de9725a34ce3d49	JCB 15 digit	33.9511833868600448	-117.699058847325674
29898	2020-06-09 19:37:47	2020-06-09	Miss Nereida Ryan DDS	miss.nereida.ryan.dds@geemail.com	Las Vegas	Nevada	869930365933442940	f6316d2c10abeebe5e92e17e787f2feb	VISA 16 digit	36.2691631442036453	-115.231313238174096
29899	2020-06-09 19:43:12	2020-06-09	Dijon Runolfsson	dijon.runolfsson@woohoo.com	New York	New York	210026820506530428	b63553770ab1eeaaa577432a8199af10	American Express	40.645453716743738	-73.882364518883449
29900	2020-06-09 19:57:35	2020-06-09	Dante Murphy	dante.murphy@geemail.com	Huntsville	Alabama	869924752075445054	b6ed556a7cbe2e2cc26125e09f767c9e	Voyager	34.741162584047764	-86.7676964482311206
29901	2020-06-09 20:05:05	2020-06-09	Dr. Len Boyer III	dr.len.boyer.iii@geemail.com	Stockton	California	869989402087354827	c58810613e0fb28fb3ddf0cc157a1248	Voyager	38.0654835117712622	-121.360985271967195
29902	2020-06-09 20:06:33	2020-06-09	Burrell Jacobs	burrell.jacobs@geemail.com	Oklahoma City	Oklahoma	3736925104184805	b301efe479e5602a35d56601db7a1a84	JCB 16 digit	35.5080440852236023	-97.5014883777022305
29903	2020-06-09 20:28:20	2020-06-09	Jethro Bednar	jethro.bednar@geemail.com	Los Angeles	California	4713533726670852	ffe4ba243f5132e89f98b56a262a9b9c	Maestro	33.9730978074815084	-118.397162056294448
29904	2020-06-09 20:31:21	2020-06-09	Dr. Vida Lakin	dr.vida.lakin@geemail.com	Kansas City	Kansas	639042562861320	e548984ad1207f77c241008bd04e37d5	VISA 16 digit	39.1157462320197382	-94.7761379095196759
29905	2020-06-09 20:42:17	2020-06-09	Dr. Charls Gibson	dr.charls.gibson@warmmail.com	San Francisco	California	869990821652378084	30a2f745e405ec3d2b49784340f956e4	JCB 16 digit	37.7547628264115644	-122.428629333486043
29906	2020-06-09 20:56:31	2020-06-09	Dr. Avis Durgan	dr.avis.durgan@woohoo.com	Albuquerque	New Mexico	3036973568620027	f611151dfac3e873ca483477695e346c	Mastercard	35.1907583459880229	-106.668377989863615
29907	2020-06-09 21:00:48	2020-06-09	Therman Sawayn-Romaguera	therman.sawayn.romaguera@geemail.com	Lubbock	Texas	3012893860500871	30766351b1dae4c32ef3a37fa58792a8	Maestro	33.5035449292551775	-101.899343577856953
29908	2020-06-09 21:01:01	2020-06-09	Miss Meagan Hirthe DVM	miss.meagan.hirthe.dvm@geemail.com	Sacramento	California	6011517855946087551	0d8ad2d36fea6cf682ae16cca31775fd	Discover	38.6133430305201557	-121.469690260595073
29909	2020-06-09 21:07:12	2020-06-09	Wayne Lemke	wayne.lemke@geemail.com	Louisville	Kentucky	3039492946310331	7fa5d11cd4740223fdc4ea1ad0f77b52	VISA 16 digit	38.1909238994956013	-85.5820334379166354
29910	2020-06-09 21:09:46	2020-06-09	Elick Fritsch	elick.fritsch@geemail.com	Philadelphia	Pennsylvania	676204505853657	f2ae954276c998290c8a0e6d747b8fba	JCB 16 digit	40.0858560121577199	-75.2322715015515797
29911	2020-06-09 21:22:19	2020-06-09	Monroe Johnston MD	monroe.johnston.md@geemail.com	High Point	North Carolina	4987462801459099	b62fdc4bb8fd2856042b68514d1ff31a	JCB 15 digit	36.0860769299417754	-79.9759022779501976
29912	2020-06-09 21:26:35	2020-06-09	Christal Lubowitz DDS	christal.lubowitz.dds@geemail.com	San Francisco	California	869934754744588627	325479865470c65c35daacf82a69744b	Maestro	37.7575402318619027	-122.440670952935875
29913	2020-06-09 21:27:39	2020-06-09	Lucile Ruecker MD	lucile.ruecker.md@geemail.com	Oakland	California	180001481837954834	df9c7abed1c6c119dc2dc5d8f0b208d6	Maestro	37.7886432469727538	-122.301535566229404
29914	2020-06-09 21:34:57	2020-06-09	Celine Lemke	celine.lemke@geemail.com	Sandy Springs	Georgia	3337068129020562704	511affc3cc17b57fffaa83a334c50cae	Voyager	34.0072578092161564	-84.365582209926842
29915	2020-06-09 21:52:00	2020-06-09	Reilly Brekke	reilly.brekke@geemail.com	Riverside	California	6011983078005485443	b722f91d67b1cca0659436dc83f99c74	VISA 13 digit	34.0074400732707218	-117.465370095983886
29916	2020-06-09 22:01:58	2020-06-09	Cody Corkery	cody.corkery@geemail.com	Portland	Oregon	869900667427977711	b3c639f3367c25cb43586a3f7f962612	JCB 16 digit	45.5214793670810778	-122.699704524734997
29917	2020-06-09 22:07:09	2020-06-09	Lacy Rath-Marks	lacy.rath.marks@geemail.com	Dallas	Texas	3528753105966764389	786dfd68866459600f5a0a2708ecf7d4	JCB 16 digit	32.8778703160390293	-96.7847554442901128
29918	2020-06-09 22:15:18	2020-06-09	Fritz Bahringer	fritz.bahringer@woohoo.com	Oakland	California	675906490419774	4efe1ff28666768889f2757dceca42b4	VISA 13 digit	37.7510399500520393	-122.286848423069685
29919	2020-06-09 22:45:36	2020-06-09	Tessie Erdman	tessie.erdman@geemail.com	Mesa	Arizona	4336893814188812	3003ba281e2a0a477b6a3d9960066416	Voyager	33.3298932176228604	-111.801384916843475
29920	2020-06-09 23:01:15	2020-06-09	Joey Cronin	joey.cronin@geemail.com	Austin	Texas	501870960664889	fbb53922625dd1edd5af1920f490d6ce	JCB 16 digit	30.2659527312625194	-97.6766499826923109
29921	2020-06-09 23:01:34	2020-06-09	Roby Wilkinson	roby.wilkinson@woohoo.com	Albuquerque	New Mexico	4995885915820923	f6f9e742b72bf7a3e21080c18318eb36	American Express	35.183753963573281	-106.683381264850127
29922	2020-06-09 23:14:50	2020-06-09	Samir Schultz-Jacobi	samir.schultz.jacobi@geemail.com	Jacksonville	Florida	3112491520176475104	bfcc7afdd85ac2a6b49d54dde13fd975	VISA 16 digit	30.3347275696747012	-81.6468505101822331
29923	2020-06-09 23:15:38	2020-06-09	Budd Leannon	budd.leannon@geemail.com	Tyler	Texas	210001811620237601	eaba746537c8be9b0ec825e60080a982	VISA 13 digit	32.3527220694862336	-95.2891133387681037
29924	2020-06-09 23:19:47	2020-06-09	Edyth Reynolds	edyth.reynolds@warmmail.com	Pasadena	Texas	4255690428238711	a234a02d440861dfad7765f04f768ee4	VISA 16 digit	29.6240445801861583	-95.1833233854215592
29925	2020-06-09 23:25:21	2020-06-09	Ms. Gigi Ziemann	ms.gigi.ziemann@woohoo.com	Nashville	Tennessee	6011686300044020142	e9fe70233bc0c8a879d3f60f0740a325	VISA 13 digit	36.1707851066377017	-86.7688024513330305
29926	2020-06-09 23:29:56	2020-06-09	Mr. Issac Hilpert V	mr.issac.hilpert.v@geemail.com	Berkeley	California	639028735176308	e37795dc5a82c43ab234a42abe134e6d	VISA 13 digit	37.8586304652025589	-122.261462731026199
29927	2020-06-09 23:31:30	2020-06-09	Dell Tremblay	dell.tremblay@woohoo.com	Independence	Missouri	3112197889223738104	391e244c34058670b9711499721f0a5d	Maestro	39.0418011151738469	-94.4181215397365321
29928	2020-06-09 23:31:34	2020-06-09	Dr. Myrl Bednar II	dr.myrl.bednar.ii@warmmail.com	Anaheim	California	869910909399673904	a0f41d88167005488dae0dfe25973f96	American Express	33.9099538835529231	-117.67016671139038
29929	2020-06-09 23:34:25	2020-06-09	Phyliss Gutmann	phyliss.gutmann@warmmail.com	Anaheim	California	3057163841354003	d1bf3eb928e8585b765843891ea03b2b	Diners Club / Carte Blanche	33.9138540577441461	-117.85712255092561
29930	2020-06-09 23:40:26	2020-06-09	Mrs. Dahlia Murazik	mrs.dahlia.murazik@geemail.com	Grand Rapids	Michigan	4879004249744400	8d8bebc4f834ee683d31cda6bb6bf2ad	Voyager	42.8896047557972366	-85.7482132347900432
29931	2020-06-09 23:45:30	2020-06-09	Saverio Corwin	saverio.corwin@geemail.com	Louisville	Kentucky	180092829221344188	e37fca19ff9d27287d2b28135825f355	Discover	38.2009695226229695	-85.6142332764413254
29932	2020-06-09 23:59:38	2020-06-09	Winford Ritchie	winford.ritchie@warmmail.com	Mesa	Arizona	3337900037919888472	e3bdf91bffbe583c0abd3bfd5dfbce1f	VISA 16 digit	33.4785610984690436	-111.802829483465842
29933	2020-06-10 00:03:54	2020-06-10	Averie Thiel	averie.thiel@geemail.com	Rochester	New York	4433106645871114	46da066c91af6d01ec15e1234847c961	Maestro	43.2231819992396993	-77.7098036248475381
29934	2020-06-10 00:04:27	2020-06-10	Kori Kozey	kori.kozey@geemail.com	Tempe	Arizona	3088964204766760591	29335c2101c49af460659a82242163ae	Diners Club / Carte Blanche	33.3406533653769586	-111.873122657605634
29935	2020-06-10 00:23:46	2020-06-10	Selina Reynolds	selina.reynolds@geemail.com	Pembroke Pines	Florida	869989481089704387	aed2fdf7b56c4f016de171e0db3323fa	JCB 16 digit	25.9803229518737666	-80.4317957987911996
29936	2020-06-10 00:24:01	2020-06-10	David Lueilwitz	david.lueilwitz@geemail.com	Lakeland	Florida	3404890965768039	4ed0cb82cbdf35800133f6aac79482bc	VISA 13 digit	28.0618933691009858	-81.9053410933703105
29937	2020-06-10 00:27:49	2020-06-10	Luigi Rempel	luigi.rempel@geemail.com	Chicago	Illinois	180052549393271385	43f401461cec4bd1df07217f9b86ced8	Mastercard	41.7615719606470321	-87.6343141428224754
29938	2020-06-10 00:38:58	2020-06-10	Osbaldo Kiehn	osbaldo.kiehn@geemail.com	Denver	Colorado	3112060673693042948	91c75b8b7100c5c552e84fbd4d20531f	VISA 16 digit	39.6832483739178628	-104.922342504632098
29939	2020-06-10 00:43:40	2020-06-10	Doss Murazik	doss.murazik@geemail.com	Joliet	Illinois	3528477375498122902	a358f54e4aebb382d27651f1ccb35b26	VISA 16 digit	41.5884155241165274	-88.1149491912789529
29981	2020-06-10 06:04:06	2020-06-10	Patty Mills-Purdy	patty.mills.purdy@geemail.com	Garland	Texas	53673735535448804	50a3890719a5a6eb1c7564f04463c547	VISA 16 digit	32.9137218878373474	-96.5625595963254568
29940	2020-06-10 00:43:48	2020-06-10	Lillianna Prosacco	lillianna.prosacco@geemail.com	Escondido	California	3007679410740702	e4592b6f4a08235b9d7f733863d428e0	VISA 16 digit	33.1054273258656266	-117.113435362257064
29941	2020-06-10 00:49:20	2020-06-10	Dr. Loretto Padberg MD	dr.loretto.padberg.md@warmmail.com	Philadelphia	Pennsylvania	676381810354167	18971ce01b7e185c7f0a81c65b7948ad	Diners Club / Carte Blanche	39.9227300628978767	-75.2058311418995373
29942	2020-06-10 00:50:58	2020-06-10	Albert Konopelski	albert.konopelski@geemail.com	Berkeley	California	3337793149913834319	35d5ed25814624a0a94575ba9467a2b5	Voyager	37.8883651209454868	-122.298698513718975
29943	2020-06-10 01:20:35	2020-06-10	Gerry Brown	gerry.brown@woohoo.com	Woodbridge	New Jersey	54115687401325291	d451b2f524efb33951571ce8ecd188ad	Mastercard	40.4669961618415996	-74.2351470313358988
29944	2020-06-10 01:56:15	2020-06-10	Esker Steuber-Cartwright	esker.steuber.cartwright@warmmail.com	Alexandria	Virginia	4238164251999	5357638a6dd00e3a906eaa70152464c3	VISA 13 digit	38.8088152559589545	-76.9989679489735579
29945	2020-06-10 01:57:25	2020-06-10	Gustave Schmitt	gustave.schmitt@geemail.com	Sunnyvale	California	53740703996445130	2f0022da4ec7c23988fbbd52e6a1638d	Diners Club / Carte Blanche	37.4253241558551792	-122.092842819794271
29946	2020-06-10 02:11:47	2020-06-10	Jettie Fritsch-Harber	jettie.fritsch.harber@woohoo.com	New York	New York	3158986558324640866	6248a5891b6d06ef450c7c77851ffaba	Diners Club / Carte Blanche	40.653746454114092	-73.9597665169171989
29947	2020-06-10 02:22:15	2020-06-10	Lilie Walsh DVM	lilie.walsh.dvm@geemail.com	New York	New York	4819603066830037	a4c842395d2eacc6729ec4f4b46393fd	VISA 16 digit	40.5975043411124474	-73.8679843911796752
29948	2020-06-10 02:25:07	2020-06-10	Dr. Ewald Wintheiser	dr.ewald.wintheiser@geemail.com	Long Beach	California	55823832490302099	8f141f3995b8e1f76ade3c6c2e1e93ae	JCB 16 digit	33.8246785520397069	-118.153367884100604
29949	2020-06-10 02:37:18	2020-06-10	Kathey Corwin	kathey.corwin@warmmail.com	Kansas City	Missouri	4546982515442796	ae8b3ee0ae7211b97193dc78175515ed	Maestro	39.1429556215949361	-94.6251792661603588
29950	2020-06-10 02:40:27	2020-06-10	Noretta Fadel	noretta.fadel@geemail.com	New York	New York	3112653420322651894	7ae72b896a437c2c24f284ada9bf8a65	Maestro	40.5946163363512582	-73.8660006370291029
29951	2020-06-10 02:41:23	2020-06-10	Genevra Ondricka MD	genevra.ondricka.md@geemail.com	Glendale	Arizona	3112713826182449245	ac69484a0ffeb08642553f8203efa3a5	VISA 16 digit	33.5777670174598697	-112.132140710183975
29952	2020-06-10 02:56:54	2020-06-10	Joy Kuhic	joy.kuhic@warmmail.com	Berkeley	California	3026775701821051	7be13fd31f17fef0e810edba5ed24a77	American Express	37.899132899479298	-122.266108505718876
29953	2020-06-10 03:05:39	2020-06-10	Orrie Turcotte-Dickens	orrie.turcotte.dickens@geemail.com	Gainesville	Florida	3464178506384343	0babc4bc58be3bf36965e3f9f6bd0384	Voyager	29.5874437228135747	-82.3274424956519226
29954	2020-06-10 03:08:02	2020-06-10	Triston Connelly	triston.connelly@woohoo.com	San Francisco	California	3466209584964751	9f79288db7580031fee46360e6d38dee	American Express	37.7579090392059982	-122.416644308579009
29955	2020-06-10 03:32:25	2020-06-10	Mr. Colter Wintheiser	mr.colter.wintheiser@geemail.com	Peoria	Arizona	6011869358669077424	8ee22f2b2d4eb69b2ef7c1585dd418d7	JCB 16 digit	33.7788126750651756	-112.21974178309739
29956	2020-06-10 03:32:46	2020-06-10	Alaya Weimann	alaya.weimann@geemail.com	Anaheim	California	869959217380130161	b66dc2020cad420b11b0cdf5669f49e6	JCB 16 digit	33.7997105609923594	-117.675419144166995
29957	2020-06-10 03:36:09	2020-06-10	Mrs. Merle Senger	mrs.merle.senger@geemail.com	New York	New York	6011725940629988628	70fc19e448174c62ae5d0d3a9a5c0b7d	Voyager	40.6104093549530916	-73.9209475458029601
29958	2020-06-10 04:00:28	2020-06-10	Valentina Koepp	valentina.koepp@woohoo.com	New York	New York	4912235572670	fef8741e5768f2512fa05e5c44f38556	Discover	40.6582799070738261	-73.8653227770596743
29959	2020-06-10 04:03:15	2020-06-10	Sondra Bogan-VonRueden	sondra.bogan.vonrueden@woohoo.com	Kansas City	Missouri	3016887416158644	2a8674c8d7f483b41af61628b6054674	Voyager	39.0276004032067974	-94.5390227907560785
29960	2020-06-10 04:03:49	2020-06-10	Alethea Cassin	alethea.cassin@geemail.com	San Francisco	California	180035100884713519	b1748e8dfdb7dc1ee9bd8f383cef872b	VISA 16 digit	37.7875813128948934	-122.453606118465302
29961	2020-06-10 04:12:22	2020-06-10	Yandel Jerde	yandel.jerde@warmmail.com	New York	New York	869973327789270997	4ba1880ab923d69d55503fd663364401	JCB 16 digit	40.6717383807748547	-73.9341649107530685
29962	2020-06-10 04:38:15	2020-06-10	Ms. Abbey Mante	ms.abbey.mante@woohoo.com	New York	New York	54382493391085466	b4463c6863235f956ecbc7f7a0cb0aa5	VISA 16 digit	40.7207263744194066	-73.9826604863058748
29963	2020-06-10 04:40:52	2020-06-10	Mrs. Adriane Mayer MD	mrs.adriane.mayer.md@geemail.com	Laredo	Texas	180048019824610475	2c751ba07e43c52764d1f5113903ae53	Voyager	27.5215237840726985	-99.5359293526045974
29964	2020-06-10 04:46:55	2020-06-10	Dyan Rippin	dyan.rippin@warmmail.com	New Orleans	Louisiana	4491282323717090	3f3446d32d7800616f555e49f0ecbb4e	JCB 15 digit	30.0630184758935108	-89.9058811342138853
29965	2020-06-10 04:55:24	2020-06-10	Latoria Will	latoria.will@geemail.com	Sioux Falls	South Dakota	6011992479453689552	43033baaaf1555b33c4473ea16c61fa6	JCB 16 digit	43.5700727840971211	-96.677494903298097
29966	2020-06-10 05:01:01	2020-06-10	Miss Deja Gleichner	miss.deja.gleichner@warmmail.com	Oklahoma City	Oklahoma	3703306527545378	f84c63c4299a1ff00a4cb228b2f0cc56	VISA 16 digit	35.5133267859838924	-97.5824892199028255
29967	2020-06-10 05:06:28	2020-06-10	Diane Davis	diane.davis@geemail.com	Denton	Texas	869937732368349440	a76f3b35694e1d5620ad57245feef7bc	JCB 16 digit	33.3161232808403653	-97.0429645538922472
29968	2020-06-10 05:07:54	2020-06-10	Nathaniel Grant	nathaniel.grant@geemail.com	New York	New York	676194607542472	0ad4348cfd990ed71ff1773d49e4a779	VISA 16 digit	40.6643026322349925	-73.8746216442797277
29969	2020-06-10 05:16:37	2020-06-10	Julian Littel	julian.littel@geemail.com	Aurora	Colorado	3030188223943427	7b595bda87ea1379e54a6a637f0effe5	VISA 16 digit	39.6942296787276874	-104.615329098154604
29970	2020-06-10 05:23:33	2020-06-10	Riley Beahan	riley.beahan@geemail.com	Boise	Idaho	4961038208308319	d3991e32f353ee8b8be8e6a62d98ec04	JCB 16 digit	43.5273699147298956	-116.292938228064031
29971	2020-06-10 05:30:47	2020-06-10	Shiloh Halvorson	shiloh.halvorson@warmmail.com	Miami	Florida	869967257708764820	5780f99e048e58746cdba0a3287dcae4	Diners Club / Carte Blanche	25.7038896078381711	-80.2909580628726616
29972	2020-06-10 05:52:17	2020-06-10	Jamil Satterfield-Connelly	jamil.satterfield.connelly@geemail.com	Syracuse	New York	639030277691421	17c8a4539e2beabb70e16daf06e89c0d	Discover	43.131001138811925	-76.0454376376479928
29973	2020-06-10 05:52:52	2020-06-10	Joi McDermott-Ritchie	joi.mcdermott.ritchie@woohoo.com	Los Angeles	California	3000071825682819	57bbe27ce2cb7c1c3d6447e81072bb81	Diners Club / Carte Blanche	34.1102994731027636	-118.431289300228656
29974	2020-06-10 05:57:20	2020-06-10	Edson Morar	edson.morar@geemail.com	San Francisco	California	180014924686193348	22237a9b33426045317b5e366530d81a	Mastercard	37.7921739318499945	-122.434882388532671
29975	2020-06-10 05:58:56	2020-06-10	Dori Stanton-Wisozk	dori.stanton.wisozk@woohoo.com	Yonkers	New York	3446825450506064	bc0324204b366f9795031c8583368fb0	JCB 16 digit	41.0186782182861123	-73.9322090902715985
29976	2020-06-10 05:59:18	2020-06-10	Caylee Kshlerin	caylee.kshlerin@geemail.com	Vancouver	Washington	53095700886588525	61100394f46fc95b18df0a55b77f5311	Voyager	45.5660374675482558	-122.511000738392397
29977	2020-06-10 05:59:39	2020-06-10	Archie Abshire	archie.abshire@geemail.com	Overland Park	Kansas	3059649713861727	c0f3be94b1e4d947c46b90483aecc901	American Express	38.8107448126990349	-94.7638967017684166
29978	2020-06-10 06:01:08	2020-06-10	Jaslene Kilback	jaslene.kilback@warmmail.com	Portland	Oregon	4841709655032992	1c90474f4b6b332f25cf7ca72113a8b6	JCB 16 digit	45.4657944656331097	-122.671403129165995
29979	2020-06-10 06:02:55	2020-06-10	Adron Wiegand	adron.wiegand@warmmail.com	Salt Lake City	Utah	4486294629577513	4e302cb4c9677108c0bfc8e58dec03b1	VISA 13 digit	40.8555263883113824	-112.02447142004408
29980	2020-06-10 06:03:55	2020-06-10	Alexander Gleichner	alexander.gleichner@woohoo.com	Chicago	Illinois	676365326728659	03724d773d858cd15026abb6a54564f9	JCB 16 digit	41.8513323419563505	-87.6516625916615055
29982	2020-06-10 06:06:56	2020-06-10	Mrs. Kathie Paucek	mrs.kathie.paucek@geemail.com	Berkeley	California	4274848363071961	568000dff69f036e61aeae12f14c6c7f	Maestro	37.8804444073615869	-122.263788976318068
29983	2020-06-10 06:16:21	2020-06-10	Coralie O'Hara-Goldner	coralie.o'hara.goldner@geemail.com	New York	New York	4391247547239156	f3e800288970ea938a528642d06cd625	VISA 16 digit	40.6206185017470247	-74.003604243871564
29984	2020-06-10 06:29:00	2020-06-10	Micky Rempel-Johnston	micky.rempel.johnston@geemail.com	Philadelphia	Pennsylvania	4378016722293255	4e92989192732f08f56a00bd360ecebc	Voyager	40.064670818108695	-75.21277273887695
29985	2020-06-10 06:36:30	2020-06-10	Izora Altenwerth	izora.altenwerth@woohoo.com	Cincinnati	Ohio	6011251197204465116	a2768fd24edb168137ba22abfaec5dbf	American Express	39.1607371676012903	-84.5996249343074851
29986	2020-06-10 06:48:12	2020-06-10	Mr. Cassius Vandervort	mr.cassius.vandervort@geemail.com	San Francisco	California	561207577255362	6af03dd587bfc4e12d7417b8721a8623	Discover	37.7876279134051529	-122.445328014355454
29987	2020-06-10 06:48:25	2020-06-10	Mr. Blanchard Pacocha	mr.blanchard.pacocha@geemail.com	Sandy Springs	Georgia	180081135522422191	0e5ea4aaef424244970d32bc8d728db9	VISA 16 digit	33.8602130143959101	-84.312673129475499
29988	2020-06-10 06:48:30	2020-06-10	Lillia Ruecker-Koch	lillia.ruecker.koch@woohoo.com	San Francisco	California	3005322977830333	be72c5743e4e423b20b911eb0c4fbc4d	VISA 13 digit	37.8148407038382643	-122.430059540921292
29989	2020-06-10 06:50:32	2020-06-10	Sanjuanita Schultz PhD	sanjuanita.schultz.phd@woohoo.com	Bakersfield	California	3464688055657451	c4a49557b8b6251134f59e8b03d2ec55	American Express	35.3141852510336776	-119.035367571170625
29990	2020-06-10 06:57:01	2020-06-10	Dabney Walker	dabney.walker@geemail.com	San Francisco	California	6011806568624247542	ba845d71c0c0ea87ec2c1d935e992296	Maestro	37.7820969183555135	-122.441757235690204
29991	2020-06-10 07:11:03	2020-06-10	Hjalmer Schneider	hjalmer.schneider@geemail.com	Daly City	California	6011935108466847234	78b998e3bebe324e6d5e2a5670861583	Voyager	37.6701603503353866	-122.428482066430149
29992	2020-06-10 07:14:10	2020-06-10	Oma Hudson	oma.hudson@warmmail.com	Grand Rapids	Michigan	4033681403349739	fa3b63467770d5843ad399ec4db7a035	VISA 16 digit	42.991873027876764	-85.721165124619759
29993	2020-06-10 07:21:33	2020-06-10	Paris Auer	paris.auer@geemail.com	Oakland	California	6011026319406681738	0fd32dcb9f923502d01554ed12bfed0b	American Express	37.8128115522829233	-122.271535934489791
29994	2020-06-10 07:27:25	2020-06-10	Mr. Maceo Frami	mr.maceo.frami@geemail.com	Allentown	Pennsylvania	869922899541361027	3fc29f313b1cd7d4aa1144708e33c6ac	VISA 16 digit	40.5587448216289275	-75.5777482941295915
29995	2020-06-10 07:30:18	2020-06-10	Matilda Rath	matilda.rath@geemail.com	Clarksville	Tennessee	6011390733694715701	9fef5a1547527e0c4f044dc6daab227f	JCB 15 digit	36.5345185196153821	-87.3781357677605115
29996	2020-06-10 07:42:59	2020-06-10	Mell Kerluke III	mell.kerluke.iii@geemail.com	Henderson	Nevada	4817304853526217	08c39b9ce47ed2ba75d7091d8b3ae497	Maestro	35.9251685573186776	-114.979237682015452
29997	2020-06-10 07:43:47	2020-06-10	Kadence Larson-King	kadence.larson.king@woohoo.com	Lubbock	Texas	180014716899053248	f0fe454790668ded3b6b37e20260c178	Mastercard	33.6173300331033786	-101.928271351327012
29998	2020-06-10 07:45:11	2020-06-10	Virgel Funk	virgel.funk@warmmail.com	Pomona	California	4140135876260	040553e645e4f71f3fdb9dd81ee0c178	Discover	34.0213939177375337	-117.764450239340221
29999	2020-06-10 07:50:28	2020-06-10	Mrs. Jazlene Bayer MD	mrs.jazlene.bayer.md@geemail.com	Oakland	California	4084546611716672	0affaffa4cd0727b11b0f8483d3f1cb7	VISA 16 digit	37.8051960290133806	-122.25919970751022
30000	2020-06-10 07:56:12	2020-06-10	Anika Marquardt	anika.marquardt@geemail.com	San Francisco	California	4686756012914501	ef37204af0bd85a985ee7a7b54a6a9d2	JCB 16 digit	37.7994291657053765	-122.483448424486994
30001	2020-06-10 08:10:47	2020-06-10	Ragna Quigley	ragna.quigley@woohoo.com	San Francisco	California	6011754602030939673	99c83807075efd67d2a573e8ebdbad30	Voyager	37.7467136992927337	-122.424979831308647
30002	2020-06-10 08:14:11	2020-06-10	Christ Kerluke	christ.kerluke@geemail.com	Lakewood	New Jersey	3528508033033018233	b383ddff9f9662d403287c542eaf382e	JCB 16 digit	39.9994787553608404	-74.1319177649259586
30003	2020-06-10 08:15:37	2020-06-10	Mr. Guido Crist V	mr.guido.crist.v@geemail.com	Scottsdale	Arizona	3337741798325960121	3bb66e2a8b6b8be61ef69cc248ba3427	JCB 16 digit	33.7361475141841893	-111.828696762813621
30004	2020-06-10 08:44:38	2020-06-10	Fallon Haag-Schumm	fallon.haag.schumm@geemail.com	Oakland	California	4734886263136801	72eef39633ea5f9247306067a39d5ad7	VISA 13 digit	37.7789021012075494	-122.265520345590701
30005	2020-06-10 08:54:00	2020-06-10	Lotta Denesik	lotta.denesik@geemail.com	Oakland	California	3088807846778891581	fa308084f065a124d3502aa410585dd4	JCB 16 digit	37.8485238381603111	-122.263056791747843
30006	2020-06-10 08:54:58	2020-06-10	Denise Barton PhD	denise.barton.phd@warmmail.com	Indianapolis	Indiana	3031280047751703	589e40067e9cf90739947a8cb46734ab	Voyager	39.7389811981476839	-86.1828782629422818
30007	2020-06-10 08:58:10	2020-06-10	Rex Abernathy	rex.abernathy@geemail.com	Los Angeles	California	4375286038563237	155251f7148b14c80af3f789031d5c82	VISA 13 digit	34.0988298560358558	-118.373761288960651
30008	2020-06-10 09:06:34	2020-06-10	Mrs. Meg Kulas DVM	mrs.meg.kulas.dvm@woohoo.com	Corona	California	4647239755935	adfb5b05ee72b22a091760903c52078d	Discover	33.7984473403897141	-117.494023486666379
30009	2020-06-10 09:07:33	2020-06-10	Ms. Moesha Hickle DVM	ms.moesha.hickle.dvm@geemail.com	Philadelphia	Pennsylvania	3783481665622884	fe6781e03dce3b4cdaef0513dcef3091	Diners Club / Carte Blanche	40.0389267704408596	-75.0786696808312115
30010	2020-06-10 09:24:15	2020-06-10	Fleet Klocko-Zulauf	fleet.klocko.zulauf@woohoo.com	Fresno	California	6011682362848114491	3298bdac2b49c3b1be428714a38f008a	JCB 16 digit	36.8380438079465193	-119.831198402039334
30011	2020-06-10 09:42:20	2020-06-10	Marchello Legros	marchello.legros@geemail.com	New York	New York	3096156858042983794	984c9506235eddad99412df773d304ab	American Express	40.7026175944823763	-74.0240363120928322
30012	2020-06-10 09:43:49	2020-06-10	Conard Crona V	conard.crona.v@woohoo.com	San Francisco	California	3456333165191287	6e69ff706bc326c004a0f14e451e6bbd	JCB 16 digit	37.7896956874397318	-122.440462020322954
30013	2020-06-10 09:48:25	2020-06-10	Elizah Howell	elizah.howell@geemail.com	Minneapolis	Minnesota	4069212101180189	3c15e09028c8b923d196d66484044593	Mastercard	45.0347074074756293	-93.2582484626483108
30014	2020-06-10 09:58:50	2020-06-10	Hennie Robel	hennie.robel@geemail.com	Boise	Idaho	3528840123455103063	88ed9d8a77c11323015e2bb0c9fabc93	VISA 16 digit	43.6153313520502337	-116.137741009398184
30015	2020-06-10 09:59:01	2020-06-10	Dr. Acey Wolff	dr.acey.wolff@geemail.com	Midland	Texas	3011361901666102	6954c9aa526868717395f5f9e5622489	Diners Club / Carte Blanche	31.9965047232996653	-102.171231818221514
30016	2020-06-10 10:09:19	2020-06-10	Mr. Brad Wilderman	mr.brad.wilderman@geemail.com	Pittsburgh	Pennsylvania	503868467702657	5e500698cf1ac50622ddca0fbdb28d97	Maestro	40.4556496053889347	-79.9587996113285442
30017	2020-06-10 10:17:19	2020-06-10	Jaren Dicki V	jaren.dicki.v@warmmail.com	Spokane	Washington	210071521302388508	0988ea630a69cdfe4aa3929e847e4667	JCB 16 digit	47.7516601207438853	-117.516643963697561
30018	2020-06-10 10:28:50	2020-06-10	Lavon Ebert	lavon.ebert@geemail.com	Los Angeles	California	55475154767053565	fe004840d68ef1b4688751aff0f3a017	VISA 13 digit	34.0624576815735551	-118.451852726749323
30019	2020-06-10 10:32:32	2020-06-10	Norene Miller PhD	norene.miller.phd@geemail.com	Aurora	Colorado	3337347994809463355	e02faaff4b60b8f3ab08e58c816ab5f8	Voyager	39.6760609612911992	-104.720126790518691
30020	2020-06-10 10:37:11	2020-06-10	Clarke Grady	clarke.grady@geemail.com	Las Vegas	Nevada	3158142498617297143	af3f2efd30a6a3a0dd96ca1cbe778785	JCB 16 digit	36.2653673234496239	-115.198272045443204
30021	2020-06-10 10:38:59	2020-06-10	Waylon Blick	waylon.blick@warmmail.com	Memphis	Tennessee	3774815698243401	bd9c37ff55b14f487561e827343bf1b8	Voyager	35.1371908710405236	-90.0009430632717908
30022	2020-06-10 10:48:15	2020-06-10	Ms. Brandie Muller MD	ms.brandie.muller.md@warmmail.com	Frisco	Texas	6011661493278870461	5339960e262dadd266f5700770649ab3	Discover	33.085367131186274	-96.8682187170464459
30023	2020-06-10 10:50:58	2020-06-10	Senora Torp-O'Connell	senora.torp.o'connell@geemail.com	Montgomery	Alabama	3337156675300533727	f8db0081d784518b9ace785e95629c3c	JCB 15 digit	32.3514068585753449	-86.2955720268808193
30024	2020-06-10 10:53:24	2020-06-10	Sean Brown	sean.brown@geemail.com	Ventura	California	503885124730343	534729379a28cb5efe4b988521006a20	JCB 16 digit	34.2984771053001296	-119.257329595657808
30025	2020-06-10 10:53:27	2020-06-10	Anastacio Graham	anastacio.graham@woohoo.com	New York	New York	4112385918696998	d32881e3cfa8389778420fe1e1dd3aa8	JCB 15 digit	40.6936194727886473	-73.8731749421812509
30026	2020-06-10 11:06:20	2020-06-10	Connor Gerhold	connor.gerhold@warmmail.com	Stamford	Connecticut	6011540605604165442	bda639a8357dc2ee06fa8151beda589a	VISA 16 digit	40.9835018011160201	-73.5410276753399614
30027	2020-06-10 11:12:16	2020-06-10	Bebe Gerlach	bebe.gerlach@geemail.com	New York	New York	869909467844052367	df3f422cdd956f66365dc0f743794730	American Express	40.7083587318882323	-73.9273570289731055
30028	2020-06-10 11:28:56	2020-06-10	Dr. Kristin Kozey DVM	dr.kristin.kozey.dvm@geemail.com	Buffalo	New York	3754188780412639	f87a7177e41dbe8f1ecc22adbb34644b	JCB 15 digit	42.9006602971069526	-78.7800114992938916
30029	2020-06-10 11:30:53	2020-06-10	Hazen Miller MD	hazen.miller.md@woohoo.com	Des Moines	Iowa	060466521125923	aeff38e2893d86466234a6b35efb1732	VISA 13 digit	41.6430767556395409	-93.642387038054693
30030	2020-06-10 11:33:04	2020-06-10	Ms. Lotta Lebsack	ms.lotta.lebsack@geemail.com	North Las Vegas	Nevada	4040085570447345	6d3925f2dd4762f2aa5130c4935801e2	VISA 13 digit	36.3328992509439601	-115.108631804281472
30031	2020-06-10 11:40:24	2020-06-10	Porsha Schmitt DDS	porsha.schmitt.dds@warmmail.com	Birmingham	Alabama	4061249810724	5a20f8e9f723634309acf22b1bf379eb	Voyager	33.5096801884729416	-86.86562987479941
30032	2020-06-10 11:44:16	2020-06-10	Charlsie Bartoletti-Hackett	charlsie.bartoletti.hackett@geemail.com	Clearwater	Florida	3112070791162411432	746834f3bc76c9d07faca1ce767b9728	Discover	27.9255707611456501	-82.7475975497424514
30033	2020-06-10 11:58:03	2020-06-10	Mr. Jory Rogahn DVM	mr.jory.rogahn.dvm@geemail.com	Kansas City	Kansas	3425175678689879	305171dfc6858d148ebb0625c7167e21	Diners Club / Carte Blanche	39.1414516391605147	-94.7123613956321009
30034	2020-06-10 12:04:44	2020-06-10	Marolyn Romaguera-McGlynn	marolyn.romaguera.mcglynn@geemail.com	Washington	District of Columbia	869917053051862167	1b5fcb5ed8b1b0c3a6892d959052d483	Diners Club / Carte Blanche	38.9850050485491764	-77.0325046311345005
30035	2020-06-10 12:12:24	2020-06-10	Mr. Ottis Bednar IV	mr.ottis.bednar.iv@woohoo.com	Anchorage	Alaska	4427384995291	19039b545e57e2074674a5a70646b6a8	VISA 16 digit	61.1104148001160468	-149.308750371274726
30036	2020-06-10 12:14:03	2020-06-10	Mr. Rhett Sanford	mr.rhett.sanford@geemail.com	Mesa	Arizona	4331518705817451	57df60d19d040ff0497408842b1a04fe	Discover	33.4632665717653879	-111.62087587722354
30037	2020-06-10 12:16:57	2020-06-10	Manuel Renner	manuel.renner@geemail.com	Glendale	Arizona	4601227423435892	6737babee3f0b2590b95ce0945981bff	Discover	33.5574171479552987	-112.172958464527127
30038	2020-06-10 12:23:45	2020-06-10	Alphonsine Mosciski	alphonsine.mosciski@geemail.com	Laredo	Texas	3088025116423535934	d4ad53609ec7a23136642c0d2ee6ab40	Maestro	27.5149378615148379	-99.5781088369440255
30039	2020-06-10 12:29:22	2020-06-10	Joycelyn Hagenes	joycelyn.hagenes@warmmail.com	Dallas	Texas	3023012083999773	cf2b7d574ae5d754310e88746d39aaa7	JCB 16 digit	32.7207623932316949	-96.769517647564399
30040	2020-06-10 12:31:08	2020-06-10	Dr. Azaria Haag	dr.azaria.haag@woohoo.com	Berkeley	California	3112226672084785124	bebbdf68292e4cda3b538b9ab06311b3	JCB 16 digit	37.9163780712110352	-122.31582297698246
30041	2020-06-10 12:35:23	2020-06-10	Arkie Mraz MD	arkie.mraz.md@woohoo.com	Chicago	Illinois	4762029926785566	abe72c8e3685bce0b5c694334f7b7543	Discover	41.8427548383664387	-87.6770445788774566
30042	2020-06-10 12:42:22	2020-06-10	Cassidy Stroman	cassidy.stroman@woohoo.com	San Jose	California	4303834840065748	862ef048a7f3a34b9b9c73e49add6ba3	Maestro	37.3590010589275536	-121.855205437237018
30043	2020-06-10 12:45:32	2020-06-10	Aline Thompson-Glover	aline.thompson.glover@geemail.com	San Diego	California	3424626802702922	711f6e3ae2e4afcbeaa7d39def39259c	Maestro	32.8473121220778665	-117.215220610508695
30044	2020-06-10 13:16:13	2020-06-10	Danae Cartwright	danae.cartwright@geemail.com	Houston	Texas	3757857826201555	2486279458f2bf88213ce5519f15de88	American Express	29.8213403029445558	-95.3296698315549662
30045	2020-06-10 13:22:45	2020-06-10	Derwin Mayer	derwin.mayer@geemail.com	San Francisco	California	3096893730516865914	ddbfadcbb6b748289f36032d59594ac8	Voyager	37.7983412885395964	-122.439776213810362
30046	2020-06-10 13:22:46	2020-06-10	Nora Koepp	nora.koepp@geemail.com	Tampa	Florida	3528426033242357108	e7ce69baae59e9387967c1f7d6c95167	JCB 16 digit	27.9646640672929578	-82.3872308897066858
30047	2020-06-10 14:07:17	2020-06-10	Miss Iris Collier DVM	miss.iris.collier.dvm@woohoo.com	Nashville	Tennessee	3708735918248322	b3803ab8a61448576cf1a3e61d7ebe68	Diners Club / Carte Blanche	36.1644811703480755	-86.8181671219784761
30048	2020-06-10 14:10:59	2020-06-10	Ms. Deborah Schaden	ms.deborah.schaden@warmmail.com	Peoria	Arizona	4137137371441631	94526f0e39ea4e1ea82870ed49ef6a4c	Discover	33.7652648266207436	-112.356024148587139
30049	2020-06-10 14:11:07	2020-06-10	Ms. Serena Little	ms.serena.little@warmmail.com	Topeka	Kansas	3049710989777268	477b58d37808876a2d1008f1a9868512	Discover	39.0616629359245309	-95.6182887531526404
30050	2020-06-10 14:14:08	2020-06-10	Mr. Laddie Ruecker	mr.laddie.ruecker@woohoo.com	Murrieta	California	210070413786555391	3a581357e9d621d29ce4b440d696615b	VISA 16 digit	33.5061705212671299	-117.251924081323295
30051	2020-06-10 14:15:22	2020-06-10	Mr. Eddie Friesen III	mr.eddie.friesen.iii@geemail.com	Oakland	California	210021586161632560	232506836da58dcf1685e789df0ce687	Diners Club / Carte Blanche	37.8192433729116075	-122.262175092401549
30052	2020-06-10 14:18:00	2020-06-10	Delcie Padberg	delcie.padberg@geemail.com	Anaheim	California	4077570863652	e217fb46884001a536e38b73aa784f3b	JCB 16 digit	33.9160611890088788	-117.678859962124747
30053	2020-06-10 14:24:54	2020-06-10	Miss Carma Batz MD	miss.carma.batz.md@warmmail.com	Philadelphia	Pennsylvania	3054630524392172	1fdc13ba5822f96f176e951df25a1308	VISA 16 digit	40.020776421805472	-75.1487209502041367
30054	2020-06-10 14:41:00	2020-06-10	Harmony Ernser	harmony.ernser@geemail.com	Irving	Texas	4235971355237	902887411dffafd19172923596608c29	VISA 16 digit	32.7826439702369257	-96.9705826159380422
30055	2020-06-10 14:51:08	2020-06-10	Odie Funk	odie.funk@geemail.com	Clinton	Michigan	3462974465576727	1f45d03a91041dfe46a47548c6577550	JCB 16 digit	42.5993492391027502	-82.8923071491606578
30056	2020-06-10 14:58:20	2020-06-10	Sydni Hansen	sydni.hansen@geemail.com	Laredo	Texas	51025281043336004	789fe9b26574022f68f5aa4cf8a8007a	Maestro	27.5769479729417739	-99.5094528285793984
30057	2020-06-10 15:49:22	2020-06-10	Rocco Haley	rocco.haley@woohoo.com	Boston	Massachusetts	4464371178483016	7cf674cbdb7be81e1fcfa6bbd59ce4df	Maestro	42.4036646607965224	-71.0906885853920159
30058	2020-06-10 16:05:07	2020-06-10	Phylicia Leannon	phylicia.leannon@geemail.com	San Antonio	Texas	3528108072080387640	bdc8c6971de8de95dc8868b75cca134c	Diners Club / Carte Blanche	29.5363016905333851	-98.5143815507482685
30059	2020-06-10 16:10:55	2020-06-10	Idella Halvorson	idella.halvorson@woohoo.com	Hartford	Connecticut	4010186684469	14915779734385c7fa9f6c9217f8dc9f	Mastercard	41.7758615212529918	-72.6976905256867383
30060	2020-06-10 16:13:25	2020-06-10	Leonce Reinger IV	leonce.reinger.iv@geemail.com	Tucson	Arizona	4780792850272020	1ea91c4d12faca51945f189ff9cb1736	Maestro	32.1679223250173081	-110.814940200023727
30061	2020-06-10 16:14:17	2020-06-10	Ivan Greenfelder	ivan.greenfelder@woohoo.com	Amarillo	Texas	6011081839073850680	30ee2c78cc8f9a0f4fefe40075140aec	Voyager	35.2652593028429919	-101.911348822000249
30062	2020-06-10 16:16:08	2020-06-10	Tolbert Hartmann	tolbert.hartmann@geemail.com	Phoenix	Arizona	3088869750020380580	d0771a1713ec630ebd8cc30dd855f677	Diners Club / Carte Blanche	33.5570646485246726	-112.148209356509525
30063	2020-06-10 16:39:30	2020-06-10	Murdock Pfannerstill	murdock.pfannerstill@geemail.com	Midland	Texas	3033249841547532	7fdd97a572db359f4317189ab953819f	JCB 16 digit	32.1011256930608297	-102.121943922037261
30064	2020-06-10 16:55:19	2020-06-10	Humberto Luettgen	humberto.luettgen@woohoo.com	New York	New York	52579220293706417	812e4875ca40a61f2cae5d7d18b14c3f	JCB 16 digit	40.7444680923353886	-74.0033752767264872
30065	2020-06-10 16:59:28	2020-06-10	Mrs. Mckenzie Zboncak DVM	mrs.mckenzie.zboncak.dvm@geemail.com	Miami	Florida	4474309240202640	0e2def9ad772e2171c939361d5b0ffba	VISA 13 digit	25.7257562421400117	-80.2761026225857535
30066	2020-06-10 17:04:07	2020-06-10	Preston Kreiger II	preston.kreiger.ii@geemail.com	Los Angeles	California	3088212875515193612	538e4c363e529bce9390842f8dbb2009	VISA 16 digit	33.9305256140749876	-118.336555126820869
30067	2020-06-10 17:07:11	2020-06-10	Rochelle Mayert	rochelle.mayert@geemail.com	Murfreesboro	Tennessee	869908065069775018	9bdf1060c2ccfe69a0fdf5a157a02cea	JCB 16 digit	35.8699472014445817	-86.3232289595846112
30068	2020-06-10 17:12:49	2020-06-10	Wess Murazik V	wess.murazik.v@warmmail.com	Aurora	Colorado	060447512762916	2527c54a79fe6c81664375b8268232e1	JCB 16 digit	39.7637642653770769	-104.78295309526176
30069	2020-06-10 17:15:01	2020-06-10	Tre O'Reilly MD	tre.o'reilly.md@geemail.com	Westminster	Colorado	3528969357448829773	8dc8bf4393ea070a1a373a6105e65020	Voyager	39.9466181574694801	-104.984966809829331
30070	2020-06-10 17:15:55	2020-06-10	Darius Farrell	darius.farrell@geemail.com	Jacksonville	Florida	3337386749545019453	c89399ce8c633a6127a934b362060168	VISA 16 digit	30.2868351859558373	-81.588069921972604
30071	2020-06-10 17:19:47	2020-06-10	Normand Sanford	normand.sanford@geemail.com	Knoxville	Tennessee	4154474339486426	fb711c99c457f9becd78922e0f354d19	Diners Club / Carte Blanche	35.8965058520033935	-84.0120946658991272
30072	2020-06-10 17:24:30	2020-06-10	Astrid Bailey	astrid.bailey@woohoo.com	Augusta	Georgia	3112297140989674136	7b83fac0df22cec9ff5be25aa16f58c8	American Express	33.3824679168146048	-82.0695472615599755
30073	2020-06-10 17:24:41	2020-06-10	Maia Kuhlman	maia.kuhlman@geemail.com	New York	New York	3013742442023374	b28fdc445a5d546be65b36fda3b4e974	Diners Club / Carte Blanche	40.6386737548969705	-73.9675787620607679
30074	2020-06-10 17:32:30	2020-06-10	Jammie Howe-Okuneva	jammie.howe.okuneva@warmmail.com	Aurora	Illinois	3037861591884745	08a337e37fa96af903941181fc2c8bf5	American Express	41.8464088959842897	-88.2309216570969568
30075	2020-06-10 17:41:57	2020-06-10	Braydon Hintz DDS	braydon.hintz.dds@woohoo.com	New York	New York	675914773651980	ea7c18d77ff41af293473332a924a1f9	Diners Club / Carte Blanche	40.5993278214465789	-73.8902149313956471
30076	2020-06-10 17:47:58	2020-06-10	Earlie Erdman DDS	earlie.erdman.dds@geemail.com	San Francisco	California	4459189064080	33d26f7f9e473af0906c7637d6dae98d	Voyager	37.7671694966320217	-122.463772853921867
30077	2020-06-10 18:00:24	2020-06-10	Jim Mann-Wunsch	jim.mann.wunsch@geemail.com	Houston	Texas	3480354695447932	f0132b1215e626a6696132346228136f	VISA 16 digit	29.8016106388144202	-95.3021315643113098
30078	2020-06-10 18:08:25	2020-06-10	Scottie Eichmann-Hansen	scottie.eichmann.hansen@geemail.com	Baltimore	Maryland	3112549730659873814	4347ca9006846424e378d69ee467c98f	Maestro	39.2156412731390418	-76.6686705159973343
30079	2020-06-10 18:12:36	2020-06-10	Shirlee Reilly	shirlee.reilly@geemail.com	Washington	District of Columbia	52180816941004260	2afab31d3a463a2cf6038fcae65b3996	JCB 16 digit	38.8245052404500512	-76.980999601932993
30080	2020-06-10 18:13:08	2020-06-10	Mrs. Gaylene Pollich	mrs.gaylene.pollich@warmmail.com	Little Rock	Arkansas	4953730029816	d68d8cca62fda95ebf96ad4f5dc3fa62	VISA 16 digit	34.7656026893571024	-92.2591777338519705
30081	2020-06-10 18:23:56	2020-06-10	Marylyn Toy	marylyn.toy@geemail.com	Killeen	Texas	869990354640925816	603adf047d8c927d7803c7adb3398b0e	JCB 16 digit	31.0111834150038668	-97.6902890736404856
30082	2020-06-10 18:33:44	2020-06-10	Desirae Will	desirae.will@woohoo.com	Berkeley	California	6011613845579097996	074d5675b37613029763e88a8aed0acb	JCB 16 digit	37.8644536354942858	-122.251946144645629
30083	2020-06-10 18:44:48	2020-06-10	Harmony Gislason	harmony.gislason@geemail.com	San Francisco	California	3003756260467976	3ad87e1347e1903aceafc0f66530a545	American Express	37.7437839350146831	-122.452362120533337
30084	2020-06-10 18:56:31	2020-06-10	Demarco Flatley	demarco.flatley@warmmail.com	Chicago	Illinois	3088889606829275734	28614a113880a891750835ae80c0e7d3	JCB 15 digit	41.8942131616476914	-87.6249306165642992
30085	2020-06-10 18:59:19	2020-06-10	Lonnie Orn MD	lonnie.orn.md@geemail.com	Los Angeles	California	3057889426653639	7dc8e70b94fd13f0a303f4317c561d1f	JCB 15 digit	34.0304682284459474	-118.465432332501933
30086	2020-06-10 19:06:18	2020-06-10	Miss Jacki Jerde	miss.jacki.jerde@warmmail.com	San Francisco	California	6011984719479455987	e90c6853b5efcd3dd0d27e74f1468484	American Express	37.7692445472849627	-122.450666981177733
30087	2020-06-10 19:08:35	2020-06-10	Laverna Kuhn	laverna.kuhn@geemail.com	Indianapolis	Indiana	3112305909852610314	e0a50b40129b68373c37e9a0cfc884c6	Voyager	39.8743078678388159	-86.2397695916906031
30088	2020-06-10 19:10:14	2020-06-10	Mrs. Francesca Schoen MD	mrs.francesca.schoen.md@geemail.com	Glendale	Arizona	6011359745909377720	c862614473f06e99026834e442021103	American Express	33.4372021170560245	-112.181185908594728
30089	2020-06-10 19:10:54	2020-06-10	Dock Davis	dock.davis@geemail.com	Jacksonville	Florida	210013031387850266	c37d66bbdaa332045762af079fe08240	American Express	30.2927522569946959	-81.6840199502263289
30090	2020-06-10 19:14:19	2020-06-10	Andra Hane	andra.hane@geemail.com	Ventura	California	3337356900697670447	86b7ef95df4d28e58ee94ff2a2d337dd	JCB 16 digit	34.1783428296606999	-119.325071568424619
30091	2020-06-10 19:14:52	2020-06-10	Mrs. Haylee Zboncak	mrs.haylee.zboncak@warmmail.com	Los Angeles	California	51255296503134682	7ebab772f0f6a63a5da06f27cc39db1c	Discover	33.9303209786169191	-118.484507480262963
30092	2020-06-10 19:15:55	2020-06-10	Adele Sanford	adele.sanford@geemail.com	New York	New York	869946269208693850	0f157df93178aed5d216eb14bb852bd4	VISA 13 digit	40.7226034135781205	-74.0230846669886233
30093	2020-06-10 19:20:54	2020-06-10	Dr. Cecil Walsh	dr.cecil.walsh@warmmail.com	San Francisco	California	3057183948251746	a3d334a6088ce311cd582772a20a1692	Discover	37.7741845468024593	-122.464193201182923
30094	2020-06-10 19:32:35	2020-06-10	Alanzo Harvey	alanzo.harvey@woohoo.com	Topeka	Kansas	53174794612442697	63d27b459ec68cd677b04b8a597b7886	JCB 16 digit	39.0963318970453031	-95.7058913924440731
30095	2020-06-10 19:36:47	2020-06-10	Vernelle Boyer	vernelle.boyer@geemail.com	Scottsdale	Arizona	3012661825159004	775a5459f8e1aee58bca6ce24e944626	JCB 16 digit	33.7032432490151379	-111.817711292948943
30096	2020-06-10 19:40:04	2020-06-10	Eliza Boyle PhD	eliza.boyle.phd@warmmail.com	Hollywood	Florida	060435676036649	61a96cf70a0b5c3fdea2256379a82ec0	JCB 16 digit	26.0912516665123384	-80.190299271541079
30097	2020-06-10 19:57:22	2020-06-10	Myah Wehner	myah.wehner@geemail.com	Santa Clarita	California	3088575567954300136	39304ee6042aa656f06d1102daacb594	Discover	34.4810235074460465	-118.55517276642918
30098	2020-06-10 19:58:50	2020-06-10	Lollie Jakubowski	lollie.jakubowski@geemail.com	Port St. Lucie	Florida	3158196741052298760	fa5a03875fea9a16fcc47af411e500c9	JCB 16 digit	27.2406141649134454	-80.3603216575544366
30099	2020-06-10 20:01:24	2020-06-10	Dr. Avery Abernathy	dr.avery.abernathy@geemail.com	San Francisco	California	3158135673696583683	a05770d65b374032e3477067020e96f3	Mastercard	37.813907041239446	-122.440312604571176
30100	2020-06-10 20:03:06	2020-06-10	Koen Kris	koen.kris@geemail.com	San Francisco	California	51705551283928356	b30b5499805301cf896c4c1a8462e458	JCB 16 digit	37.7941228719025375	-122.399791459803382
30101	2020-06-10 20:06:57	2020-06-10	Jaylin Spinka	jaylin.spinka@geemail.com	New York	New York	3712738351795753	e83483a13483b8418d3a19494806bb3f	Maestro	40.6295652985330662	-73.9574338820192878
30102	2020-06-10 20:31:48	2020-06-10	Miss Zettie Prosacco DDS	miss.zettie.prosacco.dds@geemail.com	New York	New York	3337442034496673679	40e25e41767a0ff37dbeed04ddffae12	Maestro	40.7195566109605096	-73.9112013757590205
30103	2020-06-10 20:32:05	2020-06-10	Chad Anderson-Labadie	chad.anderson.labadie@geemail.com	Pearland	Texas	4885718172438639	3220012a244977e3665a4e55fca23e24	American Express	29.5974974105406581	-95.3728018219437388
30104	2020-06-10 20:35:31	2020-06-10	Jasiah Schaden Sr.	jasiah.schaden.sr.@warmmail.com	San Antonio	Texas	180043571714940110	6042055c56026609999b525540a18a94	JCB 16 digit	29.5618699213560667	-98.5065302965067247
30105	2020-06-10 20:35:39	2020-06-10	Marylou Altenwerth	marylou.altenwerth@geemail.com	San Francisco	California	676336043072309	095eded245b089f7f8da0178c936f674	VISA 16 digit	37.7552148338148257	-122.43057148090719
30106	2020-06-10 20:44:14	2020-06-10	Muriel Nader	muriel.nader@geemail.com	Cambridge	Massachusetts	4264181969195626	861af46ad57e185372d9ee19c2065b5d	Maestro	42.3652472115810923	-71.200535335679362
30107	2020-06-10 20:54:15	2020-06-10	Rollin Willms	rollin.willms@warmmail.com	Philadelphia	Pennsylvania	4117459857555070	348f57c78b29695744db7a58c1106b48	JCB 16 digit	40.0661443138919751	-75.1270400075607085
30108	2020-06-10 21:13:28	2020-06-10	Sebrina Schuppe	sebrina.schuppe@geemail.com	Oakland	California	3528078171334708456	e415ebb7aa3375e349c2dc914158ef98	JCB 16 digit	37.8302589660005637	-122.22831387806788
30109	2020-06-10 21:27:16	2020-06-10	Shirlie Kshlerin	shirlie.kshlerin@geemail.com	Irvine	California	3158042673043917297	fc60dc233df4ad9997a416358041f285	Discover	33.7605477941703072	-117.828787350609147
30110	2020-06-10 22:03:54	2020-06-10	Ruffus Feest-Kunde	ruffus.feest.kunde@geemail.com	Syracuse	New York	51147160001120506	06ec3f7689750cdb72e5a0c40ca672db	Maestro	42.9983880757205128	-76.0447514680925849
30111	2020-06-10 22:12:17	2020-06-10	Concepcion Erdman	concepcion.erdman@geemail.com	New York	New York	6011127203241136058	67c18fab5d3ff4d8e2f9b31fdca64743	Maestro	40.5875160787012419	-73.8704416338715646
30112	2020-06-10 22:17:59	2020-06-10	Estell Stanton	estell.stanton@warmmail.com	Sioux Falls	South Dakota	4535042230066793	4b50dcc562e4999312ee8c723f1a6707	American Express	43.5501047606199947	-96.7894003420770161
30113	2020-06-10 22:18:12	2020-06-10	Mr. Knox McLaughlin DDS	mr.knox.mclaughlin.dds@geemail.com	New York	New York	3744607578071557	77d77f7b08d48f75d1039aacfa9c9ba7	VISA 13 digit	40.7037585266158004	-73.8525409323990374
30114	2020-06-10 22:25:45	2020-06-10	Luverne Stamm	luverne.stamm@warmmail.com	San Jose	California	3096296322713377381	f960167bb1e71bb89426a32c4b77c6cd	JCB 16 digit	37.3518521358080235	-121.832647290754693
30115	2020-06-10 22:36:29	2020-06-10	Ms. Shania King DDS	ms.shania.king.dds@geemail.com	Reno	Nevada	4551407748763695	e757af65c41a73889d77ce86fa262ed9	Discover	39.5872525214761524	-119.942478016361221
30116	2020-06-10 22:39:47	2020-06-10	Tristan Batz-Waters	tristan.batz.waters@geemail.com	Boston	Massachusetts	4015235425701229	ccf6df2e996e028d329e6104cd55b360	Mastercard	42.3089093892071375	-71.0304438270580079
30117	2020-06-10 23:04:43	2020-06-10	Ota Metz	ota.metz@geemail.com	Amarillo	Texas	630471797650117	a88802809e2b0987629c966c536910d1	JCB 16 digit	35.2698009782634685	-101.855118232345959
30118	2020-06-10 23:27:40	2020-06-10	Verena Wiegand	verena.wiegand@warmmail.com	North Charleston	South Carolina	3337029424351127047	a13ee79914e5c3be41c46b02f8590d49	VISA 16 digit	32.9925449198737724	-79.9818267057742958
30119	2020-06-10 23:43:40	2020-06-10	Ishmael Lindgren	ishmael.lindgren@geemail.com	Columbus	Ohio	869907464921171535	2e76b19db595177d164e182fa7feb7ee	Mastercard	39.9317481014922251	-82.9502446466360368
30120	2020-06-10 23:56:57	2020-06-10	Mr. Williams Ward	mr.williams.ward@geemail.com	Chattanooga	Tennessee	4774399786237974	6f61d4259bf68efa910f5fe17033e6b5	JCB 16 digit	35.0242726000342515	-85.2551260548472385
30121	2020-06-11 00:00:43	2020-06-11	Dr. Vinson Lubowitz DDS	dr.vinson.lubowitz.dds@geemail.com	Bridgeport	Connecticut	180090078532610778	11ed5e13980809413e80596f00c889fa	VISA 13 digit	41.23743867889754	-73.0969750384233947
30122	2020-06-11 00:01:58	2020-06-11	Cas Berge	cas.berge@warmmail.com	College Station	Texas	51953006867401451	185ee8832104bbc1d628b1ccec1bf08e	Voyager	30.6693122146230195	-96.3534473534520828
30123	2020-06-11 00:04:58	2020-06-11	Lea Gerhold	lea.gerhold@geemail.com	San Francisco	California	3481705362178416	f5583c82a210ef9b02408600cbc057b3	JCB 16 digit	37.7654841731564588	-122.416972003244325
30124	2020-06-11 00:17:44	2020-06-11	Shyheim Hamill-Lakin	shyheim.hamill.lakin@geemail.com	Sparks	Nevada	3449734478267179	1c18cf0416e14a76562511f5c90017e9	JCB 15 digit	39.5530445597838636	-119.662430437826004
30125	2020-06-11 00:28:21	2020-06-11	Lesley Walker-McClure	lesley.walker.mcclure@woohoo.com	Dallas	Texas	501890449495507	db3c69030ff9cb42ffd544d52e7e746a	Voyager	32.7375819276824629	-96.7844161076899496
30126	2020-06-11 00:38:21	2020-06-11	Madisen Prosacco PhD	madisen.prosacco.phd@geemail.com	Seattle	Washington	3528601361176205267	272fba8c33e95c4ca1a5c8fed7153b22	VISA 16 digit	47.5549844045117496	-122.335381908334412
30127	2020-06-11 00:39:49	2020-06-11	Loran Carter-Adams	loran.carter.adams@woohoo.com	Jacksonville	Florida	52520588110732679	a69607590f7bce0877ff9644c0cc8364	Discover	30.369280109233781	-81.7273141449395695
30128	2020-06-11 00:40:23	2020-06-11	Vaughn Rath	vaughn.rath@geemail.com	Denver	Colorado	639090976536897	0fa1c4214e0f621f88d22b7739973d1d	Discover	39.8315775721386061	-104.913092929428814
30129	2020-06-11 00:41:56	2020-06-11	Dr. Whitney Kautzer	dr.whitney.kautzer@geemail.com	San Diego	California	4019695586552	e5f5172e634dc21297fc14ca907ddd6e	JCB 16 digit	32.8818431363508097	-117.213302950318905
30130	2020-06-11 00:51:01	2020-06-11	Jep Ward-Nitzsche	jep.ward.nitzsche@geemail.com	San Francisco	California	51856686354049984	6d48945c25895c3912ea66ce31585a3c	Discover	37.7649019917084132	-122.426435197506237
30131	2020-06-11 00:51:42	2020-06-11	Hamilton Roberts	hamilton.roberts@geemail.com	Austin	Texas	4191523347730780	84466a423346998681d6c0ad88933432	Voyager	30.3821206439413132	-97.6852693284634483
30132	2020-06-11 00:56:01	2020-06-11	Dr. Parker Abernathy DDS	dr.parker.abernathy.dds@geemail.com	Las Vegas	Nevada	676105992182104	8716f6973086258b64967063c54ba0a7	VISA 16 digit	36.2491031772092001	-115.286546435647082
30133	2020-06-11 01:06:52	2020-06-11	Ezzard Lebsack	ezzard.lebsack@geemail.com	San Diego	California	4162384362380281	ce22194c7fee8a8b2a2e2ebbfb7529e0	JCB 16 digit	32.8907427033476552	-117.202556823883214
30134	2020-06-11 01:11:18	2020-06-11	Rico Altenwerth	rico.altenwerth@geemail.com	Sterling Heights	Michigan	3096990449930376588	5482c83612230309e6a70469b3ad16b7	American Express	42.541052504963055	-82.9686620445616541
30135	2020-06-11 01:21:48	2020-06-11	Asbury Corwin III	asbury.corwin.iii@geemail.com	Boston	Massachusetts	3158156155921351908	494fd6b8ec0beb95abdd927505f9045e	Maestro	42.3272314706519239	-71.0442702901501235
30136	2020-06-11 01:22:01	2020-06-11	Fredric Schroeder	fredric.schroeder@geemail.com	Boston	Massachusetts	6011197800499093405	f89b1029e9860843c15b8dff75ed1529	Mastercard	42.4043513844423003	-71.0870716102372882
30137	2020-06-11 01:32:58	2020-06-11	Levie Thompson	levie.thompson@geemail.com	New York	New York	3008122395666922	2ffa5a79ef7e402eef6579f186c6eb75	Discover	40.7005775992050758	-74.0070013701811433
30138	2020-06-11 01:36:20	2020-06-11	Junie Berge	junie.berge@geemail.com	New York	New York	3028975387080463	74b93bf5bfa8f9585f8fd0a21bde6309	VISA 13 digit	40.7331794314309974	-73.9119740445528208
30139	2020-06-11 02:04:27	2020-06-11	Che Davis	che.davis@geemail.com	Lincoln	Nebraska	3794508278230353	f97d4aa6b5374f837f9b4ecc29ba7c4b	Discover	40.8896887203231429	-96.7063285050142554
30140	2020-06-11 02:08:26	2020-06-11	Darryl Cormier-Schroeder	darryl.cormier.schroeder@warmmail.com	San Francisco	California	3528388021255669911	6d1a4834941075d0743e016f746eb05e	Mastercard	37.7890534334845754	-122.405053059969902
30141	2020-06-11 02:21:12	2020-06-11	Mariana Lowe MD	mariana.lowe.md@geemail.com	Anaheim	California	210042368366766633	b65fb3985c073298c6df818dc40c5e7a	VISA 13 digit	33.9066220755986834	-117.725208562959352
30142	2020-06-11 02:34:08	2020-06-11	Mrs. Delphia Adams DDS	mrs.delphia.adams.dds@geemail.com	San Francisco	California	3112802438544260047	e9a4eaa6371c57f25dae730bdab2940e	JCB 16 digit	37.7781062999131549	-122.401343858141075
30143	2020-06-11 02:39:00	2020-06-11	Adolf Schultz	adolf.schultz@geemail.com	San Francisco	California	3096100396526274254	549e018d0840b293374ff6d75e6ec379	American Express	37.7675008736516347	-122.434122159017178
30144	2020-06-11 02:58:57	2020-06-11	Miss Elvera Treutel PhD	miss.elvera.treutel.phd@warmmail.com	Phoenix	Arizona	53976696203604439	b985ca283fd687b2ef0d3ec56036d695	Diners Club / Carte Blanche	33.6542634311065072	-112.144410174938301
30145	2020-06-11 03:13:50	2020-06-11	Alver Grimes-Greenfelder	alver.grimes.greenfelder@geemail.com	Philadelphia	Pennsylvania	180019583412837043	3e64a8c7404438110e29fecece4b3df9	JCB 16 digit	40.0069713709834929	-75.1407546473100894
30146	2020-06-11 03:15:37	2020-06-11	Tillman Boyle	tillman.boyle@woohoo.com	Scottsdale	Arizona	6011090077663917127	70a3598025ef6680ca1221c5db0104aa	VISA 16 digit	33.6816126643337341	-111.887232596796366
30147	2020-06-11 03:22:36	2020-06-11	Dr. Owens Hahn	dr.owens.hahn@geemail.com	Oklahoma City	Oklahoma	3057955276390331	d35d3584a051d7edbbb9c0487a11c1ef	VISA 16 digit	35.4450956623911893	-97.4886186669010613
30148	2020-06-11 03:24:11	2020-06-11	Kaleb VonRueden	kaleb.vonrueden@woohoo.com	Tucson	Arizona	3026691860347517	f634d59b705e8d2f9a6169a72b03a5c6	Diners Club / Carte Blanche	32.2294345213606945	-110.942183361038929
30149	2020-06-11 03:25:27	2020-06-11	Octavio Kerluke	octavio.kerluke@geemail.com	Raleigh	North Carolina	4321610794414	598eb9bfd727855480e18f93d938a03e	VISA 13 digit	35.8902619380172325	-78.5431270384166424
30150	2020-06-11 03:26:51	2020-06-11	Kayli Lang	kayli.lang@geemail.com	Atlanta	Georgia	869986688470363044	0e79369f08d062005f05710729cb537f	Voyager	33.7704322026852566	-84.4281814999457509
30151	2020-06-11 03:50:05	2020-06-11	Miss Artelia Schoen	miss.artelia.schoen@geemail.com	New York	New York	6011109977684363152	f84319947df8e5a5c7aa81f1b3d76fe2	Mastercard	40.617319087939336	-74.00749745558835
30152	2020-06-11 03:50:55	2020-06-11	Dolores Gaylord	dolores.gaylord@geemail.com	Yonkers	New York	4695061327677946	948d4768eebad630c063e15c9261cf87	Maestro	40.9306128162160547	-73.8975315643359068
30153	2020-06-11 03:52:04	2020-06-11	Hunter Stamm-Altenwerth	hunter.stamm.altenwerth@geemail.com	San Francisco	California	4125617440347	826c0bb314c6ca8522ae66bd014e4bc6	JCB 16 digit	37.7839932399238805	-122.442387307519212
30154	2020-06-11 03:53:21	2020-06-11	Casimiro Ledner Sr.	casimiro.ledner.sr.@woohoo.com	San Francisco	California	3158399702132995689	e100150a8a39f40bd65a2d50dc963d22	JCB 15 digit	37.7641056869786667	-122.44291867425234
30155	2020-06-11 04:09:16	2020-06-11	Virginia Kling MD	virginia.kling.md@geemail.com	Fresno	California	869949693616423336	91e81e7574db693d618aa6d164e21b8d	Voyager	36.6865424746520787	-119.802526740414649
30156	2020-06-11 04:10:26	2020-06-11	Oran Cummerata-Feil	oran.cummerata.feil@geemail.com	Aurora	Illinois	3112396185752798604	6cf070a90d1a4ce3447a0a9fe673c28b	Mastercard	41.7535536734145154	-88.2050211670737667
30157	2020-06-11 04:17:32	2020-06-11	Clarissa Cummings	clarissa.cummings@woohoo.com	Chicago	Illinois	869938112124652388	3004c00e3a87ae9e20cd7282f09c9128	Maestro	41.8165109534583976	-87.721170682369916
30158	2020-06-11 04:18:13	2020-06-11	Rocco O'Reilly I	rocco.o'reilly.i@geemail.com	New York	New York	4519483642343	f8b94ed10762666e5d1c3ec91c28f0a2	Diners Club / Carte Blanche	40.675752529663967	-73.8765783657681112
30159	2020-06-11 04:21:16	2020-06-11	Salena Tromp DVM	salena.tromp.dvm@woohoo.com	New York	New York	869980778268929845	31a5ceca8ce748f892773a158a4f63b1	Diners Club / Carte Blanche	40.5852023277655221	-73.977360556962708
30160	2020-06-11 04:30:47	2020-06-11	Jarrell Mraz II	jarrell.mraz.ii@geemail.com	Dallas	Texas	3048001428769442	2328f28c2adf8e4b50dc84c3141d6aaf	Mastercard	32.8108865900702824	-96.8157084031924597
30161	2020-06-11 04:38:18	2020-06-11	Miss Saniyah Goyette	miss.saniyah.goyette@geemail.com	Augusta	Georgia	4513689834101	9ce9418c6ad053bada7f6d79ac60a6a9	Voyager	33.3943608102127882	-82.1422293984159921
30162	2020-06-11 04:40:03	2020-06-11	Mrs. Deidra Beahan	mrs.deidra.beahan@geemail.com	Tempe	Arizona	4495004370549424	26b627c0105261ef26bf04dee6fe535b	JCB 16 digit	33.4363068938177079	-111.86894311225339
30163	2020-06-11 04:47:06	2020-06-11	Lesley Jerde	lesley.jerde@geemail.com	Philadelphia	Pennsylvania	55463926143881643	55279fed7608379fa8722feb87223e42	Discover	40.0639723174232998	-75.0609340098585989
30164	2020-06-11 04:51:17	2020-06-11	Little Braun	little.braun@geemail.com	Indianapolis	Indiana	4902043416267861	b7db50f7f3620f0d1e20bd4bca8cc98c	Mastercard	39.8761634572416526	-86.0966574443705355
30165	2020-06-11 04:51:39	2020-06-11	Angel Heathcote-Lubowitz	angel.heathcote.lubowitz@geemail.com	New York	New York	676254599545305	8f276432b689affe679e57b1c3d2e9b4	American Express	40.663203186890108	-73.8981229777809148
30166	2020-06-11 04:56:25	2020-06-11	Barnett Price	barnett.price@woohoo.com	San Francisco	California	676325538558898	8d6abf5fd2e32902033fbf4808ce09bf	VISA 16 digit	37.8193245092897357	-122.406028787812815
30167	2020-06-11 04:58:11	2020-06-11	Abb Mohr	abb.mohr@geemail.com	Los Angeles	California	3741545905887027	6e992cd5743aff93a94b89c1199c6d6f	VISA 16 digit	33.9916296686377351	-118.316597018622971
30168	2020-06-11 05:02:01	2020-06-11	Leafy Pollich-Champlin	leafy.pollich.champlin@warmmail.com	Phoenix	Arizona	4495526683778	9b598a079cd76f24760b935fd7320467	American Express	33.5380358686137967	-112.177629623275635
30169	2020-06-11 05:08:52	2020-06-11	Miss Janay Sauer DVM	miss.janay.sauer.dvm@geemail.com	Chicago	Illinois	6011159125722902909	761e4ea18367b509ecc3a5ea62e70eff	Mastercard	41.7417724222712252	-87.7326364451583487
30170	2020-06-11 05:15:24	2020-06-11	Orie Bednar	orie.bednar@geemail.com	Milwaukee	Wisconsin	4598825508099	46199e559d49e8afb540176c8ef06b4e	Voyager	43.0932208226148035	-88.0542177484936985
30171	2020-06-11 05:17:17	2020-06-11	Billie Hyatt	billie.hyatt@geemail.com	San Francisco	California	3008355015866163	430997db47f29de9a13a1c70adf3ca1c	JCB 16 digit	37.7428324908443784	-122.426144404317242
30172	2020-06-11 05:31:46	2020-06-11	Alphonse Buckridge	alphonse.buckridge@warmmail.com	St. Louis	Missouri	4964507845624368	2518578eecbcbf524e4bef75bdae1ae4	Voyager	38.7240954906370476	-90.3115351863674931
30173	2020-06-11 05:40:08	2020-06-11	Braulio Eichmann DDS	braulio.eichmann.dds@geemail.com	Indianapolis	Indiana	4128668675083415	971e74e3f27d490adde0d1aed8066153	VISA 16 digit	39.6930932602852593	-86.2424510896407099
30174	2020-06-11 05:42:42	2020-06-11	Elianna Gleichner	elianna.gleichner@geemail.com	Midland	Texas	639022695187306	583b7ed7e8f953ba32af9c7154ad7db1	Maestro	32.0310371139276739	-102.165843071019282
30175	2020-06-11 06:02:56	2020-06-11	Micaela Ankunding	micaela.ankunding@woohoo.com	Portland	Oregon	3158275649059742223	32f621af5fd981088b6a103ef94c0a60	JCB 16 digit	45.5217624913789294	-122.567308857152241
30176	2020-06-11 06:03:19	2020-06-11	Ms. Theodora Grant PhD	ms.theodora.grant.phd@geemail.com	San Francisco	California	869920414811228872	104bf2f06ee81b29c9b7b98d51f6fab9	VISA 16 digit	37.7828503339260422	-122.399746612802275
30177	2020-06-11 06:06:30	2020-06-11	Rick Friesen	rick.friesen@geemail.com	Charleston	South Carolina	4444000124022942	697111e841af2da18f148e2aca59801d	Voyager	32.823460307437557	-80.014985590582711
30178	2020-06-11 06:06:49	2020-06-11	Debora Spinka	debora.spinka@geemail.com	Chicago	Illinois	3427564070412527	91de6fb309f9552e4895982b620d4c74	JCB 16 digit	41.8897662960294639	-87.6717400268681359
30179	2020-06-11 06:11:16	2020-06-11	Russ Walter	russ.walter@geemail.com	Bakersfield	California	6011693879281662253	1c20502f8f2d7bb75b13837f6d0ae644	Mastercard	35.2353965263057489	-118.943024898394199
30180	2020-06-11 06:13:16	2020-06-11	Vita Prohaska	vita.prohaska@geemail.com	Torrance	California	52101970531266163	03d03e373d5c2a01c94c674e9efe6ff9	Diners Club / Carte Blanche	33.8376882548816482	-118.30912414408624
30181	2020-06-11 06:14:14	2020-06-11	Mrs. Daisie Huels DVM	mrs.daisie.huels.dvm@woohoo.com	Pueblo	Colorado	4587393297932089	029ebf1537456e12dd79ca8ff8200b51	Diners Club / Carte Blanche	38.1890244047135141	-104.625482799238711
30182	2020-06-11 06:16:17	2020-06-11	Marci Beier	marci.beier@geemail.com	New Orleans	Louisiana	4248255348893779	da15c05849e8275aaa96bd4e278b6cea	American Express	30.0981560699656612	-89.8998356550261377
30183	2020-06-11 06:19:35	2020-06-11	Ludwig Pagac	ludwig.pagac@geemail.com	Albuquerque	New Mexico	54838669382153492	14ba9de28d9701eafe54c497aaa7f009	VISA 13 digit	35.0749036338314468	-106.569471221470835
30184	2020-06-11 06:38:52	2020-06-11	Jahiem Dickens-D'Amore	jahiem.dickens.d'amore@geemail.com	Phoenix	Arizona	4577428983511	66684f67268271f814b9501b501cecec	Voyager	33.556530679848791	-112.029532761957881
30185	2020-06-11 06:41:32	2020-06-11	Ally Simonis	ally.simonis@woohoo.com	Los Angeles	California	4322958812092955	b2e3f84f7bb38d9dfd890fd697a920dc	VISA 16 digit	33.9718702928494665	-118.487960175610326
30186	2020-06-11 06:45:38	2020-06-11	Naoma Hills	naoma.hills@geemail.com	Overland Park	Kansas	869922429030126127	7e0e066ee23e257500e22cc58362b63d	Mastercard	38.9769229130223422	-94.6885132475331517
30187	2020-06-11 06:51:47	2020-06-11	Ms. Aryana Powlowski	ms.aryana.powlowski@geemail.com	Huntsville	Alabama	3528917340539960668	c6dc203eba1b28f249e5dae5e13c6cfe	Discover	34.6415807960331392	-86.5909708925075847
30188	2020-06-11 07:00:25	2020-06-11	Joe Sipes	joe.sipes@geemail.com	Gresham	Oregon	869935319842287545	63489aa646e579246cb8bb96336eee80	Discover	45.571974467295405	-122.452862458376586
30189	2020-06-11 07:10:14	2020-06-11	Noreta Thompson	noreta.thompson@warmmail.com	Houston	Texas	180029782733090336	fe118759846badce8dba6ccec2a6477b	JCB 16 digit	29.8624924086578183	-95.4013825881775546
30190	2020-06-11 07:11:34	2020-06-11	Milas Monahan I	milas.monahan.i@geemail.com	Sparks	Nevada	4660621277650218	0be0c599c065170a1a41c7b90f2bbd05	VISA 16 digit	39.555621795659512	-119.733086963914715
30191	2020-06-11 07:14:39	2020-06-11	Ole Marvin	ole.marvin@woohoo.com	Gainesville	Florida	55199045795010673	d4988b7d221b326d95b50363286f5bc3	VISA 13 digit	29.6389431332994242	-82.4242223057769365
30192	2020-06-11 07:18:59	2020-06-11	Alberta Cummerata-Hintz	alberta.cummerata.hintz@geemail.com	Houston	Texas	3017640308703061	7ff05e170a8073cbbbf3fbadce3e817a	Discover	29.8395526853468276	-95.469237530558928
30193	2020-06-11 07:20:26	2020-06-11	Daron Medhurst	daron.medhurst@geemail.com	Omaha	Nebraska	3337261561838543556	2a426c2286ee85b179f0a0b3c27d0460	Discover	41.3220158835086977	-96.0901386019423711
30194	2020-06-11 07:31:07	2020-06-11	Mrs. Milda Marquardt	mrs.milda.marquardt@geemail.com	Boston	Massachusetts	3016068590582822	5ef71ea850342c5c7705e3e175905a39	Voyager	42.3741307341661297	-71.0324312973253456
30195	2020-06-11 07:36:24	2020-06-11	Miss Zillah Kris	miss.zillah.kris@geemail.com	Jacksonville	Florida	4726463412924	930455eb9f831040f197a4900b7d5bb4	Maestro	30.3394015931110843	-81.6677541018076312
30196	2020-06-11 08:04:32	2020-06-11	Adriane Bins	adriane.bins@geemail.com	Anchorage	Alaska	3482137547795956	fd16445b71361d22f51b6b6577922e0b	Voyager	61.1556115881755957	-149.218618215539692
30197	2020-06-11 08:07:38	2020-06-11	Blanchie Hackett	blanchie.hackett@warmmail.com	San Antonio	Texas	3158467983683485497	e64ec106114b5278a649b89527fb7179	Maestro	29.4491180121969442	-98.4451120105873798
30198	2020-06-11 08:42:35	2020-06-11	Deon Lind	deon.lind@geemail.com	Palmdale	California	3723041717870528	fbb4129f2f8fe4ce6ed9df3e77b7a6e9	JCB 16 digit	34.5303099291715796	-118.156997118470827
30199	2020-06-11 08:46:33	2020-06-11	Israel Lind I	israel.lind.i@warmmail.com	Ann Arbor	Michigan	180012556984785854	477b70ead2e9828a4f9b5e2dca075c9a	Maestro	42.1971636344272625	-83.7558045948498062
30200	2020-06-11 08:47:33	2020-06-11	Lorine Rohan	lorine.rohan@geemail.com	Houston	Texas	6011800807302267679	c3e2d850c7584d3483605b4cdb26ce39	Maestro	29.8676510297305882	-95.3513635600000669
30201	2020-06-11 08:49:46	2020-06-11	Dr. Seward Lesch PhD	dr.seward.lesch.phd@woohoo.com	Denton	Texas	3088177021466317990	bfcffcb8f6f14d8414c63619b9c825a0	Mastercard	33.2912825815644098	-97.1572269775100068
30202	2020-06-11 09:00:08	2020-06-11	Horace Beer	horace.beer@woohoo.com	Fresno	California	3337409731330289494	6123bf6315eb9efec948c6aef28749bf	Voyager	36.8832498398482826	-119.79648070438914
30203	2020-06-11 09:07:23	2020-06-11	Ova Ebert	ova.ebert@geemail.com	Portland	Oregon	3112289391787664288	7863b918669af42fb602aa162b6ecea0	VISA 16 digit	45.6218931690677962	-122.648849940067166
30204	2020-06-11 09:26:32	2020-06-11	Estel Davis-Quitzon	estel.davis.quitzon@geemail.com	San Francisco	California	4016278130125846	4cbeaa950677fc15573127bec6cae750	Discover	37.7762227950303355	-122.440675231124786
30205	2020-06-11 09:35:11	2020-06-11	Brandyn Gusikowski	brandyn.gusikowski@geemail.com	Indianapolis	Indiana	3528580701588487935	9942b99a3391d813d51fba8674e19dcf	Voyager	39.832681822544707	-86.1986520598843668
30206	2020-06-11 09:44:11	2020-06-11	Gail Kilback	gail.kilback@warmmail.com	Orlando	Florida	3112312248451385346	ecc3f57354b4e77473ce58e4162cf5f9	American Express	28.4471375142488618	-81.342116882089897
30207	2020-06-11 09:48:51	2020-06-11	Dr. Kathryne Heidenreich MD	dr.kathryne.heidenreich.md@geemail.com	Colorado Springs	Colorado	3337054612271411719	32c67e19514018b7895f62ebeaaa9d0f	JCB 16 digit	38.936699684341626	-104.713240400950241
30208	2020-06-11 10:03:18	2020-06-11	Mrs. Malinda Gutmann	mrs.malinda.gutmann@geemail.com	Los Angeles	California	4726707104501	b0c941555ada109d90335de521a72831	VISA 16 digit	33.982404111405458	-118.475245078605781
30209	2020-06-11 10:10:10	2020-06-11	Vander Robel	vander.robel@geemail.com	San Francisco	California	3337257092328730277	81be9b9d10b52b20f8dac007eaf6be89	VISA 16 digit	37.7575635967473673	-122.401984496626568
30210	2020-06-11 10:12:01	2020-06-11	Dr. Junie Cruickshank	dr.junie.cruickshank@warmmail.com	Fort Worth	Texas	53097549142686047	8e98efca79c2fa3c0136632d5fd5d137	Maestro	32.7025340274497864	-97.3535577099591478
30211	2020-06-11 10:13:24	2020-06-11	Miss Clemie Crooks DDS	miss.clemie.crooks.dds@geemail.com	Albuquerque	New Mexico	3112649711495664574	d6fd5af0791159583c27ea1b6d51c4a5	VISA 16 digit	35.0799565301876513	-106.66472477690094
30212	2020-06-11 10:15:06	2020-06-11	Mr. Bobbie Corwin V	mr.bobbie.corwin.v@geemail.com	Amarillo	Texas	869936266827274312	bcfea8d9f35f7a7e92a6c9ee0778f5de	JCB 15 digit	35.249102900798988	-101.750699683544042
30213	2020-06-11 10:18:54	2020-06-11	Lida Ryan	lida.ryan@woohoo.com	Oklahoma City	Oklahoma	4846446135713	a5866b5e5d6322ffa7f571f1b94e0a71	JCB 16 digit	35.5322523748878396	-97.5008075995266381
30214	2020-06-11 10:19:53	2020-06-11	Milan Jerde-Boehm	milan.jerde.boehm@geemail.com	Shreveport	Louisiana	4896682753159849	f085314a72e5fb647465e57d8be174da	Mastercard	32.3793028156045821	-93.7081406100399761
30215	2020-06-11 10:20:36	2020-06-11	Jesse Hammes-Rowe	jesse.hammes.rowe@geemail.com	Jersey City	New Jersey	210059004678102387	b553c51e41c27a88139c386c7f93eb81	JCB 15 digit	40.6912927132971589	-73.9724105302665436
30216	2020-06-11 10:25:26	2020-06-11	Dr. Genaro Lakin	dr.genaro.lakin@geemail.com	Phoenix	Arizona	869979368582841240	9416145578969c7263c8f0ead799c4bd	Voyager	33.491349971939627	-112.030113947477574
30217	2020-06-11 10:31:25	2020-06-11	Ruffus Kohler	ruffus.kohler@geemail.com	San Francisco	California	3088885548710933514	80e0611a90bb99ac7ac0ea2956b83178	JCB 16 digit	37.7721519372386112	-122.419189286525508
30218	2020-06-11 10:59:58	2020-06-11	Mariyah Feest	mariyah.feest@geemail.com	San Francisco	California	54225509553650259	982fbedcd7be18e82265fae7b342b335	Maestro	37.8069475926746463	-122.460766869677855
30219	2020-06-11 11:01:16	2020-06-11	Mrs. Lorraine Dicki PhD	mrs.lorraine.dicki.phd@geemail.com	Jacksonville	Florida	869951656009892164	2e30f38c61dd2151fd6b9ea5158717d2	Voyager	30.3566247054893523	-81.6894652635402991
30220	2020-06-11 11:02:22	2020-06-11	Miss Kyrie Cassin	miss.kyrie.cassin@geemail.com	Washington	District of Columbia	561297379174952	bc7e796e96fe4a9b409968189857dc1f	Maestro	38.9677023522820321	-76.9940108561169438
30221	2020-06-11 11:24:00	2020-06-11	Mame Kulas MD	mame.kulas.md@geemail.com	New York	New York	869907478865220421	d38f97fb61fce5486c468f1ddc6f42c5	JCB 16 digit	40.6340778050702056	-73.9506743494316936
30222	2020-06-11 11:24:42	2020-06-11	Miss Kandi Blick	miss.kandi.blick@geemail.com	Indianapolis	Indiana	3112293472728349876	3f08dd31da2f537045a2463b74764cf2	American Express	39.7192839162897329	-86.1091769306190287
30223	2020-06-11 11:38:33	2020-06-11	Gerald Barrows-O'Hara	gerald.barrows.o'hara@geemail.com	Washington	District of Columbia	869922824858705475	6210349cb3aabef70ee66f99f57c9a76	JCB 16 digit	38.8913974668629479	-77.0284193120177889
30224	2020-06-11 11:41:56	2020-06-11	Mrs. Caryl Bashirian DVM	mrs.caryl.bashirian.dvm@warmmail.com	Detroit	Michigan	4622487637933539	bbe599cd2db0772850241507668266b3	JCB 16 digit	42.4778158924933535	-83.1051581188689852
30225	2020-06-11 11:48:13	2020-06-11	Aaliyah Kub	aaliyah.kub@geemail.com	Henderson	Nevada	4131639040945476	e5cc4e7ca1750804f874143d2644cfda	Discover	35.9188622966341669	-115.037019176843401
30226	2020-06-11 11:49:54	2020-06-11	Miss Shianne Raynor	miss.shianne.raynor@geemail.com	Portland	Oregon	4807470701905614	7175dd75e355c934e0670acd4dbeb091	VISA 16 digit	45.6231696144100241	-122.629147886997089
30227	2020-06-11 11:51:49	2020-06-11	Adell Bogisich-Halvorson	adell.bogisich.halvorson@woohoo.com	Vacaville	California	4922971599191	d3ed8246c7cc8536d88177a3ab5b195e	VISA 16 digit	38.4286200613841444	-121.963818171515328
30228	2020-06-11 11:52:07	2020-06-11	Dr. Julien Medhurst DDS	dr.julien.medhurst.dds@geemail.com	San Francisco	California	4718755756035749	67627217322a450e954b88015a783189	Maestro	37.7558022214976319	-122.447395826818052
30229	2020-06-11 11:57:57	2020-06-11	Elvin Denesik	elvin.denesik@warmmail.com	Austin	Texas	51148301666303073	f7aaf24092401a3290504d484df3bb75	JCB 16 digit	30.2260197914797786	-97.8468084389582344
30230	2020-06-11 12:32:22	2020-06-11	York Flatley	york.flatley@geemail.com	San Antonio	Texas	3158698462049327058	ba838c6598019b9afda554206a727812	Mastercard	29.5596240611817684	-98.4291994104929273
30231	2020-06-11 12:34:03	2020-06-11	Dr. Sheri Lebsack DVM	dr.sheri.lebsack.dvm@geemail.com	Fargo	North Dakota	3096298841888001615	76875ea7729b2a22a0bcef61e8a07617	VISA 13 digit	46.8578548681687579	-96.7665755147077107
30232	2020-06-11 12:34:26	2020-06-11	Ms. Kathleen Macejkovic MD	ms.kathleen.macejkovic.md@geemail.com	Boston	Massachusetts	3039594820671272	d8519fa568c0289000b48c46ef5e6d34	VISA 16 digit	42.4272230689581491	-70.9671977134838698
30233	2020-06-11 12:35:21	2020-06-11	Duke Smitham-Schamberger	duke.smitham.schamberger@geemail.com	San Francisco	California	52809393091836561	401c0cd6d187a319cfd221718b117689	VISA 13 digit	37.7711306353466227	-122.447462639582781
30234	2020-06-11 13:11:24	2020-06-11	Delilah Homenick	delilah.homenick@geemail.com	Oakland	California	6011423286760905954	dea721466490906053b51a832a786af5	JCB 16 digit	37.7908413498064633	-122.279047264587916
30235	2020-06-11 13:22:38	2020-06-11	Kevon Larson-Larkin	kevon.larson.larkin@geemail.com	Modesto	California	869954100714567529	ef267e6e0c97ed14fd3505686e79f717	American Express	37.6074778974987609	-120.978963585730639
30236	2020-06-11 13:29:31	2020-06-11	Dayana Bradtke-Greenfelder	dayana.bradtke.greenfelder@geemail.com	Portland	Oregon	3740441275648325	d1ccc560dbb237ec9db6a0aa5d8f245c	Diners Club / Carte Blanche	45.4743054133728108	-122.718388747051364
30237	2020-06-11 13:33:48	2020-06-11	Jaylynn Metz	jaylynn.metz@geemail.com	Kent	Washington	3444630506341223	71dcca3cc190be92ada0b17bfeb11bb0	American Express	47.456716716347259	-122.273686627265803
30238	2020-06-11 14:02:47	2020-06-11	Jayla Waelchi-Homenick	jayla.waelchi.homenick@warmmail.com	Aurora	Illinois	4855695857292984	e0b78d1cfb24d43005d8a3eeab32cd35	JCB 15 digit	41.8035260836351696	-88.334242970303066
30239	2020-06-11 14:15:02	2020-06-11	Mr. Arvo Roob Sr.	mr.arvo.roob.sr.@geemail.com	Berkeley	California	3449723298339227	27d996ae087bdc565cb8f61d601b5192	VISA 16 digit	37.8496503371029078	-122.272463620505818
30240	2020-06-11 14:16:06	2020-06-11	Mr. Arlis Larkin	mr.arlis.larkin@geemail.com	Riverside	California	6011163134704148915	de0c19974de6a40fcf7034c6c2e195e4	American Express	34.0096821301098871	-117.366978189346185
30241	2020-06-11 14:16:11	2020-06-11	Beau Nikolaus	beau.nikolaus@geemail.com	Washington	District of Columbia	54527847291816781	272ba04486f4565eae362ee5faef074b	JCB 15 digit	38.8369826536424441	-76.9595203636892222
30242	2020-06-11 14:20:53	2020-06-11	Yasmin Hudson MD	yasmin.hudson.md@geemail.com	Chicago	Illinois	3053514526667677	7b7ed5959a15f143c7729c16c3ec5a1d	JCB 15 digit	41.8632886856630435	-87.6938456445030852
30243	2020-06-11 14:25:12	2020-06-11	Tonda Predovic-Moore	tonda.predovic.moore@geemail.com	San Francisco	California	53981812296226427	49dcfeb794891aae34df16b7e058de38	JCB 15 digit	37.7450403892097697	-122.433791597168877
30244	2020-06-11 14:35:47	2020-06-11	Kaydence Wiegand-Vandervort	kaydence.wiegand.vandervort@geemail.com	San Diego	California	6011842257620504363	23ae4adbdbc3210f3617c15461838a1c	VISA 16 digit	32.7214845398973679	-117.216178751075645
30245	2020-06-11 14:41:34	2020-06-11	Ms. Matilde O'Connell DVM	ms.matilde.o'connell.dvm@geemail.com	Raleigh	North Carolina	6011541471626958853	c82594e3cb47a7b2a74fa4a1a2402d16	Discover	35.912633070269969	-78.5611200047127909
30246	2020-06-11 14:43:59	2020-06-11	Emory Reichel	emory.reichel@geemail.com	Omaha	Nebraska	4684893765456869	9450bb3e228b9fcfeb69147f0b12ac71	JCB 16 digit	41.2141139940504004	-95.9637225918121715
30247	2020-06-11 14:49:22	2020-06-11	Jeromy Rowe-Spinka	jeromy.rowe.spinka@geemail.com	Philadelphia	Pennsylvania	52109023732854148	9c37b2acaebac7fa66f4a8e8eb50b4c1	Diners Club / Carte Blanche	39.9196684206329309	-75.2246794219028203
30248	2020-06-11 14:50:25	2020-06-11	Mr. Kolten Koss	mr.kolten.koss@geemail.com	New York	New York	53717449293407543	f0702528c1937c759ef1cf43ef0affeb	Mastercard	40.6285688969064509	-73.9534581274155443
30249	2020-06-11 14:55:52	2020-06-11	Naima Stanton DVM	naima.stanton.dvm@geemail.com	Salem	Oregon	4869711073853477	9169cd5474e2fd69b53169e6ab164b85	Discover	44.9245090574759942	-123.101906190548846
30250	2020-06-11 14:57:43	2020-06-11	Samson Spinka Sr.	samson.spinka.sr.@warmmail.com	Boston	Massachusetts	3528775470886360534	35cf47b585a0bd64f788ab82900959ef	JCB 15 digit	42.354792712366212	-71.0860726751804322
30251	2020-06-11 15:02:21	2020-06-11	Francesco Tremblay	francesco.tremblay@geemail.com	San Antonio	Texas	4134599682245014	a13ff4aae202265245e27c5ac372b73b	American Express	29.4954644412804399	-98.5835776627831137
30252	2020-06-11 15:13:11	2020-06-11	Roseann Mills	roseann.mills@geemail.com	Jacksonville	Florida	869928299808374330	c78ee963683d38e99cc13e9cd799439a	JCB 16 digit	30.2390987952757619	-81.5723978880871101
30253	2020-06-11 15:13:39	2020-06-11	Daja Bogan	daja.bogan@woohoo.com	Cleveland	Ohio	3499455639035417	0213850f1a77598abed075bfd3e0aa2a	JCB 16 digit	41.5414884678404732	-81.7044674570445011
30254	2020-06-11 15:27:34	2020-06-11	Sonji Spencer-Ryan	sonji.spencer.ryan@geemail.com	Albuquerque	New Mexico	180091222625652334	414ec768fbc3991a5ddd973d9ff7cb0a	Maestro	35.0776641718246083	-106.672357200046633
30255	2020-06-11 15:29:55	2020-06-11	Lowell Lemke Jr.	lowell.lemke.jr.@geemail.com	New York	New York	561280982620603	1b366ace736a2f0b32821b0709e7cf3b	VISA 16 digit	40.7064620292503392	-73.9777503652859423
30256	2020-06-11 15:30:29	2020-06-11	Nico Becker	nico.becker@geemail.com	Berkeley	California	4070477319613	8d4b1bc32cf4eec41ec5caafdee52bdd	Voyager	37.8839620565103701	-122.238392964416263
30257	2020-06-11 15:35:21	2020-06-11	Gregory Satterfield	gregory.satterfield@geemail.com	Glendale	California	180038052147257775	1bfbb624b408a75d15c41e9ee8f2bf4a	JCB 16 digit	34.1318717590752954	-118.202805462190142
30258	2020-06-11 15:39:00	2020-06-11	Drake Gerlach	drake.gerlach@geemail.com	Chicago	Illinois	6011372080727274518	e42f181f8dea0563903541ef1f78bea1	American Express	41.7490554700441692	-87.7094323048397797
30259	2020-06-11 15:41:22	2020-06-11	Maralyn Mosciski	maralyn.mosciski@geemail.com	Pembroke Pines	Florida	3528702894496517670	e9d7fdbb74a24395fe1aeeab64a15584	VISA 16 digit	26.0286134894043215	-80.2868627325069184
30260	2020-06-11 15:59:54	2020-06-11	Ashby Fisher-Hamill	ashby.fisher.hamill@geemail.com	Santa Ana	California	4783428446950	c407fcee9815e06f3e7fbcf88697ac7a	American Express	33.7995868994958713	-117.962944933159278
30261	2020-06-11 16:05:37	2020-06-11	Vernetta Dicki	vernetta.dicki@woohoo.com	Louisville	Kentucky	3451722285379894	11f26eeb49105252ea6eb044c20f2225	Voyager	38.0745160353273135	-85.6200503354031639
30262	2020-06-11 16:18:59	2020-06-11	Shelley Block MD	shelley.block.md@geemail.com	Fremont	California	6011909570746004849	78f4df0c207518c0846aa0aab2921bb4	Diners Club / Carte Blanche	37.4966959774661817	-122.0038757021062
30263	2020-06-11 16:39:02	2020-06-11	Marco Mayer	marco.mayer@warmmail.com	San Francisco	California	6011631635317380251	e4e6c95a02c75bb14779409588a75a38	Voyager	37.793206513396747	-122.399897761267241
30264	2020-06-11 16:46:31	2020-06-11	Ms. Gertha Barton PhD	ms.gertha.barton.phd@geemail.com	San Francisco	California	3337952036989000155	4f498acee6da083681e43a02370fa942	Voyager	37.7964848723095201	-122.411758710729487
30265	2020-06-11 16:49:25	2020-06-11	Miss Dessa Funk DVM	miss.dessa.funk.dvm@geemail.com	Chattanooga	Tennessee	869901184882668164	a911dd8f5424aa38a5fe0902953ec16d	American Express	35.1283661681544075	-85.340269148146362
30266	2020-06-11 16:53:05	2020-06-11	Bette Sporer	bette.sporer@warmmail.com	Orange	California	3337336895566322127	16234bef1744a8861ca42035719b91f3	American Express	33.8374692885559014	-117.823774468210715
30267	2020-06-11 16:53:41	2020-06-11	Dulcie Hills	dulcie.hills@warmmail.com	San Francisco	California	54363925941301516	6d375a86f81f1c1ed251e457c0a3ae6a	Maestro	37.7449883652837315	-122.454357895157827
30268	2020-06-11 17:04:13	2020-06-11	Arlington Ernser	arlington.ernser@geemail.com	Baltimore	Maryland	4103312988660408	14ebde4877eb1437f008a49303b3e6d9	VISA 13 digit	39.2156793967355028	-76.5599000577833522
30269	2020-06-11 17:06:42	2020-06-11	Katie Mayer-Balistreri	katie.mayer.balistreri@geemail.com	Boston	Massachusetts	3477970276681154	6cb8544a3839bfd0979e37a6e2c3669e	American Express	42.2345688620749868	-70.9264890887260435
30270	2020-06-11 17:13:03	2020-06-11	Bowman Tromp PhD	bowman.tromp.phd@geemail.com	Colorado Springs	Colorado	4624350098544	ebfa45a8eb6e5c1eb0c70fb838f81109	Discover	38.8578916326213601	-104.754402891468999
30271	2020-06-11 17:16:58	2020-06-11	Versie Mante-Beer	versie.mante.beer@geemail.com	Kent	Washington	4134673074292452	011223da2f8f4f9a12fe22ec65bda50a	VISA 16 digit	47.4866857650801535	-122.286458001159872
30272	2020-06-11 17:35:44	2020-06-11	Blair D'Amore	blair.d'amore@geemail.com	Renton	Washington	3096502628522530600	6dde63719f1f5fe9b79bb76595d70810	VISA 13 digit	47.4602345034539752	-122.210070320226251
30273	2020-06-11 18:21:26	2020-06-11	Tracee Spencer-Rempel	tracee.spencer.rempel@geemail.com	Manchester	New Hampshire	210001868390327491	c20fa72af17ffc7b01b6ac5fa0152e9f	JCB 16 digit	43.0203598119389312	-71.427319664590442
30274	2020-06-11 18:37:03	2020-06-11	Dr. Elwin Rogahn MD	dr.elwin.rogahn.md@geemail.com	Riverside	California	3764803351895222	67a429fb67354bd9404865683fc64cf9	Discover	33.9999564509786651	-117.304800943421938
30275	2020-06-11 18:51:40	2020-06-11	Mustafa Mertz	mustafa.mertz@geemail.com	San Francisco	California	869939239719668807	65c24858e2e8a48c5073b1213c020df8	American Express	37.7930495598886012	-122.446147142763792
30276	2020-06-11 18:52:20	2020-06-11	Eloy Green	eloy.green@geemail.com	Buffalo	New York	53396343451076588	98213e5cc28fcad97cfea1962382c100	VISA 16 digit	42.9281283961329621	-78.8695662056028937
30277	2020-06-11 18:56:52	2020-06-11	Hildur Senger	hildur.senger@geemail.com	Madison	Wisconsin	4968316055944	548d2084d8eecfd1a9da38e9d5d258fe	VISA 13 digit	43.0428519660580946	-89.4419857601519652
30278	2020-06-11 19:04:06	2020-06-11	Orange Stracke Sr.	orange.stracke.sr.@geemail.com	Colorado Springs	Colorado	6011691311331114855	b18111203db03c5f884e5fe509e3f401	JCB 15 digit	38.7876493280801924	-104.786297939547154
30279	2020-06-11 19:04:33	2020-06-11	Rylan Terry	rylan.terry@warmmail.com	Birmingham	Alabama	4302459695612443	a1742e42055675a31452eefdf86a9252	JCB 16 digit	33.5500267038378865	-86.8125950514581177
30280	2020-06-11 19:05:32	2020-06-11	Glendon McGlynn	glendon.mcglynn@geemail.com	Las Vegas	Nevada	3035562513814578	a78d88662d0a4630115d9de3fec38c3e	JCB 16 digit	36.1517647412240493	-115.321042746233189
30281	2020-06-11 19:12:54	2020-06-11	Michaele Blanda-Doyle	michaele.blanda.doyle@geemail.com	Berkeley	California	3764644180081323	276531d6dd4ad886778f9ee9cad6d2b9	JCB 15 digit	37.8741532845566837	-122.302815392965726
30282	2020-06-11 19:17:27	2020-06-11	Mr. Skip Crooks	mr.skip.crooks@woohoo.com	El Paso	Texas	6011482927167871806	3e3e09706f9ba27e78d73464f5cb1634	Maestro	31.8486668416127578	-106.356070473928014
30283	2020-06-11 19:34:42	2020-06-11	Mr. Jamel Purdy PhD	mr.jamel.purdy.phd@geemail.com	Madison	Wisconsin	630467405424416	4b24882ad400c3189f6099963450b0e6	VISA 16 digit	43.1555401075605332	-89.4902133840952132
30284	2020-06-11 19:38:47	2020-06-11	Mr. Harry Satterfield	mr.harry.satterfield@geemail.com	Cleveland	Ohio	53332694905657911	76d0885f7f3013b2a67972572cb98502	JCB 15 digit	41.3882191157750725	-81.6932834239449335
30285	2020-06-11 19:48:36	2020-06-11	Dr. Olin Osinski	dr.olin.osinski@geemail.com	Santa Rosa	California	6011494875325893210	d2e743eff02ed228ca44de2f8e002028	Mastercard	38.3785136366851631	-122.642626526417587
30286	2020-06-11 20:19:12	2020-06-11	Miss Tammy Kling	miss.tammy.kling@warmmail.com	Odessa	Texas	3112316346001158449	d24b6c5c9b886d1bfa31a0817a696bca	VISA 16 digit	31.9008689517166459	-102.277606807850674
30287	2020-06-11 20:19:52	2020-06-11	Lars Yost-Hammes	lars.yost.hammes@geemail.com	Santa Ana	California	3763940327060928	7ea811aaf5cbc7f7439b5f21cac13460	Maestro	33.6374376049369559	-117.808128030870108
30288	2020-06-11 20:21:59	2020-06-11	Raymundo Brakus	raymundo.brakus@woohoo.com	Evansville	Indiana	51906620337727283	820e55e41d29b607b67520c291c6a7ff	Discover	37.9406885934665752	-87.4948008347235628
30289	2020-06-11 20:26:08	2020-06-11	Wayman Parisian	wayman.parisian@geemail.com	San Francisco	California	3112321097711115665	78a40991ef346494b5053a519713d7e4	Diners Club / Carte Blanche	37.7849170952870494	-122.435497916020324
30290	2020-06-11 20:28:17	2020-06-11	Stan Emard	stan.emard@geemail.com	Cleveland	Ohio	3088770811150181210	93a9428f7503b266422992b0759ad31f	VISA 13 digit	41.4429903691951154	-81.6478546965174417
30291	2020-06-11 20:41:22	2020-06-11	Mrs. Jacalyn Kuhlman	mrs.jacalyn.kuhlman@geemail.com	Spokane	Washington	52231785430126596	ac34d2ff88e22082d281c0c3c85776bf	JCB 15 digit	47.7391953263204556	-117.440742157110208
30292	2020-06-11 20:43:02	2020-06-11	Dr. Ted Willms	dr.ted.willms@warmmail.com	Pittsburgh	Pennsylvania	6011617088148298664	38fa26468ba04c65683d601525e10c32	Diners Club / Carte Blanche	40.4788423384495033	-80.0540484822060989
30293	2020-06-11 21:05:26	2020-06-11	Mrs. Jasmyne Koelpin	mrs.jasmyne.koelpin@geemail.com	Dallas	Texas	4428504297188	de9f7f466b7c3a4bf0113cce41834cce	JCB 16 digit	32.8814396949756897	-96.8618879778273367
30294	2020-06-11 21:22:04	2020-06-11	Holland Goyette	holland.goyette@geemail.com	Anaheim	California	3096583297543270802	10f6736bd7cdda12c681ea17508e780e	VISA 16 digit	33.9507116960659587	-117.681357133455947
30295	2020-06-11 21:25:46	2020-06-11	Delbert Connelly	delbert.connelly@geemail.com	Houston	Texas	4564247309260284	22bfa42315c140a33e7761634e6ecb55	JCB 16 digit	29.7575347294177845	-95.4899862928796637
30296	2020-06-11 21:46:31	2020-06-11	Carrol Rosenbaum	carrol.rosenbaum@woohoo.com	Los Angeles	California	4981873255828132	67b2feaca6f6e1dce9cd83dba1debc76	VISA 13 digit	33.9414451461616906	-118.457951630651195
30297	2020-06-11 22:06:45	2020-06-11	Mr. Gus Sawayn Jr.	mr.gus.sawayn.jr.@geemail.com	Nashville	Tennessee	6011020426701538913	3e2ee39884a2e2f9169d807746e09fe8	Diners Club / Carte Blanche	36.2521598362952417	-86.7704830854572293
30298	2020-06-11 22:08:04	2020-06-11	Vera Ondricka-Bernier	vera.ondricka.bernier@geemail.com	Lubbock	Texas	869905601022840391	66075402c70d0a715ca19f32551a1a3c	Maestro	33.527574618351089	-101.900727560222904
30299	2020-06-11 22:22:07	2020-06-11	Kenton Mitchell V	kenton.mitchell.v@geemail.com	Downey	California	180053443972610289	960083840fb25aadde09c724be29a1a6	Maestro	33.9396509982429464	-118.086368431441116
30300	2020-06-11 22:25:50	2020-06-11	Edwin Gottlieb	edwin.gottlieb@geemail.com	New York	New York	4542943274029749	c9ad1e70a5748749b271f14eb41b22f1	Voyager	40.636510155791413	-73.878517519718784
30301	2020-06-11 22:29:10	2020-06-11	Fielding Ward-Collins	fielding.ward.collins@geemail.com	San Francisco	California	561241566531608	b143f498646e0ba119736be43e764f58	Maestro	37.7894906853963093	-122.458805432372216
30302	2020-06-11 22:31:25	2020-06-11	Dr. Cristal Frami PhD	dr.cristal.frami.phd@geemail.com	Long Beach	California	3088261916376037835	cc34b54bd33ff9888429ab029477f7e9	JCB 15 digit	33.7870766394127102	-118.155914185445013
30303	2020-06-11 22:39:16	2020-06-11	Ozell Rodriguez	ozell.rodriguez@geemail.com	Arlington	Texas	4164906688023068	35abd9dcce9b220bab95675e326225d9	JCB 16 digit	32.6767683428030438	-97.1598624596398395
30304	2020-06-11 22:39:29	2020-06-11	Cleo Streich-Lueilwitz	cleo.streich.lueilwitz@geemail.com	Oakland	California	55203609435254118	81b6e6e4041faf263aa28ee3a5a2a263	JCB 16 digit	37.8046265250618347	-122.246120359324308
30305	2020-06-11 22:55:48	2020-06-11	Osie Legros	osie.legros@geemail.com	Concord	California	3158976753297610440	748e5d2bb5c4338b735a45a2e3a72261	American Express	37.9651636618122481	-122.09638908115997
30306	2020-06-11 23:09:53	2020-06-11	Tasha Fadel	tasha.fadel@geemail.com	San Francisco	California	4809107953431752	84d106a82b698aa9d93b2b0f33badc52	Diners Club / Carte Blanche	37.7684773368636044	-122.440756588798976
30307	2020-06-11 23:46:17	2020-06-11	Dr. Lawyer Fay II	dr.lawyer.fay.ii@geemail.com	Newark	New Jersey	6011545499901412045	c9b584431e99b2cd55896fc3a4814e03	VISA 13 digit	40.7976883159864698	-74.2148492446843591
30308	2020-06-11 23:48:55	2020-06-11	Celestia McLaughlin	celestia.mclaughlin@geemail.com	Columbus	Ohio	3000374481131612	d71f8ff812908b460895a3b2ce9cd8a0	JCB 16 digit	40.0340400878850389	-83.042056986992435
30309	2020-06-12 00:03:29	2020-06-12	Solon Dicki	solon.dicki@geemail.com	Mesa	Arizona	4672081135633821	7e2cbeaf04f0476d47e64e7d8f31cd78	JCB 16 digit	33.4578407040476762	-111.627548615809161
30310	2020-06-12 00:04:38	2020-06-12	Dr. Davis Runolfsdottir	dr.davis.runolfsdottir@geemail.com	San Bernardino	California	4725287662961	e79d8a6410a754b7bae6c3fff06014e0	JCB 16 digit	34.1517869492791561	-117.343584137341381
30311	2020-06-12 00:08:34	2020-06-12	Maxie Rempel	maxie.rempel@woohoo.com	San Francisco	California	3337757392155269554	2b6ff1aee674baec4caaddb361f914b3	JCB 16 digit	37.7835316638169303	-122.413543086923724
30312	2020-06-12 00:10:28	2020-06-12	Triston Crona Sr.	triston.crona.sr.@geemail.com	Jacksonville	Florida	4754062914971682	515a40b86d9a5b953ff8fdcb9b60f678	JCB 16 digit	30.2714891902688876	-81.7227591878812802
30313	2020-06-12 00:20:55	2020-06-12	Orvel Reichel	orvel.reichel@warmmail.com	Mesa	Arizona	210039732203309987	e5f59bfe1df0a8ccfea355620ac06ee0	Maestro	33.3799286038294412	-111.784247048606716
30314	2020-06-12 00:20:57	2020-06-12	Latoya Hauck	latoya.hauck@geemail.com	Washington	District of Columbia	3035220091590173	1bfc8225dd2c6c9d4af47e032e22c844	Mastercard	38.9935222076982271	-77.0074844442520288
30315	2020-06-12 00:32:13	2020-06-12	Dr. Iva Block DDS	dr.iva.block.dds@geemail.com	Cary	North Carolina	4943830732993761	740ff31f21e68a8b9ea71ad5d4a2a835	Maestro	35.7233109715502763	-78.7832466725811287
30316	2020-06-12 00:37:50	2020-06-12	Clemmie Kuphal	clemmie.kuphal@geemail.com	San Francisco	California	4903263043007	bf3bad9607256652c6fc69e635d0039c	JCB 16 digit	37.7981451596105984	-122.423217774268963
30317	2020-06-12 00:40:16	2020-06-12	Kristina Gorczany-Kessler	kristina.gorczany.kessler@woohoo.com	Plano	Texas	3096034003836621114	f06cdc72cb5b90f2cba3cab4d57e53fc	Diners Club / Carte Blanche	33.1115914532069127	-96.8170278340760575
30318	2020-06-12 00:40:45	2020-06-12	Mr. Reubin Champlin DDS	mr.reubin.champlin.dds@geemail.com	Dallas	Texas	869986500395387158	bf8b1eb4d77f9c2dc9224f5600c2aa6f	Discover	32.7886799704555472	-96.6754334865100589
30319	2020-06-12 00:43:26	2020-06-12	Elisha Schneider	elisha.schneider@warmmail.com	Alexandria	Virginia	3337945058410613414	bb5b4f9440dbd3cb2c7df197da2fee7a	VISA 16 digit	38.7216485379379236	-77.069273264285556
30320	2020-06-12 00:47:59	2020-06-12	Haylie Cormier	haylie.cormier@geemail.com	Scottsdale	Arizona	4404774686210529	4246000512e3cf9c20d684d3d5bad49b	VISA 16 digit	33.7739579356864112	-111.918233717043321
30321	2020-06-12 01:11:17	2020-06-12	Ms. Natalia Jacobson DDS	ms.natalia.jacobson.dds@geemail.com	Denton	Texas	4553622540017789	3f65141ca118d5fac88d36b6b6d42fb0	VISA 13 digit	33.307093559185418	-97.2286037041932332
30322	2020-06-12 01:24:48	2020-06-12	Shanna Purdy DVM	shanna.purdy.dvm@warmmail.com	New York	New York	3158194452628414129	9e49e02ac7a76dad2a1d2847463c6776	VISA 16 digit	40.762843891022726	-73.9025026418629949
30323	2020-06-12 01:27:25	2020-06-12	Micah Aufderhar	micah.aufderhar@geemail.com	Lexington	Kentucky	4795192616938407	496508e1778426e2ca7e4e212ac58e9d	American Express	37.9494194981053496	-84.4137374809842527
30324	2020-06-12 01:37:17	2020-06-12	Brendon Oberbrunner-Cormier	brendon.oberbrunner.cormier@geemail.com	Port St. Lucie	Florida	3746135871525614	473c2306696f4b148295f4ad76362542	Discover	27.3337677358318132	-80.4519945284903031
30325	2020-06-12 01:46:30	2020-06-12	Whitney Beer	whitney.beer@geemail.com	Chicago	Illinois	52940323814300884	9d415f3a5008d8e38058d435f1c444ed	Maestro	41.7685570839162921	-87.7220258353773517
30326	2020-06-12 01:57:26	2020-06-12	Nathen Ondricka	nathen.ondricka@geemail.com	Rancho Cucamonga	California	4493035617284286	a6a83469ccb8c035068948db0fed2003	Mastercard	34.1366577380329375	-117.537032232806837
30327	2020-06-12 02:02:49	2020-06-12	Coen Doyle DDS	coen.doyle.dds@woohoo.com	Shreveport	Louisiana	54716969315759937	53c143d04c79dc7e13a21a63cbc1f659	Mastercard	32.4325951686367446	-93.7836668940473288
30328	2020-06-12 02:06:30	2020-06-12	Mrs. Armida Kshlerin	mrs.armida.kshlerin@warmmail.com	Washington	District of Columbia	4162353373853	0e695e16eada9628660fbb3bde5a82fc	Discover	38.9203719439715172	-76.9980518112637071
30329	2020-06-12 02:10:06	2020-06-12	Reanna Ziemann	reanna.ziemann@geemail.com	San Francisco	California	4038729644286	a0259d4d8645028cf8901f4094bb12f4	Mastercard	37.7423772286189561	-122.438270745130268
30330	2020-06-12 02:13:12	2020-06-12	Joanne Murphy	joanne.murphy@geemail.com	Berkeley	California	869984335188334162	eee6dc6687be721b79319963daef5ee5	JCB 15 digit	37.8300398912748648	-122.262257298720954
30331	2020-06-12 02:17:49	2020-06-12	Brenden Kling	brenden.kling@geemail.com	Sterling Heights	Michigan	4006705422374692	5d26cf1544a8ac10e7f16c87259dcd0c	Diners Club / Carte Blanche	42.4949517958879497	-83.0279658516563472
30332	2020-06-12 02:22:58	2020-06-12	Roslyn Wilderman	roslyn.wilderman@geemail.com	Clinton	Michigan	4269651005131210	8614a4164fe60308700f197877c84677	Maestro	42.5297950612448119	-82.9187859195824757
30333	2020-06-12 02:36:11	2020-06-12	Lular Sawayn	lular.sawayn@geemail.com	Clovis	California	3054388728607743	c9bae2920935ce593f4ecac64084f5a2	JCB 16 digit	36.7319744265049692	-119.655974373554443
30334	2020-06-12 02:47:21	2020-06-12	Minna Schroeder	minna.schroeder@warmmail.com	Lafayette	Louisiana	52658160545065010	0ebfbcd89222376454040bd48955581d	Maestro	30.2487275841157874	-92.0770966394189685
30335	2020-06-12 02:52:32	2020-06-12	Herminia Padberg	herminia.padberg@geemail.com	Omaha	Nebraska	180068936668252574	890bcbb1a7a7d63936698386fd7aa320	Mastercard	41.2531046845164155	-95.9552466075051598
30336	2020-06-12 02:54:47	2020-06-12	Sheldon Ebert	sheldon.ebert@geemail.com	Greensboro	North Carolina	3158748252358935231	7531581d28af7f95aed78f6e2432c155	Diners Club / Carte Blanche	36.183302712358909	-79.7862228597961405
30337	2020-06-12 02:59:44	2020-06-12	Mrs. Alysha Ziemann	mrs.alysha.ziemann@geemail.com	Davenport	Iowa	180031776043037611	1f6a7dd93fa88e110155b5207fc0c92b	Voyager	41.4569251030016659	-90.5312720891051015
30338	2020-06-12 03:08:18	2020-06-12	Bret Watsica III	bret.watsica.iii@geemail.com	Tacoma	Washington	3088449308492751595	36743b669442e3056d1402295aed6185	American Express	47.2759596522551035	-122.479352625808872
30339	2020-06-12 03:28:15	2020-06-12	Krish Harber	krish.harber@geemail.com	Anchorage	Alaska	3040690803562048	1495d52d21a9f79ed3afb467e79dee80	Voyager	61.0814466928813644	-149.328458118078487
30340	2020-06-12 03:35:48	2020-06-12	Miss Lilyanna Dach	miss.lilyanna.dach@warmmail.com	Memphis	Tennessee	4356415898705	8840a21c5692b94b37d016400f969181	VISA 16 digit	35.0710768747210508	-90.0527253714647173
30341	2020-06-12 03:52:29	2020-06-12	Clifford Hahn	clifford.hahn@geemail.com	Garland	Texas	4968347819859872	36593d2f83b52ac97114ae3408341aa3	VISA 16 digit	32.8579162767857298	-96.5860651393115575
30342	2020-06-12 04:04:46	2020-06-12	Leona Cremin	leona.cremin@geemail.com	Memphis	Tennessee	060462742132624	e48e794e145b2174ebb896d8a27f5810	Mastercard	35.0661684151340296	-89.9033294253774073
30343	2020-06-12 04:09:35	2020-06-12	Mr. Jason Lubowitz	mr.jason.lubowitz@geemail.com	Thornton	Colorado	4546327144868732	246ca313dfe4e5c5ae03167776a99e9d	Maestro	39.8214410094875859	-104.876635863228898
30344	2020-06-12 04:22:07	2020-06-12	Babette Breitenberg	babette.breitenberg@geemail.com	Las Cruces	New Mexico	51358351636417458	45cd3846a7bcf25de7084a445d6ff415	JCB 15 digit	32.3208127090740973	-106.691692786023765
30345	2020-06-12 04:28:56	2020-06-12	Giovani Nienow-Ortiz	giovani.nienow.ortiz@geemail.com	Tulsa	Oklahoma	3112117812721511879	dbca8939ca2ed1388f1c03a0dec8dc38	JCB 16 digit	36.0518655005745572	-95.9393694768615006
30346	2020-06-12 04:33:35	2020-06-12	Miss Carlota Wyman	miss.carlota.wyman@geemail.com	Sacramento	California	3004659178707641	54527b4eff0c104fade93751e6fc3309	Maestro	38.5989499114252652	-121.469803662343324
30347	2020-06-12 04:50:34	2020-06-12	Trevin Toy DVM	trevin.toy.dvm@geemail.com	Tampa	Florida	3030622847986313	def2d6f3e3ae905a1934cd8d76f2b09d	VISA 13 digit	28.0506711267981679	-82.4070856834974137
30348	2020-06-12 04:51:51	2020-06-12	Dann Rogahn-Herman	dann.rogahn.herman@geemail.com	Los Angeles	California	180011836370265864	7e21d3a0028fdc826f11051910bd52a2	Maestro	34.0410872576624115	-118.320420376536617
30349	2020-06-12 05:02:17	2020-06-12	Lenard Cormier	lenard.cormier@geemail.com	Los Angeles	California	3423514934646889	7be047643aa25caae6c2aeb9a1c8c589	JCB 16 digit	34.0739900753699203	-118.440861252368606
30350	2020-06-12 05:12:16	2020-06-12	Dr. Eliezer Willms	dr.eliezer.willms@geemail.com	Overland Park	Kansas	3528415880655781551	ca666498e73e3ff01a556f8d48361b59	VISA 13 digit	38.9639497181735948	-94.6652401079930428
30351	2020-06-12 05:17:53	2020-06-12	Vollie Schamberger	vollie.schamberger@warmmail.com	Washington	District of Columbia	6011018922744451985	c4ed349569e2e9b24ba4d7f6d0232d87	JCB 16 digit	38.8060420129712682	-76.9817837832707994
30352	2020-06-12 05:18:18	2020-06-12	Mitzi Crist	mitzi.crist@geemail.com	Colorado Springs	Colorado	869940654118310800	e914e686e72ee603904a603189b84d06	JCB 16 digit	38.7978394415743679	-104.840294724997875
30353	2020-06-12 05:20:27	2020-06-12	Mrs. Odalis Dibbert MD	mrs.odalis.dibbert.md@warmmail.com	Chicago	Illinois	4081389181660324	1f9fa5301dce0ebdd08337f8b2abf2d8	JCB 16 digit	41.8230223610367631	-87.6037398329034431
30354	2020-06-12 05:26:25	2020-06-12	Miss Amelie Bauch PhD	miss.amelie.bauch.phd@geemail.com	Philadelphia	Pennsylvania	3096830468688307698	b3426aba1eff9758d19390fb144650fc	JCB 16 digit	39.9373378488659867	-75.0593085150133845
30355	2020-06-12 05:28:09	2020-06-12	Braeden Armstrong	braeden.armstrong@geemail.com	New York	New York	4848561516969778	9065d35c37c2248f6f3519bcd95fcc38	Mastercard	40.6930428754761806	-73.8486706836044817
30356	2020-06-12 05:29:01	2020-06-12	Ms. Cyndi Cruickshank	ms.cyndi.cruickshank@geemail.com	Springfield	Missouri	4973987576471925	45c880375f9b499fdfe6ec620f52c488	JCB 15 digit	37.2919932818234017	-93.2319563584692901
30357	2020-06-12 05:36:22	2020-06-12	Dr. Mammie Kovacek	dr.mammie.kovacek@warmmail.com	San Francisco	California	3020092661680444	261330a578f0b78a337bf262b328df2c	Voyager	37.7549508097743782	-122.449867036552362
30358	2020-06-12 05:39:37	2020-06-12	Dr. Candi Streich PhD	dr.candi.streich.phd@geemail.com	Corona	California	3453514611043718	f1b62ff4eff10ad03b35a8f3848a8254	JCB 16 digit	33.9046900424994533	-117.580394922170782
30359	2020-06-12 05:47:50	2020-06-12	Brooke Nicolas	brooke.nicolas@geemail.com	Fort Worth	Texas	6011301367254069593	e0f05d1e11a6b2dbe688601f61a4aa45	VISA 16 digit	32.7648620090503258	-97.4208613101679788
30360	2020-06-12 05:54:33	2020-06-12	Mr. Jeremey Friesen	mr.jeremey.friesen@geemail.com	Dallas	Texas	3528875266505163377	2898501b2ce6c3fa44128db83149c05b	VISA 16 digit	32.860709004131337	-96.7919099738318351
30361	2020-06-12 05:56:00	2020-06-12	Kristian Cruickshank	kristian.cruickshank@geemail.com	San Francisco	California	55670466180852859	fdb80ca5dc166bae0815331e4ab94e73	Discover	37.7924321329708874	-122.387895318265819
30362	2020-06-12 05:56:30	2020-06-12	Ricardo Kunze	ricardo.kunze@warmmail.com	Phoenix	Arizona	3014064301559912	2b688cf3a731a8f37ba5b6651a28bb50	Voyager	33.515111020247268	-112.183940317334987
30363	2020-06-12 05:59:31	2020-06-12	Cecily Langosh DVM	cecily.langosh.dvm@warmmail.com	Mobile	Alabama	4708856694607	9391cc795b4d4857f56fc6d7609609a1	Maestro	30.717350864560899	-88.1451223978444887
30364	2020-06-12 06:01:24	2020-06-12	Shelly Krajcik	shelly.krajcik@warmmail.com	Austin	Texas	55654007256565122	37a8dc05908ed411c0953ea58ad4f655	VISA 16 digit	30.2513489976651968	-97.689873533952607
30365	2020-06-12 06:03:27	2020-06-12	Dempsey Greenholt	dempsey.greenholt@woohoo.com	Hillsboro	Oregon	3112553280963790588	c487263a99044599980fb2c698329f1f	VISA 16 digit	45.5736231193616987	-122.908977572821826
30366	2020-06-12 06:04:50	2020-06-12	Bryn Aufderhar	bryn.aufderhar@geemail.com	Phoenix	Arizona	3528229461188164924	aa1857191b81112c0adda74824d3409a	VISA 16 digit	33.5971221807345799	-112.128176680526138
30367	2020-06-12 06:09:52	2020-06-12	Calvin Zemlak	calvin.zemlak@geemail.com	San Jose	California	3088989241726956241	413820c9fbfa15f8379b67e1799cef6e	VISA 13 digit	37.2231747257810071	-121.886158228361609
30368	2020-06-12 06:13:39	2020-06-12	Dr. Harlon Grimes	dr.harlon.grimes@warmmail.com	Hillsboro	Oregon	210015686363999763	f554292ff08d02cb11454b2e63a39801	VISA 13 digit	45.5720899450331913	-123.017519322565562
30369	2020-06-12 06:24:50	2020-06-12	Peggy Dare-Lockman	peggy.dare.lockman@geemail.com	Dallas	Texas	3158886974475640210	25a37ab0b88caa815a044a4355b81b73	Voyager	32.7626005331326269	-96.7834198280665987
30370	2020-06-12 06:25:14	2020-06-12	Miss Kerry Lindgren	miss.kerry.lindgren@geemail.com	Boise	Idaho	180009121805713463	7de4328bb25867ef32d37fe714522b99	Diners Club / Carte Blanche	43.5182545557290297	-116.135835862644768
30371	2020-06-12 06:34:45	2020-06-12	Maddox Padberg-Zieme	maddox.padberg.zieme@geemail.com	Amarillo	Texas	3158593439474217901	ce32ae2f79ffe4fa71871d2081a9b35e	VISA 16 digit	35.110093225974218	-101.820360822821783
30372	2020-06-12 06:42:53	2020-06-12	Keyshawn Macejkovic	keyshawn.macejkovic@woohoo.com	Lubbock	Texas	3088307359815561592	3b3872963185307b6cddc1bd56d01819	VISA 13 digit	33.551285879504313	-101.878687630957742
30373	2020-06-12 06:44:35	2020-06-12	Mr. North Kuhic	mr.north.kuhic@geemail.com	San Jose	California	060444979913041	16638000efeecb48672208c22a50062a	Voyager	37.3813523436717716	-121.727730516133462
30374	2020-06-12 06:46:12	2020-06-12	Cassie Doyle	cassie.doyle@geemail.com	Chicago	Illinois	4877147035498	c78ac669f53f33446bb096f9de9edfaa	Diners Club / Carte Blanche	41.9283375744078342	-87.6997847435560089
30375	2020-06-12 06:46:21	2020-06-12	French Nader-O'Reilly	french.nader.o'reilly@woohoo.com	Berkeley	California	6011456581074825611	1ab46fc637935740c04fe384efd1d87a	JCB 16 digit	37.8938371345599805	-122.248735766097255
30376	2020-06-12 06:48:20	2020-06-12	Alphonsine Collins	alphonsine.collins@geemail.com	Ontario	California	3096486259496092797	d0cdbf85fc22352de6280f2fc1164cd2	JCB 15 digit	34.0648717561881966	-117.514439842627198
30377	2020-06-12 07:36:43	2020-06-12	Jamarion Zulauf	jamarion.zulauf@warmmail.com	Anaheim	California	3058697428097906	e63451ca23ea3143cb20f3329f03d7df	VISA 13 digit	33.7616732118483611	-117.692237351203701
30378	2020-06-12 07:42:08	2020-06-12	Lamarcus Wolff Jr.	lamarcus.wolff.jr.@woohoo.com	Louisville	Kentucky	4265630591859396	f049b0d6e639a4606450192a372937b2	JCB 16 digit	38.1189755057353494	-85.6632969120588257
30379	2020-06-12 08:05:27	2020-06-12	Jaxen Will	jaxen.will@geemail.com	Charlotte	North Carolina	4297053557690642	af9371a152d6016e58cc8204a20d7e0b	Diners Club / Carte Blanche	35.1107198057949503	-80.765405257459733
30380	2020-06-12 08:07:48	2020-06-12	Glenn Conroy III	glenn.conroy.iii@warmmail.com	San Francisco	California	3037422977697720	c597fd680fb94be329eaf131500cb6b6	VISA 13 digit	37.7350703655745576	-122.407407950948141
30381	2020-06-12 08:12:37	2020-06-12	Mr. Watt Ebert	mr.watt.ebert@geemail.com	San Diego	California	3337877461935548739	151e7f5b3b41301afd5876ab24eab385	VISA 13 digit	32.8265390033435054	-117.075567075181752
30382	2020-06-12 08:52:20	2020-06-12	Aria Haag DVM	aria.haag.dvm@geemail.com	Las Vegas	Nevada	3003088755838226	8d8d42b79a0cecb41c24e63f98f9317a	JCB 16 digit	36.2900787905890496	-115.287548761695987
30383	2020-06-12 08:54:36	2020-06-12	Mrs. Corean Jacobi DVM	mrs.corean.jacobi.dvm@geemail.com	Bakersfield	California	676362600474001	7b2a99864c272b341188bb4541988e50	VISA 16 digit	35.2615165922965801	-118.959478354062142
30384	2020-06-12 09:10:57	2020-06-12	Sky McKenzie	sky.mckenzie@geemail.com	Cary	North Carolina	4799090688259643	adfde7776b70c7028c1010edea9c9a97	JCB 16 digit	35.8781934474237261	-78.8665492095138916
30385	2020-06-12 09:15:16	2020-06-12	Taliyah Ernser	taliyah.ernser@geemail.com	Coral Springs	Florida	210034614129539092	046857c8477b8c98beccf8ba98b7baca	Diners Club / Carte Blanche	26.2050985770363383	-80.2520901502698649
30386	2020-06-12 09:18:47	2020-06-12	Madyson Huels	madyson.huels@geemail.com	Houston	Texas	6011515246041426252	73dd5de81d0a1f27766f17bf2ad0884e	Voyager	29.717680849561841	-95.43829704020321
30387	2020-06-12 09:28:28	2020-06-12	Maddox Volkman	maddox.volkman@woohoo.com	Lexington	Kentucky	3158277542046646631	4d53236e3ac79bcec90b5818518c8168	VISA 16 digit	38.1386509378783387	-84.4908164092704652
30388	2020-06-12 09:31:02	2020-06-12	Atlas Kulas	atlas.kulas@geemail.com	Everett	Washington	4487919523123803	a771a4f818be115f6955e06f6b341f96	VISA 16 digit	48.0182482204757619	-122.174787406496336
30389	2020-06-12 09:35:29	2020-06-12	Falon Lakin	falon.lakin@woohoo.com	Santa Clara	California	4951384563932	c8347e39d5dd8a0186e1ce793b7953d8	Discover	37.2932262108013077	-121.947380239097029
30390	2020-06-12 09:41:35	2020-06-12	Antony Mann-Ruecker	antony.mann.ruecker@geemail.com	Pembroke Pines	Florida	589317600829042	0f09d9e33b4683dbf969c5b499c7ffa0	Diners Club / Carte Blanche	26.0784180835392334	-80.3730605626382015
30391	2020-06-12 09:50:41	2020-06-12	Adolph Baumbach	adolph.baumbach@geemail.com	San Francisco	California	4140933845731465	22e2c43a4c32c7c72f9d45b243b9f016	JCB 16 digit	37.7622099136813461	-122.432772406214255
30392	2020-06-12 09:53:23	2020-06-12	Shanice Gutmann	shanice.gutmann@geemail.com	San Francisco	California	3528731133133572714	b8407703a47abe0c42117a4f61a20105	Discover	37.7431219257942274	-122.422187779182551
30393	2020-06-12 10:02:24	2020-06-12	Maury Kuvalis DVM	maury.kuvalis.dvm@geemail.com	San Francisco	California	4724859285775288	f5b9674c22fd08f34e6a0aa9d2380d7f	Mastercard	37.8024278112910181	-122.432247622716446
30394	2020-06-12 10:02:45	2020-06-12	Mr. Pearley Denesik	mr.pearley.denesik@woohoo.com	New York	New York	55507577589454706	c35abdb8c303c0d37ee05db0b8b7180c	Voyager	40.7093722331095478	-73.8493937431730245
30395	2020-06-12 10:03:16	2020-06-12	Mr. Jaden Littel III	mr.jaden.littel.iii@geemail.com	Seattle	Washington	869968554021875187	c41e00c64f9da1e3e130c3c655d51ab8	Maestro	47.7031599168591214	-122.324670087631418
30396	2020-06-12 10:05:02	2020-06-12	Laurette Konopelski MD	laurette.konopelski.md@geemail.com	Alexandria	Virginia	561262764798245	a8c0a76fa8dd6ec0e26a588f54aeabd6	Discover	38.7548165191546019	-77.1024891581371463
30397	2020-06-12 10:06:28	2020-06-12	Conner Mohr	conner.mohr@geemail.com	Montgomery	Alabama	676283326260797	fa8fb26fea4a81c5538745a5c885fca8	Diners Club / Carte Blanche	32.3681210968576352	-86.3074107662927332
30398	2020-06-12 10:08:18	2020-06-12	Ingrid Bernier	ingrid.bernier@geemail.com	Dallas	Texas	3779679586298652	2fb2b42f1ea5db06f16e98e7d0865da0	JCB 16 digit	32.845111133231967	-96.832533866163331
30399	2020-06-12 10:09:11	2020-06-12	Freida Kihn	freida.kihn@geemail.com	Phoenix	Arizona	3158554862986405010	6cdc45e5e4877c79b441bdd141485339	VISA 16 digit	33.6536975480549074	-111.990969478564722
30400	2020-06-12 10:19:31	2020-06-12	Donnie Schuster	donnie.schuster@geemail.com	Houston	Texas	3012244551769567	ff067c9672531ca35b7b1a371c38cdc4	Discover	29.8152803747061625	-95.3013197403416115
30401	2020-06-12 10:24:51	2020-06-12	Allisson Wisozk	allisson.wisozk@geemail.com	Sacramento	California	6011994424118465962	368f19a4ab84901efcdbee5d65800fb8	Diners Club / Carte Blanche	38.6455820741396394	-121.499166608859227
30402	2020-06-12 10:31:32	2020-06-12	Mr. Hayes Murphy	mr.hayes.murphy@warmmail.com	Boston	Massachusetts	869977942138276531	a3f79517161394c27ba8a1bbd4cb2e09	VISA 13 digit	42.3082599665671566	-70.9406034040681988
30403	2020-06-12 10:51:42	2020-06-12	Darry Conroy	darry.conroy@woohoo.com	Pembroke Pines	Florida	3088634263200111993	7dba5514783cc88026696551784c03f3	Voyager	25.9308200849723072	-80.4290488098651224
30404	2020-06-12 10:55:12	2020-06-12	Mrs. Yasmin Batz	mrs.yasmin.batz@geemail.com	Los Angeles	California	4517221847242185	98babd907f3230628d00080d4afd2c23	Diners Club / Carte Blanche	34.1074291854031344	-118.330085391550512
30405	2020-06-12 11:00:18	2020-06-12	Burke Hagenes	burke.hagenes@geemail.com	Chicago	Illinois	3735651884428870	da524353d4eb28e4e702c2816b700f88	American Express	41.7812384993139645	-87.7333722067095323
30406	2020-06-12 11:01:49	2020-06-12	Ember Schmeler	ember.schmeler@geemail.com	Berkeley	California	3462641028092464	c7e90297f870397c11e89b2cae6bab3f	Maestro	37.8949997593674226	-122.277095842885132
30407	2020-06-12 11:13:21	2020-06-12	Ariel Lehner MD	ariel.lehner.md@geemail.com	Fort Worth	Texas	4312180214154687	d993d90b657da556978cf073d6db67dc	Maestro	32.7082554352059987	-97.3062931033603888
30408	2020-06-12 11:13:32	2020-06-12	Dr. Beverley Gerhold MD	dr.beverley.gerhold.md@geemail.com	Durham	North Carolina	501872687564749	d9fa87c7ed7b367e60170e074f278c52	JCB 16 digit	35.923738081451873	-78.8863050425793944
30409	2020-06-12 11:14:28	2020-06-12	Dr. Ishmael Watsica Jr.	dr.ishmael.watsica.jr.@geemail.com	San Francisco	California	4336712978610652	f6c050ab1d67b7056a41912e9f184e0c	Voyager	37.7731683914513212	-122.465344478012966
30410	2020-06-12 11:19:32	2020-06-12	Jarad Beier	jarad.beier@geemail.com	San Francisco	California	180075506345195529	5bfa45da1a8a2fa56b971faff9b58f51	Voyager	37.7625623460702045	-122.456987359583636
30411	2020-06-12 11:32:44	2020-06-12	Maddux Anderson	maddux.anderson@geemail.com	Berkeley	California	869987422036267492	4f67c0315985f17b15ca652b25e4d57a	Voyager	37.8531446031773058	-122.277749901910312
30412	2020-06-12 11:51:19	2020-06-12	Marget Pouros PhD	marget.pouros.phd@geemail.com	Los Angeles	California	3112405207568833638	f0a31dbaf163988ac07ac51090cc6547	VISA 13 digit	34.0979834592767048	-118.365852931932722
30413	2020-06-12 12:10:34	2020-06-12	Beda Bosco	beda.bosco@geemail.com	Fresno	California	4077055243575968	570a6e7356522c3b6afdb4a7ac4d710c	Diners Club / Carte Blanche	36.7010627954140318	-119.876386166374758
30414	2020-06-12 12:15:05	2020-06-12	Sharron Beier	sharron.beier@geemail.com	Jersey City	New Jersey	869931505323551516	99746108c1aefa05d6fb643b7e5e8bf7	Diners Club / Carte Blanche	40.7006617905046753	-74.0341142219446624
30415	2020-06-12 12:22:14	2020-06-12	Dr. Eugenie Wiegand	dr.eugenie.wiegand@geemail.com	Lafayette	Louisiana	4282506164862836	472afc92f7f6bfdab638fd4543331d04	Diners Club / Carte Blanche	30.2539879657771422	-92.0229670257158574
30416	2020-06-12 12:22:41	2020-06-12	Dr. Jaren Collins	dr.jaren.collins@warmmail.com	New York	New York	54105592170459481	eede7f09c34c9f92fe8ae2919e85f92e	Diners Club / Carte Blanche	40.6308057343810773	-73.9188017704419735
30417	2020-06-12 12:30:08	2020-06-12	Mariann Vandervort	mariann.vandervort@geemail.com	San Francisco	California	676355522754252	69d4e95c00a84001428e110d93b3705b	VISA 16 digit	37.7981207868575808	-122.447588523541455
30418	2020-06-12 12:34:14	2020-06-12	Norah Oberbrunner	norah.oberbrunner@geemail.com	Lexington	Kentucky	210055575375207466	cb456bc0c558c9a2c2b94d7f8dabb6d0	VISA 16 digit	37.9979950671892652	-84.3853078494679067
30419	2020-06-12 12:41:53	2020-06-12	Thurston Stiedemann DVM	thurston.stiedemann.dvm@geemail.com	Louisville	Kentucky	3043789738132617	28c8fd2734d45fa15387dee936015274	American Express	38.1748778845086676	-85.6451081845048918
30420	2020-06-12 12:51:18	2020-06-12	Claribel Kohler	claribel.kohler@geemail.com	New York	New York	3528268474955291434	ec7248d09132350c2d58159f15015ec6	JCB 16 digit	40.6669763016737988	-74.0120733306638812
30421	2020-06-12 12:54:14	2020-06-12	Bina Braun	bina.braun@warmmail.com	Moreno Valley	California	3112578728153264534	5eb8086706f81f3a0f48f028ce1d4d7a	VISA 13 digit	33.9709214213762394	-117.163004413476955
30422	2020-06-12 12:55:57	2020-06-12	Estefania Roberts	estefania.roberts@geemail.com	San Francisco	California	869914685488581580	027998cc4dd386252c3a103ded04ef06	JCB 15 digit	37.7876733160023122	-122.428942706509588
30423	2020-06-12 12:56:38	2020-06-12	Rosalie Abshire	rosalie.abshire@geemail.com	Sacramento	California	4160221869284	de8ecbd1abd427c2b3483922fe66c4f8	VISA 13 digit	38.5257560575645428	-121.56308486813343
30424	2020-06-12 13:04:32	2020-06-12	Lex Johns	lex.johns@geemail.com	San Francisco	California	4516693374213568	b8525a921970f3530596c529f07fe26d	VISA 13 digit	37.7722424360558051	-122.440971665560227
30425	2020-06-12 13:09:14	2020-06-12	Braden Hansen PhD	braden.hansen.phd@geemail.com	Waco	Texas	53959675174202697	a0f795997727d8cea2c93d811464fdbd	Discover	31.4862961135547579	-97.166791685497401
30426	2020-06-12 13:31:52	2020-06-12	Ms. Shalonda Fritsch PhD	ms.shalonda.fritsch.phd@woohoo.com	Modesto	California	180032139940885443	b1b7d8ed2be4b4cc16cdf911808f4bf4	JCB 16 digit	37.7209504379425198	-120.923682084327567
30427	2020-06-12 13:54:41	2020-06-12	Hattie Reichel	hattie.reichel@woohoo.com	Newark	New Jersey	3096451606832216996	22011e9f9df9e2871a7201f3d64af65a	JCB 15 digit	40.7382355590730967	-74.2146992440078463
30428	2020-06-12 13:59:58	2020-06-12	Mikaila Hodkiewicz	mikaila.hodkiewicz@geemail.com	Mesquite	Texas	3411658277757672	202cfa6ed3a0edfa914b7daf00555ef4	Maestro	32.7653142057169262	-96.6216992491122397
30429	2020-06-12 14:02:22	2020-06-12	Mr. Irvin Turner III	mr.irvin.turner.iii@geemail.com	New York	New York	3112973568906367353	e213d7ffe8c4ef9bb29b88247ba14e03	Maestro	40.6143505000732858	-73.9126806913770764
30430	2020-06-12 14:14:48	2020-06-12	Ms. Eller Gleason	ms.eller.gleason@geemail.com	Baltimore	Maryland	4254068164444	d3e34894c987f402eaaaacff5234edc0	Mastercard	39.3498543379362644	-76.6968767289556581
30431	2020-06-12 14:26:55	2020-06-12	Mrs. Louisa Heaney MD	mrs.louisa.heaney.md@geemail.com	Norwalk	California	55516054455488647	20b900aaa9d61b188a2d88e53da72176	VISA 13 digit	33.9899024692479514	-118.046538718560711
30432	2020-06-12 14:40:39	2020-06-12	Mr. Dwyane Welch	mr.dwyane.welch@woohoo.com	Moreno Valley	California	4613728930973248	29263907105f15e6ba1054c87779eac2	VISA 16 digit	33.8365641877979044	-117.273897319563474
30433	2020-06-12 14:53:42	2020-06-12	Bernita Daugherty	bernita.daugherty@geemail.com	Minneapolis	Minnesota	869907422064236747	e27bcf72a76b00a1d6ebfa1d39f9563c	VISA 13 digit	44.9192134618844818	-93.2036666153270659
30434	2020-06-12 15:02:34	2020-06-12	Dr. Carey Schultz DDS	dr.carey.schultz.dds@geemail.com	Berkeley	California	3528885363654254020	b24824cd60826b77f794da98a4fa7f56	Discover	37.8525675409985922	-122.293275876259159
30435	2020-06-12 15:06:48	2020-06-12	Gustave Hane	gustave.hane@geemail.com	Philadelphia	Pennsylvania	4818919881883	5ba3a5360b120cc2729c35a8457d481a	VISA 13 digit	40.0863214600324653	-75.0419485412903242
30436	2020-06-12 15:11:19	2020-06-12	Maddison Yost	maddison.yost@woohoo.com	Salt Lake City	Utah	502066510467377	e08a43c31d49517f0a7dd6b41204f61f	JCB 16 digit	40.7262770520668482	-111.989280662447214
30437	2020-06-12 15:24:22	2020-06-12	Rebecca Feest MD	rebecca.feest.md@geemail.com	Augusta	Georgia	53016423263581163	f2f84730532a2ed6c79a0685e54e278e	Discover	33.2948720426503542	-81.9882457740899184
30438	2020-06-12 15:31:58	2020-06-12	Jethro Rolfson	jethro.rolfson@woohoo.com	Springfield	Massachusetts	3088546183613264535	20e61a9dc3313227cc2d18c68bb54fbd	Maestro	42.0932269866317483	-72.5099633041396743
30439	2020-06-12 15:37:27	2020-06-12	Mickey Schowalter	mickey.schowalter@warmmail.com	Detroit	Michigan	3337026835350433255	dc8c633dc5eb683cb7bf9df9a3f7dcf9	VISA 16 digit	42.3969569737482814	-83.1631630160033666
30440	2020-06-12 15:56:53	2020-06-12	Cleda Swift PhD	cleda.swift.phd@warmmail.com	Allentown	Pennsylvania	3112339713128897444	c5b57cf31d73573a744cbd00de27bc12	Mastercard	40.5457534070838292	-75.3958431730527394
30441	2020-06-12 16:03:42	2020-06-12	Krystin Maggio	krystin.maggio@geemail.com	Albuquerque	New Mexico	4340566233441	e907108c2fd8ba39917a5d3f03daea2a	JCB 15 digit	35.1790894850756999	-106.715952877940239
30442	2020-06-12 16:13:31	2020-06-12	Vernia Bradtke PhD	vernia.bradtke.phd@warmmail.com	San Antonio	Texas	180000599623866481	2e4b8c768022e99b13c539686ff927fd	American Express	29.445510071383417	-98.5329621651511616
30443	2020-06-12 16:21:35	2020-06-12	Carin Willms-Stroman	carin.willms.stroman@warmmail.com	San Francisco	California	4953309768363436	171870b8034b5e748b8df6c8a58b193f	Maestro	37.7566754620510565	-122.41427653471564
30444	2020-06-12 16:24:56	2020-06-12	Dr. Myrtice Jacobi DDS	dr.myrtice.jacobi.dds@warmmail.com	Chicago	Illinois	6011441396622337086	05e7495516fd7a01d794608817c05399	American Express	41.8779298310469841	-87.6904583063006413
30445	2020-06-12 16:27:57	2020-06-12	Dr. Matteo Doyle DDS	dr.matteo.doyle.dds@geemail.com	Lowell	Massachusetts	180071446950959402	1784654624111d4d31549415f1df1e6e	Discover	42.7137222927864642	-71.252399777934329
30446	2020-06-12 16:31:08	2020-06-12	Elwanda Abernathy	elwanda.abernathy@warmmail.com	Oakland	California	4385989047076	b187563445b9f5bd76b04f0e0371f451	VISA 16 digit	37.8021831502375605	-122.282212938697228
30447	2020-06-12 16:49:00	2020-06-12	Clair Lowe-Ruecker	clair.lowe.ruecker@geemail.com	Colorado Springs	Colorado	180034144033701612	83145e546f71b4eda6ed601433d737f0	Maestro	38.820581878121196	-104.762946126811954
30448	2020-06-12 17:01:42	2020-06-12	Mrs. Carlyn Ledner PhD	mrs.carlyn.ledner.phd@woohoo.com	Indianapolis	Indiana	210096896130437672	558b1be212601d5dfa846d2993de0451	Mastercard	39.8548037698499868	-86.1686925064973508
30449	2020-06-12 17:12:07	2020-06-12	Dr. Tera Stracke DDS	dr.tera.stracke.dds@warmmail.com	Milwaukee	Wisconsin	4084078508088585	93db66b27890e78b471f965ff9b9e0d7	Diners Club / Carte Blanche	43.0449758413333399	-87.9880145139627245
30450	2020-06-12 17:27:33	2020-06-12	Alto Kuhlman	alto.kuhlman@woohoo.com	Los Angeles	California	6011028866073948723	d90ea5f825b8b0336883d288bd9f2842	Discover	33.9559206974092831	-118.312233540275315
30451	2020-06-12 17:28:11	2020-06-12	Vonnie Schinner MD	vonnie.schinner.md@warmmail.com	Detroit	Michigan	180077900431729325	a8a0f1080b66fec330cbbd524756c184	VISA 16 digit	42.4737865508925196	-83.1194615254297844
30452	2020-06-12 17:36:38	2020-06-12	Lorenzo Morissette	lorenzo.morissette@warmmail.com	Los Angeles	California	869909934902004978	638e55e8a9d17109ee64bfcf5e17cfec	VISA 13 digit	33.9611228420730669	-118.434728874591357
30453	2020-06-12 17:50:34	2020-06-12	Ms. Arley Gottlieb PhD	ms.arley.gottlieb.phd@warmmail.com	San Diego	California	6011483675264853453	37028fbbdadc6f33c24205b395ffa797	American Express	32.8485637418061529	-117.167057819049816
30454	2020-06-12 17:54:08	2020-06-12	Teri Hilpert	teri.hilpert@woohoo.com	San Francisco	California	4989478722230334	5c0e4a338b348ab915613620e1e2790b	JCB 16 digit	37.7890833155600205	-122.423113367722209
30455	2020-06-12 17:56:58	2020-06-12	Arne McCullough	arne.mccullough@geemail.com	Berkeley	California	3096115998565393284	8aed41afbdd3f855658a61020266dbb1	VISA 13 digit	37.8928155718629185	-122.280893902811087
30456	2020-06-12 18:00:35	2020-06-12	Ean Dibbert	ean.dibbert@geemail.com	Stockton	California	3158767105659810063	5bb2607542de9394e5f19e4a4fb6ec25	American Express	37.9842502642154685	-121.364549212864787
30457	2020-06-12 18:11:05	2020-06-12	Bolden Streich	bolden.streich@warmmail.com	Baltimore	Maryland	869961297013044670	69b118cf37fd846190671f4721e1c411	Diners Club / Carte Blanche	39.2917045885231317	-76.6603381639830843
30458	2020-06-12 18:15:11	2020-06-12	Cuba McLaughlin	cuba.mclaughlin@geemail.com	San Jose	California	3337239396616417023	eab4b8178e6e3864983233819e4db711	VISA 16 digit	37.3740668182082487	-121.847393330162021
30459	2020-06-12 18:18:59	2020-06-12	Shelley Cummerata DVM	shelley.cummerata.dvm@warmmail.com	Columbia	Missouri	3158751254669686630	f5f21012d86df516653dfe9df8c1d8af	JCB 16 digit	39.0297245820865584	-92.2338601817430117
30460	2020-06-12 18:34:25	2020-06-12	Ronny Rippin	ronny.rippin@geemail.com	Chicago	Illinois	3112185448910133360	83cc31ad46c7dbea6bdc7cfc92a8f83a	JCB 16 digit	41.8162211825907235	-87.6644644365675703
30461	2020-06-12 18:38:08	2020-06-12	Khalilah Howe	khalilah.howe@woohoo.com	San Bernardino	California	3719175696297166	34089607e76ff0cfa12bbe262c4ef3a0	VISA 13 digit	34.0609765089381469	-117.355528799841551
30462	2020-06-12 18:39:03	2020-06-12	Winter Price	winter.price@woohoo.com	South Bend	Indiana	060414709697974	045e85da78d7af608f7c837509460215	Discover	41.5813221722520936	-86.238549248926347
30463	2020-06-12 18:41:11	2020-06-12	Marilee Ziemann	marilee.ziemann@geemail.com	New York	New York	54218107784111990	4936a23aa5573d543514998b2864c979	VISA 16 digit	40.6538501873370279	-73.9439854344248744
30464	2020-06-12 18:49:44	2020-06-12	Mr. Kevan Kuhic	mr.kevan.kuhic@geemail.com	Stockton	California	4595050873376632	d7a469fc2773e2dd18f924f5bca8d39a	VISA 16 digit	37.9628575702395281	-121.298203110656885
30465	2020-06-12 18:54:36	2020-06-12	Dr. Odus Maggio	dr.odus.maggio@geemail.com	Lafayette	Louisiana	4278756369981214	f62c2b79573459da1c952617338b1e98	VISA 16 digit	30.1318015362113698	-91.9590588434450211
30466	2020-06-12 18:55:49	2020-06-12	Maddox Nader	maddox.nader@geemail.com	Escondido	California	676114312721286	8a6374c470ca9af593c9b595bd2dcd22	Maestro	33.0411146053805922	-117.160433925200252
30467	2020-06-12 18:57:38	2020-06-12	Robyn McLaughlin	robyn.mclaughlin@geemail.com	Louisville	Kentucky	3528685533547318743	5aae1ac5ee5766edda2472613de38a3e	VISA 16 digit	38.0783824689589423	-85.5568720883760676
30468	2020-06-12 19:00:57	2020-06-12	Oma Haley DDS	oma.haley.dds@woohoo.com	New York	New York	3030420693379034	14261993c38ea519249874a33c9bdc5c	VISA 16 digit	40.5891518254056578	-73.8821594531077892
30469	2020-06-12 19:25:35	2020-06-12	Garnet Wintheiser	garnet.wintheiser@geemail.com	San Francisco	California	3337784025538506998	36c22632eb04640e633636258a374ee8	Diners Club / Carte Blanche	37.767961906490342	-122.420405310437687
30470	2020-06-12 19:27:37	2020-06-12	Kristine Simonis-Hills	kristine.simonis.hills@warmmail.com	Omaha	Nebraska	4547033315538828	6223ffa00b7a8076da6a5fcb523d7947	JCB 16 digit	41.273421874703466	-96.082033682253595
30471	2020-06-12 19:31:52	2020-06-12	Esau Wisozk	esau.wisozk@geemail.com	New York	New York	52649737942237342	764ff14d97b282144b44d8be31c6d8f5	VISA 16 digit	40.5977146357521406	-73.9362188198033721
30472	2020-06-12 19:33:26	2020-06-12	Sunshine Morar	sunshine.morar@geemail.com	Thornton	Colorado	4006372608886393	059c44a4811015523df05c8c2f73e90d	JCB 16 digit	39.8510948736552209	-105.007690857227146
30473	2020-06-12 19:41:50	2020-06-12	Mrs. Denine Franecki	mrs.denine.franecki@geemail.com	Laredo	Texas	4264432547570719	0a8660953b2d824b5aac9e6493d40fd3	Voyager	27.4718624058827778	-99.4061947848655194
30474	2020-06-12 19:55:06	2020-06-12	Mrs. Marylou McDermott DVM	mrs.marylou.mcdermott.dvm@warmmail.com	San Francisco	California	4643560527218339	6e3e673f5528d9db337563e9678cdd35	JCB 15 digit	37.7614039057895639	-122.433246577554414
30475	2020-06-12 20:00:03	2020-06-12	Cole Nader-Jones	cole.nader.jones@geemail.com	Salt Lake City	Utah	6011319664400125836	a15df976e677570243ba01f9fa6e72e8	JCB 15 digit	40.7363957698602235	-112.010318983666593
30476	2020-06-12 20:08:29	2020-06-12	Vernal Ryan	vernal.ryan@geemail.com	San Diego	California	4341681465943319	c68b6a35c7130ff6e45a9510d298ebaf	American Express	32.7567628852158776	-117.14408203888685
30477	2020-06-12 20:11:16	2020-06-12	Salma Dooley	salma.dooley@geemail.com	Lakeland	Florida	869944213555608618	7c33e0ea2d8246da4d1e44ef1fc82a85	VISA 16 digit	28.0595052135940612	-81.9971701962292201
30478	2020-06-12 20:12:02	2020-06-12	Elayne Hickle DDS	elayne.hickle.dds@geemail.com	Durham	North Carolina	3337312615762781936	81d5db5aad85f7372ac4d38e8b709b9c	American Express	35.9330885074812869	-78.9631521536406211
30479	2020-06-12 20:12:52	2020-06-12	Dr. Boyce Dooley	dr.boyce.dooley@geemail.com	Dayton	Ohio	6011622761964292242	9ea2a1f76874eb2fb0fae0f40af9eb27	American Express	39.8374826682988541	-84.1711409873984735
30480	2020-06-12 20:16:34	2020-06-12	Jailyn Bergstrom	jailyn.bergstrom@warmmail.com	Durham	North Carolina	55684736959552029	2433b90d4b98bfb376da61e65d4dfdd0	Maestro	35.9423692968919823	-78.8354859543401716
30481	2020-06-12 20:40:09	2020-06-12	Dr. John Walsh	dr.john.walsh@geemail.com	Chicago	Illinois	869905088334996790	446f2915db85a9a3d066ecaa056742ba	JCB 16 digit	41.9056486554745575	-87.6853604142583833
30482	2020-06-12 20:41:07	2020-06-12	Leann VonRueden	leann.vonrueden@woohoo.com	Palm Bay	Florida	210052461300479400	eaecc59727fcf4f2000efe2487456f0b	Discover	27.968515255986155	-80.7588769377045281
30483	2020-06-12 20:43:10	2020-06-12	Mr. Durward Hansen	mr.durward.hansen@warmmail.com	Ventura	California	3158795994458222372	fa89b03bd248272352103fd9bb31544a	VISA 16 digit	34.19994271296747	-119.221395809213448
30484	2020-06-12 20:52:33	2020-06-12	Katie Lakin	katie.lakin@woohoo.com	Philadelphia	Pennsylvania	3528828204093382271	3e3622f7631b9105b62081067cbdd872	VISA 16 digit	40.0487273390829586	-75.2201387777823953
30485	2020-06-12 21:09:32	2020-06-12	Christie Hessel	christie.hessel@geemail.com	Pittsburgh	Pennsylvania	55042090109135377	8468d1d7c42611f83da3779d68737778	JCB 15 digit	40.4300052516117674	-80.0334859506398431
30486	2020-06-12 21:15:23	2020-06-12	Noemi Bogisich	noemi.bogisich@geemail.com	Reno	Nevada	3707874740075040	f45d3f4092dffbd3c6199cd79d6994d1	VISA 13 digit	39.4849555542305168	-119.833620584958794
30487	2020-06-12 21:21:30	2020-06-12	Cleora Johnson-Ward	cleora.johnson.ward@geemail.com	Berkeley	California	3112294983249548662	6ecafd8ad3d364ea00083a892e0ebe68	Mastercard	37.8358977257789419	-122.269596030946786
30488	2020-06-12 21:39:06	2020-06-12	Fletcher Waelchi-Zulauf	fletcher.waelchi.zulauf@geemail.com	San Francisco	California	3777998724186021	bd6878dada45afe46ee26b26c49bd93a	Voyager	37.7545295116016888	-122.442360513849835
30489	2020-06-12 21:41:15	2020-06-12	Cathey Aufderhar DVM	cathey.aufderhar.dvm@geemail.com	San Francisco	California	6011050736156799692	374ada3c8c12a9eed5dd78a6c98e5e65	VISA 16 digit	37.7692032006912868	-122.449046172607041
30490	2020-06-12 21:51:28	2020-06-12	Dr. Gorden Weissnat PhD	dr.gorden.weissnat.phd@warmmail.com	Los Angeles	California	3337134836464866322	5167ebb1a5c1e3ca1967e9143022f9fb	Maestro	34.0465589006297265	-118.457936179264635
30491	2020-06-12 22:04:17	2020-06-12	Jerel Bahringer	jerel.bahringer@warmmail.com	New York	New York	3088249633235368775	e3a34e8ff928ad86b1237bf674427afb	VISA 13 digit	40.7231797907259292	-74.01939222513586
30492	2020-06-12 22:12:00	2020-06-12	Vernelle Walker	vernelle.walker@geemail.com	Tampa	Florida	3752844269739734	6967337b55f6c09c3e4e7f264f16c2c8	Voyager	27.9950080509878667	-82.4552359158851118
30493	2020-06-12 22:15:53	2020-06-12	Racheal Durgan	racheal.durgan@geemail.com	San Francisco	California	3528795524896314216	3541b75f8f55c2abb1516004707ad7aa	Diners Club / Carte Blanche	37.7507802468592715	-122.448350165156668
30494	2020-06-12 22:20:41	2020-06-12	Gerda Fadel	gerda.fadel@geemail.com	Cary	North Carolina	503811409905897	e5223d84c8a369504602d9031e64deb4	VISA 16 digit	35.8612710376843822	-78.7317780829120437
30495	2020-06-12 22:34:53	2020-06-12	Ashleigh Okuneva	ashleigh.okuneva@woohoo.com	New Orleans	Louisiana	3029143335861679	deadc1df704480aa4eeb5b355349ae1c	VISA 16 digit	30.0213100646171718	-89.9719456972349434
30496	2020-06-12 22:37:55	2020-06-12	Eartha Olson	eartha.olson@geemail.com	San Francisco	California	676333786080342	31fcb3c3cb02950db710b4b18071bd06	JCB 16 digit	37.7797332179189809	-122.443104201256361
30497	2020-06-12 22:44:11	2020-06-12	Mr. Orlin Farrell	mr.orlin.farrell@woohoo.com	Phoenix	Arizona	6011731500116907614	d85744b607cb91d7b716a8558c68007d	Discover	33.5298591198798306	-112.000673517717431
30498	2020-06-12 22:47:12	2020-06-12	Rhonda Torp	rhonda.torp@geemail.com	Bakersfield	California	4456034974967679	03d6e8ab245206f57a2417e9ed97c72c	JCB 16 digit	35.3570549035619948	-118.937942413035032
30499	2020-06-12 23:06:11	2020-06-12	Jenifer Grimes	jenifer.grimes@geemail.com	San Francisco	California	4436704381429456	60525c7acaa4ba41e8b983e5092d2dab	Discover	37.7652174737575237	-122.430353256704635
30500	2020-06-12 23:07:32	2020-06-12	Carli Vandervort	carli.vandervort@geemail.com	Chicago	Illinois	4847291980151395	3feda2cb135c6c0385c7b3c8c26828fd	JCB 15 digit	41.7550323617480714	-87.7766905264493005
30501	2020-06-12 23:21:02	2020-06-12	Carsen Thompson	carsen.thompson@woohoo.com	Hollywood	Florida	3337798663294353868	bf3d1fc037ac2fe9838ff90752e484d2	Diners Club / Carte Blanche	26.0684158908147339	-80.1042090747788507
30502	2020-06-12 23:21:32	2020-06-12	Lawerence Wiegand MD	lawerence.wiegand.md@warmmail.com	Tucson	Arizona	51729338384014357	87cb89d27f28c97aa6de81395929822b	VISA 13 digit	32.1912717498879886	-110.88882377899661
30503	2020-06-12 23:32:33	2020-06-12	Kaleena Waelchi	kaleena.waelchi@geemail.com	Huntsville	Alabama	4548313470104	1c316ef24b0527e071febc4bb1395007	VISA 16 digit	34.748133155774326	-86.6299691421929765
30504	2020-06-12 23:35:42	2020-06-12	Caryl Kozey	caryl.kozey@geemail.com	Los Angeles	California	3337134327720782586	e20d3a9671a02fe98d76ab7377b7f047	Diners Club / Carte Blanche	33.9661972991988037	-118.506996279954166
30505	2020-06-12 23:42:17	2020-06-12	Mr. Claudius Gleichner	mr.claudius.gleichner@geemail.com	San Francisco	California	4192663242914326	4c23b6a4be6f0d9d51f0a70474f87a45	Voyager	37.7695550667345827	-122.418379007749039
30506	2020-06-13 00:07:16	2020-06-13	Mrs. Laurene Hodkiewicz MD	mrs.laurene.hodkiewicz.md@geemail.com	Phoenix	Arizona	3728115805988148	a679d53f6013831a9645f3bab351824f	JCB 15 digit	33.6268265752986082	-112.145047684379307
30507	2020-06-13 00:11:56	2020-06-13	Lemuel Considine	lemuel.considine@woohoo.com	Evansville	Indiana	3337796851622353807	4e756037964bdfce3bfbf8793917dacc	Diners Club / Carte Blanche	37.9324180281858858	-87.4658971368733802
30508	2020-06-13 00:14:18	2020-06-13	Ovid Bahringer	ovid.bahringer@geemail.com	San Diego	California	3088358480244072577	fc35d79f8b4736c01c81924c62bc7caf	Mastercard	32.8940796106189524	-117.048822765648367
30509	2020-06-13 00:15:13	2020-06-13	Alessandro Hilll-Barrows	alessandro.hilll.barrows@warmmail.com	Los Angeles	California	3088171863120939628	30cbf628c62f32eda4862ca70a9f2c54	JCB 16 digit	33.9581109430506771	-118.35605793101638
30510	2020-06-13 00:18:36	2020-06-13	Slade Hegmann-Hyatt	slade.hegmann.hyatt@woohoo.com	Santa Clara	California	3096031052335687095	30f7abe21ad95de2fc699d5e81a1c64d	Mastercard	37.3516487933978496	-121.948995868395642
30511	2020-06-13 00:20:28	2020-06-13	Ivette Haley	ivette.haley@woohoo.com	Denver	Colorado	4541547857089	3f8cf95c6cf2e38fb9c7b90bf3186973	JCB 16 digit	39.7927641953393803	-104.953230464157087
30512	2020-06-13 00:28:17	2020-06-13	Hazle Watsica-Blanda	hazle.watsica.blanda@geemail.com	New York	New York	6011463414168600669	444ab054bdee7f1c5c627c837976f5f9	JCB 16 digit	40.5876445928346357	-73.9140363291732996
30513	2020-06-13 00:29:19	2020-06-13	Lottie Pfannerstill	lottie.pfannerstill@geemail.com	Oakland	California	6011064554376640222	e2feecc7c566126ee6931f5d6e80e283	Mastercard	37.7953076246073323	-122.249429692486075
30514	2020-06-13 00:43:05	2020-06-13	Zachery Hauck V	zachery.hauck.v@geemail.com	Omaha	Nebraska	4156304518384	940e0075da6cfed5a921e45c7bb99505	JCB 16 digit	41.3200720151100356	-96.0353328991796928
30515	2020-06-13 00:51:13	2020-06-13	Hyman Cremin	hyman.cremin@woohoo.com	San Francisco	California	4202929211425	b3cc2eb942d88d8c7c3f374eaa7c96d1	VISA 16 digit	37.7538357309960944	-122.402314746902675
30516	2020-06-13 00:53:06	2020-06-13	Mrs. Delfina Witting PhD	mrs.delfina.witting.phd@geemail.com	Kansas City	Kansas	3158534753317272283	bba4f966a4613531e9afb50cf9cd5b52	JCB 15 digit	39.2158937349822381	-94.8241286402504926
30517	2020-06-13 01:07:54	2020-06-13	Cicero Morissette	cicero.morissette@geemail.com	El Paso	Texas	676149914795692	9ac2ee9fc19c083280f65913556f0a2d	Mastercard	31.823202245013416	-106.506839051188905
30518	2020-06-13 01:10:43	2020-06-13	Cathey Labadie	cathey.labadie@geemail.com	Jacksonville	Florida	869919121337620960	11ebcbb556fe27b4621e4fbf32eb9dc3	Voyager	30.2549291963275522	-81.6697541518215218
30519	2020-06-13 01:12:14	2020-06-13	Mr. Kimball McDermott V	mr.kimball.mcdermott.v@geemail.com	San Francisco	California	52210459293625707	07bccefa50be3c776ab91edea9881ac0	Mastercard	37.7942673662351254	-122.435525426601032
30520	2020-06-13 01:25:30	2020-06-13	Anona Grant	anona.grant@geemail.com	Columbus	Ohio	3088041093499997605	55ce5cb905480966964210175e58b0a8	VISA 16 digit	39.9405069860208783	-82.9851638910595426
30521	2020-06-13 01:42:18	2020-06-13	Clarice Brekke	clarice.brekke@warmmail.com	San Francisco	California	4984884165296	2cc07d45d76b465793e46c21ac9c3e8d	Diners Club / Carte Blanche	37.7541138027996226	-122.428497541094856
30522	2020-06-13 01:42:58	2020-06-13	Mr. Chase Emmerich	mr.chase.emmerich@woohoo.com	Philadelphia	Pennsylvania	3096605348049022587	3d89e4227c2d71ff9f3c843b9d958dc1	Diners Club / Carte Blanche	39.9331426295410807	-75.0567451979864444
30523	2020-06-13 01:46:28	2020-06-13	Dr. Marland Prohaska	dr.marland.prohaska@warmmail.com	Philadelphia	Pennsylvania	3027918630660807	ba0d4d240ececbd10f4605cd6135827f	JCB 16 digit	40.0833018335472815	-75.104950487417355
30524	2020-06-13 01:46:48	2020-06-13	Adrien Quigley	adrien.quigley@geemail.com	Vancouver	Washington	3025408875579328	516f0cf48bd2093d7031a0fdf8d6c7e1	JCB 16 digit	45.6465335751023176	-122.599939759873592
30525	2020-06-13 01:59:16	2020-06-13	Dr. Kia Ullrich	dr.kia.ullrich@geemail.com	Fresno	California	869954467208304077	96d64fed07b914681e0d81f82315c404	JCB 16 digit	36.7938336742449579	-119.890560279285168
30526	2020-06-13 02:00:09	2020-06-13	Mr. Arjun Swift	mr.arjun.swift@geemail.com	Bakersfield	California	4772259165254275	378319ea68b100749415fee74b776db2	VISA 13 digit	35.2459384574264263	-119.033367311469462
30527	2020-06-13 02:01:14	2020-06-13	Jodi Senger PhD	jodi.senger.phd@warmmail.com	Birmingham	Alabama	180017078130635987	8562c8f9cf31bbae8c4b3957f0b7f420	Maestro	33.5479475096590818	-86.7838936750087981
30528	2020-06-13 02:01:30	2020-06-13	Leoma Donnelly	leoma.donnelly@geemail.com	Los Angeles	California	869909683929656340	d40892664478880f8e147c251ef46053	American Express	34.0521324797399316	-118.494771744962037
30529	2020-06-13 02:17:50	2020-06-13	Dr. Reilly Mayert DVM	dr.reilly.mayert.dvm@warmmail.com	Nashville	Tennessee	4483155521246	d19856bc2603b4949594331314a9b6f1	Mastercard	36.1254774897016588	-86.8654141168016878
30530	2020-06-13 02:48:59	2020-06-13	Elmer Ledner-Gorczany	elmer.ledner.gorczany@geemail.com	Chicago	Illinois	3158120092549821108	b819e80a3ec8ddf5bfa0c0bf57f1507d	JCB 15 digit	41.9099069589585085	-87.6151077926188719
30531	2020-06-13 03:03:39	2020-06-13	Dr. Esequiel Prosacco	dr.esequiel.prosacco@geemail.com	San Francisco	California	180019549974040680	ed95bf9b386dbb8b7db04ea7599cb9bf	VISA 16 digit	37.7343853213804366	-122.442827134148132
30532	2020-06-13 03:29:35	2020-06-13	Dorr Boyer	dorr.boyer@geemail.com	Roseville	California	3494253887565184	c9112c01140ca0e846df2dc6911ced9c	Diners Club / Carte Blanche	38.6979830172900066	-121.38294443327338
30533	2020-06-13 03:29:44	2020-06-13	Aniya Von	aniya.von@geemail.com	Hialeah	Florida	4847432626368	6886df2c82141122977be164aab57ce5	Diners Club / Carte Blanche	25.8237072686642435	-80.3089744075104477
30534	2020-06-13 03:42:34	2020-06-13	Mr. Demond Kessler	mr.demond.kessler@geemail.com	Oakland	California	4531190362858695	181d1f05c065702962a195633e2f0a0b	Diners Club / Carte Blanche	37.8077402914348184	-122.277309595138803
30535	2020-06-13 03:56:35	2020-06-13	Hayley Williamson	hayley.williamson@geemail.com	Lexington	Kentucky	869989288036716806	2871c39954f157ea7cdef8afcbca4b89	VISA 16 digit	38.0425775418866436	-84.3681544875625491
30536	2020-06-13 04:02:15	2020-06-13	Jerilyn Beahan	jerilyn.beahan@woohoo.com	Cleveland	Ohio	3057386086451982	4faa10814966193112a8d2dcf9b19725	VISA 13 digit	41.4859017862789301	-81.7713372847303788
30537	2020-06-13 04:09:09	2020-06-13	Ms. Tatum Wehner	ms.tatum.wehner@geemail.com	San Francisco	California	51227190369585456	9e52ead0305dae2b3f00e0bccfd8dd64	VISA 16 digit	37.7618671145949065	-122.429005670455794
30538	2020-06-13 04:13:08	2020-06-13	Salena Schuster	salena.schuster@geemail.com	Houston	Texas	4072395111556673	8601641515b51a06fd01667eb4f98c9d	VISA 16 digit	29.8078713919114335	-95.4886169228252015
30539	2020-06-13 04:22:04	2020-06-13	Jade Morar	jade.morar@warmmail.com	Fremont	California	869955435775717335	215fe2c72b72203922353ca42ceef273	VISA 16 digit	37.5013763519171661	-121.847348785213001
30540	2020-06-13 04:24:11	2020-06-13	Alex Emmerich	alex.emmerich@geemail.com	San Francisco	California	54948673547219021	8002b31cece9e36be067a468553d38c5	Maestro	37.8007078837115884	-122.447090712794775
30541	2020-06-13 04:29:06	2020-06-13	Gasper Wiegand	gasper.wiegand@geemail.com	San Francisco	California	4881196563720267	20192747f29720613250b5ada98c6541	Maestro	37.7488653052148422	-122.469113741785009
30542	2020-06-13 04:30:08	2020-06-13	Ms. Dorothy Abbott MD	ms.dorothy.abbott.md@woohoo.com	Centennial	Colorado	4671059989715929	e9d3b8d413758c05dda64b80f8a366cb	VISA 16 digit	39.5067966720596004	-104.968518876925486
30543	2020-06-13 04:33:09	2020-06-13	Maryellen Cremin-Klein	maryellen.cremin.klein@geemail.com	Hillsboro	Oregon	3057451258758323	c6e863fbcd2c7e2595c917fc0a15b8cb	VISA 16 digit	45.4574592914171518	-123.033408865441373
30544	2020-06-13 04:34:01	2020-06-13	Nicolas Price	nicolas.price@geemail.com	Oklahoma City	Oklahoma	4894260161363774	6fcae9cb4f53ab263b8c9e6faa1b8459	JCB 16 digit	35.3833305546458803	-97.4253976574063358
30545	2020-06-13 04:34:02	2020-06-13	Alfreda Runte	alfreda.runte@geemail.com	Los Angeles	California	4001312509627467	d307f65f7d01691f25a6594902faec35	Maestro	33.9541284650895747	-118.347500878525153
30546	2020-06-13 04:34:14	2020-06-13	Rollo Lemke-Robel	rollo.lemke.robel@warmmail.com	Oakland	California	4733441386466916	7b8a9a49ffa6a4eb83bbdcf4000d8724	American Express	37.7859944143405997	-122.275141478630829
30547	2020-06-13 04:38:19	2020-06-13	Archer Johns	archer.johns@woohoo.com	San Francisco	California	3337864068261123212	4754c162cd2c8d511d1b52cf2e4a3f47	JCB 15 digit	37.7542926084392647	-122.415464948360921
30548	2020-06-13 04:53:08	2020-06-13	Jonas Luettgen	jonas.luettgen@woohoo.com	Renton	Washington	4627204603128589	792c140451839c46934be71828bb08f3	Maestro	47.5251794699639092	-122.152807979572557
30549	2020-06-13 05:00:40	2020-06-13	Norma Ebert	norma.ebert@geemail.com	Tucson	Arizona	180094875211452505	9cfa3b02767c8b9c1aa8c71430c0dfe6	American Express	32.2307338618248735	-110.916991152031713
30550	2020-06-13 05:04:06	2020-06-13	Alvia Feeney	alvia.feeney@geemail.com	Thornton	Colorado	3528640159911225753	634b899515aad8a869c4b805bcfb444f	Voyager	39.9838742693286449	-104.92682990493924
30551	2020-06-13 05:08:19	2020-06-13	Randolf Johnston	randolf.johnston@geemail.com	Oakland	California	4284465453330	c5c9d1a3d6382b26730773607c989c2f	Voyager	37.7553810731006294	-122.301100043673387
30552	2020-06-13 05:49:40	2020-06-13	Von Beahan	von.beahan@warmmail.com	Miami	Florida	55421472763089325	b0939c18c7de5e6caaaf3b4c1f57f051	JCB 16 digit	25.6773857977844777	-80.2392215368677029
30553	2020-06-13 06:00:40	2020-06-13	Jessica Koelpin	jessica.koelpin@geemail.com	Louisville	Kentucky	502039697505533	9ccdc18549ab81f91525a5889bd6bf6a	Discover	38.111990580791236	-85.5822264364060032
30554	2020-06-13 06:04:50	2020-06-13	Ashlyn Ankunding-Lakin	ashlyn.ankunding.lakin@geemail.com	New York	New York	4458041892758161	5fcd6c9cced1b453db32fd57b3e79710	Mastercard	40.681084211332724	-73.9740410731069744
30555	2020-06-13 06:17:14	2020-06-13	Jami Willms	jami.willms@geemail.com	Chicago	Illinois	869960849107470830	25b5474c98d0f98bf7effb692a4efec2	JCB 16 digit	41.8564350972253862	-87.624922617993505
30556	2020-06-13 06:17:35	2020-06-13	Mr. Elisha Halvorson	mr.elisha.halvorson@geemail.com	New York	New York	4088187211975768	4f63e68de263bcd5a4766ded795b660b	VISA 16 digit	40.7550787886828161	-73.9401217444229815
30557	2020-06-13 06:26:20	2020-06-13	Dr. Huy Cartwright	dr.huy.cartwright@woohoo.com	Columbia	Missouri	54422381659129047	b4847395ac98b61d225df0dc9d3321e6	Diners Club / Carte Blanche	38.935119276062828	-92.3537524103705891
30558	2020-06-13 06:38:39	2020-06-13	Myrl Hoppe-Armstrong	myrl.hoppe.armstrong@geemail.com	San Francisco	California	54480571391224937	b7044596f25dc608bc69f47c3929f5ff	JCB 15 digit	37.779455093102726	-122.41762934194972
30559	2020-06-13 06:50:23	2020-06-13	Hilah Cartwright	hilah.cartwright@geemail.com	San Antonio	Texas	54418512299550699	eb4a177ef72057d200998051d93ab41b	VISA 16 digit	29.4324980006624024	-98.5617747691295989
30560	2020-06-13 07:15:53	2020-06-13	Seth Ernser	seth.ernser@geemail.com	Saint Paul	Minnesota	6011795701288247622	f41c1a966fb69374b009d3e021aaa552	American Express	44.943597615318005	-93.1046568181630221
30561	2020-06-13 07:33:00	2020-06-13	Miss Rebeca Nicolas PhD	miss.rebeca.nicolas.phd@geemail.com	Milwaukee	Wisconsin	4802057672678992	ff1b105181179bc81c88faee0e6ae3c3	JCB 16 digit	43.0161230475261789	-87.9568420293841484
30562	2020-06-13 07:43:58	2020-06-13	Normand Hagenes-Halvorson	normand.hagenes.halvorson@geemail.com	Berkeley	California	6011629078910562955	16be3781c948dcd3c25b448a758e73d9	VISA 13 digit	37.8795598546211068	-122.305295695502366
30563	2020-06-13 07:55:00	2020-06-13	Tennie Nader DVM	tennie.nader.dvm@warmmail.com	Athens	Georgia	3422074944049245	a33346005fa70f74cc56a9032ade25c4	Discover	34.0085569286443246	-83.3111558030009149
30564	2020-06-13 08:02:05	2020-06-13	Gus Green	gus.green@warmmail.com	New York	New York	4198493986147	b40456aecd50fc46416eac036ca5b384	Maestro	40.598190806875003	-73.9411109548889129
30565	2020-06-13 08:22:23	2020-06-13	Kiana Christiansen MD	kiana.christiansen.md@woohoo.com	San Francisco	California	3727319490369405	6643a525043492fb26a586e279043038	Mastercard	37.7833798354498143	-122.446581730457808
30566	2020-06-13 08:36:36	2020-06-13	Dr. Asbury Boyle MD	dr.asbury.boyle.md@geemail.com	El Paso	Texas	4859925434214839	4d24eb21c1ffd452f6073518ff1713ee	Voyager	31.8036993660327063	-106.501849781952799
30567	2020-06-13 08:37:38	2020-06-13	Miss Katlyn Koepp MD	miss.katlyn.koepp.md@geemail.com	Bakersfield	California	869970502538147158	4f23e2c5df7d3a5f2da5640edb59efb4	VISA 13 digit	35.3056142746180299	-119.018985828924173
30568	2020-06-13 08:46:29	2020-06-13	Mr. Hosteen Daniel Sr.	mr.hosteen.daniel.sr.@geemail.com	Lubbock	Texas	6011678144523766605	7d9a449afd4faf6a13e3e1f2aa3d8a50	VISA 16 digit	33.631451915860552	-101.952174659251057
30569	2020-06-13 08:51:55	2020-06-13	Dr. Dewitt Cartwright PhD	dr.dewitt.cartwright.phd@geemail.com	Charlotte	North Carolina	3420149126143578	8290e0be7ac15f323c23038a9d6051bb	Discover	35.2504866753492507	-80.8843010956365589
30570	2020-06-13 09:02:58	2020-06-13	Mr. Vernon Luettgen	mr.vernon.luettgen@geemail.com	Chicago	Illinois	55752091869893213	4b8aa41df1cd4ed8619f574da83c0aaa	JCB 16 digit	41.8687175988521432	-87.7187289029855179
30571	2020-06-13 09:09:43	2020-06-13	Erland Ziemann-Blanda	erland.ziemann.blanda@geemail.com	Huntington Beach	California	4492352789576006	b29865f8f788b23f33e261fa005459ab	JCB 16 digit	33.7371898698661496	-117.932004147361212
30572	2020-06-13 09:11:46	2020-06-13	Jerel Eichmann	jerel.eichmann@warmmail.com	Fullerton	California	180003926829163446	0bc02177e50bec4fbf2a76ba00f2578f	VISA 13 digit	33.8872439789742259	-117.874888313069931
30573	2020-06-13 09:35:46	2020-06-13	Keena Gutkowski	keena.gutkowski@woohoo.com	Santa Clara	California	3088858431625597786	9030c5cb01029f1a116bb80340fa1332	American Express	37.3597617472339465	-121.892603736696387
30574	2020-06-13 09:37:53	2020-06-13	Katharina Harber-Dibbert	katharina.harber.dibbert@geemail.com	Los Angeles	California	630441507603193	8fb31dad9c2b52ba5476879914e4e338	Discover	34.1117553862608958	-118.340967966661964
30575	2020-06-13 09:39:27	2020-06-13	Dorr Blick-Rippin	dorr.blick.rippin@woohoo.com	Los Angeles	California	51567036375991014	ca4b6e4a0ab27730aee2cc8581848111	Voyager	33.9783125060010676	-118.422870252094413
30576	2020-06-13 09:39:45	2020-06-13	Mallory Treutel	mallory.treutel@geemail.com	Mesquite	Texas	3088389358737509177	19d6318d40d68258da59191a68a46b60	JCB 15 digit	32.8068846566412589	-96.5896942303713502
30577	2020-06-13 09:42:28	2020-06-13	Lucio Schiller	lucio.schiller@geemail.com	Charlotte	North Carolina	3088337752986057180	22ab12b4e72b4b7a6c0414448885e120	VISA 16 digit	35.3028743881519844	-80.796326656587425
30578	2020-06-13 09:47:58	2020-06-13	Shiela Jaskolski	shiela.jaskolski@geemail.com	Phoenix	Arizona	52810398641606106	7508da75e5b27144507cc8c0219078f8	Diners Club / Carte Blanche	33.6580575994614506	-112.061323618462694
30579	2020-06-13 09:48:11	2020-06-13	Emmitt Kub	emmitt.kub@warmmail.com	San Diego	California	4177127904809	3835fc3f53f66bf2549dbb2aa9457aea	Maestro	32.9064312289536005	-117.212167426794778
30580	2020-06-13 09:51:02	2020-06-13	Anton Barton	anton.barton@woohoo.com	Phoenix	Arizona	4272685562647981	d5d5d8016b58745d9efba48f35938b12	VISA 16 digit	33.6647766860134894	-112.035283071168152
30581	2020-06-13 09:55:07	2020-06-13	Alana Kling	alana.kling@geemail.com	San Francisco	California	869910591823037037	e14e2eff41d03adb0e12caacd52f0788	Diners Club / Carte Blanche	37.7803557257896827	-122.450981775365719
30582	2020-06-13 09:55:37	2020-06-13	Lashunda Gibson-Beier	lashunda.gibson.beier@geemail.com	New York	New York	210005068113174918	5fa70ad944570cdb7d8c113a54cafea3	Mastercard	40.7292434612978269	-73.9560125331289981
30583	2020-06-13 10:01:43	2020-06-13	Miss Christian Sanford MD	miss.christian.sanford.md@geemail.com	Glendale	Arizona	869940067681267754	ca63953123941e77d0af1f0e37d870d7	VISA 16 digit	33.4415198714699571	-112.107635638516015
30584	2020-06-13 10:06:44	2020-06-13	Tollie Buckridge	tollie.buckridge@geemail.com	Los Angeles	California	6011054858336623513	41f02405dd00d3f7451445aef436b290	Discover	33.9862603309895803	-118.416733142080901
30585	2020-06-13 10:10:35	2020-06-13	Charls Champlin-Luettgen	charls.champlin.luettgen@geemail.com	Bridgeport	Connecticut	3096395442562119880	c3fbca247d1203a69228a1fec9618e3b	VISA 16 digit	41.158278799306224	-73.2526750622216696
30586	2020-06-13 10:10:56	2020-06-13	Dr. Huy Hegmann	dr.huy.hegmann@woohoo.com	Phoenix	Arizona	3026862253871781	ae2a9e139c0d85cd7e00bea44c02ce5e	VISA 16 digit	33.6661719493500939	-112.067363070968923
30587	2020-06-13 10:11:18	2020-06-13	Dequan Zulauf	dequan.zulauf@geemail.com	Chicago	Illinois	3088092985822666625	c53daacd3fdf1f30a7cfa925ccb458d2	Diners Club / Carte Blanche	41.8070510755594853	-87.6994893201656538
30588	2020-06-13 10:12:56	2020-06-13	Maddox Schinner	maddox.schinner@geemail.com	Sunnyvale	California	502009728823510	a1b2c71daa51dcd9607b338fce47c79a	Discover	37.4732637568835187	-121.976505215485773
30589	2020-06-13 10:18:47	2020-06-13	Hjalmar Fadel-Reynolds	hjalmar.fadel.reynolds@woohoo.com	Philadelphia	Pennsylvania	4830284786191	4d68a3fc0a8dd30ca1fe061bef78d38a	Maestro	39.9338174241088311	-75.0654589513681856
30590	2020-06-13 10:20:46	2020-06-13	Ms. Emeline McDermott PhD	ms.emeline.mcdermott.phd@geemail.com	Virginia Beach	Virginia	4557511278223634	bebb87f20735b4e9dbc323da8794d914	VISA 16 digit	36.7736225610319565	-76.0811626674279609
30591	2020-06-13 10:33:40	2020-06-13	Mr. Dora Rodriguez MD	mr.dora.rodriguez.md@geemail.com	San Francisco	California	502022486859584	b7ed16bd6b2de96c43df5fe3c62b91c5	American Express	37.8153204625200132	-122.443850877267849
30592	2020-06-13 10:36:21	2020-06-13	Ellyn Lehner	ellyn.lehner@geemail.com	New York	New York	6011528400156096633	d2937829986b37427b684720f84dbbba	Maestro	40.7495680262092463	-73.8860414098843847
30593	2020-06-13 10:40:54	2020-06-13	Dr. Keira Nienow DDS	dr.keira.nienow.dds@geemail.com	Tucson	Arizona	4971297869311966	9e1ed06c395e75c86e6ddb341a67f105	JCB 15 digit	32.0628532887477462	-110.784494706871357
30594	2020-06-13 10:48:21	2020-06-13	Mrs. Keila Lesch PhD	mrs.keila.lesch.phd@warmmail.com	Saint Paul	Minnesota	3449495949616226	4bfdad842068c0773973068aba8d02da	Discover	44.8984431046467307	-93.0420443148151008
30595	2020-06-13 10:48:34	2020-06-13	Keri Franecki	keri.franecki@woohoo.com	San Francisco	California	180085848817867526	417f80431a4d0581324bce0ac2f067aa	Maestro	37.8221988622064842	-122.452487720763045
30596	2020-06-13 11:03:02	2020-06-13	Mrs. Justina Maggio	mrs.justina.maggio@geemail.com	Omaha	Nebraska	6011078213280142676	adc3b6c273aad8c3fad286afa198b648	VISA 16 digit	41.2516114198282366	-95.9820777648709793
30597	2020-06-13 11:09:54	2020-06-13	Dr. Margaretta Cruickshank DVM	dr.margaretta.cruickshank.dvm@geemail.com	Eugene	Oregon	4484524883086153	f2e629f3199d08480f36efa029622af5	Voyager	44.1245923298139147	-123.16615521376842
30598	2020-06-13 11:12:51	2020-06-13	Texie Parker	texie.parker@geemail.com	Lubbock	Texas	4319579666540	9f7f3b54768f9020a9c5a2a9e7b680da	Mastercard	33.6248490818351513	-101.934257469131424
30599	2020-06-13 11:14:09	2020-06-13	Alvaro Donnelly-Fahey	alvaro.donnelly.fahey@geemail.com	Tulsa	Oklahoma	3088448595449891604	d7a99b9beb45218bda1ced94ad445fac	Voyager	36.1992703290093658	-95.865509136854854
30600	2020-06-13 11:16:16	2020-06-13	Miss Judy Olson	miss.judy.olson@woohoo.com	San Francisco	California	869963024829647415	5142a2c0fd7b38c2ae87d34d7f857298	American Express	37.764328854826708	-122.427515005689315
30601	2020-06-13 11:20:30	2020-06-13	Ethen Lebsack	ethen.lebsack@geemail.com	Philadelphia	Pennsylvania	4455341275057915	f6632eb5b52874742a40933039c8cda4	JCB 16 digit	39.9569963534787291	-75.0606291449062581
30602	2020-06-13 11:23:21	2020-06-13	Booker Orn	booker.orn@woohoo.com	New York	New York	4225233253747626	b59665ce2cf0eebb32808bde4de4581d	Discover	40.6382955626808098	-73.9292389068182558
30603	2020-06-13 11:26:44	2020-06-13	Gilda Kiehn	gilda.kiehn@geemail.com	Tacoma	Washington	3054099187979974	c17632ed8eca187eb34929d3d7119a89	VISA 16 digit	47.1913270524822224	-122.387171044782917
30604	2020-06-13 11:32:02	2020-06-13	Lavera Emmerich	lavera.emmerich@geemail.com	Hollywood	Florida	54965929875238415	f908d974e9f5c78af346ce2a2afa47ff	Diners Club / Carte Blanche	26.117441084044053	-80.2239236559536266
30605	2020-06-13 11:32:16	2020-06-13	Vance Hayes-Konopelski	vance.hayes.konopelski@woohoo.com	Memphis	Tennessee	3088638114436315807	c168bdc93358904f1dd053ee9a462a1f	Voyager	35.1831749184124192	-90.0297758897557827
30606	2020-06-13 11:33:26	2020-06-13	Hailie Kreiger DVM	hailie.kreiger.dvm@warmmail.com	Kansas City	Missouri	4799396377782039	f373c799f62d15dad762abf9a8e794e3	Discover	39.115754103457931	-94.5170097730346015
30607	2020-06-13 11:34:25	2020-06-13	Payten Donnelly	payten.donnelly@geemail.com	San Francisco	California	3010672066507605	7e5afd5f25d6e429dd266dc7805fb5e1	Mastercard	37.7438402179393151	-122.420687005886236
30608	2020-06-13 11:35:48	2020-06-13	Lucretia Kertzmann DDS	lucretia.kertzmann.dds@geemail.com	Kansas City	Missouri	3007633480179382	e4decfac7002d0407903ed0ccb03e6c7	Voyager	39.1213259600404655	-94.5827533189430909
30609	2020-06-13 11:48:08	2020-06-13	Edith Dibbert	edith.dibbert@geemail.com	New York	New York	3435748283615626	666e6a6a721431497fb0ccd3a5b911d5	JCB 15 digit	40.5951124893259276	-74.0130093083146932
30610	2020-06-13 11:53:41	2020-06-13	Dr. Dona Stoltenberg	dr.dona.stoltenberg@geemail.com	Dallas	Texas	869971131378469610	901973e68bd831fa590ec9ee7345d698	JCB 15 digit	32.8865330441195525	-96.7420366279277886
30611	2020-06-13 12:03:27	2020-06-13	Kristin Larson	kristin.larson@geemail.com	San Antonio	Texas	51869379248079160	a339f04fb5bf20607a0ddcd6eb38bea5	Discover	29.508834053489938	-98.5978116922847931
30612	2020-06-13 12:22:36	2020-06-13	Dr. Posey Pollich	dr.posey.pollich@geemail.com	Tucson	Arizona	54850294079892485	de4e3d7d9aaee0738e53b27e5e51eea7	Discover	32.1571010182186967	-110.914413281273468
30613	2020-06-13 12:24:11	2020-06-13	Dr. Miracle Beier	dr.miracle.beier@warmmail.com	Fremont	California	4347562372792	78905059db405d1a32ca3f2dcaec92fd	VISA 13 digit	37.5781984058376395	-122.033456991472093
30614	2020-06-13 12:27:50	2020-06-13	Shaneka Sipes	shaneka.sipes@geemail.com	San Francisco	California	3096627990765494955	2d03bcb27847d51d281c4fa752210e0b	Maestro	37.7678757611988445	-122.417942627651442
30615	2020-06-13 12:29:38	2020-06-13	Davie Koepp	davie.koepp@geemail.com	Lexington	Kentucky	869976836881660803	38de5db66f944a220ca3127dc792d341	VISA 13 digit	37.9903505681425315	-84.3813929162353276
30616	2020-06-13 12:33:00	2020-06-13	Dr. Edmund Gusikowski V	dr.edmund.gusikowski.v@geemail.com	New York	New York	3528275136232068973	25c87610eaed44d93d27447ccd765050	Maestro	40.7609944408517322	-73.9963982892118395
30617	2020-06-13 12:40:07	2020-06-13	Wheeler Stehr	wheeler.stehr@woohoo.com	Detroit	Michigan	55137303020550905	3ceff024dc08884d24269785530eafcc	Voyager	42.468481112124401	-83.0788140390653069
30618	2020-06-13 12:41:08	2020-06-13	Mr. Josh Larson	mr.josh.larson@geemail.com	San Francisco	California	4672793538337	9c0e1831568af13725795ce3224d51c5	Mastercard	37.8120620381679657	-122.455424350590079
30619	2020-06-13 13:01:45	2020-06-13	Johan Torphy	johan.torphy@geemail.com	Richmond	California	180016278282780059	a92ff7710668ba66dcbafb46498ccd8d	JCB 16 digit	37.9311805083837399	-122.262792358579489
30620	2020-06-13 13:09:54	2020-06-13	Dr. Dexter Runolfsdottir I	dr.dexter.runolfsdottir.i@geemail.com	San Francisco	California	54992345438314345	24fc6bdfa529b2cebea8e8034225fdab	JCB 15 digit	37.7752024476486739	-122.448604724023951
30621	2020-06-13 13:23:03	2020-06-13	Pandora Larson-Waters	pandora.larson.waters@woohoo.com	Berkeley	California	869956982938440403	d25678adc70b30cce950dd683c6c2730	VISA 16 digit	37.9020035962336621	-122.283277087884784
30622	2020-06-13 13:34:10	2020-06-13	Dock Mayert-Leuschke	dock.mayert.leuschke@geemail.com	Orlando	Florida	51586938501208386	bfa2819cff0f3b3d7947f928641f47fa	JCB 16 digit	28.3700084226936085	-81.2639508047573287
30623	2020-06-13 13:45:56	2020-06-13	Brycen Marquardt DVM	brycen.marquardt.dvm@geemail.com	San Francisco	California	3029324356061585	86f8eaeb08c1da901e26980f3983e63d	Diners Club / Carte Blanche	37.770462196587367	-122.418562862491768
30624	2020-06-13 13:54:19	2020-06-13	Aline Terry	aline.terry@warmmail.com	Inglewood	California	4231660898713898	02ade7a60e0726f5bdbeeb510b2c5272	American Express	33.9589965086676173	-118.419597441100706
30625	2020-06-13 13:56:02	2020-06-13	Dr. Velva Lang	dr.velva.lang@geemail.com	Charleston	South Carolina	4751162473258	cf374f31878b65d28c4bc0b3b1245446	JCB 16 digit	32.7844188365615921	-79.9721374371238056
30626	2020-06-13 14:04:09	2020-06-13	Payton Vandervort	payton.vandervort@geemail.com	Philadelphia	Pennsylvania	869994053737342143	dd9fd99e4c9f8d7f3ebe32725321b729	JCB 16 digit	40.0207314604386681	-75.1237324956238268
30627	2020-06-13 14:08:43	2020-06-13	Wally Volkman	wally.volkman@geemail.com	Sioux Falls	South Dakota	6011084686879776412	cd005a5884fe8123fb738aff91132268	Maestro	43.5257322388321128	-96.7536493537183873
30628	2020-06-13 14:13:27	2020-06-13	Dr. Garner Walsh	dr.garner.walsh@geemail.com	San Francisco	California	3001733457321441	97e926457ce5b7857b2bb262b172e438	Maestro	37.7783693510790783	-122.436100186129806
30629	2020-06-13 14:18:06	2020-06-13	Stephaine Kunze	stephaine.kunze@geemail.com	New Haven	Connecticut	4973744346613728	5e5ba5057817fe6fb8a9771824d7f93e	JCB 16 digit	41.3171115537166571	-72.9095188016071916
30630	2020-06-13 14:26:26	2020-06-13	Courtland Kuhic	courtland.kuhic@geemail.com	Houston	Texas	4519342470860495	1b43a21d24c66bba9927d402fbd115dc	JCB 16 digit	29.8388888757754103	-95.4573860711898732
30631	2020-06-13 14:27:09	2020-06-13	Derrell Ortiz-Veum	derrell.ortiz.veum@woohoo.com	Portland	Oregon	3043559334219484	01477483e8207166c9e5efb0b6ff0efe	VISA 13 digit	45.4888749203532896	-122.657926716236403
30632	2020-06-13 14:36:55	2020-06-13	Rafe Christiansen	rafe.christiansen@geemail.com	San Francisco	California	3012917987114066	a82fb9102c1de70250710cac55caec5c	Mastercard	37.771676966995571	-122.415155679408002
30633	2020-06-13 14:41:42	2020-06-13	Mr. Drew Miller	mr.drew.miller@geemail.com	Gresham	Oregon	3049277969294722	7b139d2f6dd26df0b1e6f3c0cedb849c	VISA 16 digit	45.4097863131623711	-122.461741848223284
30634	2020-06-13 14:43:46	2020-06-13	Lular Kutch DDS	lular.kutch.dds@geemail.com	San Francisco	California	4193638026924294	7e6cfd4757d3428a52a43309e5e05389	American Express	37.7949083903844212	-122.408566109109827
30635	2020-06-13 15:05:09	2020-06-13	Nadine Bauch	nadine.bauch@geemail.com	Atlanta	Georgia	4985031004107672	8a39de393b9a6d6f5d8e277bd6db3f9b	JCB 16 digit	33.8217171175681059	-84.3541200233202488
30636	2020-06-13 15:13:07	2020-06-13	Dalton O'Keefe	dalton.o'keefe@geemail.com	Baltimore	Maryland	3528240681524570881	95b88117b65b71023c6f3ef0e1511977	VISA 13 digit	39.2212103145662638	-76.706493561064832
30637	2020-06-13 15:17:49	2020-06-13	Janyce Wilkinson	janyce.wilkinson@geemail.com	San Diego	California	4592140110858675	5ab5a6b8eccea256cf7883665041f483	Maestro	32.8425519396618029	-117.214266046592968
30638	2020-06-13 15:22:15	2020-06-13	Amarion Luettgen DVM	amarion.luettgen.dvm@geemail.com	Nashville	Tennessee	869914429930421495	da74728c9c8e7465d679a4a6045b2337	JCB 15 digit	36.2464942074503753	-86.8586993109341705
30639	2020-06-13 15:37:14	2020-06-13	Mrs. Fabiola Connelly MD	mrs.fabiola.connelly.md@woohoo.com	El Paso	Texas	210080483642201041	11a09747bda0066c742291e910070c19	Discover	31.9460522447541386	-106.378211827620873
30640	2020-06-13 15:41:18	2020-06-13	Claiborne Cremin Jr.	claiborne.cremin.jr.@geemail.com	San Diego	California	869965519959701666	a6319553690d2c4a1997bdc05cdeb959	American Express	32.7280967509441112	-117.198939690683048
30641	2020-06-13 15:43:03	2020-06-13	Festus Willms	festus.willms@woohoo.com	Broken Arrow	Oklahoma	4839281827940	6932b05a699a290b1b87b44088ebd78e	Diners Club / Carte Blanche	36.0530256008971435	-95.8265736919306335
30642	2020-06-13 15:49:13	2020-06-13	Thornton Parker	thornton.parker@woohoo.com	Ontario	California	53243797162653891	f04bc1747d6bead68910432103c997c7	Mastercard	33.9750448927894269	-117.60967605515458
30643	2020-06-13 15:49:33	2020-06-13	Estefani Cole	estefani.cole@geemail.com	Dallas	Texas	4435246070062	201717f06ef52e5ec8fc18056a4acf9f	Voyager	32.8423454110316939	-96.8542979695331212
30644	2020-06-13 15:52:05	2020-06-13	Mrs. Phillis McLaughlin DVM	mrs.phillis.mclaughlin.dvm@geemail.com	San Francisco	California	4323133335744693	6792e41b8e627576ef25dd670cb3efbd	JCB 15 digit	37.7673805060676528	-122.435007148618539
30645	2020-06-13 15:57:32	2020-06-13	Lucas Sporer	lucas.sporer@geemail.com	Houston	Texas	869999198776030219	dc80307767b41640b55f6c0e71172336	Voyager	29.8232336744278683	-95.375139679761233
30646	2020-06-13 15:59:45	2020-06-13	Ashley Halvorson DVM	ashley.halvorson.dvm@geemail.com	Torrance	California	3054398259592453	48d8da8ac7d3060335a1aac98c27f6bc	VISA 16 digit	33.8268477525003277	-118.346310703562196
30647	2020-06-13 16:00:24	2020-06-13	Janel Watsica	janel.watsica@warmmail.com	Los Angeles	California	589309895285774	326681f8409d916044593c7ba0b77f7e	Maestro	33.972100680680569	-118.351752907921735
30648	2020-06-13 16:13:09	2020-06-13	Jodi Trantow	jodi.trantow@woohoo.com	San Francisco	California	4538234236296	12bc8c95b7a2e22675875709c7fc8d0f	American Express	37.7818155430691789	-122.434815180367295
30649	2020-06-13 16:26:09	2020-06-13	Merle Bartoletti	merle.bartoletti@warmmail.com	Phoenix	Arizona	6011379961933236685	505921fc69091d894d72232cd68b9c66	VISA 16 digit	33.5725339323680885	-112.034575562684239
30650	2020-06-13 16:30:12	2020-06-13	Dr. Clovis Hudson	dr.clovis.hudson@warmmail.com	Carlsbad	California	3337285885761958560	b89c08bcab11fbb35c10b8a945dcd708	Diners Club / Carte Blanche	33.1810387689094952	-117.232060135227812
30651	2020-06-13 16:43:07	2020-06-13	Delphine Jakubowski MD	delphine.jakubowski.md@warmmail.com	San Francisco	California	3748129893967563	181d27aae5518ff140a468cee8df3266	Maestro	37.7515345239529054	-122.440148871870207
30652	2020-06-13 16:52:50	2020-06-13	Ms. Effa Hand PhD	ms.effa.hand.phd@woohoo.com	Los Angeles	California	3766468416571719	850efb0e1fe8245f29d5eab79587cfff	Discover	33.9285242112684955	-118.326346113951132
30653	2020-06-13 17:01:28	2020-06-13	Adline Daugherty	adline.daugherty@warmmail.com	Minneapolis	Minnesota	3088011560257041616	764d9131bba62cd0b8f5fbdb09c21d5b	Voyager	44.9604657214686227	-93.2905572118043835
30654	2020-06-13 17:02:25	2020-06-13	Dr. Nelson Ryan II	dr.nelson.ryan.ii@geemail.com	Little Rock	Arkansas	3337337727955106663	fecc57f85b960a2f5769d9532ff4a3f7	American Express	34.7067905219081823	-92.3780080827291954
30655	2020-06-13 17:10:51	2020-06-13	Kennedy Monahan DVM	kennedy.monahan.dvm@woohoo.com	New York	New York	3036373545962396	272013be4aaaaf08578bf2c9601eb50a	American Express	40.6092238113041972	-74.0131135189801483
30656	2020-06-13 17:16:05	2020-06-13	Miss Mechelle Wuckert DDS	miss.mechelle.wuckert.dds@geemail.com	Plano	Texas	869925076093526656	c98f1b780dac9252f8aecf9d56749518	Discover	33.1304311098616608	-96.8454741117261335
30657	2020-06-13 17:18:02	2020-06-13	Adonis Steuber	adonis.steuber@geemail.com	Washington	District of Columbia	4623214358844409	c5360eb9dd51ac3462cc8c73692cb702	American Express	38.9693663116343316	-77.0483470147222249
30658	2020-06-13 17:25:15	2020-06-13	Madelynn Abbott-Ondricka	madelynn.abbott.ondricka@geemail.com	Indianapolis	Indiana	3088951845782673021	52780b1b84e2e8c1f8371524f1d20412	JCB 16 digit	39.8545433233965198	-86.1512383892867746
30659	2020-06-13 17:31:14	2020-06-13	Elam Emard	elam.emard@geemail.com	San Diego	California	4721254752489	800ee1d97d6d91832dd1455ac7f63047	Discover	32.7199162514947375	-117.173485325686642
30660	2020-06-13 17:33:22	2020-06-13	Marty Hane	marty.hane@geemail.com	Oakland	California	3038982088556387	305513852f977dd8652e10d19f4779ed	JCB 16 digit	37.8281507536008661	-122.290462697548307
30661	2020-06-13 17:35:12	2020-06-13	Butler Beier	butler.beier@geemail.com	Elizabeth	New Jersey	869976203151332862	8463f02a6b0df0ad407bedc03e1ee8a2	Mastercard	40.7256969007324443	-74.2698423222117157
30662	2020-06-13 17:40:40	2020-06-13	Charmaine Funk	charmaine.funk@geemail.com	Temecula	California	6011187140968824945	485573474d6d557a99c4665dc0fbb0d6	Diners Club / Carte Blanche	33.4344210389669954	-117.211808560575165
30663	2020-06-13 17:44:18	2020-06-13	Zadie Ziemann-Hoppe	zadie.ziemann.hoppe@geemail.com	San Francisco	California	3770288394385237	399619a84dec73d0ae384dc8d44080bf	Maestro	37.7399571154354661	-122.456916058617679
30664	2020-06-13 17:52:00	2020-06-13	Unique Kiehn	unique.kiehn@geemail.com	San Francisco	California	869919484156655040	1ece8ff443b338195482dfb6ff22c4a5	VISA 16 digit	37.7849187369892263	-122.410045952527184
30665	2020-06-13 17:56:24	2020-06-13	Easton Wilderman-Bradtke	easton.wilderman.bradtke@warmmail.com	Cary	North Carolina	869946780887019746	1758a07796598a9653ec4f93685f5ac9	JCB 16 digit	35.7941341710850622	-78.7318718781780404
30666	2020-06-13 17:58:01	2020-06-13	Lish Bayer	lish.bayer@geemail.com	Pomona	California	3024060442323192	6b377439d0f5f43d8cf4e5f31284abe2	Diners Club / Carte Blanche	34.0642551361154773	-117.827160498356818
30667	2020-06-13 17:58:42	2020-06-13	Zack Runolfsdottir	zack.runolfsdottir@geemail.com	Winston–Salem	North Carolina	6011208300753873334	bfe4f490a717c7dc29b76b92dc15307d	JCB 16 digit	36.0603521189883338	-80.335100767029445
30668	2020-06-13 18:27:12	2020-06-13	Mr. Terell Rodriguez	mr.terell.rodriguez@warmmail.com	San Bernardino	California	4379757595549	117cc67ac77abae0d4885ee910f44c3c	VISA 16 digit	34.1076767668858167	-117.343877016963802
30669	2020-06-13 18:40:34	2020-06-13	Byrdie Abbott	byrdie.abbott@geemail.com	San Francisco	California	3112695463248911521	8aba3d2b1b8caec4e71858c29a8b7740	JCB 16 digit	37.7369173726578282	-122.401772237227846
30670	2020-06-13 18:47:06	2020-06-13	Aleena Graham DDS	aleena.graham.dds@geemail.com	Salem	Oregon	060471097635602	1d2aeb29afd415c8ca7c5a2ca43ebe56	Maestro	44.9687643914285999	-123.08581049346067
30671	2020-06-13 19:00:46	2020-06-13	Jamey Bauch	jamey.bauch@geemail.com	Salinas	California	4078884596398036	141e0be0b630091f5b578bcc8e072c95	Discover	36.716343972249696	-121.553442174400018
30672	2020-06-13 19:12:01	2020-06-13	Mr. Ogden Bruen Jr.	mr.ogden.bruen.jr.@warmmail.com	Lakewood	New Jersey	4975665953478493	67b2011b75af0d2fae6ae96f5baf6949	VISA 16 digit	40.0424641309123501	-74.1866154748756514
30673	2020-06-13 19:19:47	2020-06-13	Burney Rutherford	burney.rutherford@geemail.com	Long Beach	California	3058146086823690	80293aafa73c52146efdcbb2cace96cb	JCB 16 digit	33.8729795973103478	-118.207468124541634
30674	2020-06-13 19:29:06	2020-06-13	Latoyia Mayer	latoyia.mayer@warmmail.com	St. Petersburg	Florida	4733540362630252	fa7531ec2648970beec64499e8bb5466	Discover	27.7901404228415352	-82.6940287779908516
30675	2020-06-13 19:31:26	2020-06-13	Guy Paucek	guy.paucek@woohoo.com	San Francisco	California	4410446167042	8b2b0018f573841543c8574365660cca	JCB 16 digit	37.7601820731440441	-122.465004712743408
30676	2020-06-13 19:33:28	2020-06-13	Valarie Halvorson-Bauch	valarie.halvorson.bauch@geemail.com	Hillsboro	Oregon	3016633702289531	3ac9cffdd498424dae50df644cff3906	JCB 16 digit	45.5345948823932574	-122.979237179380647
30677	2020-06-13 19:57:05	2020-06-13	Sharyl Gorczany	sharyl.gorczany@woohoo.com	Jacksonville	Florida	3096339310588583786	26f68f7d7e3aa226509a0e985936b526	American Express	30.4215382470801465	-81.601689560346685
30678	2020-06-13 20:02:07	2020-06-13	Miss Jeri Halvorson PhD	miss.jeri.halvorson.phd@warmmail.com	Concord	California	3003116907169289	357f8c439cdcef1feb723b8b035bf349	Voyager	37.9049593530993931	-121.940024173602836
30679	2020-06-13 20:02:40	2020-06-13	Alek Kertzmann	alek.kertzmann@geemail.com	Houston	Texas	180044095704728540	e43aa75dddcb8d81a1b66fb0a5c02c56	American Express	29.7136503736101076	-95.341058225791528
30680	2020-06-13 20:03:53	2020-06-13	Pamella Walsh	pamella.walsh@geemail.com	New York	New York	3337067314296089746	a790b025061992e7ef9f47f7cc76cc9b	Diners Club / Carte Blanche	40.5706628419216742	-73.9956504937157007
30681	2020-06-13 20:09:54	2020-06-13	Keara Barrows	keara.barrows@warmmail.com	New York	New York	869976814711141211	42c1dda94fbc69fbc7a4498025383d82	VISA 16 digit	40.7007457490768303	-74.0263943584531461
30682	2020-06-13 20:10:32	2020-06-13	Bettie Raynor-Maggio	bettie.raynor.maggio@geemail.com	Alexandria	Virginia	3337548612811911693	c09439e60f3e8f99879d333611cb26f2	JCB 16 digit	38.7989162122946212	-76.9873728062942746
30683	2020-06-13 20:11:04	2020-06-13	Cecil Heathcote	cecil.heathcote@geemail.com	Raleigh	North Carolina	6011147565766537324	1934e81a4e010cbaf0c94a1beacea10c	JCB 16 digit	35.8012425113603427	-78.7191477624170517
30684	2020-06-13 20:25:28	2020-06-13	Rory Considine	rory.considine@woohoo.com	Clarksville	Tennessee	3112731548009546791	e5a73e5afad9fec59eb474b2edca0142	Diners Club / Carte Blanche	36.4769309457983866	-87.431964234211307
30685	2020-06-13 20:27:02	2020-06-13	Luciano Doyle	luciano.doyle@warmmail.com	Fairfield	California	3337918082669493552	ea663dec7fef5bca40415b14a7af28a8	Voyager	38.2350663627620833	-122.037418981688475
30686	2020-06-13 20:31:59	2020-06-13	Mrs. Kayleen Ankunding PhD	mrs.kayleen.ankunding.phd@geemail.com	Portland	Oregon	3055960819125741	b9d6df1c59e1a7e9d88d3ef8e68bb296	Voyager	45.6156694765556594	-122.68734343117103
30687	2020-06-13 20:32:29	2020-06-13	Dr. Israel Kulas DDS	dr.israel.kulas.dds@warmmail.com	Berkeley	California	869986534811645097	7970f2f32b738d0b408d7be29747a5b8	Mastercard	37.8350733420561767	-122.269620307698261
30688	2020-06-13 20:52:32	2020-06-13	Tristin Quitzon	tristin.quitzon@woohoo.com	Abilene	Texas	4260215526235261	a8422832a1f7204d9943bb071869c44b	VISA 13 digit	32.5412510818410681	-99.7937428086478349
30689	2020-06-13 20:56:15	2020-06-13	Kelsea Fritsch DDS	kelsea.fritsch.dds@geemail.com	Edison	New Jersey	3096452532452817997	444b8e677c50c495142bfb46b5496efc	Voyager	40.4891207099389234	-74.3803621908236323
30690	2020-06-13 20:56:27	2020-06-13	Wilber Price	wilber.price@woohoo.com	Shreveport	Louisiana	3528021833776265398	5d59cb7cbf142e3e2e7c56c34473537e	JCB 16 digit	32.3864978114847091	-93.7467807753223923
30691	2020-06-13 21:09:24	2020-06-13	Dr. Helma Ullrich PhD	dr.helma.ullrich.phd@geemail.com	Chicago	Illinois	4862913948099768	715d3bd3750a71f6aa751af7989515b2	Voyager	41.9140648407697682	-87.7532213372208076
30692	2020-06-13 21:17:38	2020-06-13	Gilbert Hudson-Moen	gilbert.hudson.moen@geemail.com	Washington	District of Columbia	4945524652712	5ba162c92e1aee136b6a3243c82f86d8	Mastercard	38.8101522654093785	-77.0322956743396787
30693	2020-06-13 21:18:56	2020-06-13	Ms. Alwilda Bashirian PhD	ms.alwilda.bashirian.phd@geemail.com	Tucson	Arizona	52926697506010978	b7544e25be33f65fcbc220bea718df75	VISA 13 digit	32.1334590388037284	-110.964720769761499
30694	2020-06-13 21:20:08	2020-06-13	Mrs. Evangeline Kertzmann	mrs.evangeline.kertzmann@woohoo.com	Raleigh	North Carolina	4538003393717397	744cf12ed3e3864fa77024b40edc84a5	JCB 15 digit	35.7680235049821391	-78.6395935313712897
30695	2020-06-13 21:31:42	2020-06-13	Dr. Davis Kohler	dr.davis.kohler@woohoo.com	Clarksville	Tennessee	4778765851336196	b581412c135c8476f73b0d4d9e1efeab	Mastercard	36.6502545684237049	-87.4207281386896966
30696	2020-06-13 21:35:43	2020-06-13	Jaquez Bosco	jaquez.bosco@geemail.com	New York	New York	52211911488481055	d4c981ad9d759f833c2a8e55c5a3a18d	Mastercard	40.6040828949995358	-73.9369691745273769
30697	2020-06-13 21:39:42	2020-06-13	Winfred Cassin	winfred.cassin@geemail.com	Berkeley	California	869993303500060443	35b8cfc5d0db94aa0cdfa32e8d38e3ba	Discover	37.8452694053118535	-122.245088305576019
30698	2020-06-13 21:47:05	2020-06-13	Nolie Beer	nolie.beer@geemail.com	Anaheim	California	180071940170877808	fdf6bb7f8ce3c746d1135f35c18c46d4	American Express	33.8595991247631574	-117.705158614946896
30699	2020-06-13 22:10:02	2020-06-13	Mr. Khalid VonRueden	mr.khalid.vonrueden@geemail.com	Austin	Texas	4710094427014430	1c7482788ef82b6278b4eee5dac49154	JCB 16 digit	30.3824824437160039	-97.771886747307704
30700	2020-06-13 22:16:05	2020-06-13	Isabella Kshlerin	isabella.kshlerin@warmmail.com	Atlanta	Georgia	3036715129674492	7c2cf10fd61f552190edd4767a88314d	VISA 13 digit	33.8022013728782582	-84.5025850585240903
30701	2020-06-13 22:16:41	2020-06-13	Brion Gibson	brion.gibson@geemail.com	Sioux Falls	South Dakota	54816695793085110	ef5e920948f2d96674317b00f57e7e40	JCB 16 digit	43.6110466391865188	-96.6413471589032582
30702	2020-06-13 22:21:03	2020-06-13	Lorenza Johnson II	lorenza.johnson.ii@geemail.com	Columbus	Ohio	180021243996005592	398af69343f36d4b29bcef06e5eec3e9	VISA 16 digit	39.9235216827176487	-83.0331548644930137
30703	2020-06-13 22:30:32	2020-06-13	Kamari Walsh MD	kamari.walsh.md@geemail.com	San Francisco	California	180025146610202600	dc03596a6f81a0956c42ce00da3aaf9a	VISA 16 digit	37.760385986479676	-122.433525187752267
30704	2020-06-13 22:34:08	2020-06-13	Benedict Hilll-Volkman	benedict.hilll.volkman@geemail.com	Berkeley	California	210023941483676969	283dff443e48f74161631ff9a6f5efb4	American Express	37.8903794376076846	-122.246852070140733
30705	2020-06-13 23:05:34	2020-06-13	Teela Murray	teela.murray@woohoo.com	Los Angeles	California	3528571896788957058	335565fc53edc3cdb8502d62eddafb51	VISA 16 digit	34.1046065858431149	-118.436990854422746
30706	2020-06-13 23:12:13	2020-06-13	Cortney Terry	cortney.terry@geemail.com	Norfolk	Virginia	4340757198437	eb0ca81e4cec2f988fb0ff07ce317980	VISA 16 digit	36.9037003768160972	-76.247227990581095
30707	2020-06-13 23:18:19	2020-06-13	Elmyra Barrows	elmyra.barrows@geemail.com	Arlington	Texas	6011936006169271901	aba1dbeb0dba188e9c240efebe89c49c	VISA 16 digit	32.7432646232906706	-97.028145059247322
30708	2020-06-13 23:20:02	2020-06-13	Riya Bartell	riya.bartell@geemail.com	Philadelphia	Pennsylvania	3112633968197474516	315b01b8cbd734c3ce4d881cbd348015	Diners Club / Carte Blanche	39.937209207933023	-75.1636872887510918
30709	2020-06-13 23:22:43	2020-06-13	Irvin Funk	irvin.funk@geemail.com	New York	New York	180032026171438937	140aeb98135bbb1880ae54f1d53b0530	Diners Club / Carte Blanche	40.7303699312955132	-73.995716547257075
30710	2020-06-13 23:24:58	2020-06-13	Ivan Reichel-Wuckert	ivan.reichel.wuckert@woohoo.com	Sunnyvale	California	4516128713580807	54b719c6693f96b4d5697cc707f423e6	JCB 16 digit	37.2859489812508258	-122.056270345599586
30711	2020-06-13 23:30:30	2020-06-13	Greyson Gaylord-Conn	greyson.gaylord.conn@geemail.com	Spokane	Washington	869984247048547505	8fce3926592fe2c770faf86268aaa734	Voyager	47.5671078034449337	-117.518369760959601
30712	2020-06-13 23:43:16	2020-06-13	Adelina Prohaska	adelina.prohaska@geemail.com	Houston	Texas	4051175948408	5d28195dca4d61089d10b952d6b977f2	JCB 15 digit	29.7968596106939003	-95.3225603279206979
30713	2020-06-13 23:48:31	2020-06-13	Mr. Jadyn Lebsack	mr.jadyn.lebsack@geemail.com	Phoenix	Arizona	55759503503160521	f2ccbfca2405ea629a7d9886cfd419e7	VISA 16 digit	33.5511808080997369	-112.078368401753167
30714	2020-06-13 23:52:40	2020-06-13	Dr. Fuller Grant DDS	dr.fuller.grant.dds@geemail.com	Arlington	Texas	3732001849301023	f532d16af69dfbb548e69151fef62d4d	VISA 16 digit	32.7814908501941673	-97.1015018590752135
30715	2020-06-14 00:10:21	2020-06-14	Claudine Durgan-Shields	claudine.durgan.shields@geemail.com	Tampa	Florida	676248516417036	99526a940ad2556deb4c718e5b0bdc7d	VISA 16 digit	28.0667338410973528	-82.5780652074821262
30716	2020-06-14 00:13:34	2020-06-14	Mrs. Dori Kling	mrs.dori.kling@geemail.com	Toledo	Ohio	3789932625789316	01ff1ffbe3024b010aee93eaa15ea4e8	VISA 16 digit	41.585268021997436	-83.530926328325279
30717	2020-06-14 00:24:45	2020-06-14	Carroll Mante	carroll.mante@warmmail.com	Hayward	California	3088781678218059978	6f203a0875ff18928955675f4c8051e7	Diners Club / Carte Blanche	37.7041834143444916	-122.034662821355838
30718	2020-06-14 00:28:50	2020-06-14	Madden Abernathy	madden.abernathy@woohoo.com	Lubbock	Texas	3495843605149409	f62f261ea5bb30020021327ed6176270	JCB 16 digit	33.6104157899081741	-101.855182433259486
30719	2020-06-14 00:35:04	2020-06-14	Baxter Reilly	baxter.reilly@woohoo.com	Santa Ana	California	869923553787089565	e7c400116922a8e239ee70f3f14a8703	VISA 16 digit	33.7365900218591079	-117.815317692320789
30720	2020-06-14 00:40:26	2020-06-14	Villa Sawayn DDS	villa.sawayn.dds@geemail.com	Cape Coral	Florida	869998849354912001	d457d6ac914a8f366b6d5940d059c43d	JCB 15 digit	26.6510426616732019	-81.8979513776093739
30721	2020-06-14 00:43:35	2020-06-14	Annie Lang MD	annie.lang.md@geemail.com	McAllen	Texas	869994376756755576	f79fa798abeb65a7fc312f5d5846e326	VISA 13 digit	26.2501578930605177	-98.2255593982838064
30722	2020-06-14 00:46:33	2020-06-14	Oleta Smitham	oleta.smitham@geemail.com	Boston	Massachusetts	180007266654769652	b4b2389472f10e6e8bb67b13adb147af	Mastercard	42.2710545416157686	-71.0421269112218141
30723	2020-06-14 00:57:29	2020-06-14	Crista Runolfsson	crista.runolfsson@geemail.com	Philadelphia	Pennsylvania	3088795998559424852	117260c8712d7cd58313adc7f59ff90b	VISA 16 digit	40.0345549679320314	-75.1128390134211656
30724	2020-06-14 00:57:36	2020-06-14	Clemma Carroll	clemma.carroll@warmmail.com	Thousand Oaks	California	060483315258307	b394b49d5135f15b96a1311342c36a9b	JCB 16 digit	34.1216685077913127	-118.844197241254903
30725	2020-06-14 01:05:47	2020-06-14	Elwyn Russel DDS	elwyn.russel.dds@woohoo.com	Berkeley	California	3043466158094086	1b20311398fb1c8cd8410ff3886a9c27	JCB 16 digit	37.9105926204507711	-122.250810798558504
30726	2020-06-14 01:20:49	2020-06-14	Mrs. Jodi Jones MD	mrs.jodi.jones.md@warmmail.com	Vallejo	California	4896161870262067	342114ea375a5d051382f37330f53a3f	JCB 16 digit	38.0100960448008038	-122.251438262347122
30727	2020-06-14 01:25:57	2020-06-14	Gustav Cassin IV	gustav.cassin.iv@geemail.com	Las Cruces	New Mexico	6011163424508107005	728a40375471f182e5f069cfe9562219	VISA 16 digit	32.2417399431146663	-106.813251452020182
30728	2020-06-14 01:32:49	2020-06-14	Jacklyn Cummings DDS	jacklyn.cummings.dds@geemail.com	San Francisco	California	6011343205056693139	7e16efce00c3050c74e7c55881b4ad8c	Diners Club / Carte Blanche	37.7914367292364943	-122.420760632461892
30729	2020-06-14 01:36:31	2020-06-14	Miss Mabelle Abshire PhD	miss.mabelle.abshire.phd@geemail.com	Denver	Colorado	210002856122720918	063e4133200878adce0294097fcd79ed	VISA 16 digit	39.8533513976313145	-104.814062161721665
30730	2020-06-14 02:04:10	2020-06-14	Jordi Auer	jordi.auer@geemail.com	Frisco	Texas	6011827893254769770	57735b1eeb039f80e49b04e5e572d3a8	JCB 16 digit	33.1052021028004617	-96.8860609100408823
30731	2020-06-14 02:15:44	2020-06-14	Lorelai Emard	lorelai.emard@woohoo.com	Phoenix	Arizona	3744783772296751	e20fff660b1bbe2a1911f8c80b956989	Diners Club / Carte Blanche	33.5507013129934677	-111.998551709849764
30732	2020-06-14 02:15:53	2020-06-14	Caylee Nolan-Hoeger	caylee.nolan.hoeger@geemail.com	West Covina	California	4758399298085	8305ea8e31dc3ada1d91f586108c4b38	Discover	34.0810351254526509	-117.936569829525041
30733	2020-06-14 02:20:25	2020-06-14	Dr. Gurney Lindgren V	dr.gurney.lindgren.v@geemail.com	Tucson	Arizona	3792203360543077	d57462249597e1b2aa4aeba3398e07de	Maestro	32.2088986689265866	-110.869802570784827
30734	2020-06-14 02:23:42	2020-06-14	Tristian Batz	tristian.batz@geemail.com	Inglewood	California	180034787679074171	3d55dd8e12c12d49893439c955bf1abf	JCB 15 digit	33.8994729651849696	-118.307499761509902
30735	2020-06-14 02:31:43	2020-06-14	Mr. Rosevelt Dickens	mr.rosevelt.dickens@geemail.com	Baltimore	Maryland	6011150403796940751	787215860af9e03e439f351f1bed593f	JCB 16 digit	39.2328371246345284	-76.6220432134363847
30736	2020-06-14 02:34:12	2020-06-14	Bernardine Grady	bernardine.grady@woohoo.com	Houston	Texas	6011894652640614423	2e9535b2d8c0d19f27f5cf259cdefc45	Voyager	29.8640682374671087	-95.4599787649247844
30737	2020-06-14 02:41:59	2020-06-14	Barton Runolfsdottir	barton.runolfsdottir@geemail.com	Dallas	Texas	561299491240588	dc306d986ae672620e14211ff2b8082f	VISA 13 digit	32.712763508995252	-96.6781716443560981
30738	2020-06-14 02:50:02	2020-06-14	Donnie Shields DDS	donnie.shields.dds@woohoo.com	San Francisco	California	210079656042035621	4f8599449f063daff54a4bad53979b92	Mastercard	37.7607592793811833	-122.438875489016041
30739	2020-06-14 03:02:12	2020-06-14	Dr. Prudence Gutkowski DVM	dr.prudence.gutkowski.dvm@geemail.com	Boston	Massachusetts	210010239696519778	c3af900077c8f1254f1200652c2c97f8	JCB 16 digit	42.4158497806806096	-71.0637737329069523
30740	2020-06-14 03:04:40	2020-06-14	Mrs. Orilla Koepp	mrs.orilla.koepp@geemail.com	Mesa	Arizona	3528097076771652652	b2f38ac186da72f3037e1be7f5484a50	Maestro	33.3579332036111467	-111.790308171825103
30741	2020-06-14 03:09:38	2020-06-14	Dr. Ambrose Weber	dr.ambrose.weber@geemail.com	San Francisco	California	3337698753583078390	a104bf7e29f144a486fdfec9f75db2e2	JCB 16 digit	37.7704436487934814	-122.433559206270289
30742	2020-06-14 03:25:42	2020-06-14	Dr. Christal Sawayn MD	dr.christal.sawayn.md@geemail.com	Phoenix	Arizona	589346133144991	432cccf667a65fa94a81fbf5c18d866f	VISA 13 digit	33.5610899974990673	-112.020448332971341
30743	2020-06-14 03:30:00	2020-06-14	Ms. Vennie O'Connell	ms.vennie.o'connell@geemail.com	San Francisco	California	210025304136130751	f1d9887da7c44cc2433f79b2ce02fba7	VISA 16 digit	37.7918298898869978	-122.423807072819002
30744	2020-06-14 03:51:09	2020-06-14	Leisha Pacocha	leisha.pacocha@woohoo.com	Irvine	California	3049067147181325	f97c7503e93dcef19b87b851a129a45f	Voyager	33.6558067681748483	-117.715309009934955
30745	2020-06-14 03:54:51	2020-06-14	Ms. Valerie Strosin DDS	ms.valerie.strosin.dds@geemail.com	Boston	Massachusetts	4719580404874	5e478c1bb4ff7ffddcb80bbbd321e2b6	Diners Club / Carte Blanche	42.2379004457201788	-71.1062857927706062
30746	2020-06-14 04:02:04	2020-06-14	Willie Tremblay-Emmerich	willie.tremblay.emmerich@woohoo.com	Phoenix	Arizona	3158568658151228631	c3405c7b661a3bbe1af9ae61f6cc6b81	JCB 16 digit	33.5971569699168242	-112.186405721160028
30747	2020-06-14 04:03:19	2020-06-14	Paxton Von	paxton.von@geemail.com	Washington	District of Columbia	3112584948482901182	9b38820c74a8305b78c2263bd4796436	American Express	38.8938830663248893	-77.049236987552419
30748	2020-06-14 04:03:37	2020-06-14	Jarrod Keeling-Schowalter	jarrod.keeling.schowalter@warmmail.com	Rockford	Illinois	180052077795562623	6b4c17bc08294b5443d9687b75b34a24	VISA 16 digit	42.1870696119509674	-89.0491018607564229
30749	2020-06-14 04:35:51	2020-06-14	Raheem Heathcote	raheem.heathcote@geemail.com	Cary	North Carolina	4516374889138018	dac661ebdb5658326fd3bc07bbccb89f	Discover	35.805132662701979	-78.7893083163157115
30750	2020-06-14 04:35:51	2020-06-14	Buck Daniel	buck.daniel@woohoo.com	San Francisco	California	54759908586448612	2adfe393b2efbe69d577bfaec44b594b	VISA 16 digit	37.774917180463973	-122.453323074302503
30751	2020-06-14 04:45:58	2020-06-14	Mr. Aric Leffler	mr.aric.leffler@woohoo.com	San Francisco	California	4288569840532	bd30e1346f6819dea5bc8f3b01d5e939	VISA 16 digit	37.7851519298685545	-122.460578245293931
30752	2020-06-14 04:52:32	2020-06-14	Reinaldo Shanahan	reinaldo.shanahan@geemail.com	Kansas City	Missouri	210083131056737110	d3aa7011d24595f5ef9487c066f99232	VISA 13 digit	39.0708376082893523	-94.6325311781130694
30753	2020-06-14 04:53:15	2020-06-14	Aaden Predovic	aaden.predovic@geemail.com	Anaheim	California	3748417717833313	db5fc4e9f59afc648ba51ded231a46ac	Diners Club / Carte Blanche	33.7617156959436855	-117.815006714055684
30754	2020-06-14 04:53:34	2020-06-14	Verona Hagenes	verona.hagenes@geemail.com	Chattanooga	Tennessee	51081131430668843	9e5194ed7782e4f07c8523d8c8266af4	VISA 16 digit	35.0987288311440508	-85.2816805316895312
30755	2020-06-14 04:54:24	2020-06-14	Ramsey Green II	ramsey.green.ii@geemail.com	Peoria	Illinois	869940160037936642	273b3b105184ffc1031f5715a13d3430	VISA 16 digit	40.8440516873598085	-89.5287509901799297
30756	2020-06-14 05:09:53	2020-06-14	Miranda Ankunding PhD	miranda.ankunding.phd@woohoo.com	Fort Worth	Texas	3478983967912472	e32699106ed07944ccfbc826bfeb0560	Diners Club / Carte Blanche	32.799748677439986	-97.3384962410487162
30757	2020-06-14 05:16:46	2020-06-14	Dr. Hedwig Smith	dr.hedwig.smith@geemail.com	Virginia Beach	Virginia	3727419208478199	27703e02ce3339dd3277eccef67aa2df	VISA 16 digit	36.8206887954566611	-76.1177003280397457
30758	2020-06-14 05:17:40	2020-06-14	Tayshaun Sauer	tayshaun.sauer@woohoo.com	Dallas	Texas	52624512519968101	af4e34b786412f346a8db09f7154b0bf	JCB 16 digit	32.8388101022031194	-96.8558215312622366
30759	2020-06-14 05:29:02	2020-06-14	Gladis Spencer	gladis.spencer@geemail.com	Portland	Oregon	3337789248848673580	922b9cc67dcb4fedc5648f7f9fca8b3e	Maestro	45.5034644788019378	-122.581393380230296
30760	2020-06-14 05:30:34	2020-06-14	Elden Ratke	elden.ratke@geemail.com	Athens	Georgia	3337293021669047104	c4a27e19e8d1fcd39d166b0ef01a8279	VISA 16 digit	33.8675279676638539	-83.4599231922648812
30761	2020-06-14 05:44:24	2020-06-14	Annabelle Kiehn	annabelle.kiehn@woohoo.com	Austin	Texas	3449560725014464	fc64bdda29081f8fbf1ec4b4d2498097	Diners Club / Carte Blanche	30.3753135833084578	-97.6935912217717686
30762	2020-06-14 05:48:43	2020-06-14	Ewell Waters	ewell.waters@geemail.com	San Francisco	California	630468115512326	32eee051a1a864ebd986a81e7a284e21	VISA 13 digit	37.8018535063933285	-122.42594238226809
30763	2020-06-14 06:01:13	2020-06-14	Lessie Schiller	lessie.schiller@geemail.com	Springfield	Missouri	3158626931524041530	f9103e5914e667ea624e4de45d3876c4	Mastercard	37.223020301173257	-93.2982509894587224
30764	2020-06-14 06:13:39	2020-06-14	Easter Hessel-Ernser	easter.hessel.ernser@geemail.com	Los Angeles	California	630493085577190	7c9da31706a924a3ced0d9dbc2a4720e	Diners Club / Carte Blanche	34.0808936277270291	-118.460185255947707
30765	2020-06-14 06:15:24	2020-06-14	Maryanne Sauer	maryanne.sauer@geemail.com	Evansville	Indiana	3337527860163638654	9479658fa827204fb781b3e8e13c97cc	VISA 16 digit	38.0010766056969729	-87.5085658885471531
30766	2020-06-14 06:24:37	2020-06-14	Cleora Johnston	cleora.johnston@geemail.com	San Francisco	California	3043398218463045	7b449a172e8c21a65fca4fcc09dfbd32	JCB 16 digit	37.7978980545600152	-122.463667037557087
30767	2020-06-14 06:38:16	2020-06-14	Zola Flatley MD	zola.flatley.md@warmmail.com	Santa Rosa	California	4827784544693542	0ed262735c8d4a1c9e0403106050bb23	JCB 15 digit	38.3930670910637843	-122.750326490752784
30768	2020-06-14 06:39:20	2020-06-14	Luther VonRueden	luther.vonrueden@woohoo.com	Clarksville	Tennessee	3031820887897056	3e5ac0edbf7a641ab90ee41681e67e82	VISA 16 digit	36.5626160024791957	-87.245462466166174
30769	2020-06-14 06:49:31	2020-06-14	Kaeden Bashirian	kaeden.bashirian@geemail.com	San Francisco	California	869904480776904591	28b524bf6d96c77d740b3ec33d98c034	Voyager	37.713902469758402	-122.432596261409913
30770	2020-06-14 06:50:01	2020-06-14	Tarsha Gutkowski-Maggio	tarsha.gutkowski.maggio@geemail.com	Oakland	California	4189088144855309	423c03d94468308c2fe97f3c3ee89072	JCB 16 digit	37.8041175024809561	-122.281366263048866
30771	2020-06-14 06:50:15	2020-06-14	Chris Wisozk	chris.wisozk@geemail.com	San Francisco	California	676152064058325	4a776dfe80d92ac1a99b6babd05c4607	Diners Club / Carte Blanche	37.7954835666688851	-122.427305585567581
30772	2020-06-14 06:52:48	2020-06-14	Refugio Macejkovic	refugio.macejkovic@geemail.com	San Francisco	California	4301019611193646	c8f2a00a51e80c8ffd6cfb90a1e1ae4b	JCB 15 digit	37.7840807475013918	-122.467847615367461
30773	2020-06-14 06:57:00	2020-06-14	Mr. Finn Greenfelder III	mr.finn.greenfelder.iii@geemail.com	San Francisco	California	4973629541995923	8022d3590a0d4b400a5de19b655fedb2	VISA 16 digit	37.7704102388201122	-122.430132243530025
30774	2020-06-14 07:07:38	2020-06-14	Dr. Alonso Lind	dr.alonso.lind@geemail.com	Aurora	Illinois	3058371974890847	4c902661fe35ad77fa1a166e7afa17a6	JCB 16 digit	41.7984268991500159	-88.2609121235016687
30775	2020-06-14 07:21:38	2020-06-14	Miss Reina Hessel PhD	miss.reina.hessel.phd@geemail.com	Garden Grove	California	51039674065620640	03fa3b09abc8485642083440d68927f9	Discover	33.7242392018727912	-117.996392411507657
30776	2020-06-14 07:22:30	2020-06-14	Margeret Goldner	margeret.goldner@woohoo.com	Los Angeles	California	3728595022074857	609dcff5a0c4f44ec35318f3566f550b	VISA 16 digit	34.0404486243478956	-118.436942326602704
30777	2020-06-14 07:34:23	2020-06-14	Kaley Paucek-Dare	kaley.paucek.dare@woohoo.com	San Francisco	California	4964119834025464	7b2dfa97de0bbb4c5601960e94bf0828	JCB 15 digit	37.7664814863894094	-122.444417841246647
30778	2020-06-14 07:35:29	2020-06-14	Willia Feest-Hodkiewicz	willia.feest.hodkiewicz@geemail.com	Dallas	Texas	3096650826561713794	a5dccb4d7de5bfd4af2a19c6c475c157	VISA 13 digit	32.8472359568152612	-96.8654000869914853
30779	2020-06-14 07:36:07	2020-06-14	Daryn Schneider II	daryn.schneider.ii@geemail.com	Houston	Texas	3013658330433774	62050216fde8cb7da09d58fe03dc021d	JCB 15 digit	29.8167041570026434	-95.3448911715313869
30780	2020-06-14 07:39:07	2020-06-14	Dr. Estill Russel	dr.estill.russel@geemail.com	Arvada	Colorado	3337115831391103371	aa0c3a218a97ae89f333ca3e641f2ee1	VISA 13 digit	39.7517714577902126	-105.181726313193522
30781	2020-06-14 07:40:02	2020-06-14	Arminta Sanford-Nienow	arminta.sanford.nienow@warmmail.com	Stockton	California	630414200954817	8b7042d1db07f74b01dbb5a1b6a02dd8	VISA 13 digit	37.8806554440606433	-121.34636077304296
30782	2020-06-14 07:43:07	2020-06-14	Woody Walter V	woody.walter.v@warmmail.com	Corpus Christi	Texas	180035404837681843	ae2c4c525809bc044bf427a638dc4cc9	JCB 16 digit	27.7697491030145436	-97.2528759310316246
30783	2020-06-14 07:44:39	2020-06-14	Mr. Buford Miller	mr.buford.miller@warmmail.com	Rockford	Illinois	210067475671146136	5207f536bbc464151375f56fa0d5c0ef	VISA 13 digit	42.2195678682077684	-89.0996263296160862
30784	2020-06-14 07:59:21	2020-06-14	Laddie Kassulke	laddie.kassulke@geemail.com	Philadelphia	Pennsylvania	53882993938114336	ce422fb632969b65a4f31ee64f69afd8	Mastercard	40.075441480004784	-75.1789225988920862
30785	2020-06-14 08:02:24	2020-06-14	Verona Treutel	verona.treutel@geemail.com	San Francisco	California	676383849369851	b625742f758c76209ca714af57ebb723	VISA 13 digit	37.8099773560592709	-122.415957989899837
30786	2020-06-14 08:06:24	2020-06-14	Abbie Marks DDS	abbie.marks.dds@geemail.com	Raleigh	North Carolina	4335561082219426	4619325000befabc0e3c944771129625	JCB 15 digit	35.8012540913321047	-78.545025270332772
30787	2020-06-14 08:17:23	2020-06-14	Maci Runolfsson	maci.runolfsson@geemail.com	Las Vegas	Nevada	4969194473860	71774eef958a53407a88cb350b29bca3	Voyager	36.2926784345515046	-115.279829137746617
30788	2020-06-14 08:26:27	2020-06-14	Jacqulyn Koss MD	jacqulyn.koss.md@woohoo.com	Louisville	Kentucky	4698772808841390	adf1dfc9472770037ac543b24e290a6e	VISA 16 digit	38.1935004571821537	-85.5725785262022214
30789	2020-06-14 08:36:56	2020-06-14	Krista Greenholt DVM	krista.greenholt.dvm@geemail.com	Athens	Georgia	4330218442700901	b944494477462e9273e0e70dd8e1c0fd	Maestro	33.97566872627511	-83.3004148146252987
30790	2020-06-14 08:39:49	2020-06-14	Konnor Harber-Armstrong	konnor.harber.armstrong@warmmail.com	Los Angeles	California	4149488770450798	d512ac05b8de4074a2e9786b2efc8026	American Express	34.0829554524604177	-118.355950875858952
30791	2020-06-14 08:43:39	2020-06-14	Jasen Donnelly	jasen.donnelly@geemail.com	Oakland	California	3337875424073817748	3f2916df72ee375af43b30adcaf6bfef	JCB 16 digit	37.8296289618381181	-122.274020989323873
30792	2020-06-14 08:44:47	2020-06-14	Stafford Bayer IV	stafford.bayer.iv@geemail.com	San Antonio	Texas	869912445890536751	819a5f0d35074e642dda8198bff1cf13	JCB 15 digit	29.5132415497746337	-98.5101100026000296
30793	2020-06-14 08:44:58	2020-06-14	Madeleine Kub-Marks	madeleine.kub.marks@geemail.com	Columbus	Georgia	52222094677507704	03f34082b3f89db168d3454f3c7064bd	JCB 16 digit	32.5538976458877301	-84.923316858492413
30794	2020-06-14 08:45:14	2020-06-14	Dr. Yasmine Buckridge DDS	dr.yasmine.buckridge.dds@warmmail.com	Chicago	Illinois	589379243294257	65f80f408b1287e5961e483dc6bf6353	Maestro	41.7560613933786797	-87.6883709800459457
30795	2020-06-14 09:06:28	2020-06-14	Giles Bartoletti	giles.bartoletti@geemail.com	New York	New York	52184980364761073	9e9ebb6a3a1d3703019cd7820f059714	VISA 16 digit	40.710336352488028	-73.8598881834082306
30796	2020-06-14 09:08:51	2020-06-14	Jarett Mann	jarett.mann@geemail.com	Renton	Washington	6011872288892521077	cb3476680900db22065f89c6b0c3704c	VISA 16 digit	47.4254273221887672	-122.25980000445432
30797	2020-06-14 09:14:54	2020-06-14	Carsen Erdman	carsen.erdman@geemail.com	Visalia	California	3443069061179051	9e800436013597f5b1fb580aa6b69066	Maestro	36.2888118990186612	-119.313105073397608
30798	2020-06-14 09:17:43	2020-06-14	Rosey Dicki	rosey.dicki@geemail.com	Houston	Texas	4829976278913	e02f65080aea7a94222968e5c319c159	American Express	29.7569558097593472	-95.4720118719633746
30799	2020-06-14 09:32:15	2020-06-14	Mr. Sheridan Legros	mr.sheridan.legros@geemail.com	Norman	Oklahoma	4239351237164223	328bcf603f32ae6906f29a84d43899c8	American Express	35.2018133727408937	-97.3688579323954855
30800	2020-06-14 09:33:15	2020-06-14	Kristine Predovic PhD	kristine.predovic.phd@geemail.com	Woodbridge	New Jersey	869900293434051786	f5f9184b01721aa308eb417fd956bf6f	JCB 16 digit	40.4686749946016775	-74.2887506117902632
30801	2020-06-14 09:39:38	2020-06-14	Gaston Stamm	gaston.stamm@geemail.com	Akron	Ohio	3051770252705394	253372f5b22b1a28e2403afc47c7f43e	Diners Club / Carte Blanche	41.1451447396371535	-81.5171253344357041
30802	2020-06-14 09:41:06	2020-06-14	Nallely Orn DDS	nallely.orn.dds@warmmail.com	Salem	Oregon	3798053137885903	0bed4e696b8be30c05426720fa0d6884	VISA 16 digit	44.9625497598934913	-123.111599876793846
30803	2020-06-14 10:04:36	2020-06-14	Sanaa Kuhic	sanaa.kuhic@geemail.com	New York	New York	3088268077321801107	c7e102225bcdae1374d00c0e88258801	Maestro	40.573128999093548	-73.8487995244458233
30804	2020-06-14 10:11:44	2020-06-14	Shaniece Grady	shaniece.grady@geemail.com	Charlotte	North Carolina	869975040015078906	81dcbd8a5a13ba7947b6776811605be3	Mastercard	35.2486971659373509	-80.8231662060543954
30805	2020-06-14 10:11:54	2020-06-14	Mr. Barnie Brekke	mr.barnie.brekke@geemail.com	Hialeah	Florida	4873448715676503	b769e909aad6cd641f88521089f06c8d	Mastercard	25.9465074030660112	-80.3387608656562833
30806	2020-06-14 10:15:38	2020-06-14	Marius Bradtke	marius.bradtke@geemail.com	Boise	Idaho	4559104283151392	aac4f602969959c159dcb920701d433f	Voyager	43.5923856146771485	-116.1348498563476
30807	2020-06-14 10:20:10	2020-06-14	Mcarthur Collier	mcarthur.collier@geemail.com	Mobile	Alabama	3056278455257770	e0c875dc640b79be8c77e905cdcde2e5	VISA 13 digit	30.595108205230531	-88.0885272443898089
30808	2020-06-14 10:31:27	2020-06-14	Lorean Oberbrunner	lorean.oberbrunner@geemail.com	Tampa	Florida	675939786575660	0afb53713f28ebde96cddd14197267c8	Discover	27.8823664821799824	-82.5158566911917148
30809	2020-06-14 10:33:33	2020-06-14	Mr. Morgan Hickle	mr.morgan.hickle@woohoo.com	Jacksonville	Florida	869956647827165151	57e0ff25db842800a71f5263babceb6f	JCB 16 digit	30.404820038709417	-81.610784934794907
30810	2020-06-14 10:34:56	2020-06-14	Erastus Hermiston	erastus.hermiston@geemail.com	Chesapeake	Virginia	060437340996869	115656be5ae9c582b980617f271fe3be	VISA 16 digit	36.7690661576814932	-76.2644276260707557
30811	2020-06-14 10:35:58	2020-06-14	Nannie Kutch-Gislason	nannie.kutch.gislason@geemail.com	Chula Vista	California	6011174832117546198	3b5de0d079eed52b00cd2024df6d6d34	VISA 16 digit	32.5961732276946279	-116.940916365687542
30812	2020-06-14 10:40:55	2020-06-14	Lilian Abernathy	lilian.abernathy@woohoo.com	San Francisco	California	3158235974678689921	9485c467a8cf39b76fc3c5d6550ff368	VISA 13 digit	37.7640087958438855	-122.43906803440187
30813	2020-06-14 10:42:48	2020-06-14	Mr. Giovanni Lubowitz II	mr.giovanni.lubowitz.ii@geemail.com	Beaumont	Texas	4546981671526665	2177bd2d1b7be24ec75a46aeb2d35794	VISA 16 digit	30.0073098239559677	-94.1752756824970305
30814	2020-06-14 10:44:14	2020-06-14	Ms. Metta Lang	ms.metta.lang@geemail.com	Berkeley	California	869900858234866466	ec42ec6d95319b34486968c23dd081d0	JCB 15 digit	37.8636381447430992	-122.260935263661779
30815	2020-06-14 10:44:36	2020-06-14	Francis Cruickshank	francis.cruickshank@geemail.com	Mesquite	Texas	3528980048539170798	ba19e032b5e33753260a893895d9727b	Voyager	32.8041428212817792	-96.5070755601592367
30816	2020-06-14 11:02:09	2020-06-14	Oswaldo Olson	oswaldo.olson@geemail.com	Los Angeles	California	6011321076560187389	7bc0358c7046749ad9bdba2dafc50b1b	Mastercard	34.0412452281784255	-118.450925273726881
30817	2020-06-14 11:07:13	2020-06-14	Mrs. Sophronia Nolan	mrs.sophronia.nolan@geemail.com	Indianapolis	Indiana	210050715951066770	cfa482ea35a323bad2bf0fc985063ab9	Maestro	39.8247587330646766	-86.1042451416809058
30818	2020-06-14 11:13:29	2020-06-14	Zigmund Cruickshank-Kuhic	zigmund.cruickshank.kuhic@warmmail.com	Bridgeport	Connecticut	3528051634906505064	ad3595becdc0c9efe98c9096cf823016	VISA 16 digit	41.1109486660152612	-73.1625091535870098
30819	2020-06-14 11:14:30	2020-06-14	Marleen Koss	marleen.koss@geemail.com	Atlanta	Georgia	4267748279010	96c513f301599532c6e89d79305beaf0	Diners Club / Carte Blanche	33.7323554480724042	-84.4765669199217228
30820	2020-06-14 11:17:12	2020-06-14	Cass Fritsch V	cass.fritsch.v@geemail.com	Salinas	California	3479138990044210	4bc59914aea6dd2447097a9519c4b7f9	JCB 16 digit	36.642622295510769	-121.669423536461593
30821	2020-06-14 11:18:58	2020-06-14	Mr. Cameron Emmerich	mr.cameron.emmerich@woohoo.com	Berkeley	California	6011049607524734980	6132a7a0f05f63ab8ea84c2e75484d93	JCB 16 digit	37.9002591891648919	-122.279192334287231
30822	2020-06-14 11:22:32	2020-06-14	Jack Reilly	jack.reilly@geemail.com	Lakeland	Florida	3096787865158078050	21167b66f05bd50107af005149f6823f	Voyager	28.1474573732186109	-81.9357913231827268
30823	2020-06-14 11:31:34	2020-06-14	Lesley Pagac	lesley.pagac@woohoo.com	Anchorage	Alaska	4387927875616648	c092a8082ad8b8161f3ad815bbca6b65	Mastercard	61.1209089340392495	-149.368677015847709
30824	2020-06-14 11:33:38	2020-06-14	Carlotta Feil	carlotta.feil@geemail.com	Phoenix	Arizona	53078567181099545	abc8b11833d59c22b5715896467dbac1	American Express	33.5592403461623974	-112.094497393297416
30825	2020-06-14 11:34:11	2020-06-14	Miss Peggie Hettinger	miss.peggie.hettinger@geemail.com	San Diego	California	3528349888741683062	96a3f4bbc323d935c3cabe4ed950c33b	Maestro	32.8302533109739443	-117.201071223700424
30826	2020-06-14 11:42:16	2020-06-14	Julious Smitham-Crist	julious.smitham.crist@geemail.com	Jacksonville	Florida	54918566456134460	54950cb82166a3558b4c86e439b152ff	JCB 15 digit	30.2731248204182819	-81.7140858901742888
30827	2020-06-14 11:45:14	2020-06-14	Pascal Erdman	pascal.erdman@geemail.com	Phoenix	Arizona	6011553989943453634	718a096cefbb46332c3af3ae68b15c2e	Mastercard	33.6334373396754316	-112.176039190955834
30828	2020-06-14 11:47:22	2020-06-14	Lilliana Schmidt	lilliana.schmidt@geemail.com	San Francisco	California	52445737832176697	899ffdcce7d7545493f180fd607f05e3	JCB 16 digit	37.803709421457917	-122.434984076469149
30829	2020-06-14 11:48:07	2020-06-14	Dwayne Batz	dwayne.batz@geemail.com	Clinton	Michigan	3096848694509428278	fa90c5f83cee5400d97b27be9c538482	JCB 15 digit	42.4979159045100232	-82.9554944728109973
30830	2020-06-14 12:09:19	2020-06-14	Jewell Barrows	jewell.barrows@geemail.com	Tulsa	Oklahoma	4346761549564	cf4634e6048f1e14ca9d104df6617203	Diners Club / Carte Blanche	36.213596564707899	-95.8563248467121269
30831	2020-06-14 12:16:45	2020-06-14	Gabriel Effertz	gabriel.effertz@woohoo.com	Mobile	Alabama	869900115644323384	884bba32b70eea06bfb21ef96cca7bf4	VISA 13 digit	30.733105378282815	-88.1153401277631474
30832	2020-06-14 12:30:34	2020-06-14	Elinore Watsica	elinore.watsica@woohoo.com	New York	New York	3088861967828090173	0ff512cf8171fccc0df44e716e037c6f	American Express	40.6435501065328708	-73.8533025355439605
30833	2020-06-14 12:33:44	2020-06-14	Webster Conn	webster.conn@geemail.com	Detroit	Michigan	51914094045323373	d00c71792a65413ae9c953ffd98897ba	American Express	42.2840202528443214	-83.0455565607760064
30834	2020-06-14 12:34:41	2020-06-14	Kayley Pfeffer	kayley.pfeffer@warmmail.com	Reno	Nevada	676223695400251	9a1e978748277c5ccf76111f7562144f	Mastercard	39.5648005076762317	-119.896387598959365
30835	2020-06-14 12:36:34	2020-06-14	Trina Hermiston	trina.hermiston@geemail.com	San Francisco	California	3112043604540103478	62f53489bac52ddfc290a140fb40c5e9	VISA 16 digit	37.7510048008606702	-122.450944302476074
30836	2020-06-14 12:36:39	2020-06-14	Kipp Wyman	kipp.wyman@geemail.com	Aurora	Illinois	3004627488514627	37f902438555b991525626a67acafd17	VISA 16 digit	41.7731404211595674	-88.2848331478819262
30837	2020-06-14 12:45:39	2020-06-14	Brea Kuphal	brea.kuphal@geemail.com	New York	New York	3058149797919435	0be3dee6b8d4ba17acf0884924283392	American Express	40.6094328610450006	-73.9843560522317887
30838	2020-06-14 12:48:07	2020-06-14	Vesta Kohler	vesta.kohler@geemail.com	Denver	Colorado	52117320453587182	7872fe2a472964439d3d7e48b7752a1e	JCB 15 digit	39.6745004126854184	-104.865119034542147
30880	2020-06-14 17:36:27	2020-06-14	Oswaldo Kuphal	oswaldo.kuphal@geemail.com	New York	New York	3112484108753312020	7a7e552bcc5d3e1e868e06a848c55626	Discover	40.6743711523003881	-73.8865497661650181
30839	2020-06-14 12:50:37	2020-06-14	Mr. Benedict Hodkiewicz	mr.benedict.hodkiewicz@geemail.com	Oakland	California	3736839911434040	730e18abe41931c9de241a47b15dd5c4	VISA 13 digit	37.814375664345512	-122.250324101243805
30840	2020-06-14 12:56:44	2020-06-14	Caitlynn Jones	caitlynn.jones@warmmail.com	San Diego	California	3528701701528610384	a7be5e8b52efaebb9a7de5f68b1f0914	Diners Club / Carte Blanche	32.8902062329065075	-117.066111408071592
30841	2020-06-14 13:14:20	2020-06-14	Miss Inga Feest	miss.inga.feest@geemail.com	Milwaukee	Wisconsin	4193039286961	002fbfa70266473b6f00e3e6245536f7	JCB 16 digit	43.1629377345640179	-87.9234886951845169
30842	2020-06-14 13:17:38	2020-06-14	Dr. Ernestina Morar PhD	dr.ernestina.morar.phd@geemail.com	Colorado Springs	Colorado	180013291125073700	fb750de1edc250b5bf39935facc54f65	Mastercard	38.8942362825434671	-104.805301816963407
30843	2020-06-14 13:30:33	2020-06-14	Demario McClure PhD	demario.mcclure.phd@woohoo.com	Mesa	Arizona	676314436484308	afc3f47f7c8da9188cf443d2fca7a8e7	Diners Club / Carte Blanche	33.3078161295648627	-111.714753149391711
30844	2020-06-14 13:35:30	2020-06-14	Francina Ratke	francina.ratke@geemail.com	Simi Valley	California	4322536325358	17df2960c5d3ea5084401aa4cce306ab	Voyager	34.2727254541829254	-118.789129542758701
30845	2020-06-14 13:45:24	2020-06-14	Bert Hintz	bert.hintz@geemail.com	Minneapolis	Minnesota	210014953959307947	b96807bd8c0893176da996d118a67bb7	Diners Club / Carte Blanche	44.9167321276005325	-93.1733682913046266
30846	2020-06-14 13:48:04	2020-06-14	Meghann Roob DVM	meghann.roob.dvm@geemail.com	Port St. Lucie	Florida	4876202699417849	a8ea30a6ea225557c8e572b2334ba68f	Discover	27.3064116858545702	-80.298255172613267
30847	2020-06-14 13:48:39	2020-06-14	Dr. Nevin Borer III	dr.nevin.borer.iii@geemail.com	Santa Ana	California	6011202476012321046	6115f532e7c204e71bc3413ad2e5fb5f	American Express	33.7928887599252192	-117.828420950371765
30848	2020-06-14 13:55:13	2020-06-14	Mr. Ben Fay DVM	mr.ben.fay.dvm@geemail.com	El Paso	Texas	210012462473061057	355f7a05285c366e198874d1cb59013c	Voyager	31.7894205394495302	-106.506230134608231
30849	2020-06-14 13:57:48	2020-06-14	Mrs. Alene Gibson PhD	mrs.alene.gibson.phd@geemail.com	New York	New York	180060792868673913	8f861f553e21c87836ca57eeb623ae62	American Express	40.6520095750912986	-73.9100250902946954
30850	2020-06-14 14:09:08	2020-06-14	Grisel Daniel	grisel.daniel@woohoo.com	Tampa	Florida	4666938282029780	4b4af7d8dc89c1dd089620df5c8d5886	Maestro	28.0689562154117951	-82.5332974599886597
30851	2020-06-14 14:23:28	2020-06-14	Miss Velma Cummings PhD	miss.velma.cummings.phd@woohoo.com	Irvine	California	3720695009458582	55c61cfe900549e47c2f832b89820d5f	Maestro	33.6725792685072918	-117.870343110199272
30852	2020-06-14 14:30:33	2020-06-14	Herbert Cummings-Bosco	herbert.cummings.bosco@geemail.com	Lakewood	Colorado	55606085205829848	bc93788b6327d0ce0363a6730202da8b	Voyager	39.7249296616237615	-105.12023436054811
30853	2020-06-14 14:35:36	2020-06-14	Roma Konopelski	roma.konopelski@geemail.com	Washington	District of Columbia	3769990975990839	c1d2e8902cabbb3e55d1e81652409a72	JCB 16 digit	38.8736054734125744	-77.0141859265256699
30854	2020-06-14 14:36:24	2020-06-14	Dr. Artis Gerhold	dr.artis.gerhold@woohoo.com	Milwaukee	Wisconsin	6011545682224949468	eefcc9e66bc0a605f3e598e36fdc31f3	Maestro	42.9744113148275773	-88.0251148372057912
30855	2020-06-14 14:41:37	2020-06-14	Brittnie Macejkovic	brittnie.macejkovic@geemail.com	San Francisco	California	3054850022623312	1f47007538644661bf0dd182bf677f35	JCB 15 digit	37.7735777164388651	-122.459409528458707
30856	2020-06-14 14:56:50	2020-06-14	Mrs. Modena Von PhD	mrs.modena.von.phd@geemail.com	Durham	North Carolina	3088022063076293192	59a77f8b5ac2c4386754f01d8a838204	JCB 16 digit	35.9372681312508888	-78.845202239499983
30857	2020-06-14 15:17:10	2020-06-14	Eloisa Pagac	eloisa.pagac@warmmail.com	New York	New York	3045392088424359	f823fa168d7ff4e8ea15b01d0c77736e	VISA 16 digit	40.7149209653716539	-73.8853843074187608
30858	2020-06-14 15:18:54	2020-06-14	Ferdinand Feest	ferdinand.feest@geemail.com	Fremont	California	589314651911241	4defacce1953bf3279b9b9eb75be655f	Voyager	37.4412374420259155	-122.027929162326075
30859	2020-06-14 15:20:31	2020-06-14	Dustin Fritsch	dustin.fritsch@geemail.com	Memphis	Tennessee	4301270023593	990861fa980b4ff5a46a788ac0928ee5	VISA 13 digit	35.0904337139401576	-90.0199388878211408
30860	2020-06-14 15:24:49	2020-06-14	Jayce Koepp	jayce.koepp@geemail.com	Bakersfield	California	6011554003581606310	c3b835e9668e6ed55701b081a3ca7c02	Mastercard	35.2406153915625069	-119.102835457333541
30861	2020-06-14 15:29:55	2020-06-14	Juston Mraz	juston.mraz@geemail.com	Mesa	Arizona	869985712890439282	2f331b9ad1cfa685570ee662dd135c75	American Express	33.4902654917124636	-111.776901891676332
30862	2020-06-14 15:36:49	2020-06-14	Seaborn West MD	seaborn.west.md@warmmail.com	Modesto	California	676157918153727	836789380cb9ee858d27981bff6565f3	VISA 13 digit	37.5657513822428939	-121.037483723063019
30863	2020-06-14 15:39:07	2020-06-14	Ethelbert Prohaska MD	ethelbert.prohaska.md@warmmail.com	Oakland	California	3030996299770585	97cd16953e41b2b14041cd0c5eccb878	VISA 13 digit	37.8205081475851017	-122.252891833040422
30864	2020-06-14 15:51:11	2020-06-14	Loreen Hills	loreen.hills@geemail.com	San Francisco	California	3088202835789984171	4163ab515459ebbb9c257febbb6946c7	Maestro	37.7535854342796924	-122.413474650051938
30865	2020-06-14 15:57:06	2020-06-14	Barney Dibbert-Leuschke	barney.dibbert.leuschke@geemail.com	Milwaukee	Wisconsin	6011696516147425346	f3784b7000fd0ba627c5aea04a12c96a	Maestro	43.0689897178757946	-88.0085196634855151
30866	2020-06-14 16:01:17	2020-06-14	Lesley Hilpert	lesley.hilpert@geemail.com	Philadelphia	Pennsylvania	4154821009714	44f64001484a579ce5f8458492f00b3e	JCB 16 digit	39.9135954161133597	-75.1927902608543661
30867	2020-06-14 16:08:32	2020-06-14	Irl Hudson Sr.	irl.hudson.sr.@warmmail.com	Houston	Texas	53176044170170811	f53797e6e6f6eb0e4305cf2d75975186	JCB 15 digit	29.7922910368613891	-95.3847972381874882
30868	2020-06-14 16:09:38	2020-06-14	Nita Ernser	nita.ernser@geemail.com	Berkeley	California	4481876729320375	565106a7c074d81c363721cbd3816ea7	VISA 16 digit	37.8759782112837371	-122.292204944538753
30869	2020-06-14 16:13:31	2020-06-14	Aedan Kling-Larkin	aedan.kling.larkin@woohoo.com	Albuquerque	New Mexico	54414651217335900	014a5ca6d9b305012b0b3df57d927ef6	Mastercard	35.1706703734252599	-106.600020472852151
30870	2020-06-14 16:14:08	2020-06-14	Michial Anderson Sr.	michial.anderson.sr.@geemail.com	Raleigh	North Carolina	869900326007812240	ed378e35a0d3e3d8a1338ba39519670b	Maestro	35.7854711006529627	-78.7402971160534833
30871	2020-06-14 16:17:32	2020-06-14	Pattie Goldner DVM	pattie.goldner.dvm@warmmail.com	Dallas	Texas	676221773592718	177d8a2e3971f8b7b51e88da5c04ecfd	American Express	32.807407724931096	-96.6992132383361422
30872	2020-06-14 16:20:15	2020-06-14	Adriel Gerhold	adriel.gerhold@woohoo.com	Sparks	Nevada	589385299014713	d8147963699e14f03e73f555addff619	Diners Club / Carte Blanche	39.6176400735281433	-119.677870557256426
30873	2020-06-14 16:22:37	2020-06-14	Oma Dickens DVM	oma.dickens.dvm@warmmail.com	Dallas	Texas	4571913451091329	5bd1b4d1e91e256b24067ec3230617db	JCB 16 digit	32.7765146376837038	-96.7737014586999891
30874	2020-06-14 16:29:11	2020-06-14	Ross VonRueden	ross.vonrueden@geemail.com	Milwaukee	Wisconsin	6011908094958007615	53df8538f80d0a68786313a51104680a	Discover	43.0241363684266815	-87.8674165408227594
30875	2020-06-14 16:45:38	2020-06-14	Cyntha Kunze	cyntha.kunze@geemail.com	New York	New York	676189053088111	1dec1776e4bf6df536ade802c3c64de8	VISA 16 digit	40.7197733512371798	-74.0384412501368701
30876	2020-06-14 17:02:12	2020-06-14	Kenneth Wisoky	kenneth.wisoky@geemail.com	San Francisco	California	675920171555236	9b2aaebcf400ddfb14a2731eb9929459	Discover	37.7576184140041704	-122.442291199955321
30877	2020-06-14 17:21:35	2020-06-14	Madalyn Marks MD	madalyn.marks.md@warmmail.com	San Antonio	Texas	501882946548417	59c3a64578f90c467a352dc8618ac329	VISA 16 digit	29.5471957900166515	-98.5826616187415965
30878	2020-06-14 17:24:04	2020-06-14	Tristin Beahan IV	tristin.beahan.iv@geemail.com	Baltimore	Maryland	3528422407621054227	61bd5d6f07e73fd978056d19403212e3	Discover	39.3303551343735265	-76.5437953577395547
30879	2020-06-14 17:33:11	2020-06-14	Ms. Kimberlie Tillman	ms.kimberlie.tillman@geemail.com	New York	New York	3053446426184166	5aa10c82f933e497c8706bfdbc8b6afc	JCB 16 digit	40.5935146271474636	-73.9678602772194864
30881	2020-06-14 17:41:22	2020-06-14	Kris Ondricka	kris.ondricka@geemail.com	Los Angeles	California	6011499361430085203	b3df46d35c0552a8b695f819bb79e458	JCB 16 digit	34.0658437119662736	-118.358131658098841
30882	2020-06-14 18:03:06	2020-06-14	Blanchie Pollich	blanchie.pollich@geemail.com	Jacksonville	Florida	210069145010043751	9ca43329b785ba5697156c19704354d5	Voyager	30.2617753615189358	-81.6570349806998053
30883	2020-06-14 18:04:19	2020-06-14	Kwame Connelly	kwame.connelly@woohoo.com	Brownsville	Texas	869954285688129529	8dc8ccf9dc36e2d46be4bb0aea94399b	Discover	26.0211107890199855	-97.4688139853719662
30884	2020-06-14 18:16:29	2020-06-14	Chandler Hand III	chandler.hand.iii@geemail.com	Sterling Heights	Michigan	3485143313592939	91e08a11e8028bf16208e64dc9032ee0	VISA 16 digit	42.5363169970072832	-83.0402795335903789
30885	2020-06-14 18:20:53	2020-06-14	Cinnamon Denesik	cinnamon.denesik@geemail.com	Naperville	Illinois	4267760896606453	7ac2a3e07f57eb715457ce8bb436abcc	VISA 16 digit	41.8111046519510481	-88.1407242400459978
30886	2020-06-14 18:23:55	2020-06-14	Winnie Hoppe	winnie.hoppe@warmmail.com	Odessa	Texas	6011711244724307685	31ed6a125de4f555186f8bd119e721ed	Diners Club / Carte Blanche	31.8531268550094211	-102.394069464287156
30887	2020-06-14 18:32:00	2020-06-14	Dr. Bailee Hegmann	dr.bailee.hegmann@woohoo.com	Charlotte	North Carolina	53801016212819533	5ea80b56cf23e2d9c375a3d87f4a1c59	Mastercard	35.2142409296959613	-80.7612818394266156
30888	2020-06-14 18:32:56	2020-06-14	Lemma Hoeger	lemma.hoeger@geemail.com	Oklahoma City	Oklahoma	3088645908374493364	b80d5529599a429f1658645ddd33f7a0	VISA 13 digit	35.5549376643173431	-97.4798628901958466
30889	2020-06-14 18:40:46	2020-06-14	Bridgett Moen	bridgett.moen@geemail.com	San Diego	California	3749064122941130	cc42f7d781c7a5eb39eda5fa800aec8f	Mastercard	32.7287404372889554	-117.106798891015359
30890	2020-06-14 18:50:51	2020-06-14	Dakota Schuppe	dakota.schuppe@woohoo.com	Chicago	Illinois	55363583016476513	814b8552a070eb1b0c4d1c9ab3f0d8ef	Mastercard	41.850727676490699	-87.6823878040567024
30891	2020-06-14 18:51:44	2020-06-14	Cory Rice	cory.rice@geemail.com	Anchorage	Alaska	3009544551924994	1a3185ea4b22cca7779cc4c13c33332c	JCB 16 digit	61.2616113801237248	-149.382922568184512
30892	2020-06-14 18:55:25	2020-06-14	Mohammed Friesen	mohammed.friesen@geemail.com	Simi Valley	California	52726302930140291	6076c4907d48965172bd51de4eca2b2f	American Express	34.3665096492744979	-118.653344032088299
30893	2020-06-14 19:02:39	2020-06-14	Mr. Dwight Schmidt	mr.dwight.schmidt@warmmail.com	Mesa	Arizona	869937128504479292	a5b8f5ce09c037a64cf0769d327288d8	VISA 16 digit	33.4937610498309084	-111.656426247989387
30894	2020-06-14 19:03:34	2020-06-14	Ardell Rogahn	ardell.rogahn@geemail.com	New York	New York	180081212021976728	a9c6847da05bd0da1e5a7416312b1075	American Express	40.7361964943576567	-73.9065487315773879
30895	2020-06-14 19:04:41	2020-06-14	Daxton Mayert	daxton.mayert@geemail.com	Beaumont	Texas	55028856402885696	290b3a03de319100261f265ea84f27df	JCB 16 digit	30.0708448724892001	-94.1436285056427238
30896	2020-06-14 19:15:09	2020-06-14	Garth Grimes	garth.grimes@geemail.com	Mesa	Arizona	51718789936809996	3b6420ccd0d5b9891191b4323365d939	Diners Club / Carte Blanche	33.4859904800221315	-111.693387593177704
30897	2020-06-14 19:25:24	2020-06-14	Kayden Lang-Conn	kayden.lang.conn@geemail.com	San Francisco	California	6011511662177924478	eefb15d9cac860fc1ce29501bb5c32bf	Mastercard	37.8026809431909712	-122.420168671355583
30898	2020-06-14 19:34:20	2020-06-14	Keifer Bosco	keifer.bosco@woohoo.com	Rancho Cucamonga	California	3096793789535002280	bbcb97e8b7e0a9ce58a8fd5d2b725a87	VISA 13 digit	34.1616443705737609	-117.561125293467938
30899	2020-06-14 19:38:32	2020-06-14	Griffith Satterfield	griffith.satterfield@woohoo.com	Salt Lake City	Utah	4744373814139	10a306e40833a84c3a3d8bfa1573cfc1	JCB 16 digit	40.7328752147644764	-111.902525600459427
30900	2020-06-14 20:08:23	2020-06-14	Mr. Conley Bogisich MD	mr.conley.bogisich.md@geemail.com	Victorville	California	3112059751617599491	cc73a9e47d6b379c6360d120ab49eec5	Mastercard	34.4688234846338659	-117.333012385681641
30901	2020-06-14 20:14:15	2020-06-14	Lona Feil-Hermann	lona.feil.hermann@woohoo.com	Chattanooga	Tennessee	3056396982993921	35f98cbebbf9e342475070f7bfbb37f3	Diners Club / Carte Blanche	35.0601807850729728	-85.319636988948659
30902	2020-06-14 20:22:57	2020-06-14	Casey Kreiger	casey.kreiger@geemail.com	New York	New York	4250319906979977	66abeccfa2fad655a17ce19942e22761	Maestro	40.6966767559982827	-73.8830490815814613
30903	2020-06-14 20:28:37	2020-06-14	Rosalia Windler	rosalia.windler@warmmail.com	Broken Arrow	Oklahoma	4861169503286	872df19ff18b09a900b6292dbf44d202	VISA 16 digit	36.082190328162163	-95.7414370299726727
30904	2020-06-14 20:31:11	2020-06-14	Delmus Howell	delmus.howell@geemail.com	Chesapeake	Virginia	4766286071541170	09014bb3484929a90cdd3f05dc8aef33	VISA 16 digit	36.7053401609189791	-76.3540432309575436
30905	2020-06-14 20:33:21	2020-06-14	Mrs. Kathlene Feeney	mrs.kathlene.feeney@warmmail.com	Denver	Colorado	3112006781467082664	5906962cbe2894e2ab3d0ff782b96fff	American Express	39.7611396773770451	-104.818287682837251
30906	2020-06-14 20:38:00	2020-06-14	Kyle Morar V	kyle.morar.v@geemail.com	Pasadena	Texas	3059801299286460	27afc9278740fa79f1c3f2877f3a5071	Maestro	29.6384978121951228	-95.1209798841685057
30907	2020-06-14 20:51:45	2020-06-14	Merry Walsh DVM	merry.walsh.dvm@geemail.com	Aurora	Colorado	4980617180602	5146e7516f560d1d7d1aebc2cb437e19	VISA 13 digit	39.6780265027303258	-104.761450839333989
30908	2020-06-14 20:54:41	2020-06-14	Alton Windler-Koelpin	alton.windler.koelpin@warmmail.com	Oklahoma City	Oklahoma	3528195723710880743	b09c38db8e2a1869e578870cf48c5d24	VISA 16 digit	35.4882451128125211	-97.5853032506432356
30909	2020-06-14 20:55:47	2020-06-14	Jonnie Veum II	jonnie.veum.ii@geemail.com	San Francisco	California	4559501476761	6d86443579425625dfa5202b828280c4	Mastercard	37.7836195439453064	-122.443792993099748
30910	2020-06-14 20:57:01	2020-06-14	Lew Romaguera-Zemlak	lew.romaguera.zemlak@geemail.com	New York	New York	4542590999026	a95428a409c034e615c0fe9a6c14990a	Voyager	40.6394450597222914	-73.8628338743828152
30911	2020-06-14 21:04:43	2020-06-14	Karon Lueilwitz MD	karon.lueilwitz.md@geemail.com	New York	New York	869990173635148451	244b439eb9116b7b7afb726509ad5fab	American Express	40.621747707504781	-74.0378417419631063
30912	2020-06-14 21:12:58	2020-06-14	Tyler Spinka Sr.	tyler.spinka.sr.@geemail.com	Salem	Oregon	639029326251617	d4c8457f6b0c41c62a7feb47d02e3225	JCB 16 digit	44.9164940019872034	-123.002527594209468
30913	2020-06-14 21:13:02	2020-06-14	Dr. Einar Daugherty DVM	dr.einar.daugherty.dvm@geemail.com	Los Angeles	California	4670969775798395	944973c08eb2b926475ead920bf5b529	JCB 15 digit	33.9585807400155772	-118.508048650994141
30914	2020-06-14 21:17:17	2020-06-14	Leonore Terry	leonore.terry@geemail.com	Philadelphia	Pennsylvania	3528870431281572325	42a1fd68b1ce8d212d40d75fae3197e3	Mastercard	39.9935170650906855	-75.058053664480525
30915	2020-06-14 21:42:28	2020-06-14	Mignon Cronin-Goldner	mignon.cronin.goldner@geemail.com	Reno	Nevada	4328800560224	d359918fe370122103256cc09639f475	VISA 16 digit	39.4836409539062529	-119.934962067164108
30916	2020-06-14 21:42:41	2020-06-14	Mora Cummings	mora.cummings@warmmail.com	Seattle	Washington	4964717349050040	26d2bb19e7afe42fe823274e6424906c	Diners Club / Carte Blanche	47.7177858707420555	-122.35423112119696
30917	2020-06-14 22:02:01	2020-06-14	Shiela Haag	shiela.haag@geemail.com	High Point	North Carolina	4398476183068826	37ea455d7ffadda87358de86f2e4d88d	Maestro	35.9987048555724343	-80.0251570114139383
30918	2020-06-14 22:02:30	2020-06-14	Hollis Doyle	hollis.doyle@woohoo.com	Houston	Texas	3766843341105033	bca2de6ddab4b713152281fda2a31eb5	Voyager	29.8079270612526699	-95.3659172453001105
30919	2020-06-14 22:05:36	2020-06-14	Mrs. Jamiya Maggio	mrs.jamiya.maggio@warmmail.com	Columbia	South Carolina	4036243025860903	086df77b2a444332700e43a3de5cb624	American Express	33.9551934291407491	-80.9064790632128705
30920	2020-06-14 22:21:26	2020-06-14	Whit Zieme-Johnson	whit.zieme.johnson@warmmail.com	Amarillo	Texas	55023212140988787	de0c2586e937329912cf210c3ace4871	VISA 13 digit	35.1555025017052856	-101.925433180280777
30921	2020-06-14 22:24:37	2020-06-14	Dr. Billy Spinka	dr.billy.spinka@warmmail.com	Oakland	California	630499845025081	65fc3eba46f6621221eddd35b49d2c3b	VISA 16 digit	37.7894661410183943	-122.284632632593656
30922	2020-06-14 22:35:08	2020-06-14	Izaiah Jenkins V	izaiah.jenkins.v@geemail.com	Las Vegas	Nevada	3733558028809638	daf0aeefc25c9242d28511264fdc910a	Maestro	36.2926139162953945	-115.238241002543262
30923	2020-06-14 22:36:27	2020-06-14	Lucky Langworth	lucky.langworth@geemail.com	Jacksonville	Florida	4830016490047133	f493cc5ffbda3dd5aea0590a788c350b	Maestro	30.2529501693375416	-81.5619353661857645
30924	2020-06-14 22:39:19	2020-06-14	Lou Bruen	lou.bruen@warmmail.com	El Cajon	California	210067822973133132	f6bf0ece61938206ee711cb6d05ab08d	Voyager	32.8914464048583	-116.872851977888132
30925	2020-06-14 22:42:35	2020-06-14	Berenice Hodkiewicz	berenice.hodkiewicz@warmmail.com	Virginia Beach	Virginia	3112897203772214991	d83efbc0cbdd870a4fea4760b1e6f845	VISA 16 digit	36.8302646415028718	-76.1016408778864815
30926	2020-06-14 22:44:24	2020-06-14	Dr. Harlie Nitzsche DDS	dr.harlie.nitzsche.dds@geemail.com	Buffalo	New York	6011022073354025885	2c1ac3ad1c18b54f5d004b49099fe440	VISA 16 digit	42.9231941357906877	-78.9164325943615381
30927	2020-06-14 22:48:53	2020-06-14	Rella Ortiz DDS	rella.ortiz.dds@geemail.com	Columbus	Ohio	180054245503729010	924f49385cd44a1aa4a65f3d72e225cc	Maestro	40.0766980816654836	-83.048965087509913
30928	2020-06-14 22:53:25	2020-06-14	Darrian Lemke II	darrian.lemke.ii@geemail.com	Fayetteville	North Carolina	3025600825743158	885dc92be1d0a596bbb66b695b7a74a1	Mastercard	35.032318943671136	-78.978075000517066
30929	2020-06-14 22:59:17	2020-06-14	Gaven Breitenberg	gaven.breitenberg@warmmail.com	San Francisco	California	4061570064222	d715f5097d5563ee48052f241c901cd4	Discover	37.8167098257462229	-122.424174548255891
30930	2020-06-14 23:03:01	2020-06-14	Dr. Butch Macejkovic	dr.butch.macejkovic@geemail.com	Kansas City	Missouri	52437231836423040	a23fc30077d3e101d2639dbc0e3ac20d	JCB 16 digit	39.0949598708491806	-94.592333980113267
30931	2020-06-14 23:07:26	2020-06-14	Miss Alannah Nitzsche	miss.alannah.nitzsche@geemail.com	New York	New York	6011652646475905429	c9222f4adb3032c8d650e9b8d3e6ea27	JCB 15 digit	40.6747060387618831	-73.9365539166040691
30932	2020-06-14 23:12:36	2020-06-14	Wong Ryan-Reichel	wong.ryan.reichel@geemail.com	Fremont	California	639056675381711	ca60b6b972e3b8abaa274c839b0c0c9f	VISA 13 digit	37.4665157862640967	-122.00109733473397
30933	2020-06-14 23:23:41	2020-06-14	Brooks Kemmer	brooks.kemmer@woohoo.com	Grand Prairie	Texas	180004451978259266	06266c580b1f84d56e508ccc7a03a2c7	JCB 16 digit	32.7258214828144745	-96.9330912529364213
30934	2020-06-14 23:27:16	2020-06-14	Anne McClure	anne.mcclure@woohoo.com	New York	New York	3112377823763527645	fd25d8fd229a94a4dfbe9589f54588a5	VISA 16 digit	40.7621788040027013	-74.0191705645423355
30935	2020-06-14 23:30:35	2020-06-14	Alexia Medhurst-Ritchie	alexia.medhurst.ritchie@geemail.com	Buffalo	New York	4135439703362275	bb8b29cb31d63d84d61e587cde80a3ff	Discover	42.8943276079092186	-78.9364020629718937
30936	2020-06-15 00:00:17	2020-06-15	Adell Senger	adell.senger@geemail.com	Los Angeles	California	4707764411476	26ed778d5c93d9355103b4b149610f3e	Maestro	33.9788584665726816	-118.315810737478728
30937	2020-06-15 00:06:20	2020-06-15	Dr. Lakisha Wisozk DDS	dr.lakisha.wisozk.dds@geemail.com	Tallahassee	Florida	869950751492062739	fad4fe3525d25627765bf1468b98e86f	JCB 15 digit	30.5431780153442176	-84.1848579083584241
30938	2020-06-15 00:08:21	2020-06-15	Dorris Parisian	dorris.parisian@geemail.com	Chicago	Illinois	589300755312337	f1bb50bfa9b5b325d5d1df4b003b49d3	American Express	41.8028370316907782	-87.624353093750031
30939	2020-06-15 00:09:37	2020-06-15	Dr. Moshe Monahan	dr.moshe.monahan@geemail.com	New York	New York	4241641184246403	70dcf0011e211ac4ce7f9983bbb5684c	Diners Club / Carte Blanche	40.6117603390235473	-73.9323735719442396
30940	2020-06-15 00:21:37	2020-06-15	Mr. Darryle Harvey	mr.darryle.harvey@geemail.com	Houston	Texas	639035835476207	8173bf7b8d46601732d10530997c85f9	JCB 16 digit	29.7700070509299621	-95.4366071041688286
30941	2020-06-15 00:25:58	2020-06-15	Lennie Hackett	lennie.hackett@warmmail.com	San Angelo	Texas	4389924998397766	cf26144814ff7f4740c971bc7a3abefa	Voyager	31.5223401026487338	-100.356838790059101
30942	2020-06-15 00:33:20	2020-06-15	Dr. Chaz Hane Jr.	dr.chaz.hane.jr.@warmmail.com	New York	New York	3475666596658177	0a7d577ec0925b4741f9be9219cd7916	Diners Club / Carte Blanche	40.6150767475590087	-73.870582367143399
30943	2020-06-15 00:35:29	2020-06-15	Mrs. Renae Goldner	mrs.renae.goldner@geemail.com	San Francisco	California	3112112923975509884	a86a3639751b55e7c6f71a7c871b85de	VISA 16 digit	37.7758251255022586	-122.392400214838048
30944	2020-06-15 00:40:45	2020-06-15	Alvaro Rippin	alvaro.rippin@geemail.com	San Bernardino	California	55919952609213253	fab5c8b7498a013e4f66072dc44280af	VISA 16 digit	34.2251587578359988	-117.223834400229521
30945	2020-06-15 00:48:25	2020-06-15	Olive Miller	olive.miller@warmmail.com	Birmingham	Alabama	51460863754826521	a616bcd8afee7b48be6a59a23f66e804	American Express	33.4750255313027623	-86.7190719643384256
30946	2020-06-15 00:52:35	2020-06-15	Ronan Grady	ronan.grady@geemail.com	St. Louis	Missouri	54325686507211906	e9800c91dbdaa769c70441032bf52c1e	Mastercard	38.7118334216222166	-90.1984977147080116
30947	2020-06-15 01:23:59	2020-06-15	Amado Swift MD	amado.swift.md@geemail.com	Berkeley	California	3096653835394366313	53fe405e4fad99dc3c4745776dc4fff9	JCB 16 digit	37.8713662674263674	-122.270711950114375
30948	2020-06-15 01:32:47	2020-06-15	Betsy Maggio-Deckow	betsy.maggio.deckow@warmmail.com	Raleigh	North Carolina	589390950814310	6848d5ea5d3a580ad613bdf24e2c820e	Diners Club / Carte Blanche	35.9142615408770709	-78.7381277764152827
30949	2020-06-15 01:41:15	2020-06-15	Jaimie Rolfson	jaimie.rolfson@geemail.com	Kenosha	Wisconsin	3088017842622432033	a3bfb323c46d46caedc2ffecffdaf7e7	Diners Club / Carte Blanche	42.5611840518962623	-87.8102586580667719
30950	2020-06-15 01:46:12	2020-06-15	Darrius Windler Sr.	darrius.windler.sr.@woohoo.com	Fort Worth	Texas	3009360358189271	ea111f7185b498db36ec9cd6dfe4424d	Mastercard	32.78660383457877	-97.3654950262334182
30951	2020-06-15 01:51:52	2020-06-15	Rahn Ebert	rahn.ebert@geemail.com	Oklahoma City	Oklahoma	3337370434192909037	511c5b319e90a1d8782efbd18551e6b5	Mastercard	35.4906257639084046	-97.5260846473172336
30952	2020-06-15 01:53:56	2020-06-15	Ronaldo Bins Sr.	ronaldo.bins.sr.@geemail.com	Springfield	Illinois	3023755148536911	072951317aa9379dff2d0f73dd33a61f	JCB 15 digit	39.8233823483496892	-89.6125795964620977
30953	2020-06-15 01:58:22	2020-06-15	Dr. Jensen Leffler PhD	dr.jensen.leffler.phd@geemail.com	West Valley City	Utah	3444353448544180	abd06aa4cad6f82d95e0c22dffb7bd07	VISA 16 digit	40.6901609300393616	-112.046829363911598
30954	2020-06-15 02:27:49	2020-06-15	Jayvion Beatty	jayvion.beatty@geemail.com	Phoenix	Arizona	6011408392867278300	d7e70253a4868f90bf52c02665413db5	JCB 16 digit	33.5236636430423758	-112.151667540653051
30955	2020-06-15 02:31:22	2020-06-15	Fidel Heller	fidel.heller@warmmail.com	Berkeley	California	3088516127851361327	247bdb7baf4f09dfc20d2f9646be5ebf	Discover	37.8959214404832352	-122.242461934814614
30956	2020-06-15 02:34:34	2020-06-15	Lorri Greenholt	lorri.greenholt@geemail.com	Columbus	Ohio	3337636733321453084	6316dc02c5f14313836d06cb717a6974	VISA 13 digit	39.8929046944759804	-82.9762293621201081
30957	2020-06-15 02:34:51	2020-06-15	Mrs. Aria Mills DDS	mrs.aria.mills.dds@geemail.com	Berkeley	California	4977177627562429	bab1d81793a10f1eb73ddcdaaecb327a	JCB 16 digit	37.8964908842589807	-122.260280402296729
30958	2020-06-15 02:42:58	2020-06-15	Mrs. Jaqueline Roob DVM	mrs.jaqueline.roob.dvm@geemail.com	Fort Worth	Texas	6011754063703560892	084ed6ae0e361397a74609be78854d12	Diners Club / Carte Blanche	32.7144118407797109	-97.2666853208847328
30959	2020-06-15 02:44:50	2020-06-15	Odalys Metz	odalys.metz@warmmail.com	McKinney	Texas	3040708765134745	4edb0498a46552bf9c77690f1aa3b38f	JCB 16 digit	33.2061895684469519	-96.6198487904686516
30960	2020-06-15 02:47:23	2020-06-15	Dr. Ramiro Jacobs III	dr.ramiro.jacobs.iii@woohoo.com	San Jose	California	869981514442018943	d6cf5035f369c9155562dc0f7e22cab3	American Express	37.2290221878148628	-121.798747944900398
30961	2020-06-15 03:01:19	2020-06-15	Pamelia Blanda-Connelly	pamelia.blanda.connelly@geemail.com	Denver	Colorado	639031035144364	12ddc8057035a18675bcb06b6e126cda	JCB 16 digit	39.6994080203637481	-104.797196521215511
30962	2020-06-15 03:06:59	2020-06-15	Camden Wunsch	camden.wunsch@geemail.com	Orlando	Florida	3046012106056186	d68eb2b3c0bebfc5e1f3d0b0d18a3e5a	Maestro	28.4794797031939027	-81.2496555393062607
30963	2020-06-15 03:14:28	2020-06-15	Mr. Pierce Reinger	mr.pierce.reinger@geemail.com	Chesapeake	Virginia	3096606651979672134	4acffc7463149f24b5cfba3d92a7c1ac	Maestro	36.7243147787876438	-76.2084954320296646
30964	2020-06-15 03:26:36	2020-06-15	Gustavo Simonis I	gustavo.simonis.i@woohoo.com	Jacksonville	Florida	6011028052138484091	0d18c5e42fb9afbb73c121d1f781e157	American Express	30.2930712142080054	-81.6242057723537187
30965	2020-06-15 03:45:49	2020-06-15	Jonnie Zemlak III	jonnie.zemlak.iii@geemail.com	San Francisco	California	4263694023294558	35b8e9c5f59c1af2406fbbb2a8134786	VISA 13 digit	37.794734716878132	-122.434307601042448
30966	2020-06-15 03:58:00	2020-06-15	Adah Frami	adah.frami@geemail.com	Louisville	Kentucky	561221142641410	8cce56292dcb18d3be7fb4e964ac7475	VISA 16 digit	38.232896931273487	-85.6394750552322819
30967	2020-06-15 04:00:21	2020-06-15	Mr. Junior Reichel III	mr.junior.reichel.iii@geemail.com	Norfolk	Virginia	6011359619447221809	9b3a4f99c0296a8e43a973f07ddc51c5	VISA 13 digit	36.9501004105918156	-76.1709002868276173
30968	2020-06-15 04:00:43	2020-06-15	Mr. Arba Gulgowski	mr.arba.gulgowski@geemail.com	San Francisco	California	4220497696694	4731e1537467b60543d0d9833c3d0eb1	Voyager	37.7903904831294497	-122.421308654851543
30969	2020-06-15 04:05:03	2020-06-15	Ms. Theodocia Murazik	ms.theodocia.murazik@geemail.com	Meridian	Idaho	3715959784258097	9f55d823ac1eb283c31b3a3785928521	VISA 16 digit	43.663719334547217	-116.442609774687881
30970	2020-06-15 04:05:41	2020-06-15	Jailene Flatley	jailene.flatley@woohoo.com	Reno	Nevada	676140317325963	d349d46b4accbbc208d71f3063563cd7	JCB 16 digit	39.5506789379365742	-119.935478780667864
30971	2020-06-15 04:12:57	2020-06-15	Miss Rory Hammes PhD	miss.rory.hammes.phd@warmmail.com	Costa Mesa	California	210040401202088201	26725bcbb83cc65ce1108cef0ccdc503	Voyager	33.6389880661867551	-117.818756244969748
30972	2020-06-15 04:21:51	2020-06-15	Americo Cruickshank	americo.cruickshank@geemail.com	Los Angeles	California	3739261995790949	c1a8a8310abdc30c7e8118d0c7729d27	JCB 15 digit	34.0063180413428654	-118.503229241864005
30973	2020-06-15 04:25:43	2020-06-15	Maximilian Zulauf	maximilian.zulauf@geemail.com	Santa Rosa	California	3459608908146160	0e515178ad2bc2f25a8b62159c338076	VISA 16 digit	38.5343887290108995	-122.731971035363529
30974	2020-06-15 04:28:44	2020-06-15	Esau Ullrich	esau.ullrich@geemail.com	Vancouver	Washington	210083984625470054	e0d78a79c31875325ee2b52ac025de49	JCB 16 digit	45.6151109135314812	-122.599160609633472
30975	2020-06-15 04:30:18	2020-06-15	Cher Anderson	cher.anderson@geemail.com	Savannah	Georgia	3528280843421145347	540ea65cbd72407a9a5ccfddaedbeb5e	Mastercard	32.0010806228127294	-81.1894096221927555
30976	2020-06-15 04:34:19	2020-06-15	Hartwell Larson	hartwell.larson@geemail.com	San Francisco	California	4987909605032654	63aee2366a6294b8d471d23df53864b5	VISA 16 digit	37.8068670036411874	-122.422756419067625
30977	2020-06-15 04:40:33	2020-06-15	Dusty Bailey-Kozey	dusty.bailey.kozey@geemail.com	Arlington	Texas	4213603056132859	070f969ec0b91a19a8a661f214cb967b	Diners Club / Carte Blanche	32.6389501110434495	-97.145564502433686
30978	2020-06-15 04:45:25	2020-06-15	Margeret Schroeder	margeret.schroeder@woohoo.com	Pearland	Texas	180051218546883196	a12401cc4689b7cef6e6a600827e7752	VISA 16 digit	29.5840184450421511	-95.3053136857546832
30979	2020-06-15 04:58:11	2020-06-15	Deshaun Jacobson	deshaun.jacobson@woohoo.com	Chicago	Illinois	060418202487221	d6796e737bbaaf0e41af36aa3502479b	Diners Club / Carte Blanche	41.8257823859643239	-87.6175855774927896
30980	2020-06-15 04:59:40	2020-06-15	Sammy McGlynn	sammy.mcglynn@geemail.com	Sacramento	California	3416982064911085	30726520c17fda3c521d22bc91c999c9	VISA 16 digit	38.6478165219336773	-121.414573511738695
30981	2020-06-15 05:04:44	2020-06-15	Dr. Kamron Morissette	dr.kamron.morissette@geemail.com	San Francisco	California	3704179584430894	ab60b421ea781b62b30e59d971c38ab2	JCB 15 digit	37.7408021203007422	-122.453718255822807
30982	2020-06-15 05:27:04	2020-06-15	Jaxson Corkery	jaxson.corkery@geemail.com	Santa Maria	California	4174047392938172	ba9c9dc7d163e5c51851bb474e1a5f82	VISA 13 digit	34.8936680193588131	-120.350530490084736
30983	2020-06-15 05:31:36	2020-06-15	Fenton Adams	fenton.adams@geemail.com	Long Beach	California	6011095413197369185	142f21ece0d396b5850cd3b93b4d7267	VISA 16 digit	33.7470990252502219	-118.172754424221068
30984	2020-06-15 05:50:34	2020-06-15	Octavius Hauck	octavius.hauck@warmmail.com	Toledo	Ohio	3053161674237026	a6a52a93c098d0d8cc62cb8c30b7b8d0	Mastercard	41.6292467695366568	-83.5341142122965294
30985	2020-06-15 06:01:13	2020-06-15	Woodson Hegmann	woodson.hegmann@geemail.com	Davie	Florida	54233715522286139	bc0d660df66338abb5bfcc6ce240eaa2	Discover	26.0046128743126985	-80.1955982938781347
30986	2020-06-15 06:06:52	2020-06-15	Derrek Rowe III	derrek.rowe.iii@geemail.com	Greensboro	North Carolina	4561192618784	a9bc24fb706af0644e9d6dfc0887eb67	JCB 16 digit	36.1812915066372653	-79.8391198719833
30987	2020-06-15 06:07:46	2020-06-15	Elianna Ward	elianna.ward@geemail.com	San Francisco	California	3429300182106345	66440c0278112fa63074a359a397b102	VISA 16 digit	37.7773061053703145	-122.430381411363143
30988	2020-06-15 06:09:20	2020-06-15	Zillah Herzog	zillah.herzog@geemail.com	Boston	Massachusetts	4267370515764	3251163b1cbde078772975163c36731c	VISA 16 digit	42.3825382906645558	-70.9291933727402295
30989	2020-06-15 07:09:59	2020-06-15	Jillian Bogisich	jillian.bogisich@geemail.com	Philadelphia	Pennsylvania	6011108986665912227	d12ff6029f56b42ec5c05acc46415e9e	VISA 13 digit	39.9130637636832901	-75.1834905397046356
30990	2020-06-15 07:12:34	2020-06-15	Quincy Murray Sr.	quincy.murray.sr.@geemail.com	Plano	Texas	3723928376756206	923a8c485a76bb3376c58006448bbca2	Diners Club / Carte Blanche	32.9792568721428552	-96.66737790510021
30991	2020-06-15 07:17:58	2020-06-15	Zackery Beatty	zackery.beatty@woohoo.com	New York	New York	3748904021948739	49732f8fee357bf40eb8cbc533455f38	Maestro	40.6796062004975951	-73.8493290262192517
30992	2020-06-15 07:23:45	2020-06-15	Kerry Emmerich MD	kerry.emmerich.md@geemail.com	Temecula	California	180063103075369674	2b8bbe2cf5f31dd072f052cf93ce899a	American Express	33.3974782458640647	-117.13545471743754
30993	2020-06-15 07:27:25	2020-06-15	Kirk Wuckert	kirk.wuckert@geemail.com	Albuquerque	New Mexico	869999137149708119	f9ce956238da795cd8405b8ef77a7c1d	Diners Club / Carte Blanche	35.1053147545684183	-106.722818945681311
30994	2020-06-15 07:30:41	2020-06-15	Emely Buckridge-Haley	emely.buckridge.haley@geemail.com	San Francisco	California	4082785781377244	404934b1b830c1e10f990502b0fc5905	VISA 16 digit	37.7924923508120685	-122.42924763068882
30995	2020-06-15 07:34:06	2020-06-15	Nolie Beatty	nolie.beatty@geemail.com	Saint Paul	Minnesota	180074596185884952	686e2ed31026c93305b7a44ddc693def	JCB 15 digit	45.0079175636112723	-93.1727105518601917
30996	2020-06-15 07:36:35	2020-06-15	Jannie Douglas	jannie.douglas@geemail.com	New York	New York	4846522839238251	0238933791478c72504058b75b155542	Maestro	40.668893314035607	-73.9346644308779304
30997	2020-06-15 07:55:06	2020-06-15	Julissa Cartwright	julissa.cartwright@geemail.com	Davie	Florida	4860352663029902	4c5b321f0994a3803bbf6bec28cd858b	Discover	26.0607480853594851	-80.2717721937596735
30998	2020-06-15 07:57:16	2020-06-15	Richard Upton	richard.upton@geemail.com	Henderson	Nevada	3337412507333526701	dd2559146bb0de8a3fe7406d7c84917e	Mastercard	36.0741016241654791	-115.02377966895402
30999	2020-06-15 08:22:19	2020-06-15	Coral Strosin	coral.strosin@warmmail.com	Albuquerque	New Mexico	4174490697664	101a91350995def0f21614f448125e74	VISA 16 digit	35.1262052603665751	-106.709519094980891
31000	2020-06-15 08:31:26	2020-06-15	Giovanni Flatley	giovanni.flatley@geemail.com	Los Angeles	California	4124984906111139	4c0cf37c6f7e7b482df1c9abdd5f639c	VISA 13 digit	33.9613674689415816	-118.353243389911199
31001	2020-06-15 08:37:05	2020-06-15	Dr. Sherie Bogisich	dr.sherie.bogisich@woohoo.com	Cleveland	Ohio	869949638697022242	0531c634334376fc2706589aa2e93fe4	VISA 16 digit	41.5358320466093716	-81.6992098704684508
31002	2020-06-15 08:40:44	2020-06-15	Miss Kayla Lang	miss.kayla.lang@geemail.com	Glendale	Arizona	675984536612512	17454b21d4dcadeb9b923bac0530c34e	Voyager	33.4841694098193159	-112.245480011662096
31003	2020-06-15 08:48:40	2020-06-15	Lem Nolan	lem.nolan@geemail.com	Los Angeles	California	51944129916637016	fb55740cf47983857a13be03e24efaff	American Express	34.0400716550979752	-118.31097095692455
31004	2020-06-15 08:52:57	2020-06-15	Dr. Cliff Howell Jr.	dr.cliff.howell.jr.@geemail.com	Tampa	Florida	869918724699632282	e42e3832855796710c5a6651c817ccb4	Diners Club / Carte Blanche	28.0246834836084382	-82.4887195852331701
31005	2020-06-15 08:56:39	2020-06-15	Ms. Jenilee Sanford	ms.jenilee.sanford@geemail.com	Las Vegas	Nevada	6011847946537144025	9aeda8642dfb4bb9a13873377cf3b00d	VISA 16 digit	36.3004147299200284	-115.258135140056154
31006	2020-06-15 08:59:03	2020-06-15	Mrs. Carra Bednar	mrs.carra.bednar@geemail.com	San Francisco	California	3414239844595965	7d7ae9102a2fc6d2cc0b4f44f4947298	JCB 16 digit	37.7334300142359851	-122.421590470895126
31007	2020-06-15 09:04:28	2020-06-15	Alphonso Leffler	alphonso.leffler@geemail.com	Columbia	South Carolina	4327185535230879	fca68d9e2ec5db26c78dac0dca55955a	Discover	34.0278263292074215	-80.9603245853930673
31008	2020-06-15 09:09:07	2020-06-15	Constantine Mayert	constantine.mayert@geemail.com	Richmond	Virginia	869974250129253961	cc65912a0b2e2a8e7e41487a6c591cbe	JCB 16 digit	37.4566512243110665	-77.4384873402062794
31009	2020-06-15 09:21:56	2020-06-15	Isadore Kuvalis	isadore.kuvalis@geemail.com	Fort Worth	Texas	3730100134613951	af11c72cc912e5ad6b9ef495ef16a9ec	VISA 16 digit	32.799705659324303	-97.4311092728104455
31010	2020-06-15 09:24:15	2020-06-15	Osvaldo McGlynn	osvaldo.mcglynn@warmmail.com	New York	New York	3400682279533405	2da47231af75407afd2cd4c31a79c989	Voyager	40.7565987351573966	-73.9837164486188357
31011	2020-06-15 09:27:18	2020-06-15	Santa McLaughlin	santa.mclaughlin@geemail.com	San Francisco	California	676232054905578	23b71720d504e59478cc342125a0af36	JCB 16 digit	37.7325699847601328	-122.431715082233254
31012	2020-06-15 09:30:24	2020-06-15	Margurite Hintz-Rosenbaum	margurite.hintz.rosenbaum@geemail.com	Oakland	California	4814567779281215	38a194bc5b971c0a2b43877974493a26	Voyager	37.8054789069309933	-122.260700262516409
31013	2020-06-15 09:38:52	2020-06-15	Allison Wolff	allison.wolff@geemail.com	Lafayette	Louisiana	4099398256886128	f49fffa226511cfaa116ea32d8f2f3b2	Discover	30.197307874586059	-92.0539750468768148
31014	2020-06-15 09:48:29	2020-06-15	Rance Hudson	rance.hudson@geemail.com	Los Angeles	California	6011641804675672596	ecc74162a414de8994929e2888db05fa	American Express	33.992379044588283	-118.433174426387239
31015	2020-06-15 09:49:12	2020-06-15	Melany Hoppe	melany.hoppe@geemail.com	Madison	Wisconsin	3112022817566312022	7b667ab4c52d01a2a9c43217ff78a5d6	VISA 16 digit	43.1508570313893287	-89.385003015899656
31016	2020-06-15 09:51:01	2020-06-15	Adele Wiegand	adele.wiegand@woohoo.com	Independence	Missouri	3337632189819915122	fa81d194b87c71a3d6c37a01012a2cb4	JCB 16 digit	39.1179358852114589	-94.286686072713124
31017	2020-06-15 10:08:42	2020-06-15	Dr. Kevan Kuphal	dr.kevan.kuphal@woohoo.com	San Francisco	California	210093429265647023	865c81bf59c522d3fb31c8a6c9964495	Discover	37.7817668685111485	-122.476261017711892
31018	2020-06-15 10:09:57	2020-06-15	Miss Emilie Friesen DDS	miss.emilie.friesen.dds@woohoo.com	Peoria	Arizona	210075590819002866	0cb003274f0d241ede4bc61eb83030ac	Voyager	33.7595657819218928	-112.376151795305319
31019	2020-06-15 10:11:44	2020-06-15	Jaime Ritchie-Weber	jaime.ritchie.weber@geemail.com	Toledo	Ohio	4278910629050811	fe4d39f03907524e96ebe75ace1a2f41	VISA 16 digit	41.6358923272401071	-83.5555842577811347
31020	2020-06-15 10:20:49	2020-06-15	Ms. Casey Olson	ms.casey.olson@geemail.com	New York	New York	6011017246182873448	5c3701d57a2b3c68e656b6f7dca1ce02	VISA 16 digit	40.6799432869292801	-73.9120231618069141
31021	2020-06-15 10:22:00	2020-06-15	Annika Shanahan	annika.shanahan@geemail.com	Portland	Oregon	3158272930648390622	57de43c7299111bc3b16f73fabf2d339	Diners Club / Carte Blanche	45.5308695404678545	-122.655144228925934
31022	2020-06-15 10:24:43	2020-06-15	Dr. Romeo Dickinson V	dr.romeo.dickinson.v@geemail.com	Evansville	Indiana	4366810386267553	f43c23f174a3dcb3edb78eedb29d2021	JCB 16 digit	37.924392116083574	-87.5406623150154957
31023	2020-06-15 10:32:51	2020-06-15	Rolland Runolfsson	rolland.runolfsson@warmmail.com	San Jose	California	4606722759960	6073e6a75b701e714ecc24f77b08c2ce	VISA 16 digit	37.3083705446504084	-121.902794007420169
31024	2020-06-15 10:35:30	2020-06-15	Laurine Sawayn	laurine.sawayn@warmmail.com	New York	New York	3096402355430926081	ad5952d1baf7fbf63948c638e6703d1a	VISA 16 digit	40.6747057076301388	-74.0225747285772115
31025	2020-06-15 10:38:55	2020-06-15	Eden King	eden.king@warmmail.com	Garland	Texas	639038998777650	72b0b9f876174049a444a8ea2082994a	JCB 15 digit	32.9904507839355574	-96.6020746083624715
31026	2020-06-15 10:52:26	2020-06-15	Dominga Lang	dominga.lang@woohoo.com	Phoenix	Arizona	869940391849342378	bf5e8671741cc16c3880c6c6e35b8b83	Maestro	33.5744864405065826	-112.046769327616701
31027	2020-06-15 10:55:05	2020-06-15	River Hahn-Beatty	river.hahn.beatty@geemail.com	Aurora	Illinois	3337953455806731934	f9973f0ca93ae7c91066fac821f4018c	VISA 13 digit	41.8305777963940031	-88.3359006779663218
31028	2020-06-15 10:57:13	2020-06-15	Annice Mitchell	annice.mitchell@geemail.com	Peoria	Arizona	3047531289004258	c71417630f15680161781699b1ce3469	Maestro	33.7728980029270076	-112.348937631158165
31029	2020-06-15 11:13:00	2020-06-15	Ms. Rosanna Rice	ms.rosanna.rice@geemail.com	San Francisco	California	4425007572960575	10a1d7f2213564ad2eb9b78db6706ba8	American Express	37.7496843452910653	-122.400749080247621
31030	2020-06-15 11:17:30	2020-06-15	Dr. Nila Lang MD	dr.nila.lang.md@woohoo.com	Paterson	New Jersey	210029535456314550	8eb81ca0ab4b93563cd3c1b9f89c33a5	Voyager	40.8241897280748915	-74.2432412719793717
31031	2020-06-15 11:31:05	2020-06-15	Joshua Romaguera	joshua.romaguera@geemail.com	Durham	North Carolina	4923560990736594	fb7236086d9b1a4a4489762e59e57188	American Express	35.9578582950647885	-78.9788428150486226
31032	2020-06-15 11:38:18	2020-06-15	Colonel Powlowski-Runolfsson	colonel.powlowski.runolfsson@geemail.com	Chicago	Illinois	589328740722260	3a42ebda43b215868b013ea5a06489c7	Maestro	41.8968886274214825	-87.6694162356231317
31033	2020-06-15 11:38:56	2020-06-15	Bliss O'Keefe DDS	bliss.o'keefe.dds@warmmail.com	Phoenix	Arizona	210053844813404560	560d54e9a11cf17aed6c01441ef89213	VISA 16 digit	33.5870290940094733	-112.135682584198577
31034	2020-06-15 11:57:07	2020-06-15	Dempsey Sanford	dempsey.sanford@geemail.com	Phoenix	Arizona	561273511944925	54faaf997ea977fb1932a437dff07d21	American Express	33.6441543929211804	-112.159866042893754
31035	2020-06-15 11:57:16	2020-06-15	Marceline McLaughlin	marceline.mclaughlin@geemail.com	Victorville	California	3112576860779909069	53ffccb4ea182d3999c447b529ad1a39	American Express	34.626164478086686	-117.417503205236414
31036	2020-06-15 12:05:10	2020-06-15	Mr. Prosper Lockman	mr.prosper.lockman@geemail.com	San Francisco	California	3112208211071160157	f77b645e13aadb1db24d0a717f2d0201	VISA 16 digit	37.7933283961612076	-122.426304371686129
31037	2020-06-15 12:09:20	2020-06-15	Keenan Schmidt	keenan.schmidt@geemail.com	San Antonio	Texas	4189777218885	29c30a81c0f4bcf24ef7002d85a019b1	Diners Club / Carte Blanche	29.4340839418187734	-98.6246835484471092
31038	2020-06-15 12:17:42	2020-06-15	Thurston Streich-Sipes	thurston.streich.sipes@geemail.com	Lexington	Kentucky	3713705145757588	91a66655a60e507ae01d60d4424e2adc	Discover	38.1034268428448613	-84.4577150838348985
31039	2020-06-15 12:24:24	2020-06-15	Shep Bailey	shep.bailey@geemail.com	Murrieta	California	6011828638997590499	2cac89ed7d7d3914dfc1dc6aa334cda4	JCB 16 digit	33.5290405517540862	-117.248527107564357
31040	2020-06-15 12:35:25	2020-06-15	Alyse Aufderhar	alyse.aufderhar@geemail.com	Miramar	Florida	4630455030742625	6ff613fd780e9453f2c551375f590cb2	VISA 13 digit	25.9070291347783055	-80.3965008376624439
31041	2020-06-15 12:38:22	2020-06-15	Sherlyn O'Conner	sherlyn.o'conner@warmmail.com	Richmond	Virginia	210012676143068149	2c998faf0eeddcee470afd192ceb14ec	JCB 16 digit	37.6214011457037145	-77.5218242198917977
31042	2020-06-15 12:40:06	2020-06-15	Ms. Sherrie Fay DVM	ms.sherrie.fay.dvm@geemail.com	Arlington	Texas	55269351308414310	26e054ee4f6ac6c7d93a704ceba52280	VISA 13 digit	32.6947473400987647	-97.07014052206911
31043	2020-06-15 12:45:28	2020-06-15	Mr. Almus Dooley	mr.almus.dooley@geemail.com	Peoria	Arizona	180099907644256859	58134fa1e531b816d54baeec9022ec53	JCB 16 digit	33.7228361081134551	-112.346811748242018
31044	2020-06-15 12:45:31	2020-06-15	Mr. Bethel Kuhic	mr.bethel.kuhic@woohoo.com	San Francisco	California	3158940865606366499	2516cda5712d1450f730bf4439dcc47a	Voyager	37.7471504498679309	-122.434964782646304
31045	2020-06-15 12:48:11	2020-06-15	Joselyn Christiansen	joselyn.christiansen@geemail.com	Stockton	California	4705206477571773	cc375c2c9985cb78449fcdf777623d91	Discover	37.8965246061526244	-121.256799107519157
31046	2020-06-15 13:08:58	2020-06-15	Gunner Nikolaus-Langosh	gunner.nikolaus.langosh@geemail.com	Memphis	Tennessee	4307547175640747	b54ebffee0f2c30a9fcf3dba1d512a3a	JCB 15 digit	35.0337795734472621	-89.9208545702301052
31047	2020-06-15 13:31:44	2020-06-15	Bud Considine	bud.considine@geemail.com	Philadelphia	Pennsylvania	4927297933077507	55236e8528af2996fdffcb3fb24f5591	JCB 16 digit	40.0745462812442312	-75.0488400719028022
31048	2020-06-15 13:45:32	2020-06-15	Trilby Corkery	trilby.corkery@warmmail.com	El Cajon	California	6011742716238712602	1f2382d70fbdca6840d58bba952531fd	VISA 13 digit	32.7735607087153937	-117.006103117921953
31049	2020-06-15 14:21:22	2020-06-15	Ms. Tawanna Dietrich MD	ms.tawanna.dietrich.md@geemail.com	Chicago	Illinois	6011503446732450041	bee98429bc2c997d8a74707d83907437	JCB 16 digit	41.8010768663905594	-87.7141565037920969
31050	2020-06-15 14:25:01	2020-06-15	Leanna Deckow-Gutkowski	leanna.deckow.gutkowski@geemail.com	Reno	Nevada	3794271598731952	283e3bdcb8ae585b296199caaf128ecc	Diners Club / Carte Blanche	39.5297791627779631	-119.797370994293701
31051	2020-06-15 14:27:51	2020-06-15	Adeline Kessler	adeline.kessler@geemail.com	Chicago	Illinois	4826792446047	e4211a12614125602441e314cc4e93d2	Voyager	41.7602381001994019	-87.6479482669412988
31052	2020-06-15 14:29:58	2020-06-15	Pinkie O'Connell DVM	pinkie.o'connell.dvm@geemail.com	Arlington	Texas	3461447516377925	eff16be982fe6e631e467a3935d20f11	Maestro	32.7655240670096077	-97.0620512471560488
31053	2020-06-15 14:47:45	2020-06-15	Jamari O'Conner	jamari.o'conner@geemail.com	Rancho Cucamonga	California	3088575436330444390	5e8dc284620fca52ee387375efc10d6b	JCB 15 digit	34.2020658750545223	-117.634148267517617
31054	2020-06-15 15:21:06	2020-06-15	Vida Reynolds	vida.reynolds@geemail.com	San Francisco	California	6011916879881370290	26c1cbd4bb44d7b806c947d64e7d62d5	VISA 16 digit	37.7958741759214547	-122.438580518671216
31055	2020-06-15 15:32:03	2020-06-15	Adelard Effertz-Klein	adelard.effertz.klein@woohoo.com	Arlington	Texas	55630585592857484	c7be31365c87a67ac222d530edf0be98	Mastercard	32.6393321885045609	-97.0497217539258372
31056	2020-06-15 15:36:10	2020-06-15	Danial Huels-McLaughlin	danial.huels.mclaughlin@geemail.com	Berkeley	California	869934970550226231	0b3f62b385277dd92c054577b680dd23	VISA 16 digit	37.858961269362787	-122.272399367642151
31057	2020-06-15 15:47:38	2020-06-15	Winfred Graham	winfred.graham@geemail.com	San Francisco	California	3096180430513562943	0c037bd2ac0b6352b11c4d034593209d	JCB 15 digit	37.7659556369998626	-122.42016584431947
31058	2020-06-15 15:54:27	2020-06-15	Sloane Bogan	sloane.bogan@geemail.com	Concord	California	6011169698571371382	0676ff26ac8f0c9c71b8acb7f3085abb	Mastercard	37.8887323277469719	-122.026833889417716
31059	2020-06-15 16:09:33	2020-06-15	Beecher Okuneva-Ullrich	beecher.okuneva.ullrich@geemail.com	Chicago	Illinois	676117086662198	dcbe460fee4c23bb9b6713171e6e0399	VISA 16 digit	41.8699064520023754	-87.7297453425388767
31060	2020-06-15 16:10:33	2020-06-15	Raphael Wuckert	raphael.wuckert@geemail.com	San Francisco	California	210080953461683354	c4dc897c8f9a70d28e00e95f4c62b645	JCB 16 digit	37.7725803999823384	-122.365235155841702
31061	2020-06-15 16:14:02	2020-06-15	Hale Langworth	hale.langworth@woohoo.com	St. Louis	Missouri	51620152009875831	b5f5f4247954815e466093495c1cbaaa	VISA 16 digit	38.6675667077459408	-90.1521640058144982
31062	2020-06-15 16:36:10	2020-06-15	Alda Bode	alda.bode@geemail.com	Oakland	California	3721960367229945	931c1d3efc5c55d9ce4894bcee069634	JCB 16 digit	37.7860528266642319	-122.250089332053804
31063	2020-06-15 16:37:42	2020-06-15	Tillie Gutkowski	tillie.gutkowski@geemail.com	San Francisco	California	3024093640828068	e7afbec87960ab11774dbb2b477ded09	VISA 13 digit	37.7513738254638795	-122.405877052326275
31064	2020-06-15 16:45:58	2020-06-15	Miss Valerie Harvey PhD	miss.valerie.harvey.phd@geemail.com	Albuquerque	New Mexico	180027671378857004	4f7fa2ce3022efe77ab1bddfdac36a00	JCB 15 digit	35.192433517067137	-106.619161974319823
31065	2020-06-15 16:48:39	2020-06-15	Rosalyn Zulauf	rosalyn.zulauf@warmmail.com	Syracuse	New York	3015019289486883	673fac33d15bfe13f01fe899017e2bb6	Diners Club / Carte Blanche	42.9663851864021211	-76.2355841708615429
31066	2020-06-15 17:08:40	2020-06-15	Annice Lehner	annice.lehner@woohoo.com	San Francisco	California	869955879407901777	b56308a90891e932d35bb6bbbb9ed634	VISA 16 digit	37.73162031266817	-122.422708270690649
31067	2020-06-15 17:13:38	2020-06-15	Luster Stiedemann-Gerlach	luster.stiedemann.gerlach@warmmail.com	Philadelphia	Pennsylvania	4560101151708979	ea6c79fa79a45fd38a705c9c62c6c8df	VISA 16 digit	40.0931485342286535	-75.1510886479534292
31068	2020-06-15 17:22:34	2020-06-15	Miss Mckayla King	miss.mckayla.king@geemail.com	College Station	Texas	3337483959022917218	6e0af0790b24f8264a16707a58c4fe09	VISA 16 digit	30.6549231746744368	-96.2519730432271956
31069	2020-06-15 17:22:36	2020-06-15	Dr. Faustino Morissette DDS	dr.faustino.morissette.dds@geemail.com	Abilene	Texas	210078968958389293	5716e944cf9ccb3505973109d65afed7	VISA 13 digit	32.3628669625688374	-99.8158133625000801
31070	2020-06-15 17:40:26	2020-06-15	Linnie Marquardt	linnie.marquardt@warmmail.com	Milwaukee	Wisconsin	869988724766930143	0077f2a64285f65ae8f244523456590d	American Express	43.071020148935915	-88.0652411669127702
31071	2020-06-15 17:46:46	2020-06-15	Sofia Shields DVM	sofia.shields.dvm@geemail.com	Jersey City	New Jersey	3158131069757975005	73812c3c4891135515f2c15c0d1d293f	JCB 16 digit	40.6866710830420217	-74.0624191306021089
31072	2020-06-15 17:48:40	2020-06-15	Sherwood Farrell-Torp	sherwood.farrell.torp@geemail.com	Philadelphia	Pennsylvania	869987394419246775	63491df134f65cd813fc251dc4b3da68	VISA 16 digit	39.9626700694631793	-75.0971504972215769
31073	2020-06-15 17:57:34	2020-06-15	Toriano Schmitt	toriano.schmitt@warmmail.com	San Francisco	California	3096034768843811920	c941c8f909856535e72638f2c2a8b7af	Diners Club / Carte Blanche	37.7877439960025683	-122.404278182037203
31074	2020-06-15 17:58:20	2020-06-15	Mrs. Gaye Beier	mrs.gaye.beier@geemail.com	Virginia Beach	Virginia	6011236224300641125	a63e3903a02a134eddf75d4a16879e50	Voyager	36.7672455007396621	-75.9886455835912358
31075	2020-06-15 17:58:55	2020-06-15	Wayde Kunze	wayde.kunze@geemail.com	Des Moines	Iowa	4301248456390575	d3a140bd9c585d2569f5023f708b4775	American Express	41.6690098322205245	-93.6878870734524014
31076	2020-06-15 17:59:03	2020-06-15	Soloman Corwin	soloman.corwin@geemail.com	San Francisco	California	6011022266077932185	7e02b314df8977812821ec3fcda3966a	JCB 15 digit	37.7784305034741976	-122.458937259599196
31077	2020-06-15 18:00:14	2020-06-15	Dr. Merton Heathcote PhD	dr.merton.heathcote.phd@geemail.com	San Francisco	California	3096687045573640021	a5df93fd23c5ad4aeb2f536815963d00	American Express	37.7744783205970194	-122.418026012258537
31078	2020-06-15 18:03:23	2020-06-15	Yancy Bernhard	yancy.bernhard@geemail.com	Anaheim	California	4006690318007905	8841a6a93d67b117db08f063973b71f6	Discover	33.7922144496645771	-117.797067192916188
31079	2020-06-15 18:10:28	2020-06-15	Edw Pacocha-Rohan	edw.pacocha.rohan@warmmail.com	Austin	Texas	54111215616895637	9198ad29d335789258f25424df34a6b8	Mastercard	30.2613224459473038	-97.6793859945848624
31080	2020-06-15 18:25:05	2020-06-15	Deangelo Douglas	deangelo.douglas@geemail.com	Orlando	Florida	4382155694006925	f4e8fa686017e68fb92be117f5a9064a	Mastercard	28.466405772723629	-81.2869268563076872
31081	2020-06-15 18:27:07	2020-06-15	Dr. Jon Zboncak	dr.jon.zboncak@woohoo.com	Joliet	Illinois	3038567008089054	6dc5411184c6130f588bbf00390cd567	Maestro	41.4719840004898614	-88.103451809530327
31082	2020-06-15 18:40:54	2020-06-15	Alyssia Ritchie-Kemmer	alyssia.ritchie.kemmer@geemail.com	San Francisco	California	4224919515348051	f9fa261d1b5cd47327fde0a03f3b84ad	VISA 13 digit	37.751082092766211	-122.418686392242336
31083	2020-06-15 18:52:03	2020-06-15	Ms. Adelynn Moen PhD	ms.adelynn.moen.phd@woohoo.com	Newark	New Jersey	3770169564837217	3fdcf963889c36ceafc588854e97b54c	Mastercard	40.775576939192419	-74.2229172708209575
31084	2020-06-15 19:04:59	2020-06-15	Rosevelt Keebler	rosevelt.keebler@geemail.com	Westminster	Colorado	54645256463528413	af9d8712d597679b3d3d1977c70b4c44	Discover	39.9481700028132636	-105.131735122078666
31085	2020-06-15 19:16:59	2020-06-15	Ms. Muriel Parker DDS	ms.muriel.parker.dds@warmmail.com	San Antonio	Texas	869929515435906676	6e92609599273c37acfe4f1d38083b1e	JCB 15 digit	29.4367624042626481	-98.5041558648761253
31086	2020-06-15 19:19:06	2020-06-15	Dr. Daisy Towne MD	dr.daisy.towne.md@geemail.com	New York	New York	3337517748962741047	397b09250a5abd128f99c15a8be8ad5a	JCB 15 digit	40.5911243978645615	-73.946219134227178
31087	2020-06-15 19:19:38	2020-06-15	Akira Steuber	akira.steuber@geemail.com	Stockton	California	3158130506793404988	818f0ccf2361126d6756cb5b959c6629	JCB 16 digit	38.0238509166717549	-121.283502498277642
31088	2020-06-15 19:20:18	2020-06-15	Dr. Vincenzo Schaefer	dr.vincenzo.schaefer@woohoo.com	Renton	Washington	3528494715070086893	65b02864b111b9c4686f492546bfb5c4	VISA 13 digit	47.4812898961421155	-122.249494587218379
31089	2020-06-15 19:30:05	2020-06-15	Ilma Moore DDS	ilma.moore.dds@warmmail.com	Philadelphia	Pennsylvania	6011177257262728085	b477181cea9656c3937bd61e45aac2ea	JCB 15 digit	39.9364821629092077	-75.1123365615394079
31090	2020-06-15 19:40:35	2020-06-15	Aidyn Walsh	aidyn.walsh@geemail.com	San Antonio	Texas	4478825157328538	07f8acbcdc2a5b43d7cd52899b1dd6e3	Discover	29.4056633089274158	-98.5610792457427749
31091	2020-06-15 20:05:17	2020-06-15	Mohammed Shanahan-Murray	mohammed.shanahan.murray@geemail.com	Columbus	Ohio	3096263421388851289	e820130273f1d0bec1a345821c181672	Discover	39.8853353648956883	-83.0512298975374677
31092	2020-06-15 20:26:26	2020-06-15	Makenzie Huel DDS	makenzie.huel.dds@warmmail.com	San Francisco	California	4444342780663126	e4e744d2b11035ffabb025ba0cffb1ba	VISA 16 digit	37.7962439169040394	-122.414608249734471
31093	2020-06-15 20:33:53	2020-06-15	Donnell Green	donnell.green@geemail.com	Sacramento	California	869978797222934802	530352b3f73664c89f0b671286d904bf	JCB 15 digit	38.5247948133185503	-121.4175974189084
31094	2020-06-15 21:15:14	2020-06-15	Mace Bernhard	mace.bernhard@geemail.com	Los Angeles	California	4956784631278341	909d60f5a1cf0f4f2f6ad2ddb4015198	JCB 16 digit	33.9318591237399687	-118.45276054860949
31095	2020-06-15 21:31:58	2020-06-15	Dow Christiansen DVM	dow.christiansen.dvm@geemail.com	Bellevue	Washington	3112112679588047056	41e860a8c9893be94777c718f8702a83	JCB 16 digit	47.6531476117853074	-122.091490877937517
31096	2020-06-15 21:49:08	2020-06-15	Babyboy Conn	babyboy.conn@geemail.com	Washington	District of Columbia	3015309331033621	200359b89ad85b3856af0e4182b0e7e3	Maestro	38.8249348425105225	-77.0015237520661202
31097	2020-06-15 21:50:16	2020-06-15	Wes Okuneva-Lubowitz	wes.okuneva.lubowitz@geemail.com	Riverside	California	3778771409693192	e6576203c43e2d173524ca51f65d0b69	VISA 16 digit	33.944970891293508	-117.294482782200717
31098	2020-06-15 21:53:01	2020-06-15	Encarnacion Baumbach	encarnacion.baumbach@geemail.com	Los Angeles	California	869926882176972991	ab10f162db92d3428aad6d37cf7c1d5e	JCB 16 digit	33.9311427327204456	-118.48799797552563
31099	2020-06-15 21:57:15	2020-06-15	Keenan Ebert	keenan.ebert@geemail.com	Lakewood	New Jersey	501846897399062	a195542559b9c8f14bb593d17b98d268	Mastercard	39.9825556806106164	-74.2935189596653061
31100	2020-06-15 22:08:40	2020-06-15	Mellie Kunze	mellie.kunze@geemail.com	Jersey City	New Jersey	3036275556877035	22d230437ced6911981764b21a3a6616	JCB 16 digit	40.7781216898873424	-74.1462594999887159
31101	2020-06-15 22:10:48	2020-06-15	Pranav Parker	pranav.parker@geemail.com	Oakland	California	3158252055903397577	998f1fddb41f290bc14156bbcc73836d	Mastercard	37.8309316328776646	-122.263476812856595
31102	2020-06-15 22:56:12	2020-06-15	Dr. Ludwig Kunde	dr.ludwig.kunde@geemail.com	New York	New York	6011346182344982656	558d82469e5154061365ead2ae784656	VISA 16 digit	40.7240788310524096	-73.8850025744538783
31103	2020-06-15 23:03:34	2020-06-15	Kim Hermann	kim.hermann@geemail.com	Mobile	Alabama	4655768399648021	3b8cea7d5d69a612a5f7ec51d055b4f0	Maestro	30.7281296304069436	-88.0386767104871524
31104	2020-06-15 23:03:42	2020-06-15	Cleo Johnson	cleo.johnson@woohoo.com	New York	New York	3096817839499046690	9e29cc09699fdf54c42a4a4a505105c5	JCB 16 digit	40.6976331347823148	-73.9375222546875506
31105	2020-06-15 23:10:30	2020-06-15	Belva Bode	belva.bode@geemail.com	Warren	Michigan	3034096434214486	e3a711e2ea17ae7029693c08caede5b0	JCB 15 digit	42.5026894439008061	-83.085159990889963
31106	2020-06-15 23:12:27	2020-06-15	Parley Medhurst	parley.medhurst@geemail.com	Austin	Texas	3036084563417326	744bbedfa2f1fad3d29952f19c3bdd28	JCB 15 digit	30.4014805321708295	-97.8019303302053373
31107	2020-06-15 23:16:14	2020-06-15	Lorinda Stoltenberg-Weber	lorinda.stoltenberg.weber@geemail.com	Newark	New Jersey	54591472496581725	a73f4f1bedc4c87d35b451d2021ae630	Mastercard	40.6331290715754037	-74.1187546000558939
31108	2020-06-15 23:20:59	2020-06-15	Rozanne Ankunding	rozanne.ankunding@geemail.com	Chicago	Illinois	869951180764023923	f48eb12b41d1fe4d1bca0b79a055255c	VISA 16 digit	41.7409905201125895	-87.6543000955630021
31109	2020-06-15 23:24:22	2020-06-15	Zachariah Turner-Bartell	zachariah.turner.bartell@geemail.com	Salem	Oregon	3470037405521516	28bc782bf8b4056f6c2e00107f04d51b	Diners Club / Carte Blanche	44.8530270355556127	-122.937051672830066
31110	2020-06-15 23:34:11	2020-06-15	Alston Mayert	alston.mayert@geemail.com	New York	New York	180081668116691979	8d988bbab73296547f33a801e88513a2	Diners Club / Carte Blanche	40.6593077188115544	-73.8655113822210581
31111	2020-06-15 23:50:59	2020-06-15	Elsie Toy-Wilkinson	elsie.toy.wilkinson@warmmail.com	Beaumont	Texas	3088677047802943699	8cd0fd891728c9783102f0bbceabff47	Maestro	30.0463861161913748	-94.0472944071769774
31112	2020-06-16 00:03:54	2020-06-16	Becky Donnelly DVM	becky.donnelly.dvm@geemail.com	Los Angeles	California	869910554249351838	52c16ca85e45a057c25f0e0ea7e21cc1	American Express	34.1188241982232725	-118.374534268490223
31113	2020-06-16 00:12:22	2020-06-16	Dr. Johnathan Runte V	dr.johnathan.runte.v@geemail.com	San Antonio	Texas	4727573179037294	ae323d98b29e33754ba45cd962da47cd	Discover	29.496322708025204	-98.4933309567928319
31114	2020-06-16 00:20:21	2020-06-16	Clemie Hessel	clemie.hessel@geemail.com	Saint Paul	Minnesota	4305944695003153	98cdeb142b3300dc23fd835191a035af	JCB 15 digit	44.9580482975520184	-93.0810813364371654
31115	2020-06-16 00:23:28	2020-06-16	Jamel Brakus	jamel.brakus@geemail.com	Phoenix	Arizona	51872241078196768	2c3716390c23653c2cfb4e50a555d4d8	JCB 16 digit	33.5394361403238079	-111.991295094874133
31116	2020-06-16 00:26:50	2020-06-16	Zandra Gerlach	zandra.gerlach@woohoo.com	Jacksonville	Florida	4780685198550133	8b0b8d39684df600c04167531b892a3a	VISA 16 digit	30.30567997657284	-81.7091975100882451
31117	2020-06-16 00:27:28	2020-06-16	Ms. Yamilex Cole	ms.yamilex.cole@geemail.com	Lowell	Massachusetts	3528253183674592264	ae804bb3d54ecb4e0d0c48611d61e810	JCB 16 digit	42.6656777133569136	-71.2891028192698997
31118	2020-06-16 00:40:26	2020-06-16	Mr. Henery Auer I	mr.henery.auer.i@woohoo.com	Minneapolis	Minnesota	3528768121150953897	73fad15ea6cff70abe21a50c112a81ac	VISA 16 digit	44.893665228932349	-93.3021480603881201
31119	2020-06-16 00:43:08	2020-06-16	Laurie Huels	laurie.huels@woohoo.com	Glendale	California	3048091593199228	524749c7c6f63f06f29491b92e20b0bb	VISA 16 digit	34.093416101507465	-118.194720948337761
31120	2020-06-16 01:15:50	2020-06-16	Mr. Gregg Zemlak	mr.gregg.zemlak@geemail.com	Paterson	New Jersey	3158402899425304424	b2030051125620d17e7d1737ebaf8863	JCB 15 digit	40.8678029751360441	-74.0963672682151184
31121	2020-06-16 01:15:59	2020-06-16	Izaiah Hamill	izaiah.hamill@geemail.com	Knoxville	Tennessee	3096445065840870063	e3fb9e8f963e5da9c1db6a1da2bb6d52	VISA 16 digit	35.9837047359969446	-83.8860476672865332
31122	2020-06-16 01:24:53	2020-06-16	William Gerhold	william.gerhold@woohoo.com	San Diego	California	6011438115075990695	f5c06d7cc2673eb65d465d7aa1ae5c2c	JCB 16 digit	32.7370453584074994	-117.20145679953508
31123	2020-06-16 01:26:34	2020-06-16	Meagan Lesch-Braun	meagan.lesch.braun@geemail.com	St. Louis	Missouri	869990712721027572	5defd460ad124a2d36907f6d668f755f	VISA 13 digit	38.5547175194758935	-90.1459082072604474
31124	2020-06-16 01:31:25	2020-06-16	Mrs. Maci Collins MD	mrs.maci.collins.md@geemail.com	San Francisco	California	6011784523706720516	b4afcab4fefde40607c54e2450a4fa15	JCB 16 digit	37.7671664826995155	-122.419463809106503
31125	2020-06-16 01:32:01	2020-06-16	Dr. Isaias Wisoky	dr.isaias.wisoky@geemail.com	New York	New York	676354238023771	40aca0239d70d733f49d0e3dcfbe7e05	Mastercard	40.583372592296449	-73.9924656669039251
31126	2020-06-16 01:43:37	2020-06-16	Mrs. Letitia Beier PhD	mrs.letitia.beier.phd@geemail.com	Los Angeles	California	4587065378354918	e2d9b7bc295098b0c53bbe7ecead64ab	Diners Club / Carte Blanche	34.0157909186888432	-118.387193227232615
31127	2020-06-16 02:04:52	2020-06-16	Mariyah Sporer	mariyah.sporer@woohoo.com	Lakewood	Colorado	180090105054926447	f31a47ed42fab275e97ec2e76ab2b4c3	VISA 16 digit	39.7008134031608719	-105.107621827770387
31128	2020-06-16 02:11:31	2020-06-16	Mike Rohan	mike.rohan@geemail.com	San Antonio	Texas	3038468212829031	a0f1bdbb8a461a29fecfe81819d198df	Voyager	29.4513836171083163	-98.5020985890947287
31129	2020-06-16 02:12:35	2020-06-16	Saige Beier	saige.beier@geemail.com	Berkeley	California	4434592259313668	a5c5c631a1a3b9228b8bdc5e72f65a9d	VISA 13 digit	37.8693917924594388	-122.275763794840302
31130	2020-06-16 02:22:32	2020-06-16	Dr. Clementina Hudson DDS	dr.clementina.hudson.dds@geemail.com	San Francisco	California	210035455851743422	e6c87b5646c42dda9e3749bb3f30dcfe	Maestro	37.7692479796818503	-122.435060352449
31131	2020-06-16 02:26:42	2020-06-16	Alto Walter	alto.walter@warmmail.com	Green Bay	Wisconsin	4136657826280145	32de90c02533c32f8f36f97c1796b15b	VISA 13 digit	44.5509081862464527	-87.9369720375452175
31132	2020-06-16 02:28:34	2020-06-16	Irine Powlowski	irine.powlowski@geemail.com	New York	New York	55433872158436120	7a8855b5a7b03039eab14fcaae9ee96f	VISA 13 digit	40.6841739035900645	-73.911789309409258
31133	2020-06-16 02:35:50	2020-06-16	Clotilde Funk	clotilde.funk@geemail.com	Houston	Texas	3002418952386854	49b297ec62dfeda16339f45f8ee9ebbe	JCB 16 digit	29.8102470323521658	-95.4892102465514085
31134	2020-06-16 02:47:29	2020-06-16	Jose Skiles	jose.skiles@geemail.com	San Francisco	California	630413678718951	83e5e0f99f1c0c3b359792f4d06fec59	JCB 16 digit	37.7631269721780924	-122.437381359258367
31135	2020-06-16 02:51:37	2020-06-16	Lemuel Kertzmann	lemuel.kertzmann@geemail.com	San Francisco	California	3778306714731971	50a1e49d6027db34eae6122e6afcad36	JCB 15 digit	37.7773269180623004	-122.430466040276642
31136	2020-06-16 03:05:52	2020-06-16	Joni Gorczany	joni.gorczany@geemail.com	Irvine	California	6011850939669647125	86221aa57c48d6dc5984b2cb52656633	JCB 15 digit	33.6002530368991259	-117.702359680366882
31137	2020-06-16 03:11:40	2020-06-16	Jarett Boehm	jarett.boehm@geemail.com	Rockford	Illinois	4193598485681	df95e86a1ec9ec9ed2ca62cbe528e703	JCB 16 digit	42.2763259546842463	-89.1545243797641263
31138	2020-06-16 03:15:42	2020-06-16	Cristobal Kuhlman-Davis	cristobal.kuhlman.davis@woohoo.com	Nashville	Tennessee	3158360462910602735	df77b919927f39d170359102e4acac53	JCB 16 digit	36.1637199513271455	-86.83368993028067
31139	2020-06-16 03:22:09	2020-06-16	Domenic Nienow	domenic.nienow@geemail.com	Phoenix	Arizona	3005076874063055	0e50dfca6a05e0ed096b38e47215ed68	Voyager	33.6428826704554282	-112.038801474349953
31140	2020-06-16 03:23:16	2020-06-16	Jaleel Hills-Kerluke	jaleel.hills.kerluke@geemail.com	Shreveport	Louisiana	3010358909264527	66f2d3a29282b233710692c39f6c12e5	Discover	32.4737012825213398	-93.7985862150534899
31141	2020-06-16 03:28:23	2020-06-16	Dr. Kayla Maggio	dr.kayla.maggio@geemail.com	Omaha	Nebraska	3759924967905309	63e4d74e8d2ad71b29e0a7a208724b48	Discover	41.1858943606872145	-96.0824930996749629
31142	2020-06-16 03:41:50	2020-06-16	Kelsey Skiles III	kelsey.skiles.iii@geemail.com	Kenosha	Wisconsin	51820364680386545	4056d0bbcbbda2d1992bd85e4f1851fd	Discover	42.6180243783004613	-87.7959820243291631
31143	2020-06-16 03:50:29	2020-06-16	Junius Rohan MD	junius.rohan.md@geemail.com	Anchorage	Alaska	54012837075038142	537dd2975ffef3ff18c856db9091f068	Maestro	61.1605340745516131	-149.296118707222121
31144	2020-06-16 03:50:37	2020-06-16	Daria Bayer	daria.bayer@geemail.com	Allen	Texas	54219183787662395	3f1ba041758f58ec80deb68ea5fb08af	American Express	33.1275353904373944	-96.6009516684751901
31145	2020-06-16 04:18:59	2020-06-16	Omie Borer	omie.borer@geemail.com	Modesto	California	869908388645354631	261276adf70e45eaf06728190705089e	Discover	37.5853959036525396	-121.034243709055701
31146	2020-06-16 04:23:33	2020-06-16	Hadassah Daugherty DDS	hadassah.daugherty.dds@geemail.com	Newark	New Jersey	4563399835579249	22777337cefde3a08372aa1eec2518ce	Maestro	40.658953844141962	-74.2673773742955206
31147	2020-06-16 04:30:44	2020-06-16	Alvan Howell	alvan.howell@geemail.com	Sacramento	California	4859355776146193	89d29bb4c9f204ab621626d8c51e9d46	JCB 16 digit	38.579746490789951	-121.548416015902902
31148	2020-06-16 04:32:21	2020-06-16	Ozell Fisher PhD	ozell.fisher.phd@geemail.com	Columbus	Ohio	3528664843140107459	8d26d16cadf02e28eb5c59a6933d404e	Voyager	40.0605464960958813	-82.9838825363900554
31149	2020-06-16 04:34:19	2020-06-16	Kendal Welch	kendal.welch@geemail.com	Baton Rouge	Louisiana	676362589342583	65de443273aefb85f7e9f3203852ff38	VISA 16 digit	30.5174480832394224	-91.1927742297403512
31150	2020-06-16 04:47:47	2020-06-16	Mrs. Taryn Paucek DVM	mrs.taryn.paucek.dvm@geemail.com	Burbank	California	3469043700530445	30acbe9b531f0d7949cd6e92027cff11	Discover	34.2821797214843329	-118.263884147679065
31151	2020-06-16 05:03:25	2020-06-16	Marquez Stokes	marquez.stokes@woohoo.com	Berkeley	California	53758027263260363	d9de54a01c66ac299e40b7790044314c	Diners Club / Carte Blanche	37.8901281085776276	-122.234489816884491
31152	2020-06-16 05:12:26	2020-06-16	Mr. Austin White II	mr.austin.white.ii@geemail.com	Austin	Texas	3096779955106001435	764e7e6f188f1ad4588f56775dca6f05	Mastercard	30.3824705230198795	-97.7620382147613896
31153	2020-06-16 05:33:32	2020-06-16	Liberty Howell-Fay	liberty.howell.fay@geemail.com	Berkeley	California	639017310933837	44c3160ea400243bddec9980aed507f4	JCB 16 digit	37.8738597443379916	-122.288360365034364
31154	2020-06-16 05:48:49	2020-06-16	Miss Margo Schinner	miss.margo.schinner@geemail.com	Seattle	Washington	210035401105811334	c24fc40634343cca6709ab071c1c93b9	Diners Club / Carte Blanche	47.5753588463105288	-122.359482719322287
31155	2020-06-16 05:49:24	2020-06-16	Alvy Christiansen	alvy.christiansen@geemail.com	Santa Ana	California	55809284056898441	bc11d052e43471ef417ad465fe95e78c	Maestro	33.7965932672947673	-117.966566569676615
31156	2020-06-16 05:51:30	2020-06-16	Maritza Kris	maritza.kris@warmmail.com	New York	New York	869902167101447121	e9b7d5aaefb93e1b04738dc4246e60fa	American Express	40.7189440783802397	-73.9138392045989576
31157	2020-06-16 05:59:59	2020-06-16	Dr. True Grant	dr.true.grant@geemail.com	Houston	Texas	3453900365881215	0adf434de814a5c26b8cefa66e62bd42	VISA 16 digit	29.855508730940894	-95.3564278703197914
31158	2020-06-16 06:04:49	2020-06-16	Alexande Krajcik	alexande.krajcik@geemail.com	Portland	Oregon	561250234649049	f56839ef66d0c32600ae5ce25a54b908	VISA 16 digit	45.5048433915600157	-122.699453561054554
31159	2020-06-16 06:12:32	2020-06-16	Sammie Kuvalis	sammie.kuvalis@woohoo.com	Denton	Texas	51356825665399069	125752afcd8c4c6c2e02cddbcd9d1558	VISA 13 digit	33.1953970909848834	-97.1980830300260408
31160	2020-06-16 06:22:22	2020-06-16	Rosemarie Hayes	rosemarie.hayes@warmmail.com	San Francisco	California	3112168204804275648	d51cf9afb7302bc760ac0bf5d30feee5	VISA 16 digit	37.7884711324751805	-122.420417476448151
31161	2020-06-16 06:25:46	2020-06-16	Tisha Wisozk DVM	tisha.wisozk.dvm@woohoo.com	Anaheim	California	3112672612525777610	83c3ab3c837fb675ed470c3c268b82f6	American Express	33.8529816172849394	-117.781543995134896
31162	2020-06-16 06:27:23	2020-06-16	Minnie Lind	minnie.lind@warmmail.com	San Antonio	Texas	6011445413554030518	c3d509d40e2b98232423a2e6f3d34a52	JCB 16 digit	29.4491350002191972	-98.4354183920029442
31163	2020-06-16 06:31:39	2020-06-16	Windell Windler	windell.windler@geemail.com	San Jose	California	54910020089515925	09c9608dd72e87024f413735028a6460	JCB 16 digit	37.2374797720748916	-121.844061089608445
31164	2020-06-16 06:41:43	2020-06-16	Mrs. Jenilee Heathcote	mrs.jenilee.heathcote@geemail.com	Fort Worth	Texas	3528542076100593974	1ab7db1d280c2358bd6dc9ece21775db	Voyager	32.853829475032164	-97.3553434321012361
31165	2020-06-16 06:47:28	2020-06-16	Miss Odell O'Connell DVM	miss.odell.o'connell.dvm@geemail.com	New York	New York	676105309123460	1af2796268531768a39be49dda8a3c0d	Maestro	40.6159069953244156	-74.0115945163078521
31166	2020-06-16 06:52:02	2020-06-16	Tanisha Hermiston	tanisha.hermiston@woohoo.com	New York	New York	3789325525434424	f39548f9252cad2de68ac6a938174a1b	American Express	40.6137686473075306	-73.8921325805958276
31167	2020-06-16 07:17:06	2020-06-16	Jill Pfannerstill	jill.pfannerstill@warmmail.com	Fullerton	California	4792166848137	f422d4a182ac71612cf1f26d7912ca66	Mastercard	33.8289671870104982	-117.95929377025179
31168	2020-06-16 07:22:49	2020-06-16	Floy Langworth-Willms	floy.langworth.willms@geemail.com	Jacksonville	Florida	3528207273935714190	8af953d1b42ff6cbd2861cf73826c13d	VISA 13 digit	30.2869621331855647	-81.6289402599059173
31169	2020-06-16 07:30:34	2020-06-16	Kellan DuBuque	kellan.dubuque@geemail.com	Oxnard	California	4383518184460	72e2d9fa8b090cfaa13689826511cc52	Maestro	34.2021490701429585	-119.174489808725568
31170	2020-06-16 07:38:41	2020-06-16	Miss Esperanza Anderson	miss.esperanza.anderson@woohoo.com	Indianapolis	Indiana	6011111442818508392	05730309b5f69e4584fb23a5e7b4f543	VISA 13 digit	39.7888550884097825	-86.1244136249847685
31171	2020-06-16 07:40:36	2020-06-16	Darci Baumbach-Bayer	darci.baumbach.bayer@geemail.com	Houston	Texas	4230968980681225	b879ff45b46ecd8b0e59bfcf6bdb9773	JCB 15 digit	29.7868057141158715	-95.3835444342825554
31172	2020-06-16 07:48:47	2020-06-16	Josiephine McGlynn	josiephine.mcglynn@geemail.com	Boston	Massachusetts	3469820842417213	54f28caff60eca25a9f73ade6bf83327	Voyager	42.4232806685548312	-71.0037420219227755
31173	2020-06-16 08:23:55	2020-06-16	Jaylen Schamberger-Hermiston	jaylen.schamberger.hermiston@geemail.com	Berkeley	California	501865455155021	22a9a6e0c5f2e0de249e4a8ab648657c	VISA 16 digit	37.8750665257904799	-122.289616771336199
31174	2020-06-16 08:30:54	2020-06-16	Kaylan Schumm	kaylan.schumm@geemail.com	Minneapolis	Minnesota	869963167883506736	fd5d8c25a47296e18e106dab6a196ab1	JCB 15 digit	44.9066681165333819	-93.2071281629420838
31175	2020-06-16 08:37:14	2020-06-16	Sussie Ullrich	sussie.ullrich@woohoo.com	Indianapolis	Indiana	54733217988918318	4296ff1e79b3cb66ddf0e8b5154c168b	Maestro	39.8452332626569969	-86.234190608953682
31176	2020-06-16 08:38:05	2020-06-16	Maudie Rau	maudie.rau@geemail.com	Buffalo	New York	503840671394720	612ebe1c3d3d3686dc1b39c956d1d08b	Diners Club / Carte Blanche	42.9502358628157523	-78.7833478023231066
31177	2020-06-16 08:39:51	2020-06-16	Heath Kiehn-Blanda	heath.kiehn.blanda@geemail.com	Charlotte	North Carolina	869962083148382287	a7fb39166f1c3a15691818d3d0356f97	JCB 15 digit	35.1823534433051961	-80.8820993769858063
31178	2020-06-16 08:45:44	2020-06-16	Ford Aufderhar	ford.aufderhar@woohoo.com	Jackson	Mississippi	869929551568557481	69989eba352163c8b41d96647459f697	Voyager	32.38626259650961	-90.2139533904820752
31179	2020-06-16 08:48:46	2020-06-16	Zandra Orn PhD	zandra.orn.phd@geemail.com	Tucson	Arizona	3003506859531363	2fcb22d522b3ca2240cd621c4081780b	American Express	32.1583879751659936	-110.949475343780961
31180	2020-06-16 08:56:02	2020-06-16	Arvo Ebert DVM	arvo.ebert.dvm@geemail.com	McKinney	Texas	869965589061833962	b3d842ff88e51fb3d16cb49f77fbb934	JCB 16 digit	33.1882316245362219	-96.5689363950230302
31181	2020-06-16 09:02:00	2020-06-16	Dr. Brennan Monahan DDS	dr.brennan.monahan.dds@geemail.com	San Jose	California	4088384777997159	13a543612f0cd1b9298b79447a8a35d7	VISA 13 digit	37.304581126366557	-121.858355795334646
31182	2020-06-16 09:09:55	2020-06-16	Santa Schultz	santa.schultz@geemail.com	New York	New York	180071367231340024	225d237b49d4076f861e5d4f7f147ee6	Mastercard	40.7388668428398688	-73.9132840973220766
31183	2020-06-16 09:29:57	2020-06-16	Ashtyn Ortiz	ashtyn.ortiz@geemail.com	Des Moines	Iowa	6011525574667016513	3c639c1729c1594e7cef6ff72dcffb01	American Express	41.5722705037076068	-93.5149307143453541
31184	2020-06-16 09:45:58	2020-06-16	Marcelle Veum	marcelle.veum@geemail.com	Columbus	Ohio	3337635169142045869	16219fdc62e53696c0d2f5055c1e64e4	Diners Club / Carte Blanche	40.0842315034985504	-83.0500541281189868
31185	2020-06-16 10:16:16	2020-06-16	Edwina Swaniawski	edwina.swaniawski@geemail.com	Fontana	California	3088996060712904200	168888c7cdcc1336ec5f4dcaac4260d6	Voyager	34.1681945212334384	-117.439333195127176
31186	2020-06-16 10:20:58	2020-06-16	Miss Rashida Hintz PhD	miss.rashida.hintz.phd@geemail.com	Chicago	Illinois	3039264582833060	73f760f2afbe11346898d2b1a08720aa	JCB 15 digit	41.8536236794967209	-87.7123843512061967
31187	2020-06-16 10:45:05	2020-06-16	Sampson Keeling	sampson.keeling@geemail.com	San Francisco	California	6011077897463381852	f5db99ecaad9a2b4157e583acd50495a	VISA 16 digit	37.7764739540485905	-122.43143769052044
31188	2020-06-16 10:46:09	2020-06-16	Mr. Jamey Breitenberg IV	mr.jamey.breitenberg.iv@geemail.com	St. Louis	Missouri	4549891997114616	8477cb839bf9a7a421bc2f283a9461a6	JCB 16 digit	38.7064961366511895	-90.1677581117957914
31189	2020-06-16 10:46:46	2020-06-16	Barney Kutch	barney.kutch@geemail.com	Austin	Texas	4687681365718	1c110cc1bf082569c9d863877c44c3f7	Discover	30.3995348608713591	-97.8150481047347284
31190	2020-06-16 10:51:28	2020-06-16	Dr. Lilyan Sawayn	dr.lilyan.sawayn@geemail.com	Berkeley	California	676365949951282	b03adb39b2e675e2e65855bafa652643	Discover	37.866296760164829	-122.248285130852835
31191	2020-06-16 10:56:23	2020-06-16	Duane Koch	duane.koch@geemail.com	San Francisco	California	3096069939063729211	e63c05d0cbd5e464c993d882d4aaa0d5	VISA 16 digit	37.7703201814360838	-122.412798057599915
31192	2020-06-16 10:59:51	2020-06-16	Vinnie Haag	vinnie.haag@geemail.com	Oakland	California	869976095482151031	c34731bd5494af52f5db4244f6b07fcc	Mastercard	37.8202340192280602	-122.281409967901197
31193	2020-06-16 11:09:22	2020-06-16	Miss Jaslene Muller	miss.jaslene.muller@geemail.com	Plano	Texas	4010929901134799	653b1a0308d2e20626b0605a9ed09a98	VISA 16 digit	33.1357044355563843	-96.6879410870090084
31194	2020-06-16 11:09:42	2020-06-16	Madonna Bosco	madonna.bosco@geemail.com	Columbus	Georgia	4074002915234	bc41f5a3e199eaaaabbd595871af679b	VISA 16 digit	32.5385816245384518	-84.853232384768873
31195	2020-06-16 11:14:31	2020-06-16	Bill Dare	bill.dare@geemail.com	Dallas	Texas	4372265207806398	66dc445b7aadf828845f5c9ec8e83a57	Mastercard	32.7683303579494378	-96.7804158057048909
31196	2020-06-16 11:19:05	2020-06-16	Mrs. Suellen Gerhold	mrs.suellen.gerhold@geemail.com	Houston	Texas	3096693364582779627	1ca84dc5383e8f43e0b28a65407607ec	VISA 16 digit	29.7465748880136758	-95.3474295898355564
31197	2020-06-16 11:29:00	2020-06-16	Wynona Mohr	wynona.mohr@warmmail.com	Chicago	Illinois	3112674907733659685	b124913b33cbc1f9fd9cf54b853a2ff6	VISA 16 digit	41.8526080861523795	-87.6885404252942635
31198	2020-06-16 11:32:19	2020-06-16	Stafford Kreiger	stafford.kreiger@geemail.com	Tucson	Arizona	210025708979497400	2f075d5ee67998ebc133d1a5a0d968f2	VISA 13 digit	32.1992885916534846	-110.822364060417186
31199	2020-06-16 11:32:53	2020-06-16	Forest Glover DDS	forest.glover.dds@warmmail.com	Kansas City	Missouri	4455265325734	0240ad0f948fc3bbf3175f5451ccccce	JCB 16 digit	39.0641964911784996	-94.6288230385854803
31200	2020-06-16 11:39:42	2020-06-16	North Gulgowski	north.gulgowski@geemail.com	Tampa	Florida	6011376512859859787	50f8cf2a30fcbaab7ea1d1f6ed204904	Diners Club / Carte Blanche	28.0401045261066386	-82.439515847128618
31201	2020-06-16 11:42:26	2020-06-16	Christal Hilll PhD	christal.hilll.phd@woohoo.com	Huntsville	Alabama	3088526327057783765	eff9bbdbcd413e3ed8d63b3bed0e6b14	American Express	34.6029562453050161	-86.6854526978004714
31202	2020-06-16 11:45:15	2020-06-16	Dr. Juliette O'Reilly	dr.juliette.o'reilly@warmmail.com	Oakland	California	6011082101903205224	e0a7b5fe3d148e3b37773156d7149cf1	Mastercard	37.7728052997687271	-122.260083031372972
31203	2020-06-16 12:01:28	2020-06-16	Marland Pagac	marland.pagac@warmmail.com	Richmond	Virginia	180093737581916249	ae7fb1a75f69e0dc51480c92fc221fef	Mastercard	37.564539205118642	-77.5366898240279454
31204	2020-06-16 12:03:29	2020-06-16	Linn Runolfsson	linn.runolfsson@warmmail.com	Las Vegas	Nevada	3032898486348571	66bbca13ead62f4d32a5ecd042e5a93a	Voyager	36.2736352966267575	-115.312720291244233
31205	2020-06-16 12:09:14	2020-06-16	Dr. Amiya Oberbrunner	dr.amiya.oberbrunner@woohoo.com	Tulsa	Oklahoma	3445167156285714	e5100c3930ec681d861fc588c194a17b	JCB 16 digit	36.0478950711801645	-95.8075879788912772
31206	2020-06-16 12:16:56	2020-06-16	Laurie Daniel	laurie.daniel@geemail.com	San Mateo	California	3003696995617521	ead580ff2140a2c4ec6a2b773ea6faeb	Discover	37.5031297252394253	-122.391369265908736
31207	2020-06-16 12:51:39	2020-06-16	Rome Brakus	rome.brakus@geemail.com	West Palm Beach	Florida	869905830892222667	f8bfd5f3527bd52e8bc4d8b4a8acb6c5	Mastercard	26.788938029374556	-80.0536453713499014
31208	2020-06-16 13:03:00	2020-06-16	Minervia Ankunding MD	minervia.ankunding.md@geemail.com	Washington	District of Columbia	4690828852289130	7a12d248510ffdd52011f61eb774913b	American Express	38.9609437507841747	-77.1159368128728175
31209	2020-06-16 13:04:14	2020-06-16	Staci Lesch	staci.lesch@geemail.com	Spokane	Washington	3473064710631555	79d8521f9239b0ab76379a1cc703d39a	VISA 16 digit	47.7036617588024541	-117.333597643057999
31210	2020-06-16 13:05:07	2020-06-16	Mrs. Loren Bergstrom DDS	mrs.loren.bergstrom.dds@geemail.com	Charleston	South Carolina	501803748255373	ebd535b01f3cff40a189d8e0933dadaf	Voyager	32.7602925687093318	-79.9351295905336769
31211	2020-06-16 13:08:21	2020-06-16	Slade Rogahn	slade.rogahn@woohoo.com	Oakland	California	676261634991139	23a459e4fb7eb2032539f32ca4ba500f	American Express	37.7925517058977789	-122.262122223473199
31212	2020-06-16 13:25:16	2020-06-16	Abigale Dickens-Boyer	abigale.dickens.boyer@geemail.com	Garden Grove	California	4790059394166375	887dd5b9cace4fe4cebfd0c76d8dcf9b	Maestro	33.6861997665662258	-118.058524862166493
31213	2020-06-16 13:30:30	2020-06-16	Tayler Will	tayler.will@geemail.com	Santa Ana	California	501816901721999	39aff8c5f00a98e60da8e4890501c770	JCB 16 digit	33.7814996473129838	-117.941868111530312
31214	2020-06-16 13:58:50	2020-06-16	Arvo Cole Jr.	arvo.cole.jr.@geemail.com	Berkeley	California	53314894460749093	5ac5ae6db0dbf8375188bb8a20920f0f	Maestro	37.8817875091224678	-122.276237043451673
31215	2020-06-16 13:59:27	2020-06-16	Dr. Rakeem Considine IV	dr.rakeem.considine.iv@geemail.com	Newark	New Jersey	4422254743537147	b8ff959217400228c731ee18124fab95	Mastercard	40.6726071688726591	-74.2713766148988128
31216	2020-06-16 14:10:21	2020-06-16	Mr. Graham Rippin DVM	mr.graham.rippin.dvm@warmmail.com	New York	New York	3528461842858884049	365bddddba486a438f7e1044e6397eae	JCB 15 digit	40.6093434514235696	-73.8821515412896872
31217	2020-06-16 14:34:55	2020-06-16	Ms. Diya Kohler PhD	ms.diya.kohler.phd@woohoo.com	Lakeland	Florida	3096815963597160781	1c9a1e83b3a304052d8b137b69909424	American Express	28.1332178235352011	-81.9161389096990149
31218	2020-06-16 14:35:02	2020-06-16	Georgine Dooley	georgine.dooley@warmmail.com	San Francisco	California	3445556874949694	cf732f7c94073174d73049bc0b37daa0	JCB 16 digit	37.7730415179660923	-122.422889442411915
31219	2020-06-16 14:40:04	2020-06-16	Jazmyn Stokes	jazmyn.stokes@geemail.com	San Francisco	California	869976243525543463	4de3239d67bbf7087e12bf79691937d1	Voyager	37.7817639081622474	-122.404612265008168
31220	2020-06-16 14:45:33	2020-06-16	Chandler Larson	chandler.larson@geemail.com	San Francisco	California	3337160947013399330	278bea91629b499aa7c8a5a2cd2b65e1	Voyager	37.7976175050306438	-122.427013129661603
31221	2020-06-16 15:07:41	2020-06-16	Genevra Weissnat	genevra.weissnat@geemail.com	San Antonio	Texas	4849407226742940	859a1add89cf963fc0a4ae118df0ec5d	Diners Club / Carte Blanche	29.5480902410648767	-98.5495295466225514
31222	2020-06-16 15:14:58	2020-06-16	Severo Johns	severo.johns@geemail.com	Orlando	Florida	4898427665465	1e52ef42bd3101be0898d43702638f18	VISA 13 digit	28.3443195985428993	-81.3540780408274458
31223	2020-06-16 15:15:26	2020-06-16	Ricci Gutkowski-Denesik	ricci.gutkowski.denesik@geemail.com	San Francisco	California	869993831155897008	6bb755034f3a3b44b920514cfdabb41e	VISA 16 digit	37.7857571497543461	-122.430344493106233
31224	2020-06-16 15:22:32	2020-06-16	Reginald O'Reilly	reginald.o'reilly@warmmail.com	Oakland	California	869984317859884311	4cc6c9d1f921af8ba5701865e01c46e8	Mastercard	37.7674695394951883	-122.293694549262909
31225	2020-06-16 15:40:24	2020-06-16	Ms. Cherish Zemlak PhD	ms.cherish.zemlak.phd@geemail.com	San Francisco	California	54239376428866229	1a6001b07bd5303287072bd91beb6210	JCB 16 digit	37.7875622713361423	-122.368584528167574
31226	2020-06-16 16:04:57	2020-06-16	Brandin Wolff	brandin.wolff@geemail.com	Berkeley	California	55279177372127571	9a96716ea7801f1b3b5b6c79c4806109	Maestro	37.8763222359401865	-122.301669005861768
31227	2020-06-16 16:10:56	2020-06-16	Ms. Junia Durgan DVM	ms.junia.durgan.dvm@geemail.com	San Francisco	California	4225919580524494	2febdb01fe95d4507ddaeefa7073bd7b	VISA 13 digit	37.7750567858300954	-122.44282717405585
31228	2020-06-16 16:20:06	2020-06-16	Blanchard Farrell I	blanchard.farrell.i@geemail.com	Stockton	California	4313575949203312	93b2b8711387826c4ee3eeaee85f1574	VISA 16 digit	37.8892256713669795	-121.406987844881783
31229	2020-06-16 16:22:28	2020-06-16	Ike West	ike.west@geemail.com	Scottsdale	Arizona	3528654763963689452	32f7b561cc3b351ee734a5452c863352	VISA 13 digit	33.7127440882038343	-111.932155178577077
31230	2020-06-16 16:37:24	2020-06-16	Fulton Jast-Okuneva	fulton.jast.okuneva@geemail.com	Philadelphia	Pennsylvania	3088444078985471937	d000a0612772b2253be9f5da77fa3da2	JCB 16 digit	40.0042563541751335	-75.0741999581821347
31231	2020-06-16 16:49:57	2020-06-16	Isai Ferry	isai.ferry@geemail.com	Chicago	Illinois	869940124042749069	26e9a4b7685f4e0a6f38891c92c7c89b	American Express	41.7797884828247135	-87.6009198456101075
31232	2020-06-16 17:00:56	2020-06-16	Dr. Ashlyn Emmerich	dr.ashlyn.emmerich@woohoo.com	Peoria	Illinois	4335094742287310	89cd28e7f70e6d5b3f24b6f235e1161a	Maestro	40.7862061614505933	-89.6333959423821511
31233	2020-06-16 17:13:00	2020-06-16	Brett Maggio	brett.maggio@geemail.com	Philadelphia	Pennsylvania	3337836402970558829	6c2f1119323c5dc065f4d8c7bed4c79f	VISA 16 digit	39.9569263045635097	-75.1691292918652323
31234	2020-06-16 17:23:44	2020-06-16	Dr. Keenen Tremblay Jr.	dr.keenen.tremblay.jr.@woohoo.com	Jacksonville	Florida	676137230053177	517ef272a84d4748e52947544ab26fd2	VISA 16 digit	30.3736242956534035	-81.5799126949705311
31235	2020-06-16 17:24:54	2020-06-16	Phoenix Huel	phoenix.huel@geemail.com	Little Rock	Arkansas	501847378118179	f64b25fc1650e78667e6f05f97655a96	VISA 16 digit	34.6985901245191712	-92.3359920693900449
31236	2020-06-16 17:27:09	2020-06-16	Kieth Parker-Barrows	kieth.parker.barrows@geemail.com	New York	New York	4318414925418089	21c42eaa4df70e1896db7dec751d7428	VISA 16 digit	40.7613740562684796	-73.8976066268410534
31237	2020-06-16 17:39:26	2020-06-16	Lucinda Quitzon	lucinda.quitzon@warmmail.com	Rancho Cucamonga	California	589306660644276	cfc4fcf19579d50a8424d0ebebb585b1	VISA 16 digit	34.0954481343731288	-117.542990391469374
31238	2020-06-16 17:45:14	2020-06-16	Mallorie Schumm-Stanton	mallorie.schumm.stanton@woohoo.com	Oakland	California	3441338109200704	53d00c0e769c6c3fc0c585f14865e9b8	VISA 13 digit	37.8343824131481909	-122.249753221926568
31239	2020-06-16 18:18:04	2020-06-16	Talen Dare	talen.dare@geemail.com	San Jose	California	3096815590859364411	59601a152ee5e699dded9ea34f87d231	VISA 16 digit	37.3879056386470836	-121.851961776077374
31240	2020-06-16 18:26:20	2020-06-16	Payten Metz	payten.metz@woohoo.com	New York	New York	501828848679172	c6cbb0a579b08e2df6dfe174c624a314	VISA 16 digit	40.6177057348415218	-73.9142254446994542
31241	2020-06-16 18:36:04	2020-06-16	Tonya Homenick	tonya.homenick@geemail.com	Nashville	Tennessee	4541432946935369	865513ebd31ad087bf5859ef8f75bdc9	Mastercard	36.1792388484004874	-86.8197147257532862
31242	2020-06-16 18:43:48	2020-06-16	Minerva Mills-Gulgowski	minerva.mills.gulgowski@woohoo.com	Garland	Texas	4511891112119411	b5bd4aaf068cd8705a4eeb2d6ec63ebb	Discover	32.9132165340010019	-96.6117730816520748
31243	2020-06-16 18:49:30	2020-06-16	Cosmo Kihn	cosmo.kihn@geemail.com	Pomona	California	3337385175501941905	0bd7e63846a12234b869efbb68c95b45	Voyager	34.092248638210819	-117.806417667210468
31244	2020-06-16 18:56:13	2020-06-16	Hilton Cummerata	hilton.cummerata@geemail.com	San Diego	California	561261785520760	af7682d4ea508378f4ee38c7f1b29dd6	VISA 16 digit	32.9081702589590108	-117.196151758627977
31245	2020-06-16 18:56:49	2020-06-16	Sanjuana Carter	sanjuana.carter@warmmail.com	Eugene	Oregon	869932499399507769	c8019382f390e4ccc05281d771da4661	JCB 15 digit	44.136335414201767	-123.15407552290597
31246	2020-06-16 18:59:34	2020-06-16	Magdalena Roob-Swaniawski	magdalena.roob.swaniawski@geemail.com	Dallas	Texas	3033083006173622	70829b3b969a28057c45b14890f3aa83	Mastercard	32.8794337670125074	-96.7675700687766067
31247	2020-06-16 19:03:45	2020-06-16	Wendel Turcotte	wendel.turcotte@geemail.com	Durham	North Carolina	3088961055717024369	fe5c52f967ce5c01ca21bb3ee167ee30	Voyager	36.0355032885693021	-78.9968886892214499
31248	2020-06-16 19:09:21	2020-06-16	Mrs. Lu Block DVM	mrs.lu.block.dvm@geemail.com	Honolulu	Hawaii	55344769528366169	ad9caf6900828e416d1572b1fc21cfaa	VISA 16 digit	21.3140408138960602	-157.81327036136986
31249	2020-06-16 19:14:34	2020-06-16	Tamisha Cole	tamisha.cole@geemail.com	San Francisco	California	180023435785063612	e7bb6a1690e1955117aa9c90c881b96c	Mastercard	37.7743575448059801	-122.425307187491626
31250	2020-06-16 19:14:38	2020-06-16	Gottlieb Ryan	gottlieb.ryan@geemail.com	Madison	Wisconsin	6011467595899099985	148ad76b02201db16aabed61161ab369	Mastercard	43.1617096841774881	-89.3702491265140537
31251	2020-06-16 19:18:59	2020-06-16	Eustace Blanda-Dibbert	eustace.blanda.dibbert@geemail.com	Denver	Colorado	3755829931808535	562e94d4d38eb7da09caf19c0f95d824	VISA 16 digit	39.7144698683224604	-104.980912101945279
31252	2020-06-16 19:19:20	2020-06-16	Rahn Conn	rahn.conn@geemail.com	Los Angeles	California	502013895896267	d52d3897bd94f410e49c791de9f57f19	Diners Club / Carte Blanche	34.0408050046168213	-118.475094312847773
31253	2020-06-16 19:24:24	2020-06-16	Audrianna Lehner	audrianna.lehner@geemail.com	Burbank	California	4863909752918506	7dfb0cd2e156d7d4d21f7b4252f32545	Discover	34.1741396252926464	-118.277121294386319
31254	2020-06-16 19:31:21	2020-06-16	Gillie Hahn	gillie.hahn@warmmail.com	Santa Ana	California	4341068442241	eb9e69783ce189d50006fa856b660a5d	Maestro	33.7921172994293286	-117.83940727793798
31255	2020-06-16 19:34:38	2020-06-16	Colonel Okuneva	colonel.okuneva@geemail.com	San Francisco	California	6011574138787145451	0727fcd6b27f25febc4796a4f5261276	Discover	37.7870777884795217	-122.414812985644005
31256	2020-06-16 19:44:46	2020-06-16	Obe Kilback	obe.kilback@geemail.com	Charlotte	North Carolina	51469975382816806	7bfd4820a3d5b9f0051bc978877ff4f3	VISA 16 digit	35.1900171583306047	-80.9230626375824187
31257	2020-06-16 19:57:16	2020-06-16	Delphia Vandervort	delphia.vandervort@warmmail.com	Long Beach	California	3337146536318990015	a642c0b83996c31a03111dbc6e58c917	JCB 16 digit	33.8722332986358552	-118.153437510381636
31258	2020-06-16 20:01:29	2020-06-16	Jeannine Larkin DDS	jeannine.larkin.dds@woohoo.com	Pomona	California	3495918654820843	ef157540413e2e8bdb015e15cd3550da	Maestro	34.0694847485087848	-117.778026263272764
31259	2020-06-16 20:27:22	2020-06-16	Marin Kassulke	marin.kassulke@geemail.com	New York	New York	52218144723184648	60f3de12a64892e7d7ad82b8fd95a545	Diners Club / Carte Blanche	40.6159385542608788	-74.0197286493040565
31260	2020-06-16 20:33:41	2020-06-16	Luke Lemke	luke.lemke@geemail.com	New York	New York	3112627104421518906	a4317a212b0a02566ca6625abe33e596	Mastercard	40.66373843664676	-74.0204355629987987
31261	2020-06-16 20:46:07	2020-06-16	Jerimiah Cassin	jerimiah.cassin@geemail.com	San Francisco	California	503807347322633	d70a4424f22aafd2ad0844e0e28ab1f7	JCB 15 digit	37.7753785960373349	-122.402727617672411
31262	2020-06-16 20:54:26	2020-06-16	Crista Senger	crista.senger@warmmail.com	Austin	Texas	53142878040130690	49482481b5ab3abfecae4628f2eedd91	JCB 16 digit	30.2448104074351463	-97.715338531719155
31263	2020-06-16 20:55:19	2020-06-16	Miss Lenna Volkman PhD	miss.lenna.volkman.phd@geemail.com	San Francisco	California	3032536534851325	fe19d890af67fadb5bd9562e26cf8780	JCB 15 digit	37.7717331093278545	-122.401805205312357
31264	2020-06-16 21:00:57	2020-06-16	Ancel Tillman	ancel.tillman@geemail.com	New York	New York	54788423388804199	8a2615fc4aa339de9792a04917cf7d3c	Maestro	40.7342426282577179	-74.0251647030364666
31265	2020-06-16 21:05:50	2020-06-16	Mrs. Mettie Wilderman MD	mrs.mettie.wilderman.md@woohoo.com	New York	New York	4730173558137248	472530b6f41cba360cc2ede09872a282	JCB 16 digit	40.5827926954012383	-74.0143686739623519
31266	2020-06-16 21:06:52	2020-06-16	Mr. Jerry Raynor	mr.jerry.raynor@geemail.com	Grand Prairie	Texas	4697526923332	bf2d81c6c725a80a77cf6fb761646768	Voyager	32.6321562228776543	-97.1020761049691572
31267	2020-06-16 21:12:51	2020-06-16	Daren Padberg	daren.padberg@geemail.com	San Francisco	California	4813446767140363	03d08a4cdacaac31209bef59b208e6a0	VISA 13 digit	37.736014167446605	-122.413429044413178
31268	2020-06-16 21:34:37	2020-06-16	Krystal Tremblay-Emmerich	krystal.tremblay.emmerich@warmmail.com	Santa Clarita	California	4317820207844555	5cd66f3aebed4495ff451d05d3b3f550	VISA 13 digit	34.4364969958290459	-118.586929395152993
31269	2020-06-16 21:39:56	2020-06-16	Mr. Hollie Mraz DVM	mr.hollie.mraz.dvm@geemail.com	Louisville	Kentucky	676169319885369	bc61e6746d839c64b0e15ae901e5d1b3	JCB 15 digit	38.1747202159739984	-85.727203961887966
31270	2020-06-16 21:45:29	2020-06-16	Mrs. Ason Kub DDS	mrs.ason.kub.dds@geemail.com	Bakersfield	California	3088170656274204703	b174cc05ac66609e58b85dc89be514ca	VISA 13 digit	35.3290678377438283	-118.945800582905477
31271	2020-06-16 21:46:32	2020-06-16	Mr. Keegan Boyle V	mr.keegan.boyle.v@warmmail.com	Gilbert	Arizona	6011426806654565056	1c4b769f2dbb7c7e692990c1b52f64c1	JCB 15 digit	33.3663417121741901	-111.831477025257797
31272	2020-06-16 21:55:13	2020-06-16	Nayely Carroll	nayely.carroll@geemail.com	Sunnyvale	California	3158655055388189864	e1fbe1e4b388724289e3deeb3544c27e	JCB 16 digit	37.3829936689689788	-122.012430556510765
31273	2020-06-16 22:12:19	2020-06-16	Mrs. Chrystal Klein MD	mrs.chrystal.klein.md@geemail.com	New York	New York	3158719135456122858	e176c0fd57ba9c29297a575219f5882f	VISA 16 digit	40.6441449455674757	-73.8942459929164528
31274	2020-06-16 22:30:04	2020-06-16	Orvis Huels-Kunde	orvis.huels.kunde@geemail.com	Oakland	California	4195746763933564	f755fa97d95a58ce61637bbc10c97a1c	Maestro	37.8019290527912872	-122.207976292503901
31275	2020-06-16 22:35:51	2020-06-16	Roxana Weissnat	roxana.weissnat@warmmail.com	New York	New York	502091426128095	3db08bd8083807474c22dc664ade29e0	VISA 16 digit	40.6304802322518057	-74.0023754374019802
31276	2020-06-16 22:39:33	2020-06-16	Rayna Jacobi	rayna.jacobi@geemail.com	Virginia Beach	Virginia	54541680116866315	0274daa0de7b9572ca13c9d92169ac26	Voyager	36.8403612637612952	-75.9772289031322998
31277	2020-06-16 22:41:06	2020-06-16	Cathern Predovic-Jacobs	cathern.predovic.jacobs@geemail.com	Woodbridge	New Jersey	869945697690365515	e41b73818773e2ad25e180729b6387be	VISA 13 digit	40.5479177644167095	-74.3073590538322861
31278	2020-06-16 22:55:28	2020-06-16	Brock Schinner	brock.schinner@geemail.com	Sacramento	California	210016663762191481	54c3c9769bd486e726797c01b8992465	American Express	38.5126576974321182	-121.492604041682924
31279	2020-06-16 23:02:11	2020-06-16	Bailey Kiehn	bailey.kiehn@warmmail.com	Tulsa	Oklahoma	869910465989725752	6707f87af7b0a4fc8f4075170fd3726c	Maestro	36.0749061548054186	-95.9434945716012209
31280	2020-06-16 23:18:43	2020-06-16	Benito Ondricka	benito.ondricka@geemail.com	New York	New York	869951794167721782	776a5c6806aba67f2bd1793d1edce8db	Mastercard	40.683225193828342	-73.9060737164121093
31281	2020-06-16 23:27:11	2020-06-16	Dr. Coleton Ward	dr.coleton.ward@geemail.com	Jacksonville	Florida	210093315835620360	b0303310e02610fd2a52058ef572f8c1	American Express	30.2949402866471544	-81.6911203966554353
31282	2020-06-16 23:34:02	2020-06-16	Jeanne Schmitt	jeanne.schmitt@woohoo.com	New York	New York	630456550813911	44174626ab512ee91fa4290a58952acd	Diners Club / Carte Blanche	40.7530507685374488	-74.021012149414787
31283	2020-06-16 23:37:57	2020-06-16	Tana Jerde	tana.jerde@geemail.com	El Paso	Texas	589383885285607	3f558f00104f62078858b7709e7891ec	VISA 13 digit	31.8764736017972261	-106.352352891208611
31284	2020-06-16 23:43:48	2020-06-16	Mr. Hershell Nolan	mr.hershell.nolan@woohoo.com	Waterbury	Connecticut	4619451670295508	8b7b8ac6cb552e4edc094b8fb7e09f7b	American Express	41.5122402077112369	-73.0239408965602479
31285	2020-06-16 23:49:24	2020-06-16	Kaleigh Corwin	kaleigh.corwin@geemail.com	Lubbock	Texas	6011018986086835048	cf67e32eea22e2f24a487e4fc233c0b4	Discover	33.4696326214861131	-101.891027472299342
31286	2020-06-16 23:51:43	2020-06-16	Guillermo Christiansen	guillermo.christiansen@woohoo.com	Huntington Beach	California	4356716932250153	e3f41a5a8b88259460b0744a78793190	American Express	33.7535069982562277	-117.976304042211922
31287	2020-06-16 23:56:40	2020-06-16	Dejon Brekke	dejon.brekke@woohoo.com	Jacksonville	Florida	4985942202153	cfc915766f286d44bfa6b11bbc17f5a2	JCB 16 digit	30.2396562043629586	-81.6879063756283443
31288	2020-06-17 00:04:07	2020-06-17	Tariq Altenwerth	tariq.altenwerth@geemail.com	San Francisco	California	3029147359461548	696584e1cac845506387e44965194922	VISA 16 digit	37.7570578061098914	-122.424171180601647
31289	2020-06-17 00:11:39	2020-06-17	Lillian Stark	lillian.stark@woohoo.com	Fontana	California	4357772011616607	84e697722e53e263e8df22a1a08309c6	Voyager	34.1394920666851149	-117.477235272973402
31290	2020-06-17 00:12:28	2020-06-17	Dr. Abigail Hilll	dr.abigail.hilll@geemail.com	Fort Wayne	Indiana	3112854160329164569	2887ebb1d26758f12aeafd743ccd7daf	Maestro	41.1005483076691647	-85.2115599225494975
31291	2020-06-17 00:14:01	2020-06-17	Marcelo Hagenes	marcelo.hagenes@geemail.com	Austin	Texas	4054543562634638	dc3a927c9f62371e031c24a07c9ab0a4	JCB 16 digit	30.3274464449971894	-97.7209958732832291
31292	2020-06-17 00:21:04	2020-06-17	Brendon Schulist	brendon.schulist@geemail.com	Hartford	Connecticut	210027177784314697	0e5e51d0063889f88bf7cdd6569d58ed	Diners Club / Carte Blanche	41.7506488822415491	-72.707071667433155
31293	2020-06-17 00:22:11	2020-06-17	Dr. Cleveland Weber DVM	dr.cleveland.weber.dvm@geemail.com	Oakland	California	3442188958141213	7fa90c186f7097579fc46f4312429428	VISA 16 digit	37.8147745444534138	-122.245762115048223
31294	2020-06-17 00:23:52	2020-06-17	Maiya Casper	maiya.casper@geemail.com	Los Angeles	California	676190197491807	f616baa8d51d974a42ba8fec086a9d7a	Discover	34.013406362184881	-118.3676466017954
31295	2020-06-17 00:25:44	2020-06-17	Tamie Grant	tamie.grant@geemail.com	Oakland	California	55026737244308992	416f6b23a91a92876d43a11eb42e3430	JCB 16 digit	37.7766786465218871	-122.275115565654346
31296	2020-06-17 00:27:52	2020-06-17	Leatha Schuppe	leatha.schuppe@geemail.com	New York	New York	4249879668946880	4fa4798d4173e55381aef4ba209ad3ba	Discover	40.6269246407076707	-74.0252923893637984
31297	2020-06-17 00:35:17	2020-06-17	Dr. Lloyd King DDS	dr.lloyd.king.dds@geemail.com	Las Vegas	Nevada	4304769775202	4acc484c98ff68f5fee8ff4d196da986	JCB 15 digit	36.1492949791353197	-115.21227082691378
31298	2020-06-17 00:44:32	2020-06-17	Ericka Dickens	ericka.dickens@geemail.com	Sacramento	California	3337764843600196041	1dca5e84e65ceb9b4f620426f4acfea1	American Express	38.5122380452495108	-121.452274572734154
31299	2020-06-17 00:45:05	2020-06-17	Mr. Odis Hoppe I	mr.odis.hoppe.i@geemail.com	New York	New York	4024708961907854	5d76dbb09746702a680d712f440080c6	JCB 16 digit	40.7372335106823584	-73.9835950652033034
31300	2020-06-17 00:48:20	2020-06-17	Arlin Kessler	arlin.kessler@warmmail.com	Fort Worth	Texas	4731385697200237	37e1dc1be6a7abf8794b4c8873ba0c67	American Express	32.72269050879963	-97.2640689245712053
31301	2020-06-17 01:06:25	2020-06-17	Anabel Heaney	anabel.heaney@woohoo.com	Richmond	Virginia	6011771267420434542	4edff8f57a7802061c00146e4bbf80d6	Maestro	37.5139863557402009	-77.511166284115987
31302	2020-06-17 01:10:59	2020-06-17	Delmas Hartmann	delmas.hartmann@geemail.com	Chula Vista	California	3775210442857939	060a641eac842ea3c72da8c030212d7f	JCB 15 digit	32.7210230985421688	-117.113357135816287
31303	2020-06-17 01:27:30	2020-06-17	Pearly Carroll	pearly.carroll@geemail.com	New York	New York	54560108867591748	59ea2d581d3f6831ce6c081c85cb583b	VISA 16 digit	40.6123018636591695	-73.9999458449322702
31304	2020-06-17 01:29:37	2020-06-17	Jeannette Kautzer	jeannette.kautzer@woohoo.com	Newark	New Jersey	51667785288982507	aedaffb75e509b0ac2f0e1ba5bbca106	JCB 15 digit	40.6986266370777088	-74.1802352854259368
31305	2020-06-17 01:32:51	2020-06-17	Haden Wiza	haden.wiza@geemail.com	Miami	Florida	4330529722811410	41f3ffe919e2271afeb2a1b483b21113	Maestro	25.7701001344852152	-80.2672609174031777
31306	2020-06-17 01:35:11	2020-06-17	Tressie Okuneva-Turner	tressie.okuneva.turner@geemail.com	Tallahassee	Florida	3036486977711600	111f53f436f3d79c7e89780b55ac0206	JCB 15 digit	30.4495888004101829	-84.3338172681178833
31307	2020-06-17 01:39:01	2020-06-17	Ms. Evalyn Turcotte	ms.evalyn.turcotte@geemail.com	New York	New York	3337533050582485802	625d2572b104f273590eaef65812ae82	Discover	40.6763816224168977	-73.8932082175638527
31308	2020-06-17 01:40:49	2020-06-17	Elmore Berge	elmore.berge@geemail.com	Pueblo	Colorado	3056398124947302	df6330f683f86153abeaee6b504475fc	Discover	38.3425550292223676	-104.607666104692228
31309	2020-06-17 01:49:15	2020-06-17	Evalena Heathcote	evalena.heathcote@geemail.com	Nashville	Tennessee	210014118279280642	cc611e5981912279a46588ff1b5b1123	Mastercard	36.0757284407626813	-86.7893906528968273
31310	2020-06-17 01:50:42	2020-06-17	Chantel Flatley	chantel.flatley@geemail.com	New York	New York	6011970172882189874	a952137732e41c9c4f87c9f8136e3f23	VISA 16 digit	40.5924177289698278	-74.0164195475995541
31311	2020-06-17 02:02:51	2020-06-17	Sara Ebert	sara.ebert@warmmail.com	El Paso	Texas	4446016819535913	a1ef8e1d5836d59e7918300299024acf	American Express	31.8080608356107035	-106.35585614857078
31312	2020-06-17 02:03:41	2020-06-17	Gerry Towne-Fay	gerry.towne.fay@woohoo.com	New York	New York	4723893864260116	a6d80811df4bf9663b2318961b5223df	VISA 16 digit	40.7003518139701299	-73.851141718624902
31313	2020-06-17 02:30:22	2020-06-17	Almus Gulgowski	almus.gulgowski@warmmail.com	San Francisco	California	3158202806634397869	0f2783e1831917e2ca6170f7756fa82a	Voyager	37.7691710435183197	-122.432896890790033
31314	2020-06-17 02:35:30	2020-06-17	Pamela Ebert PhD	pamela.ebert.phd@warmmail.com	Vancouver	Washington	3035397613686141	f2fe2b39f922b458f1fcca2a0139edad	Voyager	45.6387268893025819	-122.602939205203938
31315	2020-06-17 02:39:12	2020-06-17	Volney Becker	volney.becker@geemail.com	San Francisco	California	210045843289544397	130fbc886c8484334305e27a3c76e43c	JCB 15 digit	37.757275653481436	-122.440936170736649
31316	2020-06-17 02:46:33	2020-06-17	Doshia Krajcik	doshia.krajcik@woohoo.com	Hayward	California	180015845177138725	577e28124cb42c133a1e6b2b7602102f	VISA 16 digit	37.6061601122364451	-122.161426417229322
31317	2020-06-17 02:52:01	2020-06-17	Edw Cassin	edw.cassin@geemail.com	Fullerton	California	4266048831969090	61b1a381fbbd096fca130f15f13b15af	JCB 16 digit	33.8957865565240368	-117.958479784356427
31318	2020-06-17 02:58:21	2020-06-17	Mitchel Medhurst	mitchel.medhurst@geemail.com	San Francisco	California	4787259099010	5d391dcb2340c0e9e8a608141207fafb	Maestro	37.7815151327999033	-122.432043880361661
31319	2020-06-17 03:01:33	2020-06-17	Danna Okuneva	danna.okuneva@geemail.com	Omaha	Nebraska	3042991709519555	c5bc0ecc0546458e4b9233d652090fc4	JCB 16 digit	41.3175043816357856	-96.1425725281354033
31320	2020-06-17 03:04:51	2020-06-17	Dr. Erykah Daugherty	dr.erykah.daugherty@geemail.com	Phoenix	Arizona	639027264394464	161f693bc26e0028727690eef72705ec	Discover	33.6565281063716881	-112.047849969558797
31321	2020-06-17 03:12:17	2020-06-17	Ms. Victory Bode PhD	ms.victory.bode.phd@geemail.com	Fargo	North Dakota	3793067779396156	f5b7296623bc2ba5611b64107c76c53a	American Express	46.8102163742993014	-96.8390085585843678
31322	2020-06-17 03:24:50	2020-06-17	Colvin Rippin-Will	colvin.rippin.will@geemail.com	Philadelphia	Pennsylvania	869966523912165455	98b6d0f60879350e8b0fe04432d6e7f3	JCB 16 digit	39.924622713816909	-75.1522388552214977
31323	2020-06-17 03:31:33	2020-06-17	Dannielle Mohr DDS	dannielle.mohr.dds@geemail.com	North Charleston	South Carolina	52565908408939602	2e56370adbd601e62040bb3534ae4f62	VISA 16 digit	32.8454265517342847	-80.0645735646691179
31324	2020-06-17 03:38:35	2020-06-17	Savannah Koch-Corwin	savannah.koch.corwin@geemail.com	Laredo	Texas	630472602016551	15675920ba7fe6fda92dc70e2c099408	Voyager	27.6340266199033735	-99.5335257019389417
31325	2020-06-17 03:55:13	2020-06-17	Daniele Block	daniele.block@geemail.com	San Francisco	California	210098120278839294	aae06d543ed44efc73a07b4ceaa18f2b	Maestro	37.769296981826173	-122.479686887058776
31326	2020-06-17 03:58:02	2020-06-17	Storm Wiegand	storm.wiegand@geemail.com	San Jose	California	3487453917360239	7580cb4c44f7a7f1304ada8cde6f023c	Maestro	37.3835684129789456	-121.824248658701407
31327	2020-06-17 04:06:00	2020-06-17	Beatrice Pfeffer	beatrice.pfeffer@geemail.com	Phoenix	Arizona	4897883713133135	6996f056bce6e221339d6b1825ac798c	JCB 16 digit	33.5699752709295609	-112.079324664540962
31328	2020-06-17 04:08:22	2020-06-17	Lucio Watsica	lucio.watsica@geemail.com	San Francisco	California	55246644429847212	3d5738bf3008d7c8fe9458ec94729192	American Express	37.7855773402229147	-122.468785308196104
31329	2020-06-17 04:10:38	2020-06-17	Kaylin Stokes	kaylin.stokes@geemail.com	Honolulu	Hawaii	3096936359283070737	da116cea68486addea09ff1679acdceb	VISA 16 digit	21.3435831221036629	-157.914918150820199
31330	2020-06-17 04:28:32	2020-06-17	Sadie Kunze-Jast	sadie.kunze.jast@geemail.com	San Francisco	California	3035525986691328	279778692290e36f6c815fabfcf62923	JCB 15 digit	37.7647699255642877	-122.44673496771712
31331	2020-06-17 04:36:45	2020-06-17	Dr. Chasity Denesik DDS	dr.chasity.denesik.dds@geemail.com	Chicago	Illinois	676278253384750	92d142eb789b37ee72ff57ab5feee2a2	Diners Club / Carte Blanche	41.8818221796140122	-87.7509826668567854
31332	2020-06-17 04:40:17	2020-06-17	Kenton Schiller	kenton.schiller@warmmail.com	San Francisco	California	3528089414509965361	3f7172ac7834c160d37668f6793e68ee	Diners Club / Carte Blanche	37.7714070518204892	-122.416286451046474
31333	2020-06-17 04:51:28	2020-06-17	Arthor Aufderhar Sr.	arthor.aufderhar.sr.@woohoo.com	New York	New York	3003029828129508	820b9439e3331a6191225cd38c79bb88	Maestro	40.5952375324666477	-74.0193046210695087
31334	2020-06-17 04:51:29	2020-06-17	Emilie Thiel	emilie.thiel@woohoo.com	Rancho Cucamonga	California	180082645210959956	1674974e1c694df1d5cf4aa11b45c8cb	Mastercard	34.0975713432293404	-117.593489980232718
31335	2020-06-17 05:10:36	2020-06-17	Dee Quigley-Koepp	dee.quigley.koepp@geemail.com	Bakersfield	California	6011952064646995831	accef734a230d77a5858670a5ef7164f	JCB 16 digit	35.2230420265987476	-119.069278641305118
31336	2020-06-17 05:51:22	2020-06-17	Dabney Dicki	dabney.dicki@geemail.com	San Antonio	Texas	561254826607738	f1edf9c93c28b7b0022cb0370535dcdd	VISA 16 digit	29.4902724296391021	-98.5367377550177252
31337	2020-06-17 06:02:35	2020-06-17	Tyrus Parisian	tyrus.parisian@geemail.com	Denver	Colorado	4721204654998729	113519e3a6ece1b1e349cedf7556b9ac	Discover	39.6635952310688751	-104.809836589336768
31338	2020-06-17 06:05:52	2020-06-17	Mrs. Cilla Konopelski DDS	mrs.cilla.konopelski.dds@geemail.com	Spokane	Washington	180090684438220693	8a24c5789652f3a580439d3114fadd3e	Diners Club / Carte Blanche	47.757357950159907	-117.403458197265124
31339	2020-06-17 06:09:34	2020-06-17	Shania Mraz-Dickinson	shania.mraz.dickinson@geemail.com	Jacksonville	Florida	4715013716512	b8d456e4b9daa197876e6482675af5a0	VISA 13 digit	30.4134516301617026	-81.7022925506889948
31340	2020-06-17 06:21:58	2020-06-17	Uriel Toy	uriel.toy@woohoo.com	Allentown	Pennsylvania	4323784790107303	810cbb3a53f6cc28e90374a21d57d7e3	JCB 16 digit	40.672939835792782	-75.5173458684250676
31341	2020-06-17 06:30:41	2020-06-17	Miss Marylee Roberts	miss.marylee.roberts@woohoo.com	Cleveland	Ohio	210013326129028522	6c19865543c69ef1d6fa2fb74e516f6b	Discover	41.4448144471123783	-81.7528995386097534
31342	2020-06-17 06:39:23	2020-06-17	Mr. Osbaldo Russel	mr.osbaldo.russel@warmmail.com	Louisville	Kentucky	4997698193246929	67ca2f7072dc7f8b40873e9aa9b78667	JCB 15 digit	38.1777626198619586	-85.7311473864667164
31343	2020-06-17 06:55:22	2020-06-17	Ted Raynor	ted.raynor@geemail.com	Bridgeport	Connecticut	180049980644583854	1a8a7a138f2e67dd83748492b6841318	Voyager	41.1362067861180734	-73.2889339251808849
31344	2020-06-17 06:55:25	2020-06-17	Louvenia Cummerata	louvenia.cummerata@geemail.com	Houston	Texas	869987477818186377	18f5fcb342e3b56fedc8e4f5529c21bc	Discover	29.8210491715542965	-95.3858818193912583
31345	2020-06-17 06:57:36	2020-06-17	Nyla McLaughlin	nyla.mclaughlin@geemail.com	Nashville	Tennessee	639008077404062	87e806760a6a4896db906c598c19e6f7	Mastercard	36.2330105906009621	-86.7581368310283807
31346	2020-06-17 07:05:41	2020-06-17	Hank Welch	hank.welch@geemail.com	Pomona	California	210092804841758208	69d6c6c8362687f1baf67950f7884a1f	VISA 16 digit	34.048236340800301	-117.676371012904127
31347	2020-06-17 07:22:14	2020-06-17	Harold Kuphal	harold.kuphal@geemail.com	Durham	North Carolina	51639892584887011	4ecd15949328932fc321c9279cbaa72a	Discover	35.9730510673731558	-78.9577514488153156
31348	2020-06-17 07:39:25	2020-06-17	Tana Emmerich	tana.emmerich@geemail.com	Lubbock	Texas	4137029417151011	4d8721f5cfdb3451493b8012efe5386c	JCB 16 digit	33.5524029864504953	-101.947440689840178
31349	2020-06-17 07:50:12	2020-06-17	Lisette Nicolas	lisette.nicolas@woohoo.com	Mesa	Arizona	4388111520887	be8719b50d8904624c32d9353b6ceda3	JCB 16 digit	33.4682556041661599	-111.715586492267988
31350	2020-06-17 08:03:47	2020-06-17	Rafael Abbott	rafael.abbott@geemail.com	Elizabeth	New Jersey	3007086219255660	079d4eae27544828be5f75ed7fe1a1e4	American Express	40.6368604567959935	-74.2731460193581938
31351	2020-06-17 08:12:14	2020-06-17	Ms. Skyla Rippin	ms.skyla.rippin@geemail.com	San Francisco	California	869927642078365978	a333392bb5b4d18a065b84999d146597	American Express	37.7599895022946086	-122.447884513942086
31352	2020-06-17 08:13:11	2020-06-17	Mr. Kristofer Reinger	mr.kristofer.reinger@warmmail.com	San Jose	California	869984361103887449	194a3a1b7717905a69287e328eac453a	JCB 15 digit	37.3597570959299787	-121.842316316974902
31353	2020-06-17 08:20:40	2020-06-17	Carleton Cummerata	carleton.cummerata@geemail.com	New York	New York	869992713917023977	846b9a44e6127790620d7cf20a8bb495	JCB 16 digit	40.575632082693275	-74.0020014011196707
31354	2020-06-17 08:34:12	2020-06-17	Tracy Hegmann	tracy.hegmann@geemail.com	Rochester	New York	3096013394666128741	86200f477df61557fe86062480d15e56	VISA 16 digit	43.1589639562625393	-77.684254342760525
31355	2020-06-17 08:36:09	2020-06-17	Konnor Hodkiewicz-Hudson	konnor.hodkiewicz.hudson@geemail.com	El Paso	Texas	210068307402114324	e42a203da6f487ae3a3a096f433836bd	VISA 13 digit	31.8875427291091533	-106.503647745817901
31356	2020-06-17 08:42:13	2020-06-17	Permelia Witting	permelia.witting@warmmail.com	Renton	Washington	869940648891029843	4f1182bdcf7dbf43798ed7f9d069104f	Mastercard	47.3840037689138214	-122.098898960098623
31357	2020-06-17 08:47:29	2020-06-17	Payton Hilpert	payton.hilpert@geemail.com	Berkeley	California	4865721609267	5cc5b3e55e62f3dff6ae316258fea784	VISA 16 digit	37.8848105430034181	-122.301745399170485
31358	2020-06-17 08:51:00	2020-06-17	Madie Keebler-Dare	madie.keebler.dare@woohoo.com	Aurora	Illinois	3788453841156561	5ea5b8ea008d786ca21a85bec26f15bc	Discover	41.6822474084552397	-88.2307910546123964
31359	2020-06-17 08:53:14	2020-06-17	Orie Gulgowski	orie.gulgowski@warmmail.com	Cape Coral	Florida	4317351965971257	0831122fca90f07cf461f3b697f508ee	American Express	26.6037796302203091	-81.9386715484388191
31360	2020-06-17 08:58:45	2020-06-17	Amari Stokes	amari.stokes@warmmail.com	Charleston	South Carolina	180058787964797594	f1df511910b49f9f9a694bd7f548ece3	Discover	32.8221459867429033	-79.9730505533199789
31361	2020-06-17 09:26:28	2020-06-17	Lassie Hoppe-Bashirian	lassie.hoppe.bashirian@woohoo.com	Columbus	Ohio	54148464253904453	3361ad5eabb7186ee49a78a351d6a921	JCB 15 digit	39.9455615116327962	-83.0752855169821629
31362	2020-06-17 09:55:59	2020-06-17	Lester Sipes	lester.sipes@geemail.com	Washington	District of Columbia	869916967817897525	b4cd0353a2b4197ca6dd874281bf9f47	JCB 15 digit	38.958889952887219	-77.0113975967492905
31363	2020-06-17 10:07:41	2020-06-17	Dr. Bethel Morissette	dr.bethel.morissette@geemail.com	Des Moines	Iowa	3035217622301997	acf2f5a1ec5ab33dbbba0f33d8e3fffa	Discover	41.5497442718338235	-93.6718236522793859
31364	2020-06-17 10:07:44	2020-06-17	Ann Daugherty-Hintz	ann.daugherty.hintz@warmmail.com	San Francisco	California	6011465345227504732	49b6c968c3ca8960cdf833358c87d34b	VISA 16 digit	37.7548894651505762	-122.399917131453435
31365	2020-06-17 10:09:37	2020-06-17	Erving Waters	erving.waters@geemail.com	Des Moines	Iowa	4919019419711536	385c6010e4ceeb8a204a16c55ad58461	Maestro	41.4805557872843025	-93.5419801443394334
31366	2020-06-17 10:10:23	2020-06-17	Tonia Stanton	tonia.stanton@geemail.com	El Paso	Texas	4604971680607	ab9fd15b8c28f770417c9632b7402821	JCB 15 digit	31.8243347422048473	-106.50072734062374
31367	2020-06-17 10:13:06	2020-06-17	Mrs. Vara Heathcote	mrs.vara.heathcote@woohoo.com	Dayton	Ohio	54553261432200177	c431e64d455c94d7d6a82002afad18f9	Discover	39.6847907410260277	-84.2045163797870373
31368	2020-06-17 10:38:30	2020-06-17	Marianita Cronin-Gislason	marianita.cronin.gislason@geemail.com	Killeen	Texas	3528124939510889181	948fc5c8a30af877a4f76b3a197b43b8	Discover	30.997762244031577	-97.8191777444146595
31369	2020-06-17 10:41:26	2020-06-17	Delma McLaughlin	delma.mclaughlin@geemail.com	Berkeley	California	6011036766018351787	3403de61c7ed9c2d2e5100d275663675	Diners Club / Carte Blanche	37.8841139373315627	-122.242562061647632
31370	2020-06-17 10:44:11	2020-06-17	Mr. Jaime Bradtke Sr.	mr.jaime.bradtke.sr.@geemail.com	Dallas	Texas	4164709414007326	1cfa60f5dc0d5bc0f0771332211ac8e3	VISA 13 digit	32.7708994559284292	-96.8068705970849805
31371	2020-06-17 10:49:20	2020-06-17	Mrs. Jolie Johns DVM	mrs.jolie.johns.dvm@woohoo.com	New York	New York	3024227274462899	e402d829f98e90ba5b9dc60072c03677	Maestro	40.7109708750378303	-73.8860378521855949
31372	2020-06-17 10:49:52	2020-06-17	Miss Aleah Nikolaus DVM	miss.aleah.nikolaus.dvm@geemail.com	Inglewood	California	3337213961953351810	a7c569546aadb639bf00984f96547966	Mastercard	33.9691027226638056	-118.303226940523089
31373	2020-06-17 10:57:29	2020-06-17	Ola Casper MD	ola.casper.md@warmmail.com	New York	New York	3088906440948530111	82e35249ffb9301884f9e776cb0a5d91	Discover	40.6497125500570959	-73.9862118129979791
31374	2020-06-17 10:58:22	2020-06-17	Parley Wyman-Halvorson	parley.wyman.halvorson@geemail.com	San Francisco	California	6011643470176303889	e3c0b4855134b54e9bac2faa5089eebf	JCB 16 digit	37.7992460872772398	-122.460861866368319
31375	2020-06-17 10:59:06	2020-06-17	Lenny Abshire	lenny.abshire@geemail.com	New York	New York	4984520595704195	bfe699d88df584245076e73286eb77a9	Discover	40.6705679301861664	-73.9522053794365348
31376	2020-06-17 11:15:30	2020-06-17	Bascom Rosenbaum-Dibbert	bascom.rosenbaum.dibbert@woohoo.com	San Diego	California	3439961274695277	ab7636598bb9b87c6544991826cad7d1	Discover	32.8723548383053412	-117.208736133705827
31377	2020-06-17 11:25:49	2020-06-17	Ms. Danyel Leffler PhD	ms.danyel.leffler.phd@woohoo.com	San Diego	California	3528099604319792629	5164b3da25cf9d6424b67bc0ed125cac	JCB 15 digit	32.7759493297964326	-117.172633016286426
31378	2020-06-17 11:28:57	2020-06-17	Miss Donnie Conn	miss.donnie.conn@woohoo.com	Los Angeles	California	3528916927049038935	5a884f95e8dc1b1a589b063b7eb7c3dc	JCB 16 digit	33.9856081413436684	-118.480989514802758
31379	2020-06-17 11:45:49	2020-06-17	Julious Hirthe	julious.hirthe@geemail.com	Chattanooga	Tennessee	4462427803899513	380c7925f4e72218be0186d03bd43315	JCB 15 digit	35.0780536754373458	-85.2629847887266408
31380	2020-06-17 11:50:17	2020-06-17	Miss Emmer Beahan DVM	miss.emmer.beahan.dvm@geemail.com	Ann Arbor	Michigan	869933208649989423	ab013b2431b0c73637e60321d70944b3	American Express	42.372891310608388	-83.7891874933257697
31381	2020-06-17 11:50:21	2020-06-17	Reece Bauch	reece.bauch@woohoo.com	Omaha	Nebraska	4812590726020	9b4d44e827b51e4f4ccf9175652d281d	VISA 16 digit	41.3404602694470427	-95.9981700919218355
31382	2020-06-17 12:00:08	2020-06-17	Atticus Lockman DDS	atticus.lockman.dds@geemail.com	Modesto	California	210022972722219486	a6acab9624a7873fb44d0ca07415bd09	VISA 13 digit	37.5999499501660495	-121.04930092247389
31383	2020-06-17 12:06:56	2020-06-17	Dr. Elbert Schaefer	dr.elbert.schaefer@geemail.com	Kent	Washington	4366308491780453	2dd2660bea4f3bd952f1d4a5ef911b2d	Mastercard	47.291023236757141	-122.275461428952212
31384	2020-06-17 12:08:31	2020-06-17	Dr. Jamarcus Ankunding	dr.jamarcus.ankunding@geemail.com	Arlington	Texas	3112272194827343965	bfa8e6b78dba48dd2059963559724eb1	JCB 16 digit	32.7946598666503988	-97.0684550227157814
31385	2020-06-17 12:11:01	2020-06-17	Anjelica Koch MD	anjelica.koch.md@geemail.com	El Paso	Texas	4510544740689	1df8763111f518b077a86ac89f2fe12d	American Express	31.9470604376230405	-106.484059493055568
31386	2020-06-17 12:18:58	2020-06-17	Kelby Fritsch	kelby.fritsch@geemail.com	Denver	Colorado	3041578936053663	54c43e6e54a5845e1f4eba864b7bf8b1	JCB 16 digit	39.8025439677346498	-104.976733569965148
31387	2020-06-17 12:29:26	2020-06-17	Randle Kuvalis	randle.kuvalis@geemail.com	New York	New York	180092074391307588	e13089836d6ee9703165e092113dc3a8	Maestro	40.735544370463117	-73.8393826315540736
31388	2020-06-17 12:36:46	2020-06-17	Lazaro Frami-Prosacco	lazaro.frami.prosacco@geemail.com	Louisville	Kentucky	3528828987541884233	6adcb99cd8a4818df4dfe3385248e0fa	American Express	38.1794367488842425	-85.6990775334719643
31389	2020-06-17 12:37:06	2020-06-17	Alleen Collins	alleen.collins@warmmail.com	San Francisco	California	180084154307995401	57c088dad609d78df3b695437cd048c7	Mastercard	37.7532182850477156	-122.506630055091236
31390	2020-06-17 12:52:56	2020-06-17	Mr. Sie Jerde	mr.sie.jerde@geemail.com	Detroit	Michigan	3096458165057604793	dab90cf9c8e90c14e3052349ca6b4790	VISA 13 digit	42.3327078456450252	-83.2008610408872329
31391	2020-06-17 13:07:22	2020-06-17	Izayah O'Reilly	izayah.o'reilly@geemail.com	Chicago	Illinois	869966847618862382	dbe4e5e4782d4be2540ebfd71d6bf9a0	JCB 16 digit	41.8904008817229467	-87.7164102423965915
31392	2020-06-17 13:13:45	2020-06-17	Gussie Streich	gussie.streich@warmmail.com	Minneapolis	Minnesota	3772288353094877	c7022a99007219b0bef5f43facf1f2c8	JCB 16 digit	44.9116645759057249	-93.1714230916269059
31393	2020-06-17 13:14:40	2020-06-17	Mrs. Tatia Johnson	mrs.tatia.johnson@geemail.com	North Las Vegas	Nevada	4083515795290813	40ef2202e07a24b88d5ba5902bc4bcd7	JCB 16 digit	36.3608558985561103	-115.006077105061721
31394	2020-06-17 13:16:34	2020-06-17	Tristan Crist	tristan.crist@geemail.com	Lansing	Michigan	869928556264946624	5eaecae63d46e1ca88189f153c909787	Voyager	42.70709607469216	-84.5543311885215303
31395	2020-06-17 13:20:10	2020-06-17	Gilbert McGlynn	gilbert.mcglynn@geemail.com	Chicago	Illinois	4461065965497	4e447157d081216f71a296b588eee238	VISA 13 digit	41.8823120449971427	-87.723765104453264
31396	2020-06-17 13:28:55	2020-06-17	Kittie Schumm	kittie.schumm@geemail.com	Davenport	Iowa	3700446026912373	81c3a71fa97626961a9496cee8bb7dff	Voyager	41.4553630048207893	-90.6434906293135185
31397	2020-06-17 13:56:49	2020-06-17	Eligah Bahringer	eligah.bahringer@warmmail.com	Washington	District of Columbia	6011263612357977333	228cbf3a8b399f332233957d474f2f88	VISA 16 digit	38.9928747363653017	-77.0210522935006736
31398	2020-06-17 14:12:21	2020-06-17	Cherry Stamm	cherry.stamm@warmmail.com	Arlington	Texas	4560490446529823	5005854b373d9c5d365824109b493416	VISA 16 digit	32.6768118376627541	-97.0498038809772652
31399	2020-06-17 14:23:08	2020-06-17	Dedric Fahey	dedric.fahey@woohoo.com	New York	New York	3528725047279116938	ab3f0887ce7e93d1485fc70c09bae22b	VISA 13 digit	40.6957071624454088	-73.9821018943924429
31400	2020-06-17 14:27:52	2020-06-17	Dr. Pranav Olson	dr.pranav.olson@geemail.com	Durham	North Carolina	3158386432103221205	a15a89987d155cdb2e9334157c5c902a	JCB 16 digit	35.9291657630599985	-78.8339633135493898
31401	2020-06-17 14:48:57	2020-06-17	Mr. Koda Legros	mr.koda.legros@geemail.com	Philadelphia	Pennsylvania	4918282353311397	aebc401be2b61b808394d6c77e1e6d98	VISA 16 digit	39.9471914606127854	-75.079001437257233
31402	2020-06-17 15:06:36	2020-06-17	Rey Glover Sr.	rey.glover.sr.@geemail.com	Jersey City	New Jersey	675984135841496	47561363cff24954af8f3b9b8770656f	Mastercard	40.6301504929956039	-74.0610880732957355
31403	2020-06-17 15:08:18	2020-06-17	Priscila Schumm-Berge	priscila.schumm.berge@geemail.com	Jurupa Valley	California	3158834496182038754	0a19dda4f5eed4ac554be84240884801	Diners Club / Carte Blanche	33.9646775110088299	-117.556300649328534
31404	2020-06-17 15:14:57	2020-06-17	Ms. Sebrina Maggio MD	ms.sebrina.maggio.md@woohoo.com	Denver	Colorado	630472308681617	5e878b800f6297fe5c4f2ebd9182c57f	American Express	39.7472804063517557	-104.853808004107705
31405	2020-06-17 15:49:13	2020-06-17	Heyward Braun	heyward.braun@geemail.com	New York	New York	3000071171084230	c90798cc5f0b5a2a55a0a0c842e77da6	JCB 16 digit	40.6679551844708627	-74.0253043372079702
31406	2020-06-17 15:54:07	2020-06-17	Tamya Wilkinson	tamya.wilkinson@geemail.com	Chicago	Illinois	4387746203871687	0d70d1ccdb9f74032e62b9df8163c598	Voyager	41.8933075098622609	-87.6846081992641047
31407	2020-06-17 16:05:53	2020-06-17	Fallon Bartoletti DDS	fallon.bartoletti.dds@woohoo.com	Cedar Rapids	Iowa	869930543080399861	9702791a6b146b0b5d2d408152ded0ab	VISA 13 digit	41.9653887414447979	-91.5832337223991857
31408	2020-06-17 16:27:52	2020-06-17	Bethel Ratke-Mayer	bethel.ratke.mayer@geemail.com	Athens	Georgia	3096903975448476821	4b5edb94057941ac26ffcf7d5c8a3284	Discover	33.957695545414829	-83.4512248281970557
31409	2020-06-17 16:32:08	2020-06-17	Drew Monahan	drew.monahan@woohoo.com	Yonkers	New York	869905254322209717	77f05fa33acebd8f9e6fa2333c733006	Mastercard	40.984776552134754	-73.8298775457195973
31410	2020-06-17 16:36:36	2020-06-17	Fleda Monahan	fleda.monahan@geemail.com	New York	New York	4022508212281022	74afefe48e350d0bd37448a4fbb5cff7	Voyager	40.6176057439986593	-73.9733755506005082
31411	2020-06-17 16:53:17	2020-06-17	Chadd Cummings	chadd.cummings@warmmail.com	Atlanta	Georgia	3337198248574181142	9cddc5b9ee8687771ae2d8faffae968d	Voyager	33.7720161810327326	-84.3641566541556358
31412	2020-06-17 16:56:50	2020-06-17	Carson Cronin DDS	carson.cronin.dds@geemail.com	Birmingham	Alabama	3034928192818480	9292f38389ed1bdbd35af9abf23b77c2	American Express	33.6030298039108501	-86.8653038289174475
31413	2020-06-17 17:04:29	2020-06-17	Jemal Fadel DVM	jemal.fadel.dvm@woohoo.com	Ontario	California	589334091917590	7dddd4959228c7d327d5fb7abe2a5eec	Maestro	33.950183063294368	-117.596095410744482
31414	2020-06-17 17:20:06	2020-06-17	Andrea Mueller DDS	andrea.mueller.dds@geemail.com	Dayton	Ohio	3337260131456851037	5ed7331c66e008ddb7a4a116b9ad8697	JCB 15 digit	39.685119953916967	-84.2027439740676442
31415	2020-06-17 17:22:34	2020-06-17	Miss Aloma Romaguera	miss.aloma.romaguera@geemail.com	Indianapolis	Indiana	3058147774779087	e76e673050a3aac6806a5fdf7342adb0	American Express	39.7729264304049295	-86.2215557193119082
31416	2020-06-17 17:24:05	2020-06-17	Chimere Altenwerth-Satterfield	chimere.altenwerth.satterfield@warmmail.com	San Bernardino	California	4073418898539	b0f3754a47847420123f64d0d0a67bb7	American Express	34.1158511791642738	-117.315070301831142
31417	2020-06-17 17:37:13	2020-06-17	Mr. Chin Rempel DDS	mr.chin.rempel.dds@woohoo.com	Newark	New Jersey	3477226164089269	1d68ba5df177b495bfe0d978bcf75784	American Express	40.753602220901108	-74.0866768826939222
31418	2020-06-17 17:45:11	2020-06-17	Skyla Jakubowski	skyla.jakubowski@warmmail.com	Ontario	California	3467715040056437	d8e9756aeca29f743f1a05a0184c085c	Mastercard	34.1392172768857307	-117.671906935806206
31419	2020-06-17 17:45:19	2020-06-17	Mr. Solomon Gutmann I	mr.solomon.gutmann.i@woohoo.com	Lansing	Michigan	3088994388891253277	010fa7af8a8fccf9af921d4c9757b663	JCB 16 digit	42.7916992460686743	-84.5341536926228514
31420	2020-06-17 17:52:55	2020-06-17	Rolla Aufderhar	rolla.aufderhar@geemail.com	Portland	Oregon	3772024326176131	c27b89f16d81d16a44ade5b8ea8d888b	JCB 16 digit	45.5318453434742949	-122.605914434092128
31421	2020-06-17 17:55:14	2020-06-17	Destany Rutherford	destany.rutherford@geemail.com	Dallas	Texas	4330639573633100	c7d502ad3dce705844cef4f3ea87d5ff	VISA 16 digit	32.7234398453302688	-96.7797219627499459
31422	2020-06-17 18:05:38	2020-06-17	Friend Witting	friend.witting@geemail.com	Berkeley	California	210003262532220350	4545014e4744ed7a1fde81d32c3cc867	JCB 15 digit	37.8535329839474599	-122.265801916145534
31423	2020-06-17 18:05:59	2020-06-17	Tracy Nitzsche	tracy.nitzsche@warmmail.com	San Francisco	California	6011108365215667344	1da6dfe048c3bef6262ab3108fbafbbe	Diners Club / Carte Blanche	37.7747240177906178	-122.433238536346266
31424	2020-06-17 18:07:19	2020-06-17	Rashaan O'Hara	rashaan.o'hara@geemail.com	New York	New York	3785007481562190	97e32e6517503bdd793288f3afeee1b1	Diners Club / Carte Blanche	40.7079869891740387	-73.9258273459866615
31425	2020-06-17 18:14:36	2020-06-17	Mr. Chuck Bernier III	mr.chuck.bernier.iii@warmmail.com	Austin	Texas	639063919326205	c2cf396204e9d1878276589b34c3da3d	Diners Club / Carte Blanche	30.3908249828625472	-97.7563678425975127
31426	2020-06-17 18:14:51	2020-06-17	Miss Emelie Kulas MD	miss.emelie.kulas.md@geemail.com	Miami	Florida	4853274276044954	abfc7aac4eeed2a1a83a3677be8cc5f1	Mastercard	25.7677108078401567	-80.227547063293315
31427	2020-06-17 18:23:19	2020-06-17	Dyan Mayer-Schuster	dyan.mayer.schuster@geemail.com	Houston	Texas	4475417508259043	bdce14c2d151735a7c52897ac61da289	JCB 16 digit	29.7256789256896816	-95.4412444961737805
31428	2020-06-17 18:24:56	2020-06-17	Mr. Declan Veum PhD	mr.declan.veum.phd@geemail.com	Reno	Nevada	4919222760940502	3b067131effba652388dc1eccdda57e8	JCB 16 digit	39.501062878415361	-119.891513006917762
31429	2020-06-17 18:28:26	2020-06-17	Barrett Windler DVM	barrett.windler.dvm@geemail.com	New York	New York	3743672744600292	631f996869683f7c49a19941cb0411f1	VISA 16 digit	40.7473666142430133	-73.9101278453495354
31430	2020-06-17 18:40:52	2020-06-17	Mrs. Ashlie Torphy	mrs.ashlie.torphy@warmmail.com	Chicago	Illinois	4809895047284	e8d44b2268557aa8d2f7f0fbae41c6c5	VISA 16 digit	41.8172132749412242	-87.7657506044983791
31431	2020-06-17 18:49:39	2020-06-17	Letty Larson-Bauch	letty.larson.bauch@woohoo.com	Oakland	California	3158982538783408702	692f1aab592ce8f8431d2eba59aa363e	VISA 16 digit	37.8018641341411694	-122.264788979965019
31432	2020-06-17 18:52:45	2020-06-17	Mr. Edward Schowalter	mr.edward.schowalter@geemail.com	Spokane	Washington	4869121469871085	ae45a39e9bfe1887142f5db29f430daa	JCB 16 digit	47.7423661418963192	-117.525824517886349
31433	2020-06-17 18:56:58	2020-06-17	Dr. Jess Terry MD	dr.jess.terry.md@geemail.com	San Jose	California	3112094339455908128	aec2c09d549c58a754ce125914b3918c	JCB 16 digit	37.3406390007872133	-121.779367656189578
31434	2020-06-17 18:58:00	2020-06-17	Holli Fahey	holli.fahey@geemail.com	Colorado Springs	Colorado	3056996737655012	0902263999a182d805d7b6d53fb5db21	American Express	38.8835151629105198	-104.700567800474161
31435	2020-06-17 18:59:00	2020-06-17	Wiliam Hilll	wiliam.hilll@warmmail.com	San Francisco	California	4205856400689	6d734f29c3c525a74e96a32499fd9ea5	American Express	37.7733351708123308	-122.424818092567946
31436	2020-06-17 19:01:29	2020-06-17	Sandra Price-Hoppe	sandra.price.hoppe@geemail.com	Irving	Texas	51997091269594465	65b0be13595e417cbfd430afef6f542e	Diners Club / Carte Blanche	32.9092214062295838	-96.9233542670775137
31437	2020-06-17 19:05:08	2020-06-17	Dr. Burnice Emmerich	dr.burnice.emmerich@geemail.com	Austin	Texas	3450372901392714	ea3bd60da78cf55616e6097cb81c5cd4	VISA 16 digit	30.3941727805078017	-97.7146063825819624
31438	2020-06-17 19:15:50	2020-06-17	Syed Rosenbaum PhD	syed.rosenbaum.phd@warmmail.com	Tacoma	Washington	4167186237491770	b3232d2ec7b58c80e36883d211efe260	JCB 16 digit	47.303953190485764	-122.515666162385799
31439	2020-06-17 19:22:22	2020-06-17	Jade Farrell	jade.farrell@warmmail.com	Oakland	California	3158097280848603363	bdd4b163cd3fd46044ec5268d592cd31	American Express	37.8200888701802285	-122.293353961300156
31440	2020-06-17 19:25:14	2020-06-17	Kalvin Stehr	kalvin.stehr@woohoo.com	Memphis	Tennessee	3018066433342907	08c461a7cf0a6a7957d6f172721daa09	JCB 16 digit	35.1270251988500348	-89.9547907818831476
31441	2020-06-17 19:38:18	2020-06-17	Eloisa Hane	eloisa.hane@geemail.com	Wilmington	North Carolina	869957306403592598	d270931e647c7fa31c054ed216544135	Voyager	34.2729641737237571	-77.912977658071739
31442	2020-06-17 19:40:01	2020-06-17	Theron Denesik	theron.denesik@geemail.com	San Francisco	California	3112813434134400066	9157bba4bd03c59794c8543f2d9d4c9a	Maestro	37.7378017493990541	-122.394890620905514
31443	2020-06-17 19:45:59	2020-06-17	Porsha Bernier DVM	porsha.bernier.dvm@geemail.com	Milwaukee	Wisconsin	4126594132709	dfb301f1e74a66f542a660a99dbea9f2	American Express	42.9879825281530614	-87.9169211638726296
31444	2020-06-17 19:47:03	2020-06-17	Joanna Altenwerth	joanna.altenwerth@geemail.com	Berkeley	California	4155529627475	edad56de983f94d5bdc3679dae75ccc7	Voyager	37.8839290839383196	-122.315705258201845
31445	2020-06-17 19:56:13	2020-06-17	Arleth Schaefer	arleth.schaefer@warmmail.com	San Francisco	California	3004722036408917	59bd9755026c73822d0b8dfb5a396f15	JCB 16 digit	37.7568007008287267	-122.424241508841192
31446	2020-06-17 19:58:06	2020-06-17	Alpha Labadie	alpha.labadie@geemail.com	New York	New York	869988251826754404	263f226268f3ca50579ee6070bee1d60	VISA 16 digit	40.6526078102868027	-73.9791331208672318
31447	2020-06-17 20:10:15	2020-06-17	Dorothea Torp	dorothea.torp@geemail.com	Oakland	California	869942044497834935	139e9d20b5a318d517b0e768e0369622	JCB 16 digit	37.7895244332899267	-122.274986986399327
31448	2020-06-17 20:28:03	2020-06-17	Dr. Dameon Trantow	dr.dameon.trantow@warmmail.com	Chattanooga	Tennessee	54970964592169042	c466bed6a4ff6f95acc24b66da41ce86	Diners Club / Carte Blanche	35.0836107130013417	-85.2972178616389698
31449	2020-06-17 20:41:12	2020-06-17	Alma Nitzsche	alma.nitzsche@woohoo.com	Odessa	Texas	4657386402722648	60239b52f026120378cc6078ec175369	JCB 16 digit	31.9050698468007141	-102.365505434215436
31450	2020-06-17 20:55:28	2020-06-17	Jordon McGlynn	jordon.mcglynn@geemail.com	Virginia Beach	Virginia	180084848457654383	9e7cbbfab6abc1c9bc6f1f9213f4255e	JCB 15 digit	36.8538312585745018	-76.105914749172328
31451	2020-06-17 21:17:00	2020-06-17	Corinna West	corinna.west@geemail.com	Tyler	Texas	3337185902646503056	3568b76b3c5c664a3312a30026ef7477	JCB 16 digit	32.3469692378819005	-95.2816007171865493
31452	2020-06-17 21:17:49	2020-06-17	Rondal Doyle	rondal.doyle@geemail.com	San Francisco	California	180000760802664697	d497327fe0bb8d19eacd319091787478	JCB 16 digit	37.7568767991764318	-122.45855574050465
31453	2020-06-17 21:21:08	2020-06-17	Estel Bashirian	estel.bashirian@geemail.com	Bakersfield	California	4160688326118989	9a16b8b5f69d5cba2be456533efc3b16	Voyager	35.4133274088788781	-119.059893540739267
31454	2020-06-17 21:27:13	2020-06-17	Maury Okuneva	maury.okuneva@woohoo.com	New York	New York	4060825509252109	3aac17996b3d8a246bd29017c7f50bac	JCB 16 digit	40.604335849568244	-73.8814838035859083
31455	2020-06-17 21:30:40	2020-06-17	Mr. Henery Ruecker III	mr.henery.ruecker.iii@geemail.com	Daly City	California	3112494560107766772	9d928c5cede208febafd4f8b4ce3f764	JCB 16 digit	37.6153556417595567	-122.39356699181721
31456	2020-06-17 21:34:59	2020-06-17	Jovany Kuphal	jovany.kuphal@geemail.com	Joliet	Illinois	4474974560770	4c9ebdf93bb19bc276de4d380c9aa8b4	Maestro	41.5298319731697418	-88.0970839126605512
31457	2020-06-17 21:38:15	2020-06-17	Haley Dooley-Kerluke	haley.dooley.kerluke@geemail.com	Tampa	Florida	3528185469313039384	add666d3a55a8538a27f7a654b8a3a09	VISA 16 digit	28.0093956662923098	-82.4760034970685751
31458	2020-06-17 21:38:34	2020-06-17	Zana Mayer	zana.mayer@geemail.com	Kansas City	Missouri	55738489931549590	15f4eecd1f630b83a58cc97c9e77f72e	Diners Club / Carte Blanche	39.0689997230026904	-94.5222198615539781
31459	2020-06-17 21:54:29	2020-06-17	Claiborne Heidenreich	claiborne.heidenreich@geemail.com	Miami	Florida	4420390166725793	b3b9ee50d1595caf60fed1563c8dfca3	VISA 16 digit	25.7896713686313497	-80.2836769669190033
31460	2020-06-17 21:59:58	2020-06-17	Neely Heaney	neely.heaney@geemail.com	Phoenix	Arizona	3158052026271382360	4b062451f76eae01fb0ec7d7d05e4def	Voyager	33.5108769099161066	-112.162266622709495
31461	2020-06-17 22:02:25	2020-06-17	Osbaldo Cronin	osbaldo.cronin@geemail.com	New York	New York	3010223257842128	40c8d235d3db61f79edbed47a670347a	VISA 13 digit	40.6073095423392942	-73.8688712896209125
31462	2020-06-17 22:04:19	2020-06-17	Council Labadie	council.labadie@geemail.com	Philadelphia	Pennsylvania	4168449534832743	028a26c172bfbc70d424b1866a2c5272	American Express	40.0974156345665449	-75.079819677154731
31463	2020-06-17 22:08:21	2020-06-17	Dedrick Volkman	dedrick.volkman@warmmail.com	West Jordan	Utah	3443758844987406	7e0a42f61470d8bedc64cd2f875229a3	Mastercard	40.6847221598751858	-111.986048468164356
31464	2020-06-17 22:18:00	2020-06-17	Giselle Haley	giselle.haley@geemail.com	Rochester	Minnesota	4345485041224574	9f5a91ff00909f49a5509c8473f13ea1	VISA 16 digit	43.9955475174259405	-92.4733376382969254
31465	2020-06-17 22:28:31	2020-06-17	Ole Balistreri	ole.balistreri@geemail.com	San Diego	California	4581250402624	88023703fd87e9f0a39e8376ade5ba69	VISA 13 digit	32.7476543778620695	-117.156268558129668
31466	2020-06-17 23:17:09	2020-06-17	Leatha Gaylord-Cole	leatha.gaylord.cole@geemail.com	Chicago	Illinois	3005773558068364	de2cb1704b69d1e2110884bb12fd935d	JCB 15 digit	41.926958543511482	-87.5962679977558452
31467	2020-06-17 23:24:30	2020-06-17	Avon Hessel	avon.hessel@geemail.com	Corpus Christi	Texas	4063878570865884	3a8e35e60d6fc584eba8edaaa72be30f	JCB 15 digit	27.7793656755175462	-97.181211652449889
31468	2020-06-17 23:36:58	2020-06-17	Hobart Ratke	hobart.ratke@geemail.com	San Francisco	California	869976664687075004	16e7f4164950de72fc4a72ff954f2180	VISA 13 digit	37.7705896531017871	-122.438957565178001
31469	2020-06-17 23:40:07	2020-06-17	Jinnie Wehner	jinnie.wehner@geemail.com	Hartford	Connecticut	4151464587643169	784a8dfd354924f4cb9bb1ccd86e085c	JCB 16 digit	41.8184485301855986	-72.6367969359163226
31470	2020-06-17 23:51:04	2020-06-17	Zillah Blick PhD	zillah.blick.phd@geemail.com	Phoenix	Arizona	3337988290985649949	a93bd684cdc2ce749b515834968b8f3b	Maestro	33.5753393030658387	-112.039902171625201
31471	2020-06-17 23:56:39	2020-06-17	Dr. Winton Stamm PhD	dr.winton.stamm.phd@geemail.com	Lexington	Kentucky	180087021125144339	8fe7bf72ff5058a9bd15fa7004f9bfda	Maestro	38.0110822663053867	-84.3708934635289012
31472	2020-06-17 23:59:46	2020-06-17	Russel Rice	russel.rice@warmmail.com	San Francisco	California	4807244594618	2ff2cd076f4a503f07577cefdc2a03ee	Mastercard	37.7785083249740765	-122.392070517704468
31473	2020-06-18 00:03:08	2020-06-18	Dr. Macel Ritchie	dr.macel.ritchie@geemail.com	Huntington Beach	California	180090977238983241	78ba0b807e7afcc27cbdc8b773dd5b46	Discover	33.7265733956866001	-117.934256795899188
31474	2020-06-18 00:03:49	2020-06-18	Vergil Bruen	vergil.bruen@geemail.com	Denver	Colorado	503848826410028	9457df0f4015bcddaec8f164917ea3e0	American Express	39.7582396903127417	-104.84467918633149
31475	2020-06-18 00:12:32	2020-06-18	Elza Tremblay	elza.tremblay@geemail.com	Chicago	Illinois	4533010352151	4308509f84832e125fd7d30599e14a65	Voyager	41.8390087136369218	-87.6507936395734504
31476	2020-06-18 00:19:55	2020-06-18	Gustav Ortiz Jr.	gustav.ortiz.jr.@woohoo.com	Tulsa	Oklahoma	55983025019779857	225da9a7ecff21916352b9a4ae1b9ac1	VISA 13 digit	36.1768648036658718	-95.8971414117097822
31477	2020-06-18 00:33:39	2020-06-18	Almyra Smitham	almyra.smitham@geemail.com	Phoenix	Arizona	3112705257089647675	10131737ce58a155c6bdb2c33fc76068	JCB 16 digit	33.5560268604129561	-112.003767047815401
31478	2020-06-18 00:55:04	2020-06-18	Dagny Kessler DDS	dagny.kessler.dds@geemail.com	Chesapeake	Virginia	3337581866312402473	4f47ec80605f8495fcc0c4b9a3e5bd8a	JCB 15 digit	36.6993866506736737	-76.3869947159040663
31479	2020-06-18 00:59:16	2020-06-18	Tayler Goyette	tayler.goyette@warmmail.com	Baltimore	Maryland	210055241880097765	4c46ea8f635ed2b0d57b900871ed4f62	Discover	39.3022333031520219	-76.534203588033094
31480	2020-06-18 01:11:39	2020-06-18	Chanie Johns	chanie.johns@warmmail.com	Charlotte	North Carolina	180031257787171007	d26cc4fc0ab4c4534df26aa7601b8d0c	American Express	35.1706379631321866	-80.814002195088193
31481	2020-06-18 01:13:26	2020-06-18	Derwin Lowe-Parisian	derwin.lowe.parisian@geemail.com	Philadelphia	Pennsylvania	6011336055651917758	04d035507a7fcabfd9500025df91b769	Voyager	39.9174250727478395	-75.0616361098729072
31482	2020-06-18 01:28:05	2020-06-18	Ruthie Harber	ruthie.harber@geemail.com	Newport News	Virginia	3050925227416391	dcbdf800b12e0520501f84bab6f87649	Mastercard	37.1097343800019459	-76.5163695789203047
31483	2020-06-18 01:33:10	2020-06-18	Dr. Guss Wisozk	dr.guss.wisozk@warmmail.com	New York	New York	180048298020732933	2199afbc88165ee073fb6b52fe9f32be	American Express	40.6612064157836102	-73.959762705619255
31484	2020-06-18 01:37:30	2020-06-18	Cassondra Predovic	cassondra.predovic@woohoo.com	Seattle	Washington	4184549976824411	9273a5fd6f52f1d053f67169a4126b64	American Express	47.5700794878341284	-122.281537989100059
31485	2020-06-18 01:43:26	2020-06-18	Dr. Mahala Hauck	dr.mahala.hauck@geemail.com	Topeka	Kansas	4427138333252	19d7502fc845150a40bccd58f011974f	JCB 16 digit	39.113717506539821	-95.6967347190890507
31486	2020-06-18 01:46:33	2020-06-18	Bernardine Satterfield	bernardine.satterfield@geemail.com	San Francisco	California	3481383647106485	0e48bd645a06ccc3bbc5bf12f1e696f3	VISA 13 digit	37.8343484868256184	-122.432338182500274
31487	2020-06-18 02:19:22	2020-06-18	Clemens Pacocha	clemens.pacocha@woohoo.com	Chandler	Arizona	3019234885298170	7b1c513ab5df3ce97d4dd9f2fedec360	VISA 13 digit	33.2098637886900434	-111.76848334100805
31488	2020-06-18 02:24:22	2020-06-18	Annie Kertzmann	annie.kertzmann@geemail.com	Oakland	California	869966364098135180	9fde3223b243cb79ec75613bf32adc60	VISA 13 digit	37.8623976721476581	-122.268039377177146
31489	2020-06-18 02:48:52	2020-06-18	Ms. Zariah Ruecker DVM	ms.zariah.ruecker.dvm@geemail.com	Norwalk	California	639096276996798	646020e4af3b4f95cedc1e394528c8ed	Mastercard	33.9739274697959459	-118.054046209160234
31490	2020-06-18 02:50:34	2020-06-18	Leonel Gutkowski	leonel.gutkowski@geemail.com	High Point	North Carolina	210089643333630581	bbbfc7bcae70d50f7865c2e909cd759b	JCB 16 digit	35.9354380359500638	-80.0678041204083684
31491	2020-06-18 02:54:12	2020-06-18	Kaylynn Lemke PhD	kaylynn.lemke.phd@geemail.com	Palmdale	California	4631241651241	d2274f99287efc3ee8296a2f1d1fd9fa	Diners Club / Carte Blanche	34.560837224809454	-118.112530298996347
31492	2020-06-18 02:55:05	2020-06-18	Mrs. Rubie Spinka DDS	mrs.rubie.spinka.dds@geemail.com	Albuquerque	New Mexico	3088998155447156338	497052020f4980d47d016c86d27e85dd	Discover	35.0497202449612359	-106.681936969801413
31493	2020-06-18 03:02:37	2020-06-18	Elizah Schinner	elizah.schinner@geemail.com	New York	New York	3112376240067364214	47738036a194cfe1cdd21ff865dae4ca	Discover	40.5677424777056999	-74.0363168701890828
31494	2020-06-18 03:09:30	2020-06-18	Mrs. Lesta Schinner	mrs.lesta.schinner@geemail.com	Houston	Texas	4102350922355660	ec6e5a57e601c40290a22cb08b9cfd5e	JCB 16 digit	29.7865348711222424	-95.4738756275750688
31495	2020-06-18 03:26:57	2020-06-18	Kaylyn Smitham	kaylyn.smitham@geemail.com	Santa Ana	California	561214108688848	8ec23e1fd1989393af29eeaf284f6fd5	Discover	33.8131186743371188	-117.868818744311099
31496	2020-06-18 03:32:13	2020-06-18	Colie Hagenes	colie.hagenes@warmmail.com	Huntsville	Alabama	4163617811852	cb9c14ff86f1c27b078d5ddd04e8753e	Mastercard	34.6855229289513076	-86.6467493364140466
31497	2020-06-18 03:33:25	2020-06-18	Dewayne Johnston	dewayne.johnston@geemail.com	Virginia Beach	Virginia	3112283428506950311	80a5e6dbbc9347ccdf52aa457984ed66	Voyager	36.7176546334475304	-76.0967433714445605
31498	2020-06-18 03:33:41	2020-06-18	Tawny Erdman	tawny.erdman@geemail.com	Denver	Colorado	6011505730369608015	0cb4e266631b9ffa7ee2d926c07a47fc	American Express	39.7726930709142223	-104.800233771210912
31499	2020-06-18 03:44:11	2020-06-18	Mr. Rutherford Shanahan	mr.rutherford.shanahan@warmmail.com	Stockton	California	3405384249463665	e7349b0e22b7979ec500f130204b781c	American Express	37.881912664343794	-121.345143205168839
31500	2020-06-18 03:50:29	2020-06-18	Art Mann	art.mann@geemail.com	Berkeley	California	869983205315862834	5c96c2f723159e03676565848e09023c	VISA 13 digit	37.862020109277374	-122.266778097250395
31501	2020-06-18 03:58:28	2020-06-18	Tiffany Nolan	tiffany.nolan@geemail.com	San Francisco	California	675935550889345	763d4d968cc137228104fcffeb36bb58	VISA 16 digit	37.7482175588009667	-122.428179559672046
31502	2020-06-18 04:11:49	2020-06-18	Shakira Kiehn	shakira.kiehn@geemail.com	Cedar Rapids	Iowa	3720271769511836	e9e189cb9e0b3b3a6b5a94f5535efc7b	Mastercard	41.9686946199350075	-91.6145777126375691
31503	2020-06-18 04:13:44	2020-06-18	Jackeline Jacobi	jackeline.jacobi@geemail.com	Las Vegas	Nevada	6011219829907534688	dafe293963f998adf00923149f71c868	JCB 16 digit	36.283825056032093	-115.191162599970028
31504	2020-06-18 04:16:00	2020-06-18	Mr. Simpson Hessel DDS	mr.simpson.hessel.dds@geemail.com	Topeka	Kansas	060446144404384	64d4d2b48925d5739d25cc7aa0d75940	Mastercard	39.0210329106010505	-95.7424568234186637
31505	2020-06-18 04:17:24	2020-06-18	Kimberely Schroeder PhD	kimberely.schroeder.phd@geemail.com	Houston	Texas	3528582504942814945	551845912d5603da2bac9132ec11be81	JCB 16 digit	29.7055137515611953	-95.3126879528645503
31506	2020-06-18 04:42:00	2020-06-18	Marlo Johnson	marlo.johnson@geemail.com	Anaheim	California	3528247895511484194	819a45c0f371d66f3c5431249ac2b893	JCB 15 digit	33.8061222832482287	-117.798004571415845
31507	2020-06-18 04:44:54	2020-06-18	Liller Kuvalis MD	liller.kuvalis.md@warmmail.com	Houston	Texas	3045803441956143	10c880ad9caf150d93cfd230ae3c48d5	American Express	29.7597808819808058	-95.3057746133782047
31508	2020-06-18 04:49:20	2020-06-18	Mrs. Angelia Moore DVM	mrs.angelia.moore.dvm@geemail.com	Charlotte	North Carolina	4071935294327474	3307d9a485a153733b6f9d778ec608d2	JCB 15 digit	35.1165117419112462	-80.9275696765109984
31509	2020-06-18 04:56:51	2020-06-18	Mr. Damon Watsica	mr.damon.watsica@geemail.com	San Francisco	California	3096583119531110768	c295b8744779df8a051eb48c07305f71	VISA 13 digit	37.746946342855729	-122.431974037099721
31510	2020-06-18 05:08:19	2020-06-18	Orlo Windler IV	orlo.windler.iv@geemail.com	El Paso	Texas	869913095388204518	6356a7ef1934eb0b338670640d684cf5	Voyager	31.7821245787028239	-106.33621119204723
31511	2020-06-18 05:09:31	2020-06-18	Gail Bogisich DDS	gail.bogisich.dds@warmmail.com	New York	New York	869981762403236695	24e1b75dbd0abf54bf445bae9703de9e	Discover	40.5793979051280758	-74.0252424865391134
31512	2020-06-18 05:10:09	2020-06-18	Warren Metz-Cartwright	warren.metz.cartwright@geemail.com	Glendale	Arizona	676335878698634	1e09745ee13c182f78565cc5a96e76a2	VISA 16 digit	33.4990982472192442	-112.243975382649893
31513	2020-06-18 05:11:01	2020-06-18	Johnny Johnson	johnny.johnson@geemail.com	Vallejo	California	6011520221198950647	5e27e83d06daab39d507e6674aee9cb2	VISA 16 digit	38.0485115318182849	-122.319413840431721
31514	2020-06-18 05:29:23	2020-06-18	Adron Bode	adron.bode@geemail.com	Peoria	Illinois	180089549650632078	25f639ebec4e78a26d63875871901a24	JCB 15 digit	40.6680479179937393	-89.5525291863713448
31515	2020-06-18 05:30:51	2020-06-18	Mr. Atha Ortiz Sr.	mr.atha.ortiz.sr.@geemail.com	Arlington	Texas	4153310299843563	63895690c69e423b7ed637faf8dc0f95	Discover	32.6680167129978543	-97.0639011500895066
31516	2020-06-18 05:52:36	2020-06-18	Gale Bauch	gale.bauch@geemail.com	Berkeley	California	4814161450794090	ac18f24fc0b714c4603c28557b76e80b	Diners Club / Carte Blanche	37.9071687093932184	-122.253238460858299
31517	2020-06-18 05:56:36	2020-06-18	Ms. Domonique Veum DVM	ms.domonique.veum.dvm@woohoo.com	Los Angeles	California	4814297553113588	0035c295f4d2374c7797fd016372c9cc	American Express	33.9449223107058558	-118.382005866802473
31518	2020-06-18 05:57:05	2020-06-18	Joretta Dooley DVM	joretta.dooley.dvm@geemail.com	Los Angeles	California	3025869677718424	32e1694d1db2e4a49924329f0b5bcba6	Mastercard	33.9221846274431797	-118.47972169858329
31519	2020-06-18 06:03:29	2020-06-18	Hilbert Russel	hilbert.russel@warmmail.com	Los Angeles	California	4733728896289	25b9a5e63295ad9017ebf6356c6d2d92	JCB 15 digit	34.1133352882094627	-118.350788557482133
31520	2020-06-18 06:08:27	2020-06-18	Jaymes Conroy	jaymes.conroy@geemail.com	Little Rock	Arkansas	6011617069929392629	ea3a05ecb432911a6d32bb86c75d8a8d	Mastercard	34.699934526374193	-92.3994551516477003
31521	2020-06-18 06:16:54	2020-06-18	Kelton Legros	kelton.legros@woohoo.com	Moreno Valley	California	3485352564733148	60f63080e775ef29db8ba03970c7efed	JCB 16 digit	33.8692035907872011	-117.138886834212386
31522	2020-06-18 06:17:00	2020-06-18	Amanda Becker DDS	amanda.becker.dds@geemail.com	Lexington	Kentucky	180071891722569601	0458edcabd7967da5e64a304e95bd181	American Express	38.0809697816956785	-84.5332283430632145
31523	2020-06-18 06:17:13	2020-06-18	Almond Bergnaum	almond.bergnaum@woohoo.com	Greensboro	North Carolina	4751307335765061	b30c9ecc45f2594812d4d38802467cd2	JCB 16 digit	36.064110785687717	-79.9098175614122255
31524	2020-06-18 06:20:58	2020-06-18	Juanita Mohr	juanita.mohr@geemail.com	New York	New York	630403235008798	846f016b92fcf608fd5b863ccd403cfe	American Express	40.6018504358585943	-74.0103368495952338
31525	2020-06-18 06:22:23	2020-06-18	Mr. Dempsey Mraz	mr.dempsey.mraz@geemail.com	Detroit	Michigan	869921720102667274	f1b60e0a80db7db3bf0dc7a2218d840c	Diners Club / Carte Blanche	42.4823018097709877	-83.1208069665010925
31526	2020-06-18 06:41:59	2020-06-18	Haiden Dicki	haiden.dicki@geemail.com	Virginia Beach	Virginia	3483148281667854	3c87f6aea546db8aac2f640f923c1695	Maestro	36.8274693234078612	-75.9915788325153301
31527	2020-06-18 06:48:37	2020-06-18	Mrs. Mannie Ondricka	mrs.mannie.ondricka@geemail.com	Berkeley	California	4246675224009	f487e17385411990a5fd01cbd16ed1e8	JCB 16 digit	37.8629176841849997	-122.241347535051716
31528	2020-06-18 07:02:35	2020-06-18	Dionicio Blick	dionicio.blick@geemail.com	Rockford	Illinois	4610924285823913	19c7101207d8fe64e3b7a4f3885f240f	VISA 16 digit	42.1819546495575466	-88.9974295691404507
31529	2020-06-18 07:07:15	2020-06-18	Giovanny Haag	giovanny.haag@geemail.com	Saint Paul	Minnesota	4544514593857934	15d044a8ea908f1f4c30619fd50f1612	Mastercard	45.0053744068309669	-93.0367424847356972
31530	2020-06-18 07:07:39	2020-06-18	Zachariah Labadie	zachariah.labadie@geemail.com	Joliet	Illinois	501829119174158	e866dd45e7d867a05eae371a5b97c286	Diners Club / Carte Blanche	41.5693236935742192	-88.0545969195302547
31531	2020-06-18 07:15:30	2020-06-18	Ellamae Doyle	ellamae.doyle@geemail.com	Tucson	Arizona	4348577783876319	a6e8e52595fc5d1b3a4754305ace2572	JCB 16 digit	32.1310635920655017	-110.87888131106682
31532	2020-06-18 07:31:07	2020-06-18	Vernia Padberg PhD	vernia.padberg.phd@geemail.com	Mesa	Arizona	3783348223476949	567e2ceeaaeffc50d36765580f7a6a2c	VISA 16 digit	33.3632551096524992	-111.769131136953462
31533	2020-06-18 07:53:30	2020-06-18	Cecily Purdy	cecily.purdy@geemail.com	Lakewood	New Jersey	55304872100539035	96a8ae602ccca28e2cdee4c89dd92921	Diners Club / Carte Blanche	40.0136242921281635	-74.2907803479392044
31534	2020-06-18 07:56:20	2020-06-18	Marlo Roberts	marlo.roberts@woohoo.com	Akron	Ohio	3437846592465754	a50c6f70ce7486b7a5cc0a30f2b2f238	Discover	41.0195980928670636	-81.4666331527136265
31535	2020-06-18 08:03:31	2020-06-18	Myla Dooley	myla.dooley@geemail.com	Miami	Florida	4579082322208199	91458a723ce96409ce3720cd0bc7c433	Voyager	25.8167789274498851	-80.1299342024944821
31536	2020-06-18 08:05:59	2020-06-18	Ryleigh Bednar PhD	ryleigh.bednar.phd@geemail.com	Raleigh	North Carolina	4423551837653527	af58bdd6fe793d592b96f2d50a47116b	Mastercard	35.8609877036087212	-78.5857667706843444
31537	2020-06-18 08:17:47	2020-06-18	Jadon Denesik MD	jadon.denesik.md@geemail.com	Garland	Texas	4904073780491027	9b0438f33c18b62bacaccda34976bf7a	Mastercard	32.885973259317872	-96.5662515930991674
31538	2020-06-18 08:26:18	2020-06-18	Lance Hackett	lance.hackett@geemail.com	Henderson	Nevada	639028996965829	d3825a94d4a772f16eec441a66a1daeb	VISA 16 digit	36.0783797453090571	-115.094764467856663
31539	2020-06-18 08:27:24	2020-06-18	Mr. Levy Fay IV	mr.levy.fay.iv@woohoo.com	Philadelphia	Pennsylvania	55954261326896424	e8e8ee8a545b3d57cb93d2c3ff11e3b7	VISA 13 digit	39.9650344824843131	-75.0600136506270701
31540	2020-06-18 08:29:03	2020-06-18	Mr. Logan Walker	mr.logan.walker@warmmail.com	Boulder	Colorado	6011903955495588298	3311fabc104f65592f18dbf870b925b5	VISA 13 digit	39.9584164239913235	-105.255908772363895
31541	2020-06-18 08:39:37	2020-06-18	Mr. Marius Eichmann V	mr.marius.eichmann.v@geemail.com	Omaha	Nebraska	3337935765638910107	a1824da16f13ff80c01b709eefb29788	JCB 16 digit	41.2666575119510313	-96.0052270379032962
31542	2020-06-18 08:45:27	2020-06-18	Gordon Bins	gordon.bins@woohoo.com	Miami	Florida	3088197957850201454	e75f125023cb7aa46359c4035a6a22d3	American Express	25.8549080403193834	-80.2139069104906213
31543	2020-06-18 08:47:36	2020-06-18	Danica Schimmel	danica.schimmel@geemail.com	Houston	Texas	4679540658740571	4fd9b9f6d7bb749c577e9eebd17b2ea7	Voyager	29.749078087842463	-95.364690641175585
31544	2020-06-18 08:54:55	2020-06-18	Makala Conn-Shields	makala.conn.shields@geemail.com	Scottsdale	Arizona	3001155500338695	5d5a6f8d2d47fc1ad693fc2ed1ab8292	JCB 16 digit	33.5896918864112379	-111.777751534847908
31545	2020-06-18 08:55:29	2020-06-18	Homer Von	homer.von@warmmail.com	Jersey City	New Jersey	4891848722925397	6af3ae41730bf8befd13caf3909e2776	JCB 16 digit	40.6472435444533815	-74.000350820967185
31546	2020-06-18 08:59:23	2020-06-18	Augustina McClure MD	augustina.mcclure.md@geemail.com	San Francisco	California	3337391807395819951	dbae35e67154b4dc0ed62e9e20475e1d	JCB 15 digit	37.7926764389696999	-122.402265667788498
31547	2020-06-18 09:03:54	2020-06-18	Bettie Cole-Dietrich	bettie.cole.dietrich@geemail.com	North Charleston	South Carolina	180045309250716794	87ae0f23178f87614835a0f43db38ef2	Maestro	32.8689713671497969	-80.1118732999637757
31548	2020-06-18 09:08:44	2020-06-18	Jeptha Collins	jeptha.collins@warmmail.com	New York	New York	4134639884595657	a54c0cb37772fa194a03b87c3fe5adae	JCB 16 digit	40.6331586764883212	-73.9966921884927871
31549	2020-06-18 09:14:34	2020-06-18	Dellie Berge	dellie.berge@geemail.com	Houston	Texas	180050331481115432	f28813c68795dab1021c72453f496a9a	VISA 13 digit	29.8797639051996171	-95.32953433427177
31550	2020-06-18 09:19:46	2020-06-18	Makhi Williamson-Haag	makhi.williamson.haag@geemail.com	Charlotte	North Carolina	3480994126459988	4c34b8455ce6209ede2ecf68771e141b	VISA 13 digit	35.1436431163709599	-80.8633321668896912
31551	2020-06-18 09:21:06	2020-06-18	Dr. Demetrios Blick DDS	dr.demetrios.blick.dds@geemail.com	New York	New York	51875110511104076	bcc60854247494bcea91ce0c5992d585	JCB 16 digit	40.5703953582551335	-74.0053596684604855
31552	2020-06-18 09:24:47	2020-06-18	Dorcas Gottlieb	dorcas.gottlieb@warmmail.com	Tampa	Florida	3096478267404909622	880d2985e4a0914373020c235b196fe3	JCB 15 digit	27.9240416957646609	-82.5542848682243289
31553	2020-06-18 09:30:11	2020-06-18	Mr. Trevin Lynch	mr.trevin.lynch@geemail.com	Grand Prairie	Texas	3434135805380874	d31c47099a71d1bfc55f498eb817ce72	Voyager	32.7308220385626001	-96.9664559014480574
31554	2020-06-18 09:32:34	2020-06-18	Lashanda McLaughlin DDS	lashanda.mclaughlin.dds@geemail.com	San Francisco	California	4066390682665	d9b36fecc5cbee26582510c4ecdd18cb	Discover	37.747651153935216	-122.419107314668622
31555	2020-06-18 09:32:36	2020-06-18	Ronin Nader	ronin.nader@woohoo.com	San Francisco	California	180048826644856249	30161d82fecafd7af698b4b1b26fe19e	Maestro	37.7548516147073627	-122.410201601007444
31556	2020-06-18 09:35:39	2020-06-18	Michial O'Conner	michial.o'conner@geemail.com	Fort Wayne	Indiana	180030803767366280	db06221d44ad62f389bda9ce4d067ebd	VISA 16 digit	41.0139913974579429	-85.1869900612846038
31557	2020-06-18 09:36:56	2020-06-18	Matthew Metz II	matthew.metz.ii@geemail.com	Charlotte	North Carolina	6011836318566906513	fde665bff0ae63b0b94361bdd42cc3b9	VISA 13 digit	35.1240226719781745	-80.9216537195667627
31558	2020-06-18 09:47:08	2020-06-18	Mr. Daquan Denesik	mr.daquan.denesik@geemail.com	Louisville	Kentucky	6011396881293452848	39cadf3f0246bc661a480d329b845623	JCB 16 digit	38.1275896205004301	-85.5707115343377041
31559	2020-06-18 09:58:02	2020-06-18	Nathanael Mitchell	nathanael.mitchell@warmmail.com	Houston	Texas	6011065460498258324	ff14c5a51277ddcec13e843a49ca4b1e	VISA 13 digit	29.7258292163334801	-95.4772089877180719
31560	2020-06-18 10:00:30	2020-06-18	Finis Welch	finis.welch@geemail.com	Pittsburgh	Pennsylvania	6011064835393589496	fdc3310a460ebd759e1dd1ee0c4182bb	Diners Club / Carte Blanche	40.4168686578936871	-79.9410786310382235
31561	2020-06-18 10:00:48	2020-06-18	Finley Mills-Huels	finley.mills.huels@woohoo.com	Baltimore	Maryland	180095341543915429	00de994515f7b0d6796c6e5cedc44efd	VISA 16 digit	39.3866444809827954	-76.6703412670660782
31562	2020-06-18 10:18:37	2020-06-18	Ivory Olson	ivory.olson@geemail.com	Chula Vista	California	869954392532328321	16067ed76eed06540a89cb6d0e855860	Diners Club / Carte Blanche	32.6203972289569677	-117.110308150737353
31563	2020-06-18 10:33:35	2020-06-18	Dr. Sid Mueller PhD	dr.sid.mueller.phd@geemail.com	Carlsbad	California	3464057825613840	139eb00ef6a362919fe05b3e65f1eb56	Discover	33.1207493602238614	-117.29902709515504
31564	2020-06-18 10:37:02	2020-06-18	Anaya Lind DVM	anaya.lind.dvm@geemail.com	San Antonio	Texas	6011154094742266643	16c7dbc5328fbb49ab2d2900955e6c9d	JCB 16 digit	29.5509746990237403	-98.5993146830540041
31565	2020-06-18 10:37:09	2020-06-18	Dr. Edie Ledner DDS	dr.edie.ledner.dds@geemail.com	Seattle	Washington	630407123201241	f0b5a1d92326a2508a0491882f343066	Mastercard	47.6942422836944431	-122.270138955993204
31566	2020-06-18 10:48:42	2020-06-18	Eli Jones	eli.jones@warmmail.com	Madison	Wisconsin	54542472449398458	e66def525199122020eab180df1b8a51	JCB 16 digit	43.1688491672251402	-89.5269724815037193
31567	2020-06-18 10:56:12	2020-06-18	Jordon Miller	jordon.miller@woohoo.com	Houston	Texas	4216105351999591	581f0a64b652f8a31c45330d5d722c7c	Voyager	29.8169127232007689	-95.4385182700600438
31568	2020-06-18 10:56:15	2020-06-18	Adelard Von	adelard.von@woohoo.com	Las Vegas	Nevada	3466036527013531	60918547d1717b5e7e464bac7582911c	JCB 16 digit	36.314546440039571	-115.321056785501909
31569	2020-06-18 11:07:33	2020-06-18	Doshie Wilkinson MD	doshie.wilkinson.md@geemail.com	Philadelphia	Pennsylvania	210023260988201169	c994cb01fba13a4bef6f165e04f65e64	VISA 16 digit	40.0975300771608971	-75.2264344486307408
31570	2020-06-18 11:10:51	2020-06-18	Kylie Lynch	kylie.lynch@geemail.com	San Francisco	California	676299128132737	672958439eb6e5cd82e2245100ab3afc	American Express	37.7287774610307309	-122.431759841285015
31571	2020-06-18 11:18:09	2020-06-18	Jenna Oberbrunner MD	jenna.oberbrunner.md@geemail.com	Oakland	California	3096742348665968380	7e1b5f9cbe0dc508802b31474e197151	Maestro	37.7512194753545813	-122.244365911912524
31572	2020-06-18 11:18:20	2020-06-18	Hayleigh Mante	hayleigh.mante@woohoo.com	Santa Ana	California	3112543153855650082	1433e9af3aaf615389968bdb49b91ffd	Voyager	33.7112306255951495	-117.949482430649923
31573	2020-06-18 11:25:27	2020-06-18	Teela Will	teela.will@warmmail.com	New York	New York	3112736724140606506	34f0c28829f075c5706f5c51deadca06	Mastercard	40.6735513990037134	-73.9937977158360098
31574	2020-06-18 11:26:37	2020-06-18	Bulah Brekke-Doyle	bulah.brekke.doyle@geemail.com	Olathe	Kansas	3053985384245485	09e0b337be493a5320ea87475c46b1bd	VISA 16 digit	38.8102008083958196	-94.8508015992753286
31575	2020-06-18 11:30:56	2020-06-18	Lashunda Denesik-Hansen	lashunda.denesik.hansen@geemail.com	Tacoma	Washington	6011147889102476801	eeecc6bae3b5ed1803f58f6761899b72	Diners Club / Carte Blanche	47.1815306851293883	-122.401561367721484
31576	2020-06-18 11:44:01	2020-06-18	Dian Feest	dian.feest@geemail.com	Dallas	Texas	869917879157695063	9bbea88c815f085a0674ac898f943f3a	VISA 16 digit	32.7558102250371164	-96.8634990728888567
31577	2020-06-18 11:47:51	2020-06-18	Mr. Lew Hahn	mr.lew.hahn@geemail.com	Jacksonville	Florida	3736287496140212	cfda0710f2b4dac86cc361b0ee2bf238	JCB 16 digit	30.2743998937360956	-81.7316829575303956
31578	2020-06-18 12:01:45	2020-06-18	Hezzie Botsford	hezzie.botsford@geemail.com	San Francisco	California	639098798158915	2c16fdf4606bda7f35b9ae1bb889c517	Maestro	37.7754463455578389	-122.426652948219001
31579	2020-06-18 12:15:09	2020-06-18	Markita Roob	markita.roob@warmmail.com	Tucson	Arizona	3030690449771722	fd0211e2c1213e0052b154e531660c8f	JCB 15 digit	32.1981342949479838	-110.875531631358342
31580	2020-06-18 12:40:20	2020-06-18	Karl Willms-Schowalter	karl.willms.schowalter@geemail.com	League City	Texas	6011733368141152186	d4d31764feef963aec5e29f587464867	Diners Club / Carte Blanche	29.4986052473470579	-95.1340050834681819
31581	2020-06-18 12:40:27	2020-06-18	Mrs. Brittnay Bernier DDS	mrs.brittnay.bernier.dds@geemail.com	Berkeley	California	3051023747078419	c54bed2aaed9f09844f7e176e44854a3	Mastercard	37.89348936707664	-122.321032187973657
31582	2020-06-18 12:43:44	2020-06-18	Laurette Gutmann	laurette.gutmann@geemail.com	Tallahassee	Florida	3158197305869864617	f755a595e70332b3af6744bb6ee01acf	JCB 16 digit	30.4291225546993331	-84.247546535033365
31583	2020-06-18 12:45:14	2020-06-18	Dr. Marley Grant	dr.marley.grant@woohoo.com	San Francisco	California	3745742434932236	076fe36beb73b98a0a6a8c45b151e4f4	Mastercard	37.8153511422581943	-122.458396927722944
31584	2020-06-18 12:49:05	2020-06-18	Dr. Theophile Stanton	dr.theophile.stanton@geemail.com	Corpus Christi	Texas	4438273345480	5ae286eabbba58ed92ec4019c5ea633d	VISA 16 digit	27.7018447508972159	-97.1747278099242635
31585	2020-06-18 12:53:37	2020-06-18	Braiden Will	braiden.will@geemail.com	Louisville	Kentucky	501885070446902	5822d5338c149daa342df48216893f13	JCB 16 digit	38.1946289739474665	-85.6138818627759832
31586	2020-06-18 13:05:15	2020-06-18	Zaid Mraz MD	zaid.mraz.md@warmmail.com	Charlotte	North Carolina	3096266420239645418	32eab8d91fd276a706aee851bccd9662	Discover	35.2523873982273059	-80.9153255876563549
31587	2020-06-18 13:08:39	2020-06-18	Raphael Waelchi	raphael.waelchi@geemail.com	Dallas	Texas	4793957167025354	1a2980cc0ce3724c0c653c8d59e467c7	Voyager	32.7554476185508108	-96.7415500618480024
31588	2020-06-18 13:08:51	2020-06-18	Drucilla Ledner	drucilla.ledner@geemail.com	Indianapolis	Indiana	3755609784073431	ee1f58975740a271f3f08fe40b100a3c	Discover	39.8652126557201143	-86.1220758267879489
31589	2020-06-18 13:10:27	2020-06-18	Clem Walter	clem.walter@geemail.com	Grand Prairie	Texas	3015484680579126	538de60ad4eeaf92e87d52f8e16ed67a	Maestro	32.5916511679120404	-97.0100770926907643
31590	2020-06-18 13:10:48	2020-06-18	Chuck Swaniawski V	chuck.swaniawski.v@geemail.com	Providence	Rhode Island	210054048930685601	ddc4cc7030776292c4d21d583d7decfe	JCB 15 digit	41.7766366725642229	-71.3700033526320112
31591	2020-06-18 13:20:10	2020-06-18	Anner McLaughlin	anner.mclaughlin@geemail.com	Peoria	Illinois	52826016975387364	4e0fd344f47fb7fd77a538e2c9b4743e	Voyager	40.7809646849390148	-89.5221789222095197
31592	2020-06-18 13:20:59	2020-06-18	Dr. Regina Wilderman PhD	dr.regina.wilderman.phd@geemail.com	Ann Arbor	Michigan	060429023278087	4bf00df01264c1a2dd52b59a92a22308	VISA 16 digit	42.2405683998078132	-83.6737637293633156
31593	2020-06-18 13:23:00	2020-06-18	Achsah Kassulke	achsah.kassulke@warmmail.com	San Francisco	California	3528213880356562577	79934796ec6caac846edf72bacaf256b	JCB 16 digit	37.7720947986678937	-122.423664774195856
31594	2020-06-18 13:24:43	2020-06-18	Destiney Fay PhD	destiney.fay.phd@geemail.com	San Antonio	Texas	4220670461163218	0987da7f2f0c29e8d43206795896ea48	JCB 15 digit	29.3945563248895105	-98.4361264629591233
31595	2020-06-18 13:29:58	2020-06-18	Dr. Garner Torp PhD	dr.garner.torp.phd@geemail.com	Fayetteville	North Carolina	210053947913776942	ceb1f84a5d9e7af26dc060d75dad5280	VISA 16 digit	35.0494611130814988	-78.9966954509858112
31596	2020-06-18 13:30:32	2020-06-18	Mrs. Shenna Kuvalis	mrs.shenna.kuvalis@geemail.com	Oakland	California	4886279317601580	59788aa694b861a6437281af27b65f0e	Diners Club / Carte Blanche	37.7929812937377747	-122.228316923420678
31597	2020-06-18 13:44:36	2020-06-18	Keisha Schuster-Harvey	keisha.schuster.harvey@geemail.com	San Bernardino	California	3493049289478203	5a8d7bddcd79869c16cd551cdc9cb1e3	Voyager	34.0881752257034165	-117.309105139622829
31598	2020-06-18 13:46:37	2020-06-18	Hetty Jast	hetty.jast@warmmail.com	Houston	Texas	3059351395458431	fb2a969b4345525f26de9a403b3ff111	JCB 16 digit	29.7058656623199582	-95.3274683849435291
31599	2020-06-18 13:52:03	2020-06-18	Ms. Junie Boyer	ms.junie.boyer@geemail.com	Houston	Texas	180029572750498748	14e1fab8a22b41f37fd6e1011cb32115	VISA 16 digit	29.8188658477351076	-95.4869933447815527
31600	2020-06-18 13:57:08	2020-06-18	Dr. Davion Heathcote I	dr.davion.heathcote.i@geemail.com	New York	New York	53166793424263580	f64d9d7cdd0495bd06f2a5fa95997e02	Diners Club / Carte Blanche	40.7425713805239624	-73.9753602265741677
31601	2020-06-18 14:06:47	2020-06-18	Dr. Leonard Bruen PhD	dr.leonard.bruen.phd@warmmail.com	Albuquerque	New Mexico	4176996412729128	aad7ba023f7216d65205635a93dcd78b	Discover	35.140476389289276	-106.573871890322863
31602	2020-06-18 14:09:53	2020-06-18	Jeff Veum	jeff.veum@geemail.com	Corona	California	3434222940972573	338e3f53b7f9f91c4b7c503942fde067	VISA 16 digit	33.8210295727364709	-117.490772907037282
31603	2020-06-18 14:25:00	2020-06-18	Dr. Lemmie McCullough MD	dr.lemmie.mccullough.md@warmmail.com	New York	New York	3158105040465363224	5a37689d781e7324184303a7de4c3349	JCB 16 digit	40.7103899614643296	-73.8540847732115537
31604	2020-06-18 14:29:14	2020-06-18	Seaborn Ryan	seaborn.ryan@geemail.com	New York	New York	4078833520813198	4e5da76506538371e8ec2d228745eee0	JCB 16 digit	40.6225777298901249	-74.0268604939233512
31605	2020-06-18 14:33:26	2020-06-18	Mrs. Paulette Shanahan	mrs.paulette.shanahan@geemail.com	Pembroke Pines	Florida	3741338898879403	e7ed6ebfb6c888021c1104b077ee83a9	American Express	26.0872910594139249	-80.2469261937677913
31606	2020-06-18 14:39:47	2020-06-18	Derrick Kuvalis-Schroeder	derrick.kuvalis.schroeder@woohoo.com	Worcester	Massachusetts	6011767063333807858	5328f14ac8b4e0a49150ec32c9efd645	Maestro	42.2077719435263461	-71.8731202026151124
31607	2020-06-18 14:45:27	2020-06-18	Roni Kessler	roni.kessler@geemail.com	Lancaster	California	4352088943225	59f46725e5dff9a85eb7190d6ad791f5	VISA 16 digit	34.6607416114550091	-118.119149158240475
31608	2020-06-18 14:50:23	2020-06-18	Mr. Easton Hoeger DDS	mr.easton.hoeger.dds@warmmail.com	Arlington	Texas	3112122903134456159	29bcd2ca867bb2b35c082fcf32ebf163	JCB 16 digit	32.7318952635180196	-97.1893560396533474
31609	2020-06-18 14:55:51	2020-06-18	Ossie Ullrich	ossie.ullrich@geemail.com	Durham	North Carolina	3337560288228239466	4870a0d33c6b88db585aef967d297a2c	American Express	36.0624508510123931	-78.9570584977414427
31610	2020-06-18 14:58:18	2020-06-18	Ms. Beverlee Denesik	ms.beverlee.denesik@geemail.com	San Francisco	California	3016052747416514	250ddbc6d4664eb8268d59179ad6cc47	JCB 16 digit	37.7513736529960937	-122.406105775158181
31611	2020-06-18 15:26:15	2020-06-18	Ms. Julissa Schamberger MD	ms.julissa.schamberger.md@geemail.com	New Orleans	Louisiana	4353288082248117	faaa29994ba78147f045be6cf0b73cb4	Discover	30.0347734263647332	-89.9232947673909422
31612	2020-06-18 15:32:26	2020-06-18	Mr. Hyrum Hagenes Sr.	mr.hyrum.hagenes.sr.@warmmail.com	Chicago	Illinois	3096783266444272793	f8b3e8da526f9d1ba5e2fc4ef279d746	Maestro	41.8560692054986987	-87.7695321486826998
31613	2020-06-18 15:33:32	2020-06-18	Edson Hammes	edson.hammes@geemail.com	Chicago	Illinois	6011324909892180564	9c7264f85b703e3e314f0f65f70909df	Maestro	41.7748897269204278	-87.7713711782388373
31614	2020-06-18 15:58:43	2020-06-18	Kiyoko Hessel-Rodriguez	kiyoko.hessel.rodriguez@geemail.com	Glendale	Arizona	3088284993533356112	83fba7acf9add77c23c274b933c0b9ec	JCB 16 digit	33.436518751573189	-112.272349225056914
31615	2020-06-18 16:01:44	2020-06-18	Jett Steuber	jett.steuber@woohoo.com	San Francisco	California	3003624943365811	20a93ada8c5a3d8b706ade0d76ea0469	Maestro	37.7722291433826953	-122.413649911848623
31616	2020-06-18 16:02:41	2020-06-18	Leisa Hills	leisa.hills@geemail.com	Newark	New Jersey	4584693789315880	750523fbf5ceccb416a49051af1eca2c	Discover	40.7489963414993142	-74.1086793641302819
31657	2020-06-18 20:40:15	2020-06-18	Xiomara Klocko	xiomara.klocko@geemail.com	Fontana	California	869900126716894350	5b5c58c01fddd04cb431f47256cf4fb5	Voyager	34.0576898984760064	-117.512683291807406
31617	2020-06-18 16:05:25	2020-06-18	Dr. Rocco Hoeger DDS	dr.rocco.hoeger.dds@geemail.com	Indianapolis	Indiana	3049188035830474	8b0f663e2bdfc3cc3da11fba5a2af6e6	Diners Club / Carte Blanche	39.8380568818662297	-86.0548388916268863
31618	2020-06-18 16:12:23	2020-06-18	Loring Hahn	loring.hahn@woohoo.com	San Francisco	California	53076005155176355	ca3371c3283cde6ed10f4b086b8b3757	Voyager	37.7565871445695436	-122.423001153506334
31619	2020-06-18 16:16:11	2020-06-18	Addisyn Turcotte	addisyn.turcotte@geemail.com	Denver	Colorado	3786584265606707	9959cf2cdb0e0843bed04d08f48f81a2	Voyager	39.7880738193687051	-104.880369485892729
31620	2020-06-18 16:20:31	2020-06-18	Jalon Block	jalon.block@geemail.com	San Francisco	California	4037775816546539	322e48e675ea87475e0e8c6aaaea05e2	Voyager	37.7625266420507444	-122.46546754564595
31621	2020-06-18 16:25:48	2020-06-18	Lorenzo Gottlieb	lorenzo.gottlieb@geemail.com	Omaha	Nebraska	4501672428785026	822074f27bcb4af30c7b487376d1ace3	American Express	41.2312367188889581	-96.0920053668435656
31622	2020-06-18 16:26:28	2020-06-18	Finn White-Ratke	finn.white.ratke@geemail.com	Los Angeles	California	3158476808057672520	2ecc0aa59e37108acf1cdb5b801ba566	VISA 13 digit	34.0643379185680288	-118.4354637567412
31623	2020-06-18 16:28:06	2020-06-18	Chante Ritchie	chante.ritchie@geemail.com	Dallas	Texas	869936851206011516	1a9661be95aca4ba0538e4d3e712ed6d	Diners Club / Carte Blanche	32.826474318680539	-96.7972950844056896
31624	2020-06-18 16:33:24	2020-06-18	Eartha Harber	eartha.harber@woohoo.com	New York	New York	4088995308116	4f17e7161f4938f3706110ab2b3ead2e	American Express	40.7096777821183196	-73.9832336797740311
31625	2020-06-18 16:36:05	2020-06-18	Karolyn Rogahn	karolyn.rogahn@geemail.com	Phoenix	Arizona	4052929829266078	6d79bf943e074be3ac51b7e25be02e6d	Discover	33.5581932946506925	-112.181837929265953
31626	2020-06-18 16:38:37	2020-06-18	Makayla Beier	makayla.beier@warmmail.com	Fresno	California	869906711017411634	45f9a2eb6994af8573caebb13e0705b0	VISA 16 digit	36.8227713103279441	-119.780766184964776
31627	2020-06-18 16:47:39	2020-06-18	Earnest Gorczany	earnest.gorczany@warmmail.com	New York	New York	3425255980832472	7c77eb44316dc7fd901b0da23a2e08e8	Mastercard	40.6411449294295153	-73.885547391873601
31628	2020-06-18 17:01:10	2020-06-18	Yandel Robel-Ondricka	yandel.robel.ondricka@woohoo.com	Berkeley	California	3088754682039611200	cb78cc6acd981c2b6111bfd99d9b077b	VISA 16 digit	37.858448329707997	-122.275101020378145
31629	2020-06-18 17:07:26	2020-06-18	Jacque Towne	jacque.towne@geemail.com	Fayetteville	North Carolina	3088493210379772493	1ff24e2fcef511a6e3c05ee47c8340c1	Voyager	35.0569134626325223	-78.9200267536696032
31630	2020-06-18 17:10:23	2020-06-18	Sheridan Batz DVM	sheridan.batz.dvm@warmmail.com	Virginia Beach	Virginia	4199325462153380	ecba6d5907337002c1d9ce31d1801c24	Mastercard	36.798874421389776	-76.0951902820400932
31631	2020-06-18 17:11:29	2020-06-18	Bedford Breitenberg-Brekke	bedford.breitenberg.brekke@woohoo.com	Chicago	Illinois	4193548524122095	8e329a7f3a13f947209e8f52202b72da	Voyager	41.7733380175963092	-87.5875888712268278
31632	2020-06-18 17:26:03	2020-06-18	Shirley Nicolas-Kshlerin	shirley.nicolas.kshlerin@warmmail.com	San Jose	California	53154683844737657	acdd04fb057cbbd9cbf8213079308ba9	Diners Club / Carte Blanche	37.3421312504269167	-121.753153334486854
31633	2020-06-18 17:38:20	2020-06-18	Lavon Kassulke	lavon.kassulke@geemail.com	Concord	California	4352908496354	edd3700a70f8ca39e831599876aa8fd0	JCB 16 digit	37.9781989593923086	-122.037415074294799
31634	2020-06-18 17:42:12	2020-06-18	Oneta Goyette PhD	oneta.goyette.phd@woohoo.com	Tampa	Florida	210032726141792400	e203b8ab9983b68b3a3efa4637402015	VISA 16 digit	28.0580464036319377	-82.4410389328122051
31635	2020-06-18 17:46:13	2020-06-18	Mohamed Klein	mohamed.klein@geemail.com	San Francisco	California	869943890549756404	f9dfa14ca5aeca3f71a1946ed45a15a7	Diners Club / Carte Blanche	37.7414083596945673	-122.435517082678032
31636	2020-06-18 18:01:41	2020-06-18	Janyce Kshlerin	janyce.kshlerin@geemail.com	Cary	North Carolina	3528466153230526406	b46008621dc493a7a0c59b23756520e9	JCB 16 digit	35.7796438524141962	-78.7179126242261304
31637	2020-06-18 18:18:46	2020-06-18	Gustavo Orn	gustavo.orn@geemail.com	Macon	Georgia	6011189938233568173	44c6b01f14cf652382fc148e7152c33b	JCB 16 digit	32.7126644753396505	-83.6945172964323234
31638	2020-06-18 18:23:10	2020-06-18	Rexford Hermann	rexford.hermann@geemail.com	Cape Coral	Florida	3410904116155848	03155024ce1819ed8f6ce7e2ed40af3d	JCB 16 digit	26.6984902224007996	-81.9716013361770592
31639	2020-06-18 18:23:25	2020-06-18	Chasity Botsford	chasity.botsford@geemail.com	Kansas City	Missouri	639093517039496	76d31bffd5afaea544634a452c7081aa	American Express	39.1218683260794791	-94.6458778340593057
31640	2020-06-18 18:51:03	2020-06-18	Randall O'Reilly	randall.o'reilly@woohoo.com	Los Angeles	California	3733695260496599	a0e8836329d5befd5538fbafe378c540	JCB 16 digit	33.9794477755069693	-118.483122488669295
31641	2020-06-18 18:54:14	2020-06-18	Mrs. Caydence Mosciski	mrs.caydence.mosciski@geemail.com	Oakland	California	6011417858142476231	1f1ab53554cda5db2834be86baaf7674	Discover	37.8149050570881116	-122.289768940956677
31642	2020-06-18 19:05:14	2020-06-18	Hellen Romaguera-Moen	hellen.romaguera.moen@geemail.com	Santa Clarita	California	3158794265776810821	16d34329988c0500ec7363ad9061c461	VISA 16 digit	34.4378940575029659	-118.491027147239819
31643	2020-06-18 19:07:16	2020-06-18	Hermon Ebert	hermon.ebert@woohoo.com	Chicago	Illinois	3000713243102843	c2592cdccbe358eaded02a9fe47f2cc7	VISA 16 digit	41.9192021404694799	-87.7534190667357308
31644	2020-06-18 19:12:06	2020-06-18	Rosetta Heller	rosetta.heller@geemail.com	Fremont	California	3059607453001060	0e672fef4633a97e0f1d5f8da3a4d3e2	VISA 16 digit	37.476674036372458	-122.018230316554011
31645	2020-06-18 19:18:14	2020-06-18	Mrs. Stephany Renner	mrs.stephany.renner@geemail.com	Gilbert	Arizona	4548471262665	0d4aeaa68ec5c015406225f6f682c34a	Diners Club / Carte Blanche	33.222382221684974	-111.789937071189655
31646	2020-06-18 19:21:53	2020-06-18	Azaria West MD	azaria.west.md@geemail.com	Fremont	California	4099364302903	72f10372253c99c15174dd1239dece86	Discover	37.4194178126920036	-121.847583584998546
31647	2020-06-18 19:25:48	2020-06-18	Derrek Veum	derrek.veum@geemail.com	Sioux Falls	South Dakota	6011074069345292623	522d0084e15184c86b5fb1e4c0807069	Diners Club / Carte Blanche	43.607111230501161	-96.6887979738116314
31648	2020-06-18 19:28:36	2020-06-18	Versie Mayer	versie.mayer@geemail.com	Winston–Salem	North Carolina	51308408988882126	a5fac546575a607e62cf4ccd2f5550d8	JCB 15 digit	36.029988182545452	-80.2462640503551796
31649	2020-06-18 19:38:20	2020-06-18	Sid Rutherford DVM	sid.rutherford.dvm@warmmail.com	New York	New York	4423679011316	f4a9d6216432a29273c568f5afd8c86f	American Express	40.5806265527605987	-74.0252694433450671
31650	2020-06-18 19:42:13	2020-06-18	Mr. Mal Okuneva Jr.	mr.mal.okuneva.jr.@geemail.com	Corpus Christi	Texas	3337582358173172469	b6738ccc3df155260a96d3e796c289e6	VISA 16 digit	27.8522708393570042	-97.1702171956017651
31651	2020-06-18 19:44:02	2020-06-18	Francis O'Connell	francis.o'connell@woohoo.com	San Francisco	California	6011767694650009916	d2c73e06453d910d9684efbdf657f38b	JCB 16 digit	37.765651376121113	-122.441318932892287
31652	2020-06-18 19:54:30	2020-06-18	Mrs. Maralyn Crona DVM	mrs.maralyn.crona.dvm@warmmail.com	Birmingham	Alabama	4854470348491	e628c70aec2c3e05d2c24568022a47dd	American Express	33.4839750540699796	-86.8454781018439803
31653	2020-06-18 19:55:27	2020-06-18	Bernardine Hammes	bernardine.hammes@geemail.com	Indianapolis	Indiana	3096011902092699325	4ea8d5d2c24ef5176b49bbb0460905ab	VISA 13 digit	39.6926872160758819	-86.1251172693181815
31654	2020-06-18 20:04:00	2020-06-18	Mr. Leroy Wuckert	mr.leroy.wuckert@geemail.com	Atlanta	Georgia	561222631535121	e7e4d770988f020695ab812c7d6956ed	Maestro	33.8262585935458588	-84.4940880267925678
31655	2020-06-18 20:24:00	2020-06-18	Deidre Hyatt	deidre.hyatt@geemail.com	Boston	Massachusetts	54217054300203052	2cf1814854198fdaddfba847c146f388	Voyager	42.3338959076143837	-70.9639737563159372
31656	2020-06-18 20:40:07	2020-06-18	Philomena Corwin	philomena.corwin@geemail.com	Detroit	Michigan	6011288769965292603	8cb5e52f26e5e5570d3b060514a17859	VISA 16 digit	42.4437883284334134	-83.0451396121762713
31658	2020-06-18 20:55:36	2020-06-18	Ethelene Gottlieb	ethelene.gottlieb@geemail.com	Laredo	Texas	6011757084014821242	665c996e3e5fdf1eab128da4fb2a690c	Maestro	27.6299397108327618	-99.434197235154727
31659	2020-06-18 20:56:19	2020-06-18	Murray Heaney	murray.heaney@warmmail.com	Los Angeles	California	3088782321915622652	9b29163a943c578578312a66bf06e337	VISA 16 digit	33.9209476421918694	-118.491097015840182
31660	2020-06-18 20:59:21	2020-06-18	Jonathon West	jonathon.west@woohoo.com	Santa Ana	California	3528897573099586242	dfe7d64d1f7ac9516643c04fcd718339	VISA 13 digit	33.6787245644826427	-117.84770090029761
31661	2020-06-18 21:10:20	2020-06-18	Dr. Erastus Swaniawski	dr.erastus.swaniawski@geemail.com	Oakland	California	676229171789414	8fcdadc26cdad219e94c875c8fea4f78	Mastercard	37.8038897744692903	-122.291901931166208
31662	2020-06-18 21:24:49	2020-06-18	Hailey Cole	hailey.cole@geemail.com	Little Rock	Arkansas	4741594265940011	51f096761e55b7d0e1b484db9fc9fb90	Voyager	34.6883131090361658	-92.2729140539526895
31663	2020-06-18 21:28:27	2020-06-18	Allan Weimann	allan.weimann@warmmail.com	Los Angeles	California	869983793258219914	a5b500cb228fbea4df6e0e79d7d27157	Mastercard	33.9269336155947272	-118.376125360139824
31664	2020-06-18 21:34:21	2020-06-18	Morgan Tillman	morgan.tillman@woohoo.com	San Francisco	California	4472579197179189	27d5b788484a48894e55bbd3e76f54d5	VISA 16 digit	37.7861006213679218	-122.425410714128788
31665	2020-06-18 21:45:17	2020-06-18	Jahiem Wisozk	jahiem.wisozk@geemail.com	Denver	Colorado	4276086520514981	94cce2280563cfe150a82a6152c0f06b	JCB 16 digit	39.7379582169517818	-104.980301951082794
31666	2020-06-18 21:47:22	2020-06-18	Dannie Lemke-Lind	dannie.lemke.lind@geemail.com	San Francisco	California	3337476173228711909	9b0b0f17abaec4686cf8b95c08d8300a	JCB 15 digit	37.7658757685016013	-122.420488321813806
31667	2020-06-18 21:57:18	2020-06-18	Rhianna Schmeler	rhianna.schmeler@geemail.com	Surprise	Arizona	3528919802481847811	2b1ad2add14733b28a7a7bd36e064bce	VISA 13 digit	33.5720139994513218	-112.439441597857325
31668	2020-06-18 22:01:04	2020-06-18	Juan Schumm	juan.schumm@warmmail.com	Lancaster	California	3790668710273892	b8933eb6b541b51e71dbf59e9f90469f	JCB 16 digit	34.7503478005774369	-118.215014272273692
31669	2020-06-18 22:01:35	2020-06-18	Cordella Hickle	cordella.hickle@geemail.com	Lexington	Kentucky	210092847500854339	4ab1d49f3dffb90944eb177141a3d46e	Diners Club / Carte Blanche	38.0845924368470889	-84.3861472038451552
31670	2020-06-18 22:07:33	2020-06-18	Alonzo Barrows	alonzo.barrows@geemail.com	Virginia Beach	Virginia	51829172986585590	9e5b8a64689934f3b147f36188145b23	American Express	36.7725965352449577	-75.9688432131566032
31671	2020-06-18 22:09:30	2020-06-18	Hank Connelly II	hank.connelly.ii@geemail.com	Providence	Rhode Island	3714070517511991	dd6e970b691bcd7b164d813895b2e804	Mastercard	41.7648573553975666	-71.5094746340915606
31672	2020-06-18 22:17:06	2020-06-18	Krish Johnston-Ledner	krish.johnston.ledner@geemail.com	San Francisco	California	4149262182913267	635a666b79b6d616b749154e01200d13	JCB 15 digit	37.7756674446301517	-122.395519087437251
31673	2020-06-18 22:20:15	2020-06-18	Deidre Moore	deidre.moore@geemail.com	Los Angeles	California	869992181073331156	33324b72911f988a6853cfc4063c3d74	Diners Club / Carte Blanche	34.1107017901126284	-118.489670605817054
31674	2020-06-18 22:41:01	2020-06-18	Delores Ziemann	delores.ziemann@warmmail.com	Kent	Washington	4508161280230704	f694e8281bda2cf47ee0aeca0ddaf103	JCB 15 digit	47.4424325514696505	-122.305420114951957
31675	2020-06-18 22:42:36	2020-06-18	Jens Hoppe	jens.hoppe@warmmail.com	Fort Worth	Texas	869900086998402803	e4e504e0b57bef403aee2c52fee605c5	Voyager	32.7201586351785849	-97.2907451977308853
31676	2020-06-18 22:46:41	2020-06-18	Alba Swift	alba.swift@geemail.com	Yonkers	New York	3037946842298462	9f3e9b87798db057396776847e4542ae	VISA 13 digit	40.8654143207442004	-73.8812103751465656
31677	2020-06-18 22:47:47	2020-06-18	Arla Fay	arla.fay@geemail.com	San Antonio	Texas	4422858696251	61c30e6de1129c0ec35bcf3878ff2755	VISA 13 digit	29.541375390680134	-98.5459256534300749
31678	2020-06-18 22:53:40	2020-06-18	Eppie Legros PhD	eppie.legros.phd@geemail.com	New York	New York	3056712484209972	e381db63160cca86248142b5f12cc8f2	JCB 16 digit	40.6508851567506753	-73.8557039762277157
31679	2020-06-18 22:54:14	2020-06-18	Fed Weimann IV	fed.weimann.iv@geemail.com	Columbia	Missouri	53937335373934536	b95831dfe387332659230530d6de4632	Maestro	38.9140280139513877	-92.2316068504990199
31680	2020-06-18 22:57:29	2020-06-18	Dr. Zina Breitenberg	dr.zina.breitenberg@geemail.com	Winston–Salem	North Carolina	3781437908378629	392e6af28ee3b9b414cef6c0eb14029a	Diners Club / Carte Blanche	36.1138743372865036	-80.1690040712840783
31681	2020-06-18 23:05:22	2020-06-18	Boss Christiansen-Smith	boss.christiansen.smith@geemail.com	Henderson	Nevada	3491011944442323	9208004f9db38c02629f51ebbc31765b	JCB 15 digit	35.9835508382812179	-115.074878746473047
31682	2020-06-18 23:06:06	2020-06-18	Berniece Kulas-Hammes	berniece.kulas.hammes@woohoo.com	San Francisco	California	4516642644798	f49961eb045da774f18b9fd1e8da2404	Discover	37.7917495418343563	-122.431932292391394
31683	2020-06-18 23:09:14	2020-06-18	Josefa Pouros	josefa.pouros@geemail.com	Santa Ana	California	55228273709217334	db233684c89b5812705c7af33a7e2825	Voyager	33.7491135648556053	-117.906818889819078
31684	2020-06-18 23:28:13	2020-06-18	Mr. Jude Greenfelder	mr.jude.greenfelder@warmmail.com	Beaumont	Texas	4563623700005984	7bbcfd76f4e434aa41418807f8072737	VISA 13 digit	30.0301033453620967	-94.1541187777903019
31685	2020-06-18 23:41:13	2020-06-18	Augustus Boyle	augustus.boyle@geemail.com	Baltimore	Maryland	561269667693837	cdbb37e5cfadce4d64ebd38a4ff3b9ab	Maestro	39.3224555350840035	-76.6519483248256108
31686	2020-06-18 23:49:45	2020-06-18	Lynn Price	lynn.price@geemail.com	Lakewood	Colorado	55105001604356453	38b0e8030566ddeb140bd6461914a28e	Discover	39.759836259385203	-105.115982023908188
31687	2020-06-18 23:52:59	2020-06-18	Dwaine Miller	dwaine.miller@warmmail.com	San Francisco	California	3054215200898567	7a1f76287228850ea1f60c9e20e34b9a	Maestro	37.7803516578438519	-122.409112775673876
31688	2020-06-18 23:56:17	2020-06-18	Nicolas Haag	nicolas.haag@warmmail.com	Berkeley	California	6011798348951684546	7cbcb79f005cfe5f0fa54f170103db06	Diners Club / Carte Blanche	37.908036229886342	-122.278120364111771
31689	2020-06-19 00:07:54	2020-06-19	Berniece Ritchie MD	berniece.ritchie.md@geemail.com	Minneapolis	Minnesota	3742187043001424	115e542a5677d4309613b84f11de66e9	JCB 15 digit	45.0142020118508484	-93.2925086498998013
31690	2020-06-19 00:11:11	2020-06-19	Fredy Little	fredy.little@geemail.com	Oakland	California	3096787377729072851	e692bf0d0314fd273011ff005320da4b	Maestro	37.8284302797730874	-122.290116006508399
31691	2020-06-19 00:17:29	2020-06-19	Elvis Carter	elvis.carter@geemail.com	Henderson	Nevada	4882250990974275	6df05376f09b10b9da216fb3a1119a6a	Mastercard	36.0031979303274312	-115.091911150065073
31692	2020-06-19 00:41:34	2020-06-19	Timmothy Larkin	timmothy.larkin@geemail.com	Santa Ana	California	6011222861086336978	dd67ee5e77935c7c1902377056ab6834	Voyager	33.6836124976269886	-117.787700551694257
31693	2020-06-19 00:51:28	2020-06-19	Mrs. Marie Willms	mrs.marie.willms@woohoo.com	Phoenix	Arizona	3528256723628325977	ff2fd287b6e0d53f213ba1bcd65c3e57	Voyager	33.66496418378577	-112.099777954204384
31694	2020-06-19 00:51:35	2020-06-19	Oran Wehner	oran.wehner@geemail.com	Chicago	Illinois	3088667621424492863	64b68d13010d70e2c99f782331f9ceef	JCB 15 digit	41.8655421510174861	-87.6690765027452272
31695	2020-06-19 00:55:34	2020-06-19	Mr. Tylor Schimmel	mr.tylor.schimmel@warmmail.com	Provo	Utah	6011938307111128852	2c1c8232e49bc4c5ee5d7f3f74fa5d9a	Diners Club / Carte Blanche	40.2445368616629366	-111.642686623907835
31696	2020-06-19 01:00:18	2020-06-19	Yessenia Pouros	yessenia.pouros@geemail.com	New York	New York	4261399260290523	1895cbe7feffe38a4de7f1208a4170d9	Voyager	40.7093288177382178	-73.8529217040061923
31697	2020-06-19 01:11:27	2020-06-19	Sigmund Schuster V	sigmund.schuster.v@geemail.com	Plano	Texas	3720871839393667	63656d366a531350f1dc6deba8d48019	JCB 16 digit	33.0786209746349655	-96.7871865775152997
31698	2020-06-19 01:16:27	2020-06-19	Dr. Dimitri Douglas	dr.dimitri.douglas@geemail.com	Los Angeles	California	3528616665472510144	0b54a93e02322552c767d3ece3f762a2	VISA 13 digit	33.9745091143861373	-118.395462447357545
31699	2020-06-19 01:22:12	2020-06-19	Edsel Collier	edsel.collier@geemail.com	Newark	New Jersey	3096330820057203780	ddb114a36d42a42f2939d62aad4af91f	Diners Club / Carte Blanche	40.7491953799415398	-74.2707310776434895
31700	2020-06-19 01:36:17	2020-06-19	Emory Schultz	emory.schultz@woohoo.com	Jacksonville	Florida	3112181590522457317	8016f86703b8444b264a60cdc30c37aa	VISA 13 digit	30.2556151942867793	-81.5812098194457604
31701	2020-06-19 01:46:52	2020-06-19	Henri Greenholt	henri.greenholt@geemail.com	Oakland	California	4236685725196673	cfd9dda90b4657a00ada7f0649a11365	Voyager	37.8115322450916693	-122.285197547720117
31702	2020-06-19 01:47:44	2020-06-19	Jasmyne Trantow-Ferry	jasmyne.trantow.ferry@geemail.com	San Diego	California	3781497684481591	83c6adb233b412a6dce3ec7fb007d1d3	Mastercard	32.7584213333737111	-117.11643729772419
31703	2020-06-19 01:52:45	2020-06-19	Carlee McLaughlin-Grady	carlee.mclaughlin.grady@geemail.com	San Francisco	California	3499486487730049	6b366dd2e9c39f84d86ccd05520519d1	Maestro	37.7591551200310249	-122.452428308079888
31704	2020-06-19 01:53:51	2020-06-19	Tyshawn Heathcote	tyshawn.heathcote@warmmail.com	Irvine	California	4588194735076	f96c1e47fbeb2a6e9dac1dc565407e1f	Mastercard	33.5874076932683607	-117.796660443210229
31705	2020-06-19 01:58:15	2020-06-19	Dorathy Lockman MD	dorathy.lockman.md@geemail.com	Huntsville	Alabama	4499678965862270	9d618741975072a1eed1eb1285fbc7cd	Diners Club / Carte Blanche	34.6320903684254731	-86.6558599270433234
31706	2020-06-19 02:05:56	2020-06-19	Mr. Maceo Legros	mr.maceo.legros@geemail.com	Murfreesboro	Tennessee	6011596696032486479	1de5bcf5162ffaa6cc82590c42aa5afd	VISA 16 digit	35.9343134367957759	-86.3241173270475031
31707	2020-06-19 02:09:49	2020-06-19	Ala Roberts	ala.roberts@warmmail.com	Santa Rosa	California	589351667144219	78f2fe9ba75cd23c90ef1dfdc793e956	Mastercard	38.4941499879241036	-122.774253606588033
31708	2020-06-19 02:10:05	2020-06-19	Maribel Braun	maribel.braun@geemail.com	Richmond	Virginia	51428945857845465	f8c2ac5ea32b41341e97257bea5da9d3	Maestro	37.6021127280533278	-77.4213533000312708
31709	2020-06-19 02:15:24	2020-06-19	Wm Wiza	wm.wiza@geemail.com	Oakland	California	4942645161457968	95be7fc3fb3c35b4601d0f5343cc14dd	Maestro	37.7703871611087507	-122.288963492567234
31710	2020-06-19 02:16:24	2020-06-19	Banks Kub	banks.kub@geemail.com	Oakland	California	3048216947816009	7f76ae887bc8ac4c80cf83c55c5ccbbf	Voyager	37.8179167860785626	-122.278116926233992
31711	2020-06-19 02:22:47	2020-06-19	Bailee Satterfield	bailee.satterfield@warmmail.com	Austin	Texas	4743973416873	6ad32cb218416675d6c6022889cb78bf	VISA 13 digit	30.2074787106491627	-97.8509609400067575
31712	2020-06-19 02:25:54	2020-06-19	Delta Stokes	delta.stokes@geemail.com	Augusta	Georgia	51057101723827000	45b3ed7851a264978d8ee89e24481be2	JCB 16 digit	33.4528780585359726	-82.1141207747455724
31713	2020-06-19 02:30:13	2020-06-19	Christen Borer	christen.borer@geemail.com	Fresno	California	210048060966137539	a4bb922107952fc20453bbd448477adc	Mastercard	36.7289644496854422	-119.727523938716956
31714	2020-06-19 02:32:05	2020-06-19	Linsey O'Keefe	linsey.o'keefe@geemail.com	Los Angeles	California	4037214831010	968b9ee3347fcef8230e04c36404bd08	Diners Club / Carte Blanche	33.9751589722331602	-118.33358366801329
31715	2020-06-19 02:41:15	2020-06-19	Rossie Schmidt IV	rossie.schmidt.iv@geemail.com	San Jose	California	4191140048053873	67ff3eda3d2398f9df2ad6dc1089623c	Discover	37.3665347372934207	-121.748442269045483
31716	2020-06-19 02:49:39	2020-06-19	Mr. Devan Rohan PhD	mr.devan.rohan.phd@woohoo.com	New York	New York	53813587662024739	6b645c8fef18e951b4b18fa68948d3ef	VISA 16 digit	40.7414928717296547	-73.9295259847666983
31717	2020-06-19 02:50:43	2020-06-19	Freddy Homenick MD	freddy.homenick.md@geemail.com	Naperville	Illinois	3733960089398750	3a401b60638d166aee7da4c51fe8f64a	JCB 16 digit	41.8401774600062524	-88.1440230970624867
31718	2020-06-19 02:55:22	2020-06-19	Krysten Windler DVM	krysten.windler.dvm@geemail.com	Albuquerque	New Mexico	4711997554150653	6f9bc4b38b940c409aa9abf87048e66a	JCB 15 digit	35.0218300878204403	-106.694036632224552
31719	2020-06-19 03:02:22	2020-06-19	Dr. Nicholaus Cummings V	dr.nicholaus.cummings.v@geemail.com	Winston–Salem	North Carolina	589337731663433	41703ebe689fb601bbc64d9ed27b3972	Diners Club / Carte Blanche	36.080762394261356	-80.1732893117833783
31720	2020-06-19 03:09:43	2020-06-19	Omar Huel	omar.huel@geemail.com	Buffalo	New York	4365597096988	9cc7d715dde80cf80b277b30014efbe0	Voyager	42.850473824394868	-78.7721836734030489
31721	2020-06-19 03:09:49	2020-06-19	Alex Adams	alex.adams@geemail.com	Meridian	Idaho	210060047668608035	5bf7e8aefd673ac0c44671eb641d83d2	Discover	43.6860926016241251	-116.406557895190645
31722	2020-06-19 03:40:37	2020-06-19	Graves Moore	graves.moore@geemail.com	San Antonio	Texas	4829188489902	67b4ca208f47f40002226977d2756193	Diners Club / Carte Blanche	29.3833032545238737	-98.4362537835094997
31723	2020-06-19 03:44:20	2020-06-19	Dr. Auguste Carter Jr.	dr.auguste.carter.jr.@woohoo.com	Nashville	Tennessee	4514238775068	941e99d4afd465a27131e41862026042	VISA 16 digit	36.2430904611136739	-86.8687729187216604
31724	2020-06-19 03:44:31	2020-06-19	Lillia Wolff	lillia.wolff@geemail.com	Corpus Christi	Texas	4136565878531531	564266e51d482e68a31d6a1bd1a46fef	JCB 15 digit	27.8027602955169968	-97.10023795448393
31725	2020-06-19 03:45:54	2020-06-19	Delaney Wuckert	delaney.wuckert@geemail.com	Vancouver	Washington	4820394235114	33a0518312eb24aed9a236bd7e275b4a	JCB 16 digit	45.6810425585672277	-122.533306727331876
31726	2020-06-19 03:48:47	2020-06-19	Erik Kessler II	erik.kessler.ii@geemail.com	Berkeley	California	210069159884139025	9937dccfefa6cc28ba11bc84992b6b51	VISA 16 digit	37.8910163007570517	-122.272048882319623
31727	2020-06-19 04:09:14	2020-06-19	Einar Cronin	einar.cronin@geemail.com	Knoxville	Tennessee	3337481331914142879	ffeceaf00f7b3689d464282e16f9f937	JCB 16 digit	35.9712356974899805	-83.9024781987752704
31728	2020-06-19 04:14:57	2020-06-19	Virgie Barton	virgie.barton@geemail.com	Santa Ana	California	3088593381981200113	9ae01cdcb5d52819952ad016e6067c4a	Mastercard	33.7442948020167677	-117.941184630703177
31729	2020-06-19 04:15:45	2020-06-19	Sherilyn Schinner DDS	sherilyn.schinner.dds@geemail.com	Los Angeles	California	3703029653590600	93e5f6d945c35fd0ae1327adb847aa2d	VISA 13 digit	34.0984589714422768	-118.503204850432638
31730	2020-06-19 04:15:45	2020-06-19	Zelma Ledner	zelma.ledner@woohoo.com	Sterling Heights	Michigan	3478038790158825	72bfa1d1d9e74ff95b420a9c880874bc	Diners Club / Carte Blanche	42.515503258825099	-82.994536146444446
31731	2020-06-19 04:17:25	2020-06-19	Estelle Stiedemann-Stark	estelle.stiedemann.stark@geemail.com	Memphis	Tennessee	3158593886130243087	089b5eca6fafb878234bfa8b474201bd	VISA 16 digit	35.0544519075259586	-90.0696964983154089
31732	2020-06-19 04:23:16	2020-06-19	Weston Auer	weston.auer@geemail.com	Los Angeles	California	869925414614039216	0023055c0c42e03fcd9ce212948dac41	VISA 16 digit	34.117081662952522	-118.471021322532735
31733	2020-06-19 04:29:45	2020-06-19	Mr. Stan Wehner	mr.stan.wehner@geemail.com	Los Angeles	California	180004496415756606	0fc5d15388938137c2597483e1c75bbe	American Express	33.9720925346348395	-118.335043399221448
31734	2020-06-19 04:39:57	2020-06-19	Michial McDermott	michial.mcdermott@warmmail.com	New York	New York	3096147980526512683	f963db6f389871f088e5312d36ac6c9a	VISA 13 digit	40.6600847460553041	-73.941667083454135
31735	2020-06-19 04:41:16	2020-06-19	Dr. Alexis Kulas PhD	dr.alexis.kulas.phd@geemail.com	San Francisco	California	4259268086651479	6d0972be1bf7005a80c24e4de1ade8a7	VISA 13 digit	37.7725610307294275	-122.440394953546758
31736	2020-06-19 04:44:36	2020-06-19	Amari Kessler	amari.kessler@warmmail.com	North Las Vegas	Nevada	6011877713239046327	fd23a558fee45a40d53db26b036458ec	JCB 16 digit	36.3030246160149588	-115.142682701930042
31737	2020-06-19 04:46:53	2020-06-19	Jamya Rice-Cronin	jamya.rice.cronin@warmmail.com	New York	New York	6011297524963444006	7f66b05dda2b7eda9b6a2d1ae8f9df95	Mastercard	40.7611530817337311	-73.9378752527654086
31738	2020-06-19 05:03:48	2020-06-19	Malaya Feest-Waters	malaya.feest.waters@geemail.com	San Francisco	California	4923792418223	06716a70fd35ca3e2d276bd04d6701f2	Mastercard	37.7380452728283871	-122.427675034269996
31739	2020-06-19 05:08:26	2020-06-19	Will Johns-Spencer	will.johns.spencer@woohoo.com	Garden Grove	California	3112286146090857505	8a9a672be49f9d2978db2c00c09095cb	Voyager	33.713293458876386	-117.904484503485264
31740	2020-06-19 05:31:21	2020-06-19	Dr. Edgardo Wiza MD	dr.edgardo.wiza.md@geemail.com	San Diego	California	4031893888369353	407b37a0697a1ee8771d0cdb922a5b82	JCB 15 digit	32.8262434475190972	-117.191005194177862
31741	2020-06-19 05:34:35	2020-06-19	Demetrios Tillman	demetrios.tillman@geemail.com	Fresno	California	3088755644361186291	bae53920c23d35ece45e1115acf044ba	American Express	36.7656417780429123	-119.824721494188168
31742	2020-06-19 05:44:07	2020-06-19	Mrs. Cathrine Kiehn DVM	mrs.cathrine.kiehn.dvm@geemail.com	Manchester	New Hampshire	3025601973378847	bceb05124075ebfbd9e337a53d746b29	Voyager	42.9450204454898881	-71.451734837226951
31743	2020-06-19 05:50:18	2020-06-19	Drew Kshlerin	drew.kshlerin@geemail.com	Philadelphia	Pennsylvania	51003278018706324	6955ba9b34874091c3d2649184264c63	JCB 16 digit	40.0472007586579792	-75.1922507883880371
31744	2020-06-19 06:04:41	2020-06-19	Wellington Braun	wellington.braun@geemail.com	Tacoma	Washington	3767311753272534	36d77910ebb2b4b089b67c51871ea69a	VISA 16 digit	47.3133631735228022	-122.526043623290207
31745	2020-06-19 06:10:26	2020-06-19	Anders Jakubowski	anders.jakubowski@warmmail.com	Los Angeles	California	3528432939493154188	80026baceff59f312be82eceee4e5f49	JCB 16 digit	34.0875509169749904	-118.481684779468168
31746	2020-06-19 06:13:01	2020-06-19	Dr. Reese Trantow DDS	dr.reese.trantow.dds@woohoo.com	Santa Maria	California	51398728557063977	c6b85a5c5eb2c720e68df0c8cf6c0512	American Express	34.9069461095675848	-120.359283418386426
31747	2020-06-19 06:29:50	2020-06-19	Lulah Smitham	lulah.smitham@warmmail.com	Sacramento	California	4957327131463861	e990840735f032806d3bae5351b522a3	JCB 16 digit	38.5488498464956919	-121.452981661517541
31748	2020-06-19 06:30:10	2020-06-19	Dr. Cruz O'Keefe	dr.cruz.o'keefe@woohoo.com	Visalia	California	52635036403336545	43c635422d481130f4d3fa54c387fe7e	Maestro	36.410048883217577	-119.387575939496614
31749	2020-06-19 06:31:37	2020-06-19	Aleck Sipes	aleck.sipes@warmmail.com	Huntsville	Alabama	210085186634584218	83370cf56d5596dcdf02437075e41ebf	JCB 16 digit	34.646287619905543	-86.6769604227989987
31750	2020-06-19 06:35:57	2020-06-19	Rayburn Romaguera-Herman	rayburn.romaguera.herman@woohoo.com	Boston	Massachusetts	6011501661672721522	0ee8d63603607fd6ee6551604df37273	Voyager	42.4087032526899108	-71.0163129140574512
31751	2020-06-19 06:40:09	2020-06-19	Dr. Yoshiko Fisher DVM	dr.yoshiko.fisher.dvm@warmmail.com	Lakeland	Florida	4226260619178617	8df93814bee93f8f62a17b599b77b651	VISA 16 digit	28.1045485246293225	-82.002801876317335
31752	2020-06-19 06:40:22	2020-06-19	True Gottlieb-Macejkovic	true.gottlieb.macejkovic@geemail.com	Davie	Florida	3737417686270193	03a8e4871d480299dbaf709c738af718	JCB 16 digit	26.043130900178479	-80.2953712792508298
31753	2020-06-19 06:56:38	2020-06-19	Miss Ximena Stamm	miss.ximena.stamm@warmmail.com	Los Angeles	California	3337708004858456632	ad728af55f08cafe45d79a9a75d36472	VISA 16 digit	33.9205183150112575	-118.475392887274921
31754	2020-06-19 07:02:40	2020-06-19	Kamren Stokes	kamren.stokes@geemail.com	San Diego	California	4943395830244	c5a5ce8520d95f6f5b95eaeef4fa076f	JCB 15 digit	32.8430070474810876	-117.225233716834339
31755	2020-06-19 07:03:34	2020-06-19	Letha Zboncak	letha.zboncak@geemail.com	Gresham	Oregon	4242777253119193	bfcad7a7ad2d426c07bd3077df346425	Maestro	45.5768516568422299	-122.368523563238227
31756	2020-06-19 07:11:31	2020-06-19	Louisa Renner	louisa.renner@woohoo.com	San Francisco	California	180046243473423327	786a83f197a32d83fa1504a108b49070	JCB 16 digit	37.738014747914626	-122.432063418073298
31757	2020-06-19 07:13:49	2020-06-19	Ethelbert Watsica-Bayer	ethelbert.watsica.bayer@geemail.com	San Bernardino	California	3058859003030740	269cf7e8465db8c973711894ac30d9c6	American Express	34.2116563762802599	-117.350994313113759
31758	2020-06-19 07:17:15	2020-06-19	Mr. Terence Dickens	mr.terence.dickens@geemail.com	El Paso	Texas	3031893877018306	f9a8ed53aa6dade11eb8b2b5d59d006f	JCB 16 digit	31.7646640323862464	-106.497719665195802
31759	2020-06-19 07:28:28	2020-06-19	Maribel Feest	maribel.feest@woohoo.com	New York	New York	3337162605914905682	e3bfa817f37a8d8577059da7cdc31713	Diners Club / Carte Blanche	40.6831227951440937	-74.0300789750076831
31760	2020-06-19 07:47:29	2020-06-19	Jaime Hoppe DDS	jaime.hoppe.dds@warmmail.com	Chicago	Illinois	4895578975339998	72270aecc7ad911df5f6ca3cffb2f34d	VISA 16 digit	41.7607514662504187	-87.7633853540319961
31761	2020-06-19 07:52:28	2020-06-19	Ashby Wiza	ashby.wiza@warmmail.com	Torrance	California	3015631180403518	5a6ba40e25da23918af7adfe69eb9434	Maestro	33.919188047563658	-118.31742747799828
31762	2020-06-19 08:07:53	2020-06-19	Candi Connelly	candi.connelly@geemail.com	San Francisco	California	3755549284603966	378dcef01b23e7a61838a3483cd5ab12	Diners Club / Carte Blanche	37.787054824809104	-122.421080982865817
31763	2020-06-19 08:11:27	2020-06-19	Myranda Schultz	myranda.schultz@geemail.com	Phoenix	Arizona	4543166501593779	76902ab9be39fcceff2cf575bb1d3f3f	VISA 16 digit	33.67143830176704	-112.019416773824403
31764	2020-06-19 08:15:53	2020-06-19	Waylon Smitham	waylon.smitham@geemail.com	Seattle	Washington	676241323110043	0f05e396ac93798d81341fe8eed6181c	VISA 16 digit	47.5975138114225089	-122.25415551638379
31765	2020-06-19 08:26:29	2020-06-19	Mr. Eugenio Zieme IV	mr.eugenio.zieme.iv@geemail.com	High Point	North Carolina	4398580420254196	2944bdd5c30d62b618100774b9b03724	Maestro	35.9626434993092019	-79.9627566946875277
31766	2020-06-19 08:39:32	2020-06-19	Marcella Glover	marcella.glover@geemail.com	Henderson	Nevada	4033331278259023	43c134857580c39ea915fe71fdcc7a1c	JCB 16 digit	36.059748363720999	-115.074579063120112
31767	2020-06-19 08:40:42	2020-06-19	Dylon Rohan	dylon.rohan@geemail.com	Memphis	Tennessee	060477253053704	9a9f5c104be29a4b9750d7cda4e69199	Voyager	35.0964207857914303	-89.9980635799258977
31768	2020-06-19 08:51:40	2020-06-19	Markus Collier	markus.collier@geemail.com	Santa Clara	California	676291023813180	4255b8579beaff6554288712c9da2b20	JCB 15 digit	37.3033741756159856	-121.925906929652768
31769	2020-06-19 08:57:54	2020-06-19	Ms. Ursula Parisian MD	ms.ursula.parisian.md@warmmail.com	Huntington Beach	California	53788918948777603	ede76d71ba19a8c9b595cbe7c1bce4aa	Discover	33.7577318921260598	-117.993778665422639
31770	2020-06-19 09:14:55	2020-06-19	Dr. Cleon Gorczany	dr.cleon.gorczany@geemail.com	Grand Rapids	Michigan	52468434636840742	c088f6517aa71d43db99ef5eeec71f07	Maestro	42.9322200764704505	-85.6035336605407338
31771	2020-06-19 09:15:15	2020-06-19	Hart Glover	hart.glover@warmmail.com	San Diego	California	52851736639138048	3601a7563726334d11a5efff1f8bc34c	Voyager	32.8625645996138473	-117.199458859572189
31772	2020-06-19 09:19:05	2020-06-19	Ms. Lulie Klein MD	ms.lulie.klein.md@geemail.com	Houston	Texas	54872802290848849	11cf60b96cbe20f39beb7382242bb879	JCB 15 digit	29.7394479475528009	-95.3634117436610182
31773	2020-06-19 09:30:40	2020-06-19	Valentine Barrows	valentine.barrows@woohoo.com	Berkeley	California	869967928332001504	3eac0379847d4548b32fc59d36693aca	JCB 16 digit	37.8661976989265199	-122.268578598844471
31774	2020-06-19 09:31:18	2020-06-19	Kelley Littel-Jakubowski	kelley.littel.jakubowski@geemail.com	San Jose	California	869909439992585704	7f6e3ae8e9beda6a84ca8aa7abfab708	JCB 16 digit	37.2693928457617787	-121.878604996971418
31775	2020-06-19 09:45:10	2020-06-19	Hosie Beahan-Ebert	hosie.beahan.ebert@geemail.com	New York	New York	4053007149809	8ae8f9d79fa0cfab957b3279286824f6	VISA 13 digit	40.6404052328076233	-73.8618362591963233
31776	2020-06-19 09:49:15	2020-06-19	Yasmeen Ritchie	yasmeen.ritchie@geemail.com	Carlsbad	California	210049469282575406	3723954b57adca2abc45d96938963d6b	JCB 16 digit	33.064607249287512	-117.224101147639743
31777	2020-06-19 09:52:14	2020-06-19	Delos Blick	delos.blick@geemail.com	New York	New York	3528850167745234557	8c474be3a834ac20aebf52b680ce355c	Diners Club / Carte Blanche	40.6338096211422197	-73.9802343420114283
31778	2020-06-19 09:52:15	2020-06-19	Laurie Swift	laurie.swift@woohoo.com	Anchorage	Alaska	869969808711439269	0c771232892eec1f1dc80b665ce9b330	VISA 16 digit	61.0799588239502214	-149.224154596927775
31779	2020-06-19 09:54:20	2020-06-19	Larae Morissette MD	larae.morissette.md@geemail.com	Vista	California	55330869251952239	52bdaf2b85c6ea4ae7ad4045570c89d9	VISA 16 digit	33.2880579435713599	-117.315090494469189
31780	2020-06-19 09:58:23	2020-06-19	Ms. Cliffie Armstrong DDS	ms.cliffie.armstrong.dds@geemail.com	San Francisco	California	3435140562491939	33af140ea4c1f320b79061c5f3c28568	VISA 13 digit	37.7301026504224879	-122.394539572457816
31781	2020-06-19 09:58:43	2020-06-19	Luisa D'Amore	luisa.d'amore@geemail.com	Memphis	Tennessee	561281873372320	9c78780667652bf1e754eb4e762d6877	American Express	35.0600031440213371	-90.0148562349636165
31782	2020-06-19 10:04:30	2020-06-19	Bryton Erdman-Stamm	bryton.erdman.stamm@woohoo.com	San Francisco	California	3528944230365984097	6fa2d28dc953fe9e652452354e911643	JCB 16 digit	37.7667378834019445	-122.435444614773985
31783	2020-06-19 10:17:37	2020-06-19	Maxim Collins	maxim.collins@geemail.com	Bridgeport	Connecticut	3112025620311104620	b0ad3ee20d82754cb9f81721f77fc735	VISA 16 digit	41.0962860701303896	-73.2340752872537877
31784	2020-06-19 10:23:25	2020-06-19	Dr. Teddy Jones	dr.teddy.jones@geemail.com	Berkeley	California	869980791173807725	9661c5a4993bd7d7c6cd085cb2b2e24d	Voyager	37.8467989968840044	-122.295231310280002
31785	2020-06-19 10:23:55	2020-06-19	Krystina Dach	krystina.dach@geemail.com	Chicago	Illinois	869933377176797325	84785c046e5c21b545a3331b568c175b	VISA 16 digit	41.8538141698878263	-87.6877577095787899
31786	2020-06-19 10:29:48	2020-06-19	Brenden Heathcote III	brenden.heathcote.iii@geemail.com	Arvada	Colorado	3750319850273767	6f45c6afbc6ec4d308b2b51549af0533	JCB 15 digit	39.8916542793799209	-105.053879203411938
31787	2020-06-19 10:39:38	2020-06-19	Dominic Brown-Hessel	dominic.brown.hessel@geemail.com	Charlotte	North Carolina	3488564150891448	b63489071c8fcf2c27c40ab1c0e0a5c1	American Express	35.235673859461393	-80.8071989332735541
31788	2020-06-19 10:47:37	2020-06-19	Miss Yvette Olson	miss.yvette.olson@geemail.com	Phoenix	Arizona	676274034713987	9b2afc58b3ee963debf846061e4dfa7a	JCB 15 digit	33.5997010227225772	-112.057012394482655
31789	2020-06-19 11:08:42	2020-06-19	Simon Kshlerin	simon.kshlerin@geemail.com	New York	New York	180035292159272998	4c8f3a51dfb96f5b20e3e211c92131e0	JCB 16 digit	40.5911891934219753	-73.927035467269647
31790	2020-06-19 11:09:31	2020-06-19	Wilbur Bartoletti	wilbur.bartoletti@warmmail.com	San Francisco	California	4843533465443787	af9d37cca4f99721514bec13a35d0847	Voyager	37.763271441228909	-122.42077031854754
31791	2020-06-19 11:11:54	2020-06-19	Miss Anitra Hickle DVM	miss.anitra.hickle.dvm@geemail.com	Oakland	California	52483674923372468	1932dd81737f39f93ff270597c4d015c	JCB 16 digit	37.8185494791915957	-122.269029420893474
31792	2020-06-19 11:33:40	2020-06-19	Sandra Morar	sandra.morar@geemail.com	Wilmington	North Carolina	6011536545627946384	6ad735daa1b43e852f7a174f3d71db98	Diners Club / Carte Blanche	34.1490374078329708	-77.9019892677191734
31793	2020-06-19 11:56:04	2020-06-19	Rand Crist	rand.crist@geemail.com	Concord	California	4274768039391553	a4733f0a9a9b5b2e9ae12e9fcaf97205	Voyager	37.9839110498715229	-122.066055468626686
31794	2020-06-19 12:00:36	2020-06-19	Brad Schuppe	brad.schuppe@warmmail.com	San Francisco	California	210020848983328517	8fcd29b79cede1b6c57b4ce997dc4a8b	Maestro	37.7900755561625985	-122.401957580123536
31795	2020-06-19 12:01:55	2020-06-19	Mr. Buel Carter III	mr.buel.carter.iii@geemail.com	Cincinnati	Ohio	869944976039904866	6186e157255d610f74d59bf01273815d	JCB 16 digit	39.2112518050473184	-84.5031768880590732
31796	2020-06-19 12:10:28	2020-06-19	Sheree Nolan	sheree.nolan@geemail.com	New York	New York	210019254672272921	7dcb228630c7c200d0fb9c8fa2630a9e	VISA 16 digit	40.575864505557341	-73.9658069552749424
31797	2020-06-19 12:29:47	2020-06-19	Mr. Pasquale Balistreri V	mr.pasquale.balistreri.v@woohoo.com	Plano	Texas	4265488858910	081bdba6b558bbf7c46753bcf3692678	JCB 15 digit	32.9852194019213343	-96.7798527056999518
31798	2020-06-19 12:40:04	2020-06-19	Brittanie Turner DVM	brittanie.turner.dvm@warmmail.com	Murfreesboro	Tennessee	210064051120132291	0d318ef429ec470fa047978b8af0d676	American Express	35.8223853911858114	-86.3442555482350258
31799	2020-06-19 12:44:15	2020-06-19	Dayne Conn I	dayne.conn.i@geemail.com	Berkeley	California	4878842837451	8ecb6088506f4ba2805d2b61239b5225	Maestro	37.8593254639421772	-122.304962218302492
31800	2020-06-19 13:03:09	2020-06-19	Mr. Deven Morar	mr.deven.morar@geemail.com	Columbus	Ohio	4385238376201	618670fc47300ca89120fff8af995fdd	VISA 16 digit	39.9722879824273249	-82.9229933010183373
31801	2020-06-19 13:09:27	2020-06-19	Dr. Nakisha Johns DDS	dr.nakisha.johns.dds@geemail.com	Round Rock	Texas	6011346898820777233	f493ed44858025e85cb6b4f08f4e8729	Diners Club / Carte Blanche	30.4553228113938133	-97.684803200451654
31802	2020-06-19 13:10:09	2020-06-19	Torrence McDermott	torrence.mcdermott@geemail.com	Houston	Texas	210064775355620014	e39b2218d3dff536f29c3411b71565c3	JCB 15 digit	29.7044839165717356	-95.4641229800894848
31803	2020-06-19 13:10:28	2020-06-19	Sabina Bechtelar	sabina.bechtelar@geemail.com	Spokane	Washington	4727880413947471	96e700cc2d31a306cc8b8fec0b66a284	Voyager	47.7136435201629965	-117.451768540813774
31804	2020-06-19 13:14:08	2020-06-19	Ms. Evonne Bergnaum	ms.evonne.bergnaum@geemail.com	Tempe	Arizona	55182530479074383	f83a7de5bcbe885cf0d577b4ee94c2f3	Diners Club / Carte Blanche	33.4060704335026415	-112.014659462779008
31805	2020-06-19 13:15:34	2020-06-19	Breann Lynch	breann.lynch@warmmail.com	Antioch	California	3030347620327333	09f9a7eb3a771ed9018890271e4e390a	VISA 16 digit	37.9821671664047997	-121.773987227137013
31806	2020-06-19 13:19:26	2020-06-19	Kacy Casper	kacy.casper@geemail.com	Huntington Beach	California	3096038388999258846	fb6968de8fe46a12f3e3dd551814bc6c	JCB 15 digit	33.6048112045083229	-118.015901894414043
31807	2020-06-19 13:20:32	2020-06-19	Lee Grant	lee.grant@geemail.com	Fort Lauderdale	Florida	3464900679874366	0f989847d0f1f288d080be430e482175	Voyager	26.0526363985601819	-80.1434665752861548
31808	2020-06-19 13:21:23	2020-06-19	Chauncy Strosin	chauncy.strosin@warmmail.com	Pasadena	Texas	3718421130872672	db67971250666013ef44a9463415a2a5	Diners Club / Carte Blanche	29.748065114846824	-95.2103349399700676
31809	2020-06-19 13:24:50	2020-06-19	Rayne Lynch PhD	rayne.lynch.phd@warmmail.com	New York	New York	869977089663730613	6f37a2ac43863d087cb8c1deb49936c2	JCB 16 digit	40.598320696292447	-74.0065044646047028
31810	2020-06-19 13:26:51	2020-06-19	Cade Hills	cade.hills@woohoo.com	Tucson	Arizona	3088366776881023785	0354a45bc8ede6e4a898bc831199fbbd	JCB 16 digit	32.0971412867814294	-110.953201109426459
31811	2020-06-19 13:36:19	2020-06-19	Xzavier Osinski	xzavier.osinski@geemail.com	Los Angeles	California	55777383084881532	a3571e7c11f667dde675fe293f5bf2ef	Voyager	33.9580764670722175	-118.415480349351839
31812	2020-06-19 13:37:55	2020-06-19	Estella Cole	estella.cole@geemail.com	Philadelphia	Pennsylvania	4071839954899402	a733dc267a155c8da75ef6c6157d0431	JCB 16 digit	40.0530309613287443	-75.0937096984490751
31813	2020-06-19 13:56:27	2020-06-19	Miss Karyme Hahn	miss.karyme.hahn@woohoo.com	New York	New York	3047302540137141	2597404e9d207e202faa94795e925689	Discover	40.6002198076564795	-73.8703067798063131
31814	2020-06-19 13:59:51	2020-06-19	Pablo Considine	pablo.considine@geemail.com	New York	New York	3034916704196537	49e6bdf1f1e14ba9cff2335827f473fc	VISA 16 digit	40.6372978201825177	-73.9045418555743936
31815	2020-06-19 14:02:03	2020-06-19	Dr. Darion Keeling PhD	dr.darion.keeling.phd@woohoo.com	Omaha	Nebraska	869963009623533093	c05fa6d11b8e091c3477fe3c94a09cf2	VISA 16 digit	41.2896063328865921	-96.0264571714330515
31816	2020-06-19 14:03:44	2020-06-19	Orley Watsica	orley.watsica@geemail.com	San Antonio	Texas	180029396947830732	b2e316ae820b13e9f8e36ce4835116fe	VISA 16 digit	29.4934998902563024	-98.5066302777103999
31817	2020-06-19 14:15:14	2020-06-19	Dr. Esteban Gottlieb	dr.esteban.gottlieb@woohoo.com	Memphis	Tennessee	3705688827255966	7a99e95d29d9156a764642f9fdf8e55e	VISA 16 digit	35.0962573919046719	-89.9421195023018925
31818	2020-06-19 14:15:47	2020-06-19	Hilton Batz	hilton.batz@geemail.com	Chicago	Illinois	3112306559569930049	4d05314d63a44315bcd1c8b6043d3f49	VISA 16 digit	41.916880494712295	-87.7002502583462729
31819	2020-06-19 14:23:23	2020-06-19	Adline Bode-Harris	adline.bode.harris@geemail.com	Norfolk	Virginia	4980775846593144	b61ccc908679ed249ddb53c77a32a868	JCB 15 digit	37.0126408322267224	-76.1543662785090589
31820	2020-06-19 14:24:13	2020-06-19	Mell Goodwin	mell.goodwin@woohoo.com	Colorado Springs	Colorado	4239854194987643	4897f6cc9a7683fa428591a90109f42c	VISA 16 digit	38.9640505141161384	-104.803494154537844
31821	2020-06-19 14:29:24	2020-06-19	Enola Wiegand	enola.wiegand@warmmail.com	Manchester	New Hampshire	210005170999768894	af2c8044a75a5aed12d8b119f3b37723	JCB 15 digit	42.8899644808914573	-71.4061384467300115
31822	2020-06-19 14:31:57	2020-06-19	Mr. Delvin Ankunding II	mr.delvin.ankunding.ii@woohoo.com	Lubbock	Texas	630494632263383	70f5e8910b4a25cff34c8d0bf25715bc	VISA 13 digit	33.6201707303565058	-101.820635820776971
31823	2020-06-19 14:36:49	2020-06-19	Niles Koelpin	niles.koelpin@geemail.com	Birmingham	Alabama	4722616474549	650980529be4981e18ee3425db25e0d5	VISA 16 digit	33.4440778129059808	-86.704199561826897
31824	2020-06-19 14:39:52	2020-06-19	Ethen Hackett	ethen.hackett@geemail.com	Las Vegas	Nevada	3775926884851300	f852205f92e78243838f0a990830c9a3	Voyager	36.1324413035631196	-115.254763489935911
31825	2020-06-19 14:41:11	2020-06-19	Erma Langosh PhD	erma.langosh.phd@geemail.com	Hialeah	Florida	4430154557317	deba7bd3f48087bd0bb3ca0090706268	JCB 15 digit	25.9373511347431709	-80.3214214919969436
31826	2020-06-19 14:44:25	2020-06-19	Tracy Blick	tracy.blick@geemail.com	Los Angeles	California	3158344670063047448	86eeb59c049a905a134baf0d55ef2633	Voyager	33.9650405706703609	-118.34952914039529
31827	2020-06-19 14:45:35	2020-06-19	Demond Kub-Conroy	demond.kub.conroy@geemail.com	Cary	North Carolina	3030209974145218	a5457e6243dbef2e19a4b6351fc764d8	Diners Club / Carte Blanche	35.8343978723619188	-78.7421639913313101
31828	2020-06-19 14:54:34	2020-06-19	London Romaguera	london.romaguera@geemail.com	New York	New York	4912268301451969	3c049628a051b8dcce21f9e026043c55	Discover	40.7311677986979461	-74.0170738284371765
31829	2020-06-19 14:55:45	2020-06-19	Tilda Wehner	tilda.wehner@geemail.com	Philadelphia	Pennsylvania	4710321777772253	30ab613da55d34078d052fd4b121a508	Mastercard	40.1077037849888214	-75.1258073023419826
31830	2020-06-19 14:57:07	2020-06-19	Mr. Buddie Friesen DVM	mr.buddie.friesen.dvm@woohoo.com	New York	New York	3059818334259419	58930d0b153aefc42e1a3bd520bbcb7e	Voyager	40.7409427331052711	-73.9688952233537975
31831	2020-06-19 14:59:24	2020-06-19	Dr. Junior Murazik	dr.junior.murazik@warmmail.com	San Francisco	California	3337281739571510547	cc0a75b30a8861a63011d9458e24ede3	JCB 15 digit	37.7683058609564171	-122.428523172880915
31832	2020-06-19 15:01:06	2020-06-19	Mrs. Crete Wolff DDS	mrs.crete.wolff.dds@geemail.com	Jacksonville	Florida	3096271665456613696	8601eb9b77205cd504298f46cf000ea4	Diners Club / Carte Blanche	30.3315899182163164	-81.7612639725752217
31833	2020-06-19 15:11:49	2020-06-19	Maceo Prohaska-Kuvalis	maceo.prohaska.kuvalis@warmmail.com	San Francisco	California	869941196707569437	c754bb549c6226128ba4dfcc6c04e8b0	JCB 16 digit	37.7694369277387594	-122.426482914851064
31834	2020-06-19 15:15:03	2020-06-19	Burton Nikolaus	burton.nikolaus@geemail.com	Mesa	Arizona	869931037376486135	bac9db15a709a61089eff3d2296554c0	Mastercard	33.4804629854071862	-111.734029874333743
31835	2020-06-19 15:30:40	2020-06-19	Chancy Goldner-Spinka	chancy.goldner.spinka@geemail.com	Austin	Texas	4399390250637463	5e1f405d153dc9d31616c39bf0b9a821	Discover	30.2835249036677183	-97.8448665915295521
31836	2020-06-19 15:35:38	2020-06-19	Conner Fadel	conner.fadel@woohoo.com	Lewisville	Texas	869938548364619613	fa313b4fc1e14af55fcc7bb0f508da07	JCB 16 digit	32.9741077884551146	-97.0151970553241796
31837	2020-06-19 15:38:04	2020-06-19	Parker Cronin	parker.cronin@warmmail.com	Westminster	Colorado	4746348212455	49d46bdab65f1326c8208a8b605708f1	JCB 15 digit	39.8941705320801532	-105.088036700911459
31838	2020-06-19 15:54:06	2020-06-19	Ms. Lyda Mann PhD	ms.lyda.mann.phd@geemail.com	Columbus	Ohio	4921247794547805	3de087066bbe233867098c6b7766bbbc	Discover	40.0818553351376181	-83.0463941059310002
31839	2020-06-19 15:56:35	2020-06-19	Mrs. Gracelyn Hirthe	mrs.gracelyn.hirthe@geemail.com	San Mateo	California	3096363669966271002	7fd444a528f601ea762491db9a7a439b	Diners Club / Carte Blanche	37.4989871313676204	-122.340181491043779
31840	2020-06-19 16:04:43	2020-06-19	Louisa Cartwright MD	louisa.cartwright.md@warmmail.com	Philadelphia	Pennsylvania	4060913610097	5cab721be1b43a4d0f87244cd6fe4c5d	Diners Club / Carte Blanche	39.9147408794105019	-75.1411806604724433
31841	2020-06-19 16:07:33	2020-06-19	Davonta Rippin	davonta.rippin@warmmail.com	San Francisco	California	869981866572536601	01a28ce7dcc3f1b14790ed19b17b2dd1	JCB 16 digit	37.7630523032011283	-122.39172464065193
31842	2020-06-19 16:09:12	2020-06-19	Tera Robel	tera.robel@geemail.com	New York	New York	869976007684487881	8d06f43eac88bc7950917dedf1088f64	Mastercard	40.7219457416087351	-74.0257070185512305
31843	2020-06-19 16:09:36	2020-06-19	Jaxton Terry	jaxton.terry@geemail.com	San Francisco	California	869952379342604977	ec7535d963de3810c298e799c1a6081f	VISA 16 digit	37.752175365164419	-122.424476595030782
31844	2020-06-19 16:11:12	2020-06-19	Dr. Gage Waters Sr.	dr.gage.waters.sr.@geemail.com	Los Angeles	California	180019982463459691	7546654dc8ba5fc7981d93f2bceafb7e	Diners Club / Carte Blanche	34.0070465802546593	-118.43385113952607
31845	2020-06-19 16:14:27	2020-06-19	Damond Anderson-Schowalter	damond.anderson.schowalter@geemail.com	Louisville	Kentucky	4235462996810841	32b061194c884860d26268d1febaa489	Maestro	38.2269969835314853	-85.7051807950321631
31846	2020-06-19 16:17:58	2020-06-19	Katharine Heathcote	katharine.heathcote@geemail.com	Pasadena	California	53603625568464395	70b2eee864c259e9cc88f86ab781d3f5	Diners Club / Carte Blanche	34.0921895059146038	-118.173276107833161
31847	2020-06-19 16:18:24	2020-06-19	Dewey Becker	dewey.becker@geemail.com	San Francisco	California	54434817401869477	bdc5accbe62dc10a62129e8e7c67187b	Mastercard	37.7572404674676676	-122.401598491287984
31848	2020-06-19 16:22:05	2020-06-19	Symone Blanda	symone.blanda@woohoo.com	Norfolk	Virginia	3034187411317549	54b7c1bdfdd8f63832405ce495dab4c1	Discover	36.8371278716735588	-76.2809275363575665
31849	2020-06-19 16:22:58	2020-06-19	Timmothy Swift III	timmothy.swift.iii@geemail.com	Augusta	Georgia	4822104825859156	ae02ea840a16c9a056a970741085a392	Voyager	33.405993329428135	-82.1511399225160517
31850	2020-06-19 16:28:45	2020-06-19	Burl Harber Sr.	burl.harber.sr.@geemail.com	Boulder	Colorado	54319494067975046	8410ce5c242256ec4e32dd5e5d057457	VISA 16 digit	39.9539214317202607	-105.23293503701278
31851	2020-06-19 16:35:00	2020-06-19	Dr. Donavon Bergstrom MD	dr.donavon.bergstrom.md@geemail.com	Portland	Oregon	639072536147019	41fc9522704bfdf219e22a1ddab7bbc2	JCB 15 digit	45.4424313175845853	-122.670676731364807
31852	2020-06-19 16:40:41	2020-06-19	Ulysses Stokes	ulysses.stokes@geemail.com	Columbus	Ohio	869901708880449241	712b80edaae2d0a7f09022037cabf866	Maestro	39.9821712703023096	-82.985890244716046
31853	2020-06-19 16:45:47	2020-06-19	Nakia Koelpin DVM	nakia.koelpin.dvm@geemail.com	Peoria	Illinois	4840605143329	3391f45a3458844b611100b58c9c7347	VISA 16 digit	40.65844850538857	-89.5347743701539969
31854	2020-06-19 16:53:56	2020-06-19	Mr. Rishi O'Hara DDS	mr.rishi.o'hara.dds@geemail.com	Honolulu	Hawaii	3044253469128160	7eb2a150d4f0a146530516823d7942d1	American Express	21.3306258326612408	-157.769001891065756
31855	2020-06-19 16:58:27	2020-06-19	Eusebio Watsica IV	eusebio.watsica.iv@warmmail.com	Oakland	California	4401643580133579	cac405664ea019b574e22f0d75f680c1	VISA 16 digit	37.8162338868657102	-122.297473048729216
31856	2020-06-19 16:59:15	2020-06-19	Evon Wiza-Thompson	evon.wiza.thompson@geemail.com	Houston	Texas	3112757248245311360	63f69b922f7fe26e576ebbdfc1661089	JCB 16 digit	29.8153133897189058	-95.4407749640304672
31857	2020-06-19 17:00:22	2020-06-19	Westley Russel DDS	westley.russel.dds@geemail.com	San Antonio	Texas	3096077687416037747	f66fb9c2425568d4efd47d7de0ce8f09	JCB 16 digit	29.4509005936399113	-98.530136723380906
31858	2020-06-19 17:21:43	2020-06-19	Queen Kilback	queen.kilback@geemail.com	Stamford	Connecticut	869965291671081914	00ee3b1316a094f7deff9557b9234aea	American Express	41.1139393233112997	-73.5504926831964525
31859	2020-06-19 17:22:52	2020-06-19	Woodroe Sauer	woodroe.sauer@warmmail.com	Billings	Montana	3158004959698989533	7f436a1783289dbff3b6a1248cbefc1f	VISA 16 digit	45.7870543692950136	-108.515398288813969
31860	2020-06-19 17:40:34	2020-06-19	Bailey Schneider	bailey.schneider@geemail.com	New York	New York	676236313863569	174efa51083ebad058ed890c42ef0e59	Mastercard	40.5765236349068559	-73.8894238757330868
31861	2020-06-19 17:43:09	2020-06-19	Frederick Christiansen	frederick.christiansen@geemail.com	Orange	California	3096958484316352390	fe47971b4da09923c641346b61f00aba	JCB 16 digit	33.8838020170461363	-117.887427024460578
31862	2020-06-19 17:43:58	2020-06-19	Jazmin Larkin	jazmin.larkin@geemail.com	Oklahoma City	Oklahoma	55007098214010628	634b6ca9011103dbc7389e07e3db1794	Mastercard	35.4104962277602411	-97.5772997052770137
31863	2020-06-19 17:53:31	2020-06-19	Edd Lockman	edd.lockman@geemail.com	Detroit	Michigan	3711548747169303	24651bd927119da21eb5aa2b87e41b46	JCB 16 digit	42.451360681505875	-83.1250686147369464
31864	2020-06-19 18:00:04	2020-06-19	Brennon Eichmann	brennon.eichmann@geemail.com	Coral Springs	Florida	6011238552808070985	cf895f479e5b2ba15f0951509218f67d	Mastercard	26.3366994592890151	-80.331675805024048
31865	2020-06-19 18:00:06	2020-06-19	Shoji Ryan	shoji.ryan@geemail.com	Milwaukee	Wisconsin	3051003503774369	23af726a4dddd4d0254fb80853d9a566	Maestro	43.0773116258990001	-88.0063230877377123
31866	2020-06-19 18:03:44	2020-06-19	Dr. Reese Kovacek	dr.reese.kovacek@geemail.com	San Francisco	California	3158205384448392986	db3f188b339a6a64363fb4fb5f206380	American Express	37.7758324666171461	-122.428873775242238
31867	2020-06-19 18:11:09	2020-06-19	Windy Braun-Nienow	windy.braun.nienow@woohoo.com	Lexington	Kentucky	4063395211223118	0434aca854f7095a06b246ae83b03010	Maestro	38.1054304683923704	-84.4002163244776398
31868	2020-06-19 18:14:34	2020-06-19	Imelda Hamill	imelda.hamill@geemail.com	San Francisco	California	4165561457780	94b1b2de6087f9a333661ed148c83ac5	JCB 16 digit	37.7959799529959568	-122.447354880943237
31869	2020-06-19 18:23:01	2020-06-19	Kellen Zulauf	kellen.zulauf@geemail.com	Memphis	Tennessee	4856040910588723	4ab144d12982200971c65c75f2c667b6	JCB 16 digit	35.1339989656183889	-89.8968477988407102
31870	2020-06-19 18:24:49	2020-06-19	Dr. Grayson Koepp	dr.grayson.koepp@geemail.com	Waterbury	Connecticut	6011691309978072279	f6cf503744cf2e1ce2495341ca8ba8cf	JCB 15 digit	41.5233337617516511	-73.0010939387518931
31871	2020-06-19 18:46:12	2020-06-19	May Fadel	may.fadel@geemail.com	Berkeley	California	210033434239894167	c36e437bf9bc0af9ea158c2bf72c75b5	Voyager	37.9254160628065904	-122.244746940330501
31872	2020-06-19 18:47:42	2020-06-19	Vera Runte	vera.runte@geemail.com	Wichita Falls	Texas	561240887495717	69d7f50404345a45d1fd80b60cdafb1a	VISA 16 digit	33.9855243607617936	-98.5943020742308249
31873	2020-06-19 19:01:19	2020-06-19	Josie Schimmel-Muller	josie.schimmel.muller@geemail.com	Anaheim	California	4406549160209082	a7aee0556a62723257a69d53ea06339e	JCB 15 digit	33.9076705228369661	-117.799976794675359
31874	2020-06-19 19:02:44	2020-06-19	Ms. Tashina Konopelski DDS	ms.tashina.konopelski.dds@geemail.com	Anchorage	Alaska	3096723823100642694	f5b41307658440c5754da4189d3e2277	Discover	61.2111066940456681	-149.227729960217317
31875	2020-06-19 19:09:53	2020-06-19	Miss Shani Volkman	miss.shani.volkman@geemail.com	Oakland	California	869909897235893187	a0db972fe90f840bcfae79ed4fbd22fc	JCB 16 digit	37.7780227306287131	-122.243732276890839
31876	2020-06-19 19:17:03	2020-06-19	Estefani McCullough	estefani.mccullough@warmmail.com	San Francisco	California	180042202772425890	2448bc996bee3c28e95c2a9023ba4ed7	American Express	37.7798229454892223	-122.425665401806654
31877	2020-06-19 19:27:21	2020-06-19	Mrs. Malia Skiles DVM	mrs.malia.skiles.dvm@geemail.com	San Francisco	California	4490438657473	56fa7b2b9050c559cb3383bbfadb2fe0	Maestro	37.7788711678659368	-122.449578478186694
31878	2020-06-19 19:47:35	2020-06-19	Edrie Padberg	edrie.padberg@geemail.com	McKinney	Texas	4641645818006345	8d44b7b558c577f43b1ab1e9432f91f5	Maestro	33.2275364786516931	-96.6212535470090899
31879	2020-06-19 19:50:20	2020-06-19	Olin Treutel	olin.treutel@woohoo.com	Washington	District of Columbia	3158971982123681144	6cd3c403e218f72b55fea04832125857	Mastercard	38.9861299986284209	-76.9440317702692056
31880	2020-06-19 19:54:23	2020-06-19	Lakisha Durgan	lakisha.durgan@woohoo.com	Los Angeles	California	4926110374708426	dddb9ec1cf04913f6efb0bb00c8f92f4	VISA 16 digit	34.0116008746769225	-118.400811759614569
31881	2020-06-19 20:00:25	2020-06-19	Kalene Rutherford	kalene.rutherford@geemail.com	Inglewood	California	3039951720949655	f6bcdf45c613035a75bccb5ff2c52d21	JCB 15 digit	33.9451973132103646	-118.254015776238589
31882	2020-06-19 20:17:45	2020-06-19	Tobi Paucek	tobi.paucek@geemail.com	San Antonio	Texas	4470488983963925	7a6f77b34cc15a8376e9f9e2a8d14963	Voyager	29.5438071470778425	-98.5761501582641131
31883	2020-06-19 20:35:15	2020-06-19	Dr. Linton Rohan	dr.linton.rohan@warmmail.com	San Francisco	California	4411422766732	15f0f073faafe0f43f0d4fdeffe8b655	VISA 13 digit	37.7718077779108512	-122.397067645680096
31884	2020-06-19 20:38:44	2020-06-19	Killian Langosh	killian.langosh@geemail.com	Yonkers	New York	630474802761341	3f522b8ddd3ceec1606ee13dc4212044	Voyager	40.8665081984564651	-73.9247622024618067
31885	2020-06-19 20:44:10	2020-06-19	Shannen Lakin DVM	shannen.lakin.dvm@geemail.com	Boston	Massachusetts	3785368844454974	38a629ef7eec740c74d9527b635b5840	Maestro	42.3391095692925177	-71.0780128281980836
31886	2020-06-19 20:44:52	2020-06-19	Gregoria Keebler-Kilback	gregoria.keebler.kilback@woohoo.com	San Antonio	Texas	3337351899146347406	386bf9760edfe67d0b5065836ef29b8a	VISA 16 digit	29.4589700076334182	-98.4417500377934402
31887	2020-06-19 20:46:41	2020-06-19	Dr. Eda Goodwin DDS	dr.eda.goodwin.dds@woohoo.com	San Francisco	California	3096010845985333174	241177fb95c978a7441759ea7a550dff	Mastercard	37.761711235417728	-122.443284235092349
31888	2020-06-19 20:47:47	2020-06-19	Elbert Treutel	elbert.treutel@woohoo.com	San Antonio	Texas	4661302305667792	b4d08967d23528dd71780ea381b0158c	Voyager	29.4145231315936897	-98.5441394791774457
31889	2020-06-19 21:02:29	2020-06-19	Albertus Hansen	albertus.hansen@geemail.com	Evansville	Indiana	3528629286357531736	84839d31f94e34d3f232f26acedff4a8	JCB 16 digit	37.9770509794492241	-87.565429887774215
31890	2020-06-19 21:08:11	2020-06-19	Drury Conn	drury.conn@geemail.com	Miami	Florida	4713007214313	8449ac0bcbff90bb71824c366a257d39	JCB 15 digit	25.7730469761554168	-80.2444336057048275
31891	2020-06-19 21:19:16	2020-06-19	Evangelina Quitzon	evangelina.quitzon@geemail.com	Austin	Texas	3158483429079818990	681e3fc7f6633dc81980ff181c1b264b	Discover	30.3034561714749771	-97.6620551063451927
31892	2020-06-19 21:19:47	2020-06-19	Johnpaul Reinger-Feest	johnpaul.reinger.feest@woohoo.com	New York	New York	3112795762348172184	4d9d4841e19ab46fbef908a51319863f	American Express	40.7002433448787784	-73.9459833761572867
31893	2020-06-19 21:28:27	2020-06-19	Estevan Hoppe Sr.	estevan.hoppe.sr.@geemail.com	San Diego	California	180007745388551890	b34596f3d691456968b7dc163fd0086e	Diners Club / Carte Blanche	32.7251463727626941	-117.209024612084036
31894	2020-06-19 21:30:02	2020-06-19	Mrs. Magen Stokes PhD	mrs.magen.stokes.phd@geemail.com	Sterling Heights	Michigan	4422438442695062	ab371b6d68bdda88121db4f6cf1bc595	American Express	42.4873119664460432	-83.0044004155483037
31895	2020-06-19 21:37:58	2020-06-19	Terese Thompson PhD	terese.thompson.phd@woohoo.com	Phoenix	Arizona	4388733100065885	fae98b92c213b25efcf64338c400caf0	VISA 16 digit	33.6273557581406095	-112.013632903986064
31896	2020-06-19 21:41:06	2020-06-19	Ms. Shania Aufderhar MD	ms.shania.aufderhar.md@geemail.com	San Francisco	California	3474889659333535	4e67433fc3eaff0f95ea936a705011d1	JCB 15 digit	37.7492388099049663	-122.42376009872622
31897	2020-06-19 21:48:55	2020-06-19	Atha Williamson	atha.williamson@woohoo.com	New York	New York	060492132366862	70b2e6bf855cdb89e33e75073681dd2e	VISA 13 digit	40.6584532057158654	-73.8891522325471044
31898	2020-06-19 22:01:17	2020-06-19	Hezekiah Cummerata	hezekiah.cummerata@woohoo.com	Tacoma	Washington	53064933389067609	5b8b78ea3893f0455fecb2f2ba3aa3c1	Diners Club / Carte Blanche	47.2631301564283675	-122.482561674458168
31899	2020-06-19 22:05:18	2020-06-19	Branson Cartwright	branson.cartwright@geemail.com	Arlington	Texas	589360481290413	a45d20b9b32dd3c8206bbd32fe110db0	Diners Club / Carte Blanche	32.7924067585047325	-97.2164245226912271
31900	2020-06-19 22:06:08	2020-06-19	Arlin Kautzer	arlin.kautzer@geemail.com	Washington	District of Columbia	3112869712953418852	e06cda2a367fc169f7084d06e7fe35dd	Diners Club / Carte Blanche	38.9249061703480805	-77.0782440712422101
31901	2020-06-19 22:12:59	2020-06-19	Venita Turner DDS	venita.turner.dds@geemail.com	Springfield	Massachusetts	3017038900889331	d90496e6b2ce53338ad4ce07de2439d5	VISA 13 digit	42.0912143412716659	-72.4535101384483369
31902	2020-06-19 22:24:29	2020-06-19	Essie Bogisich	essie.bogisich@geemail.com	New Orleans	Louisiana	4201562935654	802b9129e375dceca6979730c22ed0cf	JCB 16 digit	30.0991537127658724	-89.9566593270543962
31903	2020-06-19 22:42:54	2020-06-19	Kunta Crona	kunta.crona@geemail.com	San Francisco	California	3013297622175056	81528c3d6472bab718bccec208019ee4	Mastercard	37.7586393989222699	-122.409977948749727
31904	2020-06-19 22:59:34	2020-06-19	Ms. Ossie Ritchie DVM	ms.ossie.ritchie.dvm@geemail.com	Kent	Washington	3006239949565103	5a15ed309dab6d9ce3ad55a4fbdfa921	American Express	47.4486301571242493	-122.217487769867105
31905	2020-06-19 23:03:09	2020-06-19	Donald Herzog-Rodriguez	donald.herzog.rodriguez@geemail.com	Joliet	Illinois	639026710547840	045ad6f8fe9d97f0e69fbdff9bf6719c	VISA 16 digit	41.5587484908148639	-88.0861932231217537
31906	2020-06-19 23:14:30	2020-06-19	Rolanda Trantow	rolanda.trantow@geemail.com	Spokane	Washington	4616308831261261	770cff900234b29b21ecf4e2e66011c3	American Express	47.6483306390006049	-117.425792790194237
31907	2020-06-19 23:15:15	2020-06-19	Maddox Deckow	maddox.deckow@geemail.com	San Francisco	California	180045273422728964	86aeeda28ba0b6d4dd03160671ec2b5d	VISA 16 digit	37.7332336969824951	-122.433686308083637
31908	2020-06-19 23:16:33	2020-06-19	Jerome Donnelly	jerome.donnelly@geemail.com	Milwaukee	Wisconsin	3158761949101311204	c1a10a39d03da7e903790a7072fd25fa	Mastercard	43.114148680501799	-88.0017756403524487
31909	2020-06-19 23:29:01	2020-06-19	Abagail Halvorson	abagail.halvorson@geemail.com	Roseville	California	676264429828573	4d175c34be150326e674cd1b24a76758	Voyager	38.7250386965516924	-121.325574833642321
31910	2020-06-19 23:29:28	2020-06-19	Squire Farrell	squire.farrell@woohoo.com	Ann Arbor	Michigan	3337066378610986664	d11f1cec74186dc00912fd17f686bc29	VISA 13 digit	42.2901931473579253	-83.6660083762478166
31911	2020-06-19 23:35:07	2020-06-19	Phoebe Bruen-Hills	phoebe.bruen.hills@warmmail.com	San Jose	California	55207814165104527	6a41d9fded5a38d79ab9858d0fa67111	VISA 13 digit	37.2180636153843238	-121.761061138448866
31912	2020-06-19 23:51:47	2020-06-19	Stoney Wilderman III	stoney.wilderman.iii@geemail.com	San Francisco	California	630487739749536	280019b65219b6703fb7e0199a2519a5	JCB 16 digit	37.772155259055701	-122.445691480119905
31913	2020-06-19 23:52:22	2020-06-19	Dr. Warren Shields	dr.warren.shields@geemail.com	Phoenix	Arizona	210020020357813694	a0da230665b3276be72d42af51105974	Discover	33.5021143216572739	-112.042681007266424
31914	2020-06-19 23:53:06	2020-06-19	Mr. Derick Welch V	mr.derick.welch.v@geemail.com	Vancouver	Washington	210055165684043198	aa882f07c71069668d62bd5734a8c071	JCB 16 digit	45.7216665422149049	-122.501866560295966
31915	2020-06-19 23:56:10	2020-06-19	Dr. Collis Rice	dr.collis.rice@warmmail.com	Fayetteville	North Carolina	869995837419427910	d7a11f078f82d30260a2f953003ee3d4	Diners Club / Carte Blanche	35.1725213071119001	-78.9662367871161592
31916	2020-06-19 23:56:56	2020-06-19	Dr. Darian Senger MD	dr.darian.senger.md@woohoo.com	Oakland	California	869921362636644758	56c3cc78c264c6049934d8b6ff4edd25	American Express	37.7797554423214947	-122.299631733020263
31917	2020-06-20 00:00:27	2020-06-20	Jelani Gislason	jelani.gislason@geemail.com	Riverside	California	4487814212295	6f5122c9fe9eab269db8fa6de8bc09b7	VISA 16 digit	33.9372527115460443	-117.426323929938292
31918	2020-06-20 00:07:35	2020-06-20	Alda Leffler	alda.leffler@geemail.com	Las Vegas	Nevada	676355524929811	27b917992790b9651ba0e1e891541c8e	JCB 16 digit	36.2294167750149967	-115.173060076611478
31919	2020-06-20 00:15:37	2020-06-20	Kaylene Gutmann	kaylene.gutmann@geemail.com	Houston	Texas	3112827521522120787	9f0c8023f10686f5e7d6bee8ae4f965e	Voyager	29.8732689641028628	-95.4455227612532724
31920	2020-06-20 00:28:30	2020-06-20	Agustus Mann II	agustus.mann.ii@woohoo.com	San Francisco	California	6011352305473509765	ea9df5ff4a4eff5324ed065144c1e9a1	Voyager	37.7671306640172517	-122.444363221629317
31921	2020-06-20 00:32:08	2020-06-20	Mr. Arnav Ankunding	mr.arnav.ankunding@geemail.com	New York	New York	3008990660152962	9354f2ec564274f1413d34c4fb36676d	JCB 16 digit	40.5951638296470065	-73.9632459130499456
31922	2020-06-20 00:35:01	2020-06-20	Kendal Kris	kendal.kris@woohoo.com	San Francisco	California	503871830865524	0b40d53ea549b2acd4b8afb7c1d33c56	JCB 16 digit	37.7762667445118652	-122.460140013577472
31923	2020-06-20 00:38:45	2020-06-20	Donovan Kunze	donovan.kunze@geemail.com	Chicago	Illinois	210098556447473574	cce9d319d6ca9b61eb502200136bb437	JCB 16 digit	41.7870617247022693	-87.7468803363882017
31924	2020-06-20 00:41:49	2020-06-20	Jannette Stehr DDS	jannette.stehr.dds@warmmail.com	Evansville	Indiana	4891207168110644	72a0ee04b899e501271d9975ded1cbc7	Mastercard	37.9248195236220909	-87.6079792320195594
31925	2020-06-20 00:59:22	2020-06-20	Adelbert Feest	adelbert.feest@geemail.com	Oakland	California	3750129077504526	a8cb247ccfd138de83fbc43505c23291	American Express	37.828311245211097	-122.288566344519339
31926	2020-06-20 01:05:01	2020-06-20	Shasta Franecki PhD	shasta.franecki.phd@woohoo.com	Las Vegas	Nevada	3737793646532470	93717c797e7f018c07ade634dccf42c6	Mastercard	36.1780619605079252	-115.342615158783644
31927	2020-06-20 01:06:43	2020-06-20	Venessa Grimes-Smitham	venessa.grimes.smitham@geemail.com	Dallas	Texas	639098529778668	2317fee520f95d2ba4652446a7ff9615	Maestro	32.7692620063938236	-96.8539266622122312
31928	2020-06-20 01:23:34	2020-06-20	Gerard Bernhard	gerard.bernhard@geemail.com	New York	New York	3001845482321632	db32271da2885fffaa1c329cba17d451	VISA 13 digit	40.5876759252268826	-73.8721114847239022
31929	2020-06-20 01:27:34	2020-06-20	Mr. Perry Wunsch	mr.perry.wunsch@geemail.com	San Francisco	California	52679047500639886	a48468fec823c2118fd4581b55c10dfd	American Express	37.7403519433319659	-122.416307348532229
31930	2020-06-20 01:34:37	2020-06-20	Norval Murray	norval.murray@warmmail.com	Augusta	Georgia	502010430809029	ca4a440b0fa415e60a1b35a48796db54	VISA 16 digit	33.4537745244540261	-81.9813672816675165
31931	2020-06-20 01:40:19	2020-06-20	Clair Haley	clair.haley@geemail.com	New York	New York	4519653549868214	b0e5da3a0aa1e41e238b8012166e7ee8	JCB 16 digit	40.7572460105866199	-74.0078154189407798
31932	2020-06-20 01:41:09	2020-06-20	Riley Adams MD	riley.adams.md@warmmail.com	New York	New York	180085445108504353	222b0de964a74e8328e11d8a2519006d	VISA 13 digit	40.681004177102821	-74.018072193338341
31933	2020-06-20 01:41:24	2020-06-20	Elmira Runolfsson	elmira.runolfsson@geemail.com	San Francisco	California	3030791652947932	27c30fc8fcd8b6b22d52efedd9beacb5	Maestro	37.7574150089329237	-122.4077030129272
31934	2020-06-20 01:44:30	2020-06-20	Dr. Eugenio Collins	dr.eugenio.collins@geemail.com	Phoenix	Arizona	3019770441092250	bf4f641874368c2cdf23a00f1537a16c	Discover	33.628620872127641	-112.11298819118403
31935	2020-06-20 01:56:47	2020-06-20	Ms. Ilda Johnson PhD	ms.ilda.johnson.phd@warmmail.com	Albuquerque	New Mexico	54314539328057458	7c46c778f54a21f654944260f767128b	VISA 16 digit	35.1952503586322081	-106.584987268184875
31936	2020-06-20 02:02:11	2020-06-20	Miss Evangeline Kreiger PhD	miss.evangeline.kreiger.phd@warmmail.com	Houston	Texas	3475275576491573	289ce5d93b6726c2819aad40bd79f9dd	VISA 13 digit	29.7805327005762592	-95.3301668507527609
31937	2020-06-20 02:02:59	2020-06-20	Dr. Ali Rippin IV	dr.ali.rippin.iv@woohoo.com	Charlotte	North Carolina	3337456112003224815	d527f7de98b2aa33a15e9faf6ea62a99	Diners Club / Carte Blanche	35.1222118007272499	-80.8460960977189274
31938	2020-06-20 02:09:18	2020-06-20	Geovanni West	geovanni.west@geemail.com	Murrieta	California	4565138559034652	c98d1c5ae5316047451e64862f8fe8b5	Voyager	33.666331160636993	-117.167014952646198
31939	2020-06-20 02:34:02	2020-06-20	Vicie Schinner	vicie.schinner@geemail.com	Hialeah	Florida	4790732781154	438393dc893dfdcc0bf534906273f6c3	Discover	25.9121038879245518	-80.244395676618069
31940	2020-06-20 02:38:01	2020-06-20	Gladys Miller	gladys.miller@geemail.com	Atlanta	Georgia	4901898561571248	a917068da3732df1228e8d4d81b1237b	Mastercard	33.7462924599457565	-84.3311960102569316
31941	2020-06-20 02:45:03	2020-06-20	Laurance Batz	laurance.batz@geemail.com	Atlanta	Georgia	54836322361724477	0cd1c0935a6b689ccf0684ca6736ee08	VISA 16 digit	33.8351308596130451	-84.380185075108713
31942	2020-06-20 02:50:45	2020-06-20	Ms. Lavelle Connelly	ms.lavelle.connelly@geemail.com	Charlotte	North Carolina	676394360719879	5bf4e08d968e00da1da6939c961d4d0f	Discover	35.3076671468812933	-80.8383647558223544
31943	2020-06-20 03:05:14	2020-06-20	Stacey Fay-Hermiston	stacey.fay.hermiston@geemail.com	Charlotte	North Carolina	3158889048968613112	7b3c5075549418d1523f152df603b32a	Discover	35.1450390188276742	-80.819970781303951
31944	2020-06-20 03:06:44	2020-06-20	Destiny Ullrich	destiny.ullrich@geemail.com	Santa Ana	California	3112039658615988367	0f66e6dce21757171ea061356de0ec03	JCB 15 digit	33.7678256620291606	-117.941344040531661
31945	2020-06-20 03:08:05	2020-06-20	Elian Johnston	elian.johnston@warmmail.com	Sacramento	California	4741068960812684	bb191b5ca49192a5b98758548f49f704	Diners Club / Carte Blanche	38.602789728137104	-121.560014461471141
31946	2020-06-20 03:12:20	2020-06-20	Kayden Swift	kayden.swift@geemail.com	New York	New York	4533918918779645	524ce8d23a963afd0c15970765848c82	American Express	40.7236955315563804	-73.983593433339891
31947	2020-06-20 03:15:16	2020-06-20	Armond Hansen III	armond.hansen.iii@geemail.com	Newport News	Virginia	3000242601900101	15f40c85348dee0c1d30d16d4d890d7f	Diners Club / Carte Blanche	37.0126223624113919	-76.516970621587717
31948	2020-06-20 03:16:08	2020-06-20	Tatiana Lind DVM	tatiana.lind.dvm@geemail.com	San Francisco	California	3783094518363935	879395f22655e0b65adae449c13dec34	Diners Club / Carte Blanche	37.7656578690610658	-122.424999788857875
31949	2020-06-20 03:20:28	2020-06-20	Dr. Ida Bogan	dr.ida.bogan@warmmail.com	Henderson	Nevada	54838357086662642	e4107050734e7329414c39e342dfee6a	VISA 16 digit	36.101489870895449	-114.950971778497845
31950	2020-06-20 03:21:01	2020-06-20	Debera Jakubowski DVM	debera.jakubowski.dvm@geemail.com	San Francisco	California	4909389084920825	211255fe639618215f93b7c8f559b189	VISA 16 digit	37.7787815762744685	-122.448947234804493
31951	2020-06-20 03:25:49	2020-06-20	Kirk West	kirk.west@geemail.com	Saint Paul	Minnesota	869979352741681200	ba692114b242b1d9f1469cfae518d6b3	Voyager	44.9700211889516552	-93.1012760147716847
31952	2020-06-20 03:29:30	2020-06-20	Lucy King	lucy.king@warmmail.com	Murrieta	California	180060405932859968	3c04aae72b6c48fb43df4efeb8460bf0	VISA 13 digit	33.6136859993081529	-117.168551898551726
31953	2020-06-20 03:35:16	2020-06-20	Pat Langworth	pat.langworth@geemail.com	Louisville	Kentucky	3767485346695706	1c49552cf040c1759879213d59e9055a	Discover	38.2423690351560666	-85.710778789974384
31954	2020-06-20 03:38:37	2020-06-20	Ross Kemmer-Sanford	ross.kemmer.sanford@warmmail.com	New York	New York	55042649146364371	4644342c15d72e380aaaa6ea9e06b51e	Voyager	40.5729980236142893	-73.8983682817209484
31955	2020-06-20 03:49:35	2020-06-20	Dr. Asha Ortiz	dr.asha.ortiz@warmmail.com	Los Angeles	California	3014260052249204	36630482d4726bc8e8ba7488cc257984	VISA 16 digit	34.006565008811279	-118.424062747135011
31956	2020-06-20 03:58:26	2020-06-20	Conrad Christiansen	conrad.christiansen@warmmail.com	Elizabeth	New Jersey	54034651831366422	67deaf9f7a631dcd791a1d2eba21c113	Diners Club / Carte Blanche	40.6321584964297742	-74.2864883722215836
31957	2020-06-20 03:59:59	2020-06-20	Ashlea Schmitt	ashlea.schmitt@woohoo.com	Berkeley	California	3096899479525178679	6d504d003c8526dae5b2950e4c7557c1	VISA 16 digit	37.8869799425232401	-122.28379903571566
31958	2020-06-20 04:05:12	2020-06-20	Anson Daniel	anson.daniel@geemail.com	Elgin	Illinois	869914354988320391	ea261ccb5ebf2799dd37aeede8fc21e9	VISA 16 digit	42.0980918707143488	-88.3095485545981802
31959	2020-06-20 04:05:44	2020-06-20	Cliffie Donnelly	cliffie.donnelly@geemail.com	New York	New York	52801647875511122	82d29bd6680c348cf5d1e44a3b887da1	Maestro	40.7285525691453358	-73.9657072429906606
31960	2020-06-20 04:09:31	2020-06-20	Mario O'Connell	mario.o'connell@geemail.com	Washington	District of Columbia	3472373498546948	3d585723f1c37b19ffa3da9946c97001	JCB 15 digit	38.9977046446207893	-76.9230006213046664
31961	2020-06-20 04:34:43	2020-06-20	Deacon Williamson	deacon.williamson@geemail.com	Los Angeles	California	869944814735476345	57c4677234d7ec4d3e242ec1f71b4e47	Discover	34.0855063547711765	-118.424274403461439
31962	2020-06-20 04:38:33	2020-06-20	Mrs. Yulisa Deckow DDS	mrs.yulisa.deckow.dds@woohoo.com	Clinton	Michigan	869992278312839278	064d6d5040ac994a9a1e42b7987c18c8	VISA 16 digit	42.538230401563645	-83.0082170589435862
31963	2020-06-20 04:38:50	2020-06-20	Dr. Porter Eichmann	dr.porter.eichmann@geemail.com	Oakland	California	3112638595851949726	1f07ad52afe7bee13fd057fd5fcd075d	VISA 16 digit	37.8228313260439251	-122.260929977682935
31964	2020-06-20 04:46:24	2020-06-20	Taniyah O'Keefe	taniyah.o'keefe@warmmail.com	Houston	Texas	4512953774296793	42b08be402e1d518fdf645c094804ad7	Maestro	29.7399391851931796	-95.2979070748217367
31965	2020-06-20 04:54:39	2020-06-20	Cheyanne Baumbach	cheyanne.baumbach@geemail.com	Cedar Rapids	Iowa	4157406924210917	7ce6f9dbf0979594728524d3502c9ec3	JCB 15 digit	41.8825751458369169	-91.7482280873760629
31966	2020-06-20 04:57:43	2020-06-20	Anna Stamm	anna.stamm@geemail.com	Minneapolis	Minnesota	180026384537923821	b62ea2e38cd852310cedf97a10929495	Mastercard	44.9767399708360429	-93.3616983602560992
31967	2020-06-20 04:58:05	2020-06-20	Dillion Kihn Jr.	dillion.kihn.jr.@geemail.com	Lancaster	California	3112303844792954427	c77b1ec2bcec07a6cfeec016f43abba6	JCB 16 digit	34.7668002248521901	-118.106840748849507
31968	2020-06-20 05:05:21	2020-06-20	Ronin Morissette	ronin.morissette@geemail.com	New York	New York	3088093946391416395	a74bc19da17c77413a6c9c5a2550507f	VISA 16 digit	40.7311528236828764	-73.9556127729721311
31969	2020-06-20 05:08:34	2020-06-20	Amado Sipes	amado.sipes@geemail.com	Cambridge	Massachusetts	3742236637682030	fff8cbca04b1ee60e01c9d85edd586cf	Voyager	42.4467102737855129	-71.186042858714984
31970	2020-06-20 05:09:13	2020-06-20	Marcelo Lind	marcelo.lind@geemail.com	Cleveland	Ohio	676109030002522	4f13f404dd9108113ed1770eabab5f70	Discover	41.4681967868786288	-81.5984121985040645
31971	2020-06-20 05:23:41	2020-06-20	Anya Kihn PhD	anya.kihn.phd@woohoo.com	Virginia Beach	Virginia	3747589214244458	61caf5d02682852504e0aa22f52b9922	JCB 16 digit	36.7498590433225019	-76.070199476149682
31972	2020-06-20 05:29:43	2020-06-20	Mr. Asa Altenwerth PhD	mr.asa.altenwerth.phd@woohoo.com	Kansas City	Missouri	4956897681923	02aa516d7d11eaa380890f876adc34ee	JCB 16 digit	39.0515092214871231	-94.6197231012154418
31973	2020-06-20 05:33:42	2020-06-20	Robby Cormier	robby.cormier@geemail.com	Norwalk	California	4515656310175754	88bd4a2bb4d80798d1ff811f3e54f7dd	American Express	33.9474298449814356	-118.062326133767144
31974	2020-06-20 05:35:57	2020-06-20	Florrie Muller DDS	florrie.muller.dds@geemail.com	Denver	Colorado	869915208237658234	7b95f7ee336a323a3f69cd1656de7725	JCB 16 digit	39.6818351507704676	-104.93490538054742
31975	2020-06-20 05:39:31	2020-06-20	Dale Fisher	dale.fisher@geemail.com	Indianapolis	Indiana	180039552318511511	3eee7c1b59ee2518be3a2d01385ddb46	JCB 15 digit	39.7266704149551657	-86.078985259282959
31976	2020-06-20 05:42:43	2020-06-20	Hessie Rau	hessie.rau@geemail.com	Berkeley	California	3112261498622852408	b96df8ca31a4391cc725798cffffabc3	Mastercard	37.8781965977822921	-122.263946347235645
31977	2020-06-20 05:44:19	2020-06-20	Monty Stoltenberg	monty.stoltenberg@geemail.com	San Francisco	California	4936601885767859	496ae749752127ae5db372e6f14493b0	Mastercard	37.7531108123872059	-122.425693150991009
31978	2020-06-20 05:48:12	2020-06-20	Chalmers McLaughlin	chalmers.mclaughlin@geemail.com	Roseville	California	4710809074457	7b3d63e862eff7fd36c079bfb51b7d08	Mastercard	38.7666580196060195	-121.326715952133384
31979	2020-06-20 05:48:15	2020-06-20	Dr. Royce Swaniawski MD	dr.royce.swaniawski.md@geemail.com	Jacksonville	Florida	3528333125766610599	3292223ae3d5b0d8a8547b3e3084406c	American Express	30.325588785769046	-81.7516093711912646
31980	2020-06-20 05:49:04	2020-06-20	Dr. Burrel Friesen III	dr.burrel.friesen.iii@woohoo.com	Tucson	Arizona	060402168792162	a7eda81be5b1a5676d45f06ecbc0e007	VISA 13 digit	32.1315152671229143	-110.892659765178706
31981	2020-06-20 05:56:36	2020-06-20	Jolette Feest	jolette.feest@geemail.com	Richmond	Virginia	4150168982752	9cec083a456bf4f39f9d76de8a24c784	Discover	37.6243448571521739	-77.3849685081504219
31982	2020-06-20 05:59:21	2020-06-20	Earl Cole	earl.cole@warmmail.com	Madison	Wisconsin	4266245354673709	6ffe168343e61d5f5b543bcb2ae12fb3	Diners Club / Carte Blanche	43.128332079711555	-89.3504042846966513
31983	2020-06-20 06:18:00	2020-06-20	Berta DuBuque-Tremblay	berta.dubuque.tremblay@geemail.com	Bakersfield	California	4807792782758285	54e7193eb9d0fc96c848a341dcb28926	Mastercard	35.3591752161912609	-119.103894273637977
31984	2020-06-20 06:20:37	2020-06-20	Paola Borer MD	paola.borer.md@geemail.com	Berkeley	California	4097968313109458	2e788c35d87c4a61ba4c9f76fd8a1e12	JCB 15 digit	37.8543170928542096	-122.279482633883632
31985	2020-06-20 06:21:15	2020-06-20	Anwar Bosco	anwar.bosco@warmmail.com	San Francisco	California	3002739299720426	099479e4907ec0748a3ac8d0cec58349	Voyager	37.7778305872124633	-122.40898237422131
31986	2020-06-20 06:27:06	2020-06-20	Fredie D'Amore-Hirthe	fredie.d'amore.hirthe@geemail.com	Chicago	Illinois	3112409653276626721	b51f552337196f27438f6182e3971356	Discover	41.9344488857150068	-87.7545776819374339
31987	2020-06-20 06:31:47	2020-06-20	Dr. Rylan Schuppe III	dr.rylan.schuppe.iii@geemail.com	Detroit	Michigan	4963758084636230	4709420dcb525de482ea58cee290d8c2	JCB 16 digit	42.2947925806436729	-83.0779374613545798
31988	2020-06-20 06:32:15	2020-06-20	Emely Marquardt	emely.marquardt@geemail.com	Ontario	California	3158584831445919402	b759ca3b3d155c53caf136ff02547aeb	JCB 16 digit	34.0923045994859208	-117.700099102650583
31989	2020-06-20 06:37:57	2020-06-20	Mr. Ruffin Gislason PhD	mr.ruffin.gislason.phd@geemail.com	Houston	Texas	210089578998276355	f5b0322762a124ccd119fc991c0660bd	JCB 16 digit	29.8094227749001242	-95.3693893481526516
31990	2020-06-20 06:40:12	2020-06-20	Olinda Barrows	olinda.barrows@woohoo.com	Los Angeles	California	4657814891062	c7e3a2c57e035e372f0188004eab423b	VISA 16 digit	34.0865386256813991	-118.339121559401221
31991	2020-06-20 06:43:23	2020-06-20	Boston Cole	boston.cole@geemail.com	Los Angeles	California	3788220725448806	677d3a6b1096da94415c0fe34df7544f	Diners Club / Carte Blanche	34.0184388993173812	-118.467401181719453
31992	2020-06-20 06:54:25	2020-06-20	Graham Hagenes	graham.hagenes@geemail.com	Milwaukee	Wisconsin	6011407572097681206	9a29546517c60986b204e75ecc0b00ac	VISA 16 digit	43.0438825490970132	-87.997888277434555
31993	2020-06-20 06:58:25	2020-06-20	Forest Trantow	forest.trantow@woohoo.com	Sacramento	California	4835950229513749	8e6fb9ee8c370497efd7220176de5e78	JCB 16 digit	38.6599990802150231	-121.482313470567007
31994	2020-06-20 07:02:17	2020-06-20	Otelia Sipes-Satterfield	otelia.sipes.satterfield@geemail.com	Springfield	Massachusetts	4415479747677	a8e28d0b02206df51deaa5e53754f27d	Mastercard	42.0328931559082122	-72.5234466335363805
31995	2020-06-20 07:03:00	2020-06-20	Laraine Ward	laraine.ward@geemail.com	Scottsdale	Arizona	3158222010896176949	fe93b1ee0bf1994d81be2638c432830d	JCB 16 digit	33.6719195438671832	-111.9477441657301
31996	2020-06-20 07:12:35	2020-06-20	Chestina Roob	chestina.roob@warmmail.com	West Valley City	Utah	52839987625480533	3c71f41137cf225c196a0ec2bda33c3c	Discover	40.7687639905828973	-111.926320375942808
31997	2020-06-20 07:13:59	2020-06-20	Miss Cleora Bailey DDS	miss.cleora.bailey.dds@geemail.com	San Francisco	California	3480524713879296	285821dea684ca1b02d722f4005470c4	Discover	37.8157384676716148	-122.413548149695885
31998	2020-06-20 07:15:00	2020-06-20	Dr. Emett Oberbrunner	dr.emett.oberbrunner@geemail.com	Green Bay	Wisconsin	869979658724199519	ae986ec4b40cd653e4e437f178f910fb	Maestro	44.5205371326830246	-88.0368830111164584
31999	2020-06-20 07:15:14	2020-06-20	Nathalie Rutherford-Beatty	nathalie.rutherford.beatty@geemail.com	Cincinnati	Ohio	180040556127871336	cdd0781c4b65b6de082b46cc1e940ef1	Voyager	39.2003894580293419	-84.520365109275275
32000	2020-06-20 07:30:32	2020-06-20	Beyonce Goyette	beyonce.goyette@geemail.com	Wichita Falls	Texas	3528589666928276945	c064cca78fcf998de1d188ae4c739321	American Express	33.8850878895919791	-98.4413814430046727
32001	2020-06-20 07:36:27	2020-06-20	Hortensia Vandervort	hortensia.vandervort@woohoo.com	New York	New York	4047203481461	584c3737ea3a4e7c777bb0061bba5011	Discover	40.6255454127434632	-74.0175018503692002
32002	2020-06-20 07:40:06	2020-06-20	Ms. Salena Brakus DVM	ms.salena.brakus.dvm@geemail.com	Oakland	California	3337978617355652917	93061bae04cdbfbc1a0641ac0db06657	Voyager	37.7754701973803293	-122.260968516702405
32003	2020-06-20 07:43:17	2020-06-20	Woodroe Jast	woodroe.jast@warmmail.com	Laredo	Texas	4136682806410314	f05730356b0cce37b413e44debf5b74d	VISA 13 digit	27.5954709439255303	-99.5820077485877988
32004	2020-06-20 07:54:49	2020-06-20	Naima Goodwin	naima.goodwin@geemail.com	New York	New York	3112253844622552524	ec24b017a9dc9e49ff317c0596e3e4db	VISA 16 digit	40.5856398316789395	-73.8817083884857624
32005	2020-06-20 07:58:21	2020-06-20	Stephania Tromp	stephania.tromp@geemail.com	Clearwater	Florida	3405098093562907	3ff3166967b63db65514b49336ac49c1	JCB 16 digit	28.0081037366889412	-82.8332164937894788
32006	2020-06-20 07:59:04	2020-06-20	Ham Kreiger	ham.kreiger@geemail.com	Downey	California	180004887856303538	fea95ca2524efceec8527d5e27f01147	JCB 16 digit	34.0304233152203253	-118.223322728193921
32007	2020-06-20 08:05:54	2020-06-20	Jacky Ebert	jacky.ebert@woohoo.com	Phoenix	Arizona	4808629059441	3d9a7728a4e8b2f6a7b2d63fcf03efb5	VISA 13 digit	33.6371289931636355	-111.999964515857783
32008	2020-06-20 08:07:11	2020-06-20	Booker Feil	booker.feil@geemail.com	San Francisco	California	6011134044612587086	654468fd4067b822cd172a0207f118d5	American Express	37.7554847452712323	-122.475096211592515
32009	2020-06-20 08:14:04	2020-06-20	Henderson Quitzon	henderson.quitzon@woohoo.com	New York	New York	4061644418480183	9557d1b42ab64da68b33555aa88d3226	VISA 13 digit	40.6947105825636513	-73.893643056358016
32010	2020-06-20 08:16:04	2020-06-20	Ewald McGlynn	ewald.mcglynn@geemail.com	Pittsburgh	Pennsylvania	4243013778551713	5b24d72801818db27c3211983b1a01fa	JCB 16 digit	40.4496865665495378	-80.0255168962929417
32011	2020-06-20 08:16:28	2020-06-20	Dr. Jerilynn Abbott DVM	dr.jerilynn.abbott.dvm@warmmail.com	Los Angeles	California	869933361822195605	aabf605a4d3629d9307c603c8c39fa9c	Diners Club / Carte Blanche	33.9232102996069926	-118.359559562103072
32012	2020-06-20 08:22:27	2020-06-20	Tatyana Howell	tatyana.howell@geemail.com	San Francisco	California	3738456568044358	09ff3974f237512123070205e5ac8755	Voyager	37.7726742838013863	-122.443285755375769
32013	2020-06-20 08:24:54	2020-06-20	Andra Stoltenberg MD	andra.stoltenberg.md@warmmail.com	Cleveland	Ohio	869915276003664835	bd6bd55892394e4887d93cb2ab00d844	VISA 16 digit	41.4971423100531069	-81.6318806624278466
32014	2020-06-20 08:25:49	2020-06-20	Columbus Jenkins	columbus.jenkins@geemail.com	Washington	District of Columbia	4022879264826869	14fe7f0bf8cdf67648115a26193b55f2	JCB 16 digit	38.8946628679785888	-77.0268338266506873
32015	2020-06-20 08:26:12	2020-06-20	Mr. Willie Doyle	mr.willie.doyle@geemail.com	Nashville	Tennessee	4293600774784550	afc22467d69b4739e17137449da75f2d	VISA 16 digit	36.1665357229422781	-86.8622681963630043
32016	2020-06-20 08:43:33	2020-06-20	Cheryl Hansen-Russel	cheryl.hansen.russel@geemail.com	San Diego	California	3486858707757439	e93bf12c4b65abb97d1a028b63e10e9e	VISA 16 digit	32.8955795219700775	-117.174229913475003
32017	2020-06-20 08:53:40	2020-06-20	Mr. True Yost	mr.true.yost@geemail.com	Baton Rouge	Louisiana	4718303331132135	817cfc483c7d5860ad60ef69a5fe6f6b	VISA 16 digit	30.4829297153025855	-91.1677993158452153
32018	2020-06-20 08:55:41	2020-06-20	Dorman Paucek	dorman.paucek@warmmail.com	San Francisco	California	4565022421863	ea457fba47e12da3b316e2707f63b315	Diners Club / Carte Blanche	37.7841594134804026	-122.425842126219962
32019	2020-06-20 09:02:24	2020-06-20	Dr. Rocco Maggio	dr.rocco.maggio@geemail.com	Hartford	Connecticut	6011766393096808178	cba819aebf9cd0df5321a42289c10b0f	Maestro	41.7164980404559529	-72.7585517739303498
32020	2020-06-20 09:02:27	2020-06-20	Erykah Maggio	erykah.maggio@geemail.com	Henderson	Nevada	4021656455303465	06ab36f2b320e3e3831d3c057656cab1	JCB 15 digit	36.016055511350558	-114.999057475306842
32021	2020-06-20 09:03:53	2020-06-20	Helyn Purdy-Larkin	helyn.purdy.larkin@warmmail.com	Ann Arbor	Michigan	53811113262551666	c2c8388d00f9b958c6b5303126128dd6	JCB 16 digit	42.1763432948909696	-83.8143669156931423
32022	2020-06-20 09:08:43	2020-06-20	Bessie Muller	bessie.muller@geemail.com	Oakland	California	210058326156887671	ed282776bdd3a2898aefd145958e5892	JCB 16 digit	37.7841426448366917	-122.273747636503003
32023	2020-06-20 09:14:00	2020-06-20	Hazen Bruen	hazen.bruen@geemail.com	Carrollton	Texas	060488877636816	30741ea30086cae7a641d1dfb64bac03	Maestro	32.8919952047910513	-96.998074490516629
32024	2020-06-20 09:50:36	2020-06-20	Luciana Dickens	luciana.dickens@geemail.com	Albuquerque	New Mexico	869966905998602776	5c48360223445e90e2b69092684f3a6d	Diners Club / Carte Blanche	35.0826663136150714	-106.553343889077752
32025	2020-06-20 10:00:48	2020-06-20	Cayden Collins	cayden.collins@geemail.com	San Francisco	California	4436032935573854	749ae4f3b365c4d94029ba9a37cf1754	VISA 16 digit	37.7576508629897063	-122.417844154563383
32026	2020-06-20 10:03:14	2020-06-20	Tommie Will	tommie.will@warmmail.com	Raleigh	North Carolina	3059482587015091	5720417c7e9c48368d0efd4c6dee6982	Mastercard	35.7892381539236695	-78.6661873836007004
32027	2020-06-20 10:04:42	2020-06-20	Farrah Maggio	farrah.maggio@geemail.com	Dallas	Texas	52993630456906521	b1d23d01bf2519963b70706ce2030f23	VISA 16 digit	32.8820800635769999	-96.830538929203513
32028	2020-06-20 10:44:11	2020-06-20	Kyara Wilderman DVM	kyara.wilderman.dvm@geemail.com	Shreveport	Louisiana	52738208875263145	953c8fa3fb08616d94680af7e9e344ba	Maestro	32.5127202348090734	-93.7498228448189792
32029	2020-06-20 10:46:19	2020-06-20	Janel Graham	janel.graham@geemail.com	Austin	Texas	3032807460573054	41e38d683e8d4dfa381f61d6f5066355	Mastercard	30.2950887304857375	-97.7466693811822722
32030	2020-06-20 10:48:09	2020-06-20	Ms. Debroah Satterfield	ms.debroah.satterfield@geemail.com	Cleveland	Ohio	676181501444871	7e3262d3b5c0818e4785d16f87128750	American Express	41.4071153133492871	-81.7623152940306852
32031	2020-06-20 10:52:47	2020-06-20	Young Schaefer	young.schaefer@geemail.com	Los Angeles	California	4323749734682497	d9281700fca840c6bb5b7c44fdc1d3ee	JCB 15 digit	34.0890850594133141	-118.42338053225464
32032	2020-06-20 11:17:47	2020-06-20	Verne Barton-Doyle	verne.barton.doyle@warmmail.com	New York	New York	3002410932679193	2334f1c75b0ea675bb836fa698e791cf	VISA 13 digit	40.6287969299349925	-73.8920539003226935
32033	2020-06-20 11:31:24	2020-06-20	Lossie O'Keefe	lossie.o'keefe@geemail.com	Clarksville	Tennessee	4528837996578	95ebbc02f6b2dddc8350a98968bebdb8	VISA 16 digit	36.6596032725308092	-87.3866605373982424
32034	2020-06-20 11:40:12	2020-06-20	Paisley Legros	paisley.legros@geemail.com	Stockton	California	869901319319674969	8c20773a1c76e6d582d9b89caf10ce48	JCB 16 digit	37.9157369692541693	-121.404239467819409
32035	2020-06-20 11:51:15	2020-06-20	Dr. Ferman Jast	dr.ferman.jast@geemail.com	Seattle	Washington	55018316542370788	1fbc87cf5b9c326413f27df2f1562065	Diners Club / Carte Blanche	47.5799635313376754	-122.283346365570651
32036	2020-06-20 11:59:41	2020-06-20	Olin Predovic	olin.predovic@warmmail.com	San Bernardino	California	210019543430462976	f339b7472f45674dd5904942ed7ba7f1	JCB 16 digit	34.1829999557029396	-117.333126726678017
32037	2020-06-20 12:09:50	2020-06-20	Issac Stroman V	issac.stroman.v@geemail.com	Bakersfield	California	4683533161421	2561e239084cc27062ed4cf96b199d7f	Diners Club / Carte Blanche	35.4041966165125359	-118.930890353842827
32038	2020-06-20 12:17:45	2020-06-20	Bobby Lang II	bobby.lang.ii@geemail.com	Albuquerque	New Mexico	3112426294623832594	9eba356773e99243c4f239cd9575963d	JCB 15 digit	35.2055722420237984	-106.644563941571491
32039	2020-06-20 12:27:16	2020-06-20	Lindbergh Parker-Leuschke	lindbergh.parker.leuschke@geemail.com	New York	New York	3528271413365192076	bb8cd7c2afd4bba96cb6512af90004fc	VISA 16 digit	40.6911663723867392	-73.8971768648259371
32040	2020-06-20 12:27:20	2020-06-20	Adolf Tremblay	adolf.tremblay@warmmail.com	Orlando	Florida	4589963843626456	4e9e2facdde9de77c4cebc05959f2c0c	Diners Club / Carte Blanche	28.448001320639996	-81.2146729676950798
32041	2020-06-20 12:28:51	2020-06-20	Dr. Elliott Kuhlman	dr.elliott.kuhlman@geemail.com	New Orleans	Louisiana	3050889012764482	664e8f5175039ef33fb89283a03f87af	JCB 16 digit	30.1311616606559589	-90.0148913468960643
32042	2020-06-20 12:31:50	2020-06-20	Lasonya O'Connell MD	lasonya.o'connell.md@geemail.com	Greensboro	North Carolina	060481208766709	5a0e8df8b295a51c295c5b245378f80e	Voyager	36.0789207392487725	-79.8711664174199143
32043	2020-06-20 12:39:36	2020-06-20	Ari Gerlach	ari.gerlach@geemail.com	Richmond	California	3337044644937300526	8044875c42fff04489af583676654441	Maestro	38.0243342718996118	-122.346475590378418
32044	2020-06-20 12:42:40	2020-06-20	Jaden Adams	jaden.adams@geemail.com	Houston	Texas	180044398077851174	f571bc38826558379a8e5e791b1046c8	Voyager	29.8823903061062097	-95.3854615212433004
32045	2020-06-20 13:08:01	2020-06-20	Booker McDermott	booker.mcdermott@geemail.com	Cary	North Carolina	4910408249332	e2540f6877699bc790675ae4d1ee4e06	VISA 13 digit	35.681215978284925	-78.7879848822571347
32046	2020-06-20 13:13:12	2020-06-20	Deanne Pacocha-Luettgen	deanne.pacocha.luettgen@woohoo.com	Pittsburgh	Pennsylvania	4016006435862551	1d7f48816fdd298ae936e209ae17c58b	VISA 16 digit	40.4845058879770292	-79.933436895085876
32047	2020-06-20 13:15:43	2020-06-20	Dayami Kertzmann	dayami.kertzmann@woohoo.com	San Francisco	California	180044399708447663	cccd8041a92fc5dda3de8fbe04ada220	Diners Club / Carte Blanche	37.7771398695824132	-122.435159630446748
32048	2020-06-20 13:16:40	2020-06-20	Hiroshi Daugherty IV	hiroshi.daugherty.iv@geemail.com	West Valley City	Utah	3498995210946400	48fe3940f76b74890cc59df32934b0df	JCB 16 digit	40.6826188981290855	-111.948648927941164
32049	2020-06-20 13:20:59	2020-06-20	Luvinia Willms	luvinia.willms@geemail.com	Boston	Massachusetts	4986921560550100	7665f16c68380c8d6bc12a581148709c	Voyager	42.3250499440059045	-70.9467600732062067
32050	2020-06-20 13:27:39	2020-06-20	Cleola Kunze	cleola.kunze@geemail.com	Chicago	Illinois	3158192987827647567	5ee1b628a0c5dc48cfbbceda746ec158	Voyager	41.8640173051342401	-87.6618235485192372
32051	2020-06-20 13:29:09	2020-06-20	Jere Stokes	jere.stokes@warmmail.com	San Francisco	California	676246429329447	d9b468e7f1888f18d989df23c02acb6d	VISA 16 digit	37.7760794188943194	-122.451273559821502
32052	2020-06-20 13:31:06	2020-06-20	Tyrique Bogisich	tyrique.bogisich@geemail.com	Fort Worth	Texas	6011467005023842789	cfde813cb213d9aa6fe5517b38fdcaf2	JCB 16 digit	32.7120398012977134	-97.3661418919272705
32053	2020-06-20 13:35:46	2020-06-20	Mr. Elgie Nader	mr.elgie.nader@geemail.com	Richmond	California	6011411210076693512	c6ba0188068421bba91abe54b2769715	JCB 16 digit	38.0188924733504692	-122.288708406579133
32054	2020-06-20 13:50:45	2020-06-20	Mr. Derl Fadel II	mr.derl.fadel.ii@geemail.com	El Paso	Texas	52684903547389740	c3ae53fd12a67769506af7db218e3425	VISA 16 digit	31.7648960175752642	-106.331803703958172
32055	2020-06-20 13:55:43	2020-06-20	Maebell Weimann	maebell.weimann@geemail.com	Louisville	Kentucky	3096431818379390523	c3d8816e8f3cb13afb4d5b7cc22d1136	Mastercard	38.2440419376730887	-85.5689109906159331
32056	2020-06-20 13:55:48	2020-06-20	Dr. Gavyn Mayer	dr.gavyn.mayer@geemail.com	Eugene	Oregon	3337214060223308947	63bea20763e7dad43d8169ccfca60d1b	Maestro	44.0042330512505018	-123.118667341162265
32057	2020-06-20 14:32:45	2020-06-20	Hartley Beier	hartley.beier@geemail.com	New York	New York	4206911240209239	daabe40b0c2dd716e16bc966c5ec08f9	Diners Club / Carte Blanche	40.6477302648816234	-73.8740840209543705
32058	2020-06-20 14:34:15	2020-06-20	Harlie Schowalter	harlie.schowalter@woohoo.com	Wilmington	North Carolina	55273965258384910	994209e1aebd31d8b8905698cb6e8367	Mastercard	34.146229521306978	-77.8550642400972635
32059	2020-06-20 14:35:22	2020-06-20	Garvin Barton	garvin.barton@geemail.com	Chicago	Illinois	3096281411846705878	10010a6f8d1318a5d87bf1f10711723c	American Express	41.8015585000928525	-87.7264001616306501
32060	2020-06-20 14:51:36	2020-06-20	Mrs. Clarice Bergstrom	mrs.clarice.bergstrom@geemail.com	New Orleans	Louisiana	676362906890702	e34fee7efd1436a3835b071388663712	VISA 16 digit	30.0358300537817193	-89.9957121484708011
32061	2020-06-20 15:01:34	2020-06-20	Delmus Hammes	delmus.hammes@woohoo.com	Peoria	Illinois	3030313232380953	872a6dbd17dae466f0974a8625a0eed9	VISA 13 digit	40.6944149698931739	-89.5588817365817818
32062	2020-06-20 15:02:03	2020-06-20	Miss Rhona Olson	miss.rhona.olson@geemail.com	Jackson	Mississippi	4139812875556914	712a50ad6edcc15ded817129d5094252	Voyager	32.2344672332696618	-90.221924827431522
32063	2020-06-20 15:04:00	2020-06-20	Lashanda Littel	lashanda.littel@geemail.com	Oakland	California	4970886803489	bd0517b7c62409fca6d926db7f24afd1	Diners Club / Carte Blanche	37.8158030793857876	-122.263523426637548
32064	2020-06-20 15:23:16	2020-06-20	Liberty Steuber	liberty.steuber@geemail.com	Murrieta	California	3096795907906078238	ae2ca735da63d50613c81df1df4825e6	Discover	33.6567604582853619	-117.23357559772171
32065	2020-06-20 15:29:30	2020-06-20	Charlize Lebsack	charlize.lebsack@warmmail.com	Orlando	Florida	3096782763543651621	1918d744a4ac03a5b56e0abf39ee01aa	VISA 16 digit	28.3538782849706692	-81.2821322123486567
32066	2020-06-20 15:30:47	2020-06-20	Dr. Chase Wiegand PhD	dr.chase.wiegand.phd@geemail.com	Philadelphia	Pennsylvania	3112896336487782653	471833ba53017cef9f5362a0787d2879	JCB 16 digit	39.980570666161924	-75.1681604565486339
32067	2020-06-20 15:31:19	2020-06-20	Rocio Waelchi	rocio.waelchi@geemail.com	San Francisco	California	3727553419684805	3c85543acc19697a7c4fc0038842cad2	JCB 16 digit	37.7666875614495083	-122.422110429558757
32068	2020-06-20 15:35:04	2020-06-20	Mr. Lenard Simonis	mr.lenard.simonis@geemail.com	Rochester	New York	6011089952214666055	014f2051d0070e9e3de4acc48cbc0737	VISA 16 digit	43.0946870454098985	-77.6047705839626474
32069	2020-06-20 15:35:38	2020-06-20	Sharron Rempel	sharron.rempel@warmmail.com	Hayward	California	4224870454896610	c62c8ef68108e943bd42da32703cde6e	Maestro	37.6964072593476658	-122.031672748762745
32070	2020-06-20 15:36:40	2020-06-20	Keven Friesen	keven.friesen@geemail.com	Houston	Texas	4770198853588952	4f1be5825ac1a5b3e79e04fa21f6225b	VISA 16 digit	29.7985341422338053	-95.4872763942476439
32071	2020-06-20 15:40:07	2020-06-20	Norene Casper	norene.casper@woohoo.com	San Antonio	Texas	4749918625678379	6e0107e9a05f5083bfed690a3174316d	VISA 16 digit	29.450127366192266	-98.4527010028552212
32072	2020-06-20 15:44:21	2020-06-20	Heidy Renner	heidy.renner@geemail.com	New Orleans	Louisiana	53308404022055688	f61531065e1acb34265376a5efe4a549	Maestro	30.1446334461696459	-89.8718753195162918
32073	2020-06-20 15:53:50	2020-06-20	Dr. Brenton Luettgen DVM	dr.brenton.luettgen.dvm@geemail.com	Pasadena	California	4842635956663905	00bea8f2fed31c062245fa4d4f63c583	Maestro	34.2459318260517023	-118.065512269623952
32074	2020-06-20 15:56:36	2020-06-20	Jacqueline Johns	jacqueline.johns@warmmail.com	Elizabeth	New Jersey	3088420803986119054	d69a26f534a44bb13f27a434e6a01dbc	Diners Club / Carte Blanche	40.7318027195181713	-74.2482412231564552
32075	2020-06-20 15:57:35	2020-06-20	Hideo Wisozk	hideo.wisozk@geemail.com	New Orleans	Louisiana	639077756103998	22d55aa9b0f8305611885db278682bb5	JCB 16 digit	30.0698901243988423	-89.9914739989005028
32076	2020-06-20 16:11:51	2020-06-20	Louetta Heller	louetta.heller@warmmail.com	San Francisco	California	3027670259940545	cb1573131a8aebae4637f91128fc4ea2	Mastercard	37.7813794607622739	-122.444531938840981
32077	2020-06-20 16:16:34	2020-06-20	Mrs. Delpha Hayes MD	mrs.delpha.hayes.md@woohoo.com	Raleigh	North Carolina	6011066500525174678	2e1f5d3778f96972d38b6c8862374287	Mastercard	35.9304983164317875	-78.585217838076133
32078	2020-06-20 16:18:15	2020-06-20	Jerilyn Stiedemann	jerilyn.stiedemann@geemail.com	New York	New York	869983842469204973	9777c0bbbe70452bbae47cd4ab3d8473	JCB 16 digit	40.5844220814052932	-73.9371682722482859
32079	2020-06-20 16:33:23	2020-06-20	Dr. Adron Bruen	dr.adron.bruen@warmmail.com	San Francisco	California	3478532773767313	1cedbc9942b71d304cdf2df00ac72f7f	American Express	37.8142958677608831	-122.41330796939188
32080	2020-06-20 16:46:03	2020-06-20	Logan Romaguera	logan.romaguera@geemail.com	New York	New York	4049137589286684	005d2f156570ec9a51657e1dd2919050	JCB 16 digit	40.6766381582003049	-73.9557683464500997
32081	2020-06-20 17:08:34	2020-06-20	Fitzhugh Legros	fitzhugh.legros@geemail.com	West Covina	California	3088579338625528075	ebd7e8782819fb26dad430a73ca58c17	Maestro	34.1422745203707407	-117.894815934922164
32082	2020-06-20 17:11:56	2020-06-20	Ms. Danielle Runolfsson	ms.danielle.runolfsson@geemail.com	Los Angeles	California	3025210956294318	0ded5270adb508ef8b3c1e261bce7386	JCB 16 digit	34.0337220931291569	-118.346050756656751
32083	2020-06-20 17:14:15	2020-06-20	Christophe Gusikowski	christophe.gusikowski@warmmail.com	Charlotte	North Carolina	3112794513964909602	7dd0b08ddb2174459e5471ed9af59d71	JCB 15 digit	35.3066637878093843	-80.8638842956107169
32084	2020-06-20 17:15:29	2020-06-20	Donnell Murazik	donnell.murazik@geemail.com	New York	New York	4892628952865433	76fd6136434c02e230bfeea55e2b7caa	JCB 16 digit	40.7348515836279859	-73.8508904538012985
32085	2020-06-20 17:17:06	2020-06-20	Chelsey Harber	chelsey.harber@geemail.com	Los Angeles	California	3337919826166294957	a800265102d93beec91afc01f2aae34f	JCB 16 digit	33.9875089616380635	-118.459348210738227
32086	2020-06-20 17:19:54	2020-06-20	Rhianna Nitzsche	rhianna.nitzsche@geemail.com	Evansville	Indiana	3158804386813198018	f8bf5532aa81278dec3996b4f3251f2c	Maestro	38.0652769124738839	-87.5074945671416771
32087	2020-06-20 17:28:20	2020-06-20	Dr. Darryll Wisozk II	dr.darryll.wisozk.ii@geemail.com	Costa Mesa	California	3410643241228282	572681ab79ecad2e1f51ace55abde10c	Maestro	33.7074155070833896	-117.907616806063061
32088	2020-06-20 17:30:08	2020-06-20	Chadd Labadie	chadd.labadie@woohoo.com	Oklahoma City	Oklahoma	52786196257891321	15a765b903ccd4a6525672d7e7e06744	VISA 13 digit	35.5354431831188506	-97.5424639104761155
32089	2020-06-20 17:38:15	2020-06-20	Bertie O'Conner	bertie.o'conner@geemail.com	Fresno	California	3158467354631280770	08a82aa01929e7890da879e7aab27885	VISA 16 digit	36.7905607393816112	-119.831025813158234
32090	2020-06-20 18:07:10	2020-06-20	Montana Sporer DDS	montana.sporer.dds@geemail.com	Hampton	Virginia	6011195856432935807	ddfd89772d008f21383b4c7f50bc339c	Maestro	36.9967985331099527	-76.2765155842159004
32091	2020-06-20 18:13:51	2020-06-20	Domingo Prohaska	domingo.prohaska@warmmail.com	San Francisco	California	869910965723885804	7ea474343868a4b60c6e57c17afd00b0	Discover	37.7742710801253523	-122.426439836020364
32092	2020-06-20 18:21:59	2020-06-20	Berkley Lockman	berkley.lockman@geemail.com	San Francisco	California	4070838686981380	20ee6cd020cf6825ccf1586023145fa9	American Express	37.7493087710066675	-122.437790860122661
32093	2020-06-20 18:24:53	2020-06-20	Yahaira Becker-Kemmer	yahaira.becker.kemmer@geemail.com	New York	New York	51289675683051107	610c5ce1781f368f17dc30484ea6e732	Voyager	40.7525663951169719	-73.9860691625986249
32094	2020-06-20 18:28:39	2020-06-20	Bailey Schiller	bailey.schiller@warmmail.com	Olathe	Kansas	210094555804783710	a1191e6ed8edb5f234183817e57f3092	Voyager	38.8247495778027982	-94.8547632054593493
32095	2020-06-20 18:28:43	2020-06-20	May Bartoletti	may.bartoletti@warmmail.com	New York	New York	52202024194831034	221cf56de1951753fd89d74b7931baed	Voyager	40.6196833128333097	-74.0114742542978377
32096	2020-06-20 18:28:50	2020-06-20	Yasmine Kulas	yasmine.kulas@geemail.com	Tulsa	Oklahoma	4939407665842	8df7aeb338f6310eae52213466b8121b	Discover	36.0758899615980653	-95.8810383695133055
32097	2020-06-20 18:31:12	2020-06-20	Jaren Kuhlman Jr.	jaren.kuhlman.jr.@warmmail.com	San Francisco	California	3011009905858338	2d3a6ce79be04b3cfa036d45612b78c4	JCB 16 digit	37.7541510797253608	-122.441383360060513
32098	2020-06-20 18:32:51	2020-06-20	Alexys Fahey	alexys.fahey@geemail.com	Sacramento	California	630462898264171	1d5fc1866d5c6a02af2a878c1d4ea32b	JCB 16 digit	38.6264281072452675	-121.469986253349475
32099	2020-06-20 18:34:02	2020-06-20	Mr. Angus Bradtke DDS	mr.angus.bradtke.dds@geemail.com	Westminster	Colorado	6011585580582185389	64a77e984051b8c25da9c184e871e762	VISA 16 digit	39.9006960012324114	-105.009129876844213
32100	2020-06-20 18:38:35	2020-06-20	Misael Jenkins	misael.jenkins@geemail.com	Detroit	Michigan	3337251662465133851	fbf1b72b8de9b0f89c91212bd5eec14e	Diners Club / Carte Blanche	42.3945443184506203	-83.1575788848686983
32101	2020-06-20 18:54:18	2020-06-20	Vernon Monahan	vernon.monahan@warmmail.com	Norwalk	California	3112597554153656421	11a80ace558871fcf60449786a2b511e	Voyager	33.917224941879887	-118.128408906193457
32102	2020-06-20 18:55:33	2020-06-20	Joella O'Conner	joella.o'conner@geemail.com	Los Angeles	California	4744091827483751	5a83780e5ed83d18d56f2c9358727df9	Discover	33.987686712840194	-118.373281460627169
32103	2020-06-20 19:00:38	2020-06-20	Olivine Powlowski DVM	olivine.powlowski.dvm@warmmail.com	Columbus	Ohio	3158068728221366912	8a35401aa5402cd51ade48fb1647e9f5	American Express	39.8987507939849024	-83.0466699050974171
32104	2020-06-20 19:04:33	2020-06-20	Terance Kris	terance.kris@geemail.com	Fort Worth	Texas	4473359516530	337ead71960247f0e561ccf58a49ae6a	Mastercard	32.8012330855298799	-97.2482081175602957
32105	2020-06-20 19:05:41	2020-06-20	Cruz Hand	cruz.hand@geemail.com	Oklahoma City	Oklahoma	630465705930520	0c1f320a746212f5d5770fee45a6df13	JCB 16 digit	35.392861324493218	-97.5344073072437254
32106	2020-06-20 19:10:35	2020-06-20	Roby Shanahan	roby.shanahan@geemail.com	Houston	Texas	869962891120477697	0eff07409a6e568e855f83c4ae9ea3e5	JCB 16 digit	29.7691908169150352	-95.4558155125487673
32107	2020-06-20 19:14:46	2020-06-20	Miss Aiyana Cole DDS	miss.aiyana.cole.dds@geemail.com	Visalia	California	3769385215379895	5aa26ce4232e39ded7f7ce0dde15bc38	Discover	36.3023731299165675	-119.395032770013074
32108	2020-06-20 19:16:21	2020-06-20	Pennie Ward	pennie.ward@geemail.com	Newport News	Virginia	3780303561871568	769bf27bb25ab030480cce96c58666e1	JCB 16 digit	37.0635539665713907	-76.5586407581605073
32109	2020-06-20 19:24:12	2020-06-20	Dezzie Olson	dezzie.olson@geemail.com	Denver	Colorado	3006726892643820	ec0962ab0fdeb3bd5f484cb772836dfa	Maestro	39.7870402592286467	-104.8790828027077
32110	2020-06-20 19:33:27	2020-06-20	Corda Heathcote	corda.heathcote@geemail.com	Baltimore	Maryland	210042438568348009	bc6ad42b3a86eb0393763edd1f32cab3	Maestro	39.3545440392103032	-76.5543858487177715
32111	2020-06-20 19:35:03	2020-06-20	Mr. Tripp Kautzer	mr.tripp.kautzer@geemail.com	Berkeley	California	4959517784813184	01fdd1e6a190306ea461815502ca240f	VISA 13 digit	37.8945689928042881	-122.323553869071233
32112	2020-06-20 19:44:43	2020-06-20	Alessandro Larson	alessandro.larson@warmmail.com	Fort Worth	Texas	869936040398908875	d64180fd508c037be0a55a99b7b9d712	Discover	32.699908277258281	-97.2549950322888748
32113	2020-06-20 19:52:31	2020-06-20	Paola Thompson-Ferry	paola.thompson.ferry@warmmail.com	New York	New York	3158086331369665324	adee0ef3181878a96b079b02031aec03	JCB 16 digit	40.690750989247114	-73.9896424663614454
32114	2020-06-20 19:56:16	2020-06-20	Dorthey Hauck	dorthey.hauck@geemail.com	Memphis	Tennessee	4103360739814451	ae0deaf536d4544f902a8cb40b92747c	Discover	35.0057919097200028	-90.0035000587139251
32115	2020-06-20 20:01:42	2020-06-20	Brandin Koss	brandin.koss@geemail.com	New York	New York	210031097302405518	8a7ad5b24204e73478be77c67f22c1a3	VISA 13 digit	40.5919161445219032	-73.8471646574687242
32116	2020-06-20 20:02:17	2020-06-20	Atha Kunde Sr.	atha.kunde.sr.@geemail.com	Vista	California	502094333943663	0cef8a9dabefcb2c4318a26df661d24e	Discover	33.2702820856105532	-117.142285797424989
32117	2020-06-20 20:05:42	2020-06-20	Jordan Bechtelar	jordan.bechtelar@geemail.com	Chicago	Illinois	869917659836862668	321928ee84011214e8241bcfd603ed56	Maestro	41.7632552143488098	-87.6405853993289128
32118	2020-06-20 20:07:52	2020-06-20	Marylee Goodwin MD	marylee.goodwin.md@geemail.com	Chandler	Arizona	210088454412410817	c09a4c25aebf3318976bf85c8cd2a550	American Express	33.2217757176231601	-111.848798655287922
32119	2020-06-20 20:08:26	2020-06-20	Aydan Reichel DVM	aydan.reichel.dvm@geemail.com	Las Vegas	Nevada	4552584524392854	58345c35e0130b355e09716fa79055fe	VISA 16 digit	36.1875223771769541	-115.32275127598308
32120	2020-06-20 20:10:09	2020-06-20	Dena Roberts	dena.roberts@geemail.com	Peoria	Arizona	630445016047024	06366fc9ddc57f61e5991de84288195e	JCB 15 digit	33.8283343815978625	-112.342486076701434
32121	2020-06-20 20:17:23	2020-06-20	Lethia Cremin-Rodriguez	lethia.cremin.rodriguez@geemail.com	San Francisco	California	869994423381814749	b5a0a3bd0c3995c50cc11669f90c3445	Discover	37.7608246183939968	-122.425965179539119
32122	2020-06-20 20:26:11	2020-06-20	Rolla Mueller-Deckow	rolla.mueller.deckow@woohoo.com	Dallas	Texas	869908377653859193	001b4e86ab532d2d0a4dff2c374130cf	JCB 16 digit	32.7850372511699817	-96.6731655918024444
32123	2020-06-20 20:37:46	2020-06-20	Judson Bradtke	judson.bradtke@geemail.com	Warren	Michigan	52327837769474223	b9116803b11fee3b1f2bca3ef396251d	Maestro	42.4829648060254712	-83.0983018367551267
32124	2020-06-20 20:53:00	2020-06-20	Wilma McKenzie-Fay	wilma.mckenzie.fay@geemail.com	San Bernardino	California	3528945416423511555	f63c308b037eb74a712fe7d5b515f279	JCB 15 digit	34.1268375869639158	-117.293660646655042
32125	2020-06-20 20:54:37	2020-06-20	Gustie Kshlerin	gustie.kshlerin@warmmail.com	Huntington Beach	California	3337632484568137741	dbef54cb0013e4c4ddac53477c7b7c9c	Voyager	33.7642904927529415	-118.030838328425958
32126	2020-06-20 20:56:26	2020-06-20	Aloys Stracke	aloys.stracke@geemail.com	Tulsa	Oklahoma	4818397670157280	dfeaa43bc32151af4a73deea59674910	JCB 16 digit	36.1013313324093801	-95.8875425597142339
32127	2020-06-20 21:00:17	2020-06-20	Lavern McGlynn	lavern.mcglynn@geemail.com	Providence	Rhode Island	630412056271716	4f373a7552b0fae798ef18e0ca679c3a	Discover	41.760931129925325	-71.369256951092936
32128	2020-06-20 21:12:37	2020-06-20	Dr. Ennis Waelchi	dr.ennis.waelchi@geemail.com	Memphis	Tennessee	869939793367003089	26135b4589e8d8f29b70e94e294fe480	VISA 13 digit	35.0645037881631438	-90.0550215395424516
32129	2020-06-20 21:13:19	2020-06-20	Yael Blick	yael.blick@warmmail.com	Moreno Valley	California	3400418733817567	49e1111dff912ad511166e28ca0cdb69	JCB 16 digit	33.8717489886090135	-117.183713232909142
32130	2020-06-20 21:36:34	2020-06-20	Brooks Weber II	brooks.weber.ii@geemail.com	Cincinnati	Ohio	869982860235423553	13f73d48114413d4364d23fdaa28d70f	Diners Club / Carte Blanche	39.1346125271402272	-84.5597368027355429
32131	2020-06-20 21:37:06	2020-06-20	Shawnna Rolfson	shawnna.rolfson@geemail.com	El Paso	Texas	4545514127115543	a6f58c3d5459140523fac2be8185f7aa	JCB 16 digit	31.8514061410274358	-106.491680862473331
32132	2020-06-20 21:46:04	2020-06-20	Lynn Trantow	lynn.trantow@geemail.com	Milwaukee	Wisconsin	503854166111887	68404de60cb9c2bd3dada404a3f3bf1e	VISA 16 digit	43.0262725713748466	-87.9153157539300594
32133	2020-06-20 21:46:40	2020-06-20	Dr. Tory Yost	dr.tory.yost@warmmail.com	San Francisco	California	3158996829454610526	c9da562bf41ee5d10e4cfa2ff754c822	JCB 16 digit	37.76168840691507	-122.446101561660441
32134	2020-06-20 21:47:29	2020-06-20	Alivia Hartmann	alivia.hartmann@geemail.com	Sacramento	California	4666547228187	558402a278d56fb4bda138418c8014e8	VISA 13 digit	38.5256250832494374	-121.424662561878932
32135	2020-06-20 21:48:12	2020-06-20	Demonte Balistreri	demonte.balistreri@geemail.com	Los Angeles	California	3022960535220274	c8e1c858f22308e2ad0c9b7654a03159	American Express	34.0845568138040562	-118.418779130418969
32136	2020-06-20 21:55:08	2020-06-20	Tarsha Schulist	tarsha.schulist@geemail.com	San Francisco	California	210039857640115836	823f5e3d6916f93c5377d608ef3457a4	Mastercard	37.7919158082634965	-122.437545805566558
32137	2020-06-20 21:57:31	2020-06-20	Lexis Emmerich	lexis.emmerich@geemail.com	Berkeley	California	6011554344315707580	095f7608931c6a03f07050f30b04decd	Discover	37.8748378921052549	-122.279588380848196
32138	2020-06-20 21:58:32	2020-06-20	Rudy Breitenberg	rudy.breitenberg@woohoo.com	Albuquerque	New Mexico	3337774217586779385	4cdbacf9df2b77ea31bb94edc39a6fdc	Discover	35.0919563557155456	-106.66469050334544
32139	2020-06-20 22:05:25	2020-06-20	Yadira Luettgen	yadira.luettgen@geemail.com	Fort Lauderdale	Florida	6011656192771542869	1ae6e23bcb1db6e1339670b8e88b1984	Discover	26.2023726230010396	-80.1504332395557242
32140	2020-06-20 22:06:05	2020-06-20	Aldo Tromp-D'Amore	aldo.tromp.d'amore@geemail.com	Oxnard	California	4522997872571449	05bbcaa64040c5f78e2353433bd027bf	VISA 13 digit	34.293755648187549	-119.208718208820002
32141	2020-06-20 22:07:44	2020-06-20	Dr. Shavonne McDermott PhD	dr.shavonne.mcdermott.phd@geemail.com	San Francisco	California	52791941895809828	54d5a6824ea344a9ab0ccf2ea47929d5	JCB 15 digit	37.781718341031187	-122.411174135588979
32142	2020-06-20 22:08:58	2020-06-20	Dr. Wardell Baumbach	dr.wardell.baumbach@geemail.com	Indianapolis	Indiana	3158006968624486975	5d10cb9dd184300a4af1519a18aeb632	Discover	39.7700533411473032	-86.1462891477361268
32143	2020-06-20 22:11:24	2020-06-20	Tamara O'Connell	tamara.o'connell@warmmail.com	Carrollton	Texas	4240194368108	5626e443a147e9acd38a6d52eac5a4d9	Mastercard	33.0200820030566291	-96.8650992258779695
32144	2020-06-20 22:23:01	2020-06-20	Lesta Deckow PhD	lesta.deckow.phd@geemail.com	San Francisco	California	180041958534449467	d190194f5db5fd50d86098a53a7310d7	VISA 13 digit	37.8015169570832441	-122.437583646047159
32145	2020-06-20 22:28:05	2020-06-20	Gauge Gulgowski	gauge.gulgowski@warmmail.com	Aurora	Colorado	589344449665197	db2f812cf84c3ef975823bf80c16d299	Mastercard	39.7632839645370879	-104.662169146223746
32146	2020-06-20 22:35:12	2020-06-20	Mr. Moody Ullrich	mr.moody.ullrich@warmmail.com	New York	New York	4287998299610252	ba228060ece1fc9d20857016d4f88c4b	Mastercard	40.7400332242939598	-73.9089302722725989
32147	2020-06-20 22:41:01	2020-06-20	Jaycie Pollich	jaycie.pollich@geemail.com	Laredo	Texas	3158210349989366833	a82c9ebdceb3131c1e2e09a6b9218589	Voyager	27.5905647867076098	-99.3945929932415453
32148	2020-06-20 22:42:57	2020-06-20	Maegan Treutel	maegan.treutel@geemail.com	San Francisco	California	3052429899819402	005e67603c1365ee9f83432c3deb06f3	VISA 13 digit	37.8028363498374702	-122.429848172714571
32149	2020-06-20 22:46:02	2020-06-20	Dulce Legros	dulce.legros@woohoo.com	New York	New York	210083733138740333	ee502f30849cf35df1d4a8822dd83621	Mastercard	40.689719819579274	-73.8520115405216728
32150	2020-06-20 22:48:54	2020-06-20	Margery Jenkins	margery.jenkins@woohoo.com	San Antonio	Texas	3446760952695216	da2b009a1db315314abd1032a7f387fa	Voyager	29.4810479054298256	-98.4974964379634628
32151	2020-06-20 23:17:35	2020-06-20	Dr. Rosemarie Schultz	dr.rosemarie.schultz@warmmail.com	Oklahoma City	Oklahoma	4151762432507566	1585474846e83d5c05be0d909d51a71f	Maestro	35.3766546383410727	-97.533835902194312
32152	2020-06-20 23:33:39	2020-06-20	Marcy Shields DDS	marcy.shields.dds@geemail.com	San Francisco	California	3096716770158505506	0ce6d90e8d667b59e90b1aa0c3ddac26	VISA 13 digit	37.7899292485034479	-122.429400474132819
32153	2020-06-20 23:35:27	2020-06-20	Audriana Bergnaum	audriana.bergnaum@geemail.com	Chula Vista	California	3158950167772527740	e5002b18b563ef2b0914480345d56386	JCB 16 digit	32.5677749756954569	-117.077997675980242
32154	2020-06-20 23:41:09	2020-06-20	Adeline Parker	adeline.parker@geemail.com	Garland	Texas	4990716873902186	7b60597659d4c1741220b775c3868630	VISA 16 digit	32.8960165804486664	-96.6478547563005321
32155	2020-06-21 00:13:12	2020-06-21	Rodney West	rodney.west@geemail.com	San Jose	California	52155504135733529	d3fc327bb3dcf362c2c6acc3ede866cb	JCB 16 digit	37.2820343847673428	-121.918442848579588
32156	2020-06-21 00:33:22	2020-06-21	Dr. Otis Weber	dr.otis.weber@warmmail.com	New York	New York	3465496079703791	1b957b2ff4d4e4b338721cb36120cfe1	VISA 13 digit	40.6783823569528735	-74.0372646132845347
32157	2020-06-21 00:36:14	2020-06-21	Sharonda DuBuque-Schinner	sharonda.dubuque.schinner@warmmail.com	New York	New York	3422679445404036	808085dae02c2f4c918c9671e693bdc6	JCB 16 digit	40.7289062324669189	-73.8995730479609136
32158	2020-06-21 00:44:53	2020-06-21	Willie Anderson	willie.anderson@geemail.com	New York	New York	6011853495563917129	7993a22b30175c322413eac5123d0b62	American Express	40.6968608298096797	-73.8509233320958884
32159	2020-06-21 00:44:58	2020-06-21	Beckham Wolf	beckham.wolf@geemail.com	Irving	Texas	869922168629612986	acb72f681130ae97b36dadac900d0075	Discover	32.7904015573624505	-96.8806593099422741
32160	2020-06-21 00:51:42	2020-06-21	Mitchell Parisian	mitchell.parisian@woohoo.com	Cincinnati	Ohio	3011673449661712	4b0138e6c6c64fbeb93b19ac6ff6da06	Mastercard	39.1004386974729599	-84.4665885423116265
32161	2020-06-21 00:55:07	2020-06-21	Miss Madisen Tillman	miss.madisen.tillman@geemail.com	Sandy Springs	Georgia	3757605335334114	04fc2ed29765993dac41c4ee05772e5e	Discover	34.0088819744586957	-84.3081749535247695
32162	2020-06-21 00:59:32	2020-06-21	Gwyn Stracke-McKenzie	gwyn.stracke.mckenzie@geemail.com	Seattle	Washington	4447671436460	a213117fc881dff3b5efef52e13c920a	Diners Club / Carte Blanche	47.6643330138567833	-122.394364094540094
32163	2020-06-21 01:00:30	2020-06-21	Ananias Beer	ananias.beer@geemail.com	Minneapolis	Minnesota	676308336052439	fb95e18fe07e92bfa17f217dfb9510c5	JCB 15 digit	44.9324549747716588	-93.2568143821593338
32164	2020-06-21 01:04:22	2020-06-21	Zakary McGlynn	zakary.mcglynn@warmmail.com	New York	New York	060461350811867	b4c2f65b6e4b03876c272765d0af5581	Voyager	40.6803124915566272	-74.0305231336399885
32165	2020-06-21 01:12:10	2020-06-21	Brandee Corwin-Bednar	brandee.corwin.bednar@geemail.com	Boston	Massachusetts	561223559044021	ae6548e6b0e1a51798c28f0ba2479a70	JCB 16 digit	42.4195922190025456	-71.1067294642746504
32166	2020-06-21 01:12:49	2020-06-21	Ruthanne Carter	ruthanne.carter@warmmail.com	Chicago	Illinois	4076212876106	0852533ed4f7f6a358cb2a884441caac	American Express	41.763835599722718	-87.6238738602988434
32167	2020-06-21 01:16:35	2020-06-21	Ivey Nitzsche Sr.	ivey.nitzsche.sr.@geemail.com	San Francisco	California	4172613662033267	2f0c401be3b90ef92c9de2ac833a7da3	Discover	37.7799895816839921	-122.450676279713846
32168	2020-06-21 01:23:34	2020-06-21	Ms. Dorinda Walker	ms.dorinda.walker@geemail.com	Berkeley	California	3048079951768726	243fa8cd7d5efaed60da8d8de4786b6b	JCB 16 digit	37.8857520764500251	-122.28849464188481
32169	2020-06-21 01:31:09	2020-06-21	Ms. Lugenia Murphy MD	ms.lugenia.murphy.md@geemail.com	Killeen	Texas	3773317615831179	0eee53771616dc5970646741077a33fb	JCB 16 digit	31.1547544228143991	-97.8138572808057063
32170	2020-06-21 01:37:35	2020-06-21	Collins Wunsch	collins.wunsch@woohoo.com	Frisco	Texas	3005128736699533	3304f01963f93aae6d527927c88c560d	American Express	33.0829080354418608	-96.84070231837444
32171	2020-06-21 01:50:50	2020-06-21	Ms. Cortney Collins	ms.cortney.collins@geemail.com	San Francisco	California	3088412842895421995	c696e2fee10c16525ebf608a787f430a	Mastercard	37.777621046079652	-122.431946394710451
32172	2020-06-21 01:55:28	2020-06-21	Dr. Rhett Murray III	dr.rhett.murray.iii@geemail.com	Oakland	California	52949020790359022	9330c48669fa9fb6df7995eac3c16c6f	Discover	37.823461595589599	-122.254911410162549
32173	2020-06-21 02:01:38	2020-06-21	Drew Howell	drew.howell@geemail.com	Philadelphia	Pennsylvania	3049779328696299	9385259739e14671afd4c530551b1840	Diners Club / Carte Blanche	40.056726791379603	-75.2019744960490613
32174	2020-06-21 02:23:26	2020-06-21	Antonio D'Amore	antonio.d'amore@geemail.com	Fort Worth	Texas	869953838721986973	34928bd92e63a4e8474b9474236caced	JCB 16 digit	32.873191948985685	-97.364598184573282
32175	2020-06-21 02:32:55	2020-06-21	Dr. Jajuan Reynolds	dr.jajuan.reynolds@geemail.com	Midland	Texas	6011615373978333928	5828722341146006d1fcc9f2080e0d2e	American Express	32.045138166444751	-102.037483260430392
32176	2020-06-21 02:37:50	2020-06-21	Mr. Ozie Schuppe	mr.ozie.schuppe@woohoo.com	Richmond	Virginia	4448368947127917	0d23ac7f753f0ab579c98812c6092dd3	VISA 16 digit	37.5868056655615561	-77.5089351242631608
32177	2020-06-21 02:38:37	2020-06-21	Brooklyn Ryan	brooklyn.ryan@geemail.com	Saint Paul	Minnesota	3037559454559095	c30021ab3f00e1f587709d96e16ce1cd	JCB 16 digit	45.0210362023614366	-93.0763990431357229
32178	2020-06-21 02:50:30	2020-06-21	Mrs. Estell Dickinson	mrs.estell.dickinson@geemail.com	Berkeley	California	3034301894912276	0d2fb492795ca1b2cdb6706a17ab7758	American Express	37.8696733519711444	-122.265828991485805
32179	2020-06-21 02:51:30	2020-06-21	Miss Asha Johnson	miss.asha.johnson@warmmail.com	Allentown	Pennsylvania	6011308530772327107	4f813eedf34e8752c906b3ea4818c045	American Express	40.5053340473923882	-75.5573756099693412
32180	2020-06-21 02:51:56	2020-06-21	Mrs. Gussie Hammes	mrs.gussie.hammes@geemail.com	New York	New York	3029705362550472	41fe7d9b7d15daec0fa1e053b9b95011	VISA 16 digit	40.7620485323239095	-73.9036883742444246
32181	2020-06-21 02:54:03	2020-06-21	Orma Frami	orma.frami@woohoo.com	High Point	North Carolina	210008182324311289	595d4837194ee7028b3a8e03c89dbc0e	JCB 16 digit	36.0297265771403943	-79.9447624931316767
32182	2020-06-21 03:05:20	2020-06-21	Mr. Franklyn Borer I	mr.franklyn.borer.i@geemail.com	Phoenix	Arizona	3746079209756311	1eab316e0fb92c6b0c7cfd2ccb673e22	JCB 16 digit	33.4732791311040572	-112.077867463782809
32183	2020-06-21 03:08:29	2020-06-21	Mr. Rafael Conroy IV	mr.rafael.conroy.iv@geemail.com	Oakland	California	6011169772937098151	9292693dab5ee255878cab12a5e0387b	Voyager	37.8148895028441672	-122.272903477560234
32184	2020-06-21 03:09:18	2020-06-21	Aloys Sporer-King	aloys.sporer.king@geemail.com	San Francisco	California	3158085560757443883	a0387063dde862014b8163dcbe8a1a5d	Voyager	37.7644862738686555	-122.429058943366172
32185	2020-06-21 03:09:45	2020-06-21	Dr. Katelin Weimann	dr.katelin.weimann@woohoo.com	Murfreesboro	Tennessee	4948162092864241	c1d4c3f053e758857b4356a4d0746103	JCB 16 digit	35.8108732107680297	-86.513011796943843
32186	2020-06-21 03:12:48	2020-06-21	Mr. Wardell Heller	mr.wardell.heller@geemail.com	Lubbock	Texas	6011720768069134287	df66887fe830bb87977fdc2bbd7ddda1	VISA 16 digit	33.6043409106828292	-101.826173821222781
32187	2020-06-21 03:13:26	2020-06-21	Theta Hermiston	theta.hermiston@geemail.com	San Diego	California	6011479360842101925	bd757c9c59253b9710bfd0a54c068ff3	Diners Club / Carte Blanche	32.764309950598701	-117.066762782717134
32188	2020-06-21 03:14:07	2020-06-21	Damien Marvin	damien.marvin@warmmail.com	Des Moines	Iowa	4287346131306	ba89af91a6b52c18e7347b28c148bc14	Discover	41.6160625085908933	-93.6528538667641612
32189	2020-06-21 03:16:46	2020-06-21	Dr. Shaniece Schimmel	dr.shaniece.schimmel@warmmail.com	Greensboro	North Carolina	3719820801202912	9926f0292db8904b9ebfe830b6e23718	VISA 16 digit	35.9992807798203103	-79.7419387982208292
32190	2020-06-21 03:21:20	2020-06-21	Mrs. Caleigh Terry	mrs.caleigh.terry@geemail.com	Lexington	Kentucky	180001416378422189	dbb9c34cc78ca9c29edbaa596fc3161d	VISA 13 digit	37.9996867377188039	-84.4564353440321867
32191	2020-06-21 03:22:22	2020-06-21	Mr. Bethel Wolff V	mr.bethel.wolff.v@warmmail.com	Austin	Texas	4829207415065275	c61174c8c7017b03791a8ca6ebcb8fed	JCB 16 digit	30.3955663400828833	-97.7296677479758955
32192	2020-06-21 03:43:58	2020-06-21	Jaylin Ledner	jaylin.ledner@geemail.com	Albuquerque	New Mexico	3158367231403133653	5142da8959ef254698e4617ed561b629	Maestro	35.0885964777920449	-106.641158047558378
32193	2020-06-21 03:51:12	2020-06-21	Rosemarie Christiansen	rosemarie.christiansen@geemail.com	New York	New York	3030676332550034	6225a1e398f73c319166f94c9cedd6c8	Maestro	40.7468880216348879	-73.9191912124760364
32194	2020-06-21 03:54:50	2020-06-21	Angelina Ebert	angelina.ebert@geemail.com	Fresno	California	3088616256402570935	e6960b4a7b4620b8e81d86c63373c966	Maestro	36.7321730249434708	-119.85489523416534
32195	2020-06-21 04:06:54	2020-06-21	Lamar Cronin	lamar.cronin@geemail.com	Fort Worth	Texas	55198105642686272	dd51d1971431589900001bc757aa031a	Mastercard	32.7097083936966939	-97.3660572831340119
32196	2020-06-21 04:13:33	2020-06-21	Denisse Halvorson	denisse.halvorson@geemail.com	New York	New York	3337294078407306324	a76cc802c92d4cd3863fa21bcd185d1a	Maestro	40.5899564744196795	-73.9443009768042714
32197	2020-06-21 04:32:18	2020-06-21	Ilah Koepp	ilah.koepp@geemail.com	South Bend	Indiana	3024334428102023	25add261db0a2a71ae1fd41a32cabe34	VISA 16 digit	41.7458073904883165	-86.3516772514265085
32198	2020-06-21 04:41:18	2020-06-21	Dr. Ambrose O'Hara PhD	dr.ambrose.o'hara.phd@geemail.com	Houston	Texas	4974492625757	527688d017dcd76977b28e38c1b7fa8d	Discover	29.732458912775293	-95.4745854836437928
32199	2020-06-21 04:43:04	2020-06-21	Mr. Jorge Mohr DDS	mr.jorge.mohr.dds@warmmail.com	Atlanta	Georgia	6011789390565356799	a4051366c9660d17f45651bee0031a08	Mastercard	33.6693005903434042	-84.4045746329750983
32200	2020-06-21 04:48:16	2020-06-21	Dr. Golda Lowe MD	dr.golda.lowe.md@geemail.com	Lakewood	New Jersey	3051535632419390	d9740743e8bd0c6760ad285ad1a0dcb7	JCB 15 digit	40.0836621360670762	-74.2898697631709268
32201	2020-06-21 04:50:41	2020-06-21	Sabrina Pfeffer-Baumbach	sabrina.pfeffer.baumbach@woohoo.com	New York	New York	4939308062468429	470276c60639e3524c7b2a7f3696dabe	Voyager	40.6120608585644476	-73.8418104891560887
32202	2020-06-21 04:56:42	2020-06-21	Miss Desiree Daniel MD	miss.desiree.daniel.md@geemail.com	South Bend	Indiana	4471057974477291	30e2efc12c60ad37f22c2a51cfb09229	JCB 15 digit	41.6379046620015103	-86.3502127498909857
32203	2020-06-21 05:08:38	2020-06-21	Newt Hagenes	newt.hagenes@geemail.com	New York	New York	3088411546930162164	032de8cd9567e0e477485726d4cd4f72	Maestro	40.7259607837758963	-73.8690671786095976
32204	2020-06-21 05:09:53	2020-06-21	Nelie Bauch	nelie.bauch@geemail.com	New York	New York	675993925179363	ce278fe683a245aa1c9970e2cc46424a	JCB 15 digit	40.5732336518112575	-73.8822666844714462
32205	2020-06-21 05:12:52	2020-06-21	Lyndon Fahey	lyndon.fahey@warmmail.com	Sioux Falls	South Dakota	675979773340611	ec07901b6190bb8753c043885766bda1	Voyager	43.4571071998767522	-96.7952007007487083
32206	2020-06-21 05:13:06	2020-06-21	Gregoria Fisher	gregoria.fisher@woohoo.com	Providence	Rhode Island	6011302640795235850	a6b9d1d97b1b62b01a70d7b86ceb1358	JCB 15 digit	41.8105702380038764	-71.3726071278482692
32207	2020-06-21 05:16:04	2020-06-21	Golden Dare	golden.dare@geemail.com	Mesa	Arizona	4706592943399900	f6ad7f844ce19aac46ee7adb2f2e8b62	JCB 16 digit	33.3561444226332	-111.682517903705687
32208	2020-06-21 05:19:26	2020-06-21	Luda Wiza	luda.wiza@geemail.com	Worcester	Massachusetts	3783053872530588	522a01bd6e795209345e2adcdd395e1f	VISA 16 digit	42.3085003030188389	-71.7311085312414889
32209	2020-06-21 05:23:01	2020-06-21	Kyler Balistreri	kyler.balistreri@geemail.com	Providence	Rhode Island	180075069607831224	98fb94f9fab4c25403870febed7f89cc	American Express	41.8226124312583352	-71.3892349127132491
32210	2020-06-21 05:30:01	2020-06-21	Gladys Kilback	gladys.kilback@woohoo.com	Cape Coral	Florida	3700301645285307	3c6da7530ece01584e9f1347601e00a7	JCB 16 digit	26.7165862804248917	-81.9575936148013966
32211	2020-06-21 05:30:52	2020-06-21	Branch Hamill	branch.hamill@geemail.com	Milwaukee	Wisconsin	4044954090144292	77e569b4a101790434b2a18facab15bc	Mastercard	43.1436450135048446	-87.9698318347435446
32212	2020-06-21 05:33:55	2020-06-21	Dr. Tandy Adams	dr.tandy.adams@warmmail.com	San Bernardino	California	4895241197070566	f0229a6189f6ee68da96f0739e5c8ffb	JCB 16 digit	34.0791916158314763	-117.366134370236097
32213	2020-06-21 05:39:29	2020-06-21	Mrs. Kimberley Glover	mrs.kimberley.glover@woohoo.com	Bakersfield	California	4591604853943	0a28edb6307c2f665d638a299c2add1f	Voyager	35.3071114552382355	-119.092695015696066
32214	2020-06-21 05:43:14	2020-06-21	Holland Stanton	holland.stanton@warmmail.com	Oakland	California	4083149875337086	eba832ef5f2aea586c66dff98fe27266	VISA 13 digit	37.8384444836682192	-122.265480823156452
32215	2020-06-21 05:45:17	2020-06-21	Dr. Delma Emmerich	dr.delma.emmerich@geemail.com	Tucson	Arizona	3056114056033031	5cb50b6895ee1a689147536761d42c52	JCB 15 digit	32.1135570055846173	-110.81775669131838
32216	2020-06-21 05:46:03	2020-06-21	Tyreke Dibbert	tyreke.dibbert@geemail.com	Louisville	Kentucky	630452138601084	f93718acf1ef298d5e9aa41945012324	JCB 16 digit	38.1546470709979531	-85.6160671015806543
32217	2020-06-21 05:50:25	2020-06-21	Karlee Heidenreich PhD	karlee.heidenreich.phd@geemail.com	Houston	Texas	3112790223828806580	cc47db1f1d1a23112416be9cb097d23c	JCB 16 digit	29.8628729994952664	-95.3021343391403519
32218	2020-06-21 05:54:31	2020-06-21	Jeffrey Hamill MD	jeffrey.hamill.md@woohoo.com	Evansville	Indiana	210001721394629521	29d13ade20967e0b921a68f5a1e5b2be	VISA 16 digit	38.0479926607243684	-87.626252095208315
32219	2020-06-21 06:01:36	2020-06-21	Candida Schuppe	candida.schuppe@geemail.com	San Diego	California	3158794288337130554	40644675c664343dbc7a0198d93e5b79	JCB 15 digit	32.7411353510871521	-117.102681285319861
32220	2020-06-21 06:10:32	2020-06-21	Mr. Lewis Mann	mr.lewis.mann@warmmail.com	Salt Lake City	Utah	55906325631308547	2d4f3de577cec5309022a0495995a33e	Voyager	40.8433850261993712	-111.862701243715364
32221	2020-06-21 06:14:29	2020-06-21	Merlene Abbott-Sauer	merlene.abbott.sauer@woohoo.com	Los Angeles	California	869904581822435397	52741d399d3ceb5d82d685e5ab331d8e	JCB 16 digit	34.0562906809948345	-118.340092131587852
32222	2020-06-21 06:14:32	2020-06-21	Ms. Loris Klocko DVM	ms.loris.klocko.dvm@geemail.com	Oakland	California	3337415254684515606	cd9d45b5f55e7ba89fd5542a98f3d29f	Mastercard	37.8223501171028715	-122.278554898384769
32223	2020-06-21 06:22:51	2020-06-21	Vergie Gerlach	vergie.gerlach@geemail.com	Tucson	Arizona	3528804721975732115	8303e8b332b40a45fe8ac3cd57b187e0	Diners Club / Carte Blanche	32.2425390285015112	-110.865732381469002
32224	2020-06-21 06:26:11	2020-06-21	Gennaro Von III	gennaro.von.iii@geemail.com	Garden Grove	California	4402515676681282	511131400f60c81573f12e17752cc4c5	Diners Club / Carte Blanche	33.8164505635213075	-117.922330618092786
32225	2020-06-21 06:30:22	2020-06-21	Mrs. Rochelle Pfeffer PhD	mrs.rochelle.pfeffer.phd@geemail.com	Irving	Texas	3020564431221626	4f5ce614804fba7884c5675f0743f3dd	JCB 16 digit	32.7808789754237964	-97.0370324417762475
32226	2020-06-21 06:36:55	2020-06-21	Leilani Schaden	leilani.schaden@geemail.com	Memphis	Tennessee	501831252365577	f92789a5e627f9f2485fc46a995114a1	JCB 15 digit	35.0990528372183448	-89.9874495236925753
32227	2020-06-21 06:39:02	2020-06-21	Dollie Senger PhD	dollie.senger.phd@geemail.com	New York	New York	210039800472808037	1f970eee05b8eea5584f40a08cb2dcf5	JCB 15 digit	40.7194109589084974	-73.9639873489633146
32228	2020-06-21 06:40:15	2020-06-21	Dr. Deward Rempel MD	dr.deward.rempel.md@geemail.com	Aurora	Colorado	6011068448692810245	7d20ee06b59a2093bb32688466ac4e07	Voyager	39.6499071493856619	-104.656155994732686
32229	2020-06-21 06:43:33	2020-06-21	Jeffry Bashirian	jeffry.bashirian@geemail.com	New York	New York	3028458027417924	132a10fa5a99dc8ba1cadde6fbbfc98d	American Express	40.7547315193098001	-73.984799196886641
32230	2020-06-21 06:44:34	2020-06-21	Brandee Ratke	brandee.ratke@geemail.com	San Francisco	California	54085574243259647	54cdd20ff55c2e18b490b112cfef8f88	VISA 16 digit	37.740900761967211	-122.399793967072938
32231	2020-06-21 06:46:23	2020-06-21	Dr. Damaris Prosacco	dr.damaris.prosacco@woohoo.com	Fort Worth	Texas	3088914289806698597	c77acdc773fdc851009cbd07e5f77dca	American Express	32.8745905133951482	-97.4312128209330126
32232	2020-06-21 06:51:16	2020-06-21	Edd Leuschke	edd.leuschke@geemail.com	San Francisco	California	3420276420183180	983d2d8f6ff08e549a7fa5a0c4bff190	Diners Club / Carte Blanche	37.7604323735143055	-122.468728031612471
32233	2020-06-21 07:13:31	2020-06-21	Mr. Damion Fay I	mr.damion.fay.i@geemail.com	Fresno	California	869925974461588391	79dd96a56001092ae62510d5816d8ef4	VISA 16 digit	36.8771944700613616	-119.84942892953903
32234	2020-06-21 07:22:31	2020-06-21	Kenneth Tromp	kenneth.tromp@geemail.com	Louisville	Kentucky	869953340059391389	0491a7e80b2b4dbb1ef2f9e0090340b3	Maestro	38.066555667891727	-85.6975276420895113
32235	2020-06-21 07:23:53	2020-06-21	Dr. Jessy Thompson	dr.jessy.thompson@geemail.com	San Jose	California	3049010677752289	90b60e9fdcd1139243c05ea9b62e6de8	JCB 16 digit	37.3377353735089343	-121.748313141170513
32236	2020-06-21 07:36:09	2020-06-21	Mrs. Valentine Raynor DVM	mrs.valentine.raynor.dvm@geemail.com	Topeka	Kansas	3035469371134604	2af2c67739e196f44cbad132507fb7e1	JCB 16 digit	39.0684788246572055	-95.5966503431729961
32237	2020-06-21 07:51:48	2020-06-21	Lorelei Franecki	lorelei.franecki@geemail.com	Glendale	Arizona	4102331115918746	f4a3c4727262fa2385fa4280e32e97bb	Discover	33.6141230173170555	-112.120946444224188
32238	2020-06-21 07:53:49	2020-06-21	Carleton Gaylord-Lang	carleton.gaylord.lang@geemail.com	Berkeley	California	869958051769103379	483c96681ee8138fa5992e11d37d16b2	Diners Club / Carte Blanche	37.8703946097485655	-122.27624907304083
32239	2020-06-21 07:59:13	2020-06-21	Esteban Dickens-Bergnaum	esteban.dickens.bergnaum@geemail.com	Vallejo	California	4692410246544	b5949dddfa1be60dfd5136a3c0c3bccd	VISA 13 digit	38.0393077401999378	-122.304304660750546
32240	2020-06-21 08:05:05	2020-06-21	Seneca Parisian-Shields	seneca.parisian.shields@geemail.com	Tuscaloosa	Alabama	3112502788692800090	acb74191a6c00cba137f4d2541bb32d5	JCB 16 digit	33.2252174216844125	-87.4460112067036306
32241	2020-06-21 08:06:03	2020-06-21	Miss Charlene Herzog MD	miss.charlene.herzog.md@geemail.com	Escondido	California	3112212963100953028	92a09ca4545efcc98b51c4fa4f8c41f7	American Express	33.1393528587877739	-117.054243014777072
32242	2020-06-21 08:10:29	2020-06-21	Sophronia Haley DDS	sophronia.haley.dds@geemail.com	Bakersfield	California	503849037791719	875e08d870350337d88d0a3356ef0b03	JCB 16 digit	35.3542729425419111	-119.081086305090409
32243	2020-06-21 08:11:43	2020-06-21	Boris Roob	boris.roob@geemail.com	Portland	Oregon	4682922072833627	243a99ad4fa6b54d3c55b049864f54dc	Diners Club / Carte Blanche	45.4433372355420104	-122.55361738614738
32244	2020-06-21 08:15:55	2020-06-21	Tessie Macejkovic MD	tessie.macejkovic.md@woohoo.com	Oklahoma City	Oklahoma	210033703706659273	a3a935fa6a2b89a9ba330af2deebeca4	Mastercard	35.4279672929462066	-97.4243141736265272
32245	2020-06-21 08:15:59	2020-06-21	Ferd Blanda	ferd.blanda@geemail.com	Tempe	Arizona	3772114936457060	7493687283b33d827ed56af6a09dad73	JCB 15 digit	33.3849097686741487	-111.847094863423322
32246	2020-06-21 08:17:24	2020-06-21	Sondra Hartmann	sondra.hartmann@geemail.com	Scottsdale	Arizona	4019135835940	26c51c2592d299061231f471528e07f3	JCB 15 digit	33.6239953695919382	-111.885221916247531
32247	2020-06-21 08:24:15	2020-06-21	Franklin Nikolaus	franklin.nikolaus@geemail.com	San Francisco	California	53112096572111741	749c7295ee715c96178f4657509bfd27	American Express	37.7747052105802936	-122.398487358453039
32248	2020-06-21 08:43:22	2020-06-21	Mr. Donat Hilpert	mr.donat.hilpert@geemail.com	Vacaville	California	4342443736714196	e11fe05498d7f19ed72eb45697dec28a	JCB 16 digit	38.3623153627045497	-121.899515609012184
32249	2020-06-21 08:48:58	2020-06-21	Evander Marks IV	evander.marks.iv@woohoo.com	Newark	New Jersey	4749039830009522	ec08fc8227118f578e81cde3c177c9d9	VISA 16 digit	40.6312642892736946	-74.0783400251738726
32250	2020-06-21 09:03:54	2020-06-21	Mrs. Ermine Raynor DVM	mrs.ermine.raynor.dvm@woohoo.com	Killeen	Texas	3034579385963912	50e6d8bd72883efb33318a4c92937238	Maestro	31.0140014500122518	-97.7126272672489335
32251	2020-06-21 09:11:48	2020-06-21	Lexus Jast	lexus.jast@geemail.com	Elgin	Illinois	3112245413271661100	d5b5868f05c23839788ee46b8d361ca5	JCB 15 digit	42.0374919904679061	-88.3601926989208977
32252	2020-06-21 09:12:50	2020-06-21	Jerad Welch DDS	jerad.welch.dds@geemail.com	Charlotte	North Carolina	675961339551972	7a3f6a91a9c016db3ab44ed15e88828e	Mastercard	35.1337766771923725	-80.8648577026035724
32253	2020-06-21 09:18:23	2020-06-21	Linna Jakubowski	linna.jakubowski@woohoo.com	Miramar	Florida	869954127508567522	4aee51215d8569ca20e1a53520f560c2	Discover	26.0490642879139642	-80.2800999895662102
32254	2020-06-21 09:35:27	2020-06-21	Pamelia Becker	pamelia.becker@warmmail.com	Providence	Rhode Island	4995063342886	0a4d26248e011c2c7d24dc503f70eba5	VISA 13 digit	41.7660277782794083	-71.5137065579101545
32255	2020-06-21 09:38:41	2020-06-21	Tanika Kihn	tanika.kihn@geemail.com	Corona	California	6011415268898710977	c586f29f84a72c0564d2ae80fde82f8b	Diners Club / Carte Blanche	33.9551310108397146	-117.545661172430968
32256	2020-06-21 09:48:32	2020-06-21	Pinkney Brown	pinkney.brown@woohoo.com	Worcester	Massachusetts	210076611622751918	8f16cf4d0f1e73932c62e9636c57c638	VISA 13 digit	42.2342746711503736	-71.8995077800724687
32257	2020-06-21 09:49:12	2020-06-21	Damond Swaniawski	damond.swaniawski@geemail.com	Minneapolis	Minnesota	4499465102816	94a7f5a14b852491bdc013b2053f09cb	Diners Club / Carte Blanche	44.9099665552929039	-93.3415389909215207
32258	2020-06-21 09:49:56	2020-06-21	Tricia Huels	tricia.huels@geemail.com	New Orleans	Louisiana	3096536921518112024	678b67d43d47dd8c75e4a422290774d9	Voyager	30.1294104821529238	-89.9914666825700493
32259	2020-06-21 09:50:04	2020-06-21	Addisyn Cartwright-Turner	addisyn.cartwright.turner@geemail.com	Los Angeles	California	53785284195515292	37f7fe34cf08927b033265504451eed0	VISA 16 digit	33.954210484759507	-118.471588652254269
32260	2020-06-21 09:50:14	2020-06-21	Christal Abernathy	christal.abernathy@geemail.com	New York	New York	3096388759811374159	ecd9062e7bb6561865f0b775b746effe	Diners Club / Carte Blanche	40.6723116577826431	-74.032394461183614
32261	2020-06-21 09:50:47	2020-06-21	Shannan Haag	shannan.haag@geemail.com	Lewisville	Texas	3528365784959242833	3c2fd68e4e84d6254d96e8c4258caa80	VISA 16 digit	33.1062457225270563	-96.9862021975249178
32262	2020-06-21 09:51:48	2020-06-21	Clara Reinger PhD	clara.reinger.phd@geemail.com	New York	New York	180055450798134772	bb87d064590ce36114b02bb378ce8479	Maestro	40.6662293306775382	-73.9246933366533341
32263	2020-06-21 09:57:56	2020-06-21	Lolita Hudson	lolita.hudson@geemail.com	Nashville	Tennessee	4867455652549377	3db9f2fff2c7dd6723b34242c1f4f89f	Voyager	36.1626619611058331	-86.7166674469970076
32264	2020-06-21 10:01:19	2020-06-21	Arnett Kuhlman	arnett.kuhlman@geemail.com	Chicago	Illinois	3489502253200983	ec1d5184209d3c33e1c78d48b2d9b378	JCB 16 digit	41.9325285218957831	-87.7729362750455664
32265	2020-06-21 10:16:19	2020-06-21	Cristofer Langosh DVM	cristofer.langosh.dvm@geemail.com	Columbus	Ohio	6011765917122228174	a180ef2f950496fb8dd6a8c5f3c67830	Discover	40.0375734530899692	-82.9429859918776913
32266	2020-06-21 10:16:57	2020-06-21	Gilda Jacobson	gilda.jacobson@warmmail.com	New York	New York	4482411631705502	df52f022834ec49fc245c38bf2dc9e5c	Discover	40.6718352103363685	-74.037311024860287
32267	2020-06-21 10:20:57	2020-06-21	Mat Blick	mat.blick@geemail.com	San Jose	California	180066922237132820	1aff4fef8918cd406cb01867185536ce	VISA 13 digit	37.2639075681854024	-121.815148300466689
32268	2020-06-21 10:22:09	2020-06-21	Louie Emard DVM	louie.emard.dvm@geemail.com	San Francisco	California	3158572553213680107	eaff2e90760630a0cd938b413862b17a	JCB 16 digit	37.791705022558439	-122.431895558991641
32269	2020-06-21 10:24:04	2020-06-21	Reason Rohan	reason.rohan@woohoo.com	Madison	Wisconsin	54015171722577246	093f05ae73044aabe15aa4ec10b7990a	VISA 16 digit	43.0694883927211194	-89.4795014891657985
32270	2020-06-21 10:29:15	2020-06-21	Sumner Hilll	sumner.hilll@geemail.com	North Las Vegas	Nevada	4322613516994317	c5969182ffd5cb8a152f8dab18099697	American Express	36.3832622372701735	-115.13388142122291
32271	2020-06-21 10:31:50	2020-06-21	Nelson Schuppe	nelson.schuppe@geemail.com	Fort Worth	Texas	869930990624339483	410cf1883de2dd1b1cf931b59963cf7c	Voyager	32.7431227567195933	-97.26086060328484
32272	2020-06-21 10:34:27	2020-06-21	Mikala Collier-Harvey	mikala.collier.harvey@geemail.com	San Francisco	California	3096906938227177942	ee373d50e7c65dc0a00d6786292d46b6	VISA 16 digit	37.7442057238288626	-122.435835714947956
32273	2020-06-21 10:39:19	2020-06-21	Eino Lebsack	eino.lebsack@warmmail.com	Peoria	Arizona	3112142319543884830	ee64aef0cc029a4148f7b2e3ecb7e6bf	Discover	33.8837931426044534	-112.347769301796333
32274	2020-06-21 10:44:45	2020-06-21	Jaret Kihn-Frami	jaret.kihn.frami@geemail.com	Los Angeles	California	3528780669416066742	2c3a3cc5afb9671c7e365fdd8d5c9f44	Voyager	34.0886362371366474	-118.504859745920811
32275	2020-06-21 10:45:45	2020-06-21	Attilio Grimes-Steuber	attilio.grimes.steuber@geemail.com	Jersey City	New Jersey	3026826544985445	41727977d14f04847b3eb6a3d3faa09c	VISA 13 digit	40.7250922110803373	-74.0726646828420456
32276	2020-06-21 10:46:34	2020-06-21	Texas Labadie	texas.labadie@geemail.com	Miramar	Florida	630437335157915	6821eef70278166ff48cccfa85b980ca	JCB 15 digit	26.057133752617986	-80.2852915288407445
32277	2020-06-21 10:49:10	2020-06-21	Leandro Hartmann-Bradtke	leandro.hartmann.bradtke@geemail.com	Philadelphia	Pennsylvania	869948897809379152	39dee1aa64d6fd03c0c5a237d9eb4fed	JCB 15 digit	40.0973095402080588	-75.1282280497618018
32278	2020-06-21 10:51:02	2020-06-21	Adolph Hahn-Collier	adolph.hahn.collier@woohoo.com	New York	New York	4162905028916884	321a6f73c29ef294de588beba5b4a9aa	Voyager	40.753868726663292	-73.9856426483847116
32279	2020-06-21 10:52:39	2020-06-21	Alexis Lebsack	alexis.lebsack@geemail.com	Las Vegas	Nevada	4590480791547607	391821ab6c859846a9b6b44d26eed81c	Maestro	36.1788037839446233	-115.190117694877458
32280	2020-06-21 11:06:28	2020-06-21	Ieshia Padberg-Gerlach	ieshia.padberg.gerlach@geemail.com	Orlando	Florida	3528784514306846363	550163d7ac7d3806b3e5d489c3c2d222	VISA 16 digit	28.4951250198096027	-81.3057595044806618
32281	2020-06-21 11:17:53	2020-06-21	Aleck Stokes	aleck.stokes@geemail.com	Nashville	Tennessee	3041583589600463	d1b35c6f1661c9a773f5012747b84999	JCB 16 digit	36.1187831943511952	-86.8433101425785594
32282	2020-06-21 11:18:42	2020-06-21	Nickolas Turner	nickolas.turner@geemail.com	Houston	Texas	3051328895739690	f22dfee7f17c0cd7a3943e2a5e7cd3a0	Discover	29.7873817296311252	-95.4240456276588134
32283	2020-06-21 11:18:43	2020-06-21	Elmyra Yundt MD	elmyra.yundt.md@geemail.com	Sandy Springs	Georgia	6011358193125694183	4032e3c893648f3846c42b0f7a888a4a	Diners Club / Carte Blanche	34.0285267496071739	-84.4606459722470504
32284	2020-06-21 11:28:15	2020-06-21	Hampton Buckridge	hampton.buckridge@geemail.com	Oklahoma City	Oklahoma	54796227019039749	bda5da8ce027d8733853644e2c92a989	VISA 13 digit	35.4924608833532815	-97.5784957363165972
32285	2020-06-21 11:31:46	2020-06-21	Madisen Greenfelder	madisen.greenfelder@woohoo.com	Waterbury	Connecticut	3528285920795195408	f60535e1c9d77eaf5fb361150dfd8983	JCB 15 digit	41.4591186409853449	-73.0260119566142549
32286	2020-06-21 11:40:00	2020-06-21	Vollie Aufderhar	vollie.aufderhar@geemail.com	Clinton	Michigan	4507142203219	c7f557afc9e1783674a24dec0aac8a35	JCB 15 digit	42.5177096046108716	-82.9404832048416125
32287	2020-06-21 11:46:23	2020-06-21	Giovanny Ebert	giovanny.ebert@geemail.com	Santa Maria	California	3096360291006351141	e1ed3b3e3d2ad4c377453131014bd8a2	JCB 16 digit	34.9750688164092622	-120.446274999101831
32288	2020-06-21 11:49:07	2020-06-21	Dr. Sarahi Lueilwitz	dr.sarahi.lueilwitz@geemail.com	New York	New York	4539555664561	6eb37b674da06a32f003dfbdf070ca50	JCB 16 digit	40.7452863006610428	-73.8967300123896393
32289	2020-06-21 11:50:33	2020-06-21	Denzell Dickinson-Blanda	denzell.dickinson.blanda@geemail.com	Tulsa	Oklahoma	180016824986522006	204678aa00e0b7959446c1690783b243	Mastercard	36.209115424276888	-95.8642234955869554
32290	2020-06-21 11:52:13	2020-06-21	Destinee Kilback	destinee.kilback@geemail.com	Ventura	California	3036755748993741	6517a789f3c0c9a935405fe653d12565	American Express	34.3226982806038095	-119.166329891011856
32291	2020-06-21 12:12:43	2020-06-21	Sullivan Walker	sullivan.walker@woohoo.com	Buffalo	New York	4253130103987912	62fdc01202d0916bbd62b967209b2dc1	Diners Club / Carte Blanche	42.917851343117654	-78.9292984520483856
32292	2020-06-21 12:13:45	2020-06-21	Yolonda Runte	yolonda.runte@warmmail.com	Billings	Montana	210079509226998181	9c5f4ca1e870edd8bdec9a95e057acc5	Mastercard	45.8274528671279526	-108.48887276441566
32293	2020-06-21 12:25:17	2020-06-21	Delmer Bogan-Quitzon	delmer.bogan.quitzon@geemail.com	Las Vegas	Nevada	4761307539624	7504fb45720b638c964dcd9ae0a391f5	Diners Club / Carte Blanche	36.1663602510102109	-115.179825555414325
32294	2020-06-21 12:29:39	2020-06-21	Paris Ankunding	paris.ankunding@geemail.com	San Francisco	California	3096082919631606201	16dc35022d4e9aa046a726cc2d23e3ec	Diners Club / Carte Blanche	37.8038085564934363	-122.430417305502033
32295	2020-06-21 12:29:59	2020-06-21	Mr. Bolden Dietrich III	mr.bolden.dietrich.iii@geemail.com	Philadelphia	Pennsylvania	4898185369953	5f9348a43c17166e86d17278acafea51	Mastercard	40.0383327675011031	-75.080729158678281
32296	2020-06-21 12:39:01	2020-06-21	Kaleena Schuppe-Kertzmann	kaleena.schuppe.kertzmann@geemail.com	Miami	Florida	4455933703553562	21d75000fe7c5cd44cc93bc7562d3968	American Express	25.7732948926415304	-80.2035883633758857
32297	2020-06-21 12:49:26	2020-06-21	Junia Hegmann	junia.hegmann@geemail.com	San Francisco	California	3497200517366092	e87d49f67b771466559dc86a9f9f9dd7	VISA 13 digit	37.7760988637916881	-122.45216279357804
32298	2020-06-21 12:55:23	2020-06-21	Fleta Kub	fleta.kub@geemail.com	New York	New York	869918901553699454	29de5271c855ae0d146b92082a0c441b	JCB 15 digit	40.7273206966221295	-73.8857433549024165
32299	2020-06-21 13:09:04	2020-06-21	Dallas Harber	dallas.harber@geemail.com	Pembroke Pines	Florida	3451806636651950	f220f26c7ac57590225a0ab4f438ba02	VISA 13 digit	26.0442824674807483	-80.3971313367035236
32300	2020-06-21 13:13:36	2020-06-21	Crysta Maggio	crysta.maggio@geemail.com	Lubbock	Texas	3158796594429466741	deb3bd931257c716299b330ef16a7c78	American Express	33.5043008882593369	-101.931139924415206
32301	2020-06-21 13:15:31	2020-06-21	Lorenzo Glover-Stroman	lorenzo.glover.stroman@geemail.com	San Francisco	California	4245759408508493	83cacb501c314d914b0de628f5d8cd58	Voyager	37.7748522178403903	-122.435381983789512
32302	2020-06-21 13:33:39	2020-06-21	Ryland Keeling	ryland.keeling@woohoo.com	Sterling Heights	Michigan	630465459796853	f549fc5fddc01f594bc15e90b9c9c871	American Express	42.5404154244426636	-83.0453517005938977
32303	2020-06-21 13:33:50	2020-06-21	Thea O'Keefe	thea.o'keefe@geemail.com	Dallas	Texas	3112816508931467910	d2305bf1e58aaa9741ff1aed88310d75	JCB 15 digit	32.7078405425690164	-96.6699543228801303
32304	2020-06-21 13:34:17	2020-06-21	Dr. Johnie Davis	dr.johnie.davis@geemail.com	San Francisco	California	6011238536791524546	d3d59b4f7cc9268bfafdbaf26629d7fe	VISA 16 digit	37.7733910452280739	-122.407695479126005
32305	2020-06-21 13:49:23	2020-06-21	Tod Renner	tod.renner@geemail.com	New York	New York	54922038805796682	d5b63ccfd37203f0d11947e234fde7fe	JCB 15 digit	40.6412030919678529	-73.9905024671357125
32306	2020-06-21 13:52:36	2020-06-21	Bobbye Kassulke DDS	bobbye.kassulke.dds@geemail.com	Downey	California	3158473657833988855	2c216fc771ef38e750660c81e9211da0	Diners Club / Carte Blanche	34.0355080401308854	-118.070143665896353
32307	2020-06-21 13:54:54	2020-06-21	Dr. Tory Hansen DVM	dr.tory.hansen.dvm@warmmail.com	Oakland	California	3096592906969524901	4a2b3f5651ce61496a39d81a7e31bfe4	Voyager	37.7725097393782505	-122.248737845683621
32308	2020-06-21 13:56:09	2020-06-21	Mr. Bridger Effertz IV	mr.bridger.effertz.iv@geemail.com	Colorado Springs	Colorado	52112720393340672	aef6769dc5497284c99c98c61bae4c32	JCB 16 digit	38.7718902417972657	-104.843730766434973
32309	2020-06-21 13:57:19	2020-06-21	Dr. Nathanial Sawayn	dr.nathanial.sawayn@geemail.com	Jacksonville	Florida	3112657863136782346	eeb3e1eea306c4220ab00584ac7edf47	JCB 15 digit	30.4278021649509682	-81.7411096551533802
32310	2020-06-21 14:05:46	2020-06-21	Dessa McDermott	dessa.mcdermott@geemail.com	San Francisco	California	4830184548451	815fe77dcaff61cca1c14d8d4ce79c75	JCB 16 digit	37.7703865495692881	-122.437053022250169
32311	2020-06-21 14:08:45	2020-06-21	Wing Wolff-Green	wing.wolff.green@geemail.com	San Francisco	California	3033317998441740	6ae08e009493bbe47d6bdba7b52fef1b	Discover	37.7883673517007068	-122.43851554433104
32312	2020-06-21 14:13:50	2020-06-21	Hunter Olson	hunter.olson@geemail.com	New York	New York	4990174378606	a4cf8be171e769a63d94476190c9d9ce	JCB 16 digit	40.7180054716523756	-73.8828847654990852
32313	2020-06-21 14:23:40	2020-06-21	Odis Hane	odis.hane@geemail.com	San Diego	California	3337675078204569156	7174b45513f47ba02d5d236220e6fbfd	VISA 13 digit	32.8165285849079496	-117.203738182866957
32314	2020-06-21 14:23:50	2020-06-21	Byrd Turner	byrd.turner@warmmail.com	New Orleans	Louisiana	869992052960802650	8565121b17f416a5cd9316d563591ec5	Mastercard	30.0897872445188455	-89.9299453546553877
32315	2020-06-21 14:24:00	2020-06-21	Kamilah Considine MD	kamilah.considine.md@geemail.com	Rialto	California	501886588351857	ee054f2ed94342c25f0e429c684bf1f2	Mastercard	34.1397884615913085	-117.345607347934688
32316	2020-06-21 14:25:38	2020-06-21	Blas White	blas.white@geemail.com	San Antonio	Texas	3456711108216362	652bc071ee465281cde3effc0bedb4ad	American Express	29.4070637863200162	-98.5547874105464672
32317	2020-06-21 14:29:22	2020-06-21	Rosey DuBuque MD	rosey.dubuque.md@woohoo.com	San Jose	California	3702603067655646	09187a56fb17fce7a8b3b1e2f9099846	Discover	37.3498037373002632	-121.915261397486177
32318	2020-06-21 14:32:35	2020-06-21	Kenji Monahan	kenji.monahan@geemail.com	Indianapolis	Indiana	4131008590994872	0932b450a6751040df7aa73b64948764	JCB 16 digit	39.769164846372604	-86.0628384477659978
32319	2020-06-21 14:33:02	2020-06-21	Laisha Thompson	laisha.thompson@woohoo.com	Philadelphia	Pennsylvania	210055437125609766	3c025bbb5417cf5e4d236905805a3c5e	VISA 16 digit	40.0054578090976918	-75.0735890828903791
32320	2020-06-21 14:35:58	2020-06-21	Dr. Lauri Botsford PhD	dr.lauri.botsford.phd@geemail.com	New York	New York	6011129978083645898	0f70d7038b56957e64bc58f92b7a2501	Voyager	40.5781893872413804	-73.8448265117023084
32321	2020-06-21 14:39:02	2020-06-21	Rexford Ritchie-Rosenbaum	rexford.ritchie.rosenbaum@geemail.com	Charlotte	North Carolina	869971133961187583	d5f2795f270c54b67eb2da4c528e5a74	JCB 16 digit	35.2496169002514321	-80.8387755345031707
32322	2020-06-21 14:43:25	2020-06-21	Wava Harber-Hermiston	wava.harber.hermiston@woohoo.com	Los Angeles	California	6011895476817151335	7370a2ad3a0906401ef0f9d25f3914f6	Maestro	34.0087655664287496	-118.490044064399967
32323	2020-06-21 14:50:17	2020-06-21	Mr. Andreas Dare DDS	mr.andreas.dare.dds@geemail.com	Alexandria	Virginia	6011520443849741841	f736b68508a5d594cf06fbd014127da5	JCB 15 digit	38.7788605093140148	-77.0623501307316161
32324	2020-06-21 14:51:01	2020-06-21	Mrs. Lelah Tromp	mrs.lelah.tromp@geemail.com	Fresno	California	3112987463539016789	559044936814b13d0fdd07eca145c317	Discover	36.8470163247421354	-119.764722102658453
32325	2020-06-21 14:53:20	2020-06-21	Ciarra Turner	ciarra.turner@geemail.com	Berkeley	California	3337114319790621723	5c0d4781894d1ac2f9497372ee31bd4d	JCB 16 digit	37.8546364257794465	-122.290836377897364
32326	2020-06-21 14:59:36	2020-06-21	Miss Texas Cronin	miss.texas.cronin@geemail.com	San Jose	California	589375595885064	756ca1ecac9287b11e7a0230628b472a	Maestro	37.3697250789783908	-121.807779934279253
32327	2020-06-21 15:05:20	2020-06-21	Miss Emmie Cartwright	miss.emmie.cartwright@geemail.com	New York	New York	210016768371635438	d9d1a0e84c53dfb85fe380b1d37f5cf5	VISA 13 digit	40.6074948953688164	-74.0150544650282711
32328	2020-06-21 15:06:48	2020-06-21	Kiara Nolan	kiara.nolan@geemail.com	Washington	District of Columbia	3039693966898283	bec830e3ac2496797c0e69307866e9b7	Voyager	38.9717086608786119	-77.107876184371122
32329	2020-06-21 15:24:17	2020-06-21	Miss Dell Franecki	miss.dell.franecki@woohoo.com	Hollywood	Florida	52738006461337715	4db043c583d91246e16647207deb0e45	VISA 16 digit	25.9415143295135344	-80.0941583961997168
32330	2020-06-21 15:26:43	2020-06-21	Kelley Lockman	kelley.lockman@geemail.com	Lakewood	New Jersey	6011686386919083265	316fb1dee262c82dd32cd683b36703d6	VISA 16 digit	40.0589578829523205	-74.2744914698224505
32331	2020-06-21 15:42:07	2020-06-21	Alpha Hamill	alpha.hamill@geemail.com	San Francisco	California	4741778728394938	92e388645af63851425d5808510c60a7	American Express	37.7543816908558156	-122.408148359136817
32332	2020-06-21 15:42:32	2020-06-21	Kerry Fadel	kerry.fadel@geemail.com	Philadelphia	Pennsylvania	3768800785390941	58018235d55730b91d919d957213126b	JCB 16 digit	40.0910223293542884	-75.2177769324176069
32333	2020-06-21 15:43:18	2020-06-21	Landen Hamill-Homenick	landen.hamill.homenick@woohoo.com	Las Vegas	Nevada	3088748649632512019	35da25d534616623002ad0b25fda0b49	Maestro	36.1423332201883198	-115.329200005039937
32334	2020-06-21 16:20:40	2020-06-21	Gretchen Terry DDS	gretchen.terry.dds@geemail.com	Corpus Christi	Texas	561256864626785	8b6a654d72170237328a35207a6de8fc	Maestro	27.6765619025968022	-97.1493614892769557
32335	2020-06-21 16:21:16	2020-06-21	Lucius Hessel	lucius.hessel@geemail.com	Little Rock	Arkansas	3088230155919763841	0a10347cc04f5f1ae7c9f1072c904575	VISA 13 digit	34.7356030416484955	-92.4195808296896502
32336	2020-06-21 16:31:37	2020-06-21	Miss Cherry Howe MD	miss.cherry.howe.md@geemail.com	San Francisco	California	180020219786281313	fef65d6808218c2da7ef7cce11a39573	Diners Club / Carte Blanche	37.7600786792876093	-122.426979712145823
32337	2020-06-21 16:49:10	2020-06-21	Brett Stoltenberg	brett.stoltenberg@woohoo.com	Miami	Florida	3773239401027749	8205cf39cbccc4d5e5077c9a657f8793	JCB 16 digit	25.841117331771926	-80.2324167957402778
32338	2020-06-21 16:56:16	2020-06-21	Arianna Hilll	arianna.hilll@woohoo.com	Seattle	Washington	6011390271962198730	9e2e5f0ddc0496b36090c8c5abc8348e	Maestro	47.5489438593313096	-122.441998039364435
32339	2020-06-21 16:59:06	2020-06-21	Dayanara Price	dayanara.price@geemail.com	Phoenix	Arizona	180030282389154707	8372de09f4cc0e92188a510cd8588ec8	JCB 16 digit	33.5829879035640531	-112.156750476958607
32340	2020-06-21 17:06:26	2020-06-21	Cyril Smith-Jast	cyril.smith.jast@geemail.com	Atlanta	Georgia	3424124516803434	147a5dc42b813ea59fc3b9be55d29e54	JCB 15 digit	33.7933464255925315	-84.393809829423958
32341	2020-06-21 17:13:00	2020-06-21	Miss Matilda Funk	miss.matilda.funk@geemail.com	Tulsa	Oklahoma	4803013092354218	225e64f893ece5c7b8fc2a0897117cfb	Maestro	36.0657631159197507	-95.9835603490427047
32342	2020-06-21 17:13:30	2020-06-21	Mammie Russel DDS	mammie.russel.dds@geemail.com	Spokane	Washington	3013245574303168	a948c63c32cf061c0e38b6520a601eb7	Voyager	47.6650555339414623	-117.465818499856823
32343	2020-06-21 17:21:51	2020-06-21	Kash Runolfsson	kash.runolfsson@geemail.com	San Francisco	California	3158970186251273762	dcdde7b45d5dbcae41d6906e7886f64c	Diners Club / Carte Blanche	37.7507392274096247	-122.436325458285665
32344	2020-06-21 17:23:14	2020-06-21	Sarahi Jacobson PhD	sarahi.jacobson.phd@geemail.com	Fresno	California	869920905346757533	f33a9e6f1e8278194a329a51341f2077	Maestro	36.8267340156123026	-119.719894428748276
32345	2020-06-21 17:23:24	2020-06-21	Shay Johnston	shay.johnston@warmmail.com	Miami	Florida	6011424615441012765	135c5a8b9524f0831f573cc33221d101	VISA 16 digit	25.8193756640095273	-80.2854630132079166
32346	2020-06-21 17:43:49	2020-06-21	Authur Little	authur.little@woohoo.com	North Las Vegas	Nevada	3158635372907687244	d8842102121122d66d6aaa12ac23d584	JCB 16 digit	36.257650811194253	-115.028730560395502
32347	2020-06-21 17:48:05	2020-06-21	Pam Tillman	pam.tillman@geemail.com	Athens	Georgia	3403533142711610	34e07e92498abd762e84ce60bb258b07	Mastercard	33.8513661460675266	-83.3946911094825651
32348	2020-06-21 17:49:09	2020-06-21	Geneva Botsford MD	geneva.botsford.md@geemail.com	Saint Paul	Minnesota	3337470413769671419	39785868d7af8ef8ee680b7132c58a64	JCB 16 digit	44.9327659241795558	-93.0217102561410485
32349	2020-06-21 18:04:31	2020-06-21	Alethea Green	alethea.green@geemail.com	Orange	California	3057848443805135	fa4639be1e4f693b91debc3f584a7f76	Mastercard	33.8210709274169048	-117.891182243135944
32350	2020-06-21 18:06:26	2020-06-21	Dr. Ivan O'Hara Jr.	dr.ivan.o'hara.jr.@geemail.com	San Mateo	California	4950069427628743	b48c84546de79a664560783bde39daa9	JCB 16 digit	37.544642079935592	-122.384952104170239
32351	2020-06-21 18:07:38	2020-06-21	Mr. Casimir Spencer V	mr.casimir.spencer.v@geemail.com	Murrieta	California	3052944491507791	38c1e197476fb8dfc7bb08b3bb56bfcd	JCB 16 digit	33.475310338950159	-117.152328230989724
32352	2020-06-21 18:14:04	2020-06-21	Deshawn O'Connell	deshawn.o'connell@geemail.com	Detroit	Michigan	3158868162788004041	44d8b8336f7b3902984b7dd40f057870	JCB 16 digit	42.3185087878648218	-83.0790037605099343
32353	2020-06-21 18:17:15	2020-06-21	Ms. Charlottie Pouros	ms.charlottie.pouros@geemail.com	Kenosha	Wisconsin	4863485801998	98811e64df4801bff985c9db17c045a7	Voyager	42.5036400149881857	-87.8756696374382926
32354	2020-06-21 18:20:46	2020-06-21	Ms. Ellar Gleason MD	ms.ellar.gleason.md@geemail.com	Garden Grove	California	589394197719209	0efc90924e922934de2fbe98cfc89f23	VISA 13 digit	33.6841506943862825	-118.049832351181649
32355	2020-06-21 18:26:04	2020-06-21	Margaret Bednar-Marvin	margaret.bednar.marvin@geemail.com	St. Petersburg	Florida	3096321382334741141	0c2af43d34200bf29ad7756a12ee7c6a	Diners Club / Carte Blanche	27.6885288747847085	-82.6199701454382307
32356	2020-06-21 18:29:55	2020-06-21	Randal Marquardt IV	randal.marquardt.iv@woohoo.com	Long Beach	California	4901618985955	39274d7dcd15aac70e34cab1874048d5	Voyager	33.8087561260264309	-118.087546452523398
32357	2020-06-21 18:31:03	2020-06-21	Connor DuBuque	connor.dubuque@warmmail.com	New York	New York	869929615861284885	8643a9f762125ae19f53590771755738	JCB 15 digit	40.6064840390570438	-73.8623542945261988
32358	2020-06-21 18:36:00	2020-06-21	Eloise Carroll	eloise.carroll@geemail.com	Long Beach	California	210086000446142686	ee26a9cfbbe1ddf05b434559be219075	VISA 13 digit	33.7652946803074272	-118.118133694554857
32359	2020-06-21 18:45:04	2020-06-21	Alexandra Klein	alexandra.klein@geemail.com	Pembroke Pines	Florida	3011651018344571	b8fb9597e20d097defde91f05e310add	JCB 16 digit	26.0671566866841182	-80.3272038680404421
32360	2020-06-21 18:46:26	2020-06-21	Lalla Weimann MD	lalla.weimann.md@geemail.com	St. Louis	Missouri	869938731131087831	07d1abc70c94dcb186d3c454f61520d4	JCB 15 digit	38.5866515191894024	-90.147843036568176
32361	2020-06-21 18:49:29	2020-06-21	Deann Kuhn	deann.kuhn@warmmail.com	Los Angeles	California	4533460678394	33424873e3512d47784d3472ab09d4f7	VISA 16 digit	34.0784940088499297	-118.374610936268411
32362	2020-06-21 18:56:15	2020-06-21	Kayley Russel	kayley.russel@geemail.com	Anchorage	Alaska	869929390727963367	01a0ab8114595fe405f3a1db19d666bf	Discover	61.2588017943531327	-149.210925518593939
32363	2020-06-21 18:56:43	2020-06-21	Nathanael Rosenbaum-Dietrich	nathanael.rosenbaum.dietrich@woohoo.com	Minneapolis	Minnesota	676254045754055	b3dc618e9c7c2fb74cafd1210ba13da3	Mastercard	44.8831328683618409	-93.2167421095810766
32364	2020-06-21 18:59:44	2020-06-21	Kylan Dickens	kylan.dickens@warmmail.com	Detroit	Michigan	210078144723846864	a373a521d2400d76a8beb471d242728d	VISA 16 digit	42.3118158921524881	-83.0484112772278422
32365	2020-06-21 19:02:06	2020-06-21	Burney Jakubowski	burney.jakubowski@geemail.com	Dallas	Texas	3528550534697690412	5c66d428eab68bba45e4fe438069ce65	VISA 13 digit	32.7898687068179271	-96.7949095654729632
32366	2020-06-21 19:02:57	2020-06-21	Cinthia White	cinthia.white@geemail.com	Honolulu	Hawaii	4705903384273	8b71469304f4b52499570e98f9f97b5a	American Express	21.2379708102654661	-157.806417122690391
32367	2020-06-21 19:04:14	2020-06-21	Janyce Franecki	janyce.franecki@geemail.com	North Charleston	South Carolina	3042279992667319	4a366d840b197136139fc6820396ca0b	VISA 13 digit	32.8768243343729551	-80.0046087214816311
32368	2020-06-21 19:11:34	2020-06-21	Dr. Erlene Leffler MD	dr.erlene.leffler.md@geemail.com	San Diego	California	4315667329317784	f0c82e75491dbcad244a4fb6e77d62c6	Discover	32.8895680138442685	-117.162585392910998
32369	2020-06-21 19:16:43	2020-06-21	Hoyt Cole	hoyt.cole@geemail.com	Arlington	Texas	3045442058843839	f8b2b8005c74eba584ade6aed5361897	JCB 16 digit	32.7073754332277886	-97.1517458776969534
32370	2020-06-21 19:32:06	2020-06-21	Autry Hermann	autry.hermann@geemail.com	Los Angeles	California	4121866287395899	aef2d083e7fd0b6039146ebc8d60d0f7	JCB 16 digit	34.019303924157839	-118.484897305629403
32371	2020-06-21 19:33:28	2020-06-21	Elza Graham	elza.graham@geemail.com	New York	New York	4559555803928850	10ed3f56f0dd6cab36676f6f6fd2702d	Diners Club / Carte Blanche	40.7243839625492683	-73.9203254022996816
32372	2020-06-21 19:38:55	2020-06-21	Efren Leannon	efren.leannon@geemail.com	Seattle	Washington	4017598083568760	2ec06a93ee17a92ccae1aca2a7d8c480	JCB 15 digit	47.5311623705476549	-122.404585778239735
32373	2020-06-21 19:40:08	2020-06-21	Tyquan Rodriguez	tyquan.rodriguez@geemail.com	Gilbert	Arizona	3088060915813085434	d5cc7d699bbdd2eb2baf6f70b8bb1b00	VISA 13 digit	33.3787935110155445	-111.823418035976957
32374	2020-06-21 19:41:15	2020-06-21	Marleigh Grimes	marleigh.grimes@woohoo.com	Tulsa	Oklahoma	3429785805895326	d79a7bad3bfed5cfeaadcc394c086aad	VISA 16 digit	36.2074226029120325	-95.9561955131079998
32375	2020-06-21 19:44:04	2020-06-21	Paul Corwin V	paul.corwin.v@geemail.com	Rochester	New York	676318662399221	5536977a29d683b3063312971220e0a2	JCB 16 digit	43.1647327474296105	-77.5622950840514136
32376	2020-06-21 19:47:01	2020-06-21	Benjaman Olson	benjaman.olson@geemail.com	Chicago	Illinois	210027396274214692	f0ea18884e32e4e11203d38d7d35ad3c	Discover	41.81202827988416	-87.5919053498685258
32377	2020-06-21 19:52:29	2020-06-21	Harley Dickinson	harley.dickinson@geemail.com	Boston	Massachusetts	4306016743539410	fabb38c6d6440a61cf959ec0d7cb9a2c	JCB 15 digit	42.2694340391252226	-71.0886899969026445
32378	2020-06-21 19:52:30	2020-06-21	Ms. Blanca Marquardt	ms.blanca.marquardt@warmmail.com	Philadelphia	Pennsylvania	53616667155429998	a9f56ba79e8039e5946553168790f1b3	JCB 16 digit	40.0444103766657378	-75.188190316445386
32379	2020-06-21 19:59:05	2020-06-21	Felice Johns	felice.johns@geemail.com	Detroit	Michigan	6011784401229058336	e388a3ea93c35a395e5c233dfa72650a	Maestro	42.3356138160377782	-83.030956296960639
32380	2020-06-21 20:01:10	2020-06-21	Emilia Johnson-Yundt	emilia.johnson.yundt@woohoo.com	Los Angeles	California	869983180233317924	e804dc73df8779a6b767194bc5e084f3	VISA 16 digit	34.0884552740823423	-118.458312378403917
32381	2020-06-21 20:05:01	2020-06-21	Tiffany Lowe	tiffany.lowe@geemail.com	New York	New York	3027561505999379	62d155f20d3639415b92221b90a7a6a3	Diners Club / Carte Blanche	40.6956320471353834	-73.9470092170301854
32382	2020-06-21 20:14:37	2020-06-21	Dr. Alia McDermott DDS	dr.alia.mcdermott.dds@geemail.com	Tacoma	Washington	502095050597673	7d45697684d347211371229cd393a05d	VISA 16 digit	47.3324771542221328	-122.383712366759028
32383	2020-06-21 20:18:57	2020-06-21	Pablo Kutch-Beier	pablo.kutch.beier@warmmail.com	Carrollton	Texas	53371480169078545	ffe5b9777d11bcc7c724afe2d9c62c2b	Voyager	33.0736840525563807	-96.8350541760075885
32384	2020-06-21 20:19:28	2020-06-21	Verlene Windler	verlene.windler@geemail.com	Oakland	California	180003576583087008	e325cf629f06166c4b462101cc97a806	JCB 15 digit	37.7974271471663101	-122.23057457673076
32385	2020-06-21 20:20:09	2020-06-21	Konnor Marvin	konnor.marvin@geemail.com	Cincinnati	Ohio	4182610015072669	618268b8aee1a85080de83e6ca3022a2	JCB 15 digit	39.0889040060106652	-84.511420700260615
32386	2020-06-21 20:23:13	2020-06-21	Thursa O'Connell	thursa.o'connell@geemail.com	Chicago	Illinois	4780856278574	93b2b2679ecd4c33dccedbc84d8032d7	VISA 16 digit	41.7747933380607535	-87.6352673618152664
32387	2020-06-21 20:23:49	2020-06-21	Luz Parker	luz.parker@geemail.com	Tempe	Arizona	3015993323883349	c526771cc199fbbffb2008b4e676f668	Discover	33.4578843313191072	-111.96145122004971
32388	2020-06-21 20:33:45	2020-06-21	Brynn Connelly	brynn.connelly@geemail.com	San Francisco	California	3056525990877888	308de5d19734ac8b1e74ca97bffbeae6	Voyager	37.7947076535088726	-122.444833018087522
32389	2020-06-21 20:37:49	2020-06-21	Arminda Rodriguez	arminda.rodriguez@geemail.com	Omaha	Nebraska	4156281938513502	a9b90d21d6b0d801cb6cc3ab6a545db3	Voyager	41.2261252156604101	-96.1201976201612496
32390	2020-06-21 20:43:03	2020-06-21	Reino Collins-Romaguera	reino.collins.romaguera@geemail.com	Los Angeles	California	4515877085890472	f23ab05d6a1d946bbb2bf7407669bfb1	JCB 15 digit	33.9688282145053151	-118.405180206288762
32391	2020-06-21 20:45:05	2020-06-21	Dr. Doctor Gislason I	dr.doctor.gislason.i@woohoo.com	El Cajon	California	4999393794964	c359f2534bc666437fef2d12b0bc9cce	Mastercard	32.7098357986200554	-116.917219364055995
32392	2020-06-21 20:52:01	2020-06-21	Einar Turcotte	einar.turcotte@geemail.com	Aurora	Colorado	4277827643050265	df106a2d152232ec5e5f9d494098ced4	VISA 16 digit	39.6252381974942978	-104.753694036987426
32393	2020-06-21 20:53:49	2020-06-21	Ari Huels	ari.huels@geemail.com	Nashville	Tennessee	3528677873704882242	f64f441f7c7d391078fc772c0bd7f601	Voyager	36.0847281676839984	-86.7995720486529194
32394	2020-06-21 21:03:42	2020-06-21	Mrs. Beckie Herzog MD	mrs.beckie.herzog.md@geemail.com	Davenport	Iowa	639021477211979	346dd5f7cdd274b4fd55cd78d0752de4	VISA 13 digit	41.5832847794782339	-90.6713189890105298
32395	2020-06-21 21:04:15	2020-06-21	Maryanne Funk	maryanne.funk@geemail.com	Clovis	California	3088247743208501302	8c2a8cca086966521b33ae41b0c58bc2	American Express	36.8998471468098472	-119.607907321124898
32396	2020-06-21 21:05:44	2020-06-21	Lera Parisian PhD	lera.parisian.phd@geemail.com	Minneapolis	Minnesota	589380797641588	c76f529980dd74acdde19205d14cbb99	Maestro	45.0204198084391649	-93.1969101635079795
32397	2020-06-21 21:06:44	2020-06-21	Mr. Lamont Bartell	mr.lamont.bartell@woohoo.com	Rochester	New York	3045529033736037	d77599fa7af2697b556651af1e4142d8	Discover	43.1945755530592024	-77.5342471671063436
32398	2020-06-21 21:16:03	2020-06-21	Shaquita Bednar	shaquita.bednar@geemail.com	New York	New York	180051919802901263	bef16f3029a5df0e5f2701eb13bc9d0e	American Express	40.6159630037136381	-73.8747763995442455
32399	2020-06-21 21:24:17	2020-06-21	Ieshia Buckridge-Haley	ieshia.buckridge.haley@geemail.com	San Francisco	California	4725716254810	1e7fc2c063a38044cc6a709b88ed892e	American Express	37.7387153894126186	-122.4063605613986
32400	2020-06-21 21:26:24	2020-06-21	Mr. Wendel Kessler	mr.wendel.kessler@geemail.com	New York	New York	4188100504763	9c3c22656986c929ef57aac5f0fcdb23	VISA 16 digit	40.6897038995046145	-74.014874453413114
32401	2020-06-21 21:30:01	2020-06-21	Tari Reichert	tari.reichert@geemail.com	Fort Lauderdale	Florida	180076611298154538	cd6d783e5b9df040d5cdaddf6ed5f784	Mastercard	26.0987643382035195	-80.1634328041978108
32402	2020-06-21 21:39:15	2020-06-21	Mahalia Kohler	mahalia.kohler@geemail.com	San Francisco	California	6011631577041745393	8a445fe7aa4ea8b199fca4c39c1202ca	Diners Club / Carte Blanche	37.7854371349532414	-122.426023535807488
32403	2020-06-21 21:41:28	2020-06-21	Albion Gleason	albion.gleason@geemail.com	Overland Park	Kansas	4814563374184	fbe89c8baff0a6c9827a96abda5fb508	JCB 16 digit	38.912997469758615	-94.7034985070623492
32404	2020-06-21 21:47:16	2020-06-21	Terrell West DVM	terrell.west.dvm@geemail.com	West Palm Beach	Florida	3096197068684772114	4e33087fdd2f366d60c61c3ae9d99e06	Diners Club / Carte Blanche	26.8212093249741947	-80.2236013902653013
32405	2020-06-21 21:53:35	2020-06-21	Miss Leyla Monahan PhD	miss.leyla.monahan.phd@geemail.com	Elk Grove	California	4837625691692159	a641f3cc32a38d3408f9b0d50d8ec740	Diners Club / Carte Blanche	38.3477689821090522	-121.294267827821898
32406	2020-06-21 21:55:02	2020-06-21	Dr. Ingrid Treutel PhD	dr.ingrid.treutel.phd@geemail.com	Abilene	Texas	210015965837301909	4732b078c4e9ccea29b6dfe2b90ddf4f	VISA 16 digit	32.5138587897717954	-99.7128661178000328
32407	2020-06-21 22:00:12	2020-06-21	Jessica Hahn	jessica.hahn@geemail.com	Scottsdale	Arizona	630421687332037	e9c9d7fa78bb3d9263ba58b60b0e027c	VISA 13 digit	33.6462605473242675	-111.858228053521728
32408	2020-06-21 22:05:43	2020-06-21	Bobbie Gusikowski	bobbie.gusikowski@woohoo.com	Chicago	Illinois	52256102620826169	f20eb86f88b94c6264ad7bc7463f75f6	JCB 15 digit	41.8872092237997791	-87.6536058413360166
32409	2020-06-21 22:10:59	2020-06-21	Jake Spinka	jake.spinka@geemail.com	New York	New York	180010005964570664	b1fd3b2523e2f0dd2a663a790394db86	JCB 15 digit	40.6987648845408074	-73.9697065870638966
32410	2020-06-21 22:13:21	2020-06-21	Arthur Crooks	arthur.crooks@woohoo.com	San Francisco	California	4000153554771664	2a53d87ea28e12e121c8c13f8e65b598	JCB 15 digit	37.7474269008256584	-122.46015486973603
32411	2020-06-21 22:18:38	2020-06-21	Shelby Morissette	shelby.morissette@geemail.com	Olathe	Kansas	3112341525477531267	1b7f016bdb30209bde518c892168251c	Diners Club / Carte Blanche	38.9346920771647262	-94.8960375479124565
32412	2020-06-21 22:22:48	2020-06-21	Miss Oneida Herzog DVM	miss.oneida.herzog.dvm@geemail.com	Portland	Oregon	54413547859353956	00651fa14114c8487838278a8baf9f0c	Maestro	45.500034262228759	-122.748164372565228
32413	2020-06-21 22:31:01	2020-06-21	Jaylin Auer-Hermann	jaylin.auer.hermann@woohoo.com	New York	New York	3727595141774594	8c6666a02cbf6b9ba188aa09718d2529	VISA 16 digit	40.6571138199176616	-73.8873797721125101
32414	2020-06-21 22:35:54	2020-06-21	Dr. Damari Koelpin	dr.damari.koelpin@geemail.com	Ontario	California	3786889067455801	164f22e2194e2a754e4c7b9a9fc631eb	Mastercard	34.0084102288033847	-117.504771187399328
32415	2020-06-21 22:36:53	2020-06-21	Dr. Ardell Bartoletti II	dr.ardell.bartoletti.ii@geemail.com	Fort Worth	Texas	4921073767343950	a0fce14ff973358685d3f882b521d993	Voyager	32.879783354472373	-97.2985455481622381
32416	2020-06-21 23:10:59	2020-06-21	Mr. Gerardo Terry	mr.gerardo.terry@warmmail.com	Detroit	Michigan	3010473785302240	65255d726ef7d42c7c7cf2ea6b5f3fac	JCB 15 digit	42.3145282499417661	-83.1402528690293394
32417	2020-06-21 23:17:17	2020-06-21	Dr. Woodrow Schiller	dr.woodrow.schiller@geemail.com	Oakland	California	55743865123760280	60bf269ee061f479e9f85819b6cd183d	VISA 13 digit	37.8024610399510479	-122.24805999819003
32418	2020-06-21 23:37:06	2020-06-21	Wayde Goldner	wayde.goldner@woohoo.com	Berkeley	California	3009550939238775	fb27267d29f26c0d4b80c93d9666202f	Discover	37.8599862397378217	-122.289719467909947
32419	2020-06-21 23:37:20	2020-06-21	Marti Schmitt	marti.schmitt@geemail.com	Arlington	Texas	6011884724241256904	21aaac6d4d04971d70213b3cc623717c	Diners Club / Carte Blanche	32.7926856455642692	-97.1369438589576646
32420	2020-06-21 23:44:48	2020-06-21	Lilian Ullrich	lilian.ullrich@geemail.com	Salinas	California	3096204277742430737	237f3092d9e909dfca0512114f35be43	Mastercard	36.6807183285009089	-121.548415499198072
32421	2020-06-21 23:48:52	2020-06-21	Nash Predovic	nash.predovic@geemail.com	Long Beach	California	52445708897656923	a0c47c9cb61c0bac38571c162ede31eb	VISA 16 digit	33.7699706386595935	-118.18759885492473
32422	2020-06-22 00:03:42	2020-06-22	Roena Wilkinson	roena.wilkinson@geemail.com	San Francisco	California	060406794716255	fa097eef583b02e2e539ece8910452d6	Diners Club / Carte Blanche	37.7643888584038052	-122.410065445298343
32423	2020-06-22 00:09:39	2020-06-22	Marlene Mohr	marlene.mohr@geemail.com	Los Angeles	California	54402353184919709	a5bf25a29b047ca491f56f9f9b2bf4c1	Mastercard	34.0867913600388874	-118.317190315899623
32424	2020-06-22 00:13:39	2020-06-22	Mr. Everet Ankunding	mr.everet.ankunding@geemail.com	Columbia	Missouri	180027614792215201	6f588f0e7cf14f0923b9fc2ca5c82e8a	VISA 16 digit	39.0156999227472241	-92.2721276714054
32425	2020-06-22 00:45:02	2020-06-22	Bette Auer	bette.auer@geemail.com	Jackson	Mississippi	869989603548020069	b213f0b722e4c7193f1840e5f58c323e	American Express	32.2536664635121824	-90.1692018609002304
32426	2020-06-22 00:50:51	2020-06-22	Miss Marlana Steuber	miss.marlana.steuber@warmmail.com	San Francisco	California	3088055402375925437	7aa04014214f6706cd646c8c99194960	VISA 16 digit	37.7972133195315436	-122.410017421228176
32427	2020-06-22 00:51:14	2020-06-22	Brisa Dach	brisa.dach@woohoo.com	Baltimore	Maryland	675908864579837	5f9387563ab54deab08aec72f2a74929	VISA 16 digit	39.2441515161190182	-76.5478129934538174
32428	2020-06-22 00:52:25	2020-06-22	Ocie Dickinson	ocie.dickinson@geemail.com	Indianapolis	Indiana	4297553694680	3ba319fee041281826d0960122be6c9a	JCB 16 digit	39.8305660123478589	-86.0626191854212408
32429	2020-06-22 01:00:01	2020-06-22	Knox Keebler-Lemke	knox.keebler.lemke@geemail.com	Chicago	Illinois	3004545340945930	121adba93e10b72e580aa19aa76797f4	Diners Club / Carte Blanche	41.8214010086212298	-87.7813240547694278
32430	2020-06-22 01:07:15	2020-06-22	Jeana Schaefer	jeana.schaefer@geemail.com	Fort Worth	Texas	3096356206330859961	0820f1c153fc7a3ab500674877f8d77c	JCB 16 digit	32.7915039188750086	-97.2532769431181237
32431	2020-06-22 01:12:22	2020-06-22	Dr. Louis Bode	dr.louis.bode@geemail.com	New York	New York	4364585468070693	bbeebdb098e1c9a772129a84699ec665	Voyager	40.5670372933838479	-73.9155252106849048
32432	2020-06-22 01:22:09	2020-06-22	Carmella Altenwerth-Bergstrom	carmella.altenwerth.bergstrom@warmmail.com	Fort Lauderdale	Florida	3476335602253261	c8482b1c2c61e214b22f0e8e6878776c	JCB 16 digit	26.0517336791370084	-80.1694700556162729
32433	2020-06-22 01:22:50	2020-06-22	Angelita Boehm-Wolff	angelita.boehm.wolff@geemail.com	Arlington	Texas	869982608720749499	c1ce4eb987fe45050da2b2f5bc2efda0	Diners Club / Carte Blanche	32.6417164100117958	-97.1727758391786409
32434	2020-06-22 01:23:16	2020-06-22	Raynard Kuvalis	raynard.kuvalis@geemail.com	Victorville	California	54753160506445726	10ab6b3c26f9214502057b61a5add437	American Express	34.4631311937466265	-117.3578285611853
32435	2020-06-22 01:30:15	2020-06-22	Lavern Yost	lavern.yost@geemail.com	Vancouver	Washington	4657223616332	746b0052a07ad1562ff671775ac55100	VISA 16 digit	45.631276170264556	-122.601527502626922
32436	2020-06-22 01:35:42	2020-06-22	Joseline Hermiston	joseline.hermiston@geemail.com	Fresno	California	3528797595690868621	84f506ccca17770c0df4501d04680315	American Express	36.8674387501891729	-119.70792682581731
32437	2020-06-22 01:40:43	2020-06-22	Miss Lucetta Wunsch	miss.lucetta.wunsch@woohoo.com	Wilmington	North Carolina	4485266881363031	59553fa351083e254d8caae7d85ae54d	Discover	34.2261923932757242	-77.9128695638377309
32438	2020-06-22 01:47:39	2020-06-22	Mr. Leif Gutmann	mr.leif.gutmann@geemail.com	Arlington	Texas	869995297818644302	b630aeedc8961166e80d59b4c5337a23	JCB 16 digit	32.7935198368288567	-97.0667769336633484
32439	2020-06-22 01:55:45	2020-06-22	Alma Morissette	alma.morissette@geemail.com	Oklahoma City	Oklahoma	3528528992583821211	57b9cf9df792211f6ea43ec552b52186	JCB 16 digit	35.497854299648111	-97.4678706393007133
32440	2020-06-22 02:05:17	2020-06-22	Sal Gusikowski	sal.gusikowski@geemail.com	San Francisco	California	51874722356459075	54b59c2fe78e351f4281bf0263ab28e1	Mastercard	37.7346180695996054	-122.400824431565241
32441	2020-06-22 02:05:54	2020-06-22	Alvan Torp Jr.	alvan.torp.jr.@geemail.com	Dallas	Texas	4014929537654224	fe60dc8b1f6916464b33f9804bd0ec5b	Discover	32.8152759336207112	-96.7101533702071663
32442	2020-06-22 02:09:06	2020-06-22	Jann Tromp	jann.tromp@geemail.com	San Francisco	California	4652253181073020	c36db2f12045c83512fceb2e85e97678	VISA 13 digit	37.7421617267223439	-122.416556560396444
32443	2020-06-22 02:16:38	2020-06-22	Leigh Mayer-Schinner	leigh.mayer.schinner@geemail.com	Detroit	Michigan	53444477498025653	1e4c5244ea877c971c203fc32f5a938c	VISA 13 digit	42.4668939213659655	-83.0161115457423051
32444	2020-06-22 02:20:11	2020-06-22	Corinne Mayert	corinne.mayert@warmmail.com	Sugar Land	Texas	3798007399054640	62af14c4a6dc2cf4a35533c9a5f805f1	JCB 16 digit	29.6937836121354231	-95.5645381825052169
32445	2020-06-22 02:23:05	2020-06-22	Lonie DuBuque	lonie.dubuque@geemail.com	Oklahoma City	Oklahoma	4675864001316234	ce97e3aaadb987aaae7bc484aae8acea	JCB 16 digit	35.4348103784866666	-97.4446065759182005
32446	2020-06-22 02:37:43	2020-06-22	Deion Williamson-Lesch	deion.williamson.lesch@geemail.com	Orlando	Florida	4078233950340	5972e30cc5fc1e6998b6beb5ccbc5741	JCB 16 digit	28.4805935657847655	-81.2777863090824297
32447	2020-06-22 02:40:54	2020-06-22	Teagan Dickens-Murphy	teagan.dickens.murphy@woohoo.com	San Antonio	Texas	3337377557242583106	649e1e9f02405fb709540cfa09a9f471	American Express	29.455952150754257	-98.5649792106658111
32448	2020-06-22 02:46:37	2020-06-22	Brittany Murphy-Yost	brittany.murphy.yost@geemail.com	New York	New York	6011661325887795160	2ff53763a3a6666958365d76673a0306	JCB 15 digit	40.6717264270633478	-74.0044069206237793
32449	2020-06-22 02:49:58	2020-06-22	Deedee Prosacco	deedee.prosacco@geemail.com	Tampa	Florida	4164884361993	a21c06cc64bfe0d326144cf35e1f4bd7	VISA 16 digit	28.0172620449796312	-82.5611969079103289
32450	2020-06-22 02:51:32	2020-06-22	Dr. Che Lehner II	dr.che.lehner.ii@warmmail.com	San Francisco	California	4826357150076962	c11314ca37b493fda6545759bb978e83	JCB 15 digit	37.7838819822206133	-122.448152129076064
32451	2020-06-22 02:56:14	2020-06-22	Doretha Kiehn-Harber	doretha.kiehn.harber@warmmail.com	Portland	Oregon	4837627901714971	a5a8da6549889c13d316dfe986436fb8	Maestro	45.5041042369678621	-122.62200666354039
32452	2020-06-22 02:56:26	2020-06-22	Kaleb Weber	kaleb.weber@geemail.com	Rochester	New York	3455247900750747	ede011c635dddae6c3e33f41d81c0e66	Discover	43.1957714228402807	-77.6768651733413407
32453	2020-06-22 02:57:54	2020-06-22	Edmonia Windler	edmonia.windler@warmmail.com	Laredo	Texas	869985065780693793	95b90db5083482a2811ed37d8284b652	JCB 16 digit	27.6348372880551985	-99.4103737245786903
32454	2020-06-22 02:58:15	2020-06-22	Nim Mertz	nim.mertz@geemail.com	Pasadena	California	6011105095481683765	1273a6b7ab5bfbeddd0e8785e25e52a0	Diners Club / Carte Blanche	34.1330138093646624	-118.231978666670997
32455	2020-06-22 02:58:21	2020-06-22	Rafe Brown	rafe.brown@warmmail.com	New Orleans	Louisiana	3051948506359875	65b5c7d0b4de125e63cc57b341d99f10	VISA 16 digit	29.96946751368381	-89.9157275982461925
32456	2020-06-22 03:01:57	2020-06-22	Dr. Benny Sawayn	dr.benny.sawayn@geemail.com	New York	New York	869940375437430786	36fb40ad861e30c81128422b99323661	Voyager	40.6638418688196666	-73.9824985843978737
32457	2020-06-22 03:15:20	2020-06-22	Nikole Romaguera	nikole.romaguera@woohoo.com	Raleigh	North Carolina	869948626708086455	c22273996bc26182b34f2eff29522517	Diners Club / Carte Blanche	35.7624974761292336	-78.7025651687692829
32458	2020-06-22 03:20:27	2020-06-22	Philo Murphy	philo.murphy@geemail.com	San Francisco	California	4234403481948663	2e9610a4fb32d3d6521426e4b7bf6b7e	American Express	37.782054027737793	-122.433315862355812
32459	2020-06-22 03:30:21	2020-06-22	Sharleen Schmeler	sharleen.schmeler@geemail.com	New York	New York	3018740106831988	593b63f72b725f437469e4279d370801	JCB 16 digit	40.6325477781929081	-73.9817192412342877
32460	2020-06-22 03:33:15	2020-06-22	Kelli Torp	kelli.torp@geemail.com	Garden Grove	California	4525696923120183	3936ea4339f7957ebf7eaa49b572b403	VISA 16 digit	33.8776596641924215	-117.921285304009913
32461	2020-06-22 03:35:02	2020-06-22	Carla Parker	carla.parker@geemail.com	Phoenix	Arizona	4898651947951	5fde0e2fe40114393b0d31579d201bd8	JCB 16 digit	33.6144721227165348	-112.113087035475672
32462	2020-06-22 03:42:40	2020-06-22	Jaye Denesik	jaye.denesik@geemail.com	Oklahoma City	Oklahoma	6011712401683491715	b6455812d909262a56f02a0820d00a8d	Voyager	35.5181626756120465	-97.6046065234940556
32463	2020-06-22 03:43:16	2020-06-22	Atha Konopelski-Rempel	atha.konopelski.rempel@geemail.com	New York	New York	869917054299415826	68e1a100911d7bcd9d671b7feba0f8c1	Mastercard	40.7573139447942339	-73.9262852290075188
32464	2020-06-22 03:47:29	2020-06-22	Tawny Lindgren-Bechtelar	tawny.lindgren.bechtelar@geemail.com	Buffalo	New York	3088157497914606503	62aa5c3e53b063b5e42090d86857fca2	Mastercard	42.8545880301110458	-78.9562639504138417
32465	2020-06-22 03:52:03	2020-06-22	Samie Okuneva	samie.okuneva@warmmail.com	Clarksville	Tennessee	6011384795273041583	c8f19efbccfa3370c687fd68a9d0978b	American Express	36.5707016217183352	-87.3379356345113393
32466	2020-06-22 03:52:55	2020-06-22	Rozanne Bernier	rozanne.bernier@warmmail.com	Norwalk	California	4205116221494690	66cc33eff59292ca7eb7538a7fed4667	Mastercard	33.8477525557972498	-118.033030806718401
32467	2020-06-22 03:54:55	2020-06-22	Brandt Douglas Jr.	brandt.douglas.jr.@warmmail.com	Columbus	Ohio	3049224080425900	4ea786b6a10a9980802f6a582f28d0b1	American Express	39.9243940791159844	-82.9912429007004988
32468	2020-06-22 03:58:05	2020-06-22	Dolph Mayert	dolph.mayert@geemail.com	San Francisco	California	4282831980550575	efb6c073cf5825a7f4a6c97cc9793dce	Diners Club / Carte Blanche	37.749958742966129	-122.472535130331551
32469	2020-06-22 04:07:12	2020-06-22	Sharla Pfeffer DDS	sharla.pfeffer.dds@geemail.com	Houston	Texas	589375296143789	8e30a32797878c74f64689596703c7c7	VISA 16 digit	29.8008606834881	-95.3406545130085163
32470	2020-06-22 04:09:15	2020-06-22	Jarred Dooley	jarred.dooley@geemail.com	Fresno	California	3528160726453461572	4ee6ce92829e637ca868baa0a2a0d4f3	JCB 16 digit	36.7826869974717496	-119.798530007117989
32471	2020-06-22 04:11:54	2020-06-22	Madaline Huels	madaline.huels@woohoo.com	Paterson	New Jersey	6011981594223713426	d304ca8cc243e96f1fd0f2b07826ea5e	Mastercard	40.824618984987211	-74.1122549764320269
32472	2020-06-22 04:23:30	2020-06-22	Miss Jayde Lang DVM	miss.jayde.lang.dvm@geemail.com	Berkeley	California	4169182644735964	bfe2e44ff37916683166ba77306cc11c	JCB 16 digit	37.8684734591747443	-122.27146358302447
32473	2020-06-22 04:28:45	2020-06-22	Rocky Emard Sr.	rocky.emard.sr.@geemail.com	St. Louis	Missouri	3710461907370748	3bc21d6823cae9bf98d7ed65f67ce3f2	VISA 13 digit	38.6959141334675252	-90.155599590624135
32474	2020-06-22 04:43:43	2020-06-22	Mrs. Thresa Friesen	mrs.thresa.friesen@geemail.com	San Jose	California	3112206565197178373	9255ab855d701c32d25afbde8fae7fc2	American Express	37.3626675543196498	-121.784404124015566
32475	2020-06-22 04:50:14	2020-06-22	Jaquan Rippin	jaquan.rippin@geemail.com	New York	New York	4396953242016972	d0fd37001014db83c0c6fa3b2efed472	JCB 16 digit	40.6081784492582045	-73.9154446075566085
32476	2020-06-22 04:51:13	2020-06-22	Nolan Jacobson	nolan.jacobson@geemail.com	Memphis	Tennessee	52861992633406166	f180ea8a071a664dd35e854d6892eec7	JCB 16 digit	35.1722150035735268	-89.9696889217734395
32477	2020-06-22 04:53:36	2020-06-22	Octavia Wolff	octavia.wolff@geemail.com	Phoenix	Arizona	6011600536198415389	a895bf9505140fa6301a18931317dfe0	American Express	33.583438655820494	-112.172741603332014
32478	2020-06-22 04:57:37	2020-06-22	Keely Wuckert	keely.wuckert@geemail.com	Fontana	California	3424344935629588	d49e081e3e52b2d37af247b88c0517fa	Mastercard	34.1853473143335478	-117.446993146678068
32479	2020-06-22 05:06:10	2020-06-22	Mrs. Rita Krajcik	mrs.rita.krajcik@warmmail.com	San Francisco	California	4663822190646294	9c738978763a795114951eaf39bbe74e	VISA 16 digit	37.7727922787974677	-122.449165059567562
32480	2020-06-22 05:15:07	2020-06-22	Burr Kutch	burr.kutch@geemail.com	San Francisco	California	4236103222246	2fd526cf036d1d6ac6456a5d860c36ec	VISA 13 digit	37.7463680669945205	-122.432903364124357
32481	2020-06-22 05:20:24	2020-06-22	Maricela Hessel	maricela.hessel@geemail.com	Charlotte	North Carolina	3337974772879146096	36abf0f47563bd2757328c4bd16a8b47	American Express	35.2322049298577014	-80.7469121142700317
32482	2020-06-22 05:20:25	2020-06-22	Council Huel	council.huel@geemail.com	Waterbury	Connecticut	3034352849615175	9c53da30f05f8d4269fe1e7c5435c698	JCB 15 digit	41.5990663604848123	-72.9533618170682274
32483	2020-06-22 05:36:43	2020-06-22	Selma Murphy	selma.murphy@geemail.com	Oklahoma City	Oklahoma	4786199568963417	ede5971f3f8f6d06783ab19149b17292	Mastercard	35.5611743353217875	-97.4438942876074492
32484	2020-06-22 05:40:08	2020-06-22	Lucinda Kessler	lucinda.kessler@woohoo.com	Wichita Falls	Texas	4067480115846788	6aed93acd3d9b6545165473ceba8edde	JCB 16 digit	33.9794709121070824	-98.4898650778379192
32485	2020-06-22 05:40:21	2020-06-22	Mylie Wiegand	mylie.wiegand@woohoo.com	Fargo	North Dakota	52710013137045989	c8b7cb0cfa6fb42beb2929621ee36bdb	Voyager	46.929419561032951	-96.9187818848490679
32486	2020-06-22 06:05:41	2020-06-22	Rex Schmitt	rex.schmitt@warmmail.com	Cape Coral	Florida	4243943408332	9b9fd3f234d0980cc3c1b85bc09d54a6	VISA 16 digit	26.587993161610143	-81.9048484720360506
32487	2020-06-22 06:12:01	2020-06-22	Bethel Stehr	bethel.stehr@woohoo.com	San Bernardino	California	51408578594536636	d854286db62c4f76bbb43dd95eb3b714	VISA 16 digit	34.2251433428175744	-117.214535164066035
32488	2020-06-22 06:32:16	2020-06-22	Bernard Blick	bernard.blick@geemail.com	Oakland	California	3112113214031927255	012df9da9e781cb1619f1aadf98d8a3f	VISA 16 digit	37.8125093384979323	-122.252750583572364
32489	2020-06-22 06:36:09	2020-06-22	Palma Morar	palma.morar@geemail.com	New Orleans	Louisiana	4191543526849	5410d5e493cb45d328ef5166bfdd75ed	VISA 16 digit	30.0335338623277828	-89.8970440905336261
32490	2020-06-22 06:42:48	2020-06-22	Neva Turner	neva.turner@warmmail.com	Thousand Oaks	California	180036994653498875	d44d2a50dbb05c9465852bf20f629300	American Express	34.1606914340324721	-118.872930585305028
32491	2020-06-22 06:45:14	2020-06-22	Mr. Fredrick Daugherty IV	mr.fredrick.daugherty.iv@geemail.com	San Francisco	California	4313640655305006	eeaa1d5787ed1e29e44f1667400ec3cc	American Express	37.7727040917707413	-122.40604256088929
32492	2020-06-22 06:54:52	2020-06-22	Shanelle Smitham-Beatty	shanelle.smitham.beatty@warmmail.com	Saint Paul	Minnesota	4421353185707258	43572510a86380e71b9d8377db9922e1	American Express	45.0255933248844045	-93.1227839480884398
32493	2020-06-22 06:56:58	2020-06-22	Jannie Fay	jannie.fay@woohoo.com	Allentown	Pennsylvania	3337908692019014528	6add0c45014f04f834bc367d4c0e5166	VISA 16 digit	40.578728754237666	-75.4803464564043907
32494	2020-06-22 07:01:54	2020-06-22	Randolf Miller	randolf.miller@geemail.com	Houston	Texas	4705851709105500	2ed2e16470a5a1a5ae84dabea5f0b6fc	VISA 16 digit	29.878234762706235	-95.436141073053335
32495	2020-06-22 07:04:48	2020-06-22	Hailee Hudson	hailee.hudson@warmmail.com	New York	New York	869961159923882419	dc0429a8f7e280b22844c81f638f70b0	VISA 16 digit	40.5933942423891239	-73.919356079761684
32496	2020-06-22 07:08:26	2020-06-22	Ms. Dorathy Champlin PhD	ms.dorathy.champlin.phd@geemail.com	Dallas	Texas	53140601426156499	f4db15c8ece17c86d1235e0ece6ad942	Maestro	32.8468066256765283	-96.7886482669468933
32497	2020-06-22 07:11:11	2020-06-22	Nehemiah Koss	nehemiah.koss@geemail.com	Pompano Beach	Florida	52631116826344328	63307a9c40eb33a364b9ccb106dd35c2	Discover	26.2481197401214388	-80.057120235481861
32498	2020-06-22 07:12:40	2020-06-22	Sunshine Denesik	sunshine.denesik@geemail.com	Clarksville	Tennessee	3088600508615144165	3d78d10bbfed1c0edcb65f7ed33fd860	VISA 16 digit	36.5064484734680548	-87.2657145886167882
32499	2020-06-22 07:21:34	2020-06-22	Miss Suzie Larkin	miss.suzie.larkin@geemail.com	Kent	Washington	3046891630990808	d8ed0b86f49a3b811ce474d1993ff157	Diners Club / Carte Blanche	47.4246198991890964	-122.125284360782061
32500	2020-06-22 07:35:38	2020-06-22	Americo Runolfsdottir	americo.runolfsdottir@geemail.com	San Francisco	California	4291005412058262	03d19d0c3049b3a27639e8dd97689595	Discover	37.7711429976333761	-122.425928276403639
32501	2020-06-22 07:39:41	2020-06-22	Scot Beer	scot.beer@geemail.com	Greensboro	North Carolina	869993084323177438	f29841e55d8e9d719fe988dcbc607784	Discover	36.0124741360194989	-79.7512313461843831
32502	2020-06-22 07:47:36	2020-06-22	Mr. Gavyn Kuhic	mr.gavyn.kuhic@geemail.com	Kansas City	Missouri	210062183313506999	8535fc5082de40dfabb0105d292b5f91	JCB 16 digit	39.0336326793603661	-94.5491418050360011
32503	2020-06-22 08:09:39	2020-06-22	Irene Weber-Simonis	irene.weber.simonis@woohoo.com	Oakland	California	3337340531841721775	0d83a78631b715c46eb7460ce0cc36de	JCB 15 digit	37.7912656077740507	-122.236799108135742
32504	2020-06-22 08:16:35	2020-06-22	Arturo Jenkins-Kuhlman	arturo.jenkins.kuhlman@geemail.com	Newport News	Virginia	4419734504866970	4b49e6b12c36bfdab192f000a507b925	VISA 13 digit	37.0618884286273271	-76.571549942789602
32505	2020-06-22 08:22:42	2020-06-22	Edward Zieme V	edward.zieme.v@geemail.com	Cape Coral	Florida	4981543139781696	e5f15d69643788a2f41eb7596bc0f1da	American Express	26.6818390557046996	-81.9503029490426229
32506	2020-06-22 08:23:40	2020-06-22	Miss Shea Adams	miss.shea.adams@geemail.com	Lafayette	Louisiana	3045227582784991	38ca826a2944b1edc6ba44d1d07001e9	VISA 16 digit	30.2590745507251455	-91.9295906663257512
32507	2020-06-22 08:33:58	2020-06-22	Miss Malvina Padberg DDS	miss.malvina.padberg.dds@geemail.com	Jacksonville	Florida	3476525916177921	250f8938e82b798fc3533902f3cbd5e3	Voyager	30.3986908309213817	-81.5660554030057057
32508	2020-06-22 08:36:36	2020-06-22	Ms. Savana Morissette	ms.savana.morissette@geemail.com	Des Moines	Iowa	3158315106289725439	4c9e440dd6b26000bc67681783b2fce3	VISA 13 digit	41.4928098840847639	-93.6318710472945241
32509	2020-06-22 08:45:37	2020-06-22	Lemmie Turner	lemmie.turner@woohoo.com	Phoenix	Arizona	3728799955483958	46f9f3b1fd3dc1ca9539f63c13bb1306	VISA 16 digit	33.5200970446623856	-112.103185863785825
32510	2020-06-22 08:50:40	2020-06-22	Xiomara Stark	xiomara.stark@geemail.com	Tuscaloosa	Alabama	6011345515852024885	28f3692ba309c07a1944df6d94d24b1f	JCB 16 digit	33.2340649395305618	-87.5220508973211082
32511	2020-06-22 08:51:35	2020-06-22	Adlai Flatley	adlai.flatley@geemail.com	Evansville	Indiana	3112178542732459398	13b6d059ca4c2da36dab4d1b102e8649	JCB 16 digit	37.9127445028301295	-87.5652159816518463
32512	2020-06-22 08:53:11	2020-06-22	Hallie Turcotte	hallie.turcotte@woohoo.com	Houston	Texas	3112191242777450716	d4636246ef4f1e564ca2181d06675e6e	JCB 15 digit	29.6998321748882539	-95.3505313168760438
32513	2020-06-22 08:54:27	2020-06-22	Andra Schmitt-Herzog	andra.schmitt.herzog@geemail.com	Houston	Texas	869962953501990407	48a63d6e5d10d0e82d3eace57a4e5c0c	Discover	29.8268126199565842	-95.4159935696996797
32514	2020-06-22 08:55:36	2020-06-22	Lorrayne Becker	lorrayne.becker@geemail.com	Phoenix	Arizona	4583510909364	6723dc03dfb063434df4fac16d27a962	Diners Club / Carte Blanche	33.5736582506380969	-112.055438423056529
32515	2020-06-22 08:56:26	2020-06-22	Cortez Bogisich	cortez.bogisich@woohoo.com	Tyler	Texas	060411549878798	4dfb43d009fe63cc29f8c14418e72ca1	Mastercard	32.2663865070372822	-95.212577165767172
32516	2020-06-22 08:59:44	2020-06-22	Dr. Blaine Rau Sr.	dr.blaine.rau.sr.@geemail.com	San Francisco	California	6011310854846229297	d388e3c795872b241cfe5d323e0c6876	Diners Club / Carte Blanche	37.7775025129385185	-122.502503713726327
32517	2020-06-22 09:28:11	2020-06-22	Rudolf Kiehn	rudolf.kiehn@geemail.com	Bellevue	Washington	3700326552546912	2c021583604e33a9a4957ab4e219ecce	American Express	47.5401258512582672	-122.246472327975553
32518	2020-06-22 09:44:47	2020-06-22	Gus Jenkins V	gus.jenkins.v@warmmail.com	Jackson	Mississippi	3462292785148766	149271305d4762e85e6be59b85fb5422	Discover	32.2851479239940673	-90.1242110139664305
32519	2020-06-22 09:46:38	2020-06-22	Mr. Gunnar Stehr	mr.gunnar.stehr@geemail.com	Anaheim	California	4360905922157	e0f82c565db1aa94d7e8fcd4cd0cc548	Voyager	33.772303374839943	-117.822773837644974
32520	2020-06-22 09:54:18	2020-06-22	Chace Franecki IV	chace.franecki.iv@geemail.com	Miami	Florida	3052869579574803	415f9be7e1413e1f5fe7789e037ff898	JCB 16 digit	25.7164164531182529	-80.1897472688801685
32521	2020-06-22 10:06:26	2020-06-22	Keely Konopelski-Walsh	keely.konopelski.walsh@warmmail.com	Abilene	Texas	3096570253413828638	6e45035801617ef1bba0c326cef8bbef	Discover	32.4285290763322323	-99.7121251036826521
32522	2020-06-22 10:16:53	2020-06-22	Melony Fritsch	melony.fritsch@geemail.com	Glendale	Arizona	6011489682219189888	cc24e9fc417e0561713045154584b9a9	JCB 16 digit	33.546758709637821	-112.090610597867141
32523	2020-06-22 10:17:49	2020-06-22	Harve Rolfson	harve.rolfson@geemail.com	Woodbridge	New Jersey	501879715959734	18d82366c39de84d5bcb4c8904fcc597	VISA 13 digit	40.4908699522417024	-74.3636113124757969
32524	2020-06-22 10:29:33	2020-06-22	Noma Bednar MD	noma.bednar.md@geemail.com	Buffalo	New York	4091521006408996	a0c1b6a153e4ea55d43f4fd4ffad54e0	VISA 13 digit	42.9649069874268008	-78.9042022003259547
32525	2020-06-22 10:44:31	2020-06-22	Lawanda Heaney PhD	lawanda.heaney.phd@woohoo.com	Corpus Christi	Texas	6011749661940448769	7c5f53b37b0ce2a40eb752c064ecce92	American Express	27.8312707508385202	-97.1082447584081478
32526	2020-06-22 10:44:41	2020-06-22	Katlyn Hahn DDS	katlyn.hahn.dds@geemail.com	Chicago	Illinois	4696236067731124	1d7407d585b57ec5e92e99b193eb78dd	VISA 16 digit	41.8002243712380519	-87.7504650812160207
32527	2020-06-22 10:47:45	2020-06-22	Celena Treutel	celena.treutel@geemail.com	New York	New York	4775012316573722	c53700b025424a056a5d5494ccf287b6	Maestro	40.6842677916157953	-73.9552294519625519
32528	2020-06-22 10:53:27	2020-06-22	Parley Nolan	parley.nolan@geemail.com	Laredo	Texas	55723314030664768	e67af36a67b6db3aa5466552d0e36e7b	Voyager	27.6510221896410009	-99.5866201922770529
32529	2020-06-22 11:06:30	2020-06-22	Shirleyann Gaylord	shirleyann.gaylord@geemail.com	Los Angeles	California	6011438837052332589	89863a948651e52744b4a4e4ea99f808	JCB 15 digit	34.0593674639105757	-118.342292309505112
32530	2020-06-22 11:07:48	2020-06-22	Garrick Quigley	garrick.quigley@geemail.com	Fort Worth	Texas	55883005264100273	35017995aa69d949d7d44cb33655ac25	JCB 15 digit	32.684291506610812	-97.255438686610006
32531	2020-06-22 11:18:06	2020-06-22	Lidie Rath	lidie.rath@warmmail.com	Fort Worth	Texas	3017437254951947	861740613b3d6d31cdc6073395d5d6dc	Maestro	32.7907532982118468	-97.3052956970695391
32532	2020-06-22 11:24:54	2020-06-22	Cherrelle Rohan	cherrelle.rohan@woohoo.com	Olathe	Kansas	4611508756350560	f41b5012024d0c64d71311aeac44a8ea	Voyager	38.9789353366598519	-94.7569340051785218
32533	2020-06-22 11:25:42	2020-06-22	Rhea Ritchie	rhea.ritchie@woohoo.com	Downey	California	3528762120276708371	be20082567df81e6f315bef593bd3827	Diners Club / Carte Blanche	33.9040170290291343	-118.119587862828368
32534	2020-06-22 11:32:41	2020-06-22	Kaliyah Bins	kaliyah.bins@geemail.com	New York	New York	3720277626126601	12264303182a0697144c92283ec4ed9d	JCB 16 digit	40.6455988600607938	-73.9247689567401949
32535	2020-06-22 11:42:33	2020-06-22	Beverlee Spinka	beverlee.spinka@geemail.com	Boston	Massachusetts	55484591563657801	b90f60a98deb3e3c2e15bd7fe5c01b2c	VISA 16 digit	42.3097532889507733	-70.9264898977194065
32536	2020-06-22 11:45:18	2020-06-22	Dr. Adison Johnston	dr.adison.johnston@warmmail.com	Phoenix	Arizona	3112890771346012494	b81b18adc86200a02f986f4841ce5269	JCB 16 digit	33.4788603364888573	-112.122295884734399
32537	2020-06-22 11:54:41	2020-06-22	Kirby Breitenberg	kirby.breitenberg@geemail.com	Berkeley	California	3528609562970713438	c5900b02490e721c8d172b094b920b14	JCB 16 digit	37.8839894956555128	-122.251319441795545
32538	2020-06-22 12:14:26	2020-06-22	Ahmed Gorczany	ahmed.gorczany@warmmail.com	Thornton	Colorado	53261660690691782	7345bc9bd27cdca3003668b678890143	JCB 16 digit	40.0186914194241226	-104.973671374439448
32539	2020-06-22 12:22:26	2020-06-22	Primus Walter-Luettgen	primus.walter.luettgen@geemail.com	New York	New York	4041066708394905	cca35c716c096e8257bbc7c570def65b	Voyager	40.6898965585269039	-73.9978461352072685
32540	2020-06-22 12:25:28	2020-06-22	Dr. Jovita Balistreri	dr.jovita.balistreri@geemail.com	San Francisco	California	53059844862446631	92986ecb644550bc6743fbbf77e31756	Diners Club / Carte Blanche	37.7681366110083374	-122.45506360596012
32541	2020-06-22 12:33:48	2020-06-22	Dr. Octavius Durgan DVM	dr.octavius.durgan.dvm@geemail.com	Los Angeles	California	3482110322219088	3cbb41b0ddddd89704bd61a4eb606624	Discover	34.1051372318394428	-118.450045595643289
32542	2020-06-22 12:36:31	2020-06-22	Jeff McCullough	jeff.mccullough@geemail.com	Oakland	California	869996442227247722	319a1a2f82c35e188f6d61e328af6ad3	VISA 16 digit	37.7680807173820341	-122.282039372569372
32543	2020-06-22 12:37:55	2020-06-22	Tate Roob	tate.roob@geemail.com	Miami	Florida	639078608313413	1e1e983a950f156f33a3fa4026f88b44	Maestro	25.6937589757747951	-80.3082751905418917
32544	2020-06-22 12:39:31	2020-06-22	Claudius Muller	claudius.muller@geemail.com	Portland	Oregon	210032149207841807	bd1869a6e608d67983d9b4cb1dc1a412	Maestro	45.5306556102242297	-122.634069941891369
32545	2020-06-22 12:43:25	2020-06-22	Miss Trish Langosh	miss.trish.langosh@geemail.com	McAllen	Texas	3158504438467903103	b00381fb67f3df8a7d0d1947ed1f0d95	VISA 16 digit	26.1835327600434411	-98.2499284562502027
32546	2020-06-22 12:48:51	2020-06-22	Dr. Ivy Prohaska	dr.ivy.prohaska@warmmail.com	Chula Vista	California	630404211549821	0c3bad94a3456c3063717a56eecb9807	VISA 13 digit	32.5843186855081441	-116.916066766879325
32547	2020-06-22 12:54:59	2020-06-22	Ryleigh Johnson-Runte	ryleigh.johnson.runte@geemail.com	Houston	Texas	4668747996365	562f18980607b72ae70bedc255428a01	Voyager	29.8719016428183757	-95.4606336869779994
32548	2020-06-22 12:56:06	2020-06-22	Loria Howell	loria.howell@geemail.com	Houston	Texas	676283476354598	92de46db0e3e3d6c83f49b6243c365fd	JCB 16 digit	29.7351864208079881	-95.4666931751664691
32549	2020-06-22 13:03:53	2020-06-22	Francisquita Cartwright	francisquita.cartwright@geemail.com	Mesa	Arizona	503899308095167	9b68363b848fa8d7fffaa0cf9e56fd2a	JCB 16 digit	33.3953862925205343	-111.620941454486541
32550	2020-06-22 13:14:16	2020-06-22	Ms. Yahaira Stiedemann	ms.yahaira.stiedemann@warmmail.com	Anchorage	Alaska	3442677448034285	2d63a0fc78fdeff8e4a875d08a23e1e4	VISA 16 digit	61.0783416954550944	-149.307703981141742
32551	2020-06-22 13:25:08	2020-06-22	Ginny Keeling	ginny.keeling@warmmail.com	Indianapolis	Indiana	55586615775791889	fd92546fc0fec70fe8f7158eb650a1be	Diners Club / Carte Blanche	39.8706864719286571	-86.0828875262957069
32552	2020-06-22 13:34:34	2020-06-22	Dr. Shane Streich	dr.shane.streich@woohoo.com	Columbus	Ohio	3096768000043811621	839aa669c83734c9cab1b76c62d58a8d	JCB 16 digit	39.9142997756179412	-82.8848705587677728
32553	2020-06-22 13:54:20	2020-06-22	Javon Klocko-Howell	javon.klocko.howell@geemail.com	San Antonio	Texas	4205363400897588	c9f0ce26115ade905058ed2354936dd8	JCB 16 digit	29.4172085396084952	-98.5706159634351735
32554	2020-06-22 13:56:33	2020-06-22	Leonardo Auer DDS	leonardo.auer.dds@geemail.com	New York	New York	210085198647837293	c331e7e967f518eae19b8a2e1affa980	VISA 13 digit	40.6460863210018744	-74.03718738652654
32555	2020-06-22 14:02:10	2020-06-22	Torry Torp-McClure	torry.torp.mcclure@geemail.com	Atlanta	Georgia	180014371033332395	0e47eda8f619886ba5d70b55a4b907a4	American Express	33.7354074850488459	-84.499732880112532
32556	2020-06-22 14:09:58	2020-06-22	Syble Gorczany	syble.gorczany@geemail.com	Jacksonville	Florida	4757691225668731	3e9068350b93a40a7b49099126675cb0	VISA 13 digit	30.3511230477184064	-81.7038860091552266
32557	2020-06-22 14:12:15	2020-06-22	Dejah Wiza	dejah.wiza@woohoo.com	Port St. Lucie	Florida	4135670749800247	22226352b36e41f92c63ff6c6e31027e	VISA 13 digit	27.1907732278708352	-80.4039603286042848
32558	2020-06-22 14:17:57	2020-06-22	Harlan Berge	harlan.berge@geemail.com	Killeen	Texas	3337623724238244414	9d35da5c0a9352de21fd0203833cf38a	VISA 16 digit	31.0968520030144617	-97.6998387933410726
32559	2020-06-22 14:18:59	2020-06-22	Colbert Stracke	colbert.stracke@warmmail.com	Sacramento	California	502069387608792	91a8915dcef6ecd9a0124f921efe416d	JCB 16 digit	38.6123517710048745	-121.54752827321775
32560	2020-06-22 14:37:23	2020-06-22	Shaniya Stanton	shaniya.stanton@geemail.com	Nashville	Tennessee	6011038249866124810	a0a5cbeaf4a5d712bf89a5c4bb6fa202	Voyager	36.2156352443743472	-86.7759814144484665
32561	2020-06-22 14:52:20	2020-06-22	Dr. Loring Ortiz	dr.loring.ortiz@geemail.com	Sterling Heights	Michigan	3337914017337997919	494653ed85c24127a82d567333cb72eb	JCB 15 digit	42.6586581126868722	-82.932565536691996
32562	2020-06-22 14:53:51	2020-06-22	Adalberto DuBuque	adalberto.dubuque@geemail.com	Tempe	Arizona	6011297654301159808	e611f35fb57b191802de5a2c1e0f35d0	Maestro	33.4617638910111026	-111.986765155618258
32563	2020-06-22 15:05:14	2020-06-22	Alexis Nicolas	alexis.nicolas@geemail.com	Columbus	Ohio	3784579675245049	13c5267706099743065b1772bd43c92b	VISA 16 digit	39.981616741563009	-82.9424267339289258
32564	2020-06-22 15:18:24	2020-06-22	Aleta Smitham	aleta.smitham@woohoo.com	Houston	Texas	4086846591989	b164cd5a4883fcddebff72f00f4cdec1	Diners Club / Carte Blanche	29.7415435057677335	-95.4586398534491707
32565	2020-06-22 15:21:00	2020-06-22	Lilian Mohr	lilian.mohr@woohoo.com	Sioux Falls	South Dakota	4985658858882164	5898932bc8825e6842a0ba8ff23cb54b	JCB 16 digit	43.4969127439048151	-96.7601179071869666
32566	2020-06-22 15:37:30	2020-06-22	Bynum Ward Jr.	bynum.ward.jr.@geemail.com	Birmingham	Alabama	210069824240807306	0cadef399e456feb384dd306c3d5d6cc	Voyager	33.6244892471261352	-86.842394616479055
32567	2020-06-22 15:40:00	2020-06-22	Jonnie Roob	jonnie.roob@geemail.com	Murrieta	California	4754276882638	c5ed62c6803051407e8990afc303669c	Voyager	33.6255506642259618	-117.15341316334866
32568	2020-06-22 15:40:12	2020-06-22	Dandre Romaguera	dandre.romaguera@geemail.com	Berkeley	California	3497497296147566	35724c9e2800988e630e249277e53114	Mastercard	37.8665536725039757	-122.249029102010226
32569	2020-06-22 15:40:48	2020-06-22	Jordyn Schimmel-Erdman	jordyn.schimmel.erdman@geemail.com	West Jordan	Utah	6011306120558738164	4947a5f99c5dab11e9e0f4e3615e040a	VISA 16 digit	40.6472727643582985	-112.025282441926379
32570	2020-06-22 15:41:01	2020-06-22	Prentice Gutmann-Kozey	prentice.gutmann.kozey@geemail.com	Chicago	Illinois	3112867129677896812	3940c9d2c3e6ef3eac69be3a94e71533	Discover	41.819610029722007	-87.7682107174333197
32571	2020-06-22 15:55:29	2020-06-22	Mrs. Armida Schowalter	mrs.armida.schowalter@geemail.com	Chicago	Illinois	3033192850805450	0d86d8ff580528e0cb15b254d4dbd68c	Maestro	41.8383292366120969	-87.6986716855812745
32572	2020-06-22 16:03:50	2020-06-22	Odette Connelly PhD	odette.connelly.phd@geemail.com	Chicago	Illinois	4064111566363733	ec107a7f0cf9a0b65d3255505feb0180	VISA 16 digit	41.7793139781173366	-87.6926011467847957
32573	2020-06-22 16:15:18	2020-06-22	Lish Reynolds-Marvin	lish.reynolds.marvin@woohoo.com	Sacramento	California	6011168241756250500	30c66bdfac7762df9126e68dd88a2585	Diners Club / Carte Blanche	38.4950844357986028	-121.56238371606581
32574	2020-06-22 16:19:21	2020-06-22	Jalynn Frami-Mertz	jalynn.frami.mertz@woohoo.com	Chicago	Illinois	3528457091488871960	77f1151b07225adc4356d4e5dd05541d	JCB 16 digit	41.747566753050684	-87.6015455673012866
32575	2020-06-22 16:19:47	2020-06-22	Ms. Ericka McCullough DDS	ms.ericka.mccullough.dds@geemail.com	Woodbridge	New Jersey	4618555404202803	77eee507fb8d27387841cccfa432a093	Discover	40.4798994489170596	-74.3472663901139015
32576	2020-06-22 16:49:01	2020-06-22	Jeb Heathcote-Cruickshank	jeb.heathcote.cruickshank@geemail.com	Anaheim	California	3158941806820551200	e863c2a187b95dbcd640d88ebac4c3a3	JCB 16 digit	33.9022750371433759	-117.726016497958824
32577	2020-06-22 16:53:52	2020-06-22	Mr. Ellison Kassulke	mr.ellison.kassulke@geemail.com	Sioux Falls	South Dakota	3528479039036228344	e9705786e19829a87b95991d9717d1c6	Voyager	43.606576785733175	-96.821254672778764
32578	2020-06-22 17:02:43	2020-06-22	Maybelle Greenfelder-Fahey	maybelle.greenfelder.fahey@geemail.com	New York	New York	3112341722269352420	6bec68e7deb8759eab851be41c01697a	Maestro	40.6884878517817725	-73.9068594090536237
32579	2020-06-22 17:04:02	2020-06-22	Mrs. Latisha Lowe	mrs.latisha.lowe@geemail.com	Kansas City	Kansas	54591425713829921	6f004ea1a9453a96b083dbd4076f8b3f	JCB 16 digit	39.1635253094974942	-94.6829690773442394
32580	2020-06-22 17:08:19	2020-06-22	Ariane Thompson-Reichel	ariane.thompson.reichel@geemail.com	Chicago	Illinois	210001784589536885	c57dc400b6b397dbee1d4664524e667e	Mastercard	41.8180645285476018	-87.6738807553455217
32581	2020-06-22 17:08:56	2020-06-22	Fred Langworth	fred.langworth@geemail.com	San Francisco	California	869948081708448406	028cc29194be3d43fa5aca2f9c35d5aa	JCB 16 digit	37.7665421101932921	-122.440526448968086
32582	2020-06-22 17:18:10	2020-06-22	Carsen Rowe	carsen.rowe@woohoo.com	Washington	District of Columbia	4140617401473030	85f055f669de4b1f199c0cb8e679ce2c	JCB 16 digit	38.8108081918474284	-77.0324425185777244
32583	2020-06-22 17:21:37	2020-06-22	Cassie Krajcik	cassie.krajcik@geemail.com	San Francisco	California	3028809121057034	96f0abc046f9eacf512e64c4c3119169	VISA 13 digit	37.7738209359298764	-122.430277553084153
32584	2020-06-22 17:34:44	2020-06-22	Mr. John Pollich MD	mr.john.pollich.md@geemail.com	San Francisco	California	3481358656351677	ec7b75fb2d621ac6505a80cb2ceae01e	VISA 16 digit	37.7614924933827609	-122.457038190479295
32585	2020-06-22 17:40:06	2020-06-22	Mrs. Kaitlin Farrell	mrs.kaitlin.farrell@woohoo.com	Oakland	California	3337156581113933767	22043c2fd25c955ed2c2ee0312feafbe	Maestro	37.8066316914181328	-122.264860830431331
32586	2020-06-22 17:45:33	2020-06-22	Randle Stroman	randle.stroman@geemail.com	San Francisco	California	3112614309485667581	a016af0cd57389621eecc0be707bb0e2	Discover	37.8033676344025906	-122.445881393250261
32587	2020-06-22 17:48:59	2020-06-22	Mathew Bednar	mathew.bednar@woohoo.com	Houston	Texas	502029757264808	5a74fe234536c5e0cf483c6f123c7953	Diners Club / Carte Blanche	29.8625162343107178	-95.4804081226713919
32588	2020-06-22 17:51:39	2020-06-22	Marlin Hauck MD	marlin.hauck.md@woohoo.com	Rancho Cucamonga	California	180019915106955287	9467f907c491fc2f0e1cc1175ea5a508	VISA 16 digit	34.0917201647993195	-117.664038284216815
32589	2020-06-22 17:56:33	2020-06-22	Jarod Ratke	jarod.ratke@woohoo.com	Toledo	Ohio	4804975059940826	1bf44f2d25e921e74d327cb72f825f39	JCB 15 digit	41.6458923351656622	-83.6282892112020448
32590	2020-06-22 18:09:27	2020-06-22	Tony Gulgowski II	tony.gulgowski.ii@geemail.com	Chicago	Illinois	54532597064121546	393b18fe4f406434bdf6328a8be955c0	American Express	41.8104328074794296	-87.5915115586511774
32591	2020-06-22 18:26:23	2020-06-22	Wayde Mayer-Abernathy	wayde.mayer.abernathy@geemail.com	West Valley City	Utah	4073240156711164	df88510fb53e9bf20bdbb94f17d0f30c	JCB 16 digit	40.781624769348646	-112.041346018969264
32592	2020-06-22 18:45:28	2020-06-22	Miss Tiesha Nicolas MD	miss.tiesha.nicolas.md@geemail.com	Sunnyvale	California	51688097467759382	76f69968e351ceca2eaac69936bc727a	Diners Club / Carte Blanche	37.403118940348925	-122.00451679627524
32593	2020-06-22 19:00:29	2020-06-22	Eustace Bauch-Wuckert	eustace.bauch.wuckert@warmmail.com	Fort Worth	Texas	4985060988546704	87ac488d502d223e35a63cacf484d849	Diners Club / Carte Blanche	32.7269814388416691	-97.3860825531005787
32594	2020-06-22 19:05:19	2020-06-22	Lora Schulist	lora.schulist@geemail.com	Grand Rapids	Michigan	210083227783346546	0106239fc017e9b54513a4b190683425	Discover	43.0135366137873376	-85.5660862769600072
32595	2020-06-22 19:07:07	2020-06-22	Mr. Jermey Quitzon II	mr.jermey.quitzon.ii@warmmail.com	Greensboro	North Carolina	210027049107305175	4d403402f442aebcb2b3a49818549855	JCB 15 digit	36.0481567179899685	-79.7659967621769681
32596	2020-06-22 19:11:28	2020-06-22	Abdul Feest	abdul.feest@warmmail.com	Huntington Beach	California	55746116844836349	38c8897f0eaf6164364922f83ebd7e53	VISA 13 digit	33.7441185225307976	-118.060537846491854
32597	2020-06-22 19:19:10	2020-06-22	Aryanna Hegmann	aryanna.hegmann@geemail.com	Henderson	Nevada	869963961666389546	b087137d459bfefe47aee99afa64b1fc	American Express	36.0936621667750188	-114.965503177714353
32598	2020-06-22 19:22:44	2020-06-22	Kristoffer Stehr	kristoffer.stehr@geemail.com	San Diego	California	4548845424501036	ea060e0b0640c157e95175fc294f3b04	VISA 16 digit	32.8820097003664813	-117.231767368912699
32599	2020-06-22 19:23:41	2020-06-22	Agnes Kertzmann-Sanford	agnes.kertzmann.sanford@woohoo.com	Los Angeles	California	3088498946422622020	c3a7df204e4ae1de459d26e6cecc3043	Discover	34.0770997939497207	-118.367865225159747
32600	2020-06-22 19:25:50	2020-06-22	Maegan Zulauf	maegan.zulauf@woohoo.com	Fort Wayne	Indiana	180083670756177481	05b57a8b50288d6dcf600ba2341f508f	Mastercard	41.1052225288253297	-85.1174002799890985
32601	2020-06-22 19:37:38	2020-06-22	Rich Ondricka	rich.ondricka@geemail.com	New York	New York	3755010259064205	1d690094def18895163e70743be82b12	American Express	40.6967226393744355	-73.8868591678690194
32602	2020-06-22 20:07:36	2020-06-22	Araceli Marquardt	araceli.marquardt@geemail.com	Los Angeles	California	869952076616951114	8b897a517d9f5d1c14b94a99b3122437	JCB 15 digit	33.9882642056658852	-118.500493199889732
32603	2020-06-22 20:08:44	2020-06-22	Aaden Jerde	aaden.jerde@geemail.com	Albuquerque	New Mexico	4316479822108	3d713cec4139650c22ea261a35f54002	Maestro	35.1878418159339574	-106.702726538300141
32604	2020-06-22 20:10:23	2020-06-22	Mr. Shaquille Paucek	mr.shaquille.paucek@geemail.com	San Francisco	California	676358167408564	b92ff0a3345f8037d8eebce9a6ce53f6	Diners Club / Carte Blanche	37.7497581560173643	-122.394079895169284
32605	2020-06-22 20:19:40	2020-06-22	Mr. Andon Batz III	mr.andon.batz.iii@warmmail.com	Pompano Beach	Florida	4122120039443	b00686a3cfe292b77372a2a42ce2dfc7	Voyager	26.2315507994763522	-80.1071937340624629
32606	2020-06-22 20:25:39	2020-06-22	Wiliam Bernier-Herman	wiliam.bernier.herman@geemail.com	Oakland	California	4896056583694	fdccc4824ce13d0b7df70f0a424a33e0	VISA 16 digit	37.8271610481198763	-122.309063246733686
32607	2020-06-22 20:31:04	2020-06-22	Adline Kuhn	adline.kuhn@warmmail.com	Round Rock	Texas	869947230876790203	d8d26966d0d276699b5008c6abdc45d4	JCB 16 digit	30.4734073713094027	-97.760624590734011
32608	2020-06-22 20:40:24	2020-06-22	Paris Pagac	paris.pagac@geemail.com	Chicago	Illinois	6011826348000349899	6029805f3c31d83affb593d6592676b8	Mastercard	41.8656920632649232	-87.7786439918011325
32609	2020-06-22 20:43:23	2020-06-22	Miguelangel Witting	miguelangel.witting@woohoo.com	New York	New York	3112969792562245952	501c72bdac7cfb5c14a13f6a8077e90d	Diners Club / Carte Blanche	40.7126385155823058	-73.9112163500290364
32610	2020-06-22 20:56:07	2020-06-22	Rian Frami	rian.frami@geemail.com	Milwaukee	Wisconsin	639037291375451	64a431f7cf38aec5d4b4b509b627148e	Maestro	43.051897487658259	-87.8996840948805271
32611	2020-06-22 21:02:57	2020-06-22	Ms. Queen Tromp	ms.queen.tromp@warmmail.com	Chicago	Illinois	4518162243526475	2016ae2b554f15d42d07a01650fca641	JCB 15 digit	41.8568865218035882	-87.7466689820431185
32612	2020-06-22 21:09:31	2020-06-22	Lorri Bogisich	lorri.bogisich@geemail.com	San Antonio	Texas	869951705663510628	2aa467c1feb8d5dce720d649218e4279	VISA 16 digit	29.5068149753917019	-98.4689418504782026
32613	2020-06-22 21:17:46	2020-06-22	Brock Ryan-Homenick	brock.ryan.homenick@warmmail.com	Washington	District of Columbia	3158580716275054301	fe811943dec4464dcf0590a1ea5afb30	Voyager	38.9321692358501252	-76.9798414130907531
32614	2020-06-22 21:21:26	2020-06-22	Concepcion Gorczany	concepcion.gorczany@geemail.com	Greeley	Colorado	180036060763027267	97c3a3d6a0288cc08ef75a6885bb06bc	Mastercard	40.5036259245660162	-104.682454205428058
32615	2020-06-22 21:34:43	2020-06-22	Doc McGlynn-Carroll	doc.mcglynn.carroll@geemail.com	Los Angeles	California	52286743205007131	b8eb24c2bf794567e7661eb0b4e915fd	Voyager	33.9393225510936176	-118.332602626876152
32616	2020-06-22 21:41:28	2020-06-22	Kristin Stiedemann PhD	kristin.stiedemann.phd@geemail.com	Oakland	California	4049005168353	a5a8954aaf8ce91822e27bd451822f64	American Express	37.8067607548766915	-122.221275151125639
32617	2020-06-22 21:45:22	2020-06-22	Mohammad Satterfield	mohammad.satterfield@warmmail.com	Oakland	California	869915237063906995	7dab17c617710faa6d061584bdd7034d	JCB 16 digit	37.816792490237674	-122.254586273939225
32618	2020-06-22 21:57:27	2020-06-22	Miss Trudie Larkin DDS	miss.trudie.larkin.dds@warmmail.com	San Francisco	California	3158229178324183754	d6c84e9edd31b0b024325270ce0c5122	VISA 13 digit	37.750123692123509	-122.430203517442578
32619	2020-06-22 22:03:43	2020-06-22	Freeda Wehner MD	freeda.wehner.md@warmmail.com	Jersey City	New Jersey	210053888429080686	78ab8babf8bc4cc98587606d4297d0cb	Diners Club / Carte Blanche	40.6122281727787069	-73.9880165608089442
32620	2020-06-22 22:08:40	2020-06-22	Erika Blanda-Huel	erika.blanda.huel@geemail.com	Yonkers	New York	4789293072544925	bf1f12775528e1d3d411fb1d9a725f93	VISA 16 digit	40.9841637456990782	-73.883895880670849
32621	2020-06-22 22:30:12	2020-06-22	Micky Osinski	micky.osinski@woohoo.com	West Palm Beach	Florida	3158613074902691777	d39149117bbfb2fc14b7f625b9dac535	JCB 15 digit	26.7014208896864211	-80.1866012029185953
32622	2020-06-22 22:41:36	2020-06-22	Dr. Virgil Kirlin Jr.	dr.virgil.kirlin.jr.@geemail.com	Atlanta	Georgia	53667428018211604	aeed3c6f86fbc6713545eb0b217ef381	VISA 16 digit	33.847086549438167	-84.3721749773759484
32623	2020-06-22 22:44:14	2020-06-22	Carroll Schroeder	carroll.schroeder@warmmail.com	Provo	Utah	3745725957030785	3e650638582b4157537c25bef7321128	Discover	40.285618460576238	-111.733063199431825
32624	2020-06-22 22:55:46	2020-06-22	Quintin Cummerata	quintin.cummerata@geemail.com	Hartford	Connecticut	210066842345818526	6200cf10a9d3f8221e0d78e20c7197d6	JCB 16 digit	41.8234387924909612	-72.7287986543852867
32625	2020-06-22 22:58:46	2020-06-22	Alyvia Glover	alyvia.glover@geemail.com	Jersey City	New Jersey	3485656425928790	d2c7ade975422b4f2abfb44e05c1c30c	VISA 16 digit	40.6628995693229101	-74.1443785321854136
32626	2020-06-22 23:01:16	2020-06-22	Dr. Marjory Stroman	dr.marjory.stroman@woohoo.com	Baltimore	Maryland	54891398226913135	297a63962e861b12407b7122de24598c	JCB 16 digit	39.209928242815657	-76.6034357600398437
32627	2020-06-22 23:02:58	2020-06-22	Mr. Loyal Kub	mr.loyal.kub@geemail.com	Hialeah	Florida	180006159682594872	f55a148a080c8e5cc74c7e3043a67256	Maestro	25.8776654952183378	-80.3735663707271186
32628	2020-06-22 23:03:28	2020-06-22	Samira Collier	samira.collier@geemail.com	New York	New York	3014067824626209	8cb973b6638f7323fd804fcf9212e569	Diners Club / Carte Blanche	40.7436977394614388	-74.0266797046072753
32629	2020-06-22 23:18:57	2020-06-22	Delma Nitzsche III	delma.nitzsche.iii@geemail.com	Allentown	Pennsylvania	4168227679745452	863087dd17e14a4d31a3f73a6732527d	JCB 15 digit	40.5797945321783473	-75.5669649552568785
32630	2020-06-22 23:24:26	2020-06-22	Stephon Rowe	stephon.rowe@woohoo.com	St. Petersburg	Florida	4319213450814962	549541b0d4d5cd4557db49a67e26d10d	JCB 16 digit	27.7410863227564839	-82.5710355087540933
32631	2020-06-22 23:50:58	2020-06-22	Sannie Homenick-Jast	sannie.homenick.jast@geemail.com	New York	New York	3158170290923401377	22e9d50a8419f34bb5e9646e45fff6a5	VISA 16 digit	40.6178048224877557	-73.9636655865132724
32632	2020-06-22 23:52:29	2020-06-22	Dr. Margretta Lind	dr.margretta.lind@geemail.com	St. Louis	Missouri	4451106136043287	187c70183669ed5188817b2d7413576b	JCB 15 digit	38.6838277747545405	-90.2777606333144007
32633	2020-06-23 00:15:26	2020-06-23	Ernestine Grimes DVM	ernestine.grimes.dvm@woohoo.com	Aurora	Illinois	4088288644128858	b90d782c5e60e1d9b4cf2f0fb6641376	JCB 15 digit	41.7758920663725561	-88.3853611301559852
32634	2020-06-23 00:27:03	2020-06-23	Rayshawn Beahan	rayshawn.beahan@warmmail.com	Chandler	Arizona	6011450545734876211	a81ebcd42b741559f7504beb7e523cb8	JCB 15 digit	33.2752766602296361	-111.808032086293778
32635	2020-06-23 00:33:46	2020-06-23	Dr. Leonora Berge	dr.leonora.berge@geemail.com	Philadelphia	Pennsylvania	4021245657858946	083ed99952577203d53c6bc7d37ac134	Discover	39.9246719107922132	-75.0742490238409488
32636	2020-06-23 00:40:49	2020-06-23	Toby Hettinger	toby.hettinger@warmmail.com	New York	New York	3449209228482683	b4fb41e351a76e5be9620c9abb82400d	Mastercard	40.5723669367600195	-73.938845113235331
32637	2020-06-23 00:47:21	2020-06-23	Briana Emard	briana.emard@woohoo.com	San Diego	California	3716140810149621	cda585b7164a7170bc75d54163784cea	Discover	32.8340659338582341	-117.118511555474257
32638	2020-06-23 01:00:03	2020-06-23	Jelani Cole MD	jelani.cole.md@geemail.com	San Francisco	California	3470433845964293	e29994a3a3ee51b63b89dc2577e465e2	Mastercard	37.7901520340855228	-122.414509560933809
32639	2020-06-23 01:01:20	2020-06-23	Blossom Bergnaum PhD	blossom.bergnaum.phd@geemail.com	Houston	Texas	6011114975773289539	2b5974b3c4a91131d3d4eac89d11ee47	Voyager	29.772066572642327	-95.3767354248572161
32640	2020-06-23 01:20:03	2020-06-23	Miss Frederica Balistreri DDS	miss.frederica.balistreri.dds@geemail.com	Richmond	California	3011662409624869	f7bedb5663c541bc742a2725af6a389e	Discover	38.0173440531317155	-122.261867795730382
32641	2020-06-23 01:25:08	2020-06-23	Damian Gutmann	damian.gutmann@woohoo.com	Grand Prairie	Texas	3096054315940613877	902b75eb0214893a11c6c0ab0e092505	JCB 16 digit	32.6671941076923176	-97.0913173499856157
32642	2020-06-23 01:28:59	2020-06-23	Rosia Mraz-Gaylord	rosia.mraz.gaylord@geemail.com	North Charleston	South Carolina	3050312557407557	8e98383db7c7f0cfc61314f1f9345c41	VISA 16 digit	33.0121105697631805	-80.0910119707789221
32643	2020-06-23 01:36:31	2020-06-23	Ms. Erica Rolfson DDS	ms.erica.rolfson.dds@woohoo.com	Palm Bay	Florida	6011341500127641642	4d9f33a006262e82bd4d21fd42480580	American Express	28.0347626359522373	-80.6488716557458076
32644	2020-06-23 01:43:33	2020-06-23	Deangelo Lebsack-Jones	deangelo.lebsack.jones@geemail.com	Los Angeles	California	3096463778925253735	038f18dfe3b9d344b336ba707a52d039	Diners Club / Carte Blanche	34.0648620215576088	-118.446686242520059
32645	2020-06-23 01:45:25	2020-06-23	Emeline Bernhard-Legros	emeline.bernhard.legros@warmmail.com	San Francisco	California	3112913612115304147	560327d8848616181f023002ba1ed0ba	Voyager	37.7793418827267686	-122.441301841643693
32646	2020-06-23 02:02:24	2020-06-23	Gillie Altenwerth	gillie.altenwerth@woohoo.com	Vallejo	California	4307966783797220	b4d83b8b4ef4e2ef0c29120733c2beeb	Maestro	38.0775021915879108	-122.219365524627264
32647	2020-06-23 02:15:29	2020-06-23	Johnny Orn	johnny.orn@geemail.com	Santa Ana	California	4150801736593665	aec9080fa3b67f5d5bae7295f6fdcae5	Diners Club / Carte Blanche	33.6371490102365627	-117.905616271767755
32648	2020-06-23 02:22:20	2020-06-23	Lorenzo Monahan	lorenzo.monahan@geemail.com	San Francisco	California	869938968866606605	c710eec0d01e50914c5ae826dbb4160c	Maestro	37.7567031905023427	-122.423512354598131
32649	2020-06-23 02:30:58	2020-06-23	Jennette Mante	jennette.mante@woohoo.com	San Francisco	California	3337106506214142647	c37bef1126ddecc68cb6e9cfe175cf09	JCB 15 digit	37.7713328213856201	-122.440719037302017
32650	2020-06-23 02:38:55	2020-06-23	Paola Reynolds-Howe	paola.reynolds.howe@woohoo.com	Los Angeles	California	6011669256308773340	807c14d924f234338c83190e3037ef90	JCB 15 digit	34.0187555477354664	-118.369852409650747
32651	2020-06-23 02:51:44	2020-06-23	Maximo Cole DDS	maximo.cole.dds@geemail.com	Anchorage	Alaska	6011600064226654630	9501937bd6cdb4199b79599f6dbb1afc	Voyager	61.1978268026590371	-149.25248888699636
32652	2020-06-23 02:54:01	2020-06-23	Mr. Rich Purdy Sr.	mr.rich.purdy.sr.@woohoo.com	San Francisco	California	6011699763914064083	c72122cbc6513b4a30836f50e03a4cc1	JCB 15 digit	37.7973566802687202	-122.434557317955992
32653	2020-06-23 03:16:57	2020-06-23	Ms. Billye Frami PhD	ms.billye.frami.phd@geemail.com	Los Angeles	California	53255018342743238	bb70c7495a2adaaf824d5492f8037b07	American Express	34.0040274549607133	-118.348281234921131
32654	2020-06-23 03:33:31	2020-06-23	Mell Morissette	mell.morissette@geemail.com	Lexington	Kentucky	4149003478316728	d42132bb3450ae0694585be1fe5da3d2	Discover	38.0778401380747553	-84.5050125928029416
32655	2020-06-23 03:53:15	2020-06-23	Greene Runolfsson-Hackett	greene.runolfsson.hackett@geemail.com	Austin	Texas	180056561971620830	d19bf2553a8259366101853a11eeabb0	American Express	30.2980835017409156	-97.839144022041566
32656	2020-06-23 03:58:37	2020-06-23	Tye Homenick-Leffler	tye.homenick.leffler@warmmail.com	New York	New York	3337087189270164608	afa93feaf636f90e6a457db9d0c1347d	Diners Club / Carte Blanche	40.6727706692405064	-73.9933174870803896
32657	2020-06-23 04:06:09	2020-06-23	Whitney Wolf	whitney.wolf@geemail.com	Columbia	Missouri	54402299468277035	d64b94e771097561b114f67d327504b0	Discover	39.0025492675018128	-92.283729483425347
32658	2020-06-23 04:10:35	2020-06-23	Mallory Carter	mallory.carter@warmmail.com	Pittsburgh	Pennsylvania	3337455392642575428	8bebd7139ec83f0f8f87a87d1a5b2b51	JCB 16 digit	40.3867454916659696	-79.9272995660252974
32659	2020-06-23 04:22:52	2020-06-23	Kathern Parisian	kathern.parisian@geemail.com	Louisville	Kentucky	3088770519820135447	f7eb52ab954f545aa676d3b00b587e17	Maestro	38.1029421024393287	-85.6783734481386858
32660	2020-06-23 04:26:22	2020-06-23	Dr. Ah Cormier	dr.ah.cormier@geemail.com	New York	New York	676260848947630	8c42c4e6214cbee4ec7368290ce160e3	VISA 13 digit	40.6078731179926535	-73.9913788096409206
32661	2020-06-23 04:41:46	2020-06-23	Yaritza Kirlin PhD	yaritza.kirlin.phd@geemail.com	New York	New York	4655545231692924	abb6a589f67f14ab80b5cb431b3349d1	JCB 15 digit	40.6258230538796639	-73.9782161075051903
32662	2020-06-23 04:49:12	2020-06-23	Dr. Jamin Trantow Jr.	dr.jamin.trantow.jr.@geemail.com	Phoenix	Arizona	3466920507753259	e5b395c97a61fa1594a206c9a878796e	JCB 15 digit	33.6082099096316895	-112.036120732680345
32663	2020-06-23 05:20:24	2020-06-23	Neely Satterfield PhD	neely.satterfield.phd@geemail.com	New York	New York	180061723562919319	8841b6d5161ff21734b493c73a01c6d3	Maestro	40.7548966610096386	-73.9504700861301245
32664	2020-06-23 05:25:07	2020-06-23	Joretta Zemlak	joretta.zemlak@woohoo.com	Honolulu	Hawaii	3158482819531167310	6b7aff5914b04191b2bd524dfbb0c7c3	Maestro	21.2862808672461661	-157.862679098334524
32665	2020-06-23 05:33:45	2020-06-23	Tobi Bauch	tobi.bauch@geemail.com	San Francisco	California	3786474141971436	100672b45e21400eb5f094183504a9c0	VISA 16 digit	37.7830192607080591	-122.440974956198588
32666	2020-06-23 05:48:31	2020-06-23	Brandi Marvin	brandi.marvin@geemail.com	Oakland	California	6011423658269658252	f240a7378796f5642a2dd971c1f965e3	JCB 16 digit	37.772957759447479	-122.241120941780096
32667	2020-06-23 05:49:28	2020-06-23	Dwayne Jakubowski	dwayne.jakubowski@geemail.com	New York	New York	6011938165096937105	431565d96c7043e3452ca60edeac1fa6	VISA 13 digit	40.6749186509978031	-73.9087383314397215
32668	2020-06-23 05:50:05	2020-06-23	Ms. Georgiann Abernathy DDS	ms.georgiann.abernathy.dds@warmmail.com	Elk Grove	California	4001523530812	0f5829ec1800978cf3c84a42618b61dd	Maestro	38.5037875823959723	-121.293031477453198
32669	2020-06-23 05:50:49	2020-06-23	Mr. Jamie Runolfsdottir MD	mr.jamie.runolfsdottir.md@woohoo.com	Chicago	Illinois	180010183275383539	77c7010d04adbc6fc7e5a70b87cd93c9	VISA 13 digit	41.7939605931587508	-87.7633550487022802
32670	2020-06-23 05:57:19	2020-06-23	Darwyn Hettinger	darwyn.hettinger@geemail.com	Oklahoma City	Oklahoma	3088014966958003507	362711f1ee33d5746e5bf0a30fd5ea76	VISA 16 digit	35.4356065477620845	-97.494660777821025
32671	2020-06-23 06:01:09	2020-06-23	Dr. Nestor Gerhold DVM	dr.nestor.gerhold.dvm@geemail.com	New York	New York	3717205807838970	0abef298026ea5ba3337947e23b6eebb	VISA 16 digit	40.5899738291501961	-73.9018019274238469
32672	2020-06-23 06:05:43	2020-06-23	Lacie Bradtke-Rolfson	lacie.bradtke.rolfson@woohoo.com	Charlotte	North Carolina	4204423100929882	1bf07f1e7c021500b384736bbd9eb82a	VISA 13 digit	35.1276328545782732	-80.843054123263812
32673	2020-06-23 06:16:14	2020-06-23	Erik Fahey	erik.fahey@geemail.com	Anaheim	California	3112709523176851454	a392ee1f4a7d15ba6c6d5f02fb6f8faf	Discover	33.7986110448203974	-117.834369064236427
32674	2020-06-23 06:17:53	2020-06-23	Cliff Abshire	cliff.abshire@geemail.com	San Francisco	California	55768775186510441	66fb1ada1964c26083576fa98e1892cb	American Express	37.7575743516407769	-122.448149214711677
32675	2020-06-23 06:18:18	2020-06-23	Silvester Mitchell	silvester.mitchell@woohoo.com	New York	New York	869936189160371141	ca1ec3c05e9a383cb56f3feef6e9fd92	American Express	40.6460633435975751	-73.8850222818449112
32676	2020-06-23 06:38:54	2020-06-23	Dr. Auguste Harvey DVM	dr.auguste.harvey.dvm@warmmail.com	Sioux Falls	South Dakota	869982984132575123	ff714598c7aa94194976f80371af25a3	Diners Club / Carte Blanche	43.5706630642611543	-96.6745344325136386
32677	2020-06-23 06:40:44	2020-06-23	Lulu Hayes	lulu.hayes@geemail.com	Fresno	California	3528225632454279885	5e4c4130259bdd7db9ebdc375180b206	VISA 13 digit	36.7447186775378896	-119.713059946486354
32678	2020-06-23 06:41:40	2020-06-23	Dr. Dwayne Strosin DDS	dr.dwayne.strosin.dds@geemail.com	Killeen	Texas	51360341744849227	181d35f147369624084afecd0bf0bc90	Voyager	31.0997175662077971	-97.7283179330807172
32679	2020-06-23 06:43:40	2020-06-23	Mrs. Itzel Rippin PhD	mrs.itzel.rippin.phd@geemail.com	Portland	Oregon	3158575917502950108	3ce4d1a124c32e298e91d10904890954	JCB 15 digit	45.4525145599972475	-122.667479711398485
32680	2020-06-23 06:43:56	2020-06-23	Myrl Kunde	myrl.kunde@geemail.com	Moreno Valley	California	180085923717802012	1546eaf6a629adb23086f6e6f9ad7ff9	Mastercard	33.9915381717953835	-117.262509601886194
32681	2020-06-23 06:46:43	2020-06-23	Keenan Mraz-Tremblay	keenan.mraz.tremblay@geemail.com	Honolulu	Hawaii	180083287205288262	06af96b831ba981858972eaf91ba26a1	JCB 15 digit	21.3260327330540882	-157.945390877381328
32682	2020-06-23 06:47:05	2020-06-23	Filomena Kshlerin	filomena.kshlerin@warmmail.com	Brownsville	Texas	4923956611282473	a394762708a9f23b72ee4fab09767a2a	JCB 16 digit	26.022328062875566	-97.3617053794860823
32683	2020-06-23 06:55:02	2020-06-23	Jeanna Miller	jeanna.miller@woohoo.com	Jackson	Mississippi	6011434035366819235	1dcd1235b90995b43b3d3da2b84fee77	JCB 16 digit	32.301117110875623	-90.1372120163377417
32684	2020-06-23 06:58:53	2020-06-23	Dwane Kutch DDS	dwane.kutch.dds@geemail.com	Seattle	Washington	4626411186168	f3f8651ba4bdcf595f059a69b49b6af6	VISA 16 digit	47.6777027706075458	-122.258319292489062
32685	2020-06-23 07:04:30	2020-06-23	Dr. Halle Runolfsdottir	dr.halle.runolfsdottir@geemail.com	Los Angeles	California	6011206797975423800	ddad3cfda4ffbed0230d97cb855e4bb4	VISA 13 digit	33.9449908885970686	-118.381140692903841
32686	2020-06-23 07:05:08	2020-06-23	Solon Beer	solon.beer@woohoo.com	Washington	District of Columbia	180011838834054652	bd5d4fafc7c97b02a64480963f3b2f07	Maestro	38.9222770693510753	-76.959461722031989
32687	2020-06-23 07:27:53	2020-06-23	Dr. Cayla Cruickshank	dr.cayla.cruickshank@geemail.com	Los Angeles	California	3033687847788115	1573e6c2fca54a92a71f4228525865ab	JCB 15 digit	33.9982130017463078	-118.341512596094233
32688	2020-06-23 07:51:52	2020-06-23	Adilene Graham	adilene.graham@warmmail.com	Oakland	California	4811366812642	34a45536d2bc7f15a3684d35ee7b09cc	American Express	37.7940826700021546	-122.30489269284638
32689	2020-06-23 08:16:32	2020-06-23	Keith Leffler	keith.leffler@geemail.com	Virginia Beach	Virginia	502058195013790	965dc24022975e543ffe326243468ea5	VISA 13 digit	36.7977033215761224	-76.0412864903591554
32690	2020-06-23 08:18:32	2020-06-23	Wilton Cummings	wilton.cummings@woohoo.com	Oakland	California	4440478810350641	4976f3ae2b78ff670da730259e045c65	JCB 16 digit	37.7830184663601756	-122.257016674569883
32691	2020-06-23 08:19:57	2020-06-23	Vernice Nikolaus	vernice.nikolaus@geemail.com	Huntsville	Alabama	4183476294603833	337e6e85c0a728fb0232158ca3ec41c7	VISA 13 digit	34.6252237034738073	-86.7100597057510214
32692	2020-06-23 08:20:07	2020-06-23	Pryor Hermann	pryor.hermann@warmmail.com	Huntington Beach	California	3528796562685279520	49c2773c406789c0820536a04bb2f34e	JCB 16 digit	33.6488303430419435	-118.051061681484057
32693	2020-06-23 08:26:19	2020-06-23	Jamey Jerde	jamey.jerde@geemail.com	Fremont	California	869984023034177395	5350f63dbf8757777f19b728c53205c7	American Express	37.5792693896386822	-121.870940321496491
32694	2020-06-23 08:26:56	2020-06-23	Amya O'Keefe-Stehr	amya.o'keefe.stehr@woohoo.com	San Francisco	California	3528704712243383428	32dedd661fd9e05db556e088cb954331	VISA 16 digit	37.8015691721322824	-122.41777666020019
32695	2020-06-23 08:41:16	2020-06-23	Gilberto Boehm-Konopelski	gilberto.boehm.konopelski@geemail.com	Fort Worth	Texas	3088208243202702045	41000543ed2edb26dd868bbaa148e2ba	Mastercard	32.7637845979128031	-97.2807530031360699
32696	2020-06-23 08:46:22	2020-06-23	Miss Edna Baumbach PhD	miss.edna.baumbach.phd@geemail.com	Jersey City	New Jersey	4262651087279728	21ff1cf62aede6b37f647aa06edd0490	American Express	40.6699347893647811	-74.0225935630455609
32697	2020-06-23 08:49:11	2020-06-23	Mr. Ellis Herman	mr.ellis.herman@woohoo.com	Simi Valley	California	4683603410476	5112f5f523277a32e31b900bb2c1ba39	JCB 15 digit	34.3061657619435323	-118.713794786868618
32698	2020-06-23 08:51:54	2020-06-23	Terri Shanahan	terri.shanahan@geemail.com	Winston–Salem	North Carolina	3337546674568029188	8c924deb4c08cfa7928cae82717b1f5f	JCB 16 digit	36.1865455487042667	-80.1883094890173425
32699	2020-06-23 08:53:47	2020-06-23	Shyheim Kling DVM	shyheim.kling.dvm@woohoo.com	New York	New York	3088919898097195793	98917ac8171129748e787a389f45cb3f	Maestro	40.7471890834849333	-73.9144288647349867
32700	2020-06-23 08:59:01	2020-06-23	Nathaly Shanahan-Mayert	nathaly.shanahan.mayert@geemail.com	Killeen	Texas	4228757123010	66443b28e53d64517dfc5fa095eecc3b	VISA 16 digit	31.068666560458766	-97.8295130600854748
32701	2020-06-23 09:04:05	2020-06-23	Dr. Alyssia Muller	dr.alyssia.muller@geemail.com	Los Angeles	California	3088976468620752500	7618a1f7a882a6539aab69d224a20091	JCB 16 digit	33.9673979182593513	-118.32419522460475
32702	2020-06-23 09:20:37	2020-06-23	Susann Predovic	susann.predovic@geemail.com	Moreno Valley	California	4121711294672	c6ec870b915314df591d41ff2f694186	Mastercard	33.9191089873194684	-117.30014826957769
32703	2020-06-23 09:25:06	2020-06-23	Yoshio Parisian	yoshio.parisian@geemail.com	Buffalo	New York	4171646676583175	5cc9fcd7ee25726ca5f7413b69f4cc22	American Express	42.8517099162749915	-78.9028321658659735
32704	2020-06-23 09:31:44	2020-06-23	Joselin Braun	joselin.braun@woohoo.com	Dallas	Texas	210040408074943124	498eea33b6c99c0ed63663c25bc0ab2b	VISA 13 digit	32.8531419027403047	-96.6794342776257452
32705	2020-06-23 09:52:09	2020-06-23	Ashlea Berge	ashlea.berge@geemail.com	Tuscaloosa	Alabama	4580760237496721	f48bed3b33c9fbc1b25a47b47e185057	VISA 16 digit	33.1386906926576046	-87.4492513704676213
32706	2020-06-23 09:53:00	2020-06-23	Lance Pouros	lance.pouros@geemail.com	Beaumont	Texas	210081702478845269	9b734144e096b561da55fc3f87532e1a	Maestro	30.1368931755960006	-94.1695254905402663
32707	2020-06-23 10:22:28	2020-06-23	Dr. Dickie Cronin PhD	dr.dickie.cronin.phd@geemail.com	New York	New York	3112029530588070915	9fc70e52b9cf9b2077d629fd501f3c4f	JCB 15 digit	40.671945528615268	-74.0065849432151737
32708	2020-06-23 10:49:50	2020-06-23	Dr. Eric Moore V	dr.eric.moore.v@geemail.com	Lakewood	Colorado	4831110480413	380ea2d2b6073b597c111bceae3fac74	JCB 16 digit	39.765936035656928	-105.194319225896521
32709	2020-06-23 11:22:37	2020-06-23	Aspen Bartell	aspen.bartell@warmmail.com	Chicago	Illinois	4510570320261758	99a1111f1f3258b0de5bf4ab6dee71f3	VISA 16 digit	41.9298817514277999	-87.752399234336977
32710	2020-06-23 11:28:21	2020-06-23	Eliot Hirthe	eliot.hirthe@geemail.com	New York	New York	4487985123935953	145bbcb60edad69830c0c90cc930c7cc	American Express	40.7329592250976731	-73.8390998050931842
32711	2020-06-23 11:41:08	2020-06-23	Ellison Williamson	ellison.williamson@woohoo.com	San Francisco	California	4368787582106	9614103b6ed1d247320943df5f3cf783	Voyager	37.8235198554622443	-122.404442887543667
32712	2020-06-23 11:48:54	2020-06-23	Grisel Pollich PhD	grisel.pollich.phd@geemail.com	Berkeley	California	589372660315168	bef593870323c744979c453e13236f06	JCB 16 digit	37.8749340637055454	-122.294561685816561
32713	2020-06-23 11:52:01	2020-06-23	Shellie Hickle	shellie.hickle@geemail.com	Virginia Beach	Virginia	53151193595106014	2e61960ee226db16f76ce97e6ccdcd1e	JCB 16 digit	36.8481796808261421	-75.947780010583628
32714	2020-06-23 11:54:02	2020-06-23	Omari Grimes	omari.grimes@geemail.com	New York	New York	869918537210644994	833e4cebed1ec29308ffe4258775fd39	VISA 16 digit	40.7208274921625843	-73.8595876001182887
32715	2020-06-23 12:02:17	2020-06-23	Eric Reilly-Von	eric.reilly.von@woohoo.com	Charlotte	North Carolina	4271768506161	9bdc74ba17f60d158c02ed1f75e28bb9	JCB 16 digit	35.2943045128390196	-80.9224494375698242
32716	2020-06-23 12:04:40	2020-06-23	Debora Ernser	debora.ernser@warmmail.com	Frisco	Texas	6011262590516436774	601a29ac33937b0bbaadc9325a193c46	VISA 16 digit	33.0965046002991485	-96.7684776610903441
32717	2020-06-23 12:04:44	2020-06-23	Demarcus Johnston	demarcus.johnston@geemail.com	Albuquerque	New Mexico	6011190041265938575	1cd1245103d2876f001690bca84d6706	JCB 16 digit	35.201114942472806	-106.556568951073672
32718	2020-06-23 12:11:01	2020-06-23	Myles Nienow	myles.nienow@warmmail.com	Chicago	Illinois	869961930390666976	647c52e1b5f53a65d71d3855e6c96eb0	VISA 13 digit	41.8211775846149791	-87.7153281382780534
32719	2020-06-23 12:18:14	2020-06-23	Manda Thompson	manda.thompson@geemail.com	Tallahassee	Florida	51754955768244942	22701970424b75ea040ae2c7d9950c55	VISA 16 digit	30.4310419895708577	-84.1684196960661524
32720	2020-06-23 12:19:34	2020-06-23	Nelle Kunde	nelle.kunde@geemail.com	Oakland	California	210077792143595551	c5407eff599497c5cc5d818318d43d15	JCB 16 digit	37.7987372268589183	-122.279766834333017
32721	2020-06-23 12:34:33	2020-06-23	Senora Haag PhD	senora.haag.phd@woohoo.com	Minneapolis	Minnesota	3528983796780712166	91af96dbcdc57c31f3c9347efeae5bd7	JCB 16 digit	44.9609161184255015	-93.1714632463447714
32722	2020-06-23 12:38:46	2020-06-23	Boysie Rath-Pagac	boysie.rath.pagac@geemail.com	New York	New York	4476942188790	3399e059fa38c88d918ee83e5da6692a	VISA 16 digit	40.7054861084315931	-73.9741116527829234
32723	2020-06-23 12:58:57	2020-06-23	Casandra Oberbrunner-Watsica	casandra.oberbrunner.watsica@geemail.com	Dallas	Texas	3722636440292709	8f9d6b18016407ad8d0a7ff9595603eb	Mastercard	32.8213399282462888	-96.7590237000454181
32724	2020-06-23 13:09:03	2020-06-23	Urijah Metz	urijah.metz@geemail.com	Lexington	Kentucky	3762662668370192	a837d281b3700aedb1ad0840876eb773	Voyager	38.0969011027708646	-84.5232654204491496
32725	2020-06-23 13:24:25	2020-06-23	Miss Willa Wilderman	miss.willa.wilderman@warmmail.com	San Francisco	California	3006979630950367	c14c50fb7ff28bf6c1e3ba7c8eb8e2a2	Diners Club / Carte Blanche	37.80043370056962	-122.454744364495781
32726	2020-06-23 13:27:36	2020-06-23	Nelie Lakin	nelie.lakin@geemail.com	New York	New York	3112498329843951353	5bc7bd24e1bb95c91c8b939c7b222ba6	VISA 13 digit	40.6024625590760238	-73.9009403098270212
32727	2020-06-23 13:35:14	2020-06-23	Mrs. Glynis Beier DVM	mrs.glynis.beier.dvm@geemail.com	Oceanside	California	869918961474645234	24600ec80cdd0732c24d3ac3192a0ccb	JCB 16 digit	33.1970372678134567	-117.387767065743731
32728	2020-06-23 13:44:06	2020-06-23	Kim Schroeder	kim.schroeder@woohoo.com	Wichita Falls	Texas	55059038739883379	557a27c1c7401e40c4cb271c1fb74184	Maestro	34.0037854648388915	-98.5625011613048514
32729	2020-06-23 13:46:01	2020-06-23	Bianca McCullough	bianca.mccullough@geemail.com	Las Vegas	Nevada	4568156419627231	88806a1e24eb62657ec1ececaecf8e40	Discover	36.2573286881770898	-115.341467381848389
32730	2020-06-23 13:54:43	2020-06-23	Suzann Dickinson	suzann.dickinson@warmmail.com	Berkeley	California	3784186630541650	9145a17e2063ac6bbbbcb2a6c1ed9943	Maestro	37.8679552331225864	-122.247018438675823
32731	2020-06-23 14:04:58	2020-06-23	Kayleigh Harris-Will	kayleigh.harris.will@woohoo.com	Oklahoma City	Oklahoma	3337921366093911551	c3547eaa57e4c77705df3bde2d087ea8	VISA 16 digit	35.4729301009703448	-97.508583214868608
32732	2020-06-23 14:06:25	2020-06-23	Mrs. Ryann Schuppe	mrs.ryann.schuppe@geemail.com	Inglewood	California	3047449974888341	53a1fabfe5f98a55ac7cd2ba43b68085	Mastercard	33.9785167081527391	-118.390131027440731
32733	2020-06-23 14:07:44	2020-06-23	Everet Kilback	everet.kilback@geemail.com	Clovis	California	503873431820098	8ca98afed029c347fc7733c3e34b4db6	JCB 15 digit	36.8428659160032907	-119.592524231930824
32734	2020-06-23 14:08:32	2020-06-23	Dr. Jameson Walsh	dr.jameson.walsh@warmmail.com	San Francisco	California	3790320046554831	89bb5cca8ccc92285c5582dad2beed01	Discover	37.7796699224963959	-122.454710535379604
32735	2020-06-23 14:16:44	2020-06-23	Dr. Leontine Kessler DDS	dr.leontine.kessler.dds@geemail.com	Berkeley	California	4642114450819	65d35c672cbb81ad8b7f411b70915706	VISA 16 digit	37.8609622456471584	-122.287411139915633
32736	2020-06-23 14:19:23	2020-06-23	Hilbert Bergstrom	hilbert.bergstrom@geemail.com	Columbus	Ohio	503851046629658	29898031434301c8e96192dc4d580eec	JCB 16 digit	40.0073606463193912	-82.8949588721852848
32737	2020-06-23 14:19:52	2020-06-23	Hermine Reichert	hermine.reichert@geemail.com	San Francisco	California	3088465962893698414	0668f61eb184cf3df41798cf8a000db2	JCB 16 digit	37.7805999113793476	-122.453034528076245
32738	2020-06-23 14:28:21	2020-06-23	Ines Schamberger	ines.schamberger@geemail.com	Austin	Texas	3720395243516523	541b58ae370a04967a14ed5e923e9200	Voyager	30.2468217388387757	-97.8348755818098823
32739	2020-06-23 14:28:39	2020-06-23	Lucinda Roob-Gleichner	lucinda.roob.gleichner@geemail.com	Oklahoma City	Oklahoma	869947378408798994	d8a72cf828cc46dd559fe06c92cf33bd	Discover	35.5610072059933131	-97.5351779297355534
32740	2020-06-23 14:32:06	2020-06-23	Ms. Verena Turner DDS	ms.verena.turner.dds@geemail.com	Chicago	Illinois	4098641228148155	212a838b444c250515f89ea3e0c98a4c	Maestro	41.8878754081506273	-87.726125133180247
32741	2020-06-23 14:43:38	2020-06-23	Enzo Legros	enzo.legros@geemail.com	Modesto	California	210026782985845240	65a433ed7f5760f520e46636b14285eb	JCB 15 digit	37.708342295186597	-120.931253120230508
32742	2020-06-23 14:54:43	2020-06-23	Ciji Stoltenberg	ciji.stoltenberg@geemail.com	Saint Paul	Minnesota	3770395622182391	94132a7bb54ad082915897fe4f3604f3	JCB 16 digit	44.8960650511492076	-93.1676034323204334
32743	2020-06-23 14:59:53	2020-06-23	Dr. Drew Schowalter PhD	dr.drew.schowalter.phd@geemail.com	Pittsburgh	Pennsylvania	869965588869130845	b8c35027d17a60c88a7c95473312f4a1	JCB 16 digit	40.3790826793249664	-80.0355163349010041
32744	2020-06-23 15:07:12	2020-06-23	King Watsica	king.watsica@geemail.com	Milwaukee	Wisconsin	869916632020423176	5e5c012b985d01da61fc303a930b14b7	JCB 15 digit	43.0732865154363225	-87.8961922292698148
32745	2020-06-23 15:08:04	2020-06-23	Dr. Alysa Doyle DVM	dr.alysa.doyle.dvm@geemail.com	Clinton	Michigan	4549954481583868	8e7833cd99f28f31eff66e84d09b11f3	VISA 16 digit	42.536365644035115	-82.9947823169250114
32746	2020-06-23 15:17:41	2020-06-23	Hope Hand-Lang	hope.hand.lang@geemail.com	Fort Collins	Colorado	869959260001115872	47b20c0ffee673a5562ceb11ceed3dbe	Discover	40.6005533959407359	-105.089746968117737
32747	2020-06-23 15:17:59	2020-06-23	Dr. Lorenzo Lakin V	dr.lorenzo.lakin.v@geemail.com	New York	New York	3096943949605441649	b9bde133a9ea9bb94298ea0ba8399c82	VISA 16 digit	40.7562410716190939	-73.9126550258498582
32748	2020-06-23 15:19:02	2020-06-23	Rylan Dach	rylan.dach@geemail.com	Virginia Beach	Virginia	210054452535697468	4aed49ac9fb055efc550cee77a1970bf	VISA 16 digit	36.8439461794402447	-75.9278893504429533
32749	2020-06-23 15:22:02	2020-06-23	Kieran Nolan	kieran.nolan@woohoo.com	Syracuse	New York	675995053884789	808b409f2915880243c31862996d0d9f	VISA 16 digit	43.0316042228452815	-76.2138934021130297
32750	2020-06-23 15:24:01	2020-06-23	Bernadine Kassulke	bernadine.kassulke@geemail.com	Bakersfield	California	3734523926058257	303762e651017780c916b45a21bff15e	Maestro	35.321103415888544	-118.957800696957108
32751	2020-06-23 15:32:54	2020-06-23	Egbert Fisher	egbert.fisher@geemail.com	Austin	Texas	51001627862608741	ff468d28ad942126b3656827cc18a0ce	JCB 16 digit	30.23661224023774	-97.8376653819117763
32752	2020-06-23 15:47:46	2020-06-23	Carson Heaney	carson.heaney@geemail.com	Arlington	Texas	210028596100643795	b1192cac754c0a5c7aae0c60458c5776	Diners Club / Carte Blanche	32.6320928684219709	-97.1638254723072095
32753	2020-06-23 16:01:52	2020-06-23	Alberta Thiel	alberta.thiel@geemail.com	Chattanooga	Tennessee	6011266530561149738	3e916e700e85dde3ae480aca8648b6cd	VISA 13 digit	34.9717865536771768	-85.3259306885596374
32754	2020-06-23 16:03:42	2020-06-23	Eliga Schmitt	eliga.schmitt@geemail.com	Baltimore	Maryland	869972689296657292	5bea93a233f3e9af71662c92b3efdaad	Discover	39.3867788969073445	-76.6781769117824723
32755	2020-06-23 16:10:17	2020-06-23	Jamie O'Connell	jamie.o'connell@geemail.com	Oakland	California	561273105395187	c57a8a9a3a6795cb999ac50e9492e054	Diners Club / Carte Blanche	37.7884118624816736	-122.225594974651358
32756	2020-06-23 16:20:03	2020-06-23	Alberto Brown	alberto.brown@geemail.com	Colorado Springs	Colorado	6011913800767350787	4974fd2d59a01a479cf7b53c2d5db1a3	Mastercard	38.8877474895261201	-104.837123872727901
32757	2020-06-23 16:28:22	2020-06-23	Allena Robel PhD	allena.robel.phd@geemail.com	Buffalo	New York	3495418290161256	7e704b51b55d3d9dc6e165ed21f52797	American Express	42.980737993838261	-78.9057486446972973
32758	2020-06-23 16:37:21	2020-06-23	Lyla Prosacco	lyla.prosacco@geemail.com	Los Angeles	California	3052005610490705	a0ed0f3e82144996f708403a811c8c62	Diners Club / Carte Blanche	33.9758832811709439	-118.419218057765804
32759	2020-06-23 16:39:01	2020-06-23	Mrs. Hilma Kemmer	mrs.hilma.kemmer@geemail.com	Allentown	Pennsylvania	4603132214855761	e9b4977cbb0815210de3f1733304bf02	JCB 16 digit	40.5343557936850942	-75.4732181096929935
32760	2020-06-23 17:07:44	2020-06-23	Wells Vandervort	wells.vandervort@warmmail.com	Elk Grove	California	4633222168021	761e0ab3502d6c827b0645a0c29845da	American Express	38.4540415555521875	-121.290501523893326
32761	2020-06-23 17:09:14	2020-06-23	Deyanira Kling MD	deyanira.kling.md@geemail.com	Fresno	California	4504143659116650	cc6ecc9eca741f9b54e9910e8089d67c	VISA 16 digit	36.8403004134412839	-119.856753585358717
32762	2020-06-23 17:12:21	2020-06-23	Ewing Bergstrom	ewing.bergstrom@geemail.com	Charlotte	North Carolina	869984174503868434	135c03cc0059bd913ed91b2b87b4cd49	Maestro	35.1328525545328816	-80.8284088329821913
32763	2020-06-23 17:16:01	2020-06-23	Celena Padberg	celena.padberg@geemail.com	Jacksonville	Florida	51067779036722642	1cd940be0ac7f526b2195f5486ce6794	JCB 15 digit	30.3479877363942556	-81.6811959346369036
32764	2020-06-23 17:17:22	2020-06-23	Whit Rath	whit.rath@warmmail.com	Spokane	Washington	3158745023816684007	f7f2e53f86ed6767eca44f860217d9b7	JCB 15 digit	47.7161762457113667	-117.426613806923115
32765	2020-06-23 17:17:24	2020-06-23	Jaden Turner	jaden.turner@woohoo.com	Henderson	Nevada	3016056651849156	dfd7785631fe0d887c6949543b6810a8	Voyager	36.051621982914213	-115.052686551927408
32766	2020-06-23 17:17:34	2020-06-23	Kiley Larkin	kiley.larkin@geemail.com	Fort Lauderdale	Florida	6011671100453514743	dad01bcc4f16c5a2d0ded5d4fcbe11db	VISA 16 digit	26.0751981078635922	-80.1145142095915901
32767	2020-06-23 17:17:50	2020-06-23	Mrs. Ciji Hermiston MD	mrs.ciji.hermiston.md@warmmail.com	Los Angeles	California	3032427853636499	ce03f3fd0d800c8ca8d997ec043881f1	American Express	33.9563750602170771	-118.369490864918745
32768	2020-06-23 17:33:30	2020-06-23	Dr. Halley Mayer IV	dr.halley.mayer.iv@geemail.com	New York	New York	3035620547913756	53c83bbffe68d0b6fc175d6dabff214e	VISA 16 digit	40.6808038240056504	-73.8451789822325111
32769	2020-06-23 17:45:56	2020-06-23	Elizbeth Ortiz	elizbeth.ortiz@geemail.com	Philadelphia	Pennsylvania	51011774798304512	fb726476ece95e8fc6dfaf6bacaa7037	Diners Club / Carte Blanche	39.9628228292759502	-75.0740000882551186
32770	2020-06-23 17:47:36	2020-06-23	Natalia Botsford	natalia.botsford@woohoo.com	Berkeley	California	4932757892093079	59d704f8c65cfd7c1cfa3fcde76dd2e7	JCB 16 digit	37.8635918726367535	-122.272606663218752
32771	2020-06-23 17:56:12	2020-06-23	Jaden Hilll MD	jaden.hilll.md@geemail.com	Denton	Texas	4930901903326	b8c0dc6bf37d741875c226bd400e4e49	Diners Club / Carte Blanche	33.2799204047102464	-97.1400831411719423
32772	2020-06-23 18:14:08	2020-06-23	Selena Emmerich	selena.emmerich@woohoo.com	Garden Grove	California	4197758391500069	97a24934fd94c69955e50c76134ebb18	Diners Club / Carte Blanche	33.7746711422048449	-117.938675239730628
32773	2020-06-23 18:50:50	2020-06-23	Collie Larkin	collie.larkin@geemail.com	Columbia	South Carolina	4094469773264	fab3567f55ed2f5205915c3bfbdfee4e	Mastercard	34.0026452594701212	-80.9824167580362371
32774	2020-06-23 19:05:13	2020-06-23	Skip Kerluke Sr.	skip.kerluke.sr.@warmmail.com	New York	New York	3088902046221920772	483a0dc609137f092bd3d6258631d5d7	VISA 16 digit	40.7630575464330605	-74.0028086386051029
32775	2020-06-23 19:19:51	2020-06-23	Lana Gerlach DVM	lana.gerlach.dvm@geemail.com	New York	New York	3337899395515230223	aa9367781ffaef81a35a51c3e68269a0	JCB 16 digit	40.6239002485051728	-73.9195544572908432
32776	2020-06-23 19:31:22	2020-06-23	Miss Neoma Brakus MD	miss.neoma.brakus.md@geemail.com	Aurora	Colorado	3446272086767069	1ab418e460b527041cff845ade1f425d	JCB 16 digit	39.6094527519419799	-104.643748374621197
32777	2020-06-23 19:33:54	2020-06-23	Lida Krajcik	lida.krajcik@woohoo.com	Chicago	Illinois	3023376342182160	a6c47a40f67a3e9e0586af151b770c09	Diners Club / Carte Blanche	41.8708419495098312	-87.6801424974605368
32778	2020-06-23 19:39:18	2020-06-23	Nathan Kling	nathan.kling@warmmail.com	Greensboro	North Carolina	060488893273586	2c9dbe43a85e081d01573e269953acff	JCB 15 digit	36.0444954991921804	-79.816973474619914
32779	2020-06-23 19:39:38	2020-06-23	Conner Sauer	conner.sauer@warmmail.com	Louisville	Kentucky	4216681351252892	943a825ab7f4ee59757ac64944ccf681	American Express	38.1628125022534235	-85.6413708645455642
32780	2020-06-23 19:43:06	2020-06-23	Miss Carlee Lehner	miss.carlee.lehner@geemail.com	Berkeley	California	4878941084758030	bcbe4e8068e5dc985b351fa65946ee52	Diners Club / Carte Blanche	37.8605196859808117	-122.266371746641042
32781	2020-06-23 19:44:29	2020-06-23	Dicy Mueller	dicy.mueller@geemail.com	San Francisco	California	54855471844474188	2f7b13af8a5327284ce67364c53e2829	JCB 16 digit	37.7832261026141083	-122.451746644264915
32782	2020-06-23 19:52:58	2020-06-23	Rosella Nikolaus	rosella.nikolaus@woohoo.com	Baltimore	Maryland	4001025037474794	b82e411df67c0adfe350f2d6ac86a2c8	JCB 16 digit	39.3653878592886031	-76.6902869883012102
32783	2020-06-23 20:04:25	2020-06-23	Mr. Loring Jacobs Jr.	mr.loring.jacobs.jr.@geemail.com	Jacksonville	Florida	4275911448825	41554c3626c4e3344d7f50af09765055	Voyager	30.4225523292139179	-81.5935876436144127
32784	2020-06-23 20:07:48	2020-06-23	Mr. Holden Bahringer Jr.	mr.holden.bahringer.jr.@geemail.com	Huntsville	Alabama	589395337093470	40c0c1ce79375823a2f33765d843d7fe	Voyager	34.6045836176965338	-86.7342268923316198
32785	2020-06-23 20:08:29	2020-06-23	Mrs. Channie Keeling	mrs.channie.keeling@woohoo.com	Jurupa Valley	California	3528134487771170022	4174375a8a2157f0bfdd187f0d699c7d	Discover	33.959253901515531	-117.398140465982635
32786	2020-06-23 20:16:30	2020-06-23	Dr. Moses Konopelski	dr.moses.konopelski@geemail.com	Reno	Nevada	4515106783083424	9eb7fd92e9c0faf441eb93ab5806e04e	JCB 16 digit	39.4711284598879573	-119.941000397706034
32787	2020-06-23 20:24:45	2020-06-23	Velia Quigley	velia.quigley@geemail.com	San Francisco	California	3476227022540981	9ff9192302333555162cb017fd482ffd	JCB 16 digit	37.7647696543108538	-122.435280196448147
32788	2020-06-23 20:31:25	2020-06-23	Mr. Vander Luettgen	mr.vander.luettgen@warmmail.com	Miramar	Florida	869911114761258967	50ea8bc05e31bfc7846a1a9d068b08c7	Voyager	25.885591574057937	-80.2929145227178935
32789	2020-06-23 20:32:39	2020-06-23	Kyla Hansen	kyla.hansen@geemail.com	Berkeley	California	589393847501736	593ef39356f0660b41134bf90befe76e	VISA 16 digit	37.920715893585637	-122.259659249172472
32790	2020-06-23 20:41:59	2020-06-23	Bernice Schaefer	bernice.schaefer@geemail.com	Elizabeth	New Jersey	869964506059843200	25d2b5dd2eae1d5a30d4af50ec7be9a1	JCB 16 digit	40.5892280625306086	-74.141744338016963
32791	2020-06-23 20:45:19	2020-06-23	Dr. Huy Tillman	dr.huy.tillman@geemail.com	San Francisco	California	3158558151718333831	30bab9ff2e67be12555f21c58498cebf	VISA 16 digit	37.7657124523182119	-122.437320149607032
32792	2020-06-23 20:45:36	2020-06-23	Domonique McLaughlin	domonique.mclaughlin@warmmail.com	North Las Vegas	Nevada	589365129271949	139f4e766e77f1c19a598c97e62f9435	Diners Club / Carte Blanche	36.2124802961636334	-115.021607940200354
32793	2020-06-23 20:46:29	2020-06-23	Chandler Boehm II	chandler.boehm.ii@woohoo.com	Durham	North Carolina	4717958869166911	5af6aa8796f4092134012f27fc0bc3f4	JCB 16 digit	36.0784313783761093	-78.9992106404990011
32794	2020-06-23 20:47:41	2020-06-23	Terrell Johns	terrell.johns@geemail.com	Kenosha	Wisconsin	4355149239699	84b6820d2030654ffb6c1c40c97d895d	Voyager	42.563281856461245	-87.8296322653763042
32795	2020-06-23 20:56:07	2020-06-23	Brylee Brekke	brylee.brekke@geemail.com	Berkeley	California	3528744932119242498	7e48b101a7861090856dc360c01763fd	VISA 16 digit	37.9137007536778441	-122.236268488601112
32796	2020-06-23 21:09:35	2020-06-23	Ms. Jerilyn Thiel DVM	ms.jerilyn.thiel.dvm@warmmail.com	San Francisco	California	180010931329377604	f0e0336ed993efa208c4254bccd083a6	VISA 16 digit	37.7503040675152874	-122.426521908099559
32797	2020-06-23 21:20:42	2020-06-23	Davante Sanford	davante.sanford@geemail.com	Santa Ana	California	3027722085050112	e63220d1a0b77fd4ded12c4fdb8518aa	Diners Club / Carte Blanche	33.7966759338147966	-117.869337193567304
32798	2020-06-23 21:23:15	2020-06-23	Mercer O'Connell	mercer.o'connell@geemail.com	Sunnyvale	California	4538699746722	34e8a0663f1089c15a5c355895c6812a	JCB 16 digit	37.3819043803952695	-121.958688413045564
32799	2020-06-23 21:24:04	2020-06-23	Mrs. Cordella Jerde	mrs.cordella.jerde@geemail.com	Macon	Georgia	4284606107092	1bda414363b6d7b75891930d2b622bfa	VISA 16 digit	32.8315091762702878	-83.6171257341474217
32800	2020-06-23 21:50:25	2020-06-23	Dr. Phillis Braun	dr.phillis.braun@geemail.com	Detroit	Michigan	3528666837336690383	c57c2e4dd4cf9a0ff9f8dcc7e76930d2	VISA 13 digit	42.4810533269699704	-83.0190984468094939
32801	2020-06-23 22:01:34	2020-06-23	Kathlyn Fisher-Nicolas	kathlyn.fisher.nicolas@geemail.com	Santa Ana	California	4845925722690663	503db02b4a47cd97e0fe9bb04377bc18	Mastercard	33.6611836661688955	-117.791882877556603
32802	2020-06-23 22:07:55	2020-06-23	Ms. Nichelle Rodriguez	ms.nichelle.rodriguez@geemail.com	Houston	Texas	4373232680614953	891c19efe72e478724823375d5e37d1d	Discover	29.7087587541513152	-95.4466258644606995
32803	2020-06-23 22:33:35	2020-06-23	Phebe Jaskolski-D'Amore	phebe.jaskolski.d'amore@geemail.com	New York	New York	4726577804222	c3ab593ab2aab219cad2b28be1edcb74	VISA 16 digit	40.5785037794839596	-73.9626065299741953
32804	2020-06-23 22:36:26	2020-06-23	Blaine Senger DDS	blaine.senger.dds@geemail.com	Fort Worth	Texas	3010018987555895	18f3f87a6d69848ac942881daed016e3	JCB 15 digit	32.7837837246302541	-97.3637858600642545
32805	2020-06-23 22:37:32	2020-06-23	Dr. Virgil Tromp V	dr.virgil.tromp.v@geemail.com	Amarillo	Texas	4246340896740812	95254e0537563d1ed82bc1e443646e16	JCB 16 digit	35.1490869858466084	-101.926885111941772
32806	2020-06-23 22:38:46	2020-06-23	Genesis Lindgren DDS	genesis.lindgren.dds@warmmail.com	San Francisco	California	4378227772517630	9e6632157ec84e7cf4d9a4d434ebd9fd	Maestro	37.7901014971078553	-122.433363095449565
32807	2020-06-23 22:47:26	2020-06-23	Tiesha Pfannerstill DDS	tiesha.pfannerstill.dds@geemail.com	Columbus	Ohio	3337204212355748745	2b9747d614ae2812ab7ceec7a584de39	JCB 16 digit	39.9265867125753289	-83.0279831863708893
32808	2020-06-23 22:54:28	2020-06-23	Tonja Powlowski	tonja.powlowski@warmmail.com	San Francisco	California	3798427389368067	d3141d8e195bd492bb6bfbd14b2cdbc1	JCB 16 digit	37.7891866416195938	-122.41417985655508
32809	2020-06-23 23:18:21	2020-06-23	Benson Kuhn	benson.kuhn@geemail.com	Toledo	Ohio	3528120195089801685	e5e2c0f186495af93fee5359ec999076	VISA 13 digit	41.7529905035797455	-83.6447366794902933
32810	2020-06-23 23:36:50	2020-06-23	Katina Nicolas	katina.nicolas@woohoo.com	San Francisco	California	3096453218388721904	9e90349e66952071594bccb3bae3ad5e	VISA 16 digit	37.7914008932390928	-122.457781885779312
32811	2020-06-23 23:58:30	2020-06-23	Charity Maggio	charity.maggio@geemail.com	Davenport	Iowa	4069440249521382	ec000cabe614df6ea1b96196027100db	Maestro	41.521757131468874	-90.6770432891286902
32812	2020-06-24 00:15:14	2020-06-24	Newman Goldner	newman.goldner@woohoo.com	Fresno	California	210054794461611470	00d6eb16535b428b41a22dbc84f6ff71	VISA 13 digit	36.7683101059276609	-119.806762955814236
32813	2020-06-24 00:20:22	2020-06-24	Ray Corwin Sr.	ray.corwin.sr.@geemail.com	Newark	New Jersey	3528453078717997876	05f353d0062b2ccb7a7e2caf2b4b1c9f	Mastercard	40.7322811409745427	-74.1708224973384347
32814	2020-06-24 00:26:09	2020-06-24	Summer Jakubowski	summer.jakubowski@geemail.com	Carrollton	Texas	639061555108002	0827d1d3a247371adb376a6a08d5b6dd	Maestro	33.0493366224147351	-96.8126533341456224
32815	2020-06-24 00:27:10	2020-06-24	Dayton Torphy	dayton.torphy@warmmail.com	New York	New York	4600172989872727	c29c84903d3b4bd02b2c807f32cc1a3b	American Express	40.6746177530605308	-73.9603482555493628
32816	2020-06-24 00:35:31	2020-06-24	Shedrick Schaden	shedrick.schaden@geemail.com	Santa Maria	California	3337388608010021006	8fbb53b14f6988ffaf3e23cc68acc72b	Mastercard	34.8888433323770784	-120.388674131120737
32817	2020-06-24 00:43:56	2020-06-24	Dr. Fed Bosco	dr.fed.bosco@woohoo.com	Sacramento	California	639028406436767	9f5524cb9b882a6e4641265b4631dfa6	VISA 16 digit	38.6117659714337478	-121.416939309776197
32818	2020-06-24 01:02:17	2020-06-24	Tal Wilderman-Osinski	tal.wilderman.osinski@geemail.com	San Francisco	California	210011601380847188	2e1135d48f21fde5896420f2ae49e081	Voyager	37.7947182227174778	-122.422158603925965
32819	2020-06-24 01:03:12	2020-06-24	River Labadie-Donnelly	river.labadie.donnelly@geemail.com	Huntsville	Alabama	3096641238182012410	cff64fdcebfbc18d846c34b6b2db5da4	VISA 13 digit	34.7939938115198117	-86.5824853389542568
32820	2020-06-24 01:06:55	2020-06-24	Burrel Crooks	burrel.crooks@geemail.com	Berkeley	California	4145943782862475	cbbb2827a07747b7a7a3ebc571a1a0a1	Mastercard	37.8769866505808892	-122.282935377121902
32821	2020-06-24 01:10:21	2020-06-24	Pearly Huels	pearly.huels@geemail.com	San Antonio	Texas	53043415858256497	543f9ccdab3071e31e18322cec427dbe	JCB 16 digit	29.4480580829620351	-98.4828298713382253
32822	2020-06-24 01:11:23	2020-06-24	Coretta Crooks	coretta.crooks@geemail.com	Los Angeles	California	6011536435361543797	22d7ac375767ef5997720eef8acc3634	Mastercard	33.9386868062760669	-118.341717947087432
32823	2020-06-24 01:13:07	2020-06-24	Darryl Terry	darryl.terry@geemail.com	Shreveport	Louisiana	51132330183557190	498e6faed431c29da8ace3d88efd43a7	JCB 16 digit	32.4721067591343129	-93.7981373079333451
32824	2020-06-24 01:13:37	2020-06-24	Gilford Schimmel-Ritchie	gilford.schimmel.ritchie@geemail.com	Grand Rapids	Michigan	3528587850047522072	7bb5e27b6570096a770a2977ac2ddced	American Express	43.0154689780238968	-85.7417763535067508
32825	2020-06-24 01:26:27	2020-06-24	Hazen Swift	hazen.swift@geemail.com	Lancaster	California	3096818300189522937	c8170994855fdc3b9254a9a1653846e5	JCB 15 digit	34.7614866657428507	-118.267076430932804
32826	2020-06-24 01:33:06	2020-06-24	Mr. Franklyn Kemmer PhD	mr.franklyn.kemmer.phd@geemail.com	Denver	Colorado	3035241664343394	e3685e999632867725a02b4724b515d1	American Express	39.8223697174392584	-104.791698234226928
32827	2020-06-24 01:34:01	2020-06-24	Ms. Kathryne Stehr	ms.kathryne.stehr@woohoo.com	Spokane	Washington	3406407982612161	f336266c915c1b7b96fa4aa7ab39fa59	Maestro	47.6016708305343954	-117.376130745456749
32828	2020-06-24 01:35:06	2020-06-24	Elwanda Johns	elwanda.johns@warmmail.com	Irving	Texas	54852425820967014	8b32e9194d9b0150957a4823e2e96214	VISA 16 digit	32.8307236748699083	-96.9892982872482321
32829	2020-06-24 01:36:43	2020-06-24	Andre Sporer	andre.sporer@geemail.com	San Francisco	California	869945222109640513	9e3275ec2760ca640e56f52111e32aed	JCB 16 digit	37.784554537521899	-122.416622846868563
32830	2020-06-24 01:40:38	2020-06-24	Lauri Grady-Orn	lauri.grady.orn@geemail.com	Berkeley	California	3052226469071855	1e3a7fcc7920b93ea48f9db38758d27e	VISA 13 digit	37.8567332856942755	-122.313249141020634
32831	2020-06-24 01:55:33	2020-06-24	Kaiya Kuhlman	kaiya.kuhlman@woohoo.com	New York	New York	4608913468474200	df2f7c11d5c72e261839b92166668a2f	Maestro	40.7141359364371738	-74.0315972800262188
32832	2020-06-24 01:56:38	2020-06-24	Giselle O'Conner	giselle.o'conner@warmmail.com	Los Angeles	California	869911190353861814	f3c5a7834effb23051cb876545851a69	American Express	34.020393782049041	-118.412335689923907
32833	2020-06-24 02:04:09	2020-06-24	Dr. Tanisha Ebert	dr.tanisha.ebert@geemail.com	Augusta	Georgia	869952866478335277	d5dc4631b82e48f10558f04ea0869cf6	VISA 16 digit	33.390914734380317	-82.138957664819074
32834	2020-06-24 02:09:57	2020-06-24	Cathleen Borer	cathleen.borer@geemail.com	Tulsa	Oklahoma	3001786178166396	73df622a904f8f9fd491dc105d01e261	Mastercard	36.0519491776727108	-95.8821065864015338
32835	2020-06-24 02:34:59	2020-06-24	Elvira Wisoky-Farrell	elvira.wisoky.farrell@geemail.com	Los Angeles	California	3407030454882093	b59c95360f0ff5fd9c461394dfca0cb3	Maestro	33.9442179487418372	-118.503785185422004
32836	2020-06-24 02:42:53	2020-06-24	Kirstin Lynch	kirstin.lynch@woohoo.com	Oxnard	California	51865986124627294	bbd1b36967625043ee1b345375a9150b	Discover	34.1573532529130617	-119.148470147224515
32837	2020-06-24 02:49:18	2020-06-24	Reid Olson	reid.olson@geemail.com	Orange	California	3112405564168848923	cd0f8bb1e776d166b2e78a944c95be3a	VISA 13 digit	33.8073145335894054	-117.828740704675397
32838	2020-06-24 02:50:54	2020-06-24	Sierra Lueilwitz	sierra.lueilwitz@geemail.com	San Francisco	California	4482738547801	1a77bf823e35ebeca27a91f3a669f4fd	JCB 16 digit	37.776208660365576	-122.407711483630891
32839	2020-06-24 03:09:04	2020-06-24	Noretta Olson	noretta.olson@geemail.com	Orange	California	4636529813411428	86f432c5137eb1fdf9ea0598a4f6faad	JCB 15 digit	33.7705295451805014	-117.829031398111212
32840	2020-06-24 03:10:25	2020-06-24	Falon Quitzon MD	falon.quitzon.md@geemail.com	Shreveport	Louisiana	3026522700549014	f5d24d0a56af4757c6206016dacfbbab	VISA 16 digit	32.3711665082961346	-93.8589095359414785
32841	2020-06-24 03:17:27	2020-06-24	Mr. Tavion Davis IV	mr.tavion.davis.iv@warmmail.com	Portland	Oregon	4399996829048659	f4132e8a6e5abf70e1cae228b85270ff	VISA 16 digit	45.5094873933009794	-122.639376598829415
32842	2020-06-24 03:26:46	2020-06-24	Davonta Nicolas	davonta.nicolas@geemail.com	New York	New York	3785001536885862	1afe843717fafb3cd3517c51a6e9d1cd	Mastercard	40.7233654328379799	-73.8806630828779163
32843	2020-06-24 03:28:55	2020-06-24	Trenten Sanford IV	trenten.sanford.iv@geemail.com	Houston	Texas	3528539848334238641	7a0c79b6e7b6bc5b20e1af78c93f8b13	American Express	29.7515445565417416	-95.3052905773758852
32844	2020-06-24 03:31:25	2020-06-24	Dr. Blanchard McCullough IV	dr.blanchard.mccullough.iv@geemail.com	Los Angeles	California	3011976101414878	55e42aefbc6e9c7e8c02e2f174c118ed	JCB 15 digit	34.0629905821621364	-118.508702296576644
32845	2020-06-24 03:34:04	2020-06-24	Joe Marvin	joe.marvin@warmmail.com	Spokane	Washington	3046779492868412	213575489a7de0b424617c8b13065175	Discover	47.588326914399488	-117.344323721843963
32846	2020-06-24 03:35:07	2020-06-24	Monika Lehner	monika.lehner@warmmail.com	San Francisco	California	51616533934142338	bf1d070fe9e71df4cd81ff282fb7e108	Diners Club / Carte Blanche	37.7887335040495245	-122.41742325764794
32847	2020-06-24 03:38:30	2020-06-24	Michale Wisoky	michale.wisoky@woohoo.com	Fargo	North Dakota	4139574105504854	c5098466314cb63c806ef8b86f8b0e43	Voyager	46.8971993210025175	-96.7611726440917579
32848	2020-06-24 03:50:03	2020-06-24	Flavia Wehner DDS	flavia.wehner.dds@warmmail.com	San Francisco	California	561260921466383	78e4b24040374334ef0f4399c33fb2d3	JCB 16 digit	37.7366945013428676	-122.430597174387458
32849	2020-06-24 04:02:59	2020-06-24	Auther Stroman	auther.stroman@geemail.com	San Jose	California	6011393639847658226	25521849a54b621af66b529161f00ecb	JCB 16 digit	37.2973921714637413	-121.779771034301817
32850	2020-06-24 04:05:35	2020-06-24	Alvan Mueller-Pacocha	alvan.mueller.pacocha@geemail.com	Hayward	California	501833491307790	7614a0dc389756cc3721b93c4f3e43a6	VISA 16 digit	37.5838664148923058	-122.153446248245984
32851	2020-06-24 04:22:48	2020-06-24	Sanford Turner	sanford.turner@warmmail.com	Austin	Texas	210070573160082567	423db00c6d3a1a8825f1ce0e265ac219	Diners Club / Carte Blanche	30.3730752610728132	-97.7155098413355745
32852	2020-06-24 04:27:39	2020-06-24	Litha Simonis	litha.simonis@geemail.com	Vacaville	California	4893511227527625	cdbc2991259a1d01e367bf03cb353576	VISA 13 digit	38.4015724725216643	-121.886154082638399
32853	2020-06-24 04:36:57	2020-06-24	Oralia Feest PhD	oralia.feest.phd@geemail.com	San Francisco	California	676199730436393	c92303d93dc4fb320b113d682187bb97	Voyager	37.7698640222463524	-122.426063423145379
32854	2020-06-24 04:37:01	2020-06-24	Shaquille Mohr	shaquille.mohr@warmmail.com	Baltimore	Maryland	180011502231011810	16f67de82a3ab90ec1db3b18e7f87119	JCB 15 digit	39.2802638022694737	-76.5719536240696925
32855	2020-06-24 04:38:16	2020-06-24	Agatha Hegmann	agatha.hegmann@warmmail.com	Denver	Colorado	869960506566326370	d3247f94b7d83e0b775c1147461785a1	Diners Club / Carte Blanche	39.8591330296877757	-104.941326115863774
32856	2020-06-24 04:42:11	2020-06-24	Morgan Gutkowski	morgan.gutkowski@warmmail.com	Spokane	Washington	3337183872606648153	556cb65f63fb02e3bc53a64aa7211cf3	Mastercard	47.7156591002136423	-117.51845426367521
32857	2020-06-24 04:44:03	2020-06-24	Dr. Jaycob Franecki	dr.jaycob.franecki@warmmail.com	Memphis	Tennessee	630430211351983	04bc91b1a8a9f9b48e0fdb236f67b0b4	Mastercard	35.0869274623759111	-89.9966941359709978
32858	2020-06-24 04:44:33	2020-06-24	Cameron Lehner	cameron.lehner@geemail.com	Rockford	Illinois	53360497730507979	6ca3cd8331d53ac1408feb6b448a368b	JCB 16 digit	42.2485721330635258	-89.0498832221891661
32859	2020-06-24 04:51:46	2020-06-24	Samira Schinner	samira.schinner@geemail.com	Carrollton	Texas	55200536451691662	257b1ada36801174245c23ea6b72d5f1	Mastercard	32.8962836851753266	-96.9475455997373956
32860	2020-06-24 04:53:00	2020-06-24	Bryanna Schiller	bryanna.schiller@geemail.com	San Francisco	California	210025627298617201	70b815622cea36a6e7dd97bf34a8f142	American Express	37.7511926752936304	-122.431471897233507
32861	2020-06-24 04:57:35	2020-06-24	Jensen Buckridge	jensen.buckridge@geemail.com	South Bend	Indiana	3096966382495871687	33443f968fff8f3fcebe5de6be41c9ed	JCB 16 digit	41.737377624461061	-86.3455204233583089
32862	2020-06-24 05:00:32	2020-06-24	Kenji Hoeger	kenji.hoeger@warmmail.com	Frisco	Texas	53416342341704165	29c0cd0904777ea5dfd0f493665c3b76	VISA 13 digit	33.2526326326649624	-96.7370893561489851
32863	2020-06-24 05:01:11	2020-06-24	Vicente Schamberger-Abshire	vicente.schamberger.abshire@geemail.com	Hartford	Connecticut	180093018217474881	9666f10ed5490c4ebdc46516acdd663b	American Express	41.861623013998944	-72.6085619836472063
32864	2020-06-24 05:07:32	2020-06-24	Selmer Goyette	selmer.goyette@geemail.com	Louisville	Kentucky	675991749303763	698356cbb17034a002b18d7a062cf9bd	VISA 13 digit	38.2634391455348535	-85.7249012581143575
32865	2020-06-24 05:15:10	2020-06-24	Shellie Mann	shellie.mann@geemail.com	San Diego	California	869912763065586223	8f795965a22596694d20253fe8848c65	VISA 13 digit	32.7767972220268078	-117.103724930938341
32866	2020-06-24 05:16:36	2020-06-24	Jeanna Orn-Larkin	jeanna.orn.larkin@geemail.com	Seattle	Washington	6011900839969445131	e7f691349d354a76f64660cc1391a68b	Mastercard	47.5758145200479774	-122.292361807396261
32867	2020-06-24 05:19:29	2020-06-24	Cannie Rosenbaum	cannie.rosenbaum@woohoo.com	Salinas	California	4575220271670183	9b3fd439049ecbba38e0a4b383dcc2ca	JCB 16 digit	36.5993422698926167	-121.696530139976005
32868	2020-06-24 05:21:56	2020-06-24	Kerwin Nienow	kerwin.nienow@geemail.com	Little Rock	Arkansas	55998417905626412	defaeacc7310154ee60842e8aad10e0a	American Express	34.726330811651053	-92.4141828743148608
32869	2020-06-24 05:27:19	2020-06-24	Paloma Corwin	paloma.corwin@geemail.com	Springfield	Missouri	3029124822240973	ed33dad78fdf122eb07d5f50a04053fd	Discover	37.2282802408289157	-93.3060898135241246
32870	2020-06-24 05:29:09	2020-06-24	Miss Carolann Cummerata DDS	miss.carolann.cummerata.dds@warmmail.com	San Diego	California	3112075469311782343	f345038c01d8f3110f54435dfd1da936	Diners Club / Carte Blanche	32.9065644544616376	-117.069990179957827
32871	2020-06-24 05:35:45	2020-06-24	Verlie Lindgren MD	verlie.lindgren.md@geemail.com	Oklahoma City	Oklahoma	4102967725416579	088cd93270e20c18b5e774ce4c914c6c	JCB 16 digit	35.3958924718111803	-97.423809346220267
32872	2020-06-24 05:37:13	2020-06-24	Alena Runte	alena.runte@geemail.com	Miami	Florida	6011835723269112981	f16ab7ee96f9f8f0e226ea3f8e164f2b	Maestro	25.7132386618897328	-80.2823793112639379
32873	2020-06-24 06:01:38	2020-06-24	Shawna Fay	shawna.fay@warmmail.com	San Francisco	California	4779969460333581	b4048637ca3e90605c94b1594fd565eb	VISA 16 digit	37.7826308390269574	-122.412394590806386
32874	2020-06-24 06:11:28	2020-06-24	Jim Kassulke Jr.	jim.kassulke.jr.@woohoo.com	Philadelphia	Pennsylvania	869949464697992031	c336cc7a878e3e6708718abf2134ca7a	JCB 15 digit	40.0573609540663682	-75.0354917542442763
32875	2020-06-24 06:14:19	2020-06-24	Assunta Schiller PhD	assunta.schiller.phd@geemail.com	Portland	Oregon	4057736244647955	42ee67a58969a174708e252ce561abc4	JCB 16 digit	45.592462828977034	-122.748548391042277
32876	2020-06-24 06:16:43	2020-06-24	Aaden Ruecker	aaden.ruecker@geemail.com	Lancaster	California	3528135546520581778	50e67911b16fec8092929044232c6733	Diners Club / Carte Blanche	34.7083237683180741	-118.220158923228453
32877	2020-06-24 06:21:34	2020-06-24	Corina Erdman	corina.erdman@geemail.com	San Jose	California	869986609089720952	e0b204411f079219709ecab547f0ffc5	JCB 16 digit	37.2530090804964331	-121.724288771882286
32878	2020-06-24 06:49:30	2020-06-24	Evon Kuhn	evon.kuhn@warmmail.com	Athens	Georgia	180053243983894793	1ed37f105def0b3f4b5f00fc780725ce	JCB 16 digit	33.8688394518759068	-83.3789665983639594
32879	2020-06-24 07:10:04	2020-06-24	Miss Somer Volkman	miss.somer.volkman@woohoo.com	Surprise	Arizona	55958984234026273	b0b640a807daada4bf56cc76ca779ab4	Discover	33.6143082743272217	-112.518086477252467
32880	2020-06-24 07:11:26	2020-06-24	Mr. Eber DuBuque	mr.eber.dubuque@woohoo.com	Green Bay	Wisconsin	4251735181256162	f9b591fc32a161514b9d32717a746d8d	Voyager	44.5339487466558808	-88.0033787034273161
32881	2020-06-24 07:18:04	2020-06-24	Mrs. Aleen Ledner	mrs.aleen.ledner@geemail.com	Mobile	Alabama	4429602289101	c6666fedc754198de0b113e4da87e971	VISA 16 digit	30.6142040500991044	-88.1704388232573848
32882	2020-06-24 07:20:48	2020-06-24	Bernardine Ratke	bernardine.ratke@geemail.com	Washington	District of Columbia	4796434080926388	0cad46ec7fa1156905fc00eaec344596	VISA 16 digit	38.9737508202236143	-76.9172549210235559
32883	2020-06-24 07:27:50	2020-06-24	Nikhil Schroeder	nikhil.schroeder@warmmail.com	San Francisco	California	3528454819289018677	541c5e230b5dc1481a6e83e4279ccc4a	JCB 15 digit	37.7879240480816208	-122.42637991641098
32884	2020-06-24 07:29:13	2020-06-24	Arkie Turcotte MD	arkie.turcotte.md@geemail.com	Detroit	Michigan	3005009623646615	6bb675000639d2f4fa2dfe2681722371	JCB 15 digit	42.3410190022941677	-83.0701306656587803
32885	2020-06-24 07:54:51	2020-06-24	Parker Schmeler-Simonis	parker.schmeler.simonis@geemail.com	San Francisco	California	630473030227851	f90ebcbb09956606d4a5c7baf71dfd5a	American Express	37.7555883090709727	-122.443876610739466
32886	2020-06-24 08:09:36	2020-06-24	Dr. Albertus Nolan	dr.albertus.nolan@woohoo.com	Concord	California	3088919566722728912	7f973c83ef489f639404218dbad7d977	VISA 16 digit	37.9230974168915296	-122.098320343781637
32887	2020-06-24 08:10:28	2020-06-24	Desmond Wintheiser	desmond.wintheiser@woohoo.com	Winston–Salem	North Carolina	4215902605803053	eb5b01c898a7d0ab71ec119aace0bc12	Diners Club / Carte Blanche	36.080895519885047	-80.2420212341602905
32888	2020-06-24 08:26:19	2020-06-24	Daxton Hettinger	daxton.hettinger@woohoo.com	San Antonio	Texas	210087816702559522	df74f7fdabae2324189c6110c14a9ed2	JCB 15 digit	29.3873866043124359	-98.5832852185539821
32889	2020-06-24 08:27:36	2020-06-24	Mrs. Kaylen Smitham DVM	mrs.kaylen.smitham.dvm@geemail.com	Los Angeles	California	3096493495904965858	902d439a170382611c1048e10165faf4	Voyager	34.02907758703045	-118.337573127960042
32890	2020-06-24 08:31:57	2020-06-24	Vada Rempel	vada.rempel@warmmail.com	Kansas City	Missouri	210019207613359132	7b8231173d1d69da921d816416ae1b4a	Maestro	39.1673022699378492	-94.5819134512208421
32891	2020-06-24 08:33:50	2020-06-24	Akeem Lebsack	akeem.lebsack@warmmail.com	Berkeley	California	869974355446837832	425494fed5af524a647c977463829afd	VISA 16 digit	37.8358233366867083	-122.284478289622783
32892	2020-06-24 08:35:06	2020-06-24	Thorwald Gislason	thorwald.gislason@woohoo.com	Washington	District of Columbia	4818564671662127	28e6b3e7f01f97effeb6bb8abcb30a2c	VISA 16 digit	38.8757944246087206	-76.963210942384606
32893	2020-06-24 08:38:41	2020-06-24	Adriel Morar	adriel.morar@geemail.com	Wichita	Kansas	3088649423996020708	0763ef0dcc1d158a613cf17a560dde1f	Maestro	37.7465007173240181	-97.4026152228206428
32894	2020-06-24 08:39:33	2020-06-24	Fayette Wilkinson	fayette.wilkinson@geemail.com	Indianapolis	Indiana	3337378081467193649	65945acc3450884b08d9cba906472647	Voyager	39.8697775116197732	-86.122786326912788
32895	2020-06-24 08:39:43	2020-06-24	Icie Cormier	icie.cormier@geemail.com	San Francisco	California	4306698126738	c5e263fca775678b9df9cb9e1c91295c	JCB 16 digit	37.8350831148922069	-122.435199684094471
32896	2020-06-24 08:50:30	2020-06-24	Cilla Muller DVM	cilla.muller.dvm@warmmail.com	Houston	Texas	3337295706765535238	5eecdcfb6f74d0332cb2ed188e984b9c	JCB 16 digit	29.7746945444572724	-95.4828586174190121
32897	2020-06-24 08:50:48	2020-06-24	Tanisha McCullough-Lueilwitz	tanisha.mccullough.lueilwitz@geemail.com	Berkeley	California	3088725349839638777	e0bb70d60d3b150d699c3b05192b0625	Voyager	37.8445875187725136	-122.273211642501991
32898	2020-06-24 09:05:11	2020-06-24	Dr. Hobson Miller	dr.hobson.miller@geemail.com	San Francisco	California	3040667742301258	9e12c72f5b48b614fc3d10078a43960c	VISA 16 digit	37.8011222335514532	-122.400096693278627
32899	2020-06-24 09:10:49	2020-06-24	Noble Pagac	noble.pagac@geemail.com	Oakland	California	52658970584911670	581cb9152ec08c4c10411c1fd6474256	VISA 13 digit	37.8348761573943264	-122.270838540875886
32900	2020-06-24 09:15:18	2020-06-24	Dr. Tegan Metz II	dr.tegan.metz.ii@woohoo.com	Dallas	Texas	180063682084171338	5838c736fb832ca45fe314c3765498c9	JCB 16 digit	32.8358867899786731	-96.8134549539964553
32901	2020-06-24 09:31:20	2020-06-24	Mekhi Aufderhar	mekhi.aufderhar@geemail.com	San Francisco	California	210011749898778880	dccf3328d7b87cebcadd24b461c9b2ff	Discover	37.7842922636192	-122.434699249472928
32902	2020-06-24 09:32:22	2020-06-24	Mckinley Huel	mckinley.huel@geemail.com	Memphis	Tennessee	4866588527675	f5cf27df78f19323e7b0aac6e4f34636	Voyager	35.1452804493784896	-89.9172787999060006
32903	2020-06-24 09:32:45	2020-06-24	Kayleen Carroll	kayleen.carroll@geemail.com	Burbank	California	869935904473085423	f07c0097ab94c5bc2b7495c4dd78c223	Mastercard	34.2275137465376389	-118.298382086868969
32904	2020-06-24 09:32:46	2020-06-24	Mr. Warner Hills	mr.warner.hills@geemail.com	Baton Rouge	Louisiana	3158614544235693558	cc779a6fb7bbed4ef81723f3755ece6b	VISA 16 digit	30.4354385187130418	-91.0430955794282255
32905	2020-06-24 09:33:48	2020-06-24	Faustino Waelchi-Mertz	faustino.waelchi.mertz@warmmail.com	Grand Prairie	Texas	3096357235103535622	2cb6a3404674f4d565f16463818881aa	VISA 16 digit	32.5932675728160888	-96.938659031629939
32906	2020-06-24 09:46:22	2020-06-24	Miss Juana Kreiger MD	miss.juana.kreiger.md@warmmail.com	New York	New York	4647778553504523	1cf8008768c5c14daf963b6cb6ab264a	VISA 16 digit	40.7414673877637838	-73.8769034847047124
32907	2020-06-24 09:48:55	2020-06-24	Grecia Kub	grecia.kub@woohoo.com	Bakersfield	California	503852511082183	1db60b7564f1c4a01f19cbb3093d6d02	JCB 16 digit	35.2799509177159507	-119.012139688692244
32908	2020-06-24 09:50:05	2020-06-24	Devonte Batz	devonte.batz@woohoo.com	Tucson	Arizona	4496896870148592	e7c265c985fe0f2d3ff5e0b712d69c2d	JCB 16 digit	32.0901910711586495	-110.963285234593229
32909	2020-06-24 09:50:06	2020-06-24	Kyan Runolfsdottir	kyan.runolfsdottir@geemail.com	Long Beach	California	3006449861426859	64a4420651f26f7da1715c82bba66815	Voyager	33.7282053752157793	-118.175684851424023
32910	2020-06-24 09:56:17	2020-06-24	Treva Pouros	treva.pouros@woohoo.com	Baton Rouge	Louisiana	3012520148167245	f8050813b7a712d45d4a163b6f0e3b93	VISA 13 digit	30.527904099480061	-91.1267837974816501
32911	2020-06-24 09:58:04	2020-06-24	Casandra Baumbach MD	casandra.baumbach.md@woohoo.com	San Antonio	Texas	4632694465011589	72e569dec6b8dbf769f724115241d180	American Express	29.4256205727882687	-98.5836937043651886
32912	2020-06-24 10:03:30	2020-06-24	Jerrell Leuschke III	jerrell.leuschke.iii@woohoo.com	Chula Vista	California	6011941462950014427	633ba77f7d8cdf58e17c1c6537ea5f21	JCB 16 digit	32.7066459133986385	-116.924176497501122
32913	2020-06-24 10:21:24	2020-06-24	Ebony Rau	ebony.rau@geemail.com	San Jose	California	6011340973901690781	ab5e0631f665f4e691663c8c9770f880	JCB 16 digit	37.3706740180317354	-121.888083518411591
32914	2020-06-24 10:24:16	2020-06-24	Foy Sauer	foy.sauer@geemail.com	High Point	North Carolina	4393447167189	87bb7a4c334ca3ccf393eba6dd4da318	JCB 16 digit	36.0178618790209342	-79.9381982261985513
32915	2020-06-24 10:31:03	2020-06-24	Ouida Abernathy	ouida.abernathy@woohoo.com	San Francisco	California	869954707638998141	5ef3f1bdd0c8925671b2668fd0acacbe	VISA 16 digit	37.7792526217674762	-122.445695246108684
32916	2020-06-24 10:41:17	2020-06-24	Hedy Mayert	hedy.mayert@geemail.com	Fort Worth	Texas	3112032197327784787	36b5e998de437f5666b46ac911a2242e	American Express	32.7776439187172812	-97.2513398957725599
32917	2020-06-24 10:47:24	2020-06-24	Arno Hoeger	arno.hoeger@geemail.com	Hayward	California	3021509974778242	8e8e0faeda6257e06d61587902abbc74	Diners Club / Carte Blanche	37.714978556380423	-122.070262916877496
32918	2020-06-24 10:51:16	2020-06-24	Raleigh Effertz-Kemmer	raleigh.effertz.kemmer@warmmail.com	Fort Worth	Texas	3096698339064813800	3dbce2b6eb7a8a74e718cfa372e7bd23	JCB 16 digit	32.7259055765867259	-97.2946401126969533
32919	2020-06-24 10:55:37	2020-06-24	Aiyana Hand	aiyana.hand@geemail.com	Des Moines	Iowa	3337456553130719799	965817b7b5de5042370efb19a3525e5c	Mastercard	41.5281778022389858	-93.7066575613383321
32920	2020-06-24 10:56:43	2020-06-24	Dr. Baker Kling	dr.baker.kling@geemail.com	Midland	Texas	3112527874331126641	43167bda368ed5a387ea2b06316939e3	JCB 16 digit	31.9263280613537859	-102.05143683419935
32921	2020-06-24 11:00:37	2020-06-24	Miss Idella Collier	miss.idella.collier@geemail.com	El Paso	Texas	3740003412321826	1c3f4f1e7ed20fa3d44b39561d3d0059	American Express	31.8877294543027894	-106.344235993267972
32922	2020-06-24 11:12:49	2020-06-24	Jerrilyn Pacocha	jerrilyn.pacocha@geemail.com	Manchester	New Hampshire	55372099968275703	a24f72cbea3dd59b25fc47ed0c2da531	VISA 16 digit	42.9901080272696916	-71.3555038791973146
32923	2020-06-24 11:23:09	2020-06-24	Mr. Kingston Balistreri DVM	mr.kingston.balistreri.dvm@geemail.com	New York	New York	3337984049842813914	e03bae8a074b17616fc0fd81f7c66f9c	JCB 15 digit	40.7235959356874204	-74.0205802378140305
32924	2020-06-24 11:24:18	2020-06-24	Dr. Davon Davis	dr.davon.davis@woohoo.com	Vallejo	California	3717941065210938	3211a9c8c833f3c4f0dd237806daeb5d	VISA 16 digit	38.0375157970093198	-122.305561329364778
32925	2020-06-24 11:37:44	2020-06-24	Hollis Bode IV	hollis.bode.iv@geemail.com	Oklahoma City	Oklahoma	3528571681673406779	249d7a048290cf9fea5a071adab99ca3	Discover	35.4421565644353649	-97.4378906458046288
32926	2020-06-24 11:44:18	2020-06-24	Toby Lynch	toby.lynch@geemail.com	Aurora	Colorado	180029820792405225	67fb93918bdef00a65d6424dfe814071	Mastercard	39.5928776377458149	-104.647355918551611
32927	2020-06-24 11:48:45	2020-06-24	Margery Runte-Cummerata	margery.runte.cummerata@woohoo.com	New York	New York	3096530400874012744	a5ce051c2c7a46a8d4837402396cf25f	VISA 13 digit	40.7023791004661462	-73.94113655559606
32928	2020-06-24 11:57:30	2020-06-24	Leone Kertzmann	leone.kertzmann@geemail.com	Virginia Beach	Virginia	4035804214631313	cdde124022c98d89b8dde12a07968f35	JCB 16 digit	36.8772763329744322	-75.9345453651294093
32929	2020-06-24 12:10:45	2020-06-24	Miss Brittnee Klein DVM	miss.brittnee.klein.dvm@geemail.com	Anaheim	California	4880078071895453	504e739508be402ab1198de6be4971d8	JCB 16 digit	33.7557564350143053	-117.713212731408319
32930	2020-06-24 12:26:27	2020-06-24	Luke Waters	luke.waters@geemail.com	Lakewood	Colorado	210098277719394469	60d63db906b638909fd0565a78ff8911	VISA 16 digit	39.7185103001944739	-105.21024151197858
32931	2020-06-24 12:37:56	2020-06-24	Devin Bayer-Zieme	devin.bayer.zieme@geemail.com	Detroit	Michigan	4492673184873767	e309909aa05b5d2d01f82ed91c1dd033	JCB 15 digit	42.3195854358766255	-83.1981568500053044
32932	2020-06-24 12:56:23	2020-06-24	Ms. Keri Lynch DDS	ms.keri.lynch.dds@woohoo.com	San Antonio	Texas	3158767643003876596	eb3fd90394aff1e110394f6fdbe495ca	VISA 13 digit	29.4344224589481946	-98.4414709046784679
32933	2020-06-24 12:58:56	2020-06-24	Miss Mildred Adams PhD	miss.mildred.adams.phd@woohoo.com	Jacksonville	Florida	4598974821061	d27ad5f8a082794baf1bb584d7bd00f9	Discover	30.3290913161408149	-81.5747897255312751
32934	2020-06-24 13:03:26	2020-06-24	Charleen Hudson	charleen.hudson@woohoo.com	Bridgeport	Connecticut	3037105764082954	1009c4c46acdf0110b65f3236e7b4d92	VISA 16 digit	41.1806312883902308	-73.1050878412455347
32935	2020-06-24 13:16:21	2020-06-24	Rosco Windler	rosco.windler@geemail.com	Kansas City	Missouri	3112697698041932210	932ca81126bc0cb4b486d5b77c075753	JCB 15 digit	39.1353709661703562	-94.5126055419202942
32936	2020-06-24 13:21:30	2020-06-24	Harlie Cruickshank	harlie.cruickshank@warmmail.com	San Francisco	California	3096171789293477015	071baeb6b68ea4e4d79c003a92a5184a	Diners Club / Carte Blanche	37.7663016559635949	-122.400164548687627
32937	2020-06-24 13:30:56	2020-06-24	Babyboy Schumm	babyboy.schumm@geemail.com	San Francisco	California	6011785623289343931	5e8b76cba664c8304967fce8088e717f	JCB 15 digit	37.7460048239406802	-122.426989295115106
32938	2020-06-24 13:39:48	2020-06-24	Monique Nienow	monique.nienow@geemail.com	Houston	Texas	4007096610920952	14452640b08bd154431dda89111a3d4d	VISA 13 digit	29.7780435279555604	-95.3974370845142801
32939	2020-06-24 13:48:54	2020-06-24	Roy Heller-Hammes	roy.heller.hammes@geemail.com	Oakland	California	4735875638745	7b3cee2bb3d3ef22be2f41958a41465f	Maestro	37.817066552447173	-122.252751085461483
32940	2020-06-24 13:53:21	2020-06-24	Frederica Nicolas DVM	frederica.nicolas.dvm@warmmail.com	Burbank	California	52042251389027938	acf865d591062cfeb68231a9f8bd135c	Diners Club / Carte Blanche	34.1143371400818225	-118.256009274212275
32941	2020-06-24 13:57:38	2020-06-24	Isreal White	isreal.white@woohoo.com	Philadelphia	Pennsylvania	6011255314625107484	5bde649ebf3579477f0f01d86c81584d	VISA 16 digit	39.9766062995377922	-75.1006166973050711
32942	2020-06-24 14:28:04	2020-06-24	Mrs. Liberty Deckow	mrs.liberty.deckow@geemail.com	Cleveland	Ohio	4733352088758841	c97df92414005c2ace73e6406f850923	VISA 16 digit	41.4757780562005891	-81.6722728404920559
32943	2020-06-24 14:28:26	2020-06-24	Dr. Taurean Smitham DVM	dr.taurean.smitham.dvm@geemail.com	Dallas	Texas	4415595883000	2b33528597e7c3c46ed3d5ccda4c7cbd	Diners Club / Carte Blanche	32.7490678718119881	-96.7513151611164091
32944	2020-06-24 14:33:30	2020-06-24	Krystal Rippin	krystal.rippin@geemail.com	Little Rock	Arkansas	6011733511810425108	ef336abb56fa28603e18776510bff23d	JCB 16 digit	34.7836768946886039	-92.4025036326482905
32945	2020-06-24 14:41:29	2020-06-24	Eryn Rosenbaum	eryn.rosenbaum@geemail.com	Vacaville	California	210018350179593487	4b785205162be056b76b4559f9f17dcb	JCB 16 digit	38.3751720082141503	-121.918538119492311
32946	2020-06-24 14:44:04	2020-06-24	Caiden Kunde	caiden.kunde@geemail.com	San Francisco	California	55849893377417822	f84c960b9e1177d44c832e8bfbf4a80a	Diners Club / Carte Blanche	37.7716841132735723	-122.399690327149145
32947	2020-06-24 14:58:08	2020-06-24	Reuben Feest-Rice	reuben.feest.rice@geemail.com	Sacramento	California	060444728127117	2da87a6c1e238dcc7a771ea81bd7a1b3	VISA 13 digit	38.5322550260260712	-121.437552151574195
32948	2020-06-24 14:58:56	2020-06-24	Kayla Stokes	kayla.stokes@geemail.com	San Francisco	California	3337486980465793848	5300e99f6227346dbb9264c1977b4308	VISA 16 digit	37.770635424572248	-122.421936369942372
32949	2020-06-24 14:59:27	2020-06-24	Davian Leuschke	davian.leuschke@warmmail.com	Bellevue	Washington	4013806687128	e57e0c7e9651b9dfc9ffe2b76bc8b912	Diners Club / Carte Blanche	47.6546765226121991	-122.092979865293941
32950	2020-06-24 15:06:10	2020-06-24	Cedrick Wiegand	cedrick.wiegand@geemail.com	Rialto	California	3088573285623059387	5175215988f0affec36446eaea2f0983	Mastercard	34.0260796063330062	-117.450030403965343
32951	2020-06-24 15:10:21	2020-06-24	Courtland Schneider DDS	courtland.schneider.dds@geemail.com	Oakland	California	6011406135627079894	9e7a166d73f43ad9832eb6e371c9c77c	Discover	37.8354553048758362	-122.296351264908552
32952	2020-06-24 15:34:10	2020-06-24	Mr. Alfonzo Huels	mr.alfonzo.huels@geemail.com	Oklahoma City	Oklahoma	3434523460153910	83d258103343e37258a1dd048edac847	JCB 16 digit	35.4292476533822764	-97.5156473694730579
32953	2020-06-24 15:44:58	2020-06-24	Leonel Herzog MD	leonel.herzog.md@warmmail.com	Richmond	Virginia	3406331826789839	9d11b29c2f2638689ef17ebdc2366523	VISA 16 digit	37.5364078424625092	-77.3931539551112735
32954	2020-06-24 15:47:29	2020-06-24	Zettie West	zettie.west@geemail.com	New York	New York	3337837764657527289	3b427d88bf00a5531932dfd74e5701b6	JCB 16 digit	40.7433571465071296	-73.9231292743131547
32955	2020-06-24 16:11:45	2020-06-24	Mr. Harl Conroy	mr.harl.conroy@geemail.com	Louisville	Kentucky	3088675908648201927	0233a1661288978e5a7706a9c902c084	Mastercard	38.2580106362137897	-85.633464588464804
32956	2020-06-24 16:14:13	2020-06-24	May Ankunding-Farrell	may.ankunding.farrell@warmmail.com	Boston	Massachusetts	4806186523387	9e8e300c52ace4ea37604835f941113e	Mastercard	42.397667488798497	-71.1098560051012782
32957	2020-06-24 16:22:05	2020-06-24	Tomasa Medhurst-Hauck	tomasa.medhurst.hauck@woohoo.com	Los Angeles	California	55524389390233611	4eb86bf4d758b68093ab71bf2bcb8480	JCB 15 digit	34.1087991358112532	-118.458239944790677
32958	2020-06-24 16:24:24	2020-06-24	Pluma Powlowski	pluma.powlowski@geemail.com	Chicago	Illinois	3088139117888017221	d97c535204518851a021285a421bbc79	VISA 16 digit	41.7945031598512102	-87.6982578223135221
32959	2020-06-24 16:35:29	2020-06-24	Ines Goodwin	ines.goodwin@geemail.com	Houston	Texas	3158557548583865220	97681f24ee489385a22088c42b12df3b	JCB 15 digit	29.8813913282085224	-95.4659601891893885
32960	2020-06-24 16:37:36	2020-06-24	Josie McLaughlin	josie.mclaughlin@geemail.com	Los Angeles	California	869981598108737912	5141b2b9d39333b06e590e6b5e2b0630	Discover	33.936458683233333	-118.504072468540812
32961	2020-06-24 16:38:31	2020-06-24	Jennings Stark	jennings.stark@geemail.com	Chicago	Illinois	210038801677721851	b1a2e5eb5c7e1520b94a89364d97cb9b	Voyager	41.8945848138839025	-87.6023490015447095
32962	2020-06-24 16:46:00	2020-06-24	Squire Kautzer	squire.kautzer@warmmail.com	Carrollton	Texas	3088105789123820047	79f4f72559b34eb28043157fa8a4b4b8	Discover	32.9540661923974767	-96.9401498320840318
32963	2020-06-24 16:51:43	2020-06-24	Manerva Ondricka-Douglas	manerva.ondricka.douglas@geemail.com	Indianapolis	Indiana	51437344484669069	7efe545256403c127fa6dd99337a3206	Voyager	39.7521087220411715	-86.143843661594758
32964	2020-06-24 17:04:05	2020-06-24	Addyson Schmeler	addyson.schmeler@woohoo.com	San Jose	California	4617451423448687	526e0e44e5216180e7e20cc4ca693906	JCB 16 digit	37.2023413049809619	-121.786592562518635
32965	2020-06-24 17:04:49	2020-06-24	Dr. Prentiss Goldner II	dr.prentiss.goldner.ii@geemail.com	Rancho Cucamonga	California	060404706646272	3dfbd7ee6af9d20fe18ddcba47952255	Diners Club / Carte Blanche	34.0766104521222388	-117.472792031477013
32966	2020-06-24 17:05:18	2020-06-24	Miss Valentina Franecki DVM	miss.valentina.franecki.dvm@geemail.com	Louisville	Kentucky	210025732566424403	3e4ad9565390b7c4a20a0191c158d998	Discover	38.1457383596707089	-85.554453335290404
32967	2020-06-24 17:07:44	2020-06-24	Harper Walker	harper.walker@geemail.com	Mobile	Alabama	3466986352894886	adbc634a8393ba763fa30e61598063b3	JCB 16 digit	30.6487481329698106	-88.0147176812540692
32968	2020-06-24 17:20:54	2020-06-24	Roman O'Conner	roman.o'conner@geemail.com	Tampa	Florida	4306105630911491	48e9482c05a5e77778194112ea537e22	VISA 13 digit	27.9703713486552239	-82.5401879269842027
32969	2020-06-24 17:26:10	2020-06-24	Audrianna Nienow	audrianna.nienow@geemail.com	Houston	Texas	869912878890170116	98eddb91c354c2b92db058cba5a644de	Diners Club / Carte Blanche	29.8449941362798228	-95.4042888794574964
32970	2020-06-24 17:26:59	2020-06-24	Danita Haag	danita.haag@warmmail.com	Tucson	Arizona	3112648494336996437	f885eaf946a45d82b65a0c4958aa3793	VISA 16 digit	32.1038162225898347	-110.873191435937201
32971	2020-06-24 17:36:41	2020-06-24	Iyanna Pouros	iyanna.pouros@warmmail.com	San Francisco	California	869907141117399621	729a709ef1a9d5eb5b44794919499eac	Discover	37.7446210899345616	-122.402710024426028
32972	2020-06-24 18:07:52	2020-06-24	Mr. Diego Stamm V	mr.diego.stamm.v@woohoo.com	Louisville	Kentucky	3053583728542533	544d1dcb061d518fb6faf2ff1f7600c1	Voyager	38.1311324485480796	-85.6438614393655229
32973	2020-06-24 18:08:20	2020-06-24	Colie Wuckert	colie.wuckert@geemail.com	Las Vegas	Nevada	675938182391615	34f166888ef48040b32af29208a7105e	Maestro	36.1301091338142726	-115.213104273446277
32974	2020-06-24 18:19:56	2020-06-24	Mrs. Robbie Howell DDS	mrs.robbie.howell.dds@warmmail.com	Hialeah	Florida	3088099158136823547	c99ecc4235968e5b89e114a057401c1e	JCB 15 digit	25.8011127108685692	-80.3222373928777813
32975	2020-06-24 18:36:29	2020-06-24	Claudine Nader	claudine.nader@geemail.com	Boise	Idaho	55474701443625991	49b5f455e974cf5ec67a11e9e9648093	VISA 16 digit	43.589598178132249	-116.262065453660497
32976	2020-06-24 18:37:51	2020-06-24	Almyra Rodriguez	almyra.rodriguez@geemail.com	New York	New York	210056707075983083	3f92c181af51950cd9b456250feec775	VISA 16 digit	40.6565228855460887	-73.8477928261168302
32977	2020-06-24 18:59:46	2020-06-24	Mr. Freddy Champlin DVM	mr.freddy.champlin.dvm@geemail.com	Chicago	Illinois	4481942963348785	5268dd265787598d56673341f0aa559d	Voyager	41.9142940023284396	-87.7167489522632167
32978	2020-06-24 19:02:36	2020-06-24	Malcom Pacocha-Koss	malcom.pacocha.koss@geemail.com	Santa Clarita	California	3440414063223445	0a0ede57def5a26c19b8f4bc01d7a5bf	JCB 16 digit	34.4310728911980988	-118.497824182278293
32979	2020-06-24 19:21:08	2020-06-24	Loriann Carroll	loriann.carroll@geemail.com	Omaha	Nebraska	6011827565005751220	2772ba6d3c086caadf65d7b4241a8556	Maestro	41.2411543097492341	-96.0957913213990622
32980	2020-06-24 19:22:03	2020-06-24	Macel Braun	macel.braun@woohoo.com	San Jose	California	4639550765536	951e2a5294ef649f193b8446b437128f	VISA 16 digit	37.2674823632285026	-121.793507054097574
32981	2020-06-24 19:33:22	2020-06-24	Sasha Hand	sasha.hand@woohoo.com	El Paso	Texas	3431214951453851	eb413fa36e8f4c40986cc2601c12fa35	JCB 16 digit	31.8462276193607607	-106.514704017106453
32982	2020-06-24 19:40:27	2020-06-24	Dr. Orlin McCullough MD	dr.orlin.mccullough.md@woohoo.com	San Francisco	California	6011190389075760766	94de1974c9f52449f8b16e5d14f22d28	Discover	37.7949373539767137	-122.436355339910818
32983	2020-06-24 19:54:48	2020-06-24	Niki Littel	niki.littel@geemail.com	Tucson	Arizona	51652115466563829	07e0b353654537ea17d5e72c3ba387a9	JCB 16 digit	32.1151876722037812	-110.957535129156327
32984	2020-06-24 20:02:25	2020-06-24	Tyrin Hamill	tyrin.hamill@geemail.com	Akron	Ohio	3416734068758917	1389d55bbf0d63814224f63596d801a7	Mastercard	41.0488732308447339	-81.5747410487230837
32985	2020-06-24 20:08:19	2020-06-24	Jules Dach-Heidenreich	jules.dach.heidenreich@geemail.com	Naperville	Illinois	52217587473162621	cbfb9f6d3cb72e489e8d4a6536f51a95	JCB 16 digit	41.7132956535004098	-88.1764121092278543
32986	2020-06-24 20:10:03	2020-06-24	Mrs. Joi O'Conner	mrs.joi.o'conner@warmmail.com	Chattanooga	Tennessee	501825507092127	d5edc3fd2d6dba5e6a60b4c4b8ca5a71	Voyager	35.0086562163513193	-85.1858917074106614
32987	2020-06-24 20:18:55	2020-06-24	Major McCullough	major.mccullough@geemail.com	Durham	North Carolina	3112130736836501678	f37b564e9487886ee45f0abbf2256635	JCB 16 digit	35.8865756312165374	-78.9113952416364128
32988	2020-06-24 20:23:42	2020-06-24	Kelley Ziemann III	kelley.ziemann.iii@geemail.com	Minneapolis	Minnesota	3477945240639777	6172dbeab0cfd9b45f380a3a9ff65184	VISA 16 digit	44.913146426444122	-93.2743528145637271
32989	2020-06-24 20:30:28	2020-06-24	Smith Feil	smith.feil@geemail.com	Phoenix	Arizona	6011899952472986989	2e39c0fdd154bcaa2d26e603099cf570	Maestro	33.5300447056002966	-112.176908311659844
32990	2020-06-24 20:44:21	2020-06-24	Dr. Clearence Shields	dr.clearence.shields@geemail.com	Syracuse	New York	4658207645695491	87c1b48e584ac4816d945ce165a08729	American Express	43.0103224866874498	-76.1133352712974016
32991	2020-06-24 20:55:12	2020-06-24	Kelsey Swaniawski III	kelsey.swaniawski.iii@warmmail.com	West Palm Beach	Florida	4454684653974	96f29515eb026f4bb08d5911c4c9e49b	VISA 13 digit	26.7670703530624507	-80.163927079674238
32992	2020-06-24 20:55:34	2020-06-24	Keira Lesch	keira.lesch@warmmail.com	San Francisco	California	4264444563938	64686f78a5ea9036ffe370abdf7a6659	VISA 13 digit	37.7286072979354756	-122.412265856523419
32993	2020-06-24 20:59:11	2020-06-24	Dale Nolan PhD	dale.nolan.phd@woohoo.com	Chicago	Illinois	3031939659766982	bd46db10d4d8d237477ce5da1973173f	JCB 16 digit	41.8809807033114154	-87.6244897521130639
32994	2020-06-24 21:10:29	2020-06-24	Amit Witting	amit.witting@geemail.com	Irving	Texas	3112172602345170687	17acc6aed8b13835dab5cc8194a54d85	JCB 16 digit	32.7797490313600761	-97.0668894053250568
32995	2020-06-24 21:30:59	2020-06-24	Colt Watsica IV	colt.watsica.iv@geemail.com	New York	New York	4420813551391897	8d06f15303de04ef60148266eb83a67b	American Express	40.7520377232450954	-73.9959207767982008
32996	2020-06-24 21:33:10	2020-06-24	Dr. Javen Mitchell II	dr.javen.mitchell.ii@geemail.com	Fort Worth	Texas	3096604184322953342	078ab7dd5231b4e88e17766aeb96f2bc	JCB 15 digit	32.859326471906158	-97.3898183187756672
32997	2020-06-24 21:33:39	2020-06-24	Mrs. Zandra Rowe DDS	mrs.zandra.rowe.dds@warmmail.com	Tucson	Arizona	6011156624300969697	cc562be2b5eba7559760bc20236bbb78	JCB 16 digit	32.1931816705077907	-110.955648307990657
32998	2020-06-24 21:33:48	2020-06-24	Dr. Don Wintheiser MD	dr.don.wintheiser.md@geemail.com	St. Louis	Missouri	561231323050901	8911ef539249978a0a9e6495bef6d6a1	VISA 16 digit	38.66406188264191	-90.3283551993783647
32999	2020-06-24 21:46:12	2020-06-24	Lawrance Schowalter-Stamm	lawrance.schowalter.stamm@warmmail.com	Los Angeles	California	3096018232608329552	1919094d82261edad74ab9aed67e0661	VISA 16 digit	34.0931187086138863	-118.452637956011287
33000	2020-06-24 21:51:04	2020-06-24	Randolph Champlin	randolph.champlin@geemail.com	Anchorage	Alaska	210089017587671619	f1c34c237e1f07ba3431383692edde07	Diners Club / Carte Blanche	61.1989660497970931	-149.270085720404239
33001	2020-06-24 21:51:43	2020-06-24	Miss Emmaline Graham PhD	miss.emmaline.graham.phd@geemail.com	Aurora	Colorado	3471798056437125	1f7ed7e6c583f7294dc8cb02212e9f93	VISA 13 digit	39.7513445123676235	-104.625157145422705
33002	2020-06-24 22:01:24	2020-06-24	Franco Cole	franco.cole@geemail.com	San Francisco	California	3112238891510530823	d2495536a67d2b9fd82e38a06ea32d9e	Discover	37.8066997663542637	-122.420213223919134
33003	2020-06-24 22:17:05	2020-06-24	Oda Swaniawski	oda.swaniawski@warmmail.com	Alexandria	Virginia	4260618276604	a6b5ee5b1a7ab656beef82a5bae879d8	Voyager	38.9073428653296034	-77.1475081301279459
33004	2020-06-24 22:22:10	2020-06-24	Frederick Kirlin	frederick.kirlin@geemail.com	San Francisco	California	4175479228249	6ea484a31f49dea3dcdd3805b25e5a6e	Discover	37.8140005014100424	-122.411229052928121
33005	2020-06-24 22:23:03	2020-06-24	Dr. Dedrick Padberg	dr.dedrick.padberg@warmmail.com	Shreveport	Louisiana	3059592866032235	89688dcab32ba8131966e7ef15ee3c18	Discover	32.3942659204132895	-93.8840411486782074
33006	2020-06-24 22:23:44	2020-06-24	Mrs. Marlyn Dooley DVM	mrs.marlyn.dooley.dvm@woohoo.com	Port St. Lucie	Florida	4524139065345	f53f2749bce38b53cf3a285296565c19	VISA 13 digit	27.3335297493863862	-80.3916253993838978
33007	2020-06-24 22:28:22	2020-06-24	Mr. Federico Bergnaum I	mr.federico.bergnaum.i@warmmail.com	Garland	Texas	210009983439846609	b03a532dd9601f97c42409e4357a3a31	JCB 16 digit	32.9053354872625263	-96.6487427543543305
33008	2020-06-24 22:33:01	2020-06-24	Dr. Dorris Heller DVM	dr.dorris.heller.dvm@woohoo.com	Philadelphia	Pennsylvania	6011950139123452308	68a7d41210ac90522b1da6262e478e7b	VISA 16 digit	40.0336702319286744	-75.0955485588770415
33009	2020-06-24 22:36:33	2020-06-24	Mr. Claudio Quitzon	mr.claudio.quitzon@geemail.com	Chicago	Illinois	4351045194649596	fd48856800a7a7aea48e9bfe69e595a9	JCB 15 digit	41.7474999729380016	-87.7610792932595984
33010	2020-06-24 22:50:55	2020-06-24	Mauricio Ullrich	mauricio.ullrich@geemail.com	Des Moines	Iowa	6011015718126855287	e9a2c2128d6eafb8fbec8366f86409cb	VISA 13 digit	41.493307972534005	-93.6396906350784093
33011	2020-06-24 22:51:17	2020-06-24	Eathel Bahringer	eathel.bahringer@geemail.com	New York	New York	3528486691834945262	2badeca8fb4aa5adeb0c037f5877bae6	VISA 16 digit	40.7204657526444649	-73.9791937906656329
33012	2020-06-24 22:52:59	2020-06-24	Lillard Beer	lillard.beer@warmmail.com	Richardson	Texas	4841305690689050	c3bcb53478e277e7e076d490990c6705	JCB 16 digit	32.9994907141897826	-96.7431609881803354
33013	2020-06-24 23:16:09	2020-06-24	Dr. Mario Feeney	dr.mario.feeney@geemail.com	Tulsa	Oklahoma	3013275157499562	a503bdea5f709de5edb3730673654a88	JCB 16 digit	36.2274899930130658	-95.9111488780893353
33014	2020-06-24 23:19:34	2020-06-24	Earlene Welch-Streich	earlene.welch.streich@geemail.com	Rialto	California	3490485014875789	e2cf800bd6bc7c9953dd37b3231062c6	JCB 15 digit	34.0928859284829358	-117.303346562533832
33015	2020-06-24 23:30:44	2020-06-24	Ennis McCullough	ennis.mccullough@geemail.com	San Francisco	California	3738388455199583	990561baa4f905fd9d6aeb89bacd6414	Maestro	37.7837263666132728	-122.434692675018084
33016	2020-06-24 23:32:17	2020-06-24	Mr. Reuben Bosco	mr.reuben.bosco@geemail.com	Chicago	Illinois	6011699098805970944	f467e0b4848cc0eb4d0c6c3e00ad75dd	Diners Club / Carte Blanche	41.9345479451421639	-87.7075059595081967
33017	2020-06-24 23:32:45	2020-06-24	Lora Schumm-Mann	lora.schumm.mann@geemail.com	Huntsville	Alabama	869978658919863292	9f6143f0b045c2ac5e5fc5fbd02d404f	JCB 16 digit	34.691926229024304	-86.7657743479609564
33018	2020-06-24 23:35:13	2020-06-24	Blanchard Lind	blanchard.lind@geemail.com	Sterling Heights	Michigan	3033829696656676	289af193f2b6ff430a823c6db8d1b665	JCB 15 digit	42.5534865646705072	-83.0888770214442189
33019	2020-06-24 23:37:40	2020-06-24	Burrel Nader	burrel.nader@warmmail.com	Los Angeles	California	3007858071173896	4f0ff28ca9197ce45099c35e3c7cc247	Mastercard	33.9827780814241578	-118.502811083848769
33020	2020-06-24 23:40:32	2020-06-24	Dr. Kimberly Marquardt PhD	dr.kimberly.marquardt.phd@geemail.com	Lexington	Kentucky	3096897613714867484	b076d8ecd10e62933187db0dc056ac34	VISA 13 digit	38.0022561503451328	-84.4643628295875999
33021	2020-06-24 23:43:17	2020-06-24	Nella Casper	nella.casper@geemail.com	Charlotte	North Carolina	4083785776493658	f5ad396a9cf1036e62a32edb633e4a45	Discover	35.2801029225133362	-80.7532329915966898
33022	2020-06-24 23:44:47	2020-06-24	Chadwick Cartwright	chadwick.cartwright@warmmail.com	San Francisco	California	55928409101860759	d82ca9bf928015ab0a5b21e6fd89cff3	Diners Club / Carte Blanche	37.7650017690620956	-122.397599773889212
33023	2020-06-24 23:48:01	2020-06-24	Tal Ernser	tal.ernser@woohoo.com	Fort Worth	Texas	869934391417345017	88bad1a52ee64e25326082530276994a	JCB 16 digit	32.6974107444342224	-97.2583571713704629
33024	2020-06-24 23:49:52	2020-06-24	Dixon Bauch	dixon.bauch@geemail.com	Simi Valley	California	3096479959365145928	f2bb3cc63517650b0a6e707a866a42d8	JCB 15 digit	34.35994559826851	-118.752430368693553
33025	2020-06-25 00:00:24	2020-06-25	Felice Ondricka MD	felice.ondricka.md@geemail.com	Orlando	Florida	4271579490006330	e4992a55cbc30c677bd3896f5c7a3146	VISA 16 digit	28.3510465916045007	-81.3343072773389508
33026	2020-06-25 00:25:11	2020-06-25	Kiya Simonis	kiya.simonis@warmmail.com	Fort Wayne	Indiana	210069786800564462	466af254bbef24f9bc4b02cb6c37ca6f	Voyager	41.062794807485119	-85.0679440892986918
33027	2020-06-25 00:36:21	2020-06-25	Fairy Balistreri-Tremblay	fairy.balistreri.tremblay@geemail.com	Oakland	California	55889919131359728	f33f817605dafbf61615a2b31976ac8c	Voyager	37.7917543227576971	-122.274765129628264
33028	2020-06-25 00:37:21	2020-06-25	Ms. Gertie Dickinson	ms.gertie.dickinson@woohoo.com	Hialeah	Florida	869907018697261100	fa8e1d70264aa1baff766b4209dc8dd2	VISA 16 digit	25.8736186537869273	-80.2950459042001512
33029	2020-06-25 00:39:31	2020-06-25	Bertram Crist	bertram.crist@woohoo.com	Oakland	California	3158031329533912917	5bac926084858e28807a73fec210df1f	VISA 16 digit	37.814746140782745	-122.252894917106133
33030	2020-06-25 00:43:05	2020-06-25	Frances Bahringer	frances.bahringer@geemail.com	San Francisco	California	4380265223632	592248e3f1ae96a03183c225b2a2d1f3	Diners Club / Carte Blanche	37.7720376051687197	-122.447611497283432
33031	2020-06-25 00:52:37	2020-06-25	Neola Johns	neola.johns@geemail.com	Omaha	Nebraska	869946301079404222	72a4ab3517ba83077ade4427395f3c27	American Express	41.2083151518046904	-95.9730442249797306
33032	2020-06-25 00:55:23	2020-06-25	Chace Nicolas-Pfannerstill	chace.nicolas.pfannerstill@geemail.com	Fayetteville	North Carolina	4566231669084680	b972ef50fd3dfda8b148644f85c31fe8	Voyager	35.021860718566181	-78.9140611945781814
33033	2020-06-25 01:11:09	2020-06-25	Johnathon Lebsack	johnathon.lebsack@woohoo.com	Washington	District of Columbia	3023364708546293	ec14bcc332ee97936cd771a5075dd5d5	VISA 13 digit	38.8722574925780293	-77.0788855171043394
33034	2020-06-25 01:12:08	2020-06-25	Mrs. Lilyanna Weimann	mrs.lilyanna.weimann@warmmail.com	Moreno Valley	California	4604722060871380	157fbf3e52136980b11fc03e07919629	Mastercard	33.9001196907825744	-117.213115470434346
33035	2020-06-25 01:16:15	2020-06-25	Mistie Casper	mistie.casper@geemail.com	Cleveland	Ohio	4972741915345345	4ef87d796aab1882767b2d38806b81fe	Voyager	41.4309181591812461	-81.6981434590421571
33036	2020-06-25 01:16:34	2020-06-25	Ms. Tawana Green	ms.tawana.green@geemail.com	Boise	Idaho	210063144606105468	455f923d378bffb5fc3cf9f6d5fa6876	Diners Club / Carte Blanche	43.6059441330980491	-116.268070177473874
33037	2020-06-25 01:18:05	2020-06-25	Maleah Goodwin	maleah.goodwin@geemail.com	Oakland	California	180057577110484325	0ff46393fbe1151b5f6acf7f708875df	Diners Club / Carte Blanche	37.8393128441685036	-122.223286916350986
33038	2020-06-25 01:23:29	2020-06-25	Guadalupe Cruickshank	guadalupe.cruickshank@geemail.com	Houston	Texas	3730118671977522	c57f567885d5ade6fa7508f243883057	Maestro	29.7590908297881498	-95.3245583287455105
33039	2020-06-25 01:25:37	2020-06-25	Vinson Corkery	vinson.corkery@geemail.com	Richardson	Texas	676145485402643	32776863d8eaa21062092c8b5c2d552a	American Express	33.0254677255872622	-96.7261816219653952
33040	2020-06-25 01:27:23	2020-06-25	Merl Bartell	merl.bartell@geemail.com	Washington	District of Columbia	210019380264581112	8a6652fa51c08475c958be414b0c0caf	Diners Club / Carte Blanche	38.9497003573257459	-77.0359510360032402
33041	2020-06-25 01:47:53	2020-06-25	Rollo Herzog	rollo.herzog@geemail.com	Chicago	Illinois	502036815450543	456ed7807781560155acadb2204c1710	VISA 16 digit	41.7933724889833513	-87.5828156719479693
33042	2020-06-25 01:50:02	2020-06-25	Antwon Ankunding	antwon.ankunding@warmmail.com	Kansas City	Missouri	3158074700985116728	01538a8b6a7ee4ff2605ee0a69b3621f	VISA 13 digit	39.0348595049534026	-94.612054597701885
33043	2020-06-25 02:00:11	2020-06-25	Lakeisha Bogisich	lakeisha.bogisich@geemail.com	Huntington Beach	California	3096986378587252154	2ef308aaea6d6bfd684b669ef470a2d0	Diners Club / Carte Blanche	33.7874423909042036	-118.101963031909605
33044	2020-06-25 02:03:03	2020-06-25	Santiago Davis	santiago.davis@warmmail.com	Nashville	Tennessee	4633741682339878	43342e39e03ac42fa4ed03bd351d17b3	Maestro	36.2466366234824022	-86.8031535063777113
33045	2020-06-25 02:03:43	2020-06-25	Elden Frami PhD	elden.frami.phd@warmmail.com	Plano	Texas	3458140479532652	5897df8511b13e1ba3977d35b68b0f27	Discover	33.1329210365742455	-96.7598920713361395
33046	2020-06-25 02:04:04	2020-06-25	Mrs. Cheryll Marvin PhD	mrs.cheryll.marvin.phd@geemail.com	Green Bay	Wisconsin	55729626461958110	3425dcbb079dbc7b715eb11eb01f7730	Diners Club / Carte Blanche	44.491514937818792	-88.0018397744566272
33047	2020-06-25 02:05:38	2020-06-25	Dr. Rae Koelpin MD	dr.rae.koelpin.md@geemail.com	New York	New York	3337978530833644788	2bedd8f51d286130ad3bdeb5e7b09229	JCB 15 digit	40.5837604842837862	-74.0069743490673631
33048	2020-06-25 02:13:29	2020-06-25	Ermina Douglas	ermina.douglas@woohoo.com	Kansas City	Missouri	676274729724182	98ec4e8566ad5a2581bcd6573443bec9	Mastercard	39.1443834426648962	-94.594114032363521
33049	2020-06-25 02:28:00	2020-06-25	Dr. Katherine Murray	dr.katherine.murray@geemail.com	North Las Vegas	Nevada	6011603756091003606	dea33026768c53db686e4383db52d86f	JCB 16 digit	36.2067771026089744	-115.139904256745808
33050	2020-06-25 02:28:16	2020-06-25	Ms. Jessica Ebert DVM	ms.jessica.ebert.dvm@warmmail.com	Miami	Florida	3050428996868421	4b7ef9140c42f6663623f78b8d38e5f6	VISA 16 digit	25.8073067817974859	-80.3076001905709518
33051	2020-06-25 02:34:33	2020-06-25	Mr. Karim Leannon	mr.karim.leannon@geemail.com	Portland	Oregon	3007578182103216	7390d6b273c21b5a2740cd9c7c975da7	VISA 13 digit	45.5104811675269119	-122.640166192082688
33052	2020-06-25 02:35:53	2020-06-25	Evelin Quigley MD	evelin.quigley.md@geemail.com	Houston	Texas	4329699051986241	04e2990a0a2f54b171744a025818f2c4	American Express	29.8294458053153022	-95.4882309183027616
33053	2020-06-25 02:37:37	2020-06-25	Dr. Orson Will	dr.orson.will@woohoo.com	Virginia Beach	Virginia	3016123924117512	b8e2ef754ec489beaf7c5b740fbd06c2	Maestro	36.7045888083241891	-76.0784914956565927
33054	2020-06-25 02:39:09	2020-06-25	Harlow Davis V	harlow.davis.v@geemail.com	San Francisco	California	180013826711319320	39e16bc1b339ae5a5883b641b3ee8ed5	VISA 16 digit	37.7919223132100583	-122.422052542455603
33055	2020-06-25 02:43:03	2020-06-25	Ms. Sharee Swift	ms.sharee.swift@geemail.com	Akron	Ohio	869960344531405537	b3100838065d6332f5c1a6373ec93a9a	VISA 16 digit	41.0620001586917809	-81.5481622067593008
33056	2020-06-25 02:45:03	2020-06-25	Hildegard Mraz	hildegard.mraz@geemail.com	Sacramento	California	3337073463653201329	ee8bcf638f36d4811d40eb560912d892	VISA 16 digit	38.5474464089874189	-121.433284199541802
33057	2020-06-25 02:47:06	2020-06-25	Pierre Stanton	pierre.stanton@warmmail.com	New Orleans	Louisiana	502075350892867	1b16244b7960e3b22cc1fac67e47c2cf	VISA 13 digit	30.1464021656677126	-89.9801689604557993
33058	2020-06-25 03:14:55	2020-06-25	Alejandra Macejkovic-Dooley	alejandra.macejkovic.dooley@woohoo.com	San Diego	California	180084564122511516	90a4323df5372335c4088a900a6123c4	VISA 16 digit	32.8422593933131566	-117.173692714879294
33059	2020-06-25 03:16:44	2020-06-25	Glen Connelly	glen.connelly@geemail.com	West Palm Beach	Florida	3096676476741114545	58103176dcdff38acf2926ce656a6882	Discover	26.8040448501553392	-80.1631135138519113
33060	2020-06-25 03:17:50	2020-06-25	Ms. Aylin Nader MD	ms.aylin.nader.md@woohoo.com	Houston	Texas	6011760828742108891	8fa52cc36add9ade7613841ede2e453e	VISA 13 digit	29.7560596481043831	-95.350858330541854
33061	2020-06-25 03:24:09	2020-06-25	Alaya Mann	alaya.mann@geemail.com	Murfreesboro	Tennessee	4067718785448157	57973b0f25d410992aae6a7ada3fe43d	Maestro	35.8585753367867355	-86.5033864641413004
33062	2020-06-25 03:32:34	2020-06-25	Rashida Schowalter	rashida.schowalter@geemail.com	Irvine	California	3406870113313126	68dad5779800f3ad88c8d7ffa455d83e	Maestro	33.5990754990387757	-117.837111354340976
33063	2020-06-25 03:46:33	2020-06-25	Kyla Lynch	kyla.lynch@geemail.com	West Jordan	Utah	210038059952284414	bef25a8c959568cea29a7d4b16b1b94b	American Express	40.52266134878397	-111.952688404693447
33064	2020-06-25 03:57:03	2020-06-25	Mr. Mervin Paucek DDS	mr.mervin.paucek.dds@geemail.com	San Jose	California	4999144414042712	25784f13849a130ae22a669ac5217a13	Maestro	37.37328460768871	-121.823981868451085
33065	2020-06-25 04:04:31	2020-06-25	Ms. Orrie Rippin	ms.orrie.rippin@geemail.com	Philadelphia	Pennsylvania	3112379351372838417	02a958d62e226fddc2e13d65d00c13c0	JCB 15 digit	40.0020041008904599	-75.0544481667589451
33066	2020-06-25 04:08:36	2020-06-25	Dr. Taina Zboncak	dr.taina.zboncak@geemail.com	Seattle	Washington	869912416095104448	a47d3eea505c2ef9d8f00b29bacdcb92	Diners Club / Carte Blanche	47.6281830381527556	-122.424976870270072
33067	2020-06-25 04:11:42	2020-06-25	Emelia Hilll-Daugherty	emelia.hilll.daugherty@geemail.com	Fairfield	California	6011601053246518825	601493032edee4e410beeb9f796faad2	VISA 16 digit	38.307256341132522	-122.035540557513386
33068	2020-06-25 04:14:36	2020-06-25	Tevin Pacocha-Kunde	tevin.pacocha.kunde@warmmail.com	Madison	Wisconsin	561241761681125	58d3db3d98c50391aef044b0eaa4b7ca	Discover	43.1352696600344032	-89.410570705903325
33069	2020-06-25 04:15:31	2020-06-25	Mr. Kory Bartoletti IV	mr.kory.bartoletti.iv@geemail.com	Abilene	Texas	4404618756607553	ec3e7c8217ccd77522e58b66e2c7eb06	Diners Club / Carte Blanche	32.4388961887061598	-99.7125739111978646
33070	2020-06-25 04:25:06	2020-06-25	Pattie Runolfsdottir	pattie.runolfsdottir@geemail.com	Boston	Massachusetts	4106175489849185	de14af24bffe204295ba4eddee1b1641	VISA 16 digit	42.3499300211369984	-70.9769757871467704
33071	2020-06-25 04:37:26	2020-06-25	Manuela Considine	manuela.considine@geemail.com	Fremont	California	3733981611070691	7755d0e0f54453e395032566f68bf900	American Express	37.5233827075157365	-121.950240366113178
33072	2020-06-25 04:38:12	2020-06-25	Miss Etha Tremblay	miss.etha.tremblay@woohoo.com	Kansas City	Missouri	4308594057686	0bd90ded73005057a6bad2e5ba741827	VISA 13 digit	39.0988026981543797	-94.4931452614013097
33073	2020-06-25 04:40:04	2020-06-25	Mr. Britton Sporer	mr.britton.sporer@geemail.com	Philadelphia	Pennsylvania	501803584398923	fd9da895ef49fc8bf98b18010498ebd0	VISA 13 digit	40.0725676195189351	-75.0767030988253765
33074	2020-06-25 04:43:04	2020-06-25	Edie Hamill	edie.hamill@geemail.com	New York	New York	55897067890368249	0f7bee47acef374bc72ba991be4b27ca	Mastercard	40.5875276286844127	-73.9562794662907663
33075	2020-06-25 04:51:31	2020-06-25	Rosita Stracke	rosita.stracke@warmmail.com	New York	New York	3494438836938844	622f400fbc64eff027bc38b351bd91e8	VISA 16 digit	40.5884391561839735	-74.0191013229906503
33076	2020-06-25 04:56:43	2020-06-25	Makala Braun	makala.braun@geemail.com	San Francisco	California	3008124677055527	224483d5c8b2bf6b28ef09b6355c889e	JCB 16 digit	37.7640417354835805	-122.450664011430206
33077	2020-06-25 04:58:59	2020-06-25	Dr. Clint King	dr.clint.king@geemail.com	Aurora	Colorado	4149995533941814	76b2b2522c554c08f816b5320d7e4ede	Mastercard	39.5968327834848353	-104.788783937052642
33078	2020-06-25 05:02:15	2020-06-25	Dr. Jeffie Nolan	dr.jeffie.nolan@warmmail.com	Houston	Texas	3057467826943999	4fddfa85e5f48450ecd5f3c47d664a12	Discover	29.722562059954182	-95.3466804011274149
33079	2020-06-25 05:06:41	2020-06-25	Dr. Zakary Lynch DDS	dr.zakary.lynch.dds@geemail.com	Boston	Massachusetts	210001417120935916	dfb921b8cc42e52a9ae9218855d989f3	VISA 16 digit	42.4144164466932452	-70.964403014299279
33080	2020-06-25 05:13:09	2020-06-25	Dr. Claudius Rippin	dr.claudius.rippin@geemail.com	Columbus	Ohio	51000086172847302	8926c263dcf55bf5d7654071f9b761d6	VISA 16 digit	39.9601662193004046	-83.0177778615851025
33081	2020-06-25 05:15:57	2020-06-25	Dr. Pernell Robel PhD	dr.pernell.robel.phd@warmmail.com	New York	New York	869948313561376709	495b80136547cd17ae6cdd2fb0af434e	American Express	40.5797924730684585	-73.958257740213341
33082	2020-06-25 05:24:09	2020-06-25	Miss Zula Bauch DDS	miss.zula.bauch.dds@geemail.com	San Francisco	California	501897622711808	a489817628359bea6d8fd2b5de780866	Diners Club / Carte Blanche	37.7726132383032862	-122.449842941115122
33083	2020-06-25 05:27:25	2020-06-25	Mel Baumbach	mel.baumbach@geemail.com	Orlando	Florida	3337870534702970802	c24fae86e25ce1b2e75c8d2335b233c4	American Express	28.3797237825378765	-81.2661060113426288
33084	2020-06-25 05:27:42	2020-06-25	Chelsy Harris	chelsy.harris@geemail.com	Greeley	Colorado	561295323905828	6cb28baae68f2cdc8ee198c8efef6ccd	Maestro	40.4651296718578806	-104.748144611746824
33085	2020-06-25 06:04:58	2020-06-25	Lavon Kerluke DDS	lavon.kerluke.dds@woohoo.com	Simi Valley	California	3035719781894522	6cf4b9c690f798ba2a90defbddc3ba63	VISA 16 digit	34.2982880404923094	-118.802640315018607
33086	2020-06-25 06:06:47	2020-06-25	Ms. Danette Bergnaum DDS	ms.danette.bergnaum.dds@woohoo.com	Henderson	Nevada	4141962538593	6f771f29529fc19c01df9a7f444cd415	VISA 13 digit	35.9707682696104101	-115.111293220209703
33087	2020-06-25 06:06:51	2020-06-25	Jadon Rogahn I	jadon.rogahn.i@geemail.com	Phoenix	Arizona	589380613988650	cc70aee7406e97fa8c42bd20bff9cfce	Discover	33.6086881309215002	-112.177630120974413
33088	2020-06-25 06:15:59	2020-06-25	Miss Shelvia Strosin	miss.shelvia.strosin@geemail.com	New York	New York	4733761835970	f705cfed841fbcd4b43a4ba65fe263ff	Voyager	40.5870063061583792	-73.8580168389145229
33089	2020-06-25 06:25:44	2020-06-25	Aric Marquardt	aric.marquardt@geemail.com	Detroit	Michigan	3015608948337717	afc1e82e028ffdd30a485be46f05472c	VISA 16 digit	42.3642698205933002	-83.1072745996646489
33090	2020-06-25 06:26:25	2020-06-25	Mr. Earle Kuphal	mr.earle.kuphal@geemail.com	Phoenix	Arizona	869927649945262742	95d2406835e0b3233179d77eaeaaae8a	Voyager	33.5874626518625803	-112.04561107656211
33091	2020-06-25 06:42:35	2020-06-25	Deena Gibson DDS	deena.gibson.dds@geemail.com	San Diego	California	6011211092373415282	8f812ee7e90ad8359244888726e49e4c	Voyager	32.8358489517655201	-117.135980869494389
33092	2020-06-25 06:45:30	2020-06-25	Danna D'Amore-Doyle	danna.d'amore.doyle@geemail.com	New York	New York	3096878501265767299	446ed9a88c0f8b6d52d56c31272c7805	VISA 16 digit	40.6879919965509345	-73.8649147050350905
33093	2020-06-25 06:46:27	2020-06-25	Dr. Rahul Doyle	dr.rahul.doyle@geemail.com	Fort Worth	Texas	210070221397119634	1753955e10e1b4180307a47ed257efa8	Voyager	32.7682580190766615	-97.2736436819944572
33094	2020-06-25 06:51:41	2020-06-25	Ross Donnelly DVM	ross.donnelly.dvm@geemail.com	Milwaukee	Wisconsin	4552862001457949	e50a21a7bb721ea739b8b637c90ab3b0	Mastercard	43.1152616970326719	-87.8824051851041617
33095	2020-06-25 06:53:54	2020-06-25	Lylah Lemke	lylah.lemke@geemail.com	Oakland	California	3736606204327516	ca6140ad9e0eef23579f2eab291ad69e	Diners Club / Carte Blanche	37.7892897177099911	-122.259656385862058
33096	2020-06-25 06:55:33	2020-06-25	Jaida Baumbach	jaida.baumbach@geemail.com	Dallas	Texas	4302651224909	093457cabdddf120f9c783a075f35119	VISA 16 digit	32.7313312143359383	-96.7054349770266555
33097	2020-06-25 07:07:10	2020-06-25	Bianca Pacocha	bianca.pacocha@geemail.com	Lancaster	California	869940217657769784	ad52030d2c2f659d5658fd51bb7b9b1f	JCB 16 digit	34.7058817416675396	-118.263606728797029
33098	2020-06-25 07:20:48	2020-06-25	Dr. Trista Beahan	dr.trista.beahan@geemail.com	Oceanside	California	6011097059708278262	5b3b1031b7fffd1a366008c0116d936f	JCB 16 digit	33.2176874953675991	-117.402225113249202
33099	2020-06-25 07:26:37	2020-06-25	Miss Gennie Grant PhD	miss.gennie.grant.phd@geemail.com	Berkeley	California	4128534793903423	fc72954837d6d7c8ff6a38a398ce1d70	VISA 13 digit	37.8578093959919428	-122.247438012010505
33100	2020-06-25 07:42:26	2020-06-25	Ernest Heaney	ernest.heaney@geemail.com	San Francisco	California	6011377506765894564	c87cb162167d2fe09f3e511941cc915d	JCB 16 digit	37.7632515107169979	-122.408912603617367
33101	2020-06-25 07:49:34	2020-06-25	Mallie Lesch-Hintz	mallie.lesch.hintz@geemail.com	Victorville	California	630496964859340	d289db0418f4c181370e69f9c3f60aef	Mastercard	34.5884996406964973	-117.32727457761429
33102	2020-06-25 07:54:43	2020-06-25	Hyrum Batz	hyrum.batz@geemail.com	Richmond	Virginia	4116008566014	9194ff78ea403071a5fed7658df542a9	VISA 16 digit	37.5767543250914642	-77.5414746461193971
33103	2020-06-25 07:59:01	2020-06-25	Lucian Terry	lucian.terry@woohoo.com	New York	New York	180091283322542186	dcb5d7f45827bc9fe9591a913a1a5faf	Diners Club / Carte Blanche	40.751547675555571	-73.9562511846318813
33104	2020-06-25 08:01:46	2020-06-25	Lynette Kertzmann DVM	lynette.kertzmann.dvm@geemail.com	Hayward	California	180067399929219976	6c3a6759843a9fc05f65ae3c72f77251	VISA 16 digit	37.5953110357269651	-122.035355602416772
33105	2020-06-25 08:02:18	2020-06-25	Dr. Tyrel Rowe	dr.tyrel.rowe@geemail.com	Indianapolis	Indiana	501828197994859	d5943e3329061c7a1e7fcad3f2102e5b	Diners Club / Carte Blanche	39.7160818911164952	-86.233350318690384
33106	2020-06-25 08:03:28	2020-06-25	Lylah Auer	lylah.auer@geemail.com	Vista	California	54396467719458724	96317f0c91e7128bb66836133a4d5522	Mastercard	33.1843528303299138	-117.271183693368371
33107	2020-06-25 08:05:10	2020-06-25	Cory Roberts	cory.roberts@geemail.com	Toledo	Ohio	4006833120238	a434f7ae575e1769c57dc078e09670f0	Mastercard	41.655542586574704	-83.5530608520708995
33108	2020-06-25 08:08:47	2020-06-25	Lamar Rice	lamar.rice@geemail.com	Sacramento	California	3088315639683011410	9911e57824941e707d1fc7643b07668a	JCB 16 digit	38.5486679728873085	-121.384116294445832
33109	2020-06-25 08:11:43	2020-06-25	Hjalmer Hudson	hjalmer.hudson@geemail.com	Jacksonville	Florida	060498705030652	0d15b2b67c6f19dae94e47148cedfbf6	VISA 16 digit	30.3291288505360477	-81.622917381076519
33110	2020-06-25 08:11:52	2020-06-25	Hosteen Mayert-Fahey	hosteen.mayert.fahey@geemail.com	Anchorage	Alaska	4376573205987599	5644c110ca423069ae60e9109dd84119	JCB 16 digit	61.2215386549226963	-149.36415511710868
33111	2020-06-25 08:12:20	2020-06-25	Ron Herzog	ron.herzog@geemail.com	Vista	California	6011478974539641851	f8f0158dbef5b1ba8e121ccf1f364f3b	Maestro	33.1819569190479839	-117.203250113414981
33112	2020-06-25 08:13:27	2020-06-25	Ms. Izola Wiegand DVM	ms.izola.wiegand.dvm@woohoo.com	San Francisco	California	4256577929365	00406580dc963f3eaa906e1f008d2b6c	Voyager	37.7651325668686511	-122.462996081243318
33113	2020-06-25 08:16:55	2020-06-25	Dr. Ebony Jaskolski	dr.ebony.jaskolski@geemail.com	San Francisco	California	3088918858549190983	4d294cef8a10435d3e960ee6c12714a2	Discover	37.7713575960924857	-122.461541564272551
33114	2020-06-25 08:19:22	2020-06-25	Michial Prosacco I	michial.prosacco.i@warmmail.com	Sterling Heights	Michigan	3047874597454512	9aaa4085f8171b5c9b22786d5ec00f02	Diners Club / Carte Blanche	42.6133805048268286	-83.049897019487986
33115	2020-06-25 08:24:27	2020-06-25	Candi Renner	candi.renner@geemail.com	Columbus	Ohio	54550914066145323	74aa3889d1752ad773f1886d40f8b90d	JCB 16 digit	39.9584524712104354	-82.9026326230030577
33116	2020-06-25 08:26:33	2020-06-25	Leesa Jenkins	leesa.jenkins@geemail.com	Chicago	Illinois	210055141911115372	f2c0d054c8cf0b25dbb308d493409370	VISA 16 digit	41.8873103547211727	-87.619553690173845
33117	2020-06-25 09:09:51	2020-06-25	Clementina Krajcik DVM	clementina.krajcik.dvm@geemail.com	San Francisco	California	676156117843732	c802faaab66350944134a5c33311bab0	Mastercard	37.7411418955155469	-122.443353878595829
33118	2020-06-25 09:22:13	2020-06-25	Jensen Feil	jensen.feil@geemail.com	Boise	Idaho	3528058025465614707	70ff0ba2d409450d9e4151cf0fe1e726	American Express	43.5014749528512397	-116.320167253698045
33119	2020-06-25 09:46:04	2020-06-25	Latasha Kirlin MD	latasha.kirlin.md@geemail.com	San Francisco	California	3088859859675589833	239899fbf37c4be2bb68d1f933c40de5	JCB 16 digit	37.7779460063896906	-122.399211485585553
33120	2020-06-25 09:55:14	2020-06-25	Lavona Bosco	lavona.bosco@geemail.com	Fresno	California	3088393173698489655	fce677ba1adb151b722406963b1d123f	JCB 16 digit	36.8499438865449278	-119.769863460270315
33121	2020-06-25 10:04:06	2020-06-25	Ignatius Weber	ignatius.weber@geemail.com	Fort Worth	Texas	060454666592412	3e7ad05accc36217a5bdc9935e98c1b0	VISA 16 digit	32.8004392153173683	-97.4003259853281094
33122	2020-06-25 10:04:15	2020-06-25	Dr. Laverne Wuckert PhD	dr.laverne.wuckert.phd@geemail.com	Salem	Oregon	4198991190912412	80459e3e39c1b27e9f91e38fbe9e814b	VISA 16 digit	44.9156110716320569	-123.055755412920192
33123	2020-06-25 10:05:37	2020-06-25	Attilio Homenick	attilio.homenick@geemail.com	Stockton	California	6011899352381157162	ce2b8e33e835b1de6af249a1b2f4d1ed	Mastercard	38.0059559629030517	-121.292041423226891
33124	2020-06-25 10:07:03	2020-06-25	Julious Metz-Baumbach	julious.metz.baumbach@geemail.com	Houston	Texas	3158328492991050026	2cf1b4268811b9629907e3b2bb86e738	JCB 15 digit	29.8740478996265679	-95.3782351875226908
33125	2020-06-25 10:07:44	2020-06-25	Carson Corwin	carson.corwin@geemail.com	Huntington Beach	California	4275334562301771	1de81aa05ac8ce0b0a65fde7358d218c	VISA 16 digit	33.6300586721900885	-117.919941071666031
33126	2020-06-25 10:13:53	2020-06-25	Theodore Littel	theodore.littel@geemail.com	Berkeley	California	3158201602442361754	809b0ea421c9bf7e2879356303bf5c65	Maestro	37.872338983956638	-122.269974806135039
33127	2020-06-25 10:16:55	2020-06-25	Norita Hamill PhD	norita.hamill.phd@geemail.com	Ontario	California	6011775628231781312	8fc73fd3860815f9f976631db9f8268f	American Express	34.0531640595901735	-117.644592378065738
33128	2020-06-25 10:17:37	2020-06-25	Hollie Bayer-Mayer	hollie.bayer.mayer@geemail.com	Los Angeles	California	4664944425209	bf03ef0e12459bc2210f05df6bbb2e0c	Mastercard	33.9395551688369324	-118.444893772992486
33129	2020-06-25 10:19:18	2020-06-25	Mr. Bradley Littel IV	mr.bradley.littel.iv@geemail.com	San Francisco	California	869981126490041543	7eef20ea486536a6526ffeb71dd2f54e	Voyager	37.7746923870741895	-122.419819667444528
33130	2020-06-25 10:20:41	2020-06-25	Richard Haley	richard.haley@geemail.com	Indianapolis	Indiana	869976230168827683	10fb85282ff797c5e432ce61c4242d80	Maestro	39.8488572108101096	-86.2432964678123568
33131	2020-06-25 10:22:27	2020-06-25	Mrs. Donna Hane	mrs.donna.hane@geemail.com	Fort Worth	Texas	3010970914682988	d35e50eb93cb923c0d154de4aaa1013e	JCB 16 digit	32.879082081286235	-97.2798445283722089
33132	2020-06-25 10:25:34	2020-06-25	Dontae Cummings	dontae.cummings@warmmail.com	New York	New York	3337209279347592239	aaa1c345f7f758b0996854ba615ef3c8	VISA 16 digit	40.754134708525612	-74.0032029001869205
33133	2020-06-25 10:28:48	2020-06-25	Mrs. Alison Murphy MD	mrs.alison.murphy.md@warmmail.com	New York	New York	6011618767970725220	5a25301728fbc237d58631365a37f3d8	Mastercard	40.5939904509335747	-74.0214992196660404
33134	2020-06-25 10:38:31	2020-06-25	Dr. Prince Gleason	dr.prince.gleason@geemail.com	Birmingham	Alabama	3450426834363687	22d768e8f29e4d49d931c0718fb9ed56	JCB 16 digit	33.5243239842612297	-86.8628641591649568
33135	2020-06-25 10:44:02	2020-06-25	Lavelle Hilpert	lavelle.hilpert@warmmail.com	Mobile	Alabama	53657034096491100	761f6fb2d79c6562a76ff3b8529c9a73	Diners Club / Carte Blanche	30.651449633866175	-88.1233428556609937
33136	2020-06-25 10:45:08	2020-06-25	Kathleen Senger-Quigley	kathleen.senger.quigley@geemail.com	Albuquerque	New Mexico	3781699952832039	1d11249bf1d47aef6527e8462d3fd42c	VISA 16 digit	35.0231657090730977	-106.599107506831743
33137	2020-06-25 10:47:34	2020-06-25	Jaime Zulauf	jaime.zulauf@geemail.com	Louisville	Kentucky	676128725864772	8627c56a829c674a01acf7879b1608a9	JCB 16 digit	38.0892272113259835	-85.6162521972391772
33138	2020-06-25 10:50:30	2020-06-25	Cain Ferry	cain.ferry@geemail.com	Albuquerque	New Mexico	676342635969456	7d0dd7ed3009e25af6438053a6797a75	JCB 15 digit	35.022445414461572	-106.618388648571084
33139	2020-06-25 10:52:31	2020-06-25	Ezra Murphy	ezra.murphy@geemail.com	New York	New York	4262555570411	b7cce4c3e67a9ba9c791a60ff0a22d68	JCB 16 digit	40.5910102444458758	-73.9841172587022129
33140	2020-06-25 10:57:44	2020-06-25	Angeles Schuppe	angeles.schuppe@geemail.com	New York	New York	180002523811828929	973ab20342a155bf05761c9b164f2877	JCB 16 digit	40.6877027183528952	-73.939854038542876
33141	2020-06-25 11:04:58	2020-06-25	Meda Schaefer	meda.schaefer@woohoo.com	McAllen	Texas	3337672623954530800	cda4bb9369c23c1d8b5a98c2624454e6	VISA 16 digit	26.1657801367647949	-98.271218512797347
33142	2020-06-25 11:09:26	2020-06-25	Griffith Larkin	griffith.larkin@geemail.com	Riverside	California	53733535008536269	9f01ec69ea32fa0b5bb25cfd11a81918	VISA 13 digit	33.8697748578567044	-117.435529605342808
33143	2020-06-25 11:09:56	2020-06-25	Dawn Hudson	dawn.hudson@geemail.com	San Antonio	Texas	3096335343643739238	f44f14057a53f99c5836e9497640e80f	Mastercard	29.4978355960059915	-98.4256907752551058
33144	2020-06-25 11:14:33	2020-06-25	Ryne Wintheiser	ryne.wintheiser@warmmail.com	Toledo	Ohio	4730259864554281	22937a53be80289fd6b3fa4019c2f2cd	VISA 16 digit	41.5996741772335028	-83.6671730202488675
33145	2020-06-25 11:18:35	2020-06-25	Miss Bonny Oberbrunner	miss.bonny.oberbrunner@geemail.com	Virginia Beach	Virginia	4720336619360529	c0fed923614194474f2d89ed4ce95dd4	Diners Club / Carte Blanche	36.8392872354202012	-75.9814531203497125
33146	2020-06-25 11:47:22	2020-06-25	Louis Gulgowski	louis.gulgowski@warmmail.com	Los Angeles	California	3046144710016023	5fe7075182728b955afb40b5ec3c89c3	American Express	33.9457767050113475	-118.361916328733031
33147	2020-06-25 11:50:43	2020-06-25	Dayami Weber	dayami.weber@geemail.com	Los Angeles	California	869922773197114107	c30c84370667a4b8b1d39097e58b82ab	American Express	34.0149992789939049	-118.466258036623884
33148	2020-06-25 11:55:48	2020-06-25	Renaldo Murphy-Sauer	renaldo.murphy.sauer@geemail.com	Miramar	Florida	4483211144256	4f2cb75a03fceef77234224e562d325b	Discover	26.0601287898588936	-80.3214304146349463
33149	2020-06-25 11:57:38	2020-06-25	Travon Torphy	travon.torphy@warmmail.com	Chicago	Illinois	4318027338062474	6fbc2213bffecdaae8cf72c71800ff0b	Diners Club / Carte Blanche	41.7395666473381226	-87.7419967032067376
33150	2020-06-25 12:06:36	2020-06-25	Hall Conn	hall.conn@woohoo.com	El Cajon	California	6011838993658223122	f2f18af03a5bafe69d03dc2193024f2b	American Express	32.8759195468861591	-116.956901826727773
33151	2020-06-25 12:07:16	2020-06-25	Timmie Heaney	timmie.heaney@geemail.com	Fayetteville	North Carolina	210039815102185721	d54e65560b1c118cc3823cdf02dafd7d	Discover	35.1190842570524637	-78.9722320495303762
33152	2020-06-25 12:13:41	2020-06-25	Luther Pouros	luther.pouros@geemail.com	Huntington Beach	California	3158456403964530971	635265839a979aa8f9b5f871dc06b59e	JCB 16 digit	33.6652211888734314	-118.004886724346505
33153	2020-06-25 12:16:55	2020-06-25	Dr. Reubin Nicolas DVM	dr.reubin.nicolas.dvm@warmmail.com	San Francisco	California	6011187430364685028	70fb57b137f7203f9beb625746e77f79	Voyager	37.7545165368850633	-122.420966480120853
33154	2020-06-25 12:23:40	2020-06-25	Mrs. Dellie Feest	mrs.dellie.feest@geemail.com	Houston	Texas	4683844573383689	1cf97b8b52d6a28120aa047c6d032ec5	VISA 16 digit	29.7636654615014784	-95.4422287551701061
33155	2020-06-25 12:35:23	2020-06-25	Mansfield Murray-Fritsch	mansfield.murray.fritsch@geemail.com	Los Angeles	California	3002648585900230	89745cfb921be254e0566dd23beaae60	VISA 16 digit	34.0928332179650653	-118.349704244871802
33156	2020-06-25 12:36:34	2020-06-25	Lasonya Kuhlman	lasonya.kuhlman@woohoo.com	Pembroke Pines	Florida	3490163984024072	a85adf73c48aad82c37d4ee740ce091b	VISA 16 digit	26.0043814491052174	-80.272235283245891
33157	2020-06-25 12:40:17	2020-06-25	Khadijah Kuhn	khadijah.kuhn@geemail.com	New York	New York	53255438657055707	b26f5aee04c3b4aba58696fd2279308a	Discover	40.6264404253792009	-73.943845783117041
33158	2020-06-25 12:46:51	2020-06-25	Tera O'Keefe	tera.o'keefe@geemail.com	Dallas	Texas	3337617836279388690	64bcba3a3a9009da3eddd17c7edfb7a3	VISA 13 digit	32.8752706775713719	-96.6790421149656112
33159	2020-06-25 12:57:19	2020-06-25	Michial Hickle IV	michial.hickle.iv@woohoo.com	Aurora	Colorado	6011525561746734810	eb5b94a7ede4e82e3a37176120f5563e	Mastercard	39.6535464205890946	-104.697618075844645
33160	2020-06-25 13:00:01	2020-06-25	Indiana Schmitt DVM	indiana.schmitt.dvm@woohoo.com	Austin	Texas	630447323999392	f85a5a54c694c7fa89f14dc1818140be	Diners Club / Carte Blanche	30.3710461204066853	-97.7243105354025943
33161	2020-06-25 13:00:26	2020-06-25	Lyle Hamill	lyle.hamill@geemail.com	San Diego	California	6011588818788626500	7b777d2a58da6ba524913bd8aeeb0d9f	American Express	32.8850877147700658	-117.156603620331737
33162	2020-06-25 13:02:39	2020-06-25	Mr. Jamie Shields PhD	mr.jamie.shields.phd@geemail.com	Santa Clarita	California	4046566961028	5e5d574149c44598e81fba333a9eed34	VISA 16 digit	34.4213549179695519	-118.424063740866998
33163	2020-06-25 13:09:58	2020-06-25	Amalie Stiedemann DVM	amalie.stiedemann.dvm@warmmail.com	Cary	North Carolina	6011961205771305945	072fee349a0ee0d8b747c441ce3dd174	VISA 13 digit	35.7026539445962783	-78.8241091356698433
33164	2020-06-25 13:21:40	2020-06-25	Nova Smith	nova.smith@geemail.com	Portland	Oregon	3462797854885718	b3456d91383bf86131d5f0b3619350ab	Mastercard	45.6229551709145298	-122.557525999797519
33165	2020-06-25 13:34:22	2020-06-25	Jovita Rosenbaum	jovita.rosenbaum@geemail.com	Virginia Beach	Virginia	3112041697535755429	c32917724de7da35aaabd177061242fc	Diners Club / Carte Blanche	36.8652213229052705	-76.0464800670415144
33166	2020-06-25 13:37:12	2020-06-25	Alexina Wolf	alexina.wolf@geemail.com	Los Angeles	California	3422938303614668	e3a29de1b1d0b2a9a45e6073d96b9e92	JCB 16 digit	33.9746181235514584	-118.497820935164754
33167	2020-06-25 13:40:13	2020-06-25	Bryton Mayer	bryton.mayer@geemail.com	New York	New York	676216999776285	64b2ab91fe022d19f82756b300b52a56	Maestro	40.7006125084813704	-73.9105086630105887
33168	2020-06-25 13:50:04	2020-06-25	Mr. Linn Crist I	mr.linn.crist.i@geemail.com	New York	New York	3112443066368990129	a78b29c3d0341ffbb42fe12bb9c1277b	American Express	40.6193014084584973	-73.9174353052757596
33169	2020-06-25 13:51:13	2020-06-25	Mertie Nitzsche	mertie.nitzsche@warmmail.com	New York	New York	4210270251034638	152c4faca54d4d76b61705b25cd92e2e	Diners Club / Carte Blanche	40.7510030650757216	-73.854703213450307
33170	2020-06-25 14:14:13	2020-06-25	Louie Johnston	louie.johnston@geemail.com	Garland	Texas	4004056015091539	694995d5ccbb91c3a6e04bb2171bdb2a	VISA 13 digit	32.830427301046619	-96.54960215940811
33171	2020-06-25 14:17:06	2020-06-25	Lea Hilll	lea.hilll@geemail.com	Birmingham	Alabama	4768914603834	160dbe5bf77252810b2b94e3e07ca602	Voyager	33.5239644091367737	-86.8105654055960514
33172	2020-06-25 14:18:30	2020-06-25	Daulton Adams	daulton.adams@warmmail.com	Visalia	California	6011212721072205953	2e7f00765690c24c90e454dbe40c20e0	JCB 16 digit	36.3791490949645677	-119.299058615754916
33173	2020-06-25 14:21:05	2020-06-25	Reino Collins-Schultz	reino.collins.schultz@geemail.com	Cleveland	Ohio	4000167892126340	5045d3e0d54f8efe85c73b9261810139	JCB 16 digit	41.5313543578926456	-81.7641795728128358
33174	2020-06-25 14:21:43	2020-06-25	Kendal Ruecker V	kendal.ruecker.v@geemail.com	San Francisco	California	869938096608002527	0e5e6e97f5e4781c5ad29202935a5f73	Mastercard	37.7889320920130132	-122.415314615198227
33175	2020-06-25 14:22:50	2020-06-25	Margeret Steuber	margeret.steuber@geemail.com	Augusta	Georgia	4035668026667603	f812ffd153b2b847e907cc615ec801fa	JCB 16 digit	33.4441635939031841	-82.078272856615115
33176	2020-06-25 14:32:33	2020-06-25	Miss Thomasina Quigley	miss.thomasina.quigley@geemail.com	Dallas	Texas	3528301620850609760	d4b4a8ac8fab719cd83c06892fed7622	VISA 13 digit	32.7545824499607079	-96.8482197087686387
33177	2020-06-25 14:34:27	2020-06-25	Miss Mai Langosh MD	miss.mai.langosh.md@geemail.com	Hollywood	Florida	869916786739276133	61af21f9499fe3febdecdd11a5f6ac32	JCB 16 digit	26.0926757303010675	-80.1679743558917153
33178	2020-06-25 14:36:45	2020-06-25	Breonna Crooks	breonna.crooks@geemail.com	Houston	Texas	3158208847250457417	be076dc12a40cc285a3e4dbde5da4fd3	JCB 16 digit	29.7620301416687667	-95.3219960139613676
33179	2020-06-25 14:44:46	2020-06-25	Konnor Murazik	konnor.murazik@geemail.com	Port St. Lucie	Florida	676319896322021	c4684b85d33385e879631e8bd1dde4c6	Discover	27.2480935966730122	-80.4336266065102024
33180	2020-06-25 14:58:18	2020-06-25	Ottie Gleichner	ottie.gleichner@warmmail.com	Berkeley	California	3158257481830047199	5987c82a696e395750a71e9efaa3937a	Diners Club / Carte Blanche	37.8483403113451686	-122.27871317654612
33181	2020-06-25 15:06:18	2020-06-25	Miguelangel Ankunding	miguelangel.ankunding@geemail.com	Philadelphia	Pennsylvania	3033116099865108	d4d33d95fcdd1fd52ccc1aa2b31b0a20	JCB 16 digit	39.9585482459008716	-75.1321110325299202
33182	2020-06-25 15:23:38	2020-06-25	Dalton Lubowitz-Terry	dalton.lubowitz.terry@warmmail.com	Chicago	Illinois	6011265709485419093	6562e7457fab5e64044293766f7cac3e	American Express	41.8972192426979575	-87.7237952967204109
33183	2020-06-25 15:36:44	2020-06-25	Jimmy Krajcik	jimmy.krajcik@geemail.com	Savannah	Georgia	869948286531732682	da88286966d40890b2a01519025302e0	American Express	31.9411433577164985	-81.1175513530768484
33184	2020-06-25 15:38:26	2020-06-25	Valentin Morar Jr.	valentin.morar.jr.@geemail.com	Macon	Georgia	3158633271744737604	596c9ba15a96b50f1381b275ac850dde	Diners Club / Carte Blanche	32.8069796139385517	-83.7839212202660661
33185	2020-06-25 15:43:58	2020-06-25	Dessa Walker	dessa.walker@geemail.com	Killeen	Texas	4438264521466817	aa92c7c88c9356b8a9b9f1e1aed1f46b	VISA 13 digit	31.0516741824101672	-97.8093391448426956
33186	2020-06-25 16:06:20	2020-06-25	Geralyn Beahan-Nienow	geralyn.beahan.nienow@geemail.com	San Diego	California	6011885129082237915	11cb7f8794e46f035b2f216b90c1b42c	JCB 16 digit	32.753886799101906	-117.050874812519183
33187	2020-06-25 16:08:30	2020-06-25	Dr. Ted Littel	dr.ted.littel@woohoo.com	Minneapolis	Minnesota	54835855991440171	2ab1ecd399fa83152b293b25fc0816ad	Maestro	45.0275529970966275	-93.2029790665294939
33188	2020-06-25 16:11:36	2020-06-25	Jimena Tremblay	jimena.tremblay@warmmail.com	Chicago	Illinois	4975680138329206	128b7ae74d62b34c49befe1b10b64f94	Maestro	41.7547247960068333	-87.6747533397313106
33189	2020-06-25 16:14:49	2020-06-25	Macy Zemlak	macy.zemlak@geemail.com	Chicago	Illinois	4203554251283728	a3295b1fc5a43271d5eeec4b2b5c128b	Mastercard	41.7463294574826946	-87.6995758808247672
33190	2020-06-25 16:22:13	2020-06-25	Edd Johnson	edd.johnson@woohoo.com	New York	New York	869924151493590155	ca339a210f6c5a6223483267f19daef5	VISA 16 digit	40.6196559084802828	-73.9300938390556723
33191	2020-06-25 16:40:22	2020-06-25	Mrs. Karlee Borer	mrs.karlee.borer@geemail.com	Los Angeles	California	561201198270892	22608293608baf02c2210e0da83b7cee	Voyager	33.9327068267255996	-118.343991090077154
33192	2020-06-25 16:40:45	2020-06-25	Eugenio Towne	eugenio.towne@warmmail.com	Houston	Texas	4340757768155	26860de97e46d08d7ed1a354d0841bb6	Diners Club / Carte Blanche	29.8589556446377173	-95.3476135473247695
33193	2020-06-25 16:41:55	2020-06-25	Kendal Murphy	kendal.murphy@geemail.com	Tacoma	Washington	3088122906005104782	7b5b7e3931760ae63c4a3ef47471e55a	Voyager	47.1594779394686228	-122.478666194691513
33194	2020-06-25 16:43:05	2020-06-25	Marti Boehm	marti.boehm@geemail.com	Westminster	Colorado	210015216483528290	5168c2a31487948836de50b52daaca3d	Mastercard	39.9018793263778093	-105.155231504063693
33195	2020-06-25 16:45:18	2020-06-25	Redmond Torp	redmond.torp@geemail.com	San Diego	California	53617794004902857	5845233cd961a778034a8bd4d7869477	Maestro	32.8157971019923664	-117.115095472838732
33196	2020-06-25 16:55:23	2020-06-25	Melvyn Huel	melvyn.huel@woohoo.com	San Francisco	California	3528534649888787578	203647cffaba69edac39af86b0ba8607	VISA 13 digit	37.7855233610892896	-122.42878704987514
33197	2020-06-25 17:18:49	2020-06-25	Mr. Denis Von	mr.denis.von@woohoo.com	Boston	Massachusetts	4467583170627	01d5981e1bd1ead8bbb11723da12b6f8	VISA 13 digit	42.2931093163955936	-70.9508919239461449
33198	2020-06-25 17:20:20	2020-06-25	Dr. Daisey Kshlerin	dr.daisey.kshlerin@geemail.com	Portland	Oregon	180090867705963034	c63ca79fc6150e6fae0d89e1df9bd65b	Mastercard	45.6215502059441036	-122.591462824027985
33199	2020-06-25 17:24:56	2020-06-25	German Stehr-Rippin	german.stehr.rippin@woohoo.com	St. Petersburg	Florida	4885649709582278	18cfb5193fd9c4bee0c25cbb16652334	Mastercard	27.7672182755898689	-82.5857656561661457
33200	2020-06-25 17:25:11	2020-06-25	Earlie Kemmer-Botsford	earlie.kemmer.botsford@woohoo.com	Houston	Texas	210020610988156743	182b765e19040a6bf1ba61995100e4e6	VISA 16 digit	29.7850749876894056	-95.4549057969372683
33201	2020-06-25 17:27:53	2020-06-25	Alyson Corwin-Little	alyson.corwin.little@geemail.com	Concord	California	4003278662887891	4f8efb29283f4930525f36028a6fd217	VISA 16 digit	38.0101616269376166	-122.051939366728433
33202	2020-06-25 17:30:37	2020-06-25	Dwight Stoltenberg-Howell	dwight.stoltenberg.howell@geemail.com	Vacaville	California	53278607345072927	cab95d815d76644a0f277987ee79a220	VISA 13 digit	38.2605063673235506	-121.889370849344147
33203	2020-06-25 17:33:08	2020-06-25	Grecia D'Amore DDS	grecia.d'amore.dds@geemail.com	Houston	Texas	210028334518029096	01ea2f2904aa3a32b93dc250baadaf3c	Diners Club / Carte Blanche	29.7922582320015863	-95.3852184609059321
33204	2020-06-25 17:36:08	2020-06-25	Greene Dickinson-Hahn	greene.dickinson.hahn@geemail.com	New Orleans	Louisiana	869926652331156354	434057ed4a2908f239c747bad2bfc59c	JCB 15 digit	30.0967270942885428	-89.8475826981738237
33205	2020-06-25 17:36:56	2020-06-25	Vernie Yundt	vernie.yundt@geemail.com	McAllen	Texas	3088601512718331108	75ad7bfcf63e1ef8c185e8eff17600f5	VISA 16 digit	26.2702814350210119	-98.1982828806467296
33206	2020-06-25 17:39:34	2020-06-25	Millie Rippin	millie.rippin@geemail.com	Tempe	Arizona	4561129362823047	cf6abbded8ee7716fbfd3bcac111b13a	Mastercard	33.3680221868134979	-111.869066050325699
33207	2020-06-25 17:40:12	2020-06-25	Harland McDermott	harland.mcdermott@woohoo.com	San Francisco	California	676293163571156	ff95de3b4ba753e094fe00d8202215a9	JCB 15 digit	37.7609123771180037	-122.462230953149501
33208	2020-06-25 17:42:18	2020-06-25	Florie Swift	florie.swift@geemail.com	Los Angeles	California	55702056668476966	cbdcd73c4ec728ae2d3f5cf84262a3e9	VISA 16 digit	33.9483782707579422	-118.422150671015672
33209	2020-06-25 17:42:27	2020-06-25	Elle Pagac	elle.pagac@geemail.com	Salem	Oregon	676149867211440	0e3aa4328e8d817eda81cc29772cf999	JCB 16 digit	44.8846927923418519	-122.968349276778099
33210	2020-06-25 17:44:52	2020-06-25	Vernie Hamill	vernie.hamill@woohoo.com	San Francisco	California	210063058412588909	140584092bd88c7fd9029b630a83f756	VISA 16 digit	37.7410760341024343	-122.394503680049127
33211	2020-06-25 17:52:07	2020-06-25	Kennedy Morissette	kennedy.morissette@geemail.com	Houston	Texas	3041257266994214	f789fd4def761eb70f2ac1c884ce67f4	Voyager	29.7412250971499823	-95.3000164925135635
33212	2020-06-25 17:58:01	2020-06-25	Thyra Hoeger-Kunze	thyra.hoeger.kunze@woohoo.com	Washington	District of Columbia	869969610550308443	f0b7a8b627d5d6845e18212765bec71b	Voyager	38.8399501883223621	-76.9214539995629423
33213	2020-06-25 18:01:45	2020-06-25	Dr. Salomon Bahringer	dr.salomon.bahringer@geemail.com	New York	New York	3112797162248396074	5904d0cd832dc474af4b773d995fe43f	VISA 16 digit	40.6460217470061025	-73.9864773691993207
33214	2020-06-25 18:06:48	2020-06-25	Claudius Sporer	claudius.sporer@geemail.com	Oakland	California	52671462563649243	6f533192a78b1302868e082741463384	VISA 13 digit	37.8090845860362279	-122.292042381995614
33215	2020-06-25 18:09:37	2020-06-25	Karol Kris	karol.kris@geemail.com	Los Angeles	California	675999940093596	29ee02b41dacdeed02d20d42ac27be61	VISA 16 digit	33.9791582478541869	-118.44548977296725
33216	2020-06-25 18:22:46	2020-06-25	Mrs. Bobby Wuckert	mrs.bobby.wuckert@geemail.com	Boston	Massachusetts	3158779341125835824	edd9ff5bab90fb6407dd90a400378888	JCB 15 digit	42.3423235621936627	-71.1103378884911592
33217	2020-06-25 18:26:17	2020-06-25	Solomon Ernser DDS	solomon.ernser.dds@woohoo.com	Long Beach	California	3088165739175606890	97fafb24ea4fffa4983c57881188ca33	JCB 16 digit	33.797854900388792	-118.092874475165459
33218	2020-06-25 18:27:22	2020-06-25	Dr. Mitzi Balistreri PhD	dr.mitzi.balistreri.phd@geemail.com	Santa Ana	California	55131226852666778	3879a30a0bb1a6cece2710c18d2dd4bb	VISA 16 digit	33.6968763811618075	-117.898704393107437
33219	2020-06-25 18:28:59	2020-06-25	Cielo Hermann DDS	cielo.hermann.dds@woohoo.com	Downey	California	4876234185950884	41983ab4231d0e4b3988cbecfe04778e	Maestro	33.9577776724256566	-118.045501759286594
33220	2020-06-25 18:29:33	2020-06-25	Sophronia Yundt	sophronia.yundt@geemail.com	San Francisco	California	3096927956604158330	9d23f70459adbcf2259674d3057bdcb1	VISA 13 digit	37.7836054039667957	-122.413456578786452
33221	2020-06-25 18:33:39	2020-06-25	Jacey Marvin-Stokes	jacey.marvin.stokes@geemail.com	Fayetteville	North Carolina	3054384765321017	2e8f264f1de5999e3924c6f04bf10270	JCB 16 digit	35.0780560609672207	-79.047877142079173
33222	2020-06-25 18:35:43	2020-06-25	Selma Skiles	selma.skiles@geemail.com	Glendale	California	3007111918804053	5ae2abcecadea39da98ff3b174233910	American Express	34.2198686191100592	-118.20767743241899
33223	2020-06-25 18:40:28	2020-06-25	Monte Rau I	monte.rau.i@geemail.com	Raleigh	North Carolina	4329200931220743	c46b126943efbb0419a32ce99270d6c2	JCB 16 digit	35.8537709308922246	-78.6629644651368238
33224	2020-06-25 18:55:21	2020-06-25	Aloysius O'Reilly-Anderson	aloysius.o'reilly.anderson@geemail.com	Chicago	Illinois	3702630387170063	a4cfca145308f7501bc277e44d6c7099	VISA 16 digit	41.8212357956752214	-87.6528033310577257
33225	2020-06-25 19:05:55	2020-06-25	Dr. Alton Glover II	dr.alton.glover.ii@geemail.com	Toledo	Ohio	3158004544634878683	daf9c563297ed60372457dfed9cac6f5	Voyager	41.646620097261291	-83.6346989625465227
33226	2020-06-25 19:14:17	2020-06-25	Gabriel Cole	gabriel.cole@geemail.com	Naperville	Illinois	210022881944989232	bb5cc4cbf4dcf57003664558c65db2a1	Discover	41.7728255536787216	-88.2259505716506425
33227	2020-06-25 19:23:40	2020-06-25	Mr. Jaquez Nolan	mr.jaquez.nolan@geemail.com	Stockton	California	3096968538154210909	dd687242ac09940787c9e1f8e097b243	VISA 13 digit	38.0747874637331805	-121.386598885766418
33228	2020-06-25 19:35:44	2020-06-25	Averi Dietrich DDS	averi.dietrich.dds@geemail.com	Amarillo	Texas	210053746751196704	692a21ac80250be7d96160ac23d054e7	JCB 16 digit	35.2346943723201775	-101.891917234505343
33229	2020-06-25 19:37:01	2020-06-25	Vernon Marks-Cormier	vernon.marks.cormier@geemail.com	Memphis	Tennessee	55852260534565246	af1130f8a720cc049d84ad278c1e138f	Maestro	35.0305992029208682	-90.0626072746027262
33230	2020-06-25 19:42:36	2020-06-25	Verdie Hilll	verdie.hilll@woohoo.com	Phoenix	Arizona	4573409342711082	c9f83a48663a60158a99f50fdb6c078e	Diners Club / Carte Blanche	33.5744935414221146	-112.031276948370419
33231	2020-06-25 19:42:58	2020-06-25	Chet Halvorson	chet.halvorson@geemail.com	San Francisco	California	3528405982555492800	d70d58c455e084f9e628e243f427a3b1	JCB 16 digit	37.7664873336949114	-122.436261838038419
33232	2020-06-25 19:44:15	2020-06-25	Elmyra Bins	elmyra.bins@woohoo.com	San Diego	California	3337860634685809001	1b4a298ec1cae585b52d9cc73af6b180	Diners Club / Carte Blanche	32.8609173211801817	-117.067539771357559
33233	2020-06-25 19:52:02	2020-06-25	Ms. Neva Collins	ms.neva.collins@woohoo.com	Richmond	California	4859713063113468	29ddacf5b39751169e309671d981c0b1	VISA 16 digit	37.949057151745258	-122.369817652166262
33234	2020-06-25 20:15:04	2020-06-25	Mrs. Lorean Hodkiewicz MD	mrs.lorean.hodkiewicz.md@woohoo.com	Jacksonville	Florida	501810632396643	36d6b27436786a7617990b4b3730b020	Diners Club / Carte Blanche	30.4304256774071611	-81.7468343902923209
33235	2020-06-25 20:24:36	2020-06-25	Angela Kuvalis	angela.kuvalis@geemail.com	Berkeley	California	4601934620308	4058cbf325a8a9c106185b9d15bc26c9	Discover	37.8452955699222855	-122.268360769505378
33236	2020-06-25 20:29:09	2020-06-25	Natalie Emard	natalie.emard@geemail.com	Billings	Montana	4944690321129	a8f3e078a4ddf7e5b3acbbdb02bd8e85	JCB 16 digit	45.7923658312521837	-108.603065345732119
33237	2020-06-25 20:33:04	2020-06-25	Theodore Wisozk	theodore.wisozk@geemail.com	New York	New York	3440601566644784	913bff924144ce860286521d37a18dd7	JCB 15 digit	40.7017032614666974	-73.853925107688454
33238	2020-06-25 20:39:24	2020-06-25	Braylon Hane IV	braylon.hane.iv@geemail.com	Wichita Falls	Texas	6011804608412800086	cbe873ca02c43a82f1afa70d81b80fa8	Maestro	33.9778540181189754	-98.4823477510750251
33239	2020-06-25 20:44:24	2020-06-25	Aletha Spinka	aletha.spinka@woohoo.com	New Orleans	Louisiana	3747588310164891	c0ac609dc425aa45d2a7a0dedf591a79	Diners Club / Carte Blanche	30.0370753746028996	-89.8671918187551171
33240	2020-06-25 20:49:44	2020-06-25	Juston Orn	juston.orn@geemail.com	San Antonio	Texas	869963377455919536	b8eb37ce73e42c16f437236e764ff45d	JCB 15 digit	29.5492127890303742	-98.5054475691471225
33241	2020-06-25 20:50:22	2020-06-25	April Kiehn	april.kiehn@geemail.com	San Francisco	California	4287719185572178	80d193a75ff7ac02ac8608535774c0da	Mastercard	37.7799367943855486	-122.469966644021881
33242	2020-06-25 20:58:52	2020-06-25	Miss Savanah Monahan MD	miss.savanah.monahan.md@geemail.com	San Francisco	California	3429595548222260	511fad7719242ff3cb3ad0686994a059	Diners Club / Carte Blanche	37.7660272534094119	-122.466758449149737
33243	2020-06-25 21:01:14	2020-06-25	Wylie Legros	wylie.legros@geemail.com	Los Angeles	California	55680002331122575	f23656240cd7a754a2898f0c00ffb557	VISA 16 digit	34.0884339683089408	-118.436077426047248
33244	2020-06-25 21:02:37	2020-06-25	Lela Bayer DVM	lela.bayer.dvm@warmmail.com	Hartford	Connecticut	676387439983161	cd97b039cdcb43f74392384eed6bc3d3	JCB 16 digit	41.7567193489536663	-72.6938998110018701
33245	2020-06-25 21:16:13	2020-06-25	Waverly Schiller PhD	waverly.schiller.phd@geemail.com	Evansville	Indiana	676333819451718	21fc3193b3a1ab6a0c13b9ad6577607f	Maestro	37.956942004631081	-87.4769346428036698
33246	2020-06-25 21:20:12	2020-06-25	Shonna McDermott	shonna.mcdermott@geemail.com	Chicago	Illinois	4608444666322926	33faa6b40cab0a94a4e87687f7ea09eb	Discover	41.8856348304379722	-87.6754432407703206
33247	2020-06-25 21:28:06	2020-06-25	Suzan Ernser MD	suzan.ernser.md@geemail.com	Colorado Springs	Colorado	3337848748105720155	fb13bf2880e8c42c9f12f60b49f9eae1	American Express	38.8065812357749778	-104.748544751216471
33248	2020-06-25 21:29:28	2020-06-25	Kristine Kunde-Fritsch	kristine.kunde.fritsch@geemail.com	Columbia	Missouri	4806576335836461	e24fbd789b74aaf9a92897de09e9f42c	VISA 16 digit	38.8639734787282194	-92.3409858867113513
33249	2020-06-25 21:48:03	2020-06-25	Miss Liberty D'Amore	miss.liberty.d'amore@woohoo.com	New York	New York	4992699540714788	2b00cc067a679198573087bc0d8ec8a9	VISA 13 digit	40.6037008644770836	-73.8741406459722612
33250	2020-06-25 21:55:53	2020-06-25	Noreta Steuber	noreta.steuber@geemail.com	Garden Grove	California	630400817411481	e68cdc7dbe8016125218bc3a74df42b1	VISA 16 digit	33.8358948366541412	-117.876713059378787
33251	2020-06-25 21:59:02	2020-06-25	Anissa Bode PhD	anissa.bode.phd@geemail.com	Oakland	California	3763670777766472	cc268e029a53a93f9dbde5ffcb5659cf	Diners Club / Carte Blanche	37.8014485739709301	-122.23547661895833
33252	2020-06-25 22:12:34	2020-06-25	Texas Stark	texas.stark@woohoo.com	Los Angeles	California	3337411188488162377	12a3b17036971e5138961840aac3c5cd	JCB 15 digit	34.078896036125343	-118.423636929596952
33253	2020-06-25 22:15:11	2020-06-25	Albina Baumbach	albina.baumbach@geemail.com	Raleigh	North Carolina	630475429387758	1fa7df5d79954e5a54787abc99fb917a	VISA 13 digit	35.7978328454907953	-78.57431356706023
33254	2020-06-25 22:20:07	2020-06-25	Mossie Hessel	mossie.hessel@woohoo.com	San Francisco	California	4172265793741712	0c7f3e745c34cc156415e7e9c4981961	Mastercard	37.7659501956730921	-122.420835331525694
33255	2020-06-25 22:22:53	2020-06-25	Dr. Wess Runolfsson	dr.wess.runolfsson@geemail.com	Macon	Georgia	4539319456643	c0c81c6cac1cbd1d2848208c559e5845	Mastercard	32.7989765861548435	-83.7836697196781586
33256	2020-06-25 22:27:03	2020-06-25	Dr. Stacia Kuvalis PhD	dr.stacia.kuvalis.phd@geemail.com	San Jose	California	6011153075580687413	3f4c7e09fb88fddaa8b28ccb74cad0ff	Maestro	37.3347646603182	-121.825546126229312
33257	2020-06-25 22:27:32	2020-06-25	Joy Bins	joy.bins@geemail.com	Santa Ana	California	4080323854234	acd80a356ed8f8a2c504053442c61198	VISA 16 digit	33.7819714084837557	-117.911322433587159
33258	2020-06-25 22:27:46	2020-06-25	Geary Hermiston	geary.hermiston@woohoo.com	Spokane	Washington	6011908178078056808	9b7b52611d6fcbb7528f391ab5bb3435	Diners Club / Carte Blanche	47.6778089277684671	-117.420081040299692
33259	2020-06-25 22:29:32	2020-06-25	Luke Parker	luke.parker@geemail.com	Everett	Washington	869964075753888093	fdb5d397934c4a87c8402e7496e9e8fb	JCB 15 digit	47.9090154202546969	-122.163341305883236
33260	2020-06-25 22:30:39	2020-06-25	Shirley Feest DVM	shirley.feest.dvm@warmmail.com	Los Angeles	California	52911310527691159	fabb142b7834e9b70e4e0610eb796f11	Mastercard	33.9688600983802189	-118.384667287812746
33261	2020-06-25 22:46:33	2020-06-25	Leroy Bosco MD	leroy.bosco.md@warmmail.com	Milwaukee	Wisconsin	3096165096590476387	2567cec65e79cefc810e58b18712c007	JCB 15 digit	43.0841368598017809	-88.0048077335681853
33262	2020-06-25 23:02:33	2020-06-25	Dr. Luther O'Conner	dr.luther.o'conner@geemail.com	Los Angeles	California	6011817367289371805	f91669176582b1066aa01cd1c0a1cc99	VISA 16 digit	34.099232317866381	-118.396606541191403
33263	2020-06-25 23:05:58	2020-06-25	Abb Rowe	abb.rowe@geemail.com	Oklahoma City	Oklahoma	060448422472166	3f3e8df671b8511b7d99744d050b5be3	Voyager	35.3858304281163996	-97.5726634784962954
33264	2020-06-25 23:06:54	2020-06-25	Antonetta Nicolas	antonetta.nicolas@geemail.com	Cleveland	Ohio	3158345150138204612	c98f05365b4749e39bbcdeb309cb2f42	VISA 16 digit	41.3824101393893358	-81.7516183333709847
33265	2020-06-25 23:17:23	2020-06-25	Solon Swift-Gerhold	solon.swift.gerhold@geemail.com	Berkeley	California	3775778608252806	57f12d31c528dceef430753cb52f53b1	JCB 16 digit	37.8678992356141748	-122.291425499051158
33266	2020-06-25 23:42:54	2020-06-25	Madie Abshire	madie.abshire@geemail.com	Oakland	California	676212073239589	99b6c1613d5681a2d8f2e479fb627450	Mastercard	37.8080634999740113	-122.266728822021534
33267	2020-06-25 23:47:22	2020-06-25	Al Zieme	al.zieme@geemail.com	Irving	Texas	630497464909395	f6f461565168951b330808cba06225da	American Express	32.9101877544026848	-96.8973527927696665
33268	2020-06-25 23:48:40	2020-06-25	Princess Howe	princess.howe@geemail.com	San Francisco	California	53674964408681353	bcb4f7cec3e98d8154f7ed2586c53a98	Voyager	37.8025169800198313	-122.406426467971031
33269	2020-06-25 23:50:14	2020-06-25	Keon Klocko III	keon.klocko.iii@geemail.com	New York	New York	3088221344084796932	75ea355d63b98e55c8d4d3201174ce5b	Voyager	40.5736058888714766	-73.8550701368961455
33270	2020-06-25 23:51:03	2020-06-25	Bryce Schmeler	bryce.schmeler@warmmail.com	Thornton	Colorado	4164478719401507	f9e76133e0b477dc39dcf12e5958bea6	Discover	39.8551158219907435	-104.868031869332498
33271	2020-06-25 23:52:53	2020-06-25	Bama Jacobs	bama.jacobs@geemail.com	Anchorage	Alaska	3337891411156585466	4e3db7ce96577308d57428b1ea706460	JCB 16 digit	61.1532897236507438	-149.284985278745381
33272	2020-06-25 23:55:54	2020-06-25	Tasha McDermott	tasha.mcdermott@geemail.com	Seattle	Washington	3043585778217684	a46811a555e6b0a5f0764ecf0e5bb6d6	Discover	47.5575377942919744	-122.330463720012077
33273	2020-06-26 00:02:51	2020-06-26	Warren Moore IV	warren.moore.iv@geemail.com	Sugar Land	Texas	869901396804491240	ce6f45c9fea617eecbb689afbe19ba23	Maestro	29.6982419553264982	-95.5697782122537518
33274	2020-06-26 00:10:22	2020-06-26	Sherita Bogisich	sherita.bogisich@geemail.com	New York	New York	6011263482776963870	c2d53e70679e7ee855a938884690243f	VISA 16 digit	40.7321850788071771	-73.8754514466401133
33275	2020-06-26 00:13:51	2020-06-26	Elder Streich	elder.streich@geemail.com	Arlington	Texas	3158691113816086644	83a329f7f243793bb0f42c4be5690b12	JCB 16 digit	32.6023907502897075	-97.0957899969097298
33276	2020-06-26 00:16:17	2020-06-26	Murl Hansen-Jacobi	murl.hansen.jacobi@geemail.com	Killeen	Texas	3052034739837133	eb50a4988bef880d8492b50be8f382b6	VISA 16 digit	30.9844455306183555	-97.6324686533007764
33277	2020-06-26 00:19:35	2020-06-26	Charlsie Zboncak-Bogisich	charlsie.zboncak.bogisich@geemail.com	Everett	Washington	3054049112862902	92a424efa79a17746a489ee76d9ed2c5	VISA 16 digit	48.0428912133336112	-122.208629039082311
33278	2020-06-26 00:48:15	2020-06-26	Cedrick O'Reilly	cedrick.o'reilly@warmmail.com	Killeen	Texas	3337787798139907495	725b6f54af27f3ed2aa156d59888e928	Voyager	31.1550232262115934	-97.6742911006957257
33279	2020-06-26 00:51:32	2020-06-26	Devontae Mann	devontae.mann@geemail.com	Houston	Texas	501814872501961	01b759c824b6a27aa09d2d48f5d47e7e	JCB 16 digit	29.8047219237856567	-95.374633547385784
33280	2020-06-26 00:55:11	2020-06-26	Lars Williamson	lars.williamson@geemail.com	Portland	Oregon	4337824400846	dca212bc9b53fb2e8be77d07320af706	JCB 16 digit	45.5165244612265383	-122.55143849323504
33281	2020-06-26 00:55:30	2020-06-26	Del Wuckert-Medhurst	del.wuckert.medhurst@geemail.com	Murrieta	California	501803076210958	f8b2bbb104653c743269e44f5dfd8581	VISA 16 digit	33.6674956890385602	-117.275157500234982
33282	2020-06-26 00:55:52	2020-06-26	Muhammad Harber	muhammad.harber@geemail.com	Plano	Texas	180099857505377023	0c265aa7afd4c7a0c2621fb818ac73e7	VISA 13 digit	32.9813880785454074	-96.7928384866282414
33283	2020-06-26 00:56:12	2020-06-26	Taurean Kassulke II	taurean.kassulke.ii@geemail.com	Chicago	Illinois	3777191581500647	d1730a0487ebde574a643e9b17dfb269	JCB 16 digit	41.8412111596971741	-87.6816470650054498
33284	2020-06-26 01:03:43	2020-06-26	Deana Hoeger-Rempel	deana.hoeger.rempel@warmmail.com	Santa Clara	California	3464627534652071	0f82c37224f008449583f78aadf3d704	JCB 16 digit	37.354378079465036	-121.937465002480522
33285	2020-06-26 01:11:53	2020-06-26	Juelz Schinner	juelz.schinner@geemail.com	Baton Rouge	Louisiana	4074500963009	9e3073e7ead5195f591b5739e8cf8475	Discover	30.3559277422938507	-91.1861509121131064
33286	2020-06-26 01:29:24	2020-06-26	Mr. Wesley Lemke	mr.wesley.lemke@geemail.com	Columbus	Ohio	869974788521858960	f7a6ca7b6a25c8f9739783ec906b8293	Voyager	39.9308405836157476	-82.9992345290027629
33287	2020-06-26 01:30:17	2020-06-26	Pearly Hintz	pearly.hintz@geemail.com	San Jose	California	3795141228762801	83aec5462cf278075551a92128ef65bd	Maestro	37.3291885950423818	-121.754075306163728
33288	2020-06-26 01:30:30	2020-06-26	Ilah Monahan-Barrows	ilah.monahan.barrows@geemail.com	Scottsdale	Arizona	4801484940300	7645eaa5cd660f08abc96d23daa2fdbe	American Express	33.6579668854486229	-111.844772930765885
33289	2020-06-26 01:32:00	2020-06-26	Mr. Brook Abernathy PhD	mr.brook.abernathy.phd@geemail.com	Chicago	Illinois	3490014811133307	8694094d08548476453efc079d74d25c	VISA 16 digit	41.7681732443463076	-87.6771449073713285
33290	2020-06-26 01:49:14	2020-06-26	Edythe Pfeffer	edythe.pfeffer@woohoo.com	New York	New York	3046013876853653	23a0aa35ac13f893c1678442efd88426	VISA 16 digit	40.629733619395644	-73.8451548764843437
33291	2020-06-26 01:50:27	2020-06-26	Miss Arleth Boyle DVM	miss.arleth.boyle.dvm@geemail.com	Anaheim	California	51204022597970084	c4a36616641b56e9f0262f8dc577754e	Voyager	33.9508265077434501	-117.803242411811269
33292	2020-06-26 01:53:03	2020-06-26	Raynard Cartwright	raynard.cartwright@warmmail.com	San Francisco	California	3096870854238227992	66da7679307580f5374363cb19300f67	VISA 16 digit	37.7772167080353469	-122.469397156015617
33293	2020-06-26 01:53:05	2020-06-26	Amparo Cormier	amparo.cormier@warmmail.com	San Francisco	California	3337724051902279346	793d21c82758bc319cd2e31b55d87ac2	American Express	37.8050947244457234	-122.43608468333673
33294	2020-06-26 01:53:05	2020-06-26	Sherri Keebler	sherri.keebler@geemail.com	Woodbridge	New Jersey	4474250667042	2bc082a9d47f09af2c115cb03a56b5b3	JCB 16 digit	40.5561531955998333	-74.2760056505769484
33295	2020-06-26 01:55:33	2020-06-26	Garett Von	garett.von@geemail.com	Houston	Texas	53468062391431942	de6d59ffe5ef4c0560744d9bd725458b	JCB 16 digit	29.8273108643557876	-95.4497523359969335
33296	2020-06-26 02:46:48	2020-06-26	Lucio Russel IV	lucio.russel.iv@geemail.com	Lansing	Michigan	3158420152860373654	748b5d3fa641f24d3093a0d1803b6fe9	VISA 16 digit	42.7303191415809138	-84.5697393604677075
33297	2020-06-26 02:49:11	2020-06-26	Remington Schiller	remington.schiller@woohoo.com	Antioch	California	4308744318430529	e1d1930ec2fccfbb0ee4d2db7d98f9b2	JCB 16 digit	38.0457364439297478	-121.759646563296016
33298	2020-06-26 03:10:28	2020-06-26	Kylan Ondricka	kylan.ondricka@geemail.com	Reno	Nevada	630473758865999	9386040437f63ed89a5f93e460e32b66	Maestro	39.5087877240575907	-119.824966022202375
33299	2020-06-26 03:11:25	2020-06-26	Miss Zilpah Grady	miss.zilpah.grady@warmmail.com	Portland	Oregon	180063579949059452	9767c43ae1ee38d7e8a1fb4047ea6346	JCB 16 digit	45.4944367929715625	-122.7447091171518
33300	2020-06-26 03:15:44	2020-06-26	Carrol Grimes	carrol.grimes@geemail.com	New York	New York	52954167927033905	1cab3bc474be42ecd172f08fe2429b96	Discover	40.6955768930017925	-74.0197756395570963
33301	2020-06-26 03:15:46	2020-06-26	Erica Ebert	erica.ebert@geemail.com	Fort Worth	Texas	589380526343241	b29a773c0d9727eb8a56e0eefc54c02c	Discover	32.6835866991486412	-97.3431765737298917
33302	2020-06-26 03:20:33	2020-06-26	Dr. Scotty Bode I	dr.scotty.bode.i@geemail.com	Long Beach	California	6011912583732121373	ccf62c28f4525e6efbbfcce8a7c0ecc2	VISA 13 digit	33.8807519780293092	-118.179788068325436
33303	2020-06-26 03:21:28	2020-06-26	Redmond Mayert	redmond.mayert@geemail.com	Charleston	South Carolina	180063800208910221	acce54b055ef94ab065270145ceb2883	VISA 16 digit	32.8266913903873458	-79.9337354258317561
33304	2020-06-26 03:39:07	2020-06-26	Laurance Braun	laurance.braun@warmmail.com	San Francisco	California	4863662604842768	ee8b278c0b4c641a98233f0cf66df5d1	Discover	37.8111912346053458	-122.412820137179366
33305	2020-06-26 03:39:17	2020-06-26	Mr. Melbourne Kub III	mr.melbourne.kub.iii@geemail.com	St. Petersburg	Florida	210061629759082425	b57222da8796dc42a30252f3d63a0863	JCB 16 digit	27.6646272385381167	-82.5593593158185399
33306	2020-06-26 03:40:10	2020-06-26	Miss Terra Hamill DDS	miss.terra.hamill.dds@warmmail.com	New York	New York	4048062408272	4674cabb2d0d44a82c461e3de7d7f71d	American Express	40.662101468186826	-73.9460897549416813
33307	2020-06-26 03:41:01	2020-06-26	Chip Medhurst-Cronin	chip.medhurst.cronin@geemail.com	Tempe	Arizona	3049063001157717	a18e9ceb580fc62d3dd0237dd4e53a93	Maestro	33.4066875964324907	-112.026495757934825
33308	2020-06-26 03:41:51	2020-06-26	Isamar Brown DVM	isamar.brown.dvm@woohoo.com	Los Angeles	California	3158068398441959167	39f01bf518927107c3a2fc85c1f7b030	Voyager	33.9823661893006417	-118.403923973952601
33309	2020-06-26 03:42:00	2020-06-26	Nelia Mohr	nelia.mohr@geemail.com	Hillsboro	Oregon	52149389626948136	c4f75ee9e18c4f23f95e88a3830b21ce	Diners Club / Carte Blanche	45.6077418898437159	-122.845520143459368
33310	2020-06-26 03:48:25	2020-06-26	Kassandra Oberbrunner	kassandra.oberbrunner@geemail.com	Hayward	California	4398633228636716	966853a7b4b3ff627f93a9d6f10c3e3a	American Express	37.5845181324042414	-122.151440483683345
33311	2020-06-26 03:48:50	2020-06-26	Jodi Daugherty	jodi.daugherty@geemail.com	San Diego	California	630471933528680	21de39691f049e926d4cbf409d6c133e	Maestro	32.8822716715812717	-117.120924411797901
33312	2020-06-26 03:57:34	2020-06-26	Mr. Kendell Schiller	mr.kendell.schiller@geemail.com	Milwaukee	Wisconsin	3088383618683726620	23e0df659dee523c3ad8ea5dd812855d	Diners Club / Carte Blanche	43.0031583352565718	-88.0488361554786536
33313	2020-06-26 04:00:42	2020-06-26	Reanna Parisian	reanna.parisian@geemail.com	San Francisco	California	3096464324532642587	c5fd96a05c3ff19be3a1fb80b936746b	Voyager	37.7447868808513149	-122.419403237585584
33314	2020-06-26 04:01:18	2020-06-26	Kristi Schneider	kristi.schneider@geemail.com	Baltimore	Maryland	4474266221798998	04866031e067e37c8c361fa11be64707	Discover	39.2946778648532913	-76.5802411783039645
33315	2020-06-26 04:11:10	2020-06-26	Essex Feeney-Kassulke	essex.feeney.kassulke@geemail.com	Renton	Washington	589352837051243	cd774518a1e256ea2990c507ea4e33cd	JCB 16 digit	47.5370863380435864	-122.09792156746424
33316	2020-06-26 04:24:05	2020-06-26	Arthor Schumm	arthor.schumm@geemail.com	New York	New York	6011356688453040885	257a90d56d33b050c01436df56b3064f	Voyager	40.7537696898672692	-74.005025362632054
33317	2020-06-26 04:48:07	2020-06-26	Hasan Wisoky DVM	hasan.wisoky.dvm@geemail.com	Washington	District of Columbia	4132546519172921	f8da3f7bdebc89533826c10335903956	VISA 16 digit	38.8697079028267396	-77.0050847742453186
33318	2020-06-26 04:51:57	2020-06-26	Griffin Fritsch-Wuckert	griffin.fritsch.wuckert@geemail.com	Dallas	Texas	210039922277729513	608ebb437ec26ac165ea7da055ea1992	Voyager	32.7762968826379648	-96.8280640075877272
33319	2020-06-26 04:52:35	2020-06-26	Nohely Hodkiewicz	nohely.hodkiewicz@geemail.com	Chicago	Illinois	210043076533226543	6e8abd3466a7ea824182601509c70cf3	JCB 16 digit	41.8727031309459363	-87.6481603501860036
33320	2020-06-26 04:54:01	2020-06-26	Rollo Ernser DDS	rollo.ernser.dds@geemail.com	St. Louis	Missouri	54129799716011088	ad44c2f95fea3d44694bb827e6c9aad6	Diners Club / Carte Blanche	38.5895256379775731	-90.1794646800965154
33321	2020-06-26 04:58:51	2020-06-26	Cleave Ferry	cleave.ferry@geemail.com	Indianapolis	Indiana	51661447322216253	e5ad2916b1e0999e2774c25b66c8e703	American Express	39.828834978864343	-86.1173225283823882
33322	2020-06-26 05:01:59	2020-06-26	Aloma Konopelski	aloma.konopelski@warmmail.com	San Francisco	California	6011366172769538062	91251f14f83a298e1a21fc6d7efd1a91	Voyager	37.7672719121492477	-122.456192978491657
33323	2020-06-26 05:12:20	2020-06-26	Rodolfo Beer Sr.	rodolfo.beer.sr.@warmmail.com	Washington	District of Columbia	675921605047899	3cdc7530c4f2b9eaf898cbdcc994e131	JCB 16 digit	38.9457217671241622	-77.0734981807161148
33324	2020-06-26 05:24:18	2020-06-26	Justine Schinner	justine.schinner@woohoo.com	Seattle	Washington	3528363030781918022	61d711eed4ac0a04949015206b252668	JCB 15 digit	47.7176765335649264	-122.361233381546654
33325	2020-06-26 05:36:41	2020-06-26	Braydon Larkin	braydon.larkin@geemail.com	Oakland	California	676293324144125	c68cef4a0a81f1dfed25f5f52076c3e5	JCB 15 digit	37.8278428496023267	-122.267852086321597
33326	2020-06-26 05:37:54	2020-06-26	Claude Roob	claude.roob@warmmail.com	Huntington Beach	California	869995292692414369	c0dce91b9560af3306893f657c55c9e8	VISA 13 digit	33.6859700015321408	-118.029979908711454
33327	2020-06-26 05:43:33	2020-06-26	Ham Donnelly	ham.donnelly@warmmail.com	New York	New York	3158699657878146227	3c8dc623f7d112170e7a68da85140e23	Discover	40.6812487181033902	-73.9131066232815357
33328	2020-06-26 05:44:40	2020-06-26	Keyla Beier	keyla.beier@geemail.com	Philadelphia	Pennsylvania	639088375821134	72b3f2bb6e3732cdef0717effa142140	Diners Club / Carte Blanche	40.1071063934784391	-75.1884618065685117
33329	2020-06-26 05:53:09	2020-06-26	Odelia Klocko	odelia.klocko@geemail.com	San Francisco	California	3026415368502088	56cf9d9785250cfd851a5daf47b8752d	Discover	37.7577366761228461	-122.447996434910664
33330	2020-06-26 05:57:47	2020-06-26	Dr. Laci Kessler	dr.laci.kessler@geemail.com	Springfield	Massachusetts	6011839741644821445	1a72694b166b158a4042e6204c8692c2	American Express	42.1548167512025671	-72.4939856079500231
33331	2020-06-26 06:02:54	2020-06-26	Ora Hamill	ora.hamill@geemail.com	New York	New York	869990437725167931	43f62e52f4159823eb6fb5f741bfb38e	VISA 13 digit	40.5864637517128131	-74.0190694749716585
33332	2020-06-26 06:04:09	2020-06-26	Annemarie Leffler	annemarie.leffler@woohoo.com	Columbus	Ohio	210078216316767804	38d93602a9de60401f757205e0633b8e	Mastercard	39.8972613757986565	-82.9178581250134954
33333	2020-06-26 06:05:36	2020-06-26	Milda McLaughlin PhD	milda.mclaughlin.phd@warmmail.com	Dallas	Texas	4805711762569	c90c563a6f08809cf844aaa7aa45c297	American Express	32.8759611020136617	-96.684987341981369
33334	2020-06-26 06:06:30	2020-06-26	Westin Braun DDS	westin.braun.dds@geemail.com	Olathe	Kansas	503864607873086	e6714285bbf70696e4692929c2822b71	Mastercard	38.9662201676175002	-94.9048202157188285
33335	2020-06-26 06:09:30	2020-06-26	Fleda Langworth	fleda.langworth@geemail.com	San Francisco	California	3337240452553794291	3013e55a2b52a84e6f4ca7d237e9daf0	VISA 16 digit	37.768239095179986	-122.439118590500016
33336	2020-06-26 06:10:04	2020-06-26	Wilhelmine Pacocha MD	wilhelmine.pacocha.md@warmmail.com	Shreveport	Louisiana	210096367428162679	860ba579b20524a1ed4814ca142f2811	Diners Club / Carte Blanche	32.4911576813325311	-93.7114153244279322
33337	2020-06-26 06:11:23	2020-06-26	Mr. Alfred Wunsch	mr.alfred.wunsch@geemail.com	San Jose	California	3112468966173003812	81beab14459c0830a44cb0e7b57399a6	Mastercard	37.3658876715514836	-121.769182963085925
33338	2020-06-26 06:22:50	2020-06-26	Chaz Kunde	chaz.kunde@geemail.com	McKinney	Texas	6011314720696757321	e28ba4a8d7d5b521a731c2f71c25edf1	JCB 16 digit	33.1992555108983112	-96.5877927135042853
33339	2020-06-26 06:24:25	2020-06-26	Dorris Blanda	dorris.blanda@geemail.com	Palm Bay	Florida	52360489744231613	c23d4be6aa6e84579e2f91a83d646543	Discover	28.0339825808390977	-80.7323009630035529
33340	2020-06-26 06:25:48	2020-06-26	Rayfield Dibbert	rayfield.dibbert@warmmail.com	Raleigh	North Carolina	3451636153682462	99dc439dffb2d6849e79657f3f0df5bc	Voyager	35.8304242176603509	-78.597330045181522
33341	2020-06-26 06:30:13	2020-06-26	Dr. Jimena Heller	dr.jimena.heller@geemail.com	Albuquerque	New Mexico	6011827566923399829	734cddd2c6bc38c82bf6fa8a05ac10db	JCB 16 digit	35.1570303492382195	-106.61448793076687
33342	2020-06-26 06:38:14	2020-06-26	Jaylen O'Connell	jaylen.o'connell@woohoo.com	Overland Park	Kansas	3096836017971320597	1505bbce9ccd6e451ec50ccad24e8977	Maestro	38.9141561721321239	-94.6613495902664965
33343	2020-06-26 06:38:43	2020-06-26	Amya Sporer	amya.sporer@geemail.com	Philadelphia	Pennsylvania	4696107137635	26ce4257f8f2b5da8441022cac33a2d8	Diners Club / Carte Blanche	40.0289371292065823	-75.0987449786990879
33344	2020-06-26 06:39:27	2020-06-26	Danielle Homenick	danielle.homenick@geemail.com	New Haven	Connecticut	3417691901494903	e57c1d8ae3950c96c97ef8859e484308	JCB 15 digit	41.3489287854630518	-72.9716588637791546
33345	2020-06-26 06:48:10	2020-06-26	Mylie Hauck-Harber	mylie.hauck.harber@warmmail.com	Salem	Oregon	4698108549271	d910d0ce9b3b1006280c1ae5afe71b45	JCB 16 digit	44.9913293186843362	-123.117757446101677
33346	2020-06-26 06:52:00	2020-06-26	Ms. Annis Schuppe	ms.annis.schuppe@geemail.com	Durham	North Carolina	869965248833043992	8277d5d2706d07a92e091278b64b6811	American Express	35.9346855309572035	-78.8176809111978827
33347	2020-06-26 06:55:16	2020-06-26	Lavada Dicki	lavada.dicki@geemail.com	San Antonio	Texas	3337333643081523008	14d0750dddd350eb307730b73c540dd8	VISA 16 digit	29.5111055129278448	-98.4633678516209017
33348	2020-06-26 07:13:17	2020-06-26	Clay Welch	clay.welch@woohoo.com	San Diego	California	4341434009799	23505ab4f0f3ab3af88f37c600a4223e	Mastercard	32.7430446995954938	-117.047609810614958
33349	2020-06-26 07:31:31	2020-06-26	Deasia Herzog	deasia.herzog@warmmail.com	Phoenix	Arizona	3417661817569767	d7d53756720cbbfde62dfae9fbbbe7ec	VISA 16 digit	33.6591950522668668	-112.021728439947964
33350	2020-06-26 07:35:51	2020-06-26	Ms. Etta Romaguera	ms.etta.romaguera@warmmail.com	Oakland	California	4887104625207	e0fadbb53a2f4fd9623ccfd5682cf653	Diners Club / Carte Blanche	37.8126820486353949	-122.269254814242174
33351	2020-06-26 07:43:37	2020-06-26	Gerald Beier	gerald.beier@geemail.com	San Bernardino	California	210010494198208582	f661d515e520e91085fea7b8192d0be7	Voyager	34.1697166755594282	-117.300293645752959
33352	2020-06-26 07:45:25	2020-06-26	Lex Bartell	lex.bartell@geemail.com	Memphis	Tennessee	4915702175687	a8a87b0ffe4f0d16614d7266b3a2b7d4	Discover	35.1891325245678459	-89.9107096507936774
33353	2020-06-26 07:48:22	2020-06-26	Mikhail McKenzie-Windler	mikhail.mckenzie.windler@geemail.com	Houston	Texas	3717455764657026	3222daffaa42769b068b453019c29987	American Express	29.8492614499837146	-95.3200105875279746
33354	2020-06-26 07:58:01	2020-06-26	Millie Huel	millie.huel@geemail.com	Arlington	Texas	561202182433579	3e6d5a490f1c891037e28011980d62d3	JCB 15 digit	32.7687821338668428	-97.0406716928377762
33355	2020-06-26 08:00:30	2020-06-26	Tyron Pollich	tyron.pollich@warmmail.com	Oakland	California	630495273549147	c261a9e8c2cba8a5da8249ee935a5c7e	Discover	37.8090882310386647	-122.261360491637006
33356	2020-06-26 08:05:58	2020-06-26	Litzy Considine	litzy.considine@geemail.com	Tucson	Arizona	675938725531784	0d78ecc4776785473cbe7c22e81fbb2c	Discover	32.1525711522944277	-110.782792266527565
33357	2020-06-26 08:17:16	2020-06-26	Sada Bechtelar	sada.bechtelar@warmmail.com	New York	New York	4704490665582	0ec7ebd412c0965b8293457c7dfe9fea	JCB 16 digit	40.7329608438294386	-73.8934134958207522
33358	2020-06-26 08:33:47	2020-06-26	Brantley Predovic-Bailey	brantley.predovic.bailey@geemail.com	Austin	Texas	4823359035230841	0d4c8f912be6715e3fbc5c06588c2f32	JCB 16 digit	30.3210851346734884	-97.7644406782701623
33359	2020-06-26 08:50:57	2020-06-26	Nita Shanahan DDS	nita.shanahan.dds@woohoo.com	San Francisco	California	3718601102966145	e6fb9161d82ec35b6eb3c12fc4dc3569	Diners Club / Carte Blanche	37.7961139184528321	-122.409082745379308
33360	2020-06-26 08:52:18	2020-06-26	Camron Heaney	camron.heaney@geemail.com	Washington	District of Columbia	4834669141980	d8f3e07f2dfab05b0b962fd8232c857c	JCB 15 digit	38.9842028356887411	-76.9524891271468334
33361	2020-06-26 09:08:18	2020-06-26	Mr. Orvel Murray Jr.	mr.orvel.murray.jr.@geemail.com	Lewisville	Texas	3466600703975837	2f7a750c30dcde08c8f6558b6f5ca5ed	VISA 13 digit	32.9543674745582038	-96.920272834788264
33362	2020-06-26 09:16:59	2020-06-26	Bob Torphy	bob.torphy@geemail.com	Anaheim	California	3051755678656362	d61c1134a544fae81264d1e60338715b	Maestro	33.8462832231838249	-117.68528446147441
33363	2020-06-26 09:26:49	2020-06-26	Ms. Yahaira Klocko MD	ms.yahaira.klocko.md@geemail.com	Columbus	Ohio	869938181863803072	9b851fe18ce5018da825c6666467bcf0	VISA 16 digit	39.9430413020353754	-83.0044193882729928
33364	2020-06-26 09:45:19	2020-06-26	Almira Gorczany	almira.gorczany@warmmail.com	San Francisco	California	54610294514737684	6dc18a7c0acc7cc39ae5f7dfdbd2c40c	Discover	37.7773402739729036	-122.446755852000905
33365	2020-06-26 09:48:16	2020-06-26	Mrs. Irva Keeling	mrs.irva.keeling@woohoo.com	Allentown	Pennsylvania	869915255000292493	e6bfd9152702b954e90d466b3d20e3e1	JCB 16 digit	40.4990404468741261	-75.5022658465445033
33366	2020-06-26 09:49:50	2020-06-26	Hessie Auer-Jones	hessie.auer.jones@geemail.com	Cleveland	Ohio	3414801417075939	5c90fbc51f18b51ba21bd77af62b1858	JCB 15 digit	41.4228082587327791	-81.6807088033068993
33367	2020-06-26 09:51:49	2020-06-26	Mckinley Prohaska	mckinley.prohaska@geemail.com	Scottsdale	Arizona	4890311187509314	7f79b36ce34ab497212b51f9bdcfcea4	VISA 16 digit	33.6796321907669309	-111.771410474643474
33368	2020-06-26 09:54:01	2020-06-26	Kolton Ward-Bechtelar	kolton.ward.bechtelar@geemail.com	San Bernardino	California	869912596269789379	5221db388b82ca2cada6ea9a156eed32	Diners Club / Carte Blanche	34.0990330105446233	-117.222906340822945
33369	2020-06-26 09:58:57	2020-06-26	Brianna Buckridge	brianna.buckridge@geemail.com	San Diego	California	52482192870262898	df6a78598a0510357f344b6469808129	Discover	32.7830008798811576	-117.206522568631925
33370	2020-06-26 10:11:01	2020-06-26	Giles Kihn	giles.kihn@woohoo.com	Richmond	California	3096277766681255586	f6bfeba615642119275426a993aad28f	American Express	37.9602303265083592	-122.41714229419307
33371	2020-06-26 10:21:03	2020-06-26	Aleen Balistreri	aleen.balistreri@geemail.com	Memphis	Tennessee	676197791326446	03e5513117cc781383b7a1350f78e00c	American Express	35.0900079980093977	-89.9334046748723921
33372	2020-06-26 10:21:13	2020-06-26	Staci Reichel	staci.reichel@geemail.com	New York	New York	3015745302377911	925fff3e295761b31065971998e11ad1	JCB 15 digit	40.5770333956684937	-73.8596611573256467
33373	2020-06-26 10:40:06	2020-06-26	Lavelle Johns	lavelle.johns@geemail.com	Berkeley	California	4725010227765594	632e3993d8b9e3732bc275ce07db6ac7	VISA 16 digit	37.8810778202249594	-122.269987757122976
33374	2020-06-26 10:44:15	2020-06-26	Antonina Yost PhD	antonina.yost.phd@geemail.com	San Bernardino	California	4132283306641856	76e35395045aa1d543f337ab6e145e8a	VISA 13 digit	34.1030861548412574	-117.262610474113742
33375	2020-06-26 10:56:58	2020-06-26	Lizzie Dietrich DDS	lizzie.dietrich.dds@woohoo.com	Newark	New Jersey	4514772269426345	78539c5232662d3823b40cc7bb42ebeb	VISA 13 digit	40.7791385342281316	-74.0882471940688845
33376	2020-06-26 10:57:16	2020-06-26	Mr. Florencio Cruickshank	mr.florencio.cruickshank@geemail.com	Pasadena	California	3528519701600922766	bbefa8d061f92172046043b42ec3800e	VISA 16 digit	34.1684211504500368	-118.046099355612327
33377	2020-06-26 11:03:21	2020-06-26	Dr. Offie Paucek	dr.offie.paucek@warmmail.com	Los Angeles	California	3096631030353772258	08d1fb740907dee3d97050e16b3da827	JCB 16 digit	33.9984443479549086	-118.392441042279074
33378	2020-06-26 11:05:07	2020-06-26	Beverley Klocko	beverley.klocko@geemail.com	San Antonio	Texas	4410475455516	2eae5e8a75ffd30543b9a28119773066	Maestro	29.4281413319125775	-98.5678686418872303
33379	2020-06-26 11:11:10	2020-06-26	Phoenix Hansen	phoenix.hansen@warmmail.com	Berkeley	California	869902666250742588	e815ff11d2ea6485b14a662378618295	VISA 16 digit	37.8666618878018113	-122.275491291163007
33380	2020-06-26 11:12:02	2020-06-26	Ross Hamill	ross.hamill@geemail.com	Phoenix	Arizona	869957860303292816	221835c79f445d532d7b47cd3f7c62e7	VISA 13 digit	33.5854081053685434	-112.010015165938441
33381	2020-06-26 11:13:01	2020-06-26	Dr. Lonny Gleason DDS	dr.lonny.gleason.dds@geemail.com	Columbus	Ohio	55696002687224373	4b7b1019226b266c1c07050116a89ea2	VISA 13 digit	39.9929179254498308	-83.0260649249192397
33382	2020-06-26 11:20:11	2020-06-26	Miss Sibyl Olson	miss.sibyl.olson@geemail.com	Vista	California	6011750616392828187	90461c2721cf513577f32fad257f48b7	Mastercard	33.1490651450101339	-117.203147794591644
33383	2020-06-26 11:22:24	2020-06-26	Maye Abbott DVM	maye.abbott.dvm@woohoo.com	Manchester	New Hampshire	51584823301771670	f00db8399807a80246d62ffad173d9fe	VISA 16 digit	42.9308958109539063	-71.3849576341811627
33384	2020-06-26 11:22:26	2020-06-26	Candace Dooley-Friesen	candace.dooley.friesen@warmmail.com	Fresno	California	4079851531398198	0cb000d615e19de24a65e00e2900bb73	JCB 16 digit	36.8715556082654743	-119.782379195198047
33385	2020-06-26 11:23:36	2020-06-26	Miss Annalise Schimmel	miss.annalise.schimmel@woohoo.com	Oakland	California	180021670129872797	8591f51ec286cbfdc6faec9e43c5a620	Discover	37.7986486772636994	-122.254932504464108
33386	2020-06-26 11:29:56	2020-06-26	Giovanna Dicki	giovanna.dicki@geemail.com	Oakland	California	869922224815908470	0a129761fca4f8397382cea748f77ba8	VISA 16 digit	37.8082838379455879	-122.266600730558537
33387	2020-06-26 11:30:06	2020-06-26	Geraldo Hilll	geraldo.hilll@woohoo.com	San Francisco	California	180074588704786131	027b4c1c352f7906a1c244e561818fe0	Maestro	37.7764513696332571	-122.443699185163453
33388	2020-06-26 11:31:39	2020-06-26	Nevin Torphy	nevin.torphy@warmmail.com	New York	New York	55540909028185915	0b4463c0fae2f2e73cf8c3af0f52088e	VISA 16 digit	40.709787604467941	-73.9757144667103859
33389	2020-06-26 11:49:09	2020-06-26	Molly Bins	molly.bins@geemail.com	San Francisco	California	4081094724703348	679e563b50f84ae8bc64e1aefa552501	Diners Club / Carte Blanche	37.7656421938454585	-122.410851937966328
33390	2020-06-26 11:57:00	2020-06-26	Ms. Alessandra O'Reilly	ms.alessandra.o'reilly@geemail.com	Cedar Rapids	Iowa	3158645034411004062	39bf595a369d992a77028d1f4fc6aa8d	VISA 16 digit	41.8718732962459299	-91.6593319083165454
33391	2020-06-26 11:57:48	2020-06-26	Blanchard Aufderhar-Bode	blanchard.aufderhar.bode@warmmail.com	Newport News	Virginia	4028147950329109	a9ffd4fec77d2a37082e6b439b3a26cc	JCB 15 digit	37.0194240583933905	-76.4264477972667748
33392	2020-06-26 11:58:53	2020-06-26	Selena Hand	selena.hand@woohoo.com	Grand Rapids	Michigan	52860210264371257	baefdf8969d5ef044bfe0aafb497c41c	Discover	43.0267764874536525	-85.6923149831261526
33393	2020-06-26 12:02:30	2020-06-26	Dr. Belle Funk	dr.belle.funk@woohoo.com	Las Vegas	Nevada	55467842269776093	c37196bfe050fd0d32a4e163a11547b5	Diners Club / Carte Blanche	36.1495051557298765	-115.276628891026974
33394	2020-06-26 12:06:55	2020-06-26	Meadow Emard	meadow.emard@geemail.com	Phoenix	Arizona	3528566510650298742	24e6081dd8db4628bbd5b1aec931dd28	Discover	33.6405545541018256	-112.116640658390153
33395	2020-06-26 12:13:07	2020-06-26	Gayla Wintheiser-Blanda	gayla.wintheiser.blanda@geemail.com	Phoenix	Arizona	4676536696237	2f3b755def2f5204316993cafc28f10d	VISA 13 digit	33.6633777227185718	-112.100578183440874
33396	2020-06-26 12:16:43	2020-06-26	Allean Bartoletti	allean.bartoletti@geemail.com	Chicago	Illinois	4929305555641	17ef6a76e32045dcf3b9740b88e4a470	Mastercard	41.7911300412680973	-87.596345170962806
33397	2020-06-26 12:19:58	2020-06-26	Tamra Jenkins	tamra.jenkins@geemail.com	Garden Grove	California	3158849908460267189	c9df775b7edbc3f2a06dabdedfb364c3	VISA 13 digit	33.8498112191736666	-117.963036849863826
33398	2020-06-26 12:20:22	2020-06-26	Theodis Tremblay	theodis.tremblay@geemail.com	Sioux Falls	South Dakota	6011272858606733097	3063a5c386c8b12ddfd67a107497d39c	JCB 16 digit	43.5246425545394402	-96.8190422044303318
33399	2020-06-26 12:22:23	2020-06-26	Davonta Parisian III	davonta.parisian.iii@geemail.com	Boston	Massachusetts	3112563345034495406	fd467fe474ff06aa404a33c7e4cf31f4	JCB 16 digit	42.4017826067917056	-71.0132830531288022
33400	2020-06-26 12:26:32	2020-06-26	Margueritte Reynolds	margueritte.reynolds@geemail.com	Plano	Texas	51019458049800401	e8aa3420785728ef96f94cbe1e842284	Mastercard	33.0241274969272354	-96.7565457492318046
33401	2020-06-26 12:29:13	2020-06-26	Milissa Daniel	milissa.daniel@geemail.com	Greensboro	North Carolina	53550639479130667	78b25957442a77090e2008d857a187ae	JCB 16 digit	36.0673564998082838	-79.8774148334264709
33402	2020-06-26 12:38:19	2020-06-26	Dr. Gwyneth Kerluke	dr.gwyneth.kerluke@warmmail.com	Coral Springs	Florida	3757199401893757	d7d89a8daa4046fc87ccbaf18621762d	VISA 13 digit	26.255692778254673	-80.261413278442987
33403	2020-06-26 12:44:30	2020-06-26	Leora Schuster	leora.schuster@geemail.com	Chula Vista	California	6011716072312083987	f4f6102d282d3380389c02dee7294375	JCB 16 digit	32.5348912944316808	-116.916306710545712
33404	2020-06-26 12:46:16	2020-06-26	Porsche Buckridge-Monahan	porsche.buckridge.monahan@woohoo.com	Escondido	California	3088695577274110599	867e0804c04c6f4475ca489e41094247	VISA 16 digit	33.1893641763128358	-117.051173876343299
33405	2020-06-26 12:53:45	2020-06-26	Kanesha Jaskolski	kanesha.jaskolski@geemail.com	Las Vegas	Nevada	180000442229821958	0e16e4287afd5ca1188e5e22fa50ffbc	JCB 16 digit	36.29259901811443	-115.248086705685026
33406	2020-06-26 13:24:25	2020-06-26	Billie Konopelski-Ernser	billie.konopelski.ernser@geemail.com	Phoenix	Arizona	3723363155779262	2f91519edb5d499c647ff2f085134be6	Mastercard	33.5783421808786713	-112.050569851456586
33407	2020-06-26 13:33:25	2020-06-26	Anjelica Grimes	anjelica.grimes@geemail.com	Phoenix	Arizona	4602442663624	d3f8603b15a4894905edb1deb1c7f0fb	Discover	33.6661199630171097	-112.064571045751137
33408	2020-06-26 13:42:58	2020-06-26	Maranda Hirthe	maranda.hirthe@geemail.com	Brownsville	Texas	501837281307241	8940479aa079ed77c64991e1da2230ca	VISA 13 digit	25.9321318679567412	-97.5452629345655424
33409	2020-06-26 13:43:05	2020-06-26	Patric Johnston	patric.johnston@geemail.com	Honolulu	Hawaii	54859684169031666	ac66b2d9d8325c61965107bc798971fa	Mastercard	21.3550140596676634	-157.752262545630714
33410	2020-06-26 13:46:29	2020-06-26	Magnolia Davis DDS	magnolia.davis.dds@geemail.com	Hartford	Connecticut	6011378420099403010	f353b8ffae6fb9ec0ad6cf9797a548fc	Mastercard	41.7282857127502567	-72.6653663822807374
33411	2020-06-26 13:50:53	2020-06-26	Donnie O'Kon	donnie.o'kon@warmmail.com	Portland	Oregon	869986466702624545	848b7ba484411beb4f237a08540afd8f	Maestro	45.4582647234555353	-122.663267523655676
33412	2020-06-26 13:59:56	2020-06-26	Ellamae Ebert MD	ellamae.ebert.md@woohoo.com	Newport News	Virginia	3528318516203411600	b908e42090cc98c8aae75072c0cfa46b	JCB 15 digit	37.0325231354579358	-76.4637906116694239
33413	2020-06-26 14:02:00	2020-06-26	Mont Schoen-O'Keefe	mont.schoen.o'keefe@geemail.com	Grand Rapids	Michigan	6011178209706350389	b3fb2a82e91f2f627b4aa966f718e316	Voyager	42.9759689709905501	-85.7308218241803388
33414	2020-06-26 14:11:24	2020-06-26	Governor Auer	governor.auer@geemail.com	Surprise	Arizona	3337079400305748962	52ab866d6b1b0865c304b4ee14aa1437	VISA 16 digit	33.7592715519242006	-112.39837876104265
33415	2020-06-26 14:28:53	2020-06-26	Zed Bergstrom	zed.bergstrom@geemail.com	Oklahoma City	Oklahoma	4059562806691	d92c2dc790ec020f3277d3e6044fb3d9	Discover	35.5409977481145418	-97.559666838300231
33416	2020-06-26 14:33:42	2020-06-26	Penelope Hodkiewicz DVM	penelope.hodkiewicz.dvm@geemail.com	Little Rock	Arkansas	6011181190101695393	1adbeb4dd02e03e59f060e007a84bb87	VISA 16 digit	34.6716196408770969	-92.2942533358804837
33417	2020-06-26 14:36:56	2020-06-26	Derald Mitchell	derald.mitchell@warmmail.com	Cleveland	Ohio	3088983016600380684	a690dcdb861bdf3dc6f7f7754b9feb0d	American Express	41.5637534494362768	-81.7764145914238014
33418	2020-06-26 14:41:10	2020-06-26	Nicki Streich	nicki.streich@geemail.com	Tallahassee	Florida	3528926575577965082	a96ae8198e5d4a734be6e47cf8f8744c	JCB 16 digit	30.4173476039920025	-84.2266853205874497
33419	2020-06-26 14:48:02	2020-06-26	Jann Kreiger MD	jann.kreiger.md@warmmail.com	Philadelphia	Pennsylvania	210059847231614904	e83ef8c520cedabf53c933697a38967d	Diners Club / Carte Blanche	40.0502188531175278	-75.127854177857941
33420	2020-06-26 14:51:49	2020-06-26	Nanna Bogan-Larson	nanna.bogan.larson@geemail.com	Philadelphia	Pennsylvania	4488149451493205	130eed39862285d4a6455df3bf64ffed	VISA 16 digit	40.0705565952654936	-75.1996561468478291
33421	2020-06-26 14:54:52	2020-06-26	Javen Roberts	javen.roberts@woohoo.com	Chicago	Illinois	3158740545789396495	d51d1f584cb830d2ad49bcc4c6c2e09d	VISA 13 digit	41.9242622082889085	-87.7378180773958576
33422	2020-06-26 14:59:39	2020-06-26	Harley Cormier	harley.cormier@warmmail.com	Oakland	California	869986790794348204	4645fa418b13b1858a513500836313f0	Maestro	37.8008099061339351	-122.254258033969933
33423	2020-06-26 15:10:33	2020-06-26	Kaelyn Klocko	kaelyn.klocko@geemail.com	Milwaukee	Wisconsin	3158060420285730070	0af4f340d648e688433accd1575ac7a6	JCB 16 digit	43.0516881582412836	-87.9160154305033359
33424	2020-06-26 15:15:58	2020-06-26	Gael Rosenbaum	gael.rosenbaum@woohoo.com	Westminster	Colorado	6011929107336597654	7b42c9128eaa730f5e82ae7473fb08b4	American Express	39.8005134401682739	-105.022679874362055
33425	2020-06-26 15:21:29	2020-06-26	Buford Legros	buford.legros@warmmail.com	San Francisco	California	3051911054374167	05d841517b06091292dd231bc30232f6	Discover	37.7656343385621014	-122.427092143496608
33426	2020-06-26 15:37:48	2020-06-26	Mr. Jonah Hackett	mr.jonah.hackett@geemail.com	Wichita	Kansas	4414728778534	bf8f7fed625e815408b1c264272254ad	VISA 16 digit	37.6895389587495444	-97.2760431613508558
33427	2020-06-26 15:54:04	2020-06-26	Thompson Mann	thompson.mann@warmmail.com	Berkeley	California	869929563578541082	b716e804f0450039c61fbb1a40e8bebd	JCB 16 digit	37.859810918457498	-122.256054024656493
33428	2020-06-26 15:57:03	2020-06-26	Mr. Michael Hamill	mr.michael.hamill@geemail.com	San Francisco	California	869968028268756699	3367c6a7604104dec9fab7ad3b4f9bfa	Voyager	37.7777950725954952	-122.43384503323432
33429	2020-06-26 16:13:06	2020-06-26	Wallace Bruen IV	wallace.bruen.iv@geemail.com	Roseville	California	060490043246132	9d2def6d06e42bd21b9443f6f13ad8f0	Maestro	38.6994832042194901	-121.347680077490949
33430	2020-06-26 16:18:15	2020-06-26	Dr. Dandre Kautzer IV	dr.dandre.kautzer.iv@warmmail.com	Dallas	Texas	3337803884013289521	6028171abce347255b61d4cab119b0d3	Diners Club / Carte Blanche	32.8117511236380821	-96.7259722408335563
33431	2020-06-26 16:24:40	2020-06-26	Blanche Beatty	blanche.beatty@geemail.com	Berkeley	California	4794893576386393	e1c5952ee819b4646b83a42c4c4dbf63	JCB 16 digit	37.8786354051788337	-122.28180625753005
33432	2020-06-26 16:25:24	2020-06-26	Shae Littel PhD	shae.littel.phd@warmmail.com	San Jose	California	4456471158230567	d34938e4d9a07e28781d41dd28e9dfc2	JCB 16 digit	37.3049800023257774	-121.910056049491843
33433	2020-06-26 16:31:11	2020-06-26	Britni Kovacek	britni.kovacek@warmmail.com	Miramar	Florida	51518487051968794	50aaa99df4c79baaa52d1f69464e58b8	VISA 13 digit	25.9827097892276946	-80.2828689713023635
33434	2020-06-26 16:36:45	2020-06-26	Val Christiansen	val.christiansen@woohoo.com	El Paso	Texas	3723039446657216	0ef20e555705aaea7d3f98d3a25a8ed7	JCB 15 digit	31.9356633780352794	-106.37501128827968
33435	2020-06-26 16:38:15	2020-06-26	Janette Kub	janette.kub@geemail.com	Modesto	California	3528867432954264526	150b1d7aef2ceb6162ddacf0dc62900a	JCB 16 digit	37.6951854893006413	-121.004982587855309
33436	2020-06-26 16:41:49	2020-06-26	Mrs. Francine Pagac PhD	mrs.francine.pagac.phd@geemail.com	New York	New York	54013548647248973	a299ad641f6e6df678a4c78f26572300	Discover	40.6476807766817529	-73.8644213870063453
33437	2020-06-26 16:55:12	2020-06-26	Porfirio McKenzie	porfirio.mckenzie@geemail.com	New York	New York	3716738727313246	397ef0500f4a4986108872de8d6d49e8	Discover	40.702021056249734	-73.9599178352754478
33438	2020-06-26 16:58:52	2020-06-26	Brandon Simonis	brandon.simonis@geemail.com	McAllen	Texas	3769217394629917	f1ab99527c3cccfe170a7b1ffb034e61	JCB 15 digit	26.1552383622925717	-98.1661476601228031
33439	2020-06-26 17:12:15	2020-06-26	Louie McKenzie	louie.mckenzie@woohoo.com	Laredo	Texas	3440544093072378	506a5c3d531a343e76102c0df5ad7801	Voyager	27.4777082068096874	-99.5191601018428713
33440	2020-06-26 17:15:29	2020-06-26	Skyler Crona	skyler.crona@geemail.com	Orlando	Florida	3158834531770405880	431a52227b6227c8ed4e45d93d546e8a	Maestro	28.4297255452986803	-81.2156867488719598
33441	2020-06-26 17:27:10	2020-06-26	Jaheem Collins	jaheem.collins@geemail.com	Philadelphia	Pennsylvania	3022140411358858	e369864f664aa245aa814021e5127279	VISA 16 digit	39.9138814870227137	-75.1539323218997595
33442	2020-06-26 17:34:04	2020-06-26	Guadalupe Friesen	guadalupe.friesen@woohoo.com	New York	New York	630418074250491	e3d9dec96c3d8cc4b6977c4b9a5b6ae1	American Express	40.6493189291320718	-73.9632613011065843
33443	2020-06-26 17:34:20	2020-06-26	Thaddeus Yost	thaddeus.yost@geemail.com	Tulsa	Oklahoma	060471152473717	10ad24adcadbefb1cabfd1d815bd90cc	JCB 15 digit	36.2122648100737479	-95.9951957391064639
33444	2020-06-26 17:41:13	2020-06-26	Dr. Perla Okuneva PhD	dr.perla.okuneva.phd@geemail.com	Portland	Oregon	6011655577103330762	a56003a05474b3c001fb642d58dd3833	Mastercard	45.5900573273077612	-122.734262357791891
33445	2020-06-26 17:41:32	2020-06-26	Rustin West V	rustin.west.v@woohoo.com	Phoenix	Arizona	3096782946216444131	2e346cef7550d74f47f336685c923552	VISA 13 digit	33.5186645598083786	-112.175857209779707
33446	2020-06-26 17:54:38	2020-06-26	Mrs. Imogene Pacocha	mrs.imogene.pacocha@geemail.com	San Francisco	California	51430908027880479	ecae1cce6dbd13fd198514794e94b8ab	JCB 16 digit	37.7408234374664602	-122.433418903199367
33447	2020-06-26 17:57:40	2020-06-26	Deb Wunsch	deb.wunsch@woohoo.com	Sandy Springs	Georgia	3035386909845990	4359319547bee06f46924fc8b42bff92	American Express	33.9138441187851143	-84.457197263425968
33448	2020-06-26 18:02:04	2020-06-26	Rueben Farrell	rueben.farrell@geemail.com	New York	New York	4929038640311377	b8f05d0f2b925c6e64aadc07a9d3545b	Maestro	40.5806118785161516	-73.8495826354145919
33449	2020-06-26 18:02:28	2020-06-26	Rolland Baumbach	rolland.baumbach@geemail.com	Washington	District of Columbia	210059092051209739	c0c9f3f6d7c7da6eabbb9d7c5b278168	JCB 16 digit	38.8279099310081435	-77.0485053491991039
33450	2020-06-26 18:17:06	2020-06-26	Candi Wolff MD	candi.wolff.md@geemail.com	Oakland	California	55997164404644253	c48fe7552e767d75ef5d043af8896221	JCB 16 digit	37.8012225486219648	-122.284739077186259
33451	2020-06-26 18:19:49	2020-06-26	Dr. Demetria Schuster	dr.demetria.schuster@warmmail.com	Chicago	Illinois	6011694252672422316	feba3c44aabafb34702261f8aaeaa52d	VISA 16 digit	41.8209910781424483	-87.6140419144213212
33452	2020-06-26 18:24:57	2020-06-26	Djuna Mosciski	djuna.mosciski@warmmail.com	Berkeley	California	4411094861947055	f45a2b28baecda00b9d5bf89c6bd53f7	VISA 16 digit	37.8734390536243808	-122.24684451347747
33453	2020-06-26 18:25:10	2020-06-26	Izetta Hagenes	izetta.hagenes@geemail.com	San Francisco	California	869922947499391569	c6fae126eea144ca40d68912f3d1b855	Voyager	37.7285893724968631	-122.420315735475739
33454	2020-06-26 18:26:12	2020-06-26	Coby Gulgowski	coby.gulgowski@geemail.com	El Paso	Texas	3022204507153209	68954f12b3142a7eb2dbaf962b5b5e1d	Voyager	31.8564930117517733	-106.435048969693483
33455	2020-06-26 18:29:13	2020-06-26	Claribel Bosco DDS	claribel.bosco.dds@geemail.com	San Diego	California	869982117278616985	caf79d93e9bd5e19ea89567d8dd699be	VISA 13 digit	32.8797792686682229	-117.056081324806442
33456	2020-06-26 18:32:54	2020-06-26	Citlalli Haley MD	citlalli.haley.md@geemail.com	Philadelphia	Pennsylvania	3029553481659786	483f55ec8140b825a686ebcf8851832d	VISA 16 digit	39.9589214393362369	-75.1678361927524321
33457	2020-06-26 18:41:28	2020-06-26	Ms. Anne Watsica	ms.anne.watsica@geemail.com	Boston	Massachusetts	869970804725402341	dc7b2cd30e75ee928c74af119475b4f8	Voyager	42.3353777875360109	-70.9416241333305919
33458	2020-06-26 19:08:17	2020-06-26	Ms. Marceline Wyman DDS	ms.marceline.wyman.dds@geemail.com	San Francisco	California	3158424713327411837	40d1e8e199f08a7fdddd1e69cfa3e9bd	JCB 16 digit	37.7753061527932417	-122.444993524076892
33459	2020-06-26 19:25:12	2020-06-26	Domingo Orn	domingo.orn@geemail.com	Los Angeles	California	3472345693817514	aeaf7412d959a462b90846dd3fffa535	JCB 15 digit	34.0320453088130748	-118.360431560361008
33460	2020-06-26 19:34:58	2020-06-26	Alton Beier	alton.beier@geemail.com	Norman	Oklahoma	3428522908234728	1de834be1e84c2f525b79e016c9f4e18	VISA 13 digit	35.3068484996952137	-97.3023141981355764
33461	2020-06-26 19:35:17	2020-06-26	Einar Grimes V	einar.grimes.v@geemail.com	San Francisco	California	4151130403489	e626714862d1a750d7316e753aa83733	VISA 16 digit	37.7814898063579534	-122.428416513565722
33462	2020-06-26 19:53:09	2020-06-26	Kamren Armstrong	kamren.armstrong@geemail.com	Atlanta	Georgia	4393245415388947	b8c4ef821cd5e06b912c4535371723e4	Diners Club / Carte Blanche	33.7757775930963504	-84.3766504087064533
33463	2020-06-26 20:03:33	2020-06-26	Amya Cartwright	amya.cartwright@geemail.com	Escondido	California	3096114810997622894	60a3ef840429cc59f5273a0341f4e34f	VISA 16 digit	33.1629430244438339	-117.014779033629225
33464	2020-06-26 20:03:45	2020-06-26	Brandyn Bernhard	brandyn.bernhard@geemail.com	Pearland	Texas	3112318018373209559	31dcbbebda693f2171f46ee62256e963	American Express	29.5012149558208883	-95.2608546966075806
33465	2020-06-26 20:11:15	2020-06-26	Jinnie Dooley	jinnie.dooley@geemail.com	Nashville	Tennessee	3039274152898641	31191478ce84a5cea5aa46a26c6159d6	American Express	36.2338413692668055	-86.790291802203285
33466	2020-06-26 20:11:43	2020-06-26	Dr. Landyn Brekke DDS	dr.landyn.brekke.dds@woohoo.com	Mobile	Alabama	3112786006298165785	9d06d29cfd279f70de28b206047f53ec	American Express	30.5997254659064097	-88.1267789767727265
33467	2020-06-26 20:18:10	2020-06-26	Marlo Hoeger	marlo.hoeger@woohoo.com	Clinton	Michigan	4315568783278670	fc60383cbbf15427febb94c66e333e33	Discover	42.5866087551761439	-83.0057220534030336
33468	2020-06-26 20:19:36	2020-06-26	Ottilia Bergnaum	ottilia.bergnaum@woohoo.com	Gresham	Oregon	6011636510295360382	5d58f9488b8689e01bcf800659087397	Mastercard	45.5480068089861376	-122.540971005361897
33469	2020-06-26 20:24:12	2020-06-26	Thor Kuhlman	thor.kuhlman@geemail.com	Carlsbad	California	639037319955672	c0d68e5a79d2e50786e81624e2b9ca35	VISA 13 digit	33.2172076193090504	-117.237776901737973
33470	2020-06-26 20:29:14	2020-06-26	Magan Luettgen MD	magan.luettgen.md@geemail.com	Chicago	Illinois	3017611007723999	f2b30c455676a5f7c9d0977da8840d4f	Diners Club / Carte Blanche	41.8753021897118529	-87.7382354018773896
33471	2020-06-26 20:32:15	2020-06-26	Vollie Jones	vollie.jones@geemail.com	Newark	New Jersey	676390778600016	fc74ebed6acddd79fc8ddb6078f8388d	VISA 16 digit	40.7965965955898184	-74.1454304559830604
33472	2020-06-26 20:43:40	2020-06-26	Santiago Donnelly	santiago.donnelly@woohoo.com	Frisco	Texas	4107268076219984	f619a9472ca76f3472040c711a750bdf	Mastercard	33.2490087170150161	-96.8186664207115655
33473	2020-06-26 20:49:49	2020-06-26	Wava Reichert PhD	wava.reichert.phd@warmmail.com	Columbus	Ohio	3418017112458678	855753e87aeee9c6e9a88cecc1bdcd2c	Maestro	40.0664278029508907	-82.9026973465692265
33474	2020-06-26 20:51:30	2020-06-26	Maddux Carter-Abshire	maddux.carter.abshire@warmmail.com	Virginia Beach	Virginia	4820087922129734	1e2a28fb4a52ef06845af3a58cdd3376	VISA 16 digit	36.72156531430781	-75.9659139869872462
33475	2020-06-26 21:08:34	2020-06-26	Marianne Hermann	marianne.hermann@woohoo.com	Corona	California	4662043321543	0c4befe9e553256987925d75ccc096b3	JCB 16 digit	33.9442519320063312	-117.527242755537856
33476	2020-06-26 21:12:35	2020-06-26	Theodora Lockman	theodora.lockman@geemail.com	New York	New York	6011750756118286730	40d9194834c4d18c70a05995d65586c6	VISA 16 digit	40.6521060010176143	-73.933499282681197
33477	2020-06-26 21:17:11	2020-06-26	Dr. Thursa Raynor	dr.thursa.raynor@warmmail.com	Killeen	Texas	3441162427224752	5e976226cb24d43850a631a24485bc34	Diners Club / Carte Blanche	30.9942741122327732	-97.7507503484077773
33478	2020-06-26 21:18:50	2020-06-26	Frankie Beatty	frankie.beatty@geemail.com	Anchorage	Alaska	060478098122043	3b240d824fbea2471b4b463d620a4c70	JCB 15 digit	61.2592747276864955	-149.279488900316125
33479	2020-06-26 21:20:00	2020-06-26	Randall Bogisich-Schulist	randall.bogisich.schulist@geemail.com	Richmond	Virginia	676292719726355	8a6bb3ad125973fa717f01717ab57173	Voyager	37.5568922605119653	-77.5228630387447737
33480	2020-06-26 21:26:40	2020-06-26	Jasmin Bernhard	jasmin.bernhard@warmmail.com	Berkeley	California	3337664506162923307	20b25f9511ba6a3227af791ef8eedbf1	VISA 16 digit	37.8487972687166518	-122.298357415023673
33481	2020-06-26 21:31:52	2020-06-26	Aarav Jacobi	aarav.jacobi@warmmail.com	Phoenix	Arizona	180098827023771693	3c7205a0280e6d7ac2f32f0a50ae6bc7	Maestro	33.4933750387679794	-112.171877761643756
33482	2020-06-26 21:47:10	2020-06-26	Carina Morar	carina.morar@geemail.com	Lafayette	Louisiana	3048027841174613	2851c0d5f957f6a23f80118bd816defe	Diners Club / Carte Blanche	30.2662952613994491	-91.9755020234584748
33483	2020-06-26 21:47:22	2020-06-26	Mr. Jereme Walsh	mr.jereme.walsh@woohoo.com	Washington	District of Columbia	3000995166037631	b53f6e8fdb4e65c1f12fe63fceb2d52c	American Express	38.9480009895082588	-77.1085818818051365
33484	2020-06-26 21:56:30	2020-06-26	Tyquan Stracke DVM	tyquan.stracke.dvm@woohoo.com	Detroit	Michigan	3088565493585405669	a7d745cca479cfa3c7dfc8f5e6f2ff5c	Voyager	42.3004718052614521	-83.1974431203331761
33485	2020-06-26 22:04:26	2020-06-26	Raheem Lang	raheem.lang@geemail.com	Berkeley	California	4591281402410824	7e93da2eab9eb9f2b41c9f78011b453b	JCB 15 digit	37.89491392053678	-122.26274999367476
33486	2020-06-26 22:11:19	2020-06-26	Mr. Elroy Hudson II	mr.elroy.hudson.ii@geemail.com	Milwaukee	Wisconsin	6011659141764007239	169e4d6931e1b1c6ab0b6800eb11e856	Diners Club / Carte Blanche	43.1368176182351988	-88.0326762473776938
33487	2020-06-26 22:17:02	2020-06-26	Sadye Mitchell	sadye.mitchell@geemail.com	Boston	Massachusetts	3010309148887214	279d72dbbad96cb1d57bf40e5895184e	Mastercard	42.4106885199602672	-71.0233329680699939
33488	2020-06-26 22:23:06	2020-06-26	Frederica Howell-Berge	frederica.howell.berge@geemail.com	San Francisco	California	51287022635026626	2c94e8fbd71f9409e283375538dcc379	JCB 16 digit	37.775926169201	-122.446813902724102
33489	2020-06-26 22:25:36	2020-06-26	Moira Douglas MD	moira.douglas.md@geemail.com	Fort Worth	Texas	51305657838994878	f57a2a9bf91c72bdf281757a1e3ab887	JCB 15 digit	32.7151910880636407	-97.43158626517355
33490	2020-06-26 22:27:00	2020-06-26	Miss Mona Reichert	miss.mona.reichert@geemail.com	Omaha	Nebraska	4853917482319	e62af4ca5941a4d5d192c7cb30d8c0f4	Diners Club / Carte Blanche	41.2899295343697119	-96.1300545923061662
33491	2020-06-26 22:27:26	2020-06-26	Masao Aufderhar	masao.aufderhar@warmmail.com	Berkeley	California	4286304080289870	72b8d55fc184bf43e5243584af911e4d	VISA 13 digit	37.8488672664197168	-122.301151692421115
33492	2020-06-26 22:32:03	2020-06-26	Ardyce Durgan	ardyce.durgan@geemail.com	Fontana	California	869986293452730953	0478a317819104e2e72445bffb47b89d	VISA 16 digit	34.0840029478222135	-117.531123343743019
33493	2020-06-26 22:32:56	2020-06-26	Tamekia Rosenbaum-Lehner	tamekia.rosenbaum.lehner@geemail.com	Lewisville	Texas	51039211583171341	78d51f5d018b88fef71d691f4b63b6a2	VISA 13 digit	32.9751438208840781	-96.9001877547737251
33494	2020-06-26 22:40:50	2020-06-26	Tal Gerlach	tal.gerlach@geemail.com	Fresno	California	210022972980849933	3a9ab1d5c751e7840cbf34f11f01e3e7	Diners Club / Carte Blanche	36.7827808123886584	-119.800711872625726
33495	2020-06-26 22:47:21	2020-06-26	Lovisa Rippin	lovisa.rippin@geemail.com	San Francisco	California	4923101282488998	4ee588538a85bff253d30cbf47554247	JCB 16 digit	37.7995553352967875	-122.402670605424802
33496	2020-06-26 22:50:42	2020-06-26	Hosie Schaden-Huels	hosie.schaden.huels@geemail.com	Houston	Texas	3423545912556195	62acd24fc4fb6c6dc4c37156d22312e4	VISA 13 digit	29.7160068806804709	-95.4337265935741357
33497	2020-06-26 22:54:54	2020-06-26	Ermine Bradtke	ermine.bradtke@geemail.com	North Las Vegas	Nevada	3407823322341379	26afa7e8a47b02b88ace18731a3ae2c9	VISA 13 digit	36.2952693141687632	-115.002801893021541
33498	2020-06-26 23:00:10	2020-06-26	Booker Crist	booker.crist@geemail.com	Phoenix	Arizona	4721632410503542	b9094298dfef238795cd19afa727d8c8	Diners Club / Carte Blanche	33.4924060049399728	-112.026719823332883
33499	2020-06-26 23:02:35	2020-06-26	Webster Cummerata	webster.cummerata@geemail.com	Berkeley	California	4541122417952	b544aead221217c4f27883ab0c183c92	JCB 15 digit	37.8968298382548312	-122.271488943047103
33500	2020-06-26 23:08:00	2020-06-26	Dr. Demetrios Leuschke V	dr.demetrios.leuschke.v@geemail.com	Charlotte	North Carolina	6011003878386828129	6ad133486f0f1a9d980325b528db8592	VISA 16 digit	35.2797640822149816	-80.9231713812276752
33501	2020-06-26 23:14:16	2020-06-26	Antoinette Lakin-Mraz	antoinette.lakin.mraz@geemail.com	Toledo	Ohio	4901891700289335	932c0f4ca266cccf241fac86086f02dd	JCB 16 digit	41.6100616659209095	-83.5359569579228776
33502	2020-06-26 23:17:25	2020-06-26	Davey Wolff	davey.wolff@woohoo.com	Los Angeles	California	52027441385403576	22e8fc2de68b6ee453b02c24626ebc09	JCB 15 digit	34.0738879484456021	-118.48542408686987
33503	2020-06-26 23:22:20	2020-06-26	Kermit Blick	kermit.blick@geemail.com	Phoenix	Arizona	4058347442780	96541c74ca19dd2565667772106c7bf3	JCB 16 digit	33.5280969503734312	-111.991175330469758
33504	2020-06-26 23:45:43	2020-06-26	Wanda Corkery	wanda.corkery@geemail.com	Santa Ana	California	4359519291330	725e38818d2a838fb8995d6007efafd6	JCB 16 digit	33.7868460405256599	-117.975465492337932
33505	2020-06-26 23:47:36	2020-06-26	Dedra Yost	dedra.yost@woohoo.com	Fort Lauderdale	Florida	4016087284333	3d7d5e8f04a69d17f3cac98b0f41d0ce	VISA 13 digit	26.0424306967750212	-80.1616110171478198
33506	2020-06-26 23:52:45	2020-06-26	Loretto Deckow-Mueller	loretto.deckow.mueller@geemail.com	San Antonio	Texas	3058471637435269	c0717c36ec3179d423afb04d194f437a	Voyager	29.5025204263232652	-98.4918659520637192
33507	2020-06-27 00:01:36	2020-06-27	Dr. Jarret Nikolaus DDS	dr.jarret.nikolaus.dds@geemail.com	College Station	Texas	4784943916688453	40a523cf88e0086ff38f11ebf23510fa	VISA 16 digit	30.6577829721894126	-96.3292208560589813
33508	2020-06-27 00:01:55	2020-06-27	Kaleena Cummerata	kaleena.cummerata@woohoo.com	Moreno Valley	California	869977532799653449	7d06e95e591824b35a0706aa4a159809	VISA 16 digit	33.825960667430607	-117.12922922400459
33509	2020-06-27 00:11:37	2020-06-27	Iver Bode	iver.bode@warmmail.com	San Francisco	California	6011573038834826627	71e5ae386a3dae3db4575d71a852dd21	Mastercard	37.7785751733698589	-122.398971717217321
33510	2020-06-27 00:15:07	2020-06-27	Dr. Georgie Jacobi Sr.	dr.georgie.jacobi.sr.@geemail.com	New York	New York	4216714877524492	c86e4b6992f7f2030efc6d01de3ad82b	VISA 13 digit	40.6152338303383402	-73.8842943954642806
33511	2020-06-27 00:25:02	2020-06-27	Toby Collins	toby.collins@geemail.com	Long Beach	California	4086339765082	adccdbc35bc3683a98709622691b3566	JCB 15 digit	33.7913272784844025	-118.20851374419145
33512	2020-06-27 00:26:24	2020-06-27	Nash Hills-Altenwerth	nash.hills.altenwerth@geemail.com	Jacksonville	Florida	4305530806869416	0b459b5d0be8b16fcdc7c37c00f6a95f	VISA 16 digit	30.3608000323694185	-81.7202879624519625
33513	2020-06-27 00:29:21	2020-06-27	Brooklynn Reichert	brooklynn.reichert@woohoo.com	San Francisco	California	3430032310443871	6eba909a439eaa8696ecb2bdc6229b96	VISA 16 digit	37.7629161300653706	-122.439876619825597
33514	2020-06-27 00:33:54	2020-06-27	Alfreda Abernathy	alfreda.abernathy@geemail.com	Fort Worth	Texas	4882542607442815	907e6d68f45f6f90219889d29574a1c2	Maestro	32.7602790922448079	-97.2597514296237335
33515	2020-06-27 00:40:39	2020-06-27	Maxie Cummerata	maxie.cummerata@geemail.com	Chicago	Illinois	3088023130625664451	c5aa0875e66afdc2a9cab560628dd229	VISA 16 digit	41.9230487750213641	-87.6775967240829033
33516	2020-06-27 00:45:09	2020-06-27	Denzell Anderson DVM	denzell.anderson.dvm@geemail.com	San Francisco	California	4661100783538	fa79fbbb79a8d8a72910e9594b3c2c09	Maestro	37.7179465589183494	-122.450044306019052
33517	2020-06-27 00:54:25	2020-06-27	Nick Luettgen-Weber	nick.luettgen.weber@geemail.com	Plano	Texas	676385451405246	096ed58e0b1c593dc7bb4e4bd5c0b2f7	JCB 15 digit	32.9667462604206065	-96.6813887572098594
33518	2020-06-27 01:06:51	2020-06-27	Foy Collins	foy.collins@geemail.com	Tuscaloosa	Alabama	6011683589057051068	61aef3288095193f38f4d7616aef74d8	Maestro	33.2204721602667092	-87.5313199916020039
33519	2020-06-27 01:13:09	2020-06-27	Mila Moore	mila.moore@geemail.com	Lakeland	Florida	210013758330817477	42cb1e168802b92d28d7ec05faddb627	Diners Club / Carte Blanche	28.0629234702158712	-81.9157971744310061
33520	2020-06-27 01:14:14	2020-06-27	Vera Bartoletti IV	vera.bartoletti.iv@geemail.com	Santa Clarita	California	589323277230555	daf9badef5a8ca697995454e40e871c3	Discover	34.3378350955639036	-118.598867014433068
33521	2020-06-27 01:14:21	2020-06-27	Kristen Kohler II	kristen.kohler.ii@geemail.com	Los Angeles	California	210068961400298859	4368fc817ab765b361f362f5f324bcf3	JCB 16 digit	34.0311545198649128	-118.383023549475894
33522	2020-06-27 01:17:18	2020-06-27	Dr. Samir Gulgowski	dr.samir.gulgowski@woohoo.com	San Francisco	California	6011993552496712885	d9de4fc541fe8867225e36e5672ff905	VISA 16 digit	37.7834714549935953	-122.441925006608457
33523	2020-06-27 01:18:54	2020-06-27	Kamari Anderson	kamari.anderson@woohoo.com	Corpus Christi	Texas	180072412104933866	7a6521eeda4e8b909544b42968325d14	VISA 16 digit	27.7905013060599586	-97.2306554075624803
33524	2020-06-27 01:23:57	2020-06-27	Kieran Lueilwitz-Shanahan	kieran.lueilwitz.shanahan@geemail.com	New York	New York	6011759968270447130	bb4f3143e4f5648c6aa2a1004dfd2bb6	VISA 16 digit	40.6156918680518828	-73.9714248996123587
33525	2020-06-27 01:28:07	2020-06-27	Nicholaus Windler	nicholaus.windler@geemail.com	Chicago	Illinois	3739255708061077	ad48b7e80f34a46f7bcfc1a45638dfa0	VISA 16 digit	41.9134836770895873	-87.6992673927016568
33526	2020-06-27 01:36:02	2020-06-27	Latrell Braun	latrell.braun@warmmail.com	New York	New York	3467696599750606	33f7b5dcb092a9d18ecd9d93e0fa19d3	JCB 16 digit	40.5735823070853954	-73.8670359599765334
33527	2020-06-27 01:53:29	2020-06-27	Dr. Cleta Leannon DDS	dr.cleta.leannon.dds@geemail.com	Nashville	Tennessee	210099530003897392	f5e0ccd9199f9f3ac76edf3b56987a69	Voyager	36.1335125756107232	-86.8768016957119045
33528	2020-06-27 02:00:07	2020-06-27	Hedy Moen	hedy.moen@geemail.com	Joliet	Illinois	4476763076093218	52d092f1981546418cb5ea73af2bc39f	Maestro	41.4178456681173301	-88.0869686645559966
33529	2020-06-27 02:05:01	2020-06-27	Dr. Richie Mraz MD	dr.richie.mraz.md@geemail.com	Portland	Oregon	4678124763516944	c028646ea33bc770fcb10f3f52efd58e	VISA 16 digit	45.548777185369282	-122.566361573478218
33530	2020-06-27 02:09:10	2020-06-27	Miss Mathilde Fadel	miss.mathilde.fadel@geemail.com	San Francisco	California	3112819757207889490	ee39bdf9483b20879c6e92a38d29adf0	JCB 16 digit	37.7535894277420283	-122.401321620489142
33531	2020-06-27 02:13:43	2020-06-27	Frankie Stracke	frankie.stracke@geemail.com	Nashville	Tennessee	589324684519325	9e64e33ea7b472a105b966a3b03d4576	JCB 16 digit	36.2172356214497242	-86.7472705844696605
33532	2020-06-27 02:14:21	2020-06-27	Ariana Wiza	ariana.wiza@geemail.com	Fremont	California	3528502735995440405	55f444e60c7f1ab71d9932a874c7eaf3	VISA 16 digit	37.4124659597109996	-121.974828089679406
33533	2020-06-27 02:15:58	2020-06-27	Lorean Funk	lorean.funk@geemail.com	Lafayette	Louisiana	3112868898152858088	a9d46410d20baf7f0daabc2bcc159e09	Discover	30.1525952118892206	-92.0486393521390767
33534	2020-06-27 02:16:08	2020-06-27	Elliot Hegmann	elliot.hegmann@geemail.com	Provo	Utah	6011205929972549995	87a8209cf77bd35d68e8fc989b0c1127	JCB 15 digit	40.3380835431881266	-111.56194346744121
33535	2020-06-27 02:21:17	2020-06-27	Odalys Schamberger	odalys.schamberger@geemail.com	San Francisco	California	3158391632463164423	545df6f7f817bc946613f7a94a54294f	VISA 16 digit	37.7426620715798862	-122.427699631868023
33536	2020-06-27 02:22:06	2020-06-27	Mr. Dimitri Emard IV	mr.dimitri.emard.iv@geemail.com	Newport News	Virginia	3112799871238232671	bfa4a76238f6b1296251bfead40bcbd6	Maestro	37.1554066286783637	-76.5204295277856374
33537	2020-06-27 02:23:11	2020-06-27	Ula Kassulke MD	ula.kassulke.md@geemail.com	Birmingham	Alabama	180041942119253981	89d00ad8b3158bed46a8ff23440de07f	Diners Club / Carte Blanche	33.6054508481431782	-86.7640184288155325
33538	2020-06-27 02:23:51	2020-06-27	Addyson Strosin	addyson.strosin@geemail.com	Chesapeake	Virginia	3337711191819278471	5b91a77eb99c08ca8865f4db9611bd6f	VISA 16 digit	36.6176384079042805	-76.2928820514429304
33539	2020-06-27 02:39:26	2020-06-27	Rhoda Klocko	rhoda.klocko@woohoo.com	Raleigh	North Carolina	4398328346727824	8fcd93355a007125b393139bf1c51b69	Voyager	35.7572398588661073	-78.6747757661093061
33540	2020-06-27 02:51:03	2020-06-27	Elodie Cartwright	elodie.cartwright@geemail.com	Thousand Oaks	California	6011182899649368672	e28247e09f980a1e84a0c8c11dd6d276	Maestro	34.1826607987556628	-118.947473640172561
33541	2020-06-27 03:01:22	2020-06-27	Dr. Ernst Roberts MD	dr.ernst.roberts.md@geemail.com	Sparks	Nevada	869916395296950609	840c5bda283951f6a7e9c19e4b692652	Voyager	39.4544511220190657	-119.683778804619237
33542	2020-06-27 03:03:42	2020-06-27	Turner Greenholt-Schamberger	turner.greenholt.schamberger@geemail.com	Visalia	California	6011038981720830998	0da3f4c786afe85b200e003535a093bd	JCB 16 digit	36.2345147870901982	-119.32623514166437
33543	2020-06-27 03:08:13	2020-06-27	Lex Hammes-Gottlieb	lex.hammes.gottlieb@warmmail.com	Spokane	Washington	210023091135889329	ae092885aa0873a3c92a961304f2baaa	American Express	47.6951559962011871	-117.403877815594157
33544	2020-06-27 03:11:43	2020-06-27	Estel Hoeger	estel.hoeger@geemail.com	Midland	Texas	4439777839829227	0238790939c99cb3481af26f90aecfe4	JCB 16 digit	31.9898277631219479	-102.01403859120235
33545	2020-06-27 03:12:29	2020-06-27	Anthoney Hagenes IV	anthoney.hagenes.iv@woohoo.com	San Diego	California	210078796151961364	41dac3e95f8580aceb5da6eff57b9eb8	JCB 16 digit	32.8070385216336717	-117.093612446440389
33546	2020-06-27 03:18:07	2020-06-27	Zackary Williamson-Dickens	zackary.williamson.dickens@geemail.com	San Francisco	California	561224312252471	f6e69e236d3c3a510aed3e58b2d6ffe3	Diners Club / Carte Blanche	37.7711835788823365	-122.416300350585914
33547	2020-06-27 03:19:52	2020-06-27	Miss Rashida Boyer	miss.rashida.boyer@geemail.com	Charlotte	North Carolina	4896695725093326	2f8a324bff1136df0bf8810572473da3	Mastercard	35.1982600320849528	-80.7669328605700372
33548	2020-06-27 03:33:50	2020-06-27	Eugene Kohler PhD	eugene.kohler.phd@geemail.com	Yonkers	New York	4933690572385	d8d8e6e274a465775bb1cd869bdc9a3d	Mastercard	40.9626377203237269	-73.8628307022038939
33549	2020-06-27 04:02:53	2020-06-27	Maximo Miller	maximo.miller@warmmail.com	Dallas	Texas	869937345529858470	0d9fd4985141b5cc04635582e7754e13	JCB 15 digit	32.7676887053802659	-96.8204812731090811
33550	2020-06-27 04:04:09	2020-06-27	Delma Streich	delma.streich@geemail.com	Louisville	Kentucky	54422053847868402	589067ef56348cfbb3d50dd9d7ff40a1	Voyager	38.078883375729994	-85.6140190168354707
33551	2020-06-27 04:09:27	2020-06-27	Burr Aufderhar DVM	burr.aufderhar.dvm@warmmail.com	Los Angeles	California	4536355245922647	be2c29f7ce9747b4efe410b5649b23a2	JCB 16 digit	33.9704191744193409	-118.331282468605039
33552	2020-06-27 04:10:05	2020-06-27	Mathew Robel	mathew.robel@geemail.com	Los Angeles	California	3019877881450706	cadf87f1cc8566585d5533b730e8bdb4	JCB 15 digit	34.0424221936013538	-118.384504411741347
33553	2020-06-27 04:13:48	2020-06-27	Fitzhugh Stamm	fitzhugh.stamm@geemail.com	San Diego	California	210031203232357163	e879f0ae63d7eb20b86826ff22fb64a3	American Express	32.8586451879769541	-117.075283264219763
33554	2020-06-27 04:15:32	2020-06-27	Mr. Jayson Smith	mr.jayson.smith@geemail.com	Anchorage	Alaska	869932876654769467	8a246a0e804f2df816c3bdd9835e1184	American Express	61.2497951800685385	-149.282550079667203
33555	2020-06-27 04:15:46	2020-06-27	Mr. Acie Gleichner	mr.acie.gleichner@geemail.com	Boulder	Colorado	4265060834867	6b9761a12f8fead26bd8b243f152b6dd	Maestro	39.9417173049394023	-105.269182723216346
33556	2020-06-27 04:17:00	2020-06-27	Ova Hickle	ova.hickle@geemail.com	Houston	Texas	4057294136906766	6b41ae07f76797c52fcb2cd58ff6e43f	Diners Club / Carte Blanche	29.7598994989026338	-95.4497699602521976
33557	2020-06-27 04:17:43	2020-06-27	Lucina King	lucina.king@woohoo.com	Oklahoma City	Oklahoma	180071219869022269	7253b89defe82dbeea94711636ddaee5	VISA 16 digit	35.4733334515154368	-97.5216404890071544
33558	2020-06-27 04:17:55	2020-06-27	Dr. Dann Grant Jr.	dr.dann.grant.jr.@geemail.com	San Francisco	California	3096190722823840755	67c80f291db639fae89c42f99ee99040	JCB 16 digit	37.7699889157004804	-122.427413791434347
33559	2020-06-27 04:18:06	2020-06-27	Dr. Hardie Ebert III	dr.hardie.ebert.iii@geemail.com	Tallahassee	Florida	3037934419326510	efa05571abd57f80c038e020378ba59d	VISA 13 digit	30.4071168808754564	-84.1690757367309175
33560	2020-06-27 04:27:30	2020-06-27	Sarai Nolan-Gerlach	sarai.nolan.gerlach@geemail.com	Fresno	California	6011245948592852862	430daea0c5baa8bca2b7ed497eb515c2	Maestro	36.807251927290487	-119.874013108724355
33561	2020-06-27 04:30:10	2020-06-27	Pat Hauck	pat.hauck@geemail.com	Tallahassee	Florida	676250401990333	73b3b8872da282461dcde04b19349696	JCB 16 digit	30.4910416684601486	-84.1634860275328123
33562	2020-06-27 04:34:50	2020-06-27	Ms. Betsy Kling PhD	ms.betsy.kling.phd@geemail.com	Chicago	Illinois	55134797282067024	6fce8f6cda91f2f34129e78221ea686a	Maestro	41.8955415797721642	-87.7152016435313868
33563	2020-06-27 04:36:31	2020-06-27	Nathanial Bednar MD	nathanial.bednar.md@woohoo.com	Fullerton	California	869928707236968713	3ecabbdc37948a548def2a7b659bf628	JCB 16 digit	33.7991027132764472	-117.95023974978551
33564	2020-06-27 04:41:29	2020-06-27	Somer Spinka	somer.spinka@warmmail.com	Mesa	Arizona	3031271985590716	42eff3cefa0f3bc743c8293a05cfbf77	American Express	33.4247842231910681	-111.641796955640984
33565	2020-06-27 04:41:54	2020-06-27	Loris Auer PhD	loris.auer.phd@geemail.com	Tulsa	Oklahoma	6011509980254411944	627a066f88357670c33af025e9f6fc31	VISA 16 digit	36.2204883796997308	-95.9543167490001707
33566	2020-06-27 04:42:06	2020-06-27	Dr. Lizette Muller PhD	dr.lizette.muller.phd@geemail.com	Jacksonville	Florida	4390569062025038	c5234c22213bc71406e080413a0607c7	VISA 16 digit	30.3033861196652055	-81.7477529020592613
33567	2020-06-27 04:44:08	2020-06-27	Olena Sporer	olena.sporer@geemail.com	Boston	Massachusetts	6011143069383826883	002210be0f8ccf526ce7b19f7bda6d45	Mastercard	42.2339796513952308	-70.9273421334054319
33568	2020-06-27 05:00:42	2020-06-27	Denine Greenholt	denine.greenholt@geemail.com	Arlington	Texas	55096647236178656	ca87fe61fa0de10227d012b82ebcb0c9	Mastercard	32.7136412550479179	-97.1228636315584168
33569	2020-06-27 05:05:54	2020-06-27	Mitzi Dickinson	mitzi.dickinson@warmmail.com	San Antonio	Texas	3014675309196769	d4edba67a19a465208929db9a13db93e	VISA 13 digit	29.3932021151833247	-98.4556647655390123
33570	2020-06-27 05:10:47	2020-06-27	Shona Botsford	shona.botsford@geemail.com	New York	New York	869958260027925594	58918227e64a2f05736427d9fa6f9d37	Diners Club / Carte Blanche	40.7476260284651062	-73.9892617756396476
33571	2020-06-27 05:21:20	2020-06-27	Deandre Mraz-Hane	deandre.mraz.hane@geemail.com	San Francisco	California	869997987641911591	9c29ad26ae949f041aefaa20ab4c4177	VISA 16 digit	37.7844454738491748	-122.430756424624363
33572	2020-06-27 05:24:19	2020-06-27	Pearly McKenzie	pearly.mckenzie@geemail.com	Long Beach	California	6011355954922999114	fac5fc5d4f5cd8d3f17ee27a59ab4cb4	VISA 13 digit	33.744613656011218	-118.115583212410286
33573	2020-06-27 05:27:02	2020-06-27	Dr. Nyasia Muller DDS	dr.nyasia.muller.dds@geemail.com	San Francisco	California	180088528725945542	5e75bb9bebdd179b37083fcbeba39416	Maestro	37.7696090535107913	-122.429336764206965
33574	2020-06-27 05:35:20	2020-06-27	Rory Stark	rory.stark@geemail.com	Brownsville	Texas	4474913135094531	ee56a506456192f1672146989d8449e7	Maestro	26.0037489643864319	-97.4580987109057588
33575	2020-06-27 05:42:16	2020-06-27	Dr. Niles Stoltenberg DVM	dr.niles.stoltenberg.dvm@woohoo.com	Allen	Texas	3096426728623448596	62cfe5ff1cae6741b52eb23287e02709	VISA 13 digit	33.1934492809258401	-96.6744725653849599
33576	2020-06-27 05:51:35	2020-06-27	Deneen Brown	deneen.brown@geemail.com	Portland	Oregon	3528745879323836459	8a9dd3242309697a2b4bd4c485a61c6e	Mastercard	45.5889568155519669	-122.626529614906758
33577	2020-06-27 05:53:19	2020-06-27	Phil Hartmann	phil.hartmann@woohoo.com	Fresno	California	3096054647112808251	075064a91315b3c0703025576a297ff3	JCB 15 digit	36.7430440849497941	-119.831486095312613
33578	2020-06-27 05:53:47	2020-06-27	Misael Berge II	misael.berge.ii@geemail.com	Corpus Christi	Texas	3041509502381303	66998ed385d922ebc99ceb6d7b9c07a5	VISA 13 digit	27.756999975995349	-97.1957029401618939
33579	2020-06-27 05:53:47	2020-06-27	Kimball Raynor	kimball.raynor@woohoo.com	Huntsville	Alabama	3088399022588333156	9a7f174559fd5d17761c034972007c5e	VISA 13 digit	34.6493731153905387	-86.6379528715759477
33580	2020-06-27 05:59:35	2020-06-27	Barbra Weimann	barbra.weimann@geemail.com	Berkeley	California	869933150842406013	579f459b62706e94966831bfe9a48dae	VISA 16 digit	37.9009287069568543	-122.249066203537211
33581	2020-06-27 06:12:36	2020-06-27	Dr. Candida Altenwerth MD	dr.candida.altenwerth.md@geemail.com	Aurora	Colorado	3748735566908930	db7daf300c42017b1236f60f3fe2acb6	Discover	39.680001914512367	-104.749011807528134
33582	2020-06-27 06:18:27	2020-06-27	Mrs. Lauri Gleichner PhD	mrs.lauri.gleichner.phd@woohoo.com	Detroit	Michigan	6011918694585924252	861b2deeca24b62b6738781d1d3e1e23	Discover	42.3353134188260896	-83.0162305835753642
33583	2020-06-27 06:29:38	2020-06-27	Felice Torphy PhD	felice.torphy.phd@geemail.com	Pompano Beach	Florida	3431730595676409	a93733c8e0870658284b72306dc109b3	JCB 16 digit	26.270717730166762	-80.074725890656552
33584	2020-06-27 06:33:21	2020-06-27	Ms. Florance Walsh	ms.florance.walsh@geemail.com	San Francisco	California	3096575838410056152	2e9c0a574372d1cea63cb31e4fb9527a	Discover	37.7965219258629332	-122.45181554754744
33585	2020-06-27 06:36:04	2020-06-27	Eura O'Connell	eura.o'connell@warmmail.com	Mobile	Alabama	639095629842311	80c6436904b791c76316c0249956ace4	JCB 16 digit	30.7667039917424319	-88.1105615854401094
33586	2020-06-27 06:38:11	2020-06-27	Gunner Treutel	gunner.treutel@warmmail.com	San Francisco	California	3404882335257348	256b786f0d1042cf8a01f665c6504e9f	JCB 15 digit	37.7812888700936753	-122.423489938704705
33587	2020-06-27 06:38:56	2020-06-27	Miss Naomi Waters DDS	miss.naomi.waters.dds@geemail.com	Chesapeake	Virginia	4020757636614886	b11df9f19f384546f07f56e2e07a5759	American Express	36.6957391449488739	-76.3129164941918106
33588	2020-06-27 06:52:17	2020-06-27	Dr. Terell Keebler	dr.terell.keebler@geemail.com	Los Angeles	California	3337589680301425169	ce1dc74a31719e85e35ad63f55a0de20	VISA 13 digit	33.9388144725799563	-118.378625788725159
33589	2020-06-27 06:55:53	2020-06-27	Mrs. Velia Gutmann	mrs.velia.gutmann@geemail.com	Gilbert	Arizona	6011594342172542597	dc9df0283a3c8880298d41bb1041b5a5	American Express	33.3393446180850219	-111.768260054489971
33590	2020-06-27 06:56:21	2020-06-27	Mr. Shaquille Leannon Jr.	mr.shaquille.leannon.jr.@geemail.com	Orlando	Florida	869987304871197929	86d2d2671ecbc691db62406bc6cf7ca6	JCB 16 digit	28.4184641474656736	-81.3651889214258688
33591	2020-06-27 07:07:25	2020-06-27	Shanae Lebsack	shanae.lebsack@geemail.com	Oklahoma City	Oklahoma	3015990686114999	6479486622a2bd1bc5209a93db3261e8	Discover	35.5233713909894249	-97.4426383028633865
33592	2020-06-27 07:10:55	2020-06-27	Katrina Watsica	katrina.watsica@geemail.com	Surprise	Arizona	3429525702661896	cb2515e3e05b69d54d8614bb03318eda	JCB 16 digit	33.6484254225850137	-112.425677284342044
33593	2020-06-27 07:33:21	2020-06-27	Seldon Stroman	seldon.stroman@geemail.com	Rochester	New York	869917390058828605	0044c01fcd9edca2eb37d54057888249	Diners Club / Carte Blanche	43.2621176582273108	-77.7159135291125693
33594	2020-06-27 07:35:08	2020-06-27	Efren Stracke	efren.stracke@geemail.com	Phoenix	Arizona	3032951844188138	535a48f87f564c8e76036cba93030882	VISA 16 digit	33.5486845150057249	-112.092869412891943
33595	2020-06-27 07:42:58	2020-06-27	Versa Hessel	versa.hessel@geemail.com	Tallahassee	Florida	51765543531705204	3c7366612b3586d53da112a9ef9dabb4	JCB 16 digit	30.503779757071662	-84.2963650638252489
33596	2020-06-27 08:03:53	2020-06-27	Lena Borer	lena.borer@warmmail.com	Oceanside	California	3043689870278469	86c58ac2c0ff9e8f0314df8dff7acab7	JCB 15 digit	33.2001919726729398	-117.390702844139938
33597	2020-06-27 08:09:50	2020-06-27	Alexandria Doyle	alexandria.doyle@geemail.com	West Covina	California	3088919547725327274	157c263d259a0735d2c4c6c229c6edad	JCB 16 digit	33.9770044918280121	-117.991636843567335
33598	2020-06-27 08:15:02	2020-06-27	Zeb Hilll-Hermann	zeb.hilll.hermann@woohoo.com	San Diego	California	4092191588061263	71dbcb22bb62f80e623a5befcf1bf7b0	Discover	32.8597454895798151	-117.097117806077009
33599	2020-06-27 08:15:17	2020-06-27	Harmony Rice	harmony.rice@woohoo.com	New York	New York	869972494903244216	74c07b86eade8f092c5ac66f016f316e	Discover	40.6099373019058234	-73.8432826256740782
33600	2020-06-27 08:19:35	2020-06-27	Alysia Prosacco-O'Reilly	alysia.prosacco.o'reilly@geemail.com	Alexandria	Virginia	869986158306568075	95bf519564d3654352c965a00a56b8f7	VISA 13 digit	38.761898005998134	-77.0784287374451793
33601	2020-06-27 08:24:37	2020-06-27	Jolene Miller PhD	jolene.miller.phd@geemail.com	New York	New York	4424343972572830	61568edd60bf48d378b20bef3a77d625	American Express	40.7195845419764524	-74.0290982696589026
33602	2020-06-27 08:35:37	2020-06-27	Dr. Jamel Runte	dr.jamel.runte@woohoo.com	Macon	Georgia	3088116800141083463	21498b17e2e79f5105d9329c78080995	American Express	32.787184615061804	-83.7847718121211926
33603	2020-06-27 08:41:30	2020-06-27	Dr. Donie Parker	dr.donie.parker@geemail.com	Indianapolis	Indiana	676367698561056	b15b7860ce84e25b63a49ee68a6052d5	American Express	39.8020041575662802	-86.0588691882058896
33604	2020-06-27 09:04:03	2020-06-27	Elfie Windler	elfie.windler@geemail.com	Phoenix	Arizona	4261227534456556	34c596d7421c4ec4efc419cba97b52c8	Maestro	33.5808517204064927	-112.046411776209624
33605	2020-06-27 09:09:16	2020-06-27	Jan Greenfelder	jan.greenfelder@geemail.com	Centennial	Colorado	4584434530615348	566fe75ce98929167ebf60e60ec093be	Diners Club / Carte Blanche	39.5735819926060728	-104.942490036169445
33606	2020-06-27 09:10:44	2020-06-27	Darin Johnston	darin.johnston@geemail.com	San Francisco	California	6011769958547322412	d47170a45a6e609d2c49367e15630d7b	Mastercard	37.7669338713665539	-122.44271705581626
33607	2020-06-27 09:25:23	2020-06-27	Rosia Conn	rosia.conn@geemail.com	New York	New York	210012993700801600	905d6e7c9d5436d4f803e1213b809b5c	VISA 16 digit	40.7197591699883361	-74.0319744152843953
33608	2020-06-27 09:26:36	2020-06-27	Sammie Lockman-Muller	sammie.lockman.muller@geemail.com	Louisville	Kentucky	3112946129107058525	3222ad28ae3c4245a61e5855c4c8338c	JCB 15 digit	38.2156725165802982	-85.7448500208627422
33609	2020-06-27 09:36:25	2020-06-27	Vincenzo O'Hara-Runolfsdottir	vincenzo.o'hara.runolfsdottir@geemail.com	Dallas	Texas	4797801982640391	b6cad51a4346d8f3bfe7c49a5df2f297	Diners Club / Carte Blanche	32.7400851992230884	-96.8049110230021057
33610	2020-06-27 09:42:31	2020-06-27	Dr. Kalel Crist DVM	dr.kalel.crist.dvm@geemail.com	Elizabeth	New Jersey	4889009402065855	651e530baa45a417acc831af50f7a0b1	American Express	40.5715339811645492	-74.2644836442954812
33611	2020-06-27 10:25:29	2020-06-27	Jermaine Leffler III	jermaine.leffler.iii@geemail.com	Cincinnati	Ohio	4147011035564	19c0f4f6a79bd254cda8e95db545fc2a	Mastercard	39.0878303400937455	-84.558070482899609
33612	2020-06-27 10:31:28	2020-06-27	Dr. Evalyn Kautzer DVM	dr.evalyn.kautzer.dvm@geemail.com	New York	New York	869955549546878471	331a871c9f7b3a428d08b911899028ed	VISA 13 digit	40.6750709035191704	-73.8700539133872809
33613	2020-06-27 10:50:26	2020-06-27	Camisha Jacobson	camisha.jacobson@geemail.com	Kansas City	Missouri	3528470575177378983	7b3a877297405c353876e72ccdce2eb6	VISA 13 digit	39.1811293854679974	-94.5367467971276483
33614	2020-06-27 10:58:28	2020-06-27	Jayde Christiansen MD	jayde.christiansen.md@geemail.com	San Francisco	California	210071702985703839	324e179ead6119e702b7b76722df2ff0	Discover	37.7973447998470391	-122.440952740218265
33615	2020-06-27 11:03:25	2020-06-27	Mr. Vollie Herzog	mr.vollie.herzog@geemail.com	Houston	Texas	3096364586471074763	4a4f976380dd1d971be90900d290323e	VISA 13 digit	29.8039223266378031	-95.3287257840406141
33616	2020-06-27 11:10:14	2020-06-27	Paris Glover	paris.glover@geemail.com	Wilmington	North Carolina	869976231785272188	219351436ea5b1cc3626f9d4ecae77ab	VISA 16 digit	34.2705576785661279	-77.9155525756526828
33617	2020-06-27 11:11:07	2020-06-27	Roslyn Botsford-Rath	roslyn.botsford.rath@geemail.com	Downey	California	4242785215387931	466ccbf6707d8f635d29d62db340a0fe	JCB 16 digit	34.0190997698593875	-118.105841396480429
33618	2020-06-27 11:20:08	2020-06-27	Mrs. Nira Kling MD	mrs.nira.kling.md@geemail.com	San Francisco	California	3337882139693320193	d26a0e8610e380cbdde735f6aee6d3be	Diners Club / Carte Blanche	37.7676664466849772	-122.448066753983824
33619	2020-06-27 11:33:21	2020-06-27	Bjorn O'Hara	bjorn.o'hara@geemail.com	Palm Bay	Florida	3003063394183425	a1c89065df41793477bb9b4241e744e9	VISA 16 digit	27.9559959386330128	-80.69187363454364
33620	2020-06-27 11:39:41	2020-06-27	Mrs. Alondra Kunze DDS	mrs.alondra.kunze.dds@warmmail.com	Fort Worth	Texas	4927927470120142	7b4f91553c597a496bd2d463552a2faa	Maestro	32.8604104271680129	-97.2483594057436989
33621	2020-06-27 11:46:01	2020-06-27	Richard VonRueden	richard.vonrueden@geemail.com	Los Angeles	California	4952029681295	6695c56dc2b45ae666ac2a2315e140d7	JCB 16 digit	34.0681201727926677	-118.459936420385901
33622	2020-06-27 11:46:24	2020-06-27	Sidney Runolfsson	sidney.runolfsson@woohoo.com	Albuquerque	New Mexico	3337928596223702842	6610545bf598f8c2399347ca90fe2976	JCB 16 digit	35.0983228684071449	-106.727135507769518
33623	2020-06-27 11:46:46	2020-06-27	Jazmyne Swift	jazmyne.swift@geemail.com	Pompano Beach	Florida	3528643731751438360	8d2d8ddc78c9bbee2d87b69ed51efafe	JCB 16 digit	26.1651737296286946	-80.0766308787126064
33624	2020-06-27 11:50:40	2020-06-27	Ms. Carmelita Dare DDS	ms.carmelita.dare.dds@geemail.com	New York	New York	3010107144300731	fdc9209cccb210ecc8715393d496acf6	JCB 15 digit	40.608285381713884	-73.8641890109878005
33625	2020-06-27 12:02:04	2020-06-27	Dr. Gottlieb Donnelly Jr.	dr.gottlieb.donnelly.jr.@geemail.com	Centennial	Colorado	4762772662171422	1d31ede998c90b86766fa3e81f33fb34	Voyager	39.5172991240438094	-104.91851830076277
33626	2020-06-27 12:05:56	2020-06-27	Dorris Grady	dorris.grady@geemail.com	Rochester	New York	3022014977726958	97f5aab9dd87461da5c89ee1f14517a0	Maestro	43.077450139119847	-77.6401925468124432
33627	2020-06-27 12:09:32	2020-06-27	Elzie Stiedemann-Prohaska	elzie.stiedemann.prohaska@geemail.com	Richmond	California	4874532249716171	718b746cead4bcc2011a408de37c8503	Diners Club / Carte Blanche	37.9200756147459188	-122.289542092088993
33628	2020-06-27 12:20:16	2020-06-27	Pamella Gottlieb	pamella.gottlieb@warmmail.com	San Antonio	Texas	180026328887859762	1697d4db631c4c6d9aca14b33cef8b2a	Voyager	29.4093830437004584	-98.4454714834060525
33629	2020-06-27 12:21:08	2020-06-27	Hedy Block	hedy.block@geemail.com	Glendale	Arizona	4168715009518987	32ffc49c45a5b089dc1fb93f08df0c39	Voyager	33.5019190364278856	-112.239111446475235
33630	2020-06-27 12:23:21	2020-06-27	Barbie Klein	barbie.klein@woohoo.com	Orlando	Florida	6011485093638737014	386174f663c1b767d754a790e4ecdd45	JCB 16 digit	28.4154339026458551	-81.2831401551108854
33631	2020-06-27 12:32:05	2020-06-27	Antonia Keebler	antonia.keebler@geemail.com	San Francisco	California	3721152551662426	e6d6d7392436b0169fc7e3fd8f5e5af5	Mastercard	37.7849764848887588	-122.438442663260886
33632	2020-06-27 12:41:30	2020-06-27	Ottie Rau	ottie.rau@geemail.com	Dallas	Texas	3038314187932493	71fa88548c03e3b31d4b3abc8ea4d22a	Mastercard	32.7747837716985515	-96.7970721448268705
33633	2020-06-27 12:49:29	2020-06-27	Kyle Ernser	kyle.ernser@geemail.com	Mesa	Arizona	3051974672051732	990dc5dc113ce37d08aad6d3c7d6372f	JCB 16 digit	33.3753725422691545	-111.689487202453989
33634	2020-06-27 12:54:38	2020-06-27	Ruthie Kassulke	ruthie.kassulke@woohoo.com	Portland	Oregon	210050406885419877	43551614cd2875fa4376dfad3fa67fc7	VISA 16 digit	45.4724078368749431	-122.744344075350099
33635	2020-06-27 12:55:39	2020-06-27	Pierre Morissette-Ortiz	pierre.morissette.ortiz@geemail.com	San Jose	California	55267764373597201	cac60d913092ecaf147264b5fff4194d	VISA 13 digit	37.3491056375958053	-121.82626865154468
33636	2020-06-27 12:56:48	2020-06-27	Dr. Simmie Kris PhD	dr.simmie.kris.phd@geemail.com	New York	New York	55916169477873224	42ef7e77b9e2a0ff083919aaf9054199	Discover	40.5791856460031113	-74.0375436338491681
33637	2020-06-27 13:06:39	2020-06-27	Kazuko Welch PhD	kazuko.welch.phd@geemail.com	San Diego	California	3478102787536649	fe454b23f1182be88354de623aae11ab	VISA 16 digit	32.7982106398858164	-117.160136966584261
33638	2020-06-27 13:19:22	2020-06-27	Mikal West V	mikal.west.v@geemail.com	Los Angeles	California	869961149601223416	d63f66b213e464f6bec37ab328ccf67b	Maestro	34.1067692782130081	-118.31576335104107
33639	2020-06-27 13:49:52	2020-06-27	Bascom Howell-Zemlak	bascom.howell.zemlak@woohoo.com	Riverside	California	6011597018991564577	527a4f5e679a56bdf2c1ee929ba09a99	VISA 13 digit	33.9221189862530679	-117.439363373207669
33640	2020-06-27 13:58:47	2020-06-27	Zakary Schulist	zakary.schulist@woohoo.com	Mesquite	Texas	6011884744666102821	3bffaa0b2feef9d609979787adf8190a	JCB 16 digit	32.6819159459598367	-96.6750702922895613
33641	2020-06-27 14:06:04	2020-06-27	Mr. Ezell Ziemann	mr.ezell.ziemann@geemail.com	San Diego	California	4885934441685179	fd0cfc74e1e70e36116486a42821613c	JCB 16 digit	32.8961799623511766	-117.045462561482566
33642	2020-06-27 14:12:11	2020-06-27	Evita Bogan	evita.bogan@geemail.com	Aurora	Colorado	3337708959431851072	d6b6afa1dcb52eb3be53e6fe1a1d8aa5	Maestro	39.6376529886499043	-104.784538733272626
33643	2020-06-27 14:24:59	2020-06-27	Lolla Lindgren	lolla.lindgren@woohoo.com	Fort Collins	Colorado	4276853060156	bfae7baa054ce3c618d752a855a06e72	American Express	40.4735842940088375	-105.121486121085667
33644	2020-06-27 14:28:31	2020-06-27	Olar Dietrich	olar.dietrich@geemail.com	Tulsa	Oklahoma	3460141475368105	ee4993e9706a7326b425eff65ba45b02	VISA 16 digit	36.160215959595142	-95.9563704803075552
33645	2020-06-27 14:31:00	2020-06-27	Izaiah Marquardt	izaiah.marquardt@geemail.com	Palm Bay	Florida	3785747082313234	1579df11d77adf22aadea12c75712881	American Express	27.9703973723895878	-80.7220695817213425
33646	2020-06-27 14:32:36	2020-06-27	Sumner Bartoletti	sumner.bartoletti@woohoo.com	San Diego	California	3088996734621236629	c2d3dbb2c01c32825c867d2cee9358ac	Voyager	32.8078722508691243	-117.141251978175717
33647	2020-06-27 14:36:05	2020-06-27	Metta West	metta.west@geemail.com	Oakland	California	869909322366370970	79e3c158f433a3700d5075da38b38b7c	VISA 13 digit	37.8181253629252581	-122.307631601739459
33648	2020-06-27 14:36:52	2020-06-27	Tatum Armstrong	tatum.armstrong@woohoo.com	Jacksonville	Florida	3011455255817632	f6e1a19b9c3d58e8f05a46ba9262e99b	JCB 16 digit	30.4259605390071854	-81.6103778072245518
33649	2020-06-27 14:54:10	2020-06-27	Kim Brown	kim.brown@geemail.com	Montgomery	Alabama	3158702123969998237	b8b2df643259f480a9c01ecdc16ce4fe	Diners Club / Carte Blanche	32.2969144252527514	-86.1905356929790116
33650	2020-06-27 15:01:34	2020-06-27	Kennedy Fritsch	kennedy.fritsch@warmmail.com	Honolulu	Hawaii	6011180455663442174	5d2811fe08347d7471565f9ff05f502f	Diners Club / Carte Blanche	21.3855745475955317	-157.946360512797156
33651	2020-06-27 15:07:03	2020-06-27	Dr. Bobbie Kilback Sr.	dr.bobbie.kilback.sr.@geemail.com	San Bernardino	California	4964645535866731	e1346004a35f769598752772f350575c	Diners Club / Carte Blanche	34.2143680274285344	-117.336787869200478
33652	2020-06-27 15:15:05	2020-06-27	Paulo Carroll	paulo.carroll@geemail.com	New York	New York	503890118324327	394f23c3af0b3f47f98ff6cc5646472f	Discover	40.7201694529261431	-74.0117986290145637
33653	2020-06-27 15:22:14	2020-06-27	Mr. Javion Kuvalis	mr.javion.kuvalis@geemail.com	Long Beach	California	676153712774784	48be63065e48c16b60cd62e685803982	VISA 16 digit	33.8617130690075427	-118.177431218016139
33654	2020-06-27 15:26:16	2020-06-27	Jefferey Ortiz	jefferey.ortiz@geemail.com	Sandy Springs	Georgia	4167102821735902	649c15a3800233a509a3c65bbf29d0ce	Diners Club / Carte Blanche	33.9331494706273062	-84.3810804806731625
33655	2020-06-27 15:37:33	2020-06-27	Cain Sanford DVM	cain.sanford.dvm@woohoo.com	Raleigh	North Carolina	4688382193789295	6c76e3f27d17b3b2e4acfb67acd3315e	Diners Club / Carte Blanche	35.7511761922523377	-78.6645673708926978
33656	2020-06-27 15:37:39	2020-06-27	Cap Powlowski	cap.powlowski@woohoo.com	San Diego	California	3042756402148618	ed4b30099f88d483bd2240259e1dd3c1	Voyager	32.8066900601677602	-117.142125528762122
33657	2020-06-27 15:44:04	2020-06-27	Samson Zieme	samson.zieme@geemail.com	Houston	Texas	6011582363442085369	af720014d3ed8674847f09e884df9c31	Mastercard	29.8599568075578645	-95.48755722358041
33658	2020-06-27 15:45:32	2020-06-27	Andria Cronin	andria.cronin@geemail.com	San Francisco	California	55446227944387233	0f40e203d3c3a6cd54fef39d75d5bda8	Mastercard	37.7624423059699978	-122.443536272125186
33659	2020-06-27 15:49:34	2020-06-27	Kevon Lueilwitz	kevon.lueilwitz@woohoo.com	Charleston	South Carolina	3040140112723949	06d6fc58ba89281c4f824089435530ab	Maestro	32.827524710865319	-79.9894962539579808
33660	2020-06-27 16:20:43	2020-06-27	Mrs. Buelah Stehr DDS	mrs.buelah.stehr.dds@geemail.com	Palm Bay	Florida	869996251341938706	467f5867f0655514b2695e4d1566a7a7	JCB 16 digit	27.9180777018744521	-80.5892043312381929
33661	2020-06-27 16:21:23	2020-06-27	Dr. Lynn McCullough	dr.lynn.mccullough@woohoo.com	Dallas	Texas	53999925573094860	138b02a1fd9603e6547f338bf0cad904	Mastercard	32.8143795986466102	-96.6820618696473417
33662	2020-06-27 16:22:56	2020-06-27	Dr. Kiyoko Connelly MD	dr.kiyoko.connelly.md@geemail.com	Kansas City	Kansas	3088325843136820322	56d51e7e0261879bc78677c0122d8e7e	American Express	39.0275129754468821	-94.8416842678498426
33663	2020-06-27 16:25:38	2020-06-27	Genevra Hackett	genevra.hackett@geemail.com	San Jose	California	3112120869434524511	2c527a731d0770ea47be77d4278a689e	VISA 16 digit	37.212812917289142	-121.915773394586139
33664	2020-06-27 16:29:39	2020-06-27	Jacque Davis	jacque.davis@geemail.com	Santa Maria	California	52395543530994237	cd49a8db9ff1d63e481d3a150a089f54	Diners Club / Carte Blanche	35.0039763643935302	-120.493860209538781
33665	2020-06-27 16:33:08	2020-06-27	Sheila Goldner	sheila.goldner@woohoo.com	San Francisco	California	3037427208108587	0da683448cb0a1e41c207e0958b37833	VISA 16 digit	37.8124742840178101	-122.44373995832639
33666	2020-06-27 16:37:49	2020-06-27	Enrico Pfeffer	enrico.pfeffer@geemail.com	Los Angeles	California	6011006749864368002	7668460841c6261d97b14a2f05754f94	VISA 16 digit	33.9196094287425254	-118.391142352204014
33667	2020-06-27 16:46:56	2020-06-27	Fitzhugh Yundt III	fitzhugh.yundt.iii@geemail.com	San Francisco	California	3158150823655533241	a5659dd65ab6394d74330346fd18d6d2	Voyager	37.7542047359031372	-122.425465781462748
33668	2020-06-27 16:57:40	2020-06-27	Dr. Salome Wehner	dr.salome.wehner@geemail.com	Baltimore	Maryland	55427316888809667	b945ad2967f9aa570bab531f4c3dd722	Maestro	39.2264488441403927	-76.5240994977317825
33669	2020-06-27 17:00:06	2020-06-27	Glendon Kemmer	glendon.kemmer@geemail.com	Columbus	Georgia	561274772059312	f764173ad203117948b5b8b5159ca62b	Diners Club / Carte Blanche	32.5346128563906944	-84.8553285387508538
33670	2020-06-27 17:09:11	2020-06-27	Gail Hudson	gail.hudson@geemail.com	San Francisco	California	55648031901007719	c9cafd8d8be58ab4eec36706bb197aee	VISA 16 digit	37.8124751511455131	-122.411007502561361
33671	2020-06-27 17:17:22	2020-06-27	Norbert Hauck	norbert.hauck@geemail.com	Savannah	Georgia	4356195020361307	7b48a3040f6f0a4f0d362e85b9efa5b4	VISA 16 digit	31.9301650206185847	-81.2033106332331869
33672	2020-06-27 17:18:52	2020-06-27	Jarrad Hilpert V	jarrad.hilpert.v@woohoo.com	San Mateo	California	675948217756179	782ceee8f7130ddfef31c5f9386e609b	JCB 16 digit	37.4941108002208168	-122.293403763588884
33673	2020-06-27 17:23:24	2020-06-27	Marinda Erdman	marinda.erdman@geemail.com	Tucson	Arizona	3017002805068474	a0fa9cd3e6eff630884261293e25fda2	JCB 16 digit	32.0831785693805713	-110.855572781827675
33674	2020-06-27 17:30:55	2020-06-27	Arland Jerde	arland.jerde@geemail.com	San Francisco	California	3000564482150021	b24c873731d9ada9f2404579f81033e5	JCB 16 digit	37.7636116989489494	-122.440096651560893
33675	2020-06-27 17:36:12	2020-06-27	Chandler Abernathy-Stoltenberg	chandler.abernathy.stoltenberg@geemail.com	Wichita	Kansas	4558210980071	94611b1a12a778104519910636361975	Mastercard	37.7243874444503362	-97.4381144406940791
33676	2020-06-27 17:36:15	2020-06-27	Dorris Hoppe V	dorris.hoppe.v@warmmail.com	Boise	Idaho	3158772339577750100	e81e30c0732bfb075dc00488cf10105f	Maestro	43.6541316143840561	-116.224798638905213
33677	2020-06-27 17:44:39	2020-06-27	Miss Carley Kertzmann DDS	miss.carley.kertzmann.dds@geemail.com	Dallas	Texas	3088818140601386226	f84c2f5f7b145d83807e1ca68ff45214	JCB 16 digit	32.7237125903639949	-96.821993776779621
33678	2020-06-27 17:48:53	2020-06-27	Cole Zboncak	cole.zboncak@geemail.com	San Diego	California	55639079654709743	75cb294466ae7cd3a45398d6e56616db	Voyager	32.8946888613116002	-117.122842475296935
33679	2020-06-27 17:58:10	2020-06-27	Dr. Torrie Dach	dr.torrie.dach@warmmail.com	Anchorage	Alaska	6011430598966789615	1117d926a672ed2f3b6627ce9764c47a	VISA 16 digit	61.1934270210780227	-149.34620287815406
33680	2020-06-27 18:00:38	2020-06-27	Felicia Hickle-Ankunding	felicia.hickle.ankunding@geemail.com	Baltimore	Maryland	3703685364702766	b72ba486dc2f0e4a5c89bc96e0fc24a2	Mastercard	39.2589386596810073	-76.6139058358520231
33681	2020-06-27 18:01:59	2020-06-27	Lucina Adams-Ankunding	lucina.adams.ankunding@geemail.com	Oklahoma City	Oklahoma	3337166421608675904	6894f6a2aa64e6c551af0f297d38bb99	Mastercard	35.5040335741270354	-97.5788049758773326
33682	2020-06-27 18:03:52	2020-06-27	Linnie Schmeler DDS	linnie.schmeler.dds@warmmail.com	Oklahoma City	Oklahoma	869971582541478344	ac459ca7f4ade4c1b685c1111c48f067	Maestro	35.3895957616534105	-97.5814049370482621
33683	2020-06-27 18:04:55	2020-06-27	Rodrick Nader	rodrick.nader@geemail.com	Springfield	Missouri	210091951849938000	5a08f1b490e1b723268691e3caa6c7fb	American Express	37.2014921616490923	-93.3138966969970625
33684	2020-06-27 18:09:33	2020-06-27	Nichol Wehner	nichol.wehner@geemail.com	Anaheim	California	6011406722522426559	1705933fd07859dc0af3a8e639db1f46	Mastercard	33.9140386041086188	-117.798965467254064
33685	2020-06-27 18:11:17	2020-06-27	Verona Tillman	verona.tillman@warmmail.com	Denver	Colorado	869932719666129322	e31e7fa178db47d107a4635cfa7ad132	JCB 16 digit	39.7984206297486978	-104.843228193164251
33686	2020-06-27 18:19:56	2020-06-27	Dr. Lucas Ankunding DDS	dr.lucas.ankunding.dds@geemail.com	Miami	Florida	6011753723655951297	c8df66ebca3ccdcfad260933b46377bb	VISA 16 digit	25.7273852199919553	-80.212071205150707
33687	2020-06-27 18:23:35	2020-06-27	Cailyn Tillman-Bauch	cailyn.tillman.bauch@geemail.com	Chula Vista	California	869997706914468216	1c115608c73005a3709f2632f8664307	JCB 16 digit	32.6828444686017932	-116.956439541396492
33688	2020-06-27 18:24:01	2020-06-27	Ted Schamberger Jr.	ted.schamberger.jr.@warmmail.com	Milwaukee	Wisconsin	54681146697712815	8e633997f543816b422af54f96b9fbb5	American Express	43.0552241152238082	-87.9277831310506883
33689	2020-06-27 18:37:29	2020-06-27	Windell Bashirian	windell.bashirian@geemail.com	Berkeley	California	561284584844074	4a38d311cf37b2b437b328e39cb244fa	VISA 13 digit	37.8346093473403187	-122.259933264143513
33690	2020-06-27 18:40:53	2020-06-27	Dr. Gabe Hegmann	dr.gabe.hegmann@geemail.com	Aurora	Illinois	53410761243364701	cce18c1958b5d03acac1c1753d2c966c	Mastercard	41.7938636366967131	-88.3505843421839074
33691	2020-06-27 18:45:49	2020-06-27	Albina Schowalter	albina.schowalter@geemail.com	Lexington	Kentucky	4941164599499767	cd3b208251acc11c9f254698be72d8f8	JCB 16 digit	37.9490555521443511	-84.5285889201231271
33692	2020-06-27 18:46:23	2020-06-27	Pauletta Herzog	pauletta.herzog@geemail.com	Centennial	Colorado	51063712295936383	1a2aa8814986406e353350119e043ba0	JCB 15 digit	39.4946944742970203	-104.848801026948166
33693	2020-06-27 18:58:32	2020-06-27	Hettie Welch DVM	hettie.welch.dvm@geemail.com	Louisville	Kentucky	503818152960805	bc66e408609d63ae7318e3a895b8599f	Mastercard	38.1542413033448113	-85.6840163946222617
33694	2020-06-27 19:16:01	2020-06-27	Jack Windler-Baumbach	jack.windler.baumbach@geemail.com	Kansas City	Missouri	869942114053578794	19085a289ffc3582964eeb95f8e2836c	JCB 16 digit	39.0788447731010677	-94.5393891906589232
33695	2020-06-27 19:19:39	2020-06-27	Almeta Steuber	almeta.steuber@woohoo.com	Glendale	Arizona	3088981036734180349	5d7c2b7dd8f6de1dbdd765ec01be9633	Diners Club / Carte Blanche	33.5428395336255392	-112.258758868116502
33696	2020-06-27 19:23:37	2020-06-27	Norton Mueller	norton.mueller@woohoo.com	Hayward	California	53420268477407519	0c9c3e607a5be96061562847d8febca8	VISA 13 digit	37.6250897315785338	-122.182707218246165
33697	2020-06-27 19:37:28	2020-06-27	Dr. Verl Berge Sr.	dr.verl.berge.sr.@woohoo.com	San Mateo	California	6011286326317569105	8884016106801e152b61b57b89ac592e	Maestro	37.6300001887951012	-122.38723871590048
33698	2020-06-27 19:39:43	2020-06-27	Benjiman Cassin II	benjiman.cassin.ii@geemail.com	San Francisco	California	4360821255036553	24af592516761f10209802e7fc93fc09	Diners Club / Carte Blanche	37.8030001475434148	-122.43455298651304
33699	2020-06-27 19:43:38	2020-06-27	Ceasar Hegmann Sr.	ceasar.hegmann.sr.@warmmail.com	San Jose	California	4144740169780	c887255744999c5e723ab39ccfc39fbe	VISA 16 digit	37.3913066778618841	-121.853541827084129
33700	2020-06-27 19:57:23	2020-06-27	Zander White	zander.white@warmmail.com	San Diego	California	3473304230541078	5a7afe8514c1ea59996baa1a6664d492	JCB 16 digit	32.7909139936856917	-117.176898981807753
33701	2020-06-27 20:00:09	2020-06-27	Debora Ernser	debora.ernser@warmmail.com	Frisco	Texas	3033725082712075	8bbf47a19cefa54764238ce4c851cf1c	Diners Club / Carte Blanche	33.170809402595836	-96.7332126247905109
33702	2020-06-27 20:03:44	2020-06-27	Kameron Wunsch	kameron.wunsch@geemail.com	Virginia Beach	Virginia	869905298011742207	17beb58ebe3ab469793b457c03667d85	VISA 16 digit	36.8252252052258697	-76.0001750935938247
33703	2020-06-27 20:27:24	2020-06-27	Reilly Kreiger	reilly.kreiger@geemail.com	St. Petersburg	Florida	6011289483618811004	43bd8ed7081adaaf4462252aa98e9939	VISA 13 digit	27.6740773551519972	-82.7372182312313385
33704	2020-06-27 20:34:13	2020-06-27	Hideo Wiegand	hideo.wiegand@geemail.com	Berkeley	California	3481160829105125	3d6fd4c5938c3c598f91d34e7c5aad53	VISA 13 digit	37.8616116437722425	-122.259040975559586
33705	2020-06-27 20:46:33	2020-06-27	Marty Mosciski	marty.mosciski@woohoo.com	Louisville	Kentucky	4312928762616485	9fbd11ceec4da7cc0fde52c6ba291631	Diners Club / Carte Blanche	38.0772258732371043	-85.7092170801084592
33706	2020-06-27 20:51:18	2020-06-27	Essa Kling PhD	essa.kling.phd@geemail.com	San Francisco	California	3088472073369249103	045acb6620b9aa8abd0c6b1450ad792b	VISA 16 digit	37.8175114430991925	-122.441409110565942
33707	2020-06-27 20:52:41	2020-06-27	Dr. Simon Schulist	dr.simon.schulist@geemail.com	Yonkers	New York	4909538929607951	31c9ec6c5d95c882014326a9307b3afb	Voyager	41.0308110109265911	-73.8095757095493354
33708	2020-06-27 20:53:14	2020-06-27	Dr. Ennis Armstrong Sr.	dr.ennis.armstrong.sr.@woohoo.com	San Francisco	California	4525967611043	4a40a71bb81c23bb66f02e075c933012	Discover	37.7823798187743591	-122.43777617921576
33709	2020-06-27 21:04:27	2020-06-27	Acey Altenwerth	acey.altenwerth@geemail.com	Los Angeles	California	502045838272289	8049e4407676458e1550df97a222b696	JCB 16 digit	34.0720492485776489	-118.40720410495922
33710	2020-06-27 21:09:19	2020-06-27	Cara Russel-Doyle	cara.russel.doyle@woohoo.com	Scottsdale	Arizona	4493488747871	7d7668cff32fda8bc3c33aa0913b733e	JCB 16 digit	33.5958676519461008	-111.797951089075198
33711	2020-06-27 21:11:24	2020-06-27	Kierra Beier-Ernser	kierra.beier.ernser@geemail.com	Columbus	Ohio	3088231677596383014	a64d9b54497e180dfa63a3f102221724	VISA 16 digit	40.0334233006507176	-83.0178395570956269
33712	2020-06-27 21:31:20	2020-06-27	Arron VonRueden	arron.vonrueden@geemail.com	Lancaster	California	3158073842176365382	5c4d33c5644b58bd9f230b90bd68be62	Maestro	34.7421195433255292	-118.181526157024493
33713	2020-06-27 21:32:56	2020-06-27	Nestor McCullough	nestor.mccullough@warmmail.com	McKinney	Texas	3022352379058681	df0f040afb7a1fe535a615e536d95d6a	JCB 16 digit	33.1697253141682609	-96.7530406885612848
33714	2020-06-27 21:35:58	2020-06-27	Lemon Carter-Swift	lemon.carter.swift@warmmail.com	Chicago	Illinois	869936872744650649	9b986daf20987bca35d120addd4a09fd	Diners Club / Carte Blanche	41.823120064784213	-87.6158396062470928
33715	2020-06-27 21:40:24	2020-06-27	Dr. Nikia Windler	dr.nikia.windler@geemail.com	Carlsbad	California	3337971750823402255	8b8571d4ea069515aea1d9468bccb3f6	VISA 16 digit	33.1435680518798534	-117.225655779174716
33716	2020-06-27 21:46:56	2020-06-27	Julien Hills	julien.hills@geemail.com	Honolulu	Hawaii	6011810808349509477	e669258c3a5ddf140249a85a802f2caa	JCB 16 digit	21.3103162332188347	-157.753700681284442
33717	2020-06-27 21:51:12	2020-06-27	Cleora Bosco-Kunze	cleora.bosco.kunze@geemail.com	Salem	Oregon	54102215853828979	7dc42f08dd288823b26da224416d2b33	VISA 16 digit	44.9169713951915455	-122.929367419767004
33718	2020-06-27 21:53:51	2020-06-27	Julissa Gutmann PhD	julissa.gutmann.phd@geemail.com	Sterling Heights	Michigan	6011606936994002569	dd2b8a5302d0203fb18cdbeb08d16261	Mastercard	42.5836775823112603	-82.949517157782978
33719	2020-06-27 21:56:43	2020-06-27	Aiden Batz	aiden.batz@geemail.com	San Francisco	California	4203228227575	928d153cf948e55e0c79257ef4011d94	VISA 16 digit	37.7658091260672464	-122.400963040402743
33720	2020-06-27 22:15:02	2020-06-27	Collie Schiller	collie.schiller@woohoo.com	Rancho Cucamonga	California	3021062859357831	1118a959a683eac8bf08097ec9d880fd	Diners Club / Carte Blanche	34.0795620923388753	-117.611094512604922
33721	2020-06-27 22:19:44	2020-06-27	Ms. Amma Torp DDS	ms.amma.torp.dds@warmmail.com	Omaha	Nebraska	3112817084420441120	af74d33c14b4e9a31c818e8a0735d5d1	Maestro	41.2060510207112927	-96.1349006143979778
33722	2020-06-27 22:25:58	2020-06-27	Renita Schmidt	renita.schmidt@woohoo.com	Winston–Salem	North Carolina	4352177662429950	9aff29e1e386bf2c1e874e462666c744	JCB 16 digit	36.0265512100186172	-80.3537662947680786
33723	2020-06-27 22:34:56	2020-06-27	Author Ward I	author.ward.i@geemail.com	Lubbock	Texas	869994015336631473	909085a2d64cda64aa05aefeb6227aa1	JCB 16 digit	33.6620221674017657	-101.869728947422288
33724	2020-06-27 22:48:54	2020-06-27	Ashlea Rutherford	ashlea.rutherford@geemail.com	San Francisco	California	4662484723594888	c3f9eb401cfb52fe050b66367f0e1bcd	JCB 16 digit	37.7976926383385461	-122.426967726610357
33725	2020-06-27 22:51:24	2020-06-27	Kelsi Yundt DVM	kelsi.yundt.dvm@geemail.com	Los Angeles	California	52942131479715835	7195591cf68ced9c41da098a622bf0be	JCB 16 digit	34.1092189420811778	-118.42543929470628
33726	2020-06-27 23:04:02	2020-06-27	Anita Kiehn	anita.kiehn@geemail.com	Columbus	Ohio	3096077222672545108	552c620d12365562fbe50da5de4afa84	Mastercard	40.0382591135378902	-82.9903728762876369
33727	2020-06-27 23:05:19	2020-06-27	Tosha Kemmer-Cruickshank	tosha.kemmer.cruickshank@geemail.com	Yonkers	New York	4700614783823306	ce779b33c6a56fb492967aa44eb5b9ae	JCB 16 digit	40.8988392846859981	-73.8998256987310924
33728	2020-06-27 23:07:24	2020-06-27	Sabastian Kling-Crona	sabastian.kling.crona@geemail.com	San Francisco	California	3471346652596975	709b5902148bf7bbb524f59a42736d91	Diners Club / Carte Blanche	37.7483565688494664	-122.428104867388768
33729	2020-06-27 23:16:12	2020-06-27	Darvin Huels	darvin.huels@warmmail.com	San Diego	California	4809749625680710	413c62ec70caaed9f761a6c578af8789	Mastercard	32.8929189241092672	-117.048549409201371
33730	2020-06-27 23:23:43	2020-06-27	Renata Kemmer	renata.kemmer@geemail.com	San Francisco	California	3450922460062445	2885597fe67835e6c001e512aef3c6a4	Discover	37.7865776358361956	-122.413887987740992
33731	2020-06-27 23:29:08	2020-06-27	Domingo Lockman V	domingo.lockman.v@warmmail.com	Torrance	California	6011195044028440876	223ff1bac6a5c64b471811b88007975a	VISA 16 digit	33.9099111323617421	-118.30153326193205
33732	2020-06-27 23:42:05	2020-06-27	Delton Lynch	delton.lynch@geemail.com	Oakland	California	589320151501804	742d7d01c811fa2ccc858b94efb8d38e	Mastercard	37.7932481382608145	-122.289708438338025
33733	2020-06-27 23:47:12	2020-06-27	Bailee McLaughlin	bailee.mclaughlin@warmmail.com	Chicago	Illinois	3096823774846773880	1b8a53006ae817f65a2fe7c16d6d1622	JCB 16 digit	41.8681875337682712	-87.7619906493026747
33734	2020-06-27 23:50:50	2020-06-27	Lady Conn	lady.conn@geemail.com	San Antonio	Texas	51770891149740839	89fca51420857f1950e15afb694e997f	Diners Club / Carte Blanche	29.4558815693087865	-98.56331547585539
33735	2020-06-28 00:02:07	2020-06-28	Knox Oberbrunner	knox.oberbrunner@geemail.com	Louisville	Kentucky	4987249432079	9688df3c75a7df9a4349c14e62a79fc3	JCB 15 digit	38.2367714006356891	-85.6148220925197023
33736	2020-06-28 00:03:18	2020-06-28	Finn Wunsch	finn.wunsch@geemail.com	Honolulu	Hawaii	4825857449729884	9c8f67ecb4144bb15e083d414c7807cb	American Express	21.3023511006247261	-157.766975065248459
33737	2020-06-28 00:07:53	2020-06-28	Bettylou Wintheiser DVM	bettylou.wintheiser.dvm@geemail.com	Berkeley	California	3441582868325356	fff77d1f0217c6efecd3422d7ca933a7	JCB 15 digit	37.890620987114211	-122.289616915930992
33738	2020-06-28 00:07:59	2020-06-28	Mr. Isadore Mosciski	mr.isadore.mosciski@woohoo.com	Chicago	Illinois	869946055698767738	80200d9bb58587ba91e630852c4f1751	VISA 16 digit	41.8374096299357703	-87.7712426271784949
33739	2020-06-28 00:08:06	2020-06-28	Laquita Nitzsche	laquita.nitzsche@geemail.com	Santa Ana	California	3096001507404312442	ee70b636a9cadc057ba42f1e28a5c8e0	JCB 15 digit	33.8085087876405552	-117.859746239699419
33740	2020-06-28 00:08:16	2020-06-28	Erland Connelly	erland.connelly@geemail.com	Riverside	California	676232141397615	ca149b56a7fff33bf396fc68541608c5	Maestro	33.9011538489203872	-117.353632134987777
33741	2020-06-28 00:13:17	2020-06-28	Miss Bernetta Funk PhD	miss.bernetta.funk.phd@geemail.com	Eugene	Oregon	4858034068446	98158e9873da91a8b6f20c3e9f864f61	Diners Club / Carte Blanche	44.0521341798555071	-123.027921914168459
33742	2020-06-28 00:15:26	2020-06-28	Layla Goodwin	layla.goodwin@warmmail.com	Anaheim	California	3036935679342254	308430e4545f9bd97a652f946bb93d12	JCB 16 digit	33.8584436399694511	-117.705593322471145
33743	2020-06-28 00:16:37	2020-06-28	Gaston Douglas	gaston.douglas@geemail.com	Denton	Texas	3337232004936396730	5972929bf856be7717c48d22f3e94566	JCB 16 digit	33.2836078197028513	-97.1193373638331963
33744	2020-06-28 00:17:50	2020-06-28	Denzil Gulgowski DVM	denzil.gulgowski.dvm@geemail.com	San Francisco	California	3020359035446285	bd208ee183562aaee622f1fc3399a880	Discover	37.7675752838639625	-122.427362878633701
33745	2020-06-28 00:18:01	2020-06-28	Benji Schinner-Barton	benji.schinner.barton@geemail.com	Phoenix	Arizona	3492663929286643	1b76a8203b6e952a258a79f5a7ec622b	American Express	33.484934019476924	-112.081711092584214
33746	2020-06-28 00:20:18	2020-06-28	Mat Mueller	mat.mueller@geemail.com	Manchester	New Hampshire	3158512372575612514	9ed2bfa27fcb039e9d3eb3216da211f4	JCB 16 digit	42.942511126545817	-71.4552117344815372
33747	2020-06-28 00:25:55	2020-06-28	Ira Shanahan	ira.shanahan@geemail.com	San Francisco	California	6011988057473469456	e09318b33836b5482adec9968a700fe8	JCB 16 digit	37.7799159383448924	-122.426982965984962
33748	2020-06-28 00:33:27	2020-06-28	Lilliana Jaskolski-Mante	lilliana.jaskolski.mante@geemail.com	Los Angeles	California	3040052623792240	7952af6a6ceb3f49aeeca14b44c193be	VISA 13 digit	34.1142046942707111	-118.429343408811093
33749	2020-06-28 00:35:18	2020-06-28	Barbara Predovic-Sauer	barbara.predovic.sauer@warmmail.com	San Francisco	California	6011611004165658082	c3ac48b3b2b69d747553b5e492747fea	Maestro	37.7687024426100422	-122.432297738866126
33750	2020-06-28 00:46:15	2020-06-28	Adah Dach	adah.dach@warmmail.com	Rancho Cucamonga	California	869974899509529125	f79dc3d43971ded7c78929602ddd2aa3	JCB 16 digit	34.0774324479971114	-117.598814986740052
33751	2020-06-28 00:46:42	2020-06-28	Sheyla Prosacco	sheyla.prosacco@warmmail.com	San Francisco	California	4207760374968	49ca1951c91fc595c6a81981d860e6af	American Express	37.7926547133276571	-122.406319826788589
33752	2020-06-28 00:47:36	2020-06-28	Marian Zemlak	marian.zemlak@geemail.com	Milwaukee	Wisconsin	210092272628701579	6b099f1f3e108a043811e3b7b850d094	Mastercard	43.1054354143414642	-87.9188972370799604
33753	2020-06-28 00:49:08	2020-06-28	Cas Mann	cas.mann@woohoo.com	Wichita Falls	Texas	4548451780678581	7491d0e4792bde5d22d1a0d6178f4bbc	VISA 16 digit	33.8783060114093146	-98.6178781979173351
33754	2020-06-28 00:49:14	2020-06-28	Neil Rosenbaum III	neil.rosenbaum.iii@woohoo.com	Portland	Oregon	3754896274158316	6e5cf25ff8df26e09096d9b49d1f17d5	American Express	45.462524056749416	-122.707326705567539
33755	2020-06-28 00:52:14	2020-06-28	Karim Johnston	karim.johnston@geemail.com	Miami	Florida	4004503925184	ff299a86cb09d204a4bb691a8bea83ad	VISA 13 digit	25.8152013876613253	-80.133286534283684
33756	2020-06-28 00:55:18	2020-06-28	Nevaeh Pouros	nevaeh.pouros@geemail.com	Rancho Cucamonga	California	180079528526708785	a09263db841be341da46eda4900ac3f3	Voyager	34.1675127060610819	-117.497479995573684
33757	2020-06-28 01:05:46	2020-06-28	Brinda Rippin	brinda.rippin@geemail.com	San Francisco	California	3007699061931533	9d7a305773c826c54d7a08d68079d7af	VISA 16 digit	37.7708409037045101	-122.438666348688741
33758	2020-06-28 01:10:04	2020-06-28	Lexis Friesen	lexis.friesen@geemail.com	San Francisco	California	4868782508006	2ac1cd98aa815791b9a2e77a13d4171e	JCB 16 digit	37.7897315601061905	-122.423888808568393
33759	2020-06-28 01:27:35	2020-06-28	Verdie Osinski-Russel	verdie.osinski.russel@geemail.com	New York	New York	54478326712117714	859e0982361694b51fec81addf69fb2c	Voyager	40.6667846704125395	-74.015851622250679
33760	2020-06-28 01:40:04	2020-06-28	Lindsey Brekke-Koss	lindsey.brekke.koss@geemail.com	Newport News	Virginia	3029435587416024	91bc314553e46a555f748d1ad8042322	Voyager	37.1418299904920133	-76.4381491927690888
33761	2020-06-28 01:41:09	2020-06-28	Porter Ledner	porter.ledner@geemail.com	Los Angeles	California	4546815424353425	83c3d75f65c9c06742516b4431d75fcc	VISA 16 digit	33.9297909216355507	-118.416569958579913
33762	2020-06-28 01:51:01	2020-06-28	Rishi Oberbrunner-Rutherford	rishi.oberbrunner.rutherford@geemail.com	Kenosha	Wisconsin	3726560125953284	1cd0db1bd1a8d196970e2bba32035a23	Discover	42.4908746038403393	-87.8112095532234775
33763	2020-06-28 01:51:54	2020-06-28	Delpha Crist-Cassin	delpha.crist.cassin@geemail.com	Lansing	Michigan	4327012739559954	6c7b45ccbd247ed62aeb71eb58f0a1c8	VISA 13 digit	42.7017518844764723	-84.6541871155269376
33764	2020-06-28 02:11:49	2020-06-28	Brianne Koelpin	brianne.koelpin@geemail.com	Sandy Springs	Georgia	3029465161543679	a17baac3e5e02d25ea9eb8074fb4f6a6	Discover	34.0278948589749604	-84.2753604826599343
33765	2020-06-28 02:13:36	2020-06-28	Aria Streich	aria.streich@woohoo.com	Plano	Texas	180056595993839721	81c9738eb86d72f4f88d48f0577569f7	Diners Club / Carte Blanche	33.0508740199349873	-96.8348258840568406
33766	2020-06-28 02:19:04	2020-06-28	Kanisha Conroy	kanisha.conroy@geemail.com	Moreno Valley	California	180040109599870285	5c1ef14a6f2fbffabf69528cf34890d6	Discover	33.9344761420965142	-117.149395180956262
33767	2020-06-28 02:25:03	2020-06-28	Ms. Kayleigh McLaughlin	ms.kayleigh.mclaughlin@geemail.com	Memphis	Tennessee	3158880182770954874	f962da734c781113e8777f2a00a0ab1b	Diners Club / Carte Blanche	35.0949241676434909	-90.0144912014506815
33768	2020-06-28 02:26:16	2020-06-28	Eduardo Grimes	eduardo.grimes@geemail.com	Houston	Texas	210072732933070154	3a4a64b93242a6a25e83a93e49ff1540	VISA 13 digit	29.7348863709330544	-95.3137252930566632
33769	2020-06-28 02:30:13	2020-06-28	Carroll Yundt	carroll.yundt@woohoo.com	Fort Worth	Texas	53293226916422626	4b96253b4c681d6a94dc2fde72e1edcf	VISA 13 digit	32.8776798009928299	-97.3956839596208113
33770	2020-06-28 02:31:30	2020-06-28	Renard Braun	renard.braun@geemail.com	Kenosha	Wisconsin	869904755526899419	1c8a5ebaa40c7d553786e8aecdbe68ee	Diners Club / Carte Blanche	42.6534145667523177	-87.8673735507059916
33771	2020-06-28 02:34:59	2020-06-28	Vincent Ondricka-Parisian	vincent.ondricka.parisian@warmmail.com	Baltimore	Maryland	3466406973894280	a780979a49fae5ac71e942aa9becd945	JCB 15 digit	39.2612558647990184	-76.6301021790150543
33772	2020-06-28 02:36:41	2020-06-28	Wong Daugherty-Kemmer	wong.daugherty.kemmer@woohoo.com	Las Vegas	Nevada	4052186914205228	05d5a188b6f864f62a3dd4f556412ef3	Maestro	36.1457040998253945	-115.265554105604437
33773	2020-06-28 02:37:22	2020-06-28	Kris Batz	kris.batz@warmmail.com	Houston	Texas	3720986941971919	6e29951ad86594730e9dfc24376b1293	Voyager	29.7587425657160587	-95.3421766825035206
33774	2020-06-28 02:38:28	2020-06-28	Mr. Jamison Hickle	mr.jamison.hickle@warmmail.com	Jacksonville	Florida	6011365506812666720	8d9affd98acfd8945f2c10ee5f40af33	American Express	30.3655233325954512	-81.6840099248647817
33775	2020-06-28 02:38:37	2020-06-28	Jacalyn Hahn-Sanford	jacalyn.hahn.sanford@geemail.com	Elizabeth	New Jersey	561290211389128	f82dc1701f75b331ae10264251aa9578	Voyager	40.6490251675840497	-74.2415277381371652
33776	2020-06-28 02:42:38	2020-06-28	Miss Tonja Rodriguez	miss.tonja.rodriguez@woohoo.com	Chicago	Illinois	4838323293884072	714e29d849943b39b50d6e01a16f934b	Discover	41.8193873087711623	-87.6028108152124929
33777	2020-06-28 02:42:56	2020-06-28	Mr. Jacques Hilpert	mr.jacques.hilpert@geemail.com	Los Angeles	California	675911559826083	71ea9497553f2683cc0f73d0a5761bfa	Diners Club / Carte Blanche	34.0796048582397404	-118.481575033207605
33778	2020-06-28 02:51:21	2020-06-28	Tyler Greenfelder DVM	tyler.greenfelder.dvm@geemail.com	El Paso	Texas	4024319439030	dcba9d178fa9f915497c146096fc06a1	VISA 16 digit	31.803100131015853	-106.327422825897116
33779	2020-06-28 02:57:15	2020-06-28	Ms. Ebony Fahey DDS	ms.ebony.fahey.dds@geemail.com	Chandler	Arizona	3096001116308315996	2fccb906d32e3f99ef9c5df3cad2ac02	American Express	33.3562318520709837	-111.849451570573819
33780	2020-06-28 03:02:15	2020-06-28	Jaimee Doyle MD	jaimee.doyle.md@geemail.com	Los Angeles	California	503859927499778	b8cadea2e5765d96d1baa9fd9d3c393b	JCB 16 digit	34.1139165019016701	-118.321087375235919
33781	2020-06-28 03:03:53	2020-06-28	Damarion Feeney	damarion.feeney@geemail.com	Raleigh	North Carolina	4784396608738	6dbcfc7b1d6a5972f49a2c323139de6e	Diners Club / Carte Blanche	35.7680575429130343	-78.6685373314127361
33782	2020-06-28 03:05:08	2020-06-28	Kelsi Rutherford-Osinski	kelsi.rutherford.osinski@geemail.com	San Francisco	California	4552811640873768	2685875628375c487a8b58ea98587ebb	VISA 16 digit	37.7732817155408256	-122.439362845652397
33783	2020-06-28 03:09:02	2020-06-28	Jessie Von	jessie.von@warmmail.com	Phoenix	Arizona	4802254101890013	39394449f54869ce271e1bd9a1f2e113	Discover	33.5431109644405581	-112.11751002086551
33784	2020-06-28 03:11:27	2020-06-28	Dejah Lindgren	dejah.lindgren@geemail.com	Chicago	Illinois	3528238742774927637	6fff01a9c4ac6537b8a6ca485e70f30f	JCB 16 digit	41.9124168854042907	-87.6125137406431094
33785	2020-06-28 03:21:35	2020-06-28	Marget Barrows-Kiehn	marget.barrows.kiehn@geemail.com	Sparks	Nevada	51971565459523152	1e2dffec3db4db6ca6d4838d59d563a5	JCB 16 digit	39.6065463572979013	-119.826274606012191
33786	2020-06-28 03:29:22	2020-06-28	Miss Louanna Turner MD	miss.louanna.turner.md@woohoo.com	Irving	Texas	3337924513100292841	0bdad12490154e413f9e8ccaa6d35f93	Diners Club / Carte Blanche	32.7745567629065349	-96.9006898708920943
33787	2020-06-28 03:33:01	2020-06-28	Mr. Jakob Stoltenberg II	mr.jakob.stoltenberg.ii@geemail.com	Miami	Florida	210043244435440261	e5e9c3c0d5cd9e4d3a89315fff563dfd	American Express	25.8300269602935764	-80.1192042625848302
33788	2020-06-28 03:43:11	2020-06-28	Jamari Fritsch	jamari.fritsch@geemail.com	New Haven	Connecticut	210077867490213162	9182877490c6e9022c3c80af4ebb13dd	VISA 16 digit	41.3269084468476464	-72.8851101325359139
33789	2020-06-28 03:50:19	2020-06-28	Nedra Wunsch	nedra.wunsch@woohoo.com	Cape Coral	Florida	3096106675922634508	072fbab356a7a07cc5aee9f02c818072	JCB 16 digit	26.6051507568888361	-81.9936708558421543
33790	2020-06-28 03:53:26	2020-06-28	Isamar Morissette-Champlin	isamar.morissette.champlin@geemail.com	Santa Ana	California	589330029351142	c4549ac756520304682161ea605f0644	Discover	33.7696954128436744	-117.962696227936064
33791	2020-06-28 03:59:39	2020-06-28	Belen Kuhic DVM	belen.kuhic.dvm@geemail.com	Knoxville	Tennessee	675941555884943	4cad8e41061c10605a9b7771e1bf312a	Maestro	35.8978162523888074	-83.9452756313823159
33792	2020-06-28 04:08:10	2020-06-28	Dr. Val Wyman Sr.	dr.val.wyman.sr.@geemail.com	Pasadena	Texas	52899307480798399	23d3f94b50dd1b6943189c3e529e51f4	Maestro	29.6034922872543333	-95.1653221764083952
33793	2020-06-28 04:12:46	2020-06-28	Mr. Raleigh Roberts	mr.raleigh.roberts@warmmail.com	Las Vegas	Nevada	53415864265360709	4fcd72af732eff77b7517470363bfeb6	Voyager	36.2005710676412988	-115.222505276671043
33794	2020-06-28 04:15:42	2020-06-28	Trever Hagenes	trever.hagenes@woohoo.com	Oakland	California	3112190937396123799	aa3b2b7bcdf3b5628d7dd0b8ebe8e162	Maestro	37.8239141679523314	-122.293384542556666
33795	2020-06-28 04:26:35	2020-06-28	Lue Schmidt	lue.schmidt@woohoo.com	Sunnyvale	California	869910844419665871	0477f62c55a04beffeef85884975a8c7	American Express	37.3430275719605405	-122.073941642671087
33796	2020-06-28 04:29:02	2020-06-28	Sue Ortiz	sue.ortiz@geemail.com	New York	New York	210013352195027487	12494eb587458c78deadbf79e5a41214	JCB 15 digit	40.7044914278425267	-73.9614468437980861
33797	2020-06-28 05:02:12	2020-06-28	Orion Friesen	orion.friesen@warmmail.com	New York	New York	3715570102476988	c449ceb4eca3faf4cec1765c555108bb	JCB 16 digit	40.6111478911470627	-73.8978355463955552
33798	2020-06-28 05:08:31	2020-06-28	Perri Steuber	perri.steuber@woohoo.com	Oakland	California	3781250159253072	f463496c8dc6c0054df265f199100552	VISA 16 digit	37.7859015784340428	-122.277069054571768
33799	2020-06-28 05:11:33	2020-06-28	Raleigh Leuschke II	raleigh.leuschke.ii@woohoo.com	Glendale	Arizona	55868209796798914	07504c71af8ad7136efacd36799ea58a	VISA 13 digit	33.60980083357952	-112.280516439050061
33800	2020-06-28 05:17:47	2020-06-28	Zavier Brown PhD	zavier.brown.phd@woohoo.com	Inglewood	California	180084779466665435	01829a7f824910aea0d90567f77141ed	Diners Club / Carte Blanche	33.9834172673769288	-118.429746707066158
33801	2020-06-28 05:21:22	2020-06-28	Ms. Cameron Howe	ms.cameron.howe@geemail.com	Los Angeles	California	3025135007308538	e58a1b1c65922278b0f9f2f9a0ffb582	Maestro	34.0175192330364098	-118.357180922431127
33802	2020-06-28 05:22:16	2020-06-28	Jordy Hermiston III	jordy.hermiston.iii@geemail.com	New York	New York	589334756189352	de29fd6eb584dd77bcb47a8529cdcf26	JCB 16 digit	40.6699549666363751	-74.0248228135414337
33803	2020-06-28 05:26:59	2020-06-28	Isabel Bogisich	isabel.bogisich@geemail.com	West Valley City	Utah	3528523815138765663	23fc632ce6c96a101691d323be718601	American Express	40.6035017415173343	-111.992463611972696
33804	2020-06-28 05:34:54	2020-06-28	Miss Shyla Prosacco DDS	miss.shyla.prosacco.dds@geemail.com	Tempe	Arizona	589395524245636	4397fe47556f0d4f6688dd447dd59d7f	Diners Club / Carte Blanche	33.3846820409331428	-111.908262893374257
33805	2020-06-28 05:41:01	2020-06-28	Lesli Beer	lesli.beer@warmmail.com	Orlando	Florida	3112278801234841282	c3f2fc4eff67ee23e06e88f4cf8b2e65	Discover	28.3744395618591447	-81.3072896784137953
33806	2020-06-28 05:54:19	2020-06-28	Fredie Lehner	fredie.lehner@woohoo.com	Peoria	Arizona	501848623476537	73b92d052db74eff917a85295faaa5ce	JCB 16 digit	33.8706158520456384	-112.208472682621334
33807	2020-06-28 05:57:40	2020-06-28	Jensen Kling	jensen.kling@woohoo.com	Sacramento	California	180061590783526797	2ffda2c383cb4d6b450f5fb6a40fa36e	Maestro	38.6049453878574056	-121.566090871371699
33808	2020-06-28 05:57:59	2020-06-28	Mr. Stuart Pouros	mr.stuart.pouros@geemail.com	New York	New York	52147945972032239	31d64ef30ebbf1273bcf6592e56ecdea	JCB 16 digit	40.6515542080383767	-73.8554439999524419
33809	2020-06-28 06:00:29	2020-06-28	Barney Rosenbaum	barney.rosenbaum@woohoo.com	Oxnard	California	4205367394369207	409c5f0f6685e74180aa3698b0521f5a	VISA 16 digit	34.2587510740805428	-119.250420097858083
33810	2020-06-28 06:01:28	2020-06-28	Pete Balistreri	pete.balistreri@woohoo.com	Milwaukee	Wisconsin	4424693937411	881f6f303f218ca31e1c9893c56d629f	Mastercard	43.0677506157748411	-88.0319543912641791
33811	2020-06-28 06:21:57	2020-06-28	Donat Konopelski PhD	donat.konopelski.phd@geemail.com	Santa Ana	California	501874755318214	937c76755d9bd2cdf4e89a87c8d8c5ca	VISA 16 digit	33.774387265845391	-117.806277837596824
33812	2020-06-28 06:27:14	2020-06-28	Claudio Waters-Cummerata	claudio.waters.cummerata@woohoo.com	Dallas	Texas	869986639577919709	d84d917e32fee2a052efaac6270bdfda	VISA 16 digit	32.7757491886887706	-96.7385096606295463
33813	2020-06-28 06:29:15	2020-06-28	Hosie Bartoletti	hosie.bartoletti@geemail.com	San Francisco	California	180042708944114279	78a502478abc12e7c3402f2d3cfaf6de	JCB 16 digit	37.7637277316649005	-122.445423792529027
33814	2020-06-28 06:43:30	2020-06-28	Mr. Tillman Hickle	mr.tillman.hickle@woohoo.com	Miami	Florida	51339937904164576	f7e47313568f547574a82d45abd29745	Mastercard	25.8596603693112748	-80.2428828663066014
33815	2020-06-28 06:59:46	2020-06-28	Dr. Windell Schumm II	dr.windell.schumm.ii@geemail.com	New York	New York	6011766358646841011	8b5ae6f88730a89d253a4201b842959f	VISA 16 digit	40.6658415232542865	-73.9330169958423795
33816	2020-06-28 07:03:47	2020-06-28	Alanzo Wiegand-Wolff	alanzo.wiegand.wolff@geemail.com	Murfreesboro	Tennessee	589322527499093	88a7ea7a6e23aec80f6caf2604c7228c	VISA 16 digit	35.887221321382377	-86.3838620463702824
33817	2020-06-28 07:14:04	2020-06-28	Villa Weber	villa.weber@geemail.com	New York	New York	4747177301596007	6c7b60cf8d853cc5332d3e0510489049	JCB 16 digit	40.7351024014167464	-73.8455338938988746
33818	2020-06-28 07:18:42	2020-06-28	Fount Barrows	fount.barrows@woohoo.com	Berkeley	California	869960378233822045	84fc7ff7909a79786ef0d5d30798cdc4	Diners Club / Carte Blanche	37.8480816102847157	-122.312592697808924
33819	2020-06-28 07:25:00	2020-06-28	Mr. Ananias Bartoletti	mr.ananias.bartoletti@woohoo.com	Norfolk	Virginia	4446455641448517	23b782dee885795b2b61fbdeacd72e70	JCB 16 digit	37.0228861477244635	-76.3231426833201283
33820	2020-06-28 07:34:44	2020-06-28	Ms. Octa Lindgren	ms.octa.lindgren@geemail.com	San Francisco	California	589353426665864	a53334918776d370fc1f6ebad879b918	VISA 16 digit	37.7987777197965542	-122.438911129955372
33821	2020-06-28 07:39:17	2020-06-28	Dondre Schamberger	dondre.schamberger@geemail.com	Grand Rapids	Michigan	4276875788506402	53699fe086663956128a6e7e75420909	JCB 15 digit	42.9975750100601459	-85.5955020177312207
33822	2020-06-28 07:42:48	2020-06-28	Timmy O'Kon	timmy.o'kon@geemail.com	Milwaukee	Wisconsin	3778715484270749	5a2029ba461d5acd6812638c8f358c20	VISA 16 digit	43.0435422167267632	-87.8970408860228929
33823	2020-06-28 07:43:16	2020-06-28	Broderick Sanford	broderick.sanford@warmmail.com	Chicago	Illinois	3052700262995916	1aef42f5cb16414c4845d98ac3e04a94	VISA 16 digit	41.8314302611000883	-87.6468225523393585
33824	2020-06-28 07:52:37	2020-06-28	Hasel Paucek-Farrell	hasel.paucek.farrell@geemail.com	Topeka	Kansas	3528982780564843869	35190627f64ff87c5c6bdd9b4b387eb9	American Express	39.0368147115156034	-95.7925310048915435
33825	2020-06-28 07:59:48	2020-06-28	Dr. Levy Cummerata Jr.	dr.levy.cummerata.jr.@geemail.com	West Valley City	Utah	3096569141661889928	2f43b3858e03255b594f32af4982a38a	VISA 16 digit	40.6413478172607725	-111.996441124727198
33826	2020-06-28 08:02:18	2020-06-28	Dallas Monahan	dallas.monahan@geemail.com	Scottsdale	Arizona	53316790297887536	deaf66139b83c648227007fe265f056c	Maestro	33.6801714768290523	-111.955497781183936
33827	2020-06-28 08:04:37	2020-06-28	Catharine Mayert	catharine.mayert@geemail.com	San Francisco	California	3158632677274453431	d2879438a3202bda5be487ce92b5798f	VISA 16 digit	37.7429009645547282	-122.444775976530224
33828	2020-06-28 08:09:11	2020-06-28	Darius Stark	darius.stark@geemail.com	Oakland	California	4021430303867364	464f5dce231d50443d2b2526a50d0132	American Express	37.8067802061089608	-122.278166000502324
33829	2020-06-28 08:11:57	2020-06-28	Dr. Wenzel Donnelly PhD	dr.wenzel.donnelly.phd@geemail.com	San Francisco	California	6011085464412145985	8fdd58788ffb7d371757ae051392049b	JCB 16 digit	37.7664499181411557	-122.431442286924835
33830	2020-06-28 08:21:41	2020-06-28	Mabell Braun MD	mabell.braun.md@geemail.com	Las Vegas	Nevada	4061732952847485	f84894db20190c3eaebb13f37420f62a	VISA 16 digit	36.2259765617184328	-115.295840821761999
33831	2020-06-28 08:22:14	2020-06-28	Hilma Thiel	hilma.thiel@warmmail.com	Phoenix	Arizona	3158460722015053434	7e008b011dfb06884a975ce2df53b73b	VISA 16 digit	33.5658153455171728	-112.097038062701387
33832	2020-06-28 08:23:57	2020-06-28	Cheri Kulas	cheri.kulas@warmmail.com	Pueblo	Colorado	3528625432206794802	437d8e3ef2b3ccf3f91f19d20a9466cb	Maestro	38.2981591558527228	-104.606560384608059
33833	2020-06-28 08:35:13	2020-06-28	Lily Cole PhD	lily.cole.phd@geemail.com	Denver	Colorado	3337718174794210001	1f9299d3729d31bd2cff9e242c4dc3b2	JCB 16 digit	39.7305260874383137	-104.867594728270916
33834	2020-06-28 08:40:01	2020-06-28	Mohammed Cummings	mohammed.cummings@geemail.com	San Jose	California	210095302227102619	40b8b157582f1d5e8ac23977fb7f8973	Voyager	37.3802694345179987	-121.86352988064624
33835	2020-06-28 08:41:27	2020-06-28	Kameron Herzog	kameron.herzog@warmmail.com	Sugar Land	Texas	3481432679358132	8493d2309544f8687967a3bc54b57b2d	Maestro	29.6871852202858761	-95.6094916062902627
33836	2020-06-28 09:10:14	2020-06-28	Robb Mraz	robb.mraz@geemail.com	Springfield	Missouri	3455479615507555	79bc896d302437e7f71f0a80b6a9ee56	VISA 16 digit	37.1542659432820983	-93.3052418211765655
33837	2020-06-28 09:22:17	2020-06-28	Ayaan Boyle	ayaan.boyle@warmmail.com	Oakland	California	4973014649599093	c170269c720d4899df753d7d8d6cdb8d	Diners Club / Carte Blanche	37.8366538417314189	-122.255089963487748
33838	2020-06-28 09:23:18	2020-06-28	Andre Bode	andre.bode@geemail.com	San Francisco	California	4565040294128957	0a87670e10189773280e66ad3b47f637	JCB 16 digit	37.763052206483124	-122.464917435736695
33839	2020-06-28 09:37:00	2020-06-28	Sage Bernier	sage.bernier@geemail.com	Montgomery	Alabama	676354367043137	62b6db4d12627b672b375560dba45e21	VISA 16 digit	32.3237673719812193	-86.2471705680400049
33840	2020-06-28 09:38:35	2020-06-28	Zaid Kirlin	zaid.kirlin@woohoo.com	New York	New York	4865964151175	d28886a8ea5163a2bd8033a9a1a6de0d	Discover	40.6045208137705913	-73.9837782145839213
33841	2020-06-28 09:45:13	2020-06-28	Mr. Kayson McKenzie V	mr.kayson.mckenzie.v@geemail.com	Houston	Texas	869946114773261768	0abeb3a16dcdcb67c80e9d44291e7ac7	Discover	29.7112849655173719	-95.4158611242674368
33842	2020-06-28 09:49:16	2020-06-28	Ann Walker	ann.walker@geemail.com	San Jose	California	4468822200999219	87e06dc38611ce507467e58d8a339e28	Discover	37.2948253601610702	-121.746888130645829
33843	2020-06-28 09:57:19	2020-06-28	Fleeta Kassulke	fleeta.kassulke@geemail.com	San Francisco	California	676169469547397	21fde42b6b82df2c3016d2a065e5ecb4	Mastercard	37.7698647233569673	-122.409740440665189
33844	2020-06-28 09:58:17	2020-06-28	Mrs. Lenore Doyle	mrs.lenore.doyle@geemail.com	Albuquerque	New Mexico	675952954932738	3a07f88bddb7837e9a0d4cd45ac2d4f1	Maestro	35.1383933366410446	-106.624667059450971
33845	2020-06-28 09:59:55	2020-06-28	Jacquez Shanahan	jacquez.shanahan@geemail.com	Stamford	Connecticut	3088383132047924483	ffe861cd09193ce6224cea0c1d613b1e	Mastercard	41.0341876028455843	-73.6119292414784496
33846	2020-06-28 10:06:36	2020-06-28	Darrin Beahan V	darrin.beahan.v@geemail.com	New York	New York	676382159465366	788a7a5ab689992296d9e1dc33e18c2a	JCB 16 digit	40.5984534364417158	-73.8990738578502118
33847	2020-06-28 10:08:00	2020-06-28	Esco Swift	esco.swift@warmmail.com	Oakland	California	3158415835610143891	a9bfdfd4c32eb4d664250306d9012729	American Express	37.8618419094157375	-122.28626995030001
33848	2020-06-28 10:19:02	2020-06-28	Mrs. Dayanara Franecki DVM	mrs.dayanara.franecki.dvm@warmmail.com	Chicago	Illinois	4821653146703148	549446aedc3dc39e41c499d8ab4a8361	Mastercard	41.8245969533290705	-87.6922661538265658
33849	2020-06-28 10:21:43	2020-06-28	Dimitri Torp	dimitri.torp@geemail.com	San Francisco	California	3088054286452112931	7cb12d3f25488747b847c2dcae2f7add	JCB 16 digit	37.7501236193376855	-122.435464104458077
33850	2020-06-28 10:39:44	2020-06-28	Dr. Evita Metz	dr.evita.metz@woohoo.com	Jackson	Mississippi	3733002423268785	b4c91fde500e83d6a9dc9989c75d162f	Discover	32.3124593909077404	-90.2976285904619829
33851	2020-06-28 10:48:30	2020-06-28	Madie Kshlerin	madie.kshlerin@warmmail.com	Portland	Oregon	3337369485943405942	321075f162e171f7ab792b0628c9cc7f	JCB 16 digit	45.4650226900707892	-122.607204274646946
33852	2020-06-28 10:51:30	2020-06-28	Buna Braun	buna.braun@woohoo.com	Mesa	Arizona	6011839746009300331	3e41be02ee10d450161c2ca991c72114	VISA 13 digit	33.4173961884021722	-111.788404784572862
33853	2020-06-28 10:51:57	2020-06-28	Maury Leannon	maury.leannon@geemail.com	Riverside	California	675942398575748	4477527de8cb790a507a54b8b1c84b88	American Express	34.0024375961575629	-117.462712803619723
33854	2020-06-28 10:52:34	2020-06-28	Jesica Walsh-Heidenreich	jesica.walsh.heidenreich@geemail.com	Louisville	Kentucky	3704730604459154	5cc453dfddedf336e0c289c4961998cc	VISA 16 digit	38.0722931531161066	-85.5831634362299098
33855	2020-06-28 10:53:16	2020-06-28	Lugenia Tillman MD	lugenia.tillman.md@geemail.com	Cambridge	Massachusetts	3703874418023219	df8ffbd1c10c8cf5d5ef47485c417b9d	JCB 15 digit	42.3121122032627426	-71.1197898301377904
33856	2020-06-28 11:10:01	2020-06-28	Reagan O'Hara DDS	reagan.o'hara.dds@woohoo.com	Baltimore	Maryland	52563646361584146	d8be641614c54f27e2cb6cfa32370405	American Express	39.2525104257743749	-76.6121660220455425
33857	2020-06-28 11:15:15	2020-06-28	Gil Kris	gil.kris@geemail.com	San Diego	California	180053953350931479	ff018f3f08254b5b2705532bb69f5132	VISA 16 digit	32.7517759917836671	-117.18214821437374
33858	2020-06-28 11:19:47	2020-06-28	June Swift	june.swift@woohoo.com	Washington	District of Columbia	4561891490464149	cc54104ae832398cf7e6c3ec448da6aa	Diners Club / Carte Blanche	38.9609578555714364	-77.0134307504378341
33859	2020-06-28 11:36:13	2020-06-28	Dejah Langworth	dejah.langworth@geemail.com	Round Rock	Texas	3418992638301471	4045a751b3c935abfe7f0511530a1129	American Express	30.5704277272474023	-97.7290659214220909
33860	2020-06-28 11:48:16	2020-06-28	Baker Koepp-Parisian	baker.koepp.parisian@geemail.com	Phoenix	Arizona	676161166447997	4a7a9f47c2bf4e9a42225c43b0919a1e	JCB 15 digit	33.5289682075314275	-112.185126173442612
33861	2020-06-28 12:08:46	2020-06-28	Beyonce Heidenreich PhD	beyonce.heidenreich.phd@geemail.com	Houston	Texas	3088804638501084789	7da10cbdd51f8ca273513b6caea565b1	Mastercard	29.6958335759662084	-95.454758226547014
33862	2020-06-28 12:11:49	2020-06-28	Kris Smith	kris.smith@geemail.com	Irving	Texas	4947314795685	0b747b94aaa472e3c5cfde9e27318a14	Voyager	32.8440715195097042	-97.0437674116622588
33863	2020-06-28 12:28:06	2020-06-28	Hayden Dickens	hayden.dickens@geemail.com	Cleveland	Ohio	51888130487785646	093ac16ff05cb65dc979925e47142411	JCB 15 digit	41.4295712440591259	-81.7731342244200476
33864	2020-06-28 12:43:43	2020-06-28	Waldemar Feil	waldemar.feil@geemail.com	Toledo	Ohio	589340633262387	927d62347ad01d1e4721154e46673207	VISA 13 digit	41.7626333489254122	-83.499520434984575
33865	2020-06-28 12:46:52	2020-06-28	Jerrell Rogahn	jerrell.rogahn@geemail.com	Port St. Lucie	Florida	3044280898276559	887e05c3fa0a2a5a1cf4f057aac8275d	VISA 16 digit	27.1952068437490624	-80.3442027548879452
33866	2020-06-28 12:58:44	2020-06-28	Darrien Schimmel	darrien.schimmel@geemail.com	Berkeley	California	502042679348997	f1e2d139ca636ae9aa40ce015298d911	JCB 16 digit	37.8374356878819995	-122.283809854029073
33867	2020-06-28 13:06:13	2020-06-28	Chester Predovic	chester.predovic@geemail.com	Phoenix	Arizona	869993053584053398	ce849d1c3caf76bd5574c70f7228a09c	Maestro	33.6332155530273909	-112.044412795121232
33868	2020-06-28 13:07:35	2020-06-28	Orange Rowe II	orange.rowe.ii@geemail.com	Santa Rosa	California	4660390668800952	e80ed3b9142fb07fa773ee7c2a6dc902	JCB 15 digit	38.4134210962459477	-122.629602579657373
33869	2020-06-28 13:08:34	2020-06-28	Corinne Marquardt	corinne.marquardt@geemail.com	Plano	Texas	4844834948205408	aa2db050cf776b0c7ae7cdfeac5b0b41	JCB 16 digit	32.969691069525858	-96.783426447463782
33870	2020-06-28 13:08:41	2020-06-28	Miss Essie Roberts	miss.essie.roberts@geemail.com	Evansville	Indiana	3112936907430676176	0daa4f31dcda19192d871d8b8cdc200d	VISA 16 digit	37.9282343072954546	-87.609287113736201
33871	2020-06-28 13:10:07	2020-06-28	Kenyon Wiza	kenyon.wiza@geemail.com	Coral Springs	Florida	589378370463644	c315d45d7eae4b82eebbb29a9e1f805d	American Express	26.1827589429046981	-80.3086374032899641
33872	2020-06-28 13:11:49	2020-06-28	Mckinley Abshire	mckinley.abshire@geemail.com	Bakersfield	California	869903976386175143	71c3b21bf5348994f184011230bf8d8f	Voyager	35.3672799257270967	-119.077719257706022
33873	2020-06-28 13:34:12	2020-06-28	Arman Nienow	arman.nienow@woohoo.com	Oakland	California	4899385694122127	71bbb2e80c97ff89d8bb623f8d4478a0	VISA 16 digit	37.7997308934715619	-122.244744780780479
33874	2020-06-28 13:38:19	2020-06-28	Mr. Tyreek Paucek	mr.tyreek.paucek@geemail.com	Orlando	Florida	3158319549936426727	8ed456778f0d11e07af6dfd62fd40f97	American Express	28.5149854371588667	-81.3441717049539079
33875	2020-06-28 13:51:35	2020-06-28	Mr. Arnav Wyman III	mr.arnav.wyman.iii@geemail.com	Boston	Massachusetts	589327716836823	a2f68e6434938e931803996f41649e47	Diners Club / Carte Blanche	42.342447880625727	-70.9580695799503474
33876	2020-06-28 13:52:02	2020-06-28	Leamon Kautzer	leamon.kautzer@geemail.com	North Las Vegas	Nevada	869916717014660055	1be4b089bc378c3a1283b5721aa6d81f	JCB 15 digit	36.3437963495653094	-115.134495756843691
33877	2020-06-28 13:52:38	2020-06-28	Dickie Stamm	dickie.stamm@warmmail.com	San Francisco	California	3783120408457881	a3cfa44d9e0ca83668f37bccb8347f4b	Mastercard	37.7590823914178415	-122.404048016731949
33878	2020-06-28 13:58:57	2020-06-28	Pheobe Haag	pheobe.haag@woohoo.com	Los Angeles	California	6011609523347152536	3ddbf6968d916e2a350e981a941a2dbd	VISA 16 digit	33.9376808682322491	-118.328103021205578
33879	2020-06-28 14:04:39	2020-06-28	Maudie Robel	maudie.robel@geemail.com	Lincoln	Nebraska	869952219896246280	e2c021297a1ca3446aaa7dfb00d70b78	Voyager	40.8843497822545459	-96.6968958029218015
33880	2020-06-28 14:05:48	2020-06-28	Portia Marquardt	portia.marquardt@geemail.com	Oakland	California	3337287746586179535	f03e22f307f91bc3c3ebdb3445dc3ada	American Express	37.825078603565764	-122.245797061508995
33881	2020-06-28 14:26:04	2020-06-28	Raelyn Bechtelar	raelyn.bechtelar@woohoo.com	San Diego	California	3112062071456874755	3a80179fc6eeab3f45bf8d0e90bee232	JCB 16 digit	32.8436023430500157	-117.10194650733844
33882	2020-06-28 14:35:42	2020-06-28	Niki Moen-Ernser	niki.moen.ernser@geemail.com	Denver	Colorado	4915982459001239	743460f1d719b4fc1680c3e3d415a9f2	Diners Club / Carte Blanche	39.7075982333213062	-104.891181754671408
33883	2020-06-28 14:41:03	2020-06-28	Champ Osinski	champ.osinski@geemail.com	Manchester	New Hampshire	3528757634170976097	6b76c7d909b3635a764f522f1b4d2e97	VISA 13 digit	43.0177149571083532	-71.4542665362715752
33884	2020-06-28 14:54:18	2020-06-28	Eda Heathcote	eda.heathcote@geemail.com	Portland	Oregon	4840429450330	e14216e222d0e015fa1c173ca0f9c781	VISA 13 digit	45.6213620059546088	-122.581027994211766
33885	2020-06-28 14:55:53	2020-06-28	Demi Konopelski-Bogan	demi.konopelski.bogan@geemail.com	Detroit	Michigan	4771978233138803	5876dbc9d1e2b04bd468f2c1e35bb7fe	American Express	42.4060794955976306	-83.0246009476136351
33886	2020-06-28 14:58:22	2020-06-28	Saige Paucek	saige.paucek@warmmail.com	New York	New York	55727607285798728	17aca91fc6a8cfb670f6753477b2b8e7	American Express	40.7004609572459017	-74.0105869642354577
33887	2020-06-28 15:00:11	2020-06-28	Dr. Memphis Rippin	dr.memphis.rippin@geemail.com	Memphis	Tennessee	6011220974010431864	3ef729751674a3dc13c919c9ffd189e6	Diners Club / Carte Blanche	35.0735090122159576	-89.9890184279788343
33888	2020-06-28 15:05:54	2020-06-28	Earl VonRueden	earl.vonrueden@warmmail.com	Irving	Texas	3096054029305572509	0b40f46695c59c01a10196ea6941e45d	JCB 16 digit	32.8926618792533887	-97.0674120690021596
33889	2020-06-28 15:08:29	2020-06-28	Miss Debrah Conn	miss.debrah.conn@geemail.com	Oakland	California	4345039475662559	45aa85b59a56e79e978a830c104a9149	American Express	37.780262742292642	-122.272908396020043
33890	2020-06-28 15:20:00	2020-06-28	Lella Bednar DDS	lella.bednar.dds@geemail.com	Newark	New Jersey	51431716649160447	cd324746dcdb3d825fb7c54c0fd563ce	Mastercard	40.6244290093340013	-74.2312017793044419
33891	2020-06-28 15:25:45	2020-06-28	Duncan Cassin-Hilpert	duncan.cassin.hilpert@geemail.com	St. Louis	Missouri	3752421509261090	9c6f8f07bc0b95b38ef50b242211ca52	JCB 15 digit	38.5725934910278738	-90.3180009042382324
33892	2020-06-28 15:27:30	2020-06-28	Ms. Angelique Grant MD	ms.angelique.grant.md@geemail.com	New Orleans	Louisiana	210041203844049974	8a32a70abbd6db6dcfe82a7d176ff98a	JCB 15 digit	30.0522825660664594	-89.9800872619058936
33893	2020-06-28 15:27:33	2020-06-28	Verda Borer DDS	verda.borer.dds@geemail.com	New York	New York	3490225007521945	3770ad8ac0be1a1c0372b221dd30c4c1	Discover	40.6733720372654517	-73.99673685714491
33894	2020-06-28 15:47:46	2020-06-28	Chana Upton	chana.upton@geemail.com	Stockton	California	4753156292744	a3b1670a90b089c2ad9a03f75aab6c82	JCB 16 digit	37.9552098248351371	-121.288727906680847
33895	2020-06-28 15:48:09	2020-06-28	Rashida Feeney	rashida.feeney@woohoo.com	El Paso	Texas	4886378514463420	f0b751f3491aad218a1de19852a2fef3	American Express	31.9451679236084232	-106.511622469637544
33896	2020-06-28 15:57:43	2020-06-28	Brandy Boehm	brandy.boehm@geemail.com	Arlington	Texas	3528450051874383969	2f83d5bf82087cbabf31dcf8b8ff9c30	Voyager	32.7503097611729004	-97.1908275204271064
33897	2020-06-28 16:18:41	2020-06-28	Echo Armstrong PhD	echo.armstrong.phd@warmmail.com	Billings	Montana	3453293994083381	dcfc8f65190fad51d76ba9eb19042691	JCB 15 digit	45.6991091624591519	-108.507688935815906
33898	2020-06-28 16:20:50	2020-06-28	Delora Schneider	delora.schneider@geemail.com	Cape Coral	Florida	4639594097045	a0ac021a7d4afdc59d44aa25b496281a	VISA 16 digit	26.6905061292897905	-82.0680102691125057
33899	2020-06-28 16:25:36	2020-06-28	Hasan Heathcote	hasan.heathcote@warmmail.com	Los Angeles	California	4881103434381204	cd6c1d50b69202f75f9f1d3962298827	Mastercard	34.0196230616286357	-118.466900892880929
33900	2020-06-28 16:34:19	2020-06-28	Dr. Ron Zulauf	dr.ron.zulauf@woohoo.com	Mobile	Alabama	3528642488956251442	1e2745ae7897fa65032fa12bbe692907	Diners Club / Carte Blanche	30.6093306640736742	-88.1964599528953386
33901	2020-06-28 16:43:05	2020-06-28	Tavion Gleason	tavion.gleason@geemail.com	Hialeah	Florida	4888916184896	29c7787707c1e0cb082ab725198a541f	VISA 16 digit	25.8110806094925849	-80.27945674298293
33902	2020-06-28 16:54:58	2020-06-28	Diallo Pagac I	diallo.pagac.i@geemail.com	New York	New York	3337671898163116374	13053c2316ded903c45e56fd4bf97d58	JCB 16 digit	40.6779682037178389	-73.9353955067589794
33903	2020-06-28 17:06:07	2020-06-28	Columbus Cormier	columbus.cormier@geemail.com	Visalia	California	4885258764429886	490996055a204c48999efa7d8f74e025	JCB 16 digit	36.2787623621944348	-119.250260598178585
33904	2020-06-28 17:08:06	2020-06-28	Mr. Tyree Yundt	mr.tyree.yundt@woohoo.com	Cincinnati	Ohio	3112760436763037195	b5a74c73fcc91e3bb3ec84e4c0ec8e32	JCB 15 digit	39.2338567808501395	-84.5186455621190333
33905	2020-06-28 17:26:16	2020-06-28	Brock Erdman III	brock.erdman.iii@geemail.com	Los Angeles	California	3337411443424205982	874bd30af51ce94ebdf3e2f9aa0fa88b	Discover	33.9867667773604367	-118.360701942675931
33906	2020-06-28 17:32:07	2020-06-28	Wells Macejkovic	wells.macejkovic@geemail.com	San Francisco	California	4994704535049824	363a7eefbd7246b472b80777f2f83070	Mastercard	37.8009892447251161	-122.428586732741337
33907	2020-06-28 17:45:22	2020-06-28	Manerva Lowe DVM	manerva.lowe.dvm@geemail.com	Scottsdale	Arizona	4302561711169	4a8b23158a549d90880485f18c97dfb6	VISA 16 digit	33.685625110765173	-111.859288372794538
33908	2020-06-28 17:46:38	2020-06-28	Joanna Lockman	joanna.lockman@geemail.com	Yonkers	New York	4228408952254	5b5213efdfe304917365cfe9fa7a7705	Mastercard	40.9570276654992256	-73.8844620332472033
33909	2020-06-28 17:58:21	2020-06-28	Silvester Jones	silvester.jones@woohoo.com	Memphis	Tennessee	869993386949364617	63cd71d0e2fa45c36037a7f128049dff	JCB 15 digit	35.1424138755604645	-90.0638497873932096
33910	2020-06-28 18:02:02	2020-06-28	Albertus Bogisich	albertus.bogisich@woohoo.com	San Francisco	California	6011501403089545701	f78036636d5cc65b005787bcf1816a80	JCB 15 digit	37.7984708863602776	-122.420710226942589
33911	2020-06-28 18:03:07	2020-06-28	Francisco Koss	francisco.koss@geemail.com	San Francisco	California	869924753434895112	22145783b1459a483054fb058703c9c8	JCB 15 digit	37.7661202558064772	-122.427760679966553
33912	2020-06-28 18:09:46	2020-06-28	Adin Thompson	adin.thompson@geemail.com	New York	New York	51173793121795562	4866a90544b1e492bda0221b6dbfff7d	Mastercard	40.679315861197189	-73.9750668510690303
33913	2020-06-28 18:22:30	2020-06-28	Mario Nolan	mario.nolan@geemail.com	McAllen	Texas	4590129657253780	d37ea30d7f196c92e6f32b2612634abb	Mastercard	26.170712810133395	-98.2962803221154928
33914	2020-06-28 18:28:13	2020-06-28	Guilford Marvin	guilford.marvin@geemail.com	Norwalk	California	210088802912913807	5dc9510651a327c125fa185a7d282faf	VISA 16 digit	33.8617022921446704	-118.158450967356558
33915	2020-06-28 18:36:39	2020-06-28	Madlyn Larkin	madlyn.larkin@geemail.com	Fort Wayne	Indiana	3012871630473413	51cf4ecd8686c0eb5235584c7b383677	Diners Club / Carte Blanche	41.0808833580713753	-85.1159477289985915
33916	2020-06-28 18:37:21	2020-06-28	Rigoberto Bode	rigoberto.bode@geemail.com	Tampa	Florida	6011443320068837993	eba56455a1f189b937925cf81aedac28	American Express	28.0238943703122416	-82.54724938936792
33917	2020-06-28 18:39:18	2020-06-28	Blanca Daugherty-Glover	blanca.daugherty.glover@geemail.com	San Diego	California	210048454690956738	f581ebb4eb7b3b0b059c2888b180dad7	Mastercard	32.9108330923665306	-117.196132407467815
33918	2020-06-28 18:44:19	2020-06-28	Mr. Nick Weimann	mr.nick.weimann@geemail.com	New York	New York	4829188691036	a33d0f6da967069572b5d33b31e443af	JCB 16 digit	40.5737408695500363	-73.8747527380835294
33919	2020-06-28 19:14:19	2020-06-28	Atha Runolfsdottir	atha.runolfsdottir@geemail.com	Virginia Beach	Virginia	4915912282497304	f37590e10a470706b26feaa6793e0bee	Diners Club / Carte Blanche	36.7061668244842423	-76.0411891445189667
33920	2020-06-28 19:15:04	2020-06-28	Miss Gena Dibbert	miss.gena.dibbert@geemail.com	Washington	District of Columbia	6011206002654312923	8176e1ecfc8ea248c597fe1660467a9d	Mastercard	38.8228628596555438	-77.0093968059148608
33921	2020-06-28 19:18:03	2020-06-28	Venessa Jast	venessa.jast@warmmail.com	Tucson	Arizona	3096424727343664823	cde193ff8d1aea527784c517ab8fcd9c	JCB 15 digit	32.1743254181038623	-110.885506032802539
33922	2020-06-28 19:18:10	2020-06-28	Dr. Casimiro Corkery DVM	dr.casimiro.corkery.dvm@woohoo.com	Los Angeles	California	4949192168126	f0daffa3a881d395ad3c3cb1064fb1b7	Voyager	33.9543964729044561	-118.333587685273216
33923	2020-06-28 19:24:48	2020-06-28	Melanie Anderson	melanie.anderson@warmmail.com	Stockton	California	3096500266664506013	c962f5db752a9d4d52b5664c5e7c547d	JCB 15 digit	37.9262903066083794	-121.286740046375613
33924	2020-06-28 19:31:47	2020-06-28	Charles Lehner	charles.lehner@geemail.com	Downey	California	3088028816757995623	748dcf3cf7063eb47ea85b7416f9b6b6	JCB 15 digit	33.8439679121848229	-118.058376304536679
33925	2020-06-28 19:32:02	2020-06-28	Mr. Mackenzie Hamill DVM	mr.mackenzie.hamill.dvm@geemail.com	San Francisco	California	503849042263605	857f57b8af8489ef2acce13498aca9e4	Mastercard	37.7732084861367525	-122.417630801834875
33926	2020-06-28 19:34:44	2020-06-28	Hezekiah Ullrich-Monahan	hezekiah.ullrich.monahan@geemail.com	Tempe	Arizona	3018109680109734	189d4865c0f97bea9c79292207611679	VISA 16 digit	33.3758446792062315	-111.859608897756033
33927	2020-06-28 19:47:47	2020-06-28	Ms. Eden Cartwright MD	ms.eden.cartwright.md@warmmail.com	Houston	Texas	869982961071366342	2c6218527f28947a1d84defd095fad11	Maestro	29.7154269924931214	-95.4748152221102231
33928	2020-06-28 20:01:26	2020-06-28	Gaylon Powlowski	gaylon.powlowski@warmmail.com	Greensboro	North Carolina	6011125486372961822	a183b9262c9a6c829b24883dbfd70841	Voyager	36.0539736372534207	-79.8449995630402043
33929	2020-06-28 20:16:04	2020-06-28	Candi Marquardt	candi.marquardt@warmmail.com	Dallas	Texas	3054551136932157	b76f1157663c3275eb2d722c0a60ebfb	Maestro	32.8453905827637769	-96.8534062068406456
33930	2020-06-28 20:18:06	2020-06-28	Cedrick King IV	cedrick.king.iv@geemail.com	Phoenix	Arizona	3528647558548171582	5e51de4b6c35511c202994bee64aa192	VISA 16 digit	33.509380864857512	-112.158963903870813
33931	2020-06-28 20:18:34	2020-06-28	Monika Gerlach MD	monika.gerlach.md@geemail.com	El Paso	Texas	3337509736325825037	1ca750cce909794583da1cd04c9bdd11	American Express	31.8375707073431471	-106.427524191465238
33932	2020-06-28 20:25:55	2020-06-28	Jackson Runolfsdottir Sr.	jackson.runolfsdottir.sr.@geemail.com	Berkeley	California	869903006472244320	cf341636f322931eed697f0651219e49	JCB 16 digit	37.8591355184246439	-122.248673455374629
33933	2020-06-28 20:29:28	2020-06-28	Monty Gaylord	monty.gaylord@geemail.com	Columbus	Ohio	53826852505482147	0db52b6f30515ce0e102009ab0536be8	Diners Club / Carte Blanche	39.8895750279583012	-83.0580940737158073
33934	2020-06-28 20:30:22	2020-06-28	Wendel Goodwin-Zieme	wendel.goodwin.zieme@warmmail.com	Lafayette	Louisiana	3112708578847125903	0fbdf6f730a1634bf7cc163d236c0e95	JCB 16 digit	30.2792643954023717	-91.9399056809805302
33935	2020-06-28 20:33:22	2020-06-28	Jereme Pfannerstill	jereme.pfannerstill@woohoo.com	Miami	Florida	4735471990144	324c09d42936a8581474460ce73b86a9	Maestro	25.7249626796830455	-80.1614842983301799
33936	2020-06-28 20:37:07	2020-06-28	Mr. Palmer Bartell	mr.palmer.bartell@warmmail.com	Laredo	Texas	6011895407424007453	8479065991cb5e5b0ccce6458f39fb72	VISA 16 digit	27.508595807263255	-99.57276839763
33937	2020-06-28 20:39:45	2020-06-28	Rosalia Medhurst MD	rosalia.medhurst.md@warmmail.com	San Antonio	Texas	676286668527764	7587b8af69de0b39b4f42f99385562b3	JCB 15 digit	29.4628430635273446	-98.444267652167369
33938	2020-06-28 20:50:27	2020-06-28	Grace Doyle MD	grace.doyle.md@geemail.com	Henderson	Nevada	180020368196592247	bb21273da12884035f145b67485044b5	JCB 16 digit	36.0176357888083913	-115.074361803770813
33939	2020-06-28 20:57:42	2020-06-28	Mrs. Kailyn Reinger DDS	mrs.kailyn.reinger.dds@geemail.com	Dallas	Texas	4822305930396071	be7a9f7907250dd44b2bb8504b0b4b68	Voyager	32.78330641349703	-96.6979809616189385
33940	2020-06-28 21:00:30	2020-06-28	Mamie Gleason	mamie.gleason@geemail.com	Lakeland	Florida	869959911742705872	b05bd8c20b79489f6cc17f1fadfdfa0b	VISA 16 digit	28.0723557276949265	-81.9514061575174253
33941	2020-06-28 21:05:29	2020-06-28	Ermine Fisher	ermine.fisher@warmmail.com	Jacksonville	Florida	3021744454628902	d39e0b48769e8749315a97f7527f79d8	JCB 16 digit	30.3991952238656573	-81.6978699705176155
33942	2020-06-28 21:13:25	2020-06-28	Deandra Schowalter	deandra.schowalter@geemail.com	Anchorage	Alaska	180091882599987881	03c522b2993468faacd0ffea2203aeb1	Diners Club / Carte Blanche	61.1616972411733144	-149.218859596423073
33943	2020-06-28 21:17:26	2020-06-28	Dr. Susann O'Kon	dr.susann.o'kon@warmmail.com	San Francisco	California	639080347380802	a82c37c3546e414efa9349f8d37cd6c5	Diners Club / Carte Blanche	37.7848287458830825	-122.453228547411598
33944	2020-06-28 21:25:00	2020-06-28	Kamari Dickinson-Senger	kamari.dickinson.senger@geemail.com	Richmond	California	3088640087954787464	c9c3ec208693f38066d5a18874defd0a	JCB 16 digit	37.9783208598338078	-122.339875787062951
33945	2020-06-28 21:32:54	2020-06-28	Dr. Rush Labadie	dr.rush.labadie@geemail.com	Santa Maria	California	630440466539158	01c5453d477a789ca048ef2c5f731678	Discover	34.8460026641439669	-120.453037801935523
33946	2020-06-28 21:44:37	2020-06-28	Price Roberts-Thiel	price.roberts.thiel@warmmail.com	Plano	Texas	3045435201142133	0725edd84e1d74ea17981c52955c511b	Diners Club / Carte Blanche	33.0596554381858567	-96.7467308639731272
33947	2020-06-28 21:50:27	2020-06-28	Mr. Orvil Buckridge Jr.	mr.orvil.buckridge.jr.@geemail.com	Tulsa	Oklahoma	3015086313422556	38e4906b791ddf8fdb5d909aae3e7fda	Discover	36.0863426691755649	-95.9679013718340457
33948	2020-06-28 21:57:53	2020-06-28	June Grimes	june.grimes@warmmail.com	San Francisco	California	3337905942429055972	e6aecea188aefef394e998cdf3fae9ad	JCB 16 digit	37.7713586516351256	-122.464020462555879
33949	2020-06-28 22:12:57	2020-06-28	Lilliana Rodriguez	lilliana.rodriguez@geemail.com	Los Angeles	California	869904251535133636	8364f27e01c88797151641b8c9f5df37	Mastercard	34.0473928493779141	-118.412274283635611
33950	2020-06-28 22:20:36	2020-06-28	Irven Leffler	irven.leffler@woohoo.com	Dallas	Texas	210022623806357409	dc1cef9165f91629306438fc10481ace	VISA 16 digit	32.7653316449645899	-96.7286085945516731
33951	2020-06-28 22:29:27	2020-06-28	Kyara Greenfelder-Kris	kyara.greenfelder.kris@geemail.com	New York	New York	3059619910434792	31e677c2c2df5b57c20b41823b043051	American Express	40.622259690867736	-73.8763279357820721
33952	2020-06-28 22:44:01	2020-06-28	Jaret Pouros MD	jaret.pouros.md@geemail.com	Pasadena	Texas	3008397047024031	073bb67f7b9e40dfdfb35683b60886dc	VISA 13 digit	29.7253634164448819	-95.2369115457352251
33953	2020-06-28 22:51:11	2020-06-28	Ms. Beatrix Kemmer MD	ms.beatrix.kemmer.md@geemail.com	Oakland	California	210047483556921875	388fa3bf666f00794f5db4d7f2691ae1	Mastercard	37.8165149463478656	-122.276489604817826
33954	2020-06-28 22:52:44	2020-06-28	Luella Ward	luella.ward@warmmail.com	Philadelphia	Pennsylvania	3096630260873430332	a20d827d4a176d32d3cb9e5c52b878b9	VISA 16 digit	40.105145011745023	-75.1895170358374827
33955	2020-06-28 23:00:33	2020-06-28	Miss Krystina Walter	miss.krystina.walter@geemail.com	Berkeley	California	4280867493148	c37d3594e6f644937f96bce2eb7618e1	JCB 15 digit	37.8752006449479452	-122.255227302789834
33956	2020-06-28 23:25:34	2020-06-28	Chancey DuBuque	chancey.dubuque@geemail.com	Temecula	California	4351322537744	7f2fa0617be189d3bba2d16c6d88b7af	VISA 16 digit	33.4863805427350059	-117.188828703081981
33957	2020-06-28 23:27:09	2020-06-28	Aleck Corwin V	aleck.corwin.v@geemail.com	North Las Vegas	Nevada	210040027590476474	d6313d22080104f7b09a16159458f7dc	Diners Club / Carte Blanche	36.1947210569556788	-115.085909230749692
33958	2020-06-28 23:42:13	2020-06-28	Marge Miller	marge.miller@warmmail.com	Rochester	Minnesota	3737822152281725	52c6c5c11d62e21de41ff70537ead51a	VISA 13 digit	44.0409495972931353	-92.4328095651816568
33959	2020-06-28 23:46:34	2020-06-28	Jeanna Hamill	jeanna.hamill@geemail.com	Stockton	California	3528514376645638159	e3e11c4ec53f7a17a98f8e2eaef62a27	Discover	37.9155374340444808	-121.407984419641267
33960	2020-06-28 23:49:45	2020-06-28	Rosanne Wiegand	rosanne.wiegand@geemail.com	Houston	Texas	4240410256533	86918b1f5edb67c923c702530cdfbb0c	VISA 13 digit	29.804281824741885	-95.3495823976598729
33961	2020-06-29 00:02:57	2020-06-29	Dr. Brinda Gutmann	dr.brinda.gutmann@woohoo.com	Coral Springs	Florida	3005534518645620	b818adc7af51a62db5cfe246363ec345	Voyager	26.2034715259976707	-80.2465236469294894
33962	2020-06-29 00:07:31	2020-06-29	Darcy Schmeler I	darcy.schmeler.i@geemail.com	Jacksonville	Florida	210002726710309640	36892f611c2f4867bb1a129b2c720119	Diners Club / Carte Blanche	30.2741989329509451	-81.5670221665952369
33963	2020-06-29 00:26:59	2020-06-29	Adolfo Lehner	adolfo.lehner@geemail.com	Las Vegas	Nevada	3402327726409571	3de2f266ccc303f92e800010ed147187	JCB 16 digit	36.2883504341922674	-115.343392585937295
33964	2020-06-29 00:28:27	2020-06-29	Gerri Witting	gerri.witting@geemail.com	San Francisco	California	4000557378759	1d72229a5626d36f257283d60896f0d4	JCB 15 digit	37.7841303311721717	-122.423827886253079
33965	2020-06-29 00:32:27	2020-06-29	Kale Greenholt	kale.greenholt@geemail.com	Fresno	California	6011945975001096727	52b60d21db5f590703951ee2eee726a5	VISA 16 digit	36.7800360563084467	-119.773436110570657
33966	2020-06-29 00:35:10	2020-06-29	Carleen Kirlin	carleen.kirlin@woohoo.com	Honolulu	Hawaii	6011522595382305595	21e4ec84cc1146ee50987f0f480976d6	VISA 13 digit	21.3218739975925544	-157.766059114292631
33967	2020-06-29 00:37:22	2020-06-29	Ms. Arkie Cruickshank	ms.arkie.cruickshank@geemail.com	Victorville	California	4078970091522	9a441b10940482d19c04525f33830a87	JCB 16 digit	34.5935981864806266	-117.354929752942553
33968	2020-06-29 00:44:21	2020-06-29	Darold Conn	darold.conn@geemail.com	Fayetteville	North Carolina	4995372855830162	fc048f2d4a1ef21305ef758908576e0b	VISA 13 digit	35.0088024642571796	-79.0022660620640949
33969	2020-06-29 00:44:30	2020-06-29	Suellen Schoen	suellen.schoen@geemail.com	Houston	Texas	4272523559823317	64913578a9df8b51ebde82474150c4cd	Voyager	29.7979928167149417	-95.3845778563074731
33970	2020-06-29 01:06:01	2020-06-29	Kandace Schmitt	kandace.schmitt@geemail.com	Houston	Texas	3016787939786469	1d6c879d8bb955ed50081c76444191ca	JCB 16 digit	29.8056223133657134	-95.348756658101081
33971	2020-06-29 01:19:14	2020-06-29	Mr. Kayden Lemke	mr.kayden.lemke@geemail.com	Kansas City	Missouri	501833436882352	c3c964f466ad76adf795f1bbea3bd8bc	JCB 16 digit	39.1471991740468894	-94.5745310424584886
33972	2020-06-29 01:25:26	2020-06-29	Leona Prohaska	leona.prohaska@geemail.com	Oakland	California	3032624771708869	2bdd2bb3ff4bd7ed0add80b640977ce1	Diners Club / Carte Blanche	37.8216855903037796	-122.291147354396657
33973	2020-06-29 01:38:31	2020-06-29	Eleanor Bogan	eleanor.bogan@woohoo.com	Charlotte	North Carolina	869911653503530373	bca6d0b8134e8269ca6a5c2b515e8934	Diners Club / Carte Blanche	35.2968026691835348	-80.8957315943613651
33974	2020-06-29 01:48:40	2020-06-29	Blair Koch-Lesch	blair.koch.lesch@geemail.com	New York	New York	4062144244188836	219a8ae286bc189c7a2a763fe0116674	Voyager	40.6649744078740483	-74.0129181328590988
33975	2020-06-29 01:49:09	2020-06-29	Lorri Feil	lorri.feil@geemail.com	San Antonio	Texas	3088651689966632780	8ed428eb3525235e7285e1539ca8f2c2	Maestro	29.5223394590966421	-98.5846569229219085
33976	2020-06-29 01:50:45	2020-06-29	Arleth Dach DDS	arleth.dach.dds@warmmail.com	Berkeley	California	180075808940632785	6e6b34363af8c302c4a9a86eb0aa975e	JCB 15 digit	37.9012713184883552	-122.269703109035461
33977	2020-06-29 01:51:36	2020-06-29	Tamera Bauch	tamera.bauch@woohoo.com	Charlotte	North Carolina	3096348099735363437	4a18d63e74cadbe21f870eb752a6032f	JCB 16 digit	35.1607129317961622	-80.8692446724921439
33978	2020-06-29 01:59:31	2020-06-29	Lawson Kertzmann	lawson.kertzmann@geemail.com	Baltimore	Maryland	869985181564932164	0d486960151b07330b733125a2265212	JCB 15 digit	39.208211095770821	-76.6437802601158609
33979	2020-06-29 02:13:38	2020-06-29	Sergio Kirlin	sergio.kirlin@geemail.com	Los Angeles	California	55445208197505961	6738c7446a8147f171c30d52b651372c	JCB 16 digit	33.9442908390756699	-118.488720856373376
33980	2020-06-29 02:16:46	2020-06-29	Gwenda Dibbert	gwenda.dibbert@geemail.com	Reno	Nevada	3112092089821683861	4a0a0bc3acbb0523505c988376a59fd7	Voyager	39.4493367495559184	-119.92328097849861
33981	2020-06-29 02:25:50	2020-06-29	Latonya Zemlak	latonya.zemlak@warmmail.com	Cary	North Carolina	180053675456526792	a2ce819a800778a6500566bce90276dd	Voyager	35.7423838758017922	-78.8859436370518097
33982	2020-06-29 02:31:51	2020-06-29	Add Jast IV	add.jast.iv@geemail.com	San Diego	California	4656322268687014	29577a9d5528a464b4dfd7f1b47e89f8	VISA 16 digit	32.728352872102711	-117.171269230162736
33983	2020-06-29 02:46:01	2020-06-29	Dr. Almon Blanda	dr.almon.blanda@woohoo.com	Wichita Falls	Texas	3755740900981700	26ee068f11ffff444ba07e0c444963c6	VISA 16 digit	33.9480264552131317	-98.53457428323253
33984	2020-06-29 03:01:06	2020-06-29	Virgel Vandervort	virgel.vandervort@geemail.com	San Jose	California	869962035123346851	8c8fefa264b2494af7852f104a5e840d	JCB 15 digit	37.3816899773486	-121.868472156323122
33985	2020-06-29 03:24:20	2020-06-29	Mettie Gorczany	mettie.gorczany@woohoo.com	Cedar Rapids	Iowa	3112691338415271376	72a252f8e5e78d304b79c6451294c00e	JCB 16 digit	41.9483870672136518	-91.7470558633629309
33986	2020-06-29 03:24:55	2020-06-29	Maricela Hegmann-Koch	maricela.hegmann.koch@geemail.com	New York	New York	3528957106566653745	bdb88114b83526202b1500256dc907b4	Diners Club / Carte Blanche	40.7353421929981536	-73.865793948982656
33987	2020-06-29 03:31:57	2020-06-29	Charissa Lowe DDS	charissa.lowe.dds@geemail.com	Mobile	Alabama	180069413139894920	150cdff3d46eec8abd8328587042625d	VISA 16 digit	30.6334725836399926	-88.0269499214969642
33988	2020-06-29 03:33:28	2020-06-29	Tegan Goodwin III	tegan.goodwin.iii@woohoo.com	Detroit	Michigan	676308809852398	c52446810cd98f167d06baa729347d1b	Voyager	42.316800245728345	-83.1760467358052722
33989	2020-06-29 03:38:09	2020-06-29	Misti Boehm	misti.boehm@geemail.com	Columbus	Ohio	3032572684637321	06398a6ee0f5b072e850e2e08b602db4	Discover	40.0107182898137737	-82.9948856577046286
33990	2020-06-29 03:47:04	2020-06-29	Paul Effertz	paul.effertz@warmmail.com	New Orleans	Louisiana	3423355332524819	68a40e836f65d2c915649f49af2627ba	Voyager	30.0578987469911567	-89.9221653040293631
33991	2020-06-29 03:48:10	2020-06-29	Lesia Kuvalis DDS	lesia.kuvalis.dds@warmmail.com	Peoria	Arizona	561230293201833	8a5a6fdd000e373fcc792f56bdddf4c6	Discover	33.8725102262374023	-112.378828470680872
33992	2020-06-29 03:53:20	2020-06-29	Dallas Boehm-Ziemann	dallas.boehm.ziemann@geemail.com	San Francisco	California	53156203952595033	5d45d8c371fd4705698f4ac07527dcaf	Mastercard	37.758757348050402	-122.416441206986434
33993	2020-06-29 04:17:47	2020-06-29	Delores Sawayn-Kautzer	delores.sawayn.kautzer@warmmail.com	Temecula	California	210081308991542043	51369650f3de2fcbf15b844daf1c2076	JCB 15 digit	33.5781755858235016	-117.042769944826887
33994	2020-06-29 04:17:52	2020-06-29	Carolyne Anderson	carolyne.anderson@geemail.com	Cincinnati	Ohio	4588504329347	1b7c4b354002e2e1a0718e456dfa7e3d	Voyager	39.19634875936881	-84.4130833337820974
33995	2020-06-29 04:20:11	2020-06-29	Latifah Hamill PhD	latifah.hamill.phd@geemail.com	Los Angeles	California	676283147088674	007008d1459c11625a85858322ea42d2	Maestro	34.119388806806505	-118.386658552567653
33996	2020-06-29 04:31:22	2020-06-29	Allison Hansen	allison.hansen@geemail.com	New York	New York	55071629766533673	df8c91b371f40b53bb81b93e98a7dcc4	JCB 16 digit	40.6429517881702651	-73.900239243394509
33997	2020-06-29 04:35:44	2020-06-29	Tosha Kertzmann-Huel	tosha.kertzmann.huel@geemail.com	Anchorage	Alaska	3054971696804648	b8cfa4bb3051947c0b31db205b492ff6	Diners Club / Carte Blanche	61.1619291610300593	-149.205317781598495
33998	2020-06-29 04:48:29	2020-06-29	Julianne Marquardt	julianne.marquardt@geemail.com	Lakewood	Colorado	3001100566305618	7dd6e23870b962eb1db2c694c33f8c91	Mastercard	39.7815545236166557	-105.133293193441247
33999	2020-06-29 04:52:27	2020-06-29	Santana Ferry	santana.ferry@warmmail.com	Los Angeles	California	3337046134204917184	aecc1db9f47d8a6c9e461e531b719f52	American Express	33.9423001389816363	-118.506189696257181
34000	2020-06-29 04:52:51	2020-06-29	Clint Rau	clint.rau@geemail.com	Henderson	Nevada	54140674923145612	bfe19474e53113c16657a297a14ad0e3	Maestro	35.9612751767437899	-115.000707358742886
34001	2020-06-29 04:54:21	2020-06-29	Alton Boehm	alton.boehm@woohoo.com	San Bernardino	California	53625785576529086	0ff8d59222f309fd4f8dbc94f824c37f	VISA 16 digit	34.2337344996895609	-117.298262310890848
34002	2020-06-29 05:08:43	2020-06-29	Norman Abernathy	norman.abernathy@warmmail.com	Seattle	Washington	3158475559860727164	a2375bbd0e534b14914c2b60eda3ec89	JCB 16 digit	47.5362914103474452	-122.265573167606817
34003	2020-06-29 05:11:46	2020-06-29	Orlando O'Keefe DVM	orlando.o'keefe.dvm@geemail.com	Nashville	Tennessee	4546552446561	9b032d983fac57429dd9b9c5e71ab4ba	Voyager	36.2135025483678987	-86.8285143789742051
34004	2020-06-29 05:32:03	2020-06-29	Cephus Wilderman	cephus.wilderman@warmmail.com	Columbus	Ohio	4242765389192945	6863581a51776715faf3078412d9e193	JCB 15 digit	39.9616361353125384	-82.8949656511425985
34005	2020-06-29 05:46:21	2020-06-29	Trayvon Crooks	trayvon.crooks@woohoo.com	New York	New York	675981459709960	ab24069d6b8dac75c4e4f6ddc38f0cd4	Diners Club / Carte Blanche	40.5748432527054064	-73.8638816948410124
34006	2020-06-29 05:52:37	2020-06-29	Kori Leannon DVM	kori.leannon.dvm@woohoo.com	Cincinnati	Ohio	4476116798788	4406409b9f3f6954f4a29fa708347bc7	Discover	39.0997882196445019	-84.5364404105853282
34007	2020-06-29 06:06:38	2020-06-29	Sylvester Langworth Sr.	sylvester.langworth.sr.@geemail.com	Cambridge	Massachusetts	6011592907977094358	e15d6c5cf23f3bf8844fbc87f5361e70	Diners Club / Carte Blanche	42.4420643468145258	-71.0222722273867646
34008	2020-06-29 06:12:08	2020-06-29	Hoy Heathcote	hoy.heathcote@geemail.com	Nashville	Tennessee	869963275732767613	11f9058dafd86e90a8c1e78d89a324d6	American Express	36.0964473832987238	-86.8167573536187405
34009	2020-06-29 06:13:16	2020-06-29	Miss Thyra Sauer MD	miss.thyra.sauer.md@geemail.com	Seattle	Washington	3088411988609296339	95735e2eec041c3ee33089542241dd97	VISA 16 digit	47.6809542530607402	-122.333009526684506
34010	2020-06-29 06:16:54	2020-06-29	Kameron Heller	kameron.heller@geemail.com	New York	New York	180028324393024213	383551b09d3fcc0f13f613b11478e776	VISA 16 digit	40.7039169932007781	-73.9442601694155428
34011	2020-06-29 06:40:33	2020-06-29	Sherry Lemke-Lindgren	sherry.lemke.lindgren@geemail.com	San Francisco	California	3096775757606222840	5ee751f751863cd1261ae3d011cf7c88	Maestro	37.7407224748382575	-122.420258785928041
34012	2020-06-29 06:43:13	2020-06-29	Mr. Dallin Bergnaum	mr.dallin.bergnaum@geemail.com	Cary	North Carolina	3112566192620827866	1028f67d911657bba8a610314939b6ae	JCB 16 digit	35.8221385158706482	-78.7857072720389766
34013	2020-06-29 06:55:58	2020-06-29	Alize Rowe DDS	alize.rowe.dds@warmmail.com	San Diego	California	4163964007200819	bf43537f3391ba37f71794d5d3303f8c	Voyager	32.7280443717792622	-117.122211679434415
34014	2020-06-29 06:58:15	2020-06-29	Purl Beier	purl.beier@geemail.com	Little Rock	Arkansas	4662685121052	46b2f84d0eba2f0d757f87abe99133aa	VISA 13 digit	34.6259391046404872	-92.326547261407967
34015	2020-06-29 07:07:09	2020-06-29	Harmon Walter-Sauer	harmon.walter.sauer@geemail.com	Mesa	Arizona	4974607784753166	a8ec52799746cd4ef846c0a2c8dc71b6	Diners Club / Carte Blanche	33.4170649122592067	-111.803555040562145
34016	2020-06-29 07:17:55	2020-06-29	Micheal Moore	micheal.moore@geemail.com	West Jordan	Utah	676198181419585	35c96c1546a303046fb2d17f0d36ba5e	VISA 16 digit	40.5062612580858215	-112.015626659206305
34017	2020-06-29 07:20:32	2020-06-29	Lugenia Schiller	lugenia.schiller@geemail.com	Killeen	Texas	3498834255037918	8d51e6d935e01d0be3b8c928d1882ffb	VISA 16 digit	31.1255393771219993	-97.7301688842643017
34018	2020-06-29 07:23:26	2020-06-29	Kellee Morar	kellee.morar@woohoo.com	San Diego	California	501896172824383	4d3271bab3ee5d7ef78e5e9279051087	Maestro	32.7635750611379777	-117.206964617399507
34019	2020-06-29 07:24:00	2020-06-29	Angelo Farrell	angelo.farrell@geemail.com	Hayward	California	639068232630431	b9f07066d1b04aae569ecaf6bf5bbfd5	Maestro	37.5645491652179544	-122.139779060825333
34020	2020-06-29 07:33:08	2020-06-29	Kavon Bednar	kavon.bednar@woohoo.com	Miami	Florida	3703161671055132	38badce1523f213aaf81f60780f05893	Voyager	25.8542928548667597	-80.1220223407600116
34021	2020-06-29 07:33:45	2020-06-29	Mr. Tremayne Grimes	mr.tremayne.grimes@woohoo.com	Birmingham	Alabama	3088408637055422148	a535ac2484157124801bbb1a06e42708	Voyager	33.4802093464206934	-86.8868485900815699
34022	2020-06-29 07:38:17	2020-06-29	Montie Skiles	montie.skiles@geemail.com	Fullerton	California	869906687416677647	d9928ff75f36f064e1ed3b78768fc29f	JCB 16 digit	33.8369294217944159	-117.998886615104965
34023	2020-06-29 07:39:26	2020-06-29	Miss Lupe Gottlieb PhD	miss.lupe.gottlieb.phd@geemail.com	Seattle	Washington	4825749306265427	88d6ce71a9f9467b89743204705067aa	Diners Club / Carte Blanche	47.7015654184315352	-122.322843533327429
34024	2020-06-29 07:42:30	2020-06-29	Ms. Kaylynn Kuhlman	ms.kaylynn.kuhlman@geemail.com	San Francisco	California	4323027894686255	981ca43ba19b33fe1b81af1b2dcf3b69	VISA 13 digit	37.7947958124685002	-122.405045096282919
34025	2020-06-29 07:42:58	2020-06-29	Ernesto Cummerata	ernesto.cummerata@woohoo.com	Albuquerque	New Mexico	4920384160897331	1c7fe8274e26d6c7467cc4c282b8d62b	Maestro	35.1863658616919111	-106.686470270769306
34026	2020-06-29 07:42:59	2020-06-29	Rhonda Powlowski	rhonda.powlowski@geemail.com	Las Vegas	Nevada	4909079540130370	2c355e3fdb4cafe31d575324ac5f273e	JCB 16 digit	36.1416287528451505	-115.287494090965382
34027	2020-06-29 07:55:46	2020-06-29	Ms. Bina Bergnaum DVM	ms.bina.bergnaum.dvm@woohoo.com	Fort Worth	Texas	869997203935679765	016f84487611294bd694aa6799f3f616	Diners Club / Carte Blanche	32.8152689216248703	-97.2670345597256016
34028	2020-06-29 08:05:33	2020-06-29	Rosalia Howell	rosalia.howell@geemail.com	San Francisco	California	3042287053786001	22c838718caecab09f5ea03612a2ec15	Discover	37.7864834878218616	-122.421320383418717
34029	2020-06-29 08:12:09	2020-06-29	Ebert Bruen	ebert.bruen@warmmail.com	San Francisco	California	3016186307294679	a84eecc4199b56da307e7fa7bd771f3c	VISA 13 digit	37.7442953692408878	-122.42003334158737
34030	2020-06-29 08:18:04	2020-06-29	Mr. Damarion Cassin V	mr.damarion.cassin.v@geemail.com	New York	New York	869905221142994265	84258794b56e66dc48bab6a5fb992ab2	Maestro	40.6685458686891934	-73.8798728398408713
34031	2020-06-29 08:20:04	2020-06-29	Lucina Lubowitz	lucina.lubowitz@geemail.com	Los Angeles	California	4289198694209	4b05fd7cfb14d7e93d1001c044525e8f	Voyager	34.0111266888543966	-118.480987925826753
34032	2020-06-29 08:41:32	2020-06-29	Octavius Jones	octavius.jones@geemail.com	San Francisco	California	3337866781846936480	28c9d41e9ac8b94ef40bceecd4054a3b	VISA 16 digit	37.7654120584409796	-122.4385213610893
34033	2020-06-29 08:56:12	2020-06-29	Mr. Vera Keeling	mr.vera.keeling@geemail.com	Fort Worth	Texas	51822008114441958	c147cfac2107c8fad5805367b708afd2	VISA 16 digit	32.8417829603478353	-97.3916561849236473
34034	2020-06-29 09:06:14	2020-06-29	Kennedy Jones-Treutel	kennedy.jones.treutel@geemail.com	New York	New York	869937050843654494	19c40ea483c454badbe81c22fb54868b	JCB 15 digit	40.7202935797385877	-73.9773355986818615
34035	2020-06-29 09:09:41	2020-06-29	Sade Dicki DDS	sade.dicki.dds@woohoo.com	Philadelphia	Pennsylvania	6011031608147270295	7f739f71b4783f53ba100d5921f6b3aa	Maestro	39.9331942252773757	-75.0767918523766156
34036	2020-06-29 09:22:58	2020-06-29	Lugenia Quitzon	lugenia.quitzon@geemail.com	Arlington	Texas	3005453844216693	46509ed02c6f7d732af7464b21f0cab7	VISA 13 digit	32.7826862985052117	-97.1875198353573779
34037	2020-06-29 09:25:47	2020-06-29	Ellwood Cremin	ellwood.cremin@warmmail.com	West Valley City	Utah	3088544903022338980	01bcf541003d55424da68961b7c0f9fe	VISA 13 digit	40.6122918084952929	-111.936413862251854
34038	2020-06-29 09:43:58	2020-06-29	Toy Nienow	toy.nienow@warmmail.com	New York	New York	4629368479396	6c958fc08a5d3f503f60ae041acbc3c2	Diners Club / Carte Blanche	40.7446869163531815	-73.8735064072430134
34039	2020-06-29 09:48:01	2020-06-29	Bird Corkery	bird.corkery@warmmail.com	Nashville	Tennessee	3158529761684887796	b38cf389aa2d13bc8400ba939fa5a2a7	Diners Club / Carte Blanche	36.1086966683745345	-86.8311460241116606
34040	2020-06-29 09:50:45	2020-06-29	Otto Roob	otto.roob@woohoo.com	Madison	Wisconsin	4414973717219602	9c443fb9d07ed47d6a17c6f0e0393e1e	Voyager	43.0481058633394582	-89.4235659283004765
34041	2020-06-29 10:08:52	2020-06-29	Icy Price DDS	icy.price.dds@warmmail.com	Round Rock	Texas	3481941918853844	9187bdff21ba4f65f6d5701dd0c23094	Diners Club / Carte Blanche	30.4538618185695285	-97.7294815236087828
34042	2020-06-29 10:18:02	2020-06-29	Mrs. Trinidad Bins MD	mrs.trinidad.bins.md@warmmail.com	Hillsboro	Oregon	869971572392876142	7e2772d964f76f2737f5e82051124b9a	Maestro	45.6230574021786452	-123.00193125215992
34043	2020-06-29 10:25:23	2020-06-29	Isla Predovic-O'Reilly	isla.predovic.o'reilly@geemail.com	Berkeley	California	6011912894838415167	f93f50c50ac1232edea64d6909374ed7	American Express	37.9007614002303583	-122.294983848067332
34044	2020-06-29 10:35:03	2020-06-29	Oran DuBuque	oran.dubuque@geemail.com	El Paso	Texas	589373071376146	159d14649aa84516f58070004e54d4a6	JCB 16 digit	31.8298106680918487	-106.497853052707399
34045	2020-06-29 10:38:39	2020-06-29	Jared Hackett-Cormier	jared.hackett.cormier@geemail.com	Houston	Texas	4365599727920175	e46f7028bb09914eb98acc58e39bcef6	VISA 16 digit	29.7550403690509491	-95.3139570382904253
34046	2020-06-29 10:41:37	2020-06-29	Dr. Karley Raynor PhD	dr.karley.raynor.phd@geemail.com	Columbia	South Carolina	6011311201030846388	cb332cf8447ff38f1ad11efa696be88a	Diners Club / Carte Blanche	34.0041715354923184	-80.9691046649143118
34047	2020-06-29 10:50:21	2020-06-29	Lucina Lehner	lucina.lehner@geemail.com	Washington	District of Columbia	52878235495743628	5f4fdb024540b2757656e3a6b5bf423e	VISA 16 digit	38.895919825256243	-76.9564358697950865
34048	2020-06-29 10:54:49	2020-06-29	Elvia Daugherty	elvia.daugherty@warmmail.com	Berkeley	California	3088501619644366800	ea617631daa2d0843ba5bd0be584d58f	Discover	37.8780787341903817	-122.290276207952942
34049	2020-06-29 10:59:39	2020-06-29	Clayton Kovacek	clayton.kovacek@geemail.com	Nashville	Tennessee	210047749113560525	50570e047d808fb3d6b00faf121e5a6d	JCB 16 digit	36.250265970419342	-86.8831550340075012
34050	2020-06-29 11:01:22	2020-06-29	Sean Dare-Stiedemann	sean.dare.stiedemann@woohoo.com	Lincoln	Nebraska	869971178336180045	93ba9f54ee75ddc33fc1b2d5130515ac	JCB 16 digit	40.7896006429120845	-96.6832406276065939
34051	2020-06-29 11:08:47	2020-06-29	Marcia Koelpin	marcia.koelpin@warmmail.com	Cedar Rapids	Iowa	502085412360407	8d99dbee8cd071132a2e06a2764122a8	JCB 16 digit	41.9220779939629153	-91.7397575842749404
34052	2020-06-29 11:10:26	2020-06-29	Miss Dagny Ondricka DDS	miss.dagny.ondricka.dds@geemail.com	Berkeley	California	869954859166199178	3ce7e9035b763175fd98deb209e05d68	JCB 16 digit	37.8421301829888606	-122.266069400123499
34053	2020-06-29 11:11:30	2020-06-29	Larry Anderson	larry.anderson@geemail.com	Salt Lake City	Utah	4603836431211307	c83f9161ccd9220c27c8ae134f489eef	Voyager	40.6884450697019702	-111.920244350651274
34054	2020-06-29 11:20:59	2020-06-29	Diana Jones-Vandervort	diana.jones.vandervort@geemail.com	Tulsa	Oklahoma	4254802335259554	8b340d37dcf0c8c1a1eeb7135808c903	Mastercard	36.1261240212149914	-95.86457231244556
34055	2020-06-29 11:21:32	2020-06-29	Latrell Gleichner-Haley	latrell.gleichner.haley@geemail.com	Plano	Texas	3430311468482810	4862b907da370ad25a0d2974385e6f05	Diners Club / Carte Blanche	33.0176898407835537	-96.7638246149007273
34056	2020-06-29 11:22:04	2020-06-29	Loula Dach	loula.dach@geemail.com	Davenport	Iowa	4077837748084	cca799fe40193eecad0c67d438ee4a22	JCB 16 digit	41.4785252057280402	-90.5345091693066024
34057	2020-06-29 11:25:37	2020-06-29	Amelie Koss	amelie.koss@woohoo.com	Los Angeles	California	55911151858802787	ce4f9e3212aac59b3ef1fd06b2283340	JCB 16 digit	33.9426846933882658	-118.338805008259783
34058	2020-06-29 11:32:15	2020-06-29	Rashawn Weissnat	rashawn.weissnat@geemail.com	Fayetteville	North Carolina	6011058669579187462	758248b61c73fa8bc1e4b9554f00ca13	Voyager	35.0035974003162238	-79.0672197669874919
34059	2020-06-29 11:33:42	2020-06-29	Corda Bosco	corda.bosco@geemail.com	Oxnard	California	3088738429223351925	fe0f20e94271a57a6594aa1497400e69	Maestro	34.1607236709401008	-119.232416483052447
34060	2020-06-29 11:34:06	2020-06-29	Mr. Louis Mante MD	mr.louis.mante.md@geemail.com	Kansas City	Missouri	4178646507980205	6f492abba4d92b49b638c2b1cdd50a15	VISA 16 digit	39.1797068853698676	-94.6226979584190957
34061	2020-06-29 11:39:10	2020-06-29	Jerald Dickinson-Abbott	jerald.dickinson.abbott@geemail.com	Kent	Washington	6011581988537978069	c25aa413c0e2931a27f1428fab7e2e43	VISA 13 digit	47.3716060238070753	-122.16839839607924
34062	2020-06-29 11:39:52	2020-06-29	Felice Pfannerstill	felice.pfannerstill@geemail.com	San Antonio	Texas	3528601565594887155	56e844dfa97501a9d17a3f403ef0f116	JCB 16 digit	29.3765294063907128	-98.5641068919397867
34063	2020-06-29 11:44:24	2020-06-29	Mr. Moe Marvin	mr.moe.marvin@geemail.com	Boston	Massachusetts	180080901889137214	32450615d008afe1927a288cb1e947ec	JCB 15 digit	42.2714802514463699	-70.9221598669838187
34064	2020-06-29 11:47:42	2020-06-29	Mrs. Sabina Murazik PhD	mrs.sabina.murazik.phd@geemail.com	New York	New York	54394546737114641	e30ed1699e3070211e59cf0459671b57	Maestro	40.6213313743229918	-74.0146024241939102
34065	2020-06-29 11:59:57	2020-06-29	Kirstie Hilll-Price	kirstie.hilll.price@geemail.com	Clearwater	Florida	6011666936263084741	ddb1d428e55440c568d7710819d33040	Mastercard	28.0674426537599402	-82.6897209791731029
34066	2020-06-29 12:06:34	2020-06-29	Arron Green	arron.green@geemail.com	Los Angeles	California	4191676752246	e36d3bba6cfda533a8e98dfeee68b252	JCB 15 digit	34.0061582630831722	-118.310955291939152
34067	2020-06-29 12:06:35	2020-06-29	Kelsie Cruickshank	kelsie.cruickshank@geemail.com	Plano	Texas	3528773569573661351	a9ab7563dc348ae1085ac20f8575e819	Diners Club / Carte Blanche	33.0838651393160248	-96.6999093958359168
34068	2020-06-29 12:07:32	2020-06-29	Dr. Bryn Hammes DDS	dr.bryn.hammes.dds@warmmail.com	Boston	Massachusetts	53018550603798459	0e20ca3049a474cdd1c83e43d2ffb9e9	VISA 16 digit	42.2867732764855049	-71.0664475166190499
34069	2020-06-29 12:10:05	2020-06-29	Emilee Klocko-Gleichner	emilee.klocko.gleichner@woohoo.com	Lowell	Massachusetts	4868176566809074	abac9b889358e49c78a6aaff052d483e	VISA 13 digit	42.6709807829801022	-71.2361929453782778
34070	2020-06-29 12:12:05	2020-06-29	Deon Keebler	deon.keebler@geemail.com	Amarillo	Texas	3758277434608530	63465769730c43c42e8927e05633e684	Voyager	35.1720253285184512	-101.82727486210392
34071	2020-06-29 12:29:51	2020-06-29	Janel Fay-Mann	janel.fay.mann@warmmail.com	New York	New York	3053040598566902	ab405c40f772097552c2c297836cd919	Mastercard	40.7010568798277532	-73.9917815920792492
34072	2020-06-29 12:47:18	2020-06-29	Cassius Roob	cassius.roob@warmmail.com	Anaheim	California	3407087306111147	123fdb414a2804fc9c02c357050898de	JCB 16 digit	33.8842329383660115	-117.77192749532162
34073	2020-06-29 12:48:39	2020-06-29	Nolie Barrows	nolie.barrows@geemail.com	Anchorage	Alaska	4743674414789	f3edb8277da2b1bd360798b63a61d500	VISA 16 digit	61.2431514041714422	-149.21026604316495
34074	2020-06-29 12:49:09	2020-06-29	Dr. Braxton Towne II	dr.braxton.towne.ii@geemail.com	Santa Clarita	California	3717102898137059	c05c91d295787c5e13ec022cba56fc6b	JCB 16 digit	34.3647209988180506	-118.554956867649025
34075	2020-06-29 12:49:53	2020-06-29	Kamari Feil-Stoltenberg	kamari.feil.stoltenberg@warmmail.com	New York	New York	6011549570552467979	5346763b80f3a5770e3816e12f4d8887	Diners Club / Carte Blanche	40.703530111186204	-73.8941670579731493
34076	2020-06-29 12:56:47	2020-06-29	Miss Dovie Schumm MD	miss.dovie.schumm.md@geemail.com	Oakland	California	3337113494245626824	0c0316d4250f4ba7b4982acc4765a976	VISA 16 digit	37.80871038787906	-122.249193424992612
34077	2020-06-29 13:07:54	2020-06-29	Claudius Rice-Hodkiewicz	claudius.rice.hodkiewicz@geemail.com	San Francisco	California	3042446926278139	4c04d2da3d25496a8d887fd37b987e0b	JCB 16 digit	37.761423508790152	-122.447758016553649
34078	2020-06-29 13:12:22	2020-06-29	Drucilla Moore	drucilla.moore@geemail.com	Virginia Beach	Virginia	6011974190113660352	0954c75920680a44c4a3b7ce47b8f083	VISA 16 digit	36.7201638219133031	-76.0132153097212324
34079	2020-06-29 13:26:47	2020-06-29	Mr. Tyrek Reichert Jr.	mr.tyrek.reichert.jr.@woohoo.com	New York	New York	869976528695750819	0ee7c2d163cf94e460955436c10a2d33	VISA 13 digit	40.6820165262781046	-73.9091598687589197
34080	2020-06-29 13:33:17	2020-06-29	Dr. Justina Hansen	dr.justina.hansen@woohoo.com	Irvine	California	6011715234952942101	f7ed25c55105e6a6805f7b56f1284773	JCB 16 digit	33.6707997494392117	-117.679601534317428
34081	2020-06-29 13:45:03	2020-06-29	Burleigh Waters Jr.	burleigh.waters.jr.@geemail.com	New York	New York	6011811677702373899	42cfbfc4e7c920f6738b65a5610b19cd	American Express	40.5999733097609123	-73.9895755076676522
34082	2020-06-29 13:53:30	2020-06-29	Adriane Ryan	adriane.ryan@geemail.com	Aurora	Illinois	4359004819087122	cd6b50e81ba289598efd01776c49fffd	VISA 13 digit	41.7468537034224738	-88.2195993710238469
34083	2020-06-29 13:54:36	2020-06-29	Liston Abbott PhD	liston.abbott.phd@woohoo.com	San Francisco	California	3770778939927055	39d61a92d94710a55d5afc6fa14cfe08	JCB 16 digit	37.7614912540852075	-122.421365476482379
34084	2020-06-29 14:00:20	2020-06-29	Myrl Shields	myrl.shields@geemail.com	Lincoln	Nebraska	4648229166612	11ed5ccb85621639705c274054e103dc	JCB 15 digit	40.7288103562798298	-96.7072281450193429
34085	2020-06-29 14:02:50	2020-06-29	Kala Little	kala.little@warmmail.com	Jacksonville	Florida	4646972188901953	e7fd1c03a624f4f46e926d088ef4cc00	Maestro	30.3078240681026116	-81.6345481945745775
34086	2020-06-29 14:18:26	2020-06-29	Davonta Bins	davonta.bins@geemail.com	Lakewood	Colorado	4245117696893459	6cd52f2e79820eeefce75efdabe2b16a	Maestro	39.7614104042235752	-105.189553245531769
34087	2020-06-29 14:43:07	2020-06-29	Loda Stanton	loda.stanton@geemail.com	San Antonio	Texas	3158178553984742613	9070b0fc921c2df3fd3a684fa696a4c0	VISA 16 digit	29.4913613839611415	-98.5571775711908913
34088	2020-06-29 14:53:57	2020-06-29	Armstead Koss-Senger	armstead.koss.senger@geemail.com	New York	New York	3088694816104739040	6924d121a9642d26a8ca803341503712	VISA 13 digit	40.5937477055694913	-73.9255045924697072
34089	2020-06-29 14:59:32	2020-06-29	Cain Purdy	cain.purdy@geemail.com	New York	New York	3088443283852997003	594575062367b68df65b024a85d3d63a	JCB 15 digit	40.6770292226448618	-73.8811184507690371
34090	2020-06-29 15:05:14	2020-06-29	Jaylah Hahn	jaylah.hahn@geemail.com	San Francisco	California	4158432012117979	d953e7efd2979570043a975271869b5f	Voyager	37.7178887550189685	-122.407332110339979
34091	2020-06-29 15:09:12	2020-06-29	Chalmer Murazik	chalmer.murazik@woohoo.com	San Francisco	California	4960843103586	38defcca86d183762b5b554939ab2c11	JCB 15 digit	37.7525773609651836	-122.452321448329741
34092	2020-06-29 15:16:08	2020-06-29	Vernia Schultz	vernia.schultz@geemail.com	Columbus	Ohio	869978372938296993	a34ccc71310946eb962e3c5649015fc2	JCB 16 digit	39.9797323619060236	-82.9807977373015149
34093	2020-06-29 15:25:22	2020-06-29	Jami Corkery DVM	jami.corkery.dvm@geemail.com	Gresham	Oregon	180043271626713156	444186ea90438a584458ad8868301336	Diners Club / Carte Blanche	45.4414136779449862	-122.509950146850571
34094	2020-06-29 15:30:53	2020-06-29	Lilianna Mann	lilianna.mann@geemail.com	Jacksonville	Florida	3088379431692700651	5358b0f9a4efedbf8f0d7f77ad8e7ce0	Maestro	30.335714778868109	-81.5780175701793411
34095	2020-06-29 15:38:52	2020-06-29	Drew Zieme-Abbott	drew.zieme.abbott@woohoo.com	Memphis	Tennessee	4652279695777	621924b99c96a5a3901c751225cf29e9	Mastercard	35.1269535535082227	-89.9805883799470934
34096	2020-06-29 15:42:34	2020-06-29	Hoover Krajcik	hoover.krajcik@geemail.com	El Paso	Texas	3112346540884012798	28b75a5a95863f9ff32e932f1360306a	Maestro	31.8038987258277857	-106.516175173919649
34097	2020-06-29 15:45:49	2020-06-29	Dr. Carlyle Aufderhar DVM	dr.carlyle.aufderhar.dvm@geemail.com	Boston	Massachusetts	3528517621170762891	9593f2d2360bfbcedc9aa1d232a0b7ce	VISA 16 digit	42.339940453197805	-71.1012590687207933
34098	2020-06-29 15:50:10	2020-06-29	Mychal Torphy	mychal.torphy@geemail.com	Richmond	California	3059561612109522	020fbce91111119311e7321601e93cd0	Discover	37.8780820893079024	-122.329054754957937
34099	2020-06-29 15:50:39	2020-06-29	Whit Hauck	whit.hauck@geemail.com	New York	New York	4388136157672647	1579da11ab0671d37a373d2b50a5ddd1	Discover	40.5707881659958502	-73.8809602904960485
34100	2020-06-29 15:50:44	2020-06-29	Joselin Weissnat	joselin.weissnat@geemail.com	Cambridge	Massachusetts	180076806611087205	27e01f2a7eec9a6056392ebe71833cf2	Mastercard	42.383647828897459	-71.1166492234066112
34101	2020-06-29 15:57:12	2020-06-29	Yaakov Howell	yaakov.howell@geemail.com	Macon	Georgia	869939509304092864	698ed40a3239958d808da9fba589e444	JCB 15 digit	32.8714391622703488	-83.6748699202395869
34102	2020-06-29 16:07:32	2020-06-29	Abigayle Cassin MD	abigayle.cassin.md@geemail.com	Rockford	Illinois	53391282322479172	ed5af462858ec08cff4d0c6c2117adc5	Maestro	42.26350628645271	-89.0772159767620195
34103	2020-06-29 16:08:43	2020-06-29	Latricia Jakubowski	latricia.jakubowski@warmmail.com	New York	New York	51375245278086283	151c30403d5eb69d02e3dfd612769597	Discover	40.5742250882778279	-73.8425967589847687
34104	2020-06-29 16:15:36	2020-06-29	Clell Nolan DDS	clell.nolan.dds@geemail.com	Los Angeles	California	3419029302065519	6772eb042ecdee805553e54ab851f527	JCB 16 digit	34.0724147228855614	-118.473749848128477
34105	2020-06-29 16:17:25	2020-06-29	Luke Waelchi	luke.waelchi@geemail.com	Memphis	Tennessee	4347655968369937	e9cf2e2c46b6ea93628b31d7c9636fa2	Diners Club / Carte Blanche	35.0298752036012715	-89.9065021838784304
34106	2020-06-29 16:20:35	2020-06-29	Darian Cronin	darian.cronin@woohoo.com	Berkeley	California	4379551758331412	e72e5446d5eb512cf5967db0232b66e2	VISA 16 digit	37.8423603433369777	-122.281041534831729
34107	2020-06-29 16:30:31	2020-06-29	Sylvan Gorczany	sylvan.gorczany@geemail.com	Burbank	California	3446054542235943	2a953159511add8ee60e495574bb4548	Voyager	34.2840482640940678	-118.341903058675683
34108	2020-06-29 16:40:03	2020-06-29	Greggory Kris	greggory.kris@geemail.com	Glendale	Arizona	502064056221670	c9d9cdd2fa45447620a403119e8776b4	VISA 16 digit	33.6100568059127767	-112.24947038034685
34109	2020-06-29 16:44:56	2020-06-29	Mrs. Maura Bradtke	mrs.maura.bradtke@warmmail.com	Peoria	Arizona	6011475360570340822	8c03e315614144aa6187c57ed892694e	JCB 16 digit	33.8652192771237353	-112.214559429550548
34110	2020-06-29 16:54:15	2020-06-29	Essex Jakubowski	essex.jakubowski@geemail.com	Dallas	Texas	6011185289208379236	d358f8b664978e93b9e0955d955738a3	JCB 16 digit	32.7117115455020269	-96.7958202149681739
34111	2020-06-29 17:17:13	2020-06-29	Dr. Evan Witting IV	dr.evan.witting.iv@geemail.com	Vancouver	Washington	4104664383510	6fe86a624b24bfdbb2aeb2c9453ba42f	Voyager	45.5676202297281492	-122.556413789612051
34112	2020-06-29 17:25:47	2020-06-29	Zakary Smitham	zakary.smitham@geemail.com	San Jose	California	3448958082005706	64940cd35c5d78b4a67e6ff85c82d709	Discover	37.3239160433232797	-121.834813524245845
34113	2020-06-29 17:26:07	2020-06-29	Mrs. Misti Rice PhD	mrs.misti.rice.phd@woohoo.com	Philadelphia	Pennsylvania	869993315818075335	a858368045e04a75d9b3ce3f24ee9170	VISA 16 digit	39.9290919615380488	-75.1542601270034965
34114	2020-06-29 17:27:32	2020-06-29	Earl Pfannerstill	earl.pfannerstill@geemail.com	Alexandria	Virginia	4166606197178027	be514b6e1de0ec511dfc2555e4fe1f92	JCB 16 digit	38.8708061207666944	-76.9955763396792179
34115	2020-06-29 17:30:06	2020-06-29	Donal West DVM	donal.west.dvm@warmmail.com	Hialeah	Florida	3421962784377158	ab0f28941ad57042fcb51f1a3f371873	Discover	25.8632240198530283	-80.3242518757373034
34116	2020-06-29 17:36:44	2020-06-29	Brycen Lemke	brycen.lemke@geemail.com	Denver	Colorado	869920199820303168	a0ae83baad548e1e4f2390d310acc4ea	JCB 16 digit	39.6959603420510874	-104.960905579129616
34117	2020-06-29 17:38:04	2020-06-29	Ms. Nanci Denesik	ms.nanci.denesik@warmmail.com	Kansas City	Kansas	6011930316689250665	4d68fb9e2b895b2b3aa48fde07638e81	Mastercard	39.1124720303714284	-94.6576691375516361
34118	2020-06-29 17:44:47	2020-06-29	Ida Corwin	ida.corwin@geemail.com	Los Angeles	California	3052305272608341	43e5beeec29605d16ada5e8f5bf3ff8f	Voyager	34.0650239053513815	-118.342491661057991
34119	2020-06-29 17:49:47	2020-06-29	Monna Cartwright-Von	monna.cartwright.von@woohoo.com	Kenosha	Wisconsin	561232366490475	a9002593ee7605358cfd39e9835ae73a	JCB 15 digit	42.5082962435510012	-87.7960116672091289
34120	2020-06-29 18:05:11	2020-06-29	Hobson Farrell	hobson.farrell@woohoo.com	San Francisco	California	3112815138624548049	3bd071b03f8e403643a38f4ba2011a84	Diners Club / Carte Blanche	37.7834580877483646	-122.46392940228759
34121	2020-06-29 18:11:25	2020-06-29	Al Wolff MD	al.wolff.md@geemail.com	Denver	Colorado	210056262768906553	940ff2f3385300fff3a21c1fcf32f62c	JCB 16 digit	39.6777374429680378	-104.818396895449979
34122	2020-06-29 18:12:09	2020-06-29	Jaden Wilderman	jaden.wilderman@geemail.com	North Charleston	South Carolina	4248246029437168	2079a6e4316028101bbf84d71f916d8f	American Express	32.825319645337018	-80.018421884123228
34123	2020-06-29 18:17:32	2020-06-29	Tyrone Mills	tyrone.mills@warmmail.com	Las Vegas	Nevada	561262768357626	daf57d4d5b0edba710d67bd50e386093	JCB 15 digit	36.2277988521017136	-115.254724111056319
34124	2020-06-29 18:19:24	2020-06-29	Miss Paulina Lockman DVM	miss.paulina.lockman.dvm@geemail.com	Los Angeles	California	4267943268732665	91d0803448961633c52a75c6ba08ad94	Diners Club / Carte Blanche	33.9380891933903044	-118.496743968081844
34125	2020-06-29 18:40:04	2020-06-29	Burt Moore II	burt.moore.ii@geemail.com	Indianapolis	Indiana	4320407631012424	7c9e029f6111bcc76981c5fc82812cff	JCB 15 digit	39.7042589900556919	-86.1602225245643325
34126	2020-06-29 18:41:27	2020-06-29	Math Altenwerth	math.altenwerth@woohoo.com	San Francisco	California	3468344082271447	7ca212f9766dead8f21202e7e4786597	Maestro	37.7636446553987426	-122.402182649106365
34127	2020-06-29 19:01:26	2020-06-29	Lilly Littel	lilly.littel@geemail.com	Pittsburgh	Pennsylvania	51924431715860201	fabaa1923d1201dcaf15be8d8f01cd55	VISA 13 digit	40.4831229926042226	-79.9455243505243232
34128	2020-06-29 19:02:02	2020-06-29	Nylah Hermiston	nylah.hermiston@geemail.com	Sandy Springs	Georgia	060454737087863	18328af346223f1e09f60708303fcd5a	VISA 16 digit	33.9684116024114218	-84.3476961664937477
34129	2020-06-29 19:05:41	2020-06-29	Chas Kiehn	chas.kiehn@geemail.com	Montgomery	Alabama	869918090516658045	72257ddafb6facad59065ab331144337	Mastercard	32.358191298919543	-86.2811907929521027
34130	2020-06-29 19:20:11	2020-06-29	Vassie Macejkovic	vassie.macejkovic@woohoo.com	Tallahassee	Florida	53982780064824229	043912273d417296fbfb11e66aaaebbb	Voyager	30.4607414974387751	-84.2657049977701149
34131	2020-06-29 19:23:18	2020-06-29	Eliseo Lowe-Brown	eliseo.lowe.brown@geemail.com	Sandy Springs	Georgia	4140497336881312	ab6f53aa7aa20604afaff4e572dbb3ab	Mastercard	33.9098068040385812	-84.4251716030843653
34132	2020-06-29 19:24:44	2020-06-29	Hermon Willms-Champlin	hermon.willms.champlin@geemail.com	Stamford	Connecticut	869991975052977389	f6434b1d170238594a1a260c4e8c9ec8	Discover	41.020329583704104	-73.4735353446137225
34133	2020-06-29 19:28:52	2020-06-29	Mr. Benedict Schmitt	mr.benedict.schmitt@woohoo.com	San Francisco	California	3112920810733389661	694d319b27670eb30d8b55bff7bbacbe	Diners Club / Carte Blanche	37.7258043842800888	-122.417550408594096
34134	2020-06-29 19:29:56	2020-06-29	Mr. Karson Morar MD	mr.karson.morar.md@geemail.com	San Francisco	California	6011848896311133356	3b47658515af35c581046115ef4bc453	Diners Club / Carte Blanche	37.7695278497513058	-122.429288082815944
34135	2020-06-29 19:36:12	2020-06-29	Dr. Landen Huels IV	dr.landen.huels.iv@geemail.com	Phoenix	Arizona	3112135727851291985	e9bb732a56158f0e948d0c5c70f3fd31	VISA 16 digit	33.5670172125499704	-112.064375501118974
34136	2020-06-29 19:37:51	2020-06-29	Dr. Aubrey Durgan III	dr.aubrey.durgan.iii@geemail.com	Fort Worth	Texas	4949007654775286	56c68079fed5317360b52971f8184656	Voyager	32.7606853555943829	-97.3938852494869423
34137	2020-06-29 19:49:36	2020-06-29	Shayna Denesik	shayna.denesik@geemail.com	Las Vegas	Nevada	4509581424629876	561f52610d5ff5030668623c68205407	Mastercard	36.1834333984747545	-115.216154010894144
34138	2020-06-29 19:58:34	2020-06-29	Elnora Carroll	elnora.carroll@geemail.com	San Francisco	California	3051217402993264	5f1bc39937a123cf2102f8993085e0b6	Maestro	37.7766355020587099	-122.441049826158519
34139	2020-06-29 20:04:08	2020-06-29	Coty Cronin	coty.cronin@geemail.com	Phoenix	Arizona	180068006444561662	806eee6e027f1b671ee11831ef2564b9	VISA 16 digit	33.593065075523036	-112.083373965688423
34140	2020-06-29 20:15:06	2020-06-29	Christeen Ernser	christeen.ernser@geemail.com	San Francisco	California	869999483926091497	a745b833b60ae2202bd01e7a208541ab	Voyager	37.8212091877968177	-122.440962927860767
34141	2020-06-29 20:15:55	2020-06-29	Dr. Charls Shields DVM	dr.charls.shields.dvm@geemail.com	Minneapolis	Minnesota	6011384526840831911	4cac34cd826e205d57a4a942a716a8e4	VISA 16 digit	44.9982543744698162	-93.3496043660949937
34142	2020-06-29 20:17:22	2020-06-29	Henry Strosin	henry.strosin@warmmail.com	Los Angeles	California	3015710627175283	7344a4fad1b5b004e23630b29cf93b38	VISA 16 digit	33.9370637775730302	-118.393375099077076
34143	2020-06-29 20:30:39	2020-06-29	Darcy Goldner	darcy.goldner@geemail.com	New York	New York	4396776972006065	e393c2ce9160aa5ce5586e290601f11f	Discover	40.5943484137058235	-74.0199131379265367
34144	2020-06-29 20:41:03	2020-06-29	Mrs. Angela Hammes DDS	mrs.angela.hammes.dds@geemail.com	Milwaukee	Wisconsin	3088761425539387884	981707a00cdfe40c9b483b60ae0485ee	VISA 16 digit	43.1124038722451743	-87.9699939546275971
34145	2020-06-29 20:46:09	2020-06-29	Willodean Parker	willodean.parker@geemail.com	Chicago	Illinois	4837240690508	6b02c81e8f3a3411a118f282fe37cb2d	Voyager	41.8763739987112587	-87.5998052281822908
34146	2020-06-29 20:46:21	2020-06-29	Donita Conn	donita.conn@woohoo.com	Fort Worth	Texas	3429044089680966	5484485fb9e130bce636563fa8599ce7	VISA 16 digit	32.7623589993976054	-97.3676861680865215
34147	2020-06-29 20:57:05	2020-06-29	Crete Macejkovic MD	crete.macejkovic.md@geemail.com	Los Angeles	California	180000433517170737	b28df3378a6e96b4fb24d375c021b69f	Maestro	33.9918754584021841	-118.481579387373472
34148	2020-06-29 21:02:50	2020-06-29	Mr. Jamal Kris IV	mr.jamal.kris.iv@geemail.com	New York	New York	3754719148850522	e618110724ea942cd8c0334bfd8fb5e3	Maestro	40.7294420103766015	-73.8471952462464571
34149	2020-06-29 21:05:59	2020-06-29	Mell Fay	mell.fay@woohoo.com	Los Angeles	California	4357114802853695	fc576d79ab8ae28c6fd472d2818f74a5	Maestro	33.970305360886826	-118.402968461531401
34150	2020-06-29 21:14:58	2020-06-29	Rhea Funk	rhea.funk@geemail.com	Huntington Beach	California	3012560734835979	2a73a3bdc25b38790d6c5b1faf62b787	Diners Club / Carte Blanche	33.7082134072709891	-118.015153048572316
34151	2020-06-29 21:38:03	2020-06-29	Mathew Denesik	mathew.denesik@warmmail.com	San Jose	California	869967622295564034	5af639d5b0314c7e7de5e2edcafbba74	VISA 13 digit	37.3301441819693878	-121.851517854280402
34152	2020-06-29 21:44:15	2020-06-29	Dennie Shields	dennie.shields@geemail.com	San Francisco	California	3337903458764185995	8d8a863b1778a6b85d579222179dcf63	VISA 13 digit	37.8223656667172818	-122.420428978190685
34153	2020-06-29 21:57:52	2020-06-29	Faith Ritchie	faith.ritchie@geemail.com	West Palm Beach	Florida	3158238175973922747	a33107d7a74849f53b4f2bd1a4e88f0d	Maestro	26.7505954049840575	-80.1688746976502244
34154	2020-06-29 22:02:51	2020-06-29	Pratt McCullough-Bernhard	pratt.mccullough.bernhard@woohoo.com	Beaumont	Texas	3746892554651063	1089baf1c85a4e8fe48e6f3399bb00fc	Diners Club / Carte Blanche	29.9910567991506305	-94.1884373198982416
34155	2020-06-29 22:03:43	2020-06-29	Orra Boehm-Fisher	orra.boehm.fisher@warmmail.com	Pearland	Texas	4294566466240723	f9610ada88b28d19503e281640c8c471	VISA 16 digit	29.5338480653047561	-95.3557861854642539
34156	2020-06-29 22:06:17	2020-06-29	Epifanio Runolfsson	epifanio.runolfsson@warmmail.com	San Francisco	California	3762877803014683	2f4a84422e87adebffbbf498876a933f	JCB 15 digit	37.7606068500838177	-122.431028228165388
34157	2020-06-29 22:12:05	2020-06-29	Delilah Stokes DDS	delilah.stokes.dds@warmmail.com	Fort Worth	Texas	589315573154455	e9fe05a254139406445102f1b8cda351	American Express	32.6836929652895805	-97.2881077673107342
34158	2020-06-29 22:19:08	2020-06-29	Carmella Haag	carmella.haag@woohoo.com	San Francisco	California	4969371841747771	0043bffd5560cedd74e45735889cd2c0	VISA 16 digit	37.7642292113992042	-122.437652657956974
34159	2020-06-29 22:19:32	2020-06-29	Alvan Boyer	alvan.boyer@geemail.com	Montgomery	Alabama	6011904333138264553	bac57310a6151db803dd996df8373f47	Maestro	32.2674054411172904	-86.2058045573219545
34160	2020-06-29 22:21:26	2020-06-29	Sophronia Maggio-Schneider	sophronia.maggio.schneider@geemail.com	Cleveland	Ohio	4208752668577337	7b7529ab3175338974915aeb2220bffe	American Express	41.4289319225437893	-81.7566807700093818
34161	2020-06-29 22:23:55	2020-06-29	Millicent Littel	millicent.littel@geemail.com	Columbus	Ohio	869943071013104187	d0cf81aa24c1709673eb0d99f67b6332	VISA 13 digit	39.8880807871975023	-82.9482176805149862
34162	2020-06-29 22:29:06	2020-06-29	Sondra Hirthe	sondra.hirthe@woohoo.com	Santa Ana	California	675916330639937	fa2c3410f70d6dc9a710b73b336adb69	Mastercard	33.8127026606921106	-117.926129653250797
34163	2020-06-29 22:30:41	2020-06-29	Dr. Cheyenne Barton DVM	dr.cheyenne.barton.dvm@geemail.com	Colorado Springs	Colorado	3783047112539961	7651994fc9296ce9ccb5397cffb4434e	Voyager	38.778091534837337	-104.835333084656668
34164	2020-06-29 22:36:11	2020-06-29	Jaylynn Upton-VonRueden	jaylynn.upton.vonrueden@geemail.com	Albuquerque	New Mexico	4337540718794	ba2026f4c98b19a2bd9ad9384c1e6a1e	Maestro	35.1127440355852301	-106.721128795163338
34165	2020-06-29 22:37:18	2020-06-29	Pattie Johnston-Hansen	pattie.johnston.hansen@geemail.com	Coral Springs	Florida	4807917459149	9f690242124d30c4ad123d6d2cdc51d2	Discover	26.2928351372543752	-80.3073400355998359
34166	2020-06-29 22:38:33	2020-06-29	Mr. Taylor Green	mr.taylor.green@woohoo.com	Henderson	Nevada	51906713003987024	d8b487f630eddf1b50e0f41562837acf	Maestro	36.0608835687328124	-114.986649015747759
34167	2020-06-29 22:39:56	2020-06-29	Dr. Maximo Konopelski V	dr.maximo.konopelski.v@woohoo.com	Chicago	Illinois	502067996880901	cb080184bc09f5846621b2f2b18b5bfc	JCB 15 digit	41.7916561885107356	-87.7571292776644185
34168	2020-06-29 22:46:07	2020-06-29	Linus Swift Sr.	linus.swift.sr.@geemail.com	Denver	Colorado	3460057279557174	9f27c6bcfe242aca04e0acccf41298d0	American Express	39.7940497990749762	-104.918607053278393
34169	2020-06-29 22:49:18	2020-06-29	Mr. Vashon Stiedemann I	mr.vashon.stiedemann.i@warmmail.com	Berkeley	California	3088981911649759520	6aa820fb894ca2ac11b33b1fcd61187a	JCB 16 digit	37.8665753377815335	-122.26739824168861
34170	2020-06-29 22:52:15	2020-06-29	Coen Lesch	coen.lesch@warmmail.com	Des Moines	Iowa	869969458790260853	862f583600bb8e61bf55296c4dab3ca6	JCB 16 digit	41.6680102118965223	-93.7058617277581334
34171	2020-06-29 23:02:32	2020-06-29	Sydnee Gleichner	sydnee.gleichner@warmmail.com	Chicago	Illinois	3158068606516803346	f66b829913aede5d442e5f4b050497a7	JCB 15 digit	41.8930001121781785	-87.7217843913968665
34172	2020-06-29 23:05:03	2020-06-29	Alger Lowe	alger.lowe@geemail.com	Los Angeles	California	675905373931814	8722baa6c1b0ce27ea8dc63ea4f30316	VISA 13 digit	34.1089986902061852	-118.425943231349066
34173	2020-06-29 23:13:22	2020-06-29	Mr. Orland Bashirian I	mr.orland.bashirian.i@warmmail.com	North Las Vegas	Nevada	4425962863204	032fdb24caba1b94d252c103351d2981	VISA 13 digit	36.2649667319532441	-115.125193731741618
34174	2020-06-29 23:14:36	2020-06-29	Dr. Vicente Torp III	dr.vicente.torp.iii@geemail.com	Roseville	California	3015133426448936	6da37f4bc69266312d88f1929d254583	VISA 16 digit	38.7652844287976635	-121.393071283328908
34175	2020-06-29 23:19:42	2020-06-29	Miss Sylva Goodwin DVM	miss.sylva.goodwin.dvm@geemail.com	Raleigh	North Carolina	3158358009727794835	c98518b1ff458eafa7dfd33478da4e5c	Voyager	35.8414023914508491	-78.5941899899795686
34176	2020-06-29 23:27:58	2020-06-29	Dr. Mikayla Halvorson	dr.mikayla.halvorson@geemail.com	Houston	Texas	869950770348155562	b7549398907e755431eedba924d13615	JCB 15 digit	29.7764195168469108	-95.3322044296205036
34177	2020-06-29 23:38:17	2020-06-29	Kayli Lynch	kayli.lynch@geemail.com	Savannah	Georgia	210041987271921966	06edb8a920df132820ee1343c2887b1a	JCB 15 digit	31.9849685538653254	-81.2305984158687266
34178	2020-06-29 23:52:11	2020-06-29	Precious Gutmann	precious.gutmann@geemail.com	Bellevue	Washington	869918106829910772	95ae23e443cff80b895ac6036b3bfd04	VISA 13 digit	47.57034217600674	-122.164606979634613
34179	2020-06-29 23:53:57	2020-06-29	Yoselin Crooks-O'Reilly	yoselin.crooks.o'reilly@geemail.com	Tulsa	Oklahoma	6011815205789335528	ee07154f93d69ff4c52b1b8b7db9490a	Maestro	36.0567860825821711	-95.8926730161022363
34180	2020-06-30 00:11:53	2020-06-30	Durrell Green	durrell.green@geemail.com	Los Angeles	California	3053190286870874	353ad60306fe5929ae45b6c25af72a0f	Voyager	33.9595796463411261	-118.359676676801584
34181	2020-06-30 00:19:08	2020-06-30	Jobe Kuhlman	jobe.kuhlman@geemail.com	Omaha	Nebraska	503800897442067	a7d85d971f0230637ce2b92339dd9ce5	Maestro	41.2095242037583134	-96.1386338602867028
34182	2020-06-30 00:23:24	2020-06-30	Dr. Suzette Gulgowski DVM	dr.suzette.gulgowski.dvm@warmmail.com	Oakland	California	4703438620717	8b08db57ffd40ce164b893ce67833060	Voyager	37.7780049802456546	-122.256429793542793
34183	2020-06-30 00:24:49	2020-06-30	Dr. Lora Schneider	dr.lora.schneider@woohoo.com	Norfolk	Virginia	3158463048777906917	e732054179664711bbf8f44f9931854b	Discover	36.9634161348473285	-76.2844428664077157
34184	2020-06-30 00:26:57	2020-06-30	Michal Ankunding-Cassin	michal.ankunding.cassin@warmmail.com	Chicago	Illinois	6011423018053062437	ff8765708803e7ceb2257cdb5196c265	VISA 16 digit	41.8461575025994321	-87.6422719937313275
34185	2020-06-30 00:29:44	2020-06-30	Sharonda Bahringer-Cummings	sharonda.bahringer.cummings@geemail.com	Los Angeles	California	3158257824049257606	46b9d8533ca94790fb763a69f233df44	JCB 16 digit	34.0915336298622194	-118.478672885754321
34186	2020-06-30 00:32:23	2020-06-30	Ms. Sondra Hodkiewicz	ms.sondra.hodkiewicz@geemail.com	Brownsville	Texas	869946897642345909	fa05076cd394db3a2f959362f72cc306	Discover	26.0732613930091262	-97.4112571795191542
34187	2020-06-30 00:36:22	2020-06-30	Arlen Kassulke	arlen.kassulke@geemail.com	Lakewood	Colorado	3337516294167443627	402dd772ca782a778f3abeb90bd5cbc5	VISA 16 digit	39.7898456023480733	-105.136945394475376
34188	2020-06-30 00:38:01	2020-06-30	Lashonda Anderson	lashonda.anderson@geemail.com	San Francisco	California	3048096254185333	2d78bf606630fc0c5c43e445256296bb	Maestro	37.7526552038620125	-122.419965411897081
34189	2020-06-30 00:42:37	2020-06-30	Valentino Sporer	valentino.sporer@geemail.com	Chicago	Illinois	869964502673263578	cad81b212f375040244d5daabb73d5e1	Maestro	41.8865466753788311	-87.662418627974759
34190	2020-06-30 00:46:52	2020-06-30	Darryle Stehr	darryle.stehr@geemail.com	Columbus	Ohio	3088438254025316170	a0b7befac390d522621a8cc1f55f0714	VISA 16 digit	40.0625256777785737	-82.9675763739042083
34191	2020-06-30 00:51:05	2020-06-30	Ms. Jerusha Kihn	ms.jerusha.kihn@geemail.com	Milwaukee	Wisconsin	4146156909846102	752487584774d0a27608c58fdeccea62	Diners Club / Carte Blanche	43.1082811935424814	-87.8766937877152117
34192	2020-06-30 00:51:33	2020-06-30	Abner Schulist II	abner.schulist.ii@woohoo.com	Mobile	Alabama	869988899559541214	5625f4c2e8f0bf15498dd460b8584983	Mastercard	30.7232764059320083	-88.1849216984722801
34193	2020-06-30 01:12:40	2020-06-30	Cornelious Weissnat	cornelious.weissnat@geemail.com	Denton	Texas	6011813222060296842	733562a0a71e7c84bfb71a1b843455e7	JCB 16 digit	33.3138492883913244	-97.1915377589069323
34194	2020-06-30 01:34:42	2020-06-30	Auther Runolfsson	auther.runolfsson@geemail.com	Oklahoma City	Oklahoma	4139298062187301	6e9ab1ecbe9314900d437a3d2027b99f	Maestro	35.3988106443922987	-97.5676250712841693
34195	2020-06-30 01:36:40	2020-06-30	Luster Hauck	luster.hauck@geemail.com	Hollywood	Florida	6011570690624064901	c7d8ca6c3d23eba9a3fb8f9696236ab7	Discover	25.9629025557022537	-80.2571899050198425
34196	2020-06-30 01:44:06	2020-06-30	Ferd Marquardt MD	ferd.marquardt.md@geemail.com	Tucson	Arizona	4065809994778	10267e13608eff718b00bbbf3d46a477	Mastercard	32.1437163285020731	-110.792194909438862
34197	2020-06-30 01:55:12	2020-06-30	Daron Skiles-Barrows	daron.skiles.barrows@geemail.com	San Francisco	California	4654913545573084	e5be8b4de1f4a29045ebcf56b461ddba	Diners Club / Carte Blanche	37.7704035275440617	-122.434155593827597
34198	2020-06-30 02:02:08	2020-06-30	Therman Runolfsson	therman.runolfsson@geemail.com	San Francisco	California	3017547370574629	eb3024c69792b3ebaef3342f5b0a6d06	American Express	37.7852914023290509	-122.434767141174831
34199	2020-06-30 02:04:47	2020-06-30	Duke Kovacek	duke.kovacek@geemail.com	El Paso	Texas	869937131579979428	41c7d632c9372b3ff5f8703239f9e12b	JCB 16 digit	31.908895923552663	-106.484313030259685
34200	2020-06-30 02:12:09	2020-06-30	Shaquille Beatty	shaquille.beatty@geemail.com	Augusta	Georgia	6011762469326367807	5d06ac685bec796d68f173a691513ab1	American Express	33.404699597015977	-82.0456289402503529
34201	2020-06-30 02:24:19	2020-06-30	Tyriq Dickens	tyriq.dickens@geemail.com	New York	New York	3088499609662258173	37d7c9b9cefff8cd3dd87a68c117fdec	VISA 16 digit	40.6830825945585985	-73.9575153332564952
34202	2020-06-30 02:28:18	2020-06-30	Tyler Adams	tyler.adams@warmmail.com	Seattle	Washington	4377755023951	a2d494ad3f8de4a924bcbcd373a62786	VISA 16 digit	47.6623277021963148	-122.376119473801552
34203	2020-06-30 02:30:12	2020-06-30	Lota Dooley DVM	lota.dooley.dvm@geemail.com	Laredo	Texas	6011849718867062343	6f095fa16d82eb9caa4789bc5143f974	Discover	27.5618034800697131	-99.5844794780023364
34204	2020-06-30 02:32:03	2020-06-30	Trinidad Blanda-Bartoletti	trinidad.blanda.bartoletti@geemail.com	New York	New York	501864808802660	8b9b388ea7891eb3263edc94aed6ab0d	VISA 16 digit	40.7614725881479671	-73.9945909967541695
34205	2020-06-30 02:33:32	2020-06-30	Mr. Dimitrios Mills I	mr.dimitrios.mills.i@geemail.com	Milwaukee	Wisconsin	3742321944631480	d885654487e383264fd5fb9983af3e71	VISA 16 digit	43.1112055857751528	-88.0477877290088742
34206	2020-06-30 02:33:41	2020-06-30	Milan Barton	milan.barton@geemail.com	San Jose	California	3088343580973763383	3989c473143a4ef9f743a9e57eed3200	Diners Club / Carte Blanche	37.3923082603894201	-121.776699386838445
34207	2020-06-30 02:57:21	2020-06-30	Nikita Kohler	nikita.kohler@woohoo.com	Louisville	Kentucky	6011096595458439043	57c7bfa637be631809cafe45b2ba969d	VISA 16 digit	38.1022936607148495	-85.6497840150795895
34208	2020-06-30 03:08:21	2020-06-30	Alexus Kertzmann	alexus.kertzmann@geemail.com	Oakland	California	869967792699387355	c60b08902f4af0700f2e9eec5244df4e	JCB 16 digit	37.8224162170822282	-122.272196165207305
34209	2020-06-30 03:14:39	2020-06-30	Ms. Tyesha Kuphal DDS	ms.tyesha.kuphal.dds@woohoo.com	Colorado Springs	Colorado	6011681207695468576	50c6821b94d4af87767df60783732720	JCB 16 digit	38.7812257702045144	-104.727406908121708
34210	2020-06-30 03:28:38	2020-06-30	Miss Katharine Upton MD	miss.katharine.upton.md@warmmail.com	Oakland	California	3528895779819522084	63922318898fa11efbe4f056f0c6e2dd	Maestro	37.7799120176198358	-122.241023226622715
34211	2020-06-30 03:29:56	2020-06-30	Arnulfo Heller-Powlowski	arnulfo.heller.powlowski@warmmail.com	San Jose	California	4082257964810037	6a38dbd27e32b123825991ae4f38a3c3	JCB 16 digit	37.2134224329896313	-121.751145518779381
34212	2020-06-30 03:33:04	2020-06-30	Donavon Haley	donavon.haley@geemail.com	Lafayette	Louisiana	4694439995127	e8560a18b3bbac922798baaa7be433e7	Diners Club / Carte Blanche	30.2554527219828202	-91.9791327999290047
34213	2020-06-30 03:45:37	2020-06-30	Keyshawn Crona	keyshawn.crona@woohoo.com	Philadelphia	Pennsylvania	4692605662034	78511d881fca939203283bb34a1eb604	VISA 16 digit	40.0964270515792052	-75.1439320642866306
34214	2020-06-30 03:48:22	2020-06-30	Luz Reichert	luz.reichert@woohoo.com	Seattle	Washington	060424990736084	236c92e1dc85a08174a287e1595fb215	VISA 16 digit	47.5642084506731493	-122.341911996380986
34215	2020-06-30 03:48:39	2020-06-30	Maiya Oberbrunner	maiya.oberbrunner@geemail.com	San Francisco	California	3528002521459723832	8d4cd07e2966cbc0a3c8329f35f08532	Maestro	37.7598933268785828	-122.427718771403363
34216	2020-06-30 04:03:09	2020-06-30	Mrs. Karley Simonis DVM	mrs.karley.simonis.dvm@geemail.com	El Paso	Texas	3096079055618067516	90491390df1cdcbb2b6e3a720ee0d3ab	JCB 16 digit	31.9097807976711572	-106.390971645804129
34217	2020-06-30 04:04:58	2020-06-30	Dr. Nyah O'Kon	dr.nyah.o'kon@geemail.com	Beaumont	Texas	6011637186423729423	ff3e6cdd089d2a92538d92f4544c43f7	JCB 16 digit	30.0735462573893386	-94.0567712096750768
34218	2020-06-30 04:08:12	2020-06-30	Marjorie Rippin-Rohan	marjorie.rippin.rohan@woohoo.com	Oakland	California	4670463879590791	1ba0baa098c7188cb15e707970baf9e1	VISA 16 digit	37.7837982208672116	-122.25974415146365
34219	2020-06-30 04:16:44	2020-06-30	Mrs. Lynne Stokes	mrs.lynne.stokes@geemail.com	Houston	Texas	180040167927531029	68528b05b13d35c1c970c557484fdc3c	JCB 16 digit	29.7242219934783876	-95.312839096972354
34220	2020-06-30 04:19:45	2020-06-30	Ogden Klein-Walsh	ogden.klein.walsh@warmmail.com	Huntington Beach	California	3158642853451755470	484bdb64c5cec83267594f085093d18d	JCB 16 digit	33.6416294497013126	-118.099352392845972
34221	2020-06-30 04:28:01	2020-06-30	Mr. Lindy Prosacco	mr.lindy.prosacco@woohoo.com	Corpus Christi	Texas	3528372453812960897	466df7a195c448bd6bb3258d6d1e44a0	American Express	27.6896269362356513	-97.2601902679368919
34222	2020-06-30 04:28:12	2020-06-30	Reece Leannon	reece.leannon@woohoo.com	Riverside	California	3444043314057231	940cfeff98126b6379a9cf33dae6c177	JCB 15 digit	33.9301709702186258	-117.424056974609186
34223	2020-06-30 04:42:31	2020-06-30	Ms. Julie Ullrich DDS	ms.julie.ullrich.dds@geemail.com	San Antonio	Texas	53987683968027631	f523dd33c08cc1b02bad50caa5f5dc55	VISA 16 digit	29.5391147428728651	-98.569721769338841
34224	2020-06-30 05:02:02	2020-06-30	Dr. Alonso Schowalter	dr.alonso.schowalter@geemail.com	Los Angeles	California	3528560410768636105	69f167b9c2df69b66faf336adacc8b19	Mastercard	33.9726070575747627	-118.49449104154408
34225	2020-06-30 05:13:57	2020-06-30	Wing Halvorson	wing.halvorson@woohoo.com	Boston	Massachusetts	3096643819215626157	5e3ba9c9bd676d28df1327c142763075	JCB 15 digit	42.4107829289212859	-70.991309961112961
34226	2020-06-30 05:16:19	2020-06-30	Esco Medhurst	esco.medhurst@geemail.com	San Francisco	California	676130843424810	d8e0adbc4746185765118524751fc028	American Express	37.7827348086429282	-122.443608031414655
34227	2020-06-30 05:32:29	2020-06-30	Isom Christiansen	isom.christiansen@geemail.com	New York	New York	4051639699184381	b014c3f87f8d4563ef7ed2fc302100b1	VISA 16 digit	40.7488857139125429	-73.8546225001931163
34228	2020-06-30 05:37:02	2020-06-30	Yaretzi Leffler	yaretzi.leffler@geemail.com	Phoenix	Arizona	675943698439502	f4e4a677773b7b7e28cdd22bb14da423	JCB 16 digit	33.5937349231381006	-112.147208414871628
34229	2020-06-30 05:38:17	2020-06-30	Milford Lind DDS	milford.lind.dds@geemail.com	Austin	Texas	210078333490697804	4deaea31296a3de6d1d0227489888f86	JCB 15 digit	30.2873482656791779	-97.6651014422770629
34230	2020-06-30 05:43:16	2020-06-30	Ms. Melodie Russel	ms.melodie.russel@warmmail.com	Hillsboro	Oregon	210070647612108434	4908b842e9d271cde97bbb1ee819aecd	JCB 15 digit	45.6062374268863309	-122.906939488665017
34231	2020-06-30 05:44:00	2020-06-30	Ms. Baylee Mayer	ms.baylee.mayer@geemail.com	Phoenix	Arizona	3711197399697466	c9dabac09846b86bce2b8ecf677f3c86	VISA 16 digit	33.5512725935250558	-112.151512464128814
34232	2020-06-30 05:46:17	2020-06-30	Dixon Mitchell	dixon.mitchell@warmmail.com	New Orleans	Louisiana	4196621005086266	a79fe24782d7ef4ab73a5ca1404a3983	VISA 13 digit	30.0030340944431728	-89.9956952318809869
34233	2020-06-30 05:53:08	2020-06-30	Zettie Lockman	zettie.lockman@warmmail.com	Houston	Texas	55090238571723854	937c26fc26f3e8a0a8b5b8d4cd46b1f3	Voyager	29.8010239588640644	-95.3799774252824477
34234	2020-06-30 06:00:54	2020-06-30	Kelvin Hoppe	kelvin.hoppe@geemail.com	Oakland	California	3041873929981438	464edc878791f77d768bf3b216555347	American Express	37.8059339978526694	-122.288292979889647
34235	2020-06-30 06:23:40	2020-06-30	Acie Parker	acie.parker@geemail.com	Round Rock	Texas	3088932589143105380	90cdee35edbabecebdefe9008351b593	Mastercard	30.5109238684780912	-97.69777182585932
34236	2020-06-30 06:30:53	2020-06-30	Archie Rath	archie.rath@geemail.com	Vista	California	180091031637814299	08d9fa87eb5b1de9709d106cbcb5f61b	Diners Club / Carte Blanche	33.1084536600839385	-117.221853669226547
34237	2020-06-30 06:31:14	2020-06-30	Madilyn Wiegand	madilyn.wiegand@warmmail.com	New York	New York	3158115890924365378	718164c7a67b0482066596784d36ccd1	Mastercard	40.5825408840309834	-73.9264698266413092
34238	2020-06-30 06:31:27	2020-06-30	Dr. Debbra Schamberger DVM	dr.debbra.schamberger.dvm@geemail.com	Boston	Massachusetts	6011148138096216818	3574cf7f0a3a9cc0b65ad620e342425d	Discover	42.2754207174461314	-71.0557715747457053
34239	2020-06-30 06:55:18	2020-06-30	Selena Bechtelar	selena.bechtelar@geemail.com	Los Angeles	California	675913124259196	66461db821e2bb7e004aa99262d82aec	Mastercard	34.0875246716529077	-118.333529032579804
34240	2020-06-30 06:56:46	2020-06-30	Dr. Gustavus Barton DDS	dr.gustavus.barton.dds@geemail.com	Los Angeles	California	6011031414674651845	1b636c79a958081366976ecc1a2f7686	Diners Club / Carte Blanche	33.946356501463427	-118.425494701274857
34241	2020-06-30 07:04:03	2020-06-30	Lilianna Herman	lilianna.herman@warmmail.com	Peoria	Illinois	3711375962882281	2e1e887c906600ff8fb7a2dbbc342d34	VISA 16 digit	40.6532797689884902	-89.5662141336478328
34242	2020-06-30 07:20:36	2020-06-30	Tommy Witting-Schinner	tommy.witting.schinner@woohoo.com	San Francisco	California	4090864292785	25f2cb4da606ed3d47930c4af2dff03c	Maestro	37.7832436848320512	-122.474854904533672
34243	2020-06-30 07:20:36	2020-06-30	Fidencio Predovic-Bradtke	fidencio.predovic.bradtke@geemail.com	San Francisco	California	3765255877220907	10cd87d40718b96f22afd3392def451b	Mastercard	37.830655341992717	-122.421487707435006
34244	2020-06-30 07:25:21	2020-06-30	Chalmer Walsh-Weimann	chalmer.walsh.weimann@geemail.com	San Diego	California	180029213825194570	707cbdcd0b05a879e1c17ff1e03d4b7f	Mastercard	32.8136157847076646	-117.221461959593
34245	2020-06-30 07:37:58	2020-06-30	Laverna Schuster-Mann	laverna.schuster.mann@geemail.com	Oakland	California	180002885276530971	b1ffc9b26b2bbd1dec511959453259c5	Discover	37.7892834945135476	-122.309799603978021
34246	2020-06-30 07:38:38	2020-06-30	Deirdre Orn MD	deirdre.orn.md@geemail.com	San Bernardino	California	503864257623146	aa38a31eeb4fdda150ba347f459d0f02	Diners Club / Carte Blanche	34.1107112574189841	-117.380458205776662
34247	2020-06-30 07:54:43	2020-06-30	Errol Schmitt	errol.schmitt@woohoo.com	Escondido	California	210028004436386098	f9ba8dca48d3a6d2fd1ebd9b7c6ed7d0	VISA 16 digit	33.184721832931416	-117.118484419561923
34248	2020-06-30 07:56:38	2020-06-30	Nohely Collier-Mann	nohely.collier.mann@geemail.com	Victorville	California	4157402472580108	e4954a58fd015c497b00d0125dd50885	Discover	34.5930596357442468	-117.276822541669389
34249	2020-06-30 08:04:36	2020-06-30	Lilia O'Keefe	lilia.o'keefe@geemail.com	New York	New York	3461212749899446	a7d39c2a8045eb7062a6042ec4a77f92	JCB 16 digit	40.6521240229010559	-73.9686713275860939
34250	2020-06-30 08:11:23	2020-06-30	Ms. Rikki Prohaska DDS	ms.rikki.prohaska.dds@geemail.com	Greensboro	North Carolina	4971810101202817	da725031c6c93c2601afbcdfac658cce	Voyager	36.0750026734661304	-79.9088667202256602
34251	2020-06-30 08:11:38	2020-06-30	Joetta Zieme	joetta.zieme@geemail.com	New York	New York	3088884978985026267	f3ce56a51d911ac7a71ce67dc2a3fc28	Mastercard	40.6806278601977951	-73.8956569379091235
34252	2020-06-30 08:17:27	2020-06-30	Antony O'Kon	antony.o'kon@geemail.com	San Francisco	California	55844484770432587	affadbf72b8a4abb5a690dcf35b83c23	Mastercard	37.8151709319124834	-122.441651216963308
34253	2020-06-30 08:25:33	2020-06-30	Esley McDermott	esley.mcdermott@geemail.com	San Antonio	Texas	3337141923663283672	a23eb4bb4e0047f5d0c5ff5b54d6b9b6	Discover	29.5650553711760793	-98.4820577570538944
34254	2020-06-30 08:27:07	2020-06-30	Dr. Margarete McClure PhD	dr.margarete.mcclure.phd@geemail.com	Sparks	Nevada	51241923331675993	20dcba0dcfb5ef681009befb68947031	VISA 16 digit	39.514629235747833	-119.683172185238831
34255	2020-06-30 08:31:06	2020-06-30	Mr. Braulio Terry IV	mr.braulio.terry.iv@geemail.com	San Jose	California	6011681518833015040	3155c4b040fac0abcbb3d248732569fb	JCB 16 digit	37.3940928278312086	-121.828845210861047
34256	2020-06-30 08:37:34	2020-06-30	Commodore Terry	commodore.terry@geemail.com	Louisville	Kentucky	3002581659582396	cd642b273dcfd584f3f9ec0ad4855841	JCB 15 digit	38.2040190261226158	-85.7465382570937322
34257	2020-06-30 08:38:18	2020-06-30	Dr. Aniya Herman MD	dr.aniya.herman.md@geemail.com	Meridian	Idaho	210063201152257224	1d3c0c8d008b0822b96cc4fdac1658ce	JCB 16 digit	43.6808474050376532	-116.401408676610885
34258	2020-06-30 08:47:04	2020-06-30	Alexandra Johns	alexandra.johns@warmmail.com	San Francisco	California	4770533916661760	1bfe4824aa75dcee0d89e44c7cdf9a5f	VISA 16 digit	37.7594667115623892	-122.416643780057086
34259	2020-06-30 08:52:08	2020-06-30	Eduardo Weber	eduardo.weber@geemail.com	Overland Park	Kansas	3096524946768206105	56eb66eed3bd4a3b9b2b45b3716ab596	Discover	38.8953021847046969	-94.7747938399244134
34260	2020-06-30 08:55:23	2020-06-30	Atha Kemmer	atha.kemmer@woohoo.com	Miramar	Florida	4684432669167	eacc73ac7d1d93509d8d48317c69081b	Diners Club / Carte Blanche	26.001927969696002	-80.3198895348228632
34261	2020-06-30 08:56:46	2020-06-30	Wiley Christiansen II	wiley.christiansen.ii@geemail.com	Bakersfield	California	502031666460436	6701fd17b3172ac8fc8cb511e48d4d0e	Discover	35.3838750849187349	-118.922311102253573
34262	2020-06-30 09:00:22	2020-06-30	Cheri Williamson	cheri.williamson@geemail.com	Oakland	California	3096069403193094020	abc936467f9ef7e29de2c3d722affe6a	Voyager	37.8250554399872456	-122.295562383234127
34263	2020-06-30 09:04:36	2020-06-30	Eddie Bosco	eddie.bosco@geemail.com	San Diego	California	501817930742469	589fde1338ba7d0007a8d42a8195e674	VISA 16 digit	32.8092504565671064	-117.141759588001307
34264	2020-06-30 09:05:10	2020-06-30	Lannie Walker	lannie.walker@woohoo.com	Fort Lauderdale	Florida	54873876992745791	cf41449fd6bfe6157c4b9cf9c20e81f4	VISA 13 digit	26.0479531773354864	-80.1799380816340346
34265	2020-06-30 09:28:28	2020-06-30	Georgene Kub-Metz	georgene.kub.metz@geemail.com	Cary	North Carolina	6011998726599799560	1e0ba2212b297933203339876a403030	JCB 16 digit	35.7859394104793722	-78.7742709907788736
34266	2020-06-30 09:30:32	2020-06-30	Jailene Crooks	jailene.crooks@woohoo.com	Los Angeles	California	3444347743028634	9e06f4ed6a08c689618f1e2fb27a6e71	VISA 13 digit	34.0818417495448145	-118.327755175064496
34267	2020-06-30 09:31:45	2020-06-30	Mr. Braiden Schroeder I	mr.braiden.schroeder.i@geemail.com	Antioch	California	4810982524533519	36b252e7571079be6e425ec1357c3ee8	VISA 13 digit	38.0035216815102856	-121.722523298690845
34268	2020-06-30 09:33:50	2020-06-30	Dione O'Hara-Mueller	dione.o'hara.mueller@woohoo.com	Jacksonville	Florida	4937325863248307	9a3759a1452d4bc08a8207eccf0cafb4	Voyager	30.2666134988941238	-81.6906975093841652
34269	2020-06-30 09:49:19	2020-06-30	Treyvon Bergnaum	treyvon.bergnaum@geemail.com	New York	New York	3442771867089027	e2efcad6efe442363aef7d52bbd305ca	Diners Club / Carte Blanche	40.5717919674459822	-73.9974586726993238
34270	2020-06-30 09:59:56	2020-06-30	Lamonte Blanda	lamonte.blanda@woohoo.com	Chicago	Illinois	6011489110277303928	b3d4b5ac41cb8e6038d2a7cb0f90b46d	Maestro	41.8140460013713735	-87.6429335614230496
34271	2020-06-30 10:05:42	2020-06-30	Nakia Schoen	nakia.schoen@warmmail.com	New York	New York	3158762977237265928	c9e38fcc441a1191e25716f8614dc679	Discover	40.6791243288423843	-74.013461094292623
34272	2020-06-30 10:39:24	2020-06-30	Claudius Hickle Sr.	claudius.hickle.sr.@geemail.com	San Francisco	California	4312597224530012	c80ad5b864097b3db7037f2b2cdc44ad	Maestro	37.7573651164838182	-122.432508043779436
34273	2020-06-30 10:40:11	2020-06-30	Dr. Towanda Ferry DVM	dr.towanda.ferry.dvm@geemail.com	Surprise	Arizona	502037471549321	109d4935ec9bc2d438da2536d79336f2	American Express	33.6340468533098687	-112.395907046622398
34274	2020-06-30 10:46:49	2020-06-30	Hollis Rath	hollis.rath@geemail.com	New York	New York	3096006096286585783	2e90791bd9897cae84cd036dedb55b0c	Diners Club / Carte Blanche	40.7036995671913004	-74.0110368585575316
34275	2020-06-30 10:50:02	2020-06-30	Hector Armstrong	hector.armstrong@geemail.com	Oakland	California	3337330035586475482	fc065fcb611489d1bc456c3498d98b4d	VISA 16 digit	37.8128992138068654	-122.247295178317614
34276	2020-06-30 10:50:43	2020-06-30	Wood Klein MD	wood.klein.md@geemail.com	Modesto	California	180023885149673342	0c830ce13271433f0a2c6ce574201cd1	JCB 15 digit	37.7189172914717403	-120.926612148035318
34277	2020-06-30 10:58:36	2020-06-30	Milburn Baumbach	milburn.baumbach@woohoo.com	Peoria	Illinois	3088171951532864185	0f53b9047382d3e905c345606515de83	Discover	40.7685286161359386	-89.6358564958326554
34278	2020-06-30 11:04:19	2020-06-30	Dr. Ingram Oberbrunner	dr.ingram.oberbrunner@woohoo.com	Columbus	Ohio	3528844984386614957	37534b6e52d7a063d87626ad7be335bd	Discover	39.8981219058901075	-82.926792164961995
34279	2020-06-30 11:17:43	2020-06-30	Kaleena Farrell-Rowe	kaleena.farrell.rowe@geemail.com	Indianapolis	Indiana	52592885462034206	9a0d6b003a898af37793143e483a66f9	VISA 13 digit	39.7085951057735826	-86.2114832759570362
34280	2020-06-30 11:18:24	2020-06-30	Mr. Lynwood Yundt	mr.lynwood.yundt@geemail.com	Long Beach	California	6011433755509645426	52b85a03a229e1809f06dbc4c0304717	JCB 16 digit	33.8870268352150887	-118.142301396249977
34281	2020-06-30 11:23:53	2020-06-30	Dr. Mikel Reinger	dr.mikel.reinger@warmmail.com	Grand Rapids	Michigan	4779118746562502	66a1f17e7ccd18ad86a2afd0238628e1	Maestro	42.990867997453357	-85.7328591300774434
34282	2020-06-30 11:26:07	2020-06-30	Hobson Davis	hobson.davis@geemail.com	Vista	California	3096681278881670242	bc43c341c0aabdc9fc82d22bb857c248	Discover	33.1035413803979779	-117.236888297234103
34283	2020-06-30 11:45:15	2020-06-30	Alcee Vandervort-Nader	alcee.vandervort.nader@geemail.com	Berkeley	California	3158425475556697119	acfac242538b435e4056455e4161c41c	JCB 16 digit	37.8747387893437306	-122.293270453624473
34284	2020-06-30 11:47:59	2020-06-30	Hugh Greenfelder-Yost	hugh.greenfelder.yost@woohoo.com	Pembroke Pines	Florida	4219184307235	db2adcd327f8a7706472421ec16dd2c9	Discover	26.1008052540980273	-80.2490472136434221
34285	2020-06-30 11:55:01	2020-06-30	Lydell O'Connell	lydell.o'connell@geemail.com	New York	New York	4587414114948	a818293f9b6e318173db7c74d7a6f6c0	American Express	40.5720952323395778	-73.9541112663585665
34286	2020-06-30 12:11:55	2020-06-30	Cain Kuphal	cain.kuphal@geemail.com	Madison	Wisconsin	4572386969628	a7ed937d4bfd0ed51f3da9d4542ec193	JCB 15 digit	43.0730991093881457	-89.4894575958490464
34287	2020-06-30 12:28:18	2020-06-30	Caryn Farrell	caryn.farrell@geemail.com	New York	New York	3112611605110523138	d3546eeeb5076ee3146c7a9c21a683a0	Discover	40.7131635315474085	-73.8936327862448934
34288	2020-06-30 12:29:30	2020-06-30	Thelma Krajcik	thelma.krajcik@woohoo.com	Cape Coral	Florida	3489726819418959	624ae37f93b4a588e2bbfc71704a1f14	Diners Club / Carte Blanche	26.5622433469135331	-82.0370045489702306
34289	2020-06-30 12:42:25	2020-06-30	Kiley West PhD	kiley.west.phd@geemail.com	Ann Arbor	Michigan	3337706862704563840	9a6df5ab88888d11637c100a03ebc730	Diners Club / Carte Blanche	42.3490835191275892	-83.8057697844333944
34290	2020-06-30 12:42:39	2020-06-30	Dylon Luettgen	dylon.luettgen@geemail.com	New York	New York	869995680258765556	0d5c9e41dcc11072ae4010a25b8e9271	Diners Club / Carte Blanche	40.5732385744098565	-73.9602704937465489
34291	2020-06-30 13:19:37	2020-06-30	Ms. Myrna Ferry DDS	ms.myrna.ferry.dds@geemail.com	Kansas City	Missouri	4276692036404482	0ac70378b8824f54f6cddcc9dcd400f9	Discover	39.1373482574079219	-94.6410974087417145
34292	2020-06-30 13:25:31	2020-06-30	Ms. Susannah Fisher	ms.susannah.fisher@geemail.com	Hialeah	Florida	869943030309530653	4a47646348a5b60130f18738e4f63955	American Express	25.8069404670014997	-80.3231644224744201
34293	2020-06-30 13:28:47	2020-06-30	Tobin Jerde	tobin.jerde@geemail.com	Houston	Texas	6011990461935467957	264fb516ffac479bd76374bed7bf2e15	JCB 15 digit	29.8093993588894612	-95.3155049823705127
34294	2020-06-30 13:30:16	2020-06-30	Valentin Wiza	valentin.wiza@geemail.com	Seattle	Washington	3432694351297686	c0446b5087a16ac11bd6c20d140bd421	JCB 16 digit	47.7042817879859342	-122.259647403044255
34295	2020-06-30 13:31:18	2020-06-30	Miss Lucero Williamson MD	miss.lucero.williamson.md@geemail.com	Las Vegas	Nevada	869914922806026638	2bee1ab1bd5a84c637ceaa6fbf5b8344	Diners Club / Carte Blanche	36.2726110653586673	-115.29381932785958
34296	2020-06-30 13:31:33	2020-06-30	Asha Zieme	asha.zieme@warmmail.com	New Orleans	Louisiana	3426985878535378	31adccda820876d047bc84bf48884845	Voyager	30.0685323538273579	-90.0264979187659975
34297	2020-06-30 13:33:18	2020-06-30	Ernest Heathcote	ernest.heathcote@geemail.com	New York	New York	3528170098816517922	9d4225cbe37efb4073bd2c300fa7d01c	JCB 16 digit	40.5960443807523674	-73.8690760094568049
34298	2020-06-30 13:37:11	2020-06-30	Jameel Kerluke	jameel.kerluke@geemail.com	Winston–Salem	North Carolina	3158876865570623055	b4c528c0b90663fa3a4dfaba4d0ab435	JCB 16 digit	36.1475188088834258	-80.3066702314782788
34299	2020-06-30 13:42:49	2020-06-30	Mortimer Koepp	mortimer.koepp@geemail.com	Mesa	Arizona	869936674349165332	3d16b73b68c6ec27022c4c9c6f3b5dba	VISA 13 digit	33.445059218272192	-111.676025354338435
34300	2020-06-30 14:08:51	2020-06-30	Sergio Gorczany	sergio.gorczany@geemail.com	Houston	Texas	6011181337929783519	1b71db8a74fb4b73dfe0e3f3875fa0f0	JCB 16 digit	29.8646991329811513	-95.4320209994927069
34301	2020-06-30 14:19:29	2020-06-30	Damari Reilly	damari.reilly@geemail.com	Oakland	California	180055217962063586	15c937c5f5fbcf188aa1ea44eded7b4a	Discover	37.7773216327314643	-122.242997660842775
34302	2020-06-30 14:21:22	2020-06-30	Corey King-Herzog	corey.king.herzog@warmmail.com	Grand Prairie	Texas	3754333485059422	6e276944a9d0e0f8bfcb3f7bab6ff1d5	Voyager	32.7055557490378632	-96.9313052290923878
34303	2020-06-30 14:23:09	2020-06-30	Regena O'Connell	regena.o'connell@geemail.com	Austin	Texas	53705905509519136	e67c2f92b2c45997ec8cba19b9fa2e27	VISA 13 digit	30.3854278066322188	-97.7576582585234206
34304	2020-06-30 14:31:15	2020-06-30	Newman Langworth	newman.langworth@geemail.com	Los Angeles	California	676132906001097	c19fa80e99999bb565cb757660dd2ece	Diners Club / Carte Blanche	34.0489186359900984	-118.498960186307499
34305	2020-06-30 14:39:57	2020-06-30	Virgle Mohr	virgle.mohr@geemail.com	Denton	Texas	3026113106496693	1b2e52168715da03697adbb4a4917864	JCB 16 digit	33.12729810781628	-97.0526991355359598
34306	2020-06-30 14:46:18	2020-06-30	Achsah Kihn DDS	achsah.kihn.dds@geemail.com	Los Angeles	California	4887709066583	c15e4726d24fd4ac7180ec0a59029cfb	JCB 16 digit	33.9949993037484575	-118.366359161398549
34307	2020-06-30 15:11:00	2020-06-30	Jayme Spencer	jayme.spencer@geemail.com	Las Vegas	Nevada	3030577386835869	0d03ed490721bd31a7ec8ab89effe43a	JCB 15 digit	36.1648324615422609	-115.305089917566988
34308	2020-06-30 15:14:18	2020-06-30	Cuba Bartoletti	cuba.bartoletti@geemail.com	Cleveland	Ohio	4659984887854	bafced43f4cb7be555410655ec396e61	VISA 16 digit	41.4604766577333166	-81.6913810496922537
34309	2020-06-30 15:14:59	2020-06-30	Maricela D'Amore PhD	maricela.d'amore.phd@woohoo.com	Chicago	Illinois	3158501302039821081	ace8386a3fc75de23e4303207e2b4688	JCB 16 digit	41.8234876456040894	-87.6970419610880327
34310	2020-06-30 15:25:34	2020-06-30	Mr. Olen Larson	mr.olen.larson@warmmail.com	Seattle	Washington	4413988180601525	a8622e35a78240abfc5ef1ea2adec12a	JCB 16 digit	47.5858518888633668	-122.279522771287333
34311	2020-06-30 15:47:24	2020-06-30	Dr. Job Zboncak PhD	dr.job.zboncak.phd@geemail.com	Arlington	Texas	3795894845690645	63c1122673580a4f2551421e6402ef48	Diners Club / Carte Blanche	32.7732467131473086	-97.1057217793099596
34312	2020-06-30 15:56:17	2020-06-30	Devon Dickens	devon.dickens@geemail.com	Lincoln	Nebraska	589316899713875	763e0346647b5713298278cb027ff6a4	Voyager	40.7812071503624267	-96.7697803975243147
34313	2020-06-30 16:03:50	2020-06-30	Cristofer Casper-Fisher	cristofer.casper.fisher@geemail.com	Ann Arbor	Michigan	180088556944330444	9bb7ccee2d1e2a593141ac47dcfe8827	Maestro	42.2553586030438524	-83.7135953785959686
34314	2020-06-30 16:05:05	2020-06-30	Mignon Doyle-Fay	mignon.doyle.fay@geemail.com	New York	New York	3754983495197867	c9b549cd1bd99427d373139ac566e000	JCB 15 digit	40.6220681807715422	-73.9803372037958269
34315	2020-06-30 16:05:35	2020-06-30	Earlie Hamill	earlie.hamill@geemail.com	Saint Paul	Minnesota	3738872116489970	d233fa1a8adac1930859bcabee67544b	Maestro	44.9387109675850738	-93.1865260995257643
34316	2020-06-30 16:16:23	2020-06-30	Ingeborg Hauck-Tillman	ingeborg.hauck.tillman@geemail.com	Charlotte	North Carolina	4648770146560004	54d578799536d1a33d35c90f1edc5b9a	VISA 16 digit	35.1410148592919072	-80.7372369725201366
34317	2020-06-30 16:17:50	2020-06-30	Joanna Koss	joanna.koss@geemail.com	Scottsdale	Arizona	676154178380884	635f2c2ee6092e9a7ebcfbcc292751a2	VISA 16 digit	33.6368096467230444	-111.800238879440712
34318	2020-06-30 16:40:21	2020-06-30	Dr. Rocco Vandervort DDS	dr.rocco.vandervort.dds@woohoo.com	New York	New York	869917816051132603	fcfb8c5002540773e39fabd7c3665849	American Express	40.7583393155355012	-73.8982214751083433
34319	2020-06-30 16:47:22	2020-06-30	Kelby Feil	kelby.feil@warmmail.com	Los Angeles	California	3436777367178838	272084088166330a6d30208a28e89d80	Diners Club / Carte Blanche	33.9859748021565338	-118.34924146882183
34320	2020-06-30 17:06:06	2020-06-30	Maximillian Schinner	maximillian.schinner@geemail.com	New York	New York	210050355537501311	88046f3a4c964bba7ee050a34c718f9d	JCB 15 digit	40.688134832935404	-74.0074098827213049
34321	2020-06-30 17:09:23	2020-06-30	Dr. Harman Welch	dr.harman.welch@geemail.com	Philadelphia	Pennsylvania	3748108977447338	13d5fbdf1864ace2af9dd576466b7dc6	Voyager	39.9875990866642468	-75.0929459924243474
34322	2020-06-30 17:20:56	2020-06-30	Elaina Koelpin MD	elaina.koelpin.md@geemail.com	San Francisco	California	4998130078635702	f53cc72753015225c33bd23c2444e72b	JCB 16 digit	37.8268907391351519	-122.430934061267166
34323	2020-06-30 17:23:21	2020-06-30	Haden Steuber DVM	haden.steuber.dvm@geemail.com	Oxnard	California	6011026129767801340	fd5b72bdfb9df56452f81aec8180d1f9	Discover	34.1143521636679807	-119.249725618763264
34324	2020-06-30 17:28:24	2020-06-30	Jazmyn DuBuque	jazmyn.dubuque@woohoo.com	Los Angeles	California	4719422546163	c5608ad5cc96edd5f46f66093df99d3d	Diners Club / Carte Blanche	33.9372028140682716	-118.498050725459308
34325	2020-06-30 17:42:58	2020-06-30	Mackenzie Leffler PhD	mackenzie.leffler.phd@geemail.com	Columbus	Ohio	4171757040505	a2b8baea7f96d6ab7704b8a74bfa8835	JCB 16 digit	39.9958323715765047	-83.0594935897041182
34326	2020-06-30 17:49:12	2020-06-30	Clotilde Reichel	clotilde.reichel@geemail.com	Minneapolis	Minnesota	3112906259152937022	8bdcd6cfed64e1ea5cee53e1e9bd400a	Discover	44.9537671754222359	-93.2198846834983641
34327	2020-06-30 17:54:56	2020-06-30	Dr. Hassan Hirthe	dr.hassan.hirthe@geemail.com	Berkeley	California	3158567193117494482	8265df28e7f926be48f6b2c41fbf16d7	Maestro	37.9074648036383763	-122.264042345958075
34328	2020-06-30 17:59:19	2020-06-30	Dr. Eliezer Leannon	dr.eliezer.leannon@woohoo.com	San Francisco	California	3011493629388238	65ac9d3e935e899b5cea921e43b9e210	Maestro	37.7775171153626061	-122.436027305653354
34329	2020-06-30 18:00:34	2020-06-30	Lynn Emmerich	lynn.emmerich@geemail.com	San Francisco	California	4137777737675529	48da983454856e60bf26027a442cbb77	Diners Club / Carte Blanche	37.7575849093400038	-122.424002298632189
34330	2020-06-30 18:06:45	2020-06-30	Miss Lindy Dach	miss.lindy.dach@geemail.com	Des Moines	Iowa	4770319584687216	358b1a21daafeb12f4ea60b2c8abdf08	Discover	41.566378886040674	-93.6734470544427751
34331	2020-06-30 18:16:04	2020-06-30	Chante Koch	chante.koch@geemail.com	Miami	Florida	639058967510932	898091b4df852d9a91f4caf9ebdba9c2	Mastercard	25.7452710500590527	-80.2986725399609753
34332	2020-06-30 18:17:28	2020-06-30	Johana Fritsch	johana.fritsch@geemail.com	Denver	Colorado	3528935776447768883	84abc052b8e23b7e05ffbcd27e2a1e83	JCB 16 digit	39.6809972871612757	-104.821208669083575
34333	2020-06-30 18:20:47	2020-06-30	Hans Fahey DDS	hans.fahey.dds@warmmail.com	Jacksonville	Florida	3792052079448171	97f3ff0b01d874f2318e8a4b804ddba6	VISA 13 digit	30.3653188929479576	-81.6123158692926296
34334	2020-06-30 18:22:26	2020-06-30	Dr. Elbert McCullough	dr.elbert.mccullough@geemail.com	Omaha	Nebraska	6011105522764003189	e2e668c0209a3556e189884a9ddf872d	Diners Club / Carte Blanche	41.3243571096245219	-96.0848255501244211
34335	2020-06-30 18:28:06	2020-06-30	Mr. Layton Mosciski	mr.layton.mosciski@warmmail.com	Riverside	California	4577770544713333	053768a77afcf97fa399aa7ad62509ee	Mastercard	34.0052636274084463	-117.332781534126767
34336	2020-06-30 18:29:48	2020-06-30	Jabbar Pouros	jabbar.pouros@woohoo.com	Nashville	Tennessee	3528226913832646212	ac5bb2062ae71cbecfb5ca3032407e2e	VISA 16 digit	36.1147911457467785	-86.7213737710751502
34337	2020-06-30 18:45:56	2020-06-30	Vic Willms	vic.willms@geemail.com	Oakland	California	3528875241882229455	198464a73525a1cefe7c078a212e6363	JCB 16 digit	37.7796773964910102	-122.304579123192212
34338	2020-06-30 18:49:45	2020-06-30	Danna Baumbach	danna.baumbach@warmmail.com	Clarksville	Tennessee	4363284860205021	a7d8bc5c0a10d33a0d3ee21b5237869a	Mastercard	36.5902561546430007	-87.3123043646521921
34339	2020-06-30 18:52:37	2020-06-30	Miss Orma Kirlin DDS	miss.orma.kirlin.dds@geemail.com	Reno	Nevada	4443606744870	24346fc0071ac233515cf5cce80147eb	JCB 16 digit	39.6441806905049887	-119.948272624209153
34340	2020-06-30 18:53:03	2020-06-30	Mr. Case Marvin V	mr.case.marvin.v@woohoo.com	Chesapeake	Virginia	4427975514978202	b6d58a1b94639590174eaecfee948334	VISA 13 digit	36.6915445862576348	-76.3460325547803222
34341	2020-06-30 18:54:22	2020-06-30	Starling Rosenbaum	starling.rosenbaum@warmmail.com	Washington	District of Columbia	4612742712864	827bde33655459a4f6f35f2e8566a943	American Express	38.9604348853494997	-77.0128972788088078
34342	2020-06-30 19:00:43	2020-06-30	Mr. Demetri Jacobs	mr.demetri.jacobs@geemail.com	Chicago	Illinois	869982442746084990	84575a3203fc302dce6a3e8a9a6065d0	Mastercard	41.8922977347228667	-87.6814743689291163
34343	2020-06-30 19:02:24	2020-06-30	Michelina Koch	michelina.koch@geemail.com	Washington	District of Columbia	869928409147522677	f2e2ec78ceed2f35df1d93d8708a2ea0	VISA 16 digit	38.9129877367321413	-76.948778108342367
34344	2020-06-30 19:03:58	2020-06-30	Mr. Trent Tillman I	mr.trent.tillman.i@woohoo.com	Scottsdale	Arizona	4630137586131	77e6af29afc9f23d479b9eef407cc803	JCB 16 digit	33.6972817706998455	-111.934865238095071
34345	2020-06-30 19:05:19	2020-06-30	Winford Moen	winford.moen@geemail.com	San Jose	California	3088813248799348281	075cd63f21306f9da8c397bbfbd7e95e	VISA 16 digit	37.2878551625002217	-121.895622945272919
34346	2020-06-30 19:10:20	2020-06-30	Miss Rena Schaden	miss.rena.schaden@geemail.com	San Francisco	California	3023290034935100	370980308fcc524a132eed59b15b58c2	VISA 13 digit	37.7807405397593641	-122.422383478531799
34347	2020-06-30 19:24:02	2020-06-30	Edwardo Feeney	edwardo.feeney@warmmail.com	Clovis	California	676287000554946	c1e6fc62c0a77366761146fd35e18f45	VISA 13 digit	36.8328380884945403	-119.611326744414498
34348	2020-06-30 19:25:28	2020-06-30	Rahn Weber Jr.	rahn.weber.jr.@geemail.com	Evansville	Indiana	639084436344927	00a2d96425a301a032f3099b95e716a6	JCB 15 digit	37.8997317792519866	-87.491072936069969
34349	2020-06-30 19:35:36	2020-06-30	Zettie Spinka	zettie.spinka@warmmail.com	Tyler	Texas	3158186685216114979	bbd0b78fbe4f1218643cd4228e0b568e	Voyager	32.3978028089787813	-95.3061074186690149
34350	2020-06-30 19:36:34	2020-06-30	Clemmie Deckow III	clemmie.deckow.iii@warmmail.com	Inglewood	California	676229653937812	059a798aee0fd7035df3c27e94196a43	JCB 16 digit	33.9292034108903238	-118.41435941960961
34351	2020-06-30 19:57:41	2020-06-30	Burnett Abbott	burnett.abbott@woohoo.com	Augusta	Georgia	3055272502440613	9e3c4dcd42cfc6f37ec43be4f33a7035	VISA 16 digit	33.3356142028439777	-82.0284193326547779
34352	2020-06-30 20:02:00	2020-06-30	Mrs. Emily Wisoky DVM	mrs.emily.wisoky.dvm@geemail.com	Elizabeth	New Jersey	4042269408764836	2db4660122d6d1d6fafcd73da9e259eb	Discover	40.6137910816013843	-74.1237448864094972
34353	2020-06-30 20:08:05	2020-06-30	Dr. Anastacio Zemlak	dr.anastacio.zemlak@geemail.com	Anaheim	California	4316490358603	ddec68839dda6cf8ad7a478ffd8607ac	Mastercard	33.8680054082833237	-117.849221336350212
34354	2020-06-30 20:16:37	2020-06-30	Rutha Emard-Lubowitz	rutha.emard.lubowitz@geemail.com	Phoenix	Arizona	3528570375384407371	57d01ff4664dc6c1033d6dff366f9f0b	Discover	33.5358891433969148	-112.132098045239601
34355	2020-06-30 20:33:59	2020-06-30	Dr. Ferne Walsh	dr.ferne.walsh@geemail.com	Springfield	Missouri	3112986395871449700	fb76063a0a1ff88611620c6acdf51402	Maestro	37.2502535774100565	-93.2713525743048706
34356	2020-06-30 20:53:08	2020-06-30	Mrs. Christine Barton	mrs.christine.barton@warmmail.com	Charlotte	North Carolina	4411627098921565	866d1f11e03734ae475eaa05cac08888	Discover	35.300319247112796	-80.8515977110192239
34357	2020-06-30 20:55:12	2020-06-30	Rosaline Schoen	rosaline.schoen@geemail.com	Baton Rouge	Louisiana	3496158300481828	5eea27f444e69340fc90dfcea5e4f26e	Diners Club / Carte Blanche	30.4117901224389655	-91.1141816530484618
34358	2020-06-30 21:01:43	2020-06-30	Linwood Keeling	linwood.keeling@geemail.com	Oakland	California	210023397908341251	833d5861b34840e1381abb6d47502aff	Voyager	37.8251292477184933	-122.259599830347895
34359	2020-06-30 21:04:44	2020-06-30	Keila O'Reilly	keila.o'reilly@geemail.com	Newport News	Virginia	4461891096189364	dc3a2132140bae26ce110b781b2c2bd2	Voyager	37.0984701411694289	-76.5654068190399641
34360	2020-06-30 21:30:33	2020-06-30	Shayna Hudson-Johnson	shayna.hudson.johnson@woohoo.com	Provo	Utah	210098848327377433	ea2a48b0a961bd1736eec0a6cc979fe7	Maestro	40.3282278966411951	-111.581024655527628
34361	2020-06-30 21:36:29	2020-06-30	Aracely Bartell	aracely.bartell@geemail.com	Athens	Georgia	3337262525846989357	49f99b0744648c6d2528787d325fcdcb	Voyager	33.9565358031265419	-83.3358921536825505
34362	2020-06-30 21:51:28	2020-06-30	Marylouise Schmitt	marylouise.schmitt@geemail.com	North Las Vegas	Nevada	3112453503627813392	73b27702a2baea254716ec31deca7c50	Discover	36.2206938606377662	-115.13792089738287
34363	2020-06-30 22:03:05	2020-06-30	Madilyn Stamm	madilyn.stamm@geemail.com	Nashville	Tennessee	3734134966283118	a223b8a67d209f93aba10363d37eea67	American Express	36.1212827490299944	-86.7074541821982621
34364	2020-06-30 22:07:32	2020-06-30	Mirna Wolf	mirna.wolf@woohoo.com	San Francisco	California	4524992017012902	92f3f916b5716531743d3ea9ef0a3b9d	Mastercard	37.773988377408223	-122.459979043149204
34365	2020-06-30 22:14:05	2020-06-30	Makaila Collins MD	makaila.collins.md@woohoo.com	New York	New York	561299639408980	5cb043fc8410fa8ab3c42d72bbe2ee3c	VISA 13 digit	40.7179887319207197	-73.9063285569556001
34366	2020-06-30 22:14:40	2020-06-30	Lamonte Ernser	lamonte.ernser@geemail.com	San Francisco	California	639068623277099	1aacf9cc1456c0e46820a712db202432	VISA 13 digit	37.7722177572171347	-122.441107135121428
34367	2020-06-30 22:16:46	2020-06-30	Roselyn Koepp	roselyn.koepp@woohoo.com	Oakland	California	3158547267113781236	b0af116e5c02480202f43d497e074bd4	VISA 13 digit	37.8082486341437161	-122.29061208665928
34368	2020-06-30 22:33:03	2020-06-30	Jeremie Wintheiser	jeremie.wintheiser@geemail.com	Berkeley	California	3493219579990544	bacd239fa07a52c02fc4a322654f1b53	VISA 16 digit	37.8931215727169359	-122.276627682409611
34369	2020-06-30 22:39:10	2020-06-30	Ermina Gutmann-Wyman	ermina.gutmann.wyman@geemail.com	Houston	Texas	52328291175773894	3d7549a0422f05ec46cedc0351cc82f4	VISA 13 digit	29.8239423377051942	-95.3275292783524861
34370	2020-06-30 22:40:33	2020-06-30	Macarthur Hartmann	macarthur.hartmann@woohoo.com	Long Beach	California	3158083040049737717	52e0045fbc9579d18f368044500db889	VISA 13 digit	33.7175554176147969	-118.185739797043794
34371	2020-06-30 22:41:24	2020-06-30	Sarina Kunde	sarina.kunde@woohoo.com	Providence	Rhode Island	6011273881608990803	59ded168948fec9bbb5c936aa67ea44a	VISA 16 digit	41.8314513870835256	-71.4125771149911088
34372	2020-06-30 22:45:03	2020-06-30	Earnestine Olson	earnestine.olson@warmmail.com	Nashville	Tennessee	4109139200672729	0fcd90cbf3de0d98c6327609a47a69b5	JCB 16 digit	36.1987407099578533	-86.7358172606583651
34373	2020-06-30 22:46:05	2020-06-30	Renata Huels	renata.huels@woohoo.com	San Jose	California	4978311307347269	f048aa4cb6787a074ac34ec3495911de	JCB 15 digit	37.3157004642587182	-121.782861608009412
34374	2020-06-30 22:55:12	2020-06-30	Mr. Irving Bins PhD	mr.irving.bins.phd@geemail.com	Kent	Washington	3020954056593237	2eae78de20d744d7c4956c5c52115776	Discover	47.3898876925576431	-122.161060954038803
34375	2020-06-30 22:57:02	2020-06-30	Debby Hamill-Shanahan	debby.hamill.shanahan@geemail.com	Hartford	Connecticut	3337860720590061653	00bc851b9e6c4324793e3e7760bca77d	VISA 16 digit	41.7927753012176595	-72.7244502390626906
34376	2020-06-30 23:14:00	2020-06-30	Javier DuBuque	javier.dubuque@woohoo.com	Temecula	California	589350832037142	8d8e55bf48f56267a055f1df11359539	Maestro	33.584181195650622	-117.175412866818533
34377	2020-06-30 23:15:24	2020-06-30	Arnold Jast	arnold.jast@geemail.com	Saint Paul	Minnesota	676372461040643	8475d27524c949b8b6b10ee3f443b378	Diners Club / Carte Blanche	45.0471291784137478	-93.0074639603760147
34378	2020-06-30 23:16:27	2020-06-30	Demetri Huel	demetri.huel@geemail.com	Berkeley	California	3744856560168885	220a168222b4c153b6ac55b5cbde294d	VISA 16 digit	37.8440319285473379	-122.298118614103856
34379	2020-06-30 23:22:18	2020-06-30	Halsey Denesik	halsey.denesik@geemail.com	New York	New York	869929875122348826	53c1b41f469e7717e3ade2441a6ac342	Mastercard	40.5776246515326164	-74.0379955807596417
34380	2020-06-30 23:28:21	2020-06-30	Ms. Laraine Dare DVM	ms.laraine.dare.dvm@geemail.com	Anchorage	Alaska	3768533500802268	978e862e032a96af53c2065efc66375e	JCB 15 digit	61.2112363426696504	-149.270489255118378
34381	2020-06-30 23:35:52	2020-06-30	Joetta Blanda MD	joetta.blanda.md@geemail.com	Vallejo	California	3337399445867796860	72f914cc8c96f6b1565ec0ae96fc8fea	JCB 16 digit	38.040858580181002	-122.357249892117451
34382	2020-06-30 23:35:52	2020-06-30	Humphrey Koch	humphrey.koch@woohoo.com	New York	New York	869909944007564743	75ae089a8de1538a92be003da9ae5aac	JCB 16 digit	40.6565525043979292	-74.0087706924777393
34383	2020-06-30 23:44:26	2020-06-30	Rosalyn Feeney	rosalyn.feeney@geemail.com	Grand Prairie	Texas	4379678695623260	b4781288deaa3c629a8b41908d54c807	Discover	32.6272332006186261	-97.1020058160986821
34384	2020-06-30 23:47:59	2020-06-30	Oliva Turner MD	oliva.turner.md@geemail.com	San Francisco	California	3112342821926013026	8f3bd683d638113a641a0c7fdde324ab	Voyager	37.7771463898934527	-122.454936969052483
34385	2020-06-30 23:52:36	2020-06-30	Jenni Feeney	jenni.feeney@geemail.com	Greensboro	North Carolina	3429387093581542	7f4e84e258c392837ba642bd20196e2f	Voyager	36.1483123734708869	-79.7545807416997832
34386	2020-06-30 23:53:50	2020-06-30	Mrs. Anona Hilll	mrs.anona.hilll@geemail.com	Omaha	Nebraska	6011847956939400842	699965a430a3b3409fd089813df9575c	JCB 16 digit	41.1934471177082528	-95.9964856870122247
34387	2020-06-30 23:55:59	2020-06-30	Arnav Hirthe	arnav.hirthe@woohoo.com	Los Angeles	California	4238255674517150	bba5211560c71ce0ad5b401238e5ef24	Voyager	33.9290960881724928	-118.456778297712276
34388	2020-07-01 00:20:22	2020-07-01	Kristen Kshlerin-Pfeffer	kristen.kshlerin.pfeffer@warmmail.com	San Antonio	Texas	4171592949407463	cd6e07af4ad390c9965860c32b1b05de	Diners Club / Carte Blanche	29.4371762664593746	-98.4979650090284622
34389	2020-07-01 00:33:50	2020-07-01	Mr. Olan Bergnaum DVM	mr.olan.bergnaum.dvm@geemail.com	Wilmington	North Carolina	3453975809243123	dae123826308d191d7d91a7dad4aa2df	Mastercard	34.1157218154340995	-77.8043453042853628
34390	2020-07-01 00:36:36	2020-07-01	Kennith Mills	kennith.mills@woohoo.com	Oklahoma City	Oklahoma	869937284216043585	437818e5232b624de87f47e131f84f48	JCB 15 digit	35.4267126701682855	-97.6038300969999284
34391	2020-07-01 00:36:54	2020-07-01	Dr. Theta Wolff DVM	dr.theta.wolff.dvm@geemail.com	Alexandria	Virginia	4551292377850173	76f3242ad0349299a133f1d8ac0d6be8	VISA 16 digit	38.8777912031974608	-77.1142528779789842
34392	2020-07-01 00:39:40	2020-07-01	Dr. Thurston Huel PhD	dr.thurston.huel.phd@geemail.com	Phoenix	Arizona	3096715359166010997	e81b0c56c00711cd6fd4af657acacbbe	Mastercard	33.5364363769467957	-111.999824616631869
34393	2020-07-01 00:40:21	2020-07-01	Dr. Clemence Rohan DVM	dr.clemence.rohan.dvm@geemail.com	Chicago	Illinois	210044239099891113	2b8dc7379e68aff6cf12e6dac641fd98	JCB 15 digit	41.8727367541123172	-87.6848381444375917
34394	2020-07-01 00:44:31	2020-07-01	Dr. Debi Will DVM	dr.debi.will.dvm@geemail.com	New York	New York	3448406424862897	ec9b41ff331f50b154808c439df10314	JCB 15 digit	40.6004705870747529	-73.9286685260374128
34395	2020-07-01 00:49:22	2020-07-01	Caylee Connelly	caylee.connelly@woohoo.com	Fort Worth	Texas	4333517834295165	95efafe3fe745e39dbd95852b7b8e64d	American Express	32.824509147560228	-97.3617312953162894
34396	2020-07-01 01:04:44	2020-07-01	Adelard Lebsack	adelard.lebsack@warmmail.com	Beaumont	Texas	3467542004270329	e24ea6d63650f8812dfa4a29589c91d0	VISA 13 digit	30.1441238968238245	-94.2191239669241014
34397	2020-07-01 01:08:21	2020-07-01	Markus Boehm	markus.boehm@geemail.com	Seattle	Washington	3006060564906988	2e464fb8a53ead66e6e253901ee7ebd0	Discover	47.6594268853235974	-122.314130588519944
34398	2020-07-01 01:10:37	2020-07-01	Myrta Kutch	myrta.kutch@geemail.com	Las Vegas	Nevada	589394260757193	260621e8ad5978c22876632160a6b6c0	Mastercard	36.3164093045618372	-115.267046570891878
34399	2020-07-01 01:13:10	2020-07-01	Cassidy Denesik	cassidy.denesik@geemail.com	Rochester	New York	561226802743208	349629e06b243b9bdcb2dac9a402bbd1	VISA 16 digit	43.2130634335778652	-77.5466107458114635
34400	2020-07-01 01:24:49	2020-07-01	Arlington Grant	arlington.grant@geemail.com	Phoenix	Arizona	3096563492057902965	77a0a812bdc7a39ac89a899bb008ca11	VISA 13 digit	33.6698371819153479	-112.116565491624556
34401	2020-07-01 01:29:19	2020-07-01	Delwin Schimmel V	delwin.schimmel.v@geemail.com	New York	New York	869931004345261759	518dcc8a7ce0f089ae043be6baf851bd	Voyager	40.7402265672795494	-73.9316424921981934
34402	2020-07-01 01:40:55	2020-07-01	Javon Rohan	javon.rohan@geemail.com	Houston	Texas	6011667770765267804	dca44e457de3866808d049362d5f8e7b	JCB 16 digit	29.8128762574478969	-95.3222402715604744
34403	2020-07-01 01:53:24	2020-07-01	Aracely Johnson	aracely.johnson@geemail.com	Chula Vista	California	3046102997802127	4349ae43dc427f3b4536933ff74eb8f9	JCB 16 digit	32.5992771429706352	-117.010563172097122
34404	2020-07-01 01:54:03	2020-07-01	Adalberto Rau	adalberto.rau@geemail.com	Corpus Christi	Texas	4747870756336362	3b5b1b821753aabea5c533a0c0fdb5d1	VISA 16 digit	27.6598047838017358	-97.1753258998334388
34405	2020-07-01 02:06:29	2020-07-01	Annie Mayert	annie.mayert@geemail.com	Rochester	Minnesota	4972220139440224	feb8316e63ea44984da1e4aec36a6baa	Voyager	44.0699357363298532	-92.5761387301728149
34406	2020-07-01 02:19:22	2020-07-01	Mr. Squire Huel V	mr.squire.huel.v@geemail.com	Baton Rouge	Louisiana	869946374659201383	e31377d28ae8bdcf7c11bd9f8367400b	Maestro	30.5390879551161092	-91.0419307255294115
34407	2020-07-01 02:26:11	2020-07-01	Mr. Felix Bergstrom DVM	mr.felix.bergstrom.dvm@geemail.com	San Francisco	California	675905730090395	af2012870be1adb45321a4438f910f79	JCB 15 digit	37.7739950383332115	-122.432121250464292
34408	2020-07-01 02:31:10	2020-07-01	Destry Vandervort-Baumbach	destry.vandervort.baumbach@geemail.com	Kent	Washington	4963491793963220	a1d320beaa3fa752a552606b43601f96	VISA 16 digit	47.2951291191037697	-122.25436501951404
34409	2020-07-01 02:34:57	2020-07-01	Waylon Effertz	waylon.effertz@geemail.com	Midland	Texas	3441834926029821	9148dbde7d25f6f22aa2d3301733727c	VISA 13 digit	32.0365642263278332	-102.100705271702267
34410	2020-07-01 02:43:48	2020-07-01	Jordan Weber III	jordan.weber.iii@geemail.com	San Francisco	California	869990276884856144	c9655217ff5659e490681360bf135b3c	JCB 16 digit	37.7585073717707402	-122.448753056431258
34411	2020-07-01 02:44:23	2020-07-01	Jaidyn Howe	jaidyn.howe@geemail.com	Woodbridge	New Jersey	869987238830146348	80441cb2dd384d7c246152958c30d79d	VISA 16 digit	40.5496548854436725	-74.3820026568461117
34412	2020-07-01 02:59:02	2020-07-01	Mrs. Gillie Bogisich PhD	mrs.gillie.bogisich.phd@warmmail.com	Bellevue	Washington	3112483501630996570	f70f18205487b988666d077eb15a3519	American Express	47.6918110054634568	-122.219847371015689
34413	2020-07-01 03:10:21	2020-07-01	Mrs. January Connelly	mrs.january.connelly@geemail.com	Fort Worth	Texas	4032713853846426	7b47473a56e9139f946710ed9d7cbef9	Mastercard	32.8052834636587676	-97.2574639006338941
34414	2020-07-01 03:27:56	2020-07-01	Shafter O'Conner	shafter.o'conner@woohoo.com	Fort Lauderdale	Florida	4448467996535	2bb9af1c1b148ee7d99f94fede63344b	VISA 16 digit	26.102816042489188	-80.1716068706762002
34415	2020-07-01 03:32:15	2020-07-01	Mrs. Loren Deckow DDS	mrs.loren.deckow.dds@woohoo.com	Berkeley	California	4363745075467	8d2e5c7bacd1903a2b16639f7cda4fc1	VISA 16 digit	37.8347152242502034	-122.245902867316175
34416	2020-07-01 03:36:07	2020-07-01	Tallie Rippin	tallie.rippin@geemail.com	San Francisco	California	869936548748737604	1466ab3a545f649f690b10819e3edd7b	Voyager	37.7822872538051868	-122.423448230137964
34417	2020-07-01 03:51:32	2020-07-01	Percival McGlynn	percival.mcglynn@woohoo.com	Salem	Oregon	6011825067413105323	6a510ba6489218910332ecb1cf32974b	JCB 16 digit	44.8889129171881791	-123.057341338290655
34418	2020-07-01 03:57:14	2020-07-01	Pallie Ryan-Sporer	pallie.ryan.sporer@geemail.com	Huntsville	Alabama	3096815889220483169	fdb6b988669d4e99fcbf5020c200ae6c	JCB 15 digit	34.6671682842317921	-86.6038476537466124
34419	2020-07-01 04:06:09	2020-07-01	Lee Towne	lee.towne@geemail.com	Henderson	Nevada	54785134296841545	92185c3a438d16b99d208ed5efe00090	Maestro	36.1037891440957779	-115.041142252755165
34420	2020-07-01 04:07:34	2020-07-01	Otis Lesch-Bogan	otis.lesch.bogan@warmmail.com	Los Angeles	California	060490691036413	295cf58dfc4e2f8110c065d2aa9bd8d0	Diners Club / Carte Blanche	34.0939946493931103	-118.332339127174762
34421	2020-07-01 04:10:49	2020-07-01	Judy Kshlerin DVM	judy.kshlerin.dvm@geemail.com	Oakland	California	3752005742574763	c6762702468072598a4f929d107fc3b9	Voyager	37.7999330995597091	-122.275019407433462
34422	2020-07-01 04:12:13	2020-07-01	Candy Ledner-Emard	candy.ledner.emard@geemail.com	Columbus	Ohio	6011181112613622632	77eee86f2b6cc6de501e93af02a23703	Maestro	40.0738332420632233	-82.9746273166269077
34423	2020-07-01 04:13:49	2020-07-01	Kalvin Farrell V	kalvin.farrell.v@geemail.com	College Station	Texas	3096512904350527499	ed31460b088390f9fd055079eb22210d	Mastercard	30.5064481692899037	-96.355753858092811
34424	2020-07-01 04:14:26	2020-07-01	Areli Shanahan	areli.shanahan@geemail.com	Greensboro	North Carolina	4751814009990636	c420f53cecc6f0b7ae00bb5507f0fcc3	VISA 16 digit	36.1833812507450574	-79.7619189888685867
34425	2020-07-01 04:21:43	2020-07-01	Hyman Feest	hyman.feest@geemail.com	Pompano Beach	Florida	3025440398272990	2fe181565a4ed1f1b68667cf363b7ab7	American Express	26.2768096545509984	-80.1422772047422853
34426	2020-07-01 04:32:58	2020-07-01	Sidney Nader-Emard	sidney.nader.emard@warmmail.com	Louisville	Kentucky	869905315197341404	459d3e906f4d0069c41ccb10c14b657d	American Express	38.0921957720439863	-85.6022784678801969
34427	2020-07-01 04:39:09	2020-07-01	Brianda Metz	brianda.metz@woohoo.com	Lowell	Massachusetts	3487397939831869	1335557d295200ac0ac90c80f0bba55d	JCB 16 digit	42.6554569789078144	-71.2798566792033625
34428	2020-07-01 04:45:24	2020-07-01	Edwin Dach	edwin.dach@geemail.com	Los Angeles	California	4102931490480	44514e96a4d80e2cd3bc06218ee4d5c3	JCB 15 digit	34.0249359727237319	-118.349411605111499
34429	2020-07-01 04:55:21	2020-07-01	Owen Lebsack	owen.lebsack@geemail.com	San Diego	California	4390952809791	cba64888f675db295a4984a23e45de26	JCB 16 digit	32.8444361851152067	-117.205681379782035
34430	2020-07-01 05:01:07	2020-07-01	Mr. Cory Cole DDS	mr.cory.cole.dds@geemail.com	San Francisco	California	3337754449852850277	5a02f0fc7ad22d95d1aa6265e28975fb	VISA 13 digit	37.7809732271398886	-122.403001698199063
34431	2020-07-01 05:01:20	2020-07-01	Ms. Breann Powlowski	ms.breann.powlowski@geemail.com	New York	New York	4227851171982922	0b39bb7a50b64c05c72e06a2a214946b	JCB 16 digit	40.7075664439927749	-73.8573394182499499
34432	2020-07-01 05:15:29	2020-07-01	Dr. Amber Marvin	dr.amber.marvin@woohoo.com	Fairfield	California	3112071150692740217	c7bc1d1e9efdc1caf9deb7d35f2849b2	VISA 16 digit	38.3577018336050273	-122.005918306904292
34433	2020-07-01 05:15:43	2020-07-01	Katharine Jast	katharine.jast@warmmail.com	Pittsburgh	Pennsylvania	6011299189765832705	11ccc60374c141f93c779e74b8c84ce7	Discover	40.4732292659070296	-79.9249057038392863
34434	2020-07-01 05:15:53	2020-07-01	Tiana Mayert	tiana.mayert@woohoo.com	Berkeley	California	3016828920185319	b00241c120da21257b7d2597a30b0822	JCB 16 digit	37.8797287474553741	-122.298733720155298
34435	2020-07-01 05:18:01	2020-07-01	Brenden Schneider	brenden.schneider@geemail.com	New York	New York	3038488704170140	bee492c876ce3a9eed0bdfee0b8abff2	Voyager	40.6051607917286432	-73.9723543261539191
34436	2020-07-01 05:30:52	2020-07-01	Shari Crooks	shari.crooks@geemail.com	Los Angeles	California	869940475268867955	235a94f6dcd12deab1dea7eaf20e42d0	American Express	33.9549821641627645	-118.463251616525639
34437	2020-07-01 05:34:26	2020-07-01	Mart Halvorson	mart.halvorson@geemail.com	Columbia	South Carolina	210082993042214574	6e0388c8b5021aed9799217d53bdee82	VISA 16 digit	34.0538203553095471	-80.8538645545039287
34438	2020-07-01 05:46:49	2020-07-01	Bernard Smitham IV	bernard.smitham.iv@woohoo.com	North Las Vegas	Nevada	4731040541821684	f838e7310a397a20d0f2859da33077d7	Diners Club / Carte Blanche	36.2871316488523021	-115.123753433882825
34439	2020-07-01 06:02:58	2020-07-01	Cristen Hills	cristen.hills@geemail.com	New York	New York	4496760677188955	aaae3b0b869501906c3093a70b95a024	Discover	40.626316996593026	-73.8811314364790945
34440	2020-07-01 06:07:21	2020-07-01	Norah Wyman	norah.wyman@geemail.com	San Francisco	California	561233625135943	2869ced420de3c04c2f3cdf6b314fca5	Discover	37.7708467254086813	-122.449020904171391
34441	2020-07-01 06:08:03	2020-07-01	Rodger Nicolas	rodger.nicolas@geemail.com	Bridgeport	Connecticut	869922539944070136	9e0d208145b3a0eeedd984f55b8523e4	Maestro	41.1971151980735328	-73.1399967213060762
34442	2020-07-01 06:11:23	2020-07-01	Jones Hyatt MD	jones.hyatt.md@geemail.com	Little Rock	Arkansas	4145553613606999	3e0db1490f0d2563654b5e3f3a56104e	Voyager	34.7321217517178482	-92.2936910743232772
34443	2020-07-01 06:22:48	2020-07-01	Helen Daniel	helen.daniel@warmmail.com	San Francisco	California	3053989418749660	975a801650c5ee8963ef5ea5c236f2d2	Diners Club / Carte Blanche	37.7692348509359803	-122.43300082595988
34444	2020-07-01 06:24:35	2020-07-01	Natalie Lakin	natalie.lakin@geemail.com	Daly City	California	4336259966518034	b9df33259d2dbfee98988318c1af1020	JCB 15 digit	37.7269939530096892	-122.428478071475411
34445	2020-07-01 06:30:41	2020-07-01	Isaac Hudson-Beier	isaac.hudson.beier@warmmail.com	Austin	Texas	3039065547024244	4db5a02586d5a71f76cf48c80dc77c1a	VISA 13 digit	30.2120493271049106	-97.7182392992783377
34446	2020-07-01 06:30:57	2020-07-01	Kristopher Muller	kristopher.muller@geemail.com	San Antonio	Texas	55408189662216109	8b11a29b46572f9088b4cacca9e7bd75	JCB 16 digit	29.3893731018599134	-98.478177503386874
34447	2020-07-01 06:33:28	2020-07-01	Mrs. Niki Koch DVM	mrs.niki.koch.dvm@geemail.com	Moreno Valley	California	4437121330711372	074eaa2fdc20fd84a9072ac8f022893e	VISA 16 digit	33.9742186892304545	-117.248253234612562
34448	2020-07-01 06:44:04	2020-07-01	Keri Hauck	keri.hauck@geemail.com	Los Angeles	California	4409785230237292	27dac3aae8719297bc7a14de1913b2ae	JCB 16 digit	33.9496605859935272	-118.441245307446636
34449	2020-07-01 06:45:12	2020-07-01	Jayme Schoen	jayme.schoen@geemail.com	New York	New York	3054744452379406	976f041006f0174722277461f1744896	American Express	40.5863283158037831	-73.8427633178781662
34450	2020-07-01 07:08:12	2020-07-01	Mattye Brown	mattye.brown@geemail.com	San Francisco	California	3112348265736679150	1fa10847a8836596541402b870cc4d45	JCB 15 digit	37.7860492016818483	-122.445376022877966
34451	2020-07-01 07:10:15	2020-07-01	Nylah Ernser	nylah.ernser@geemail.com	San Francisco	California	869917851109477809	dd1c3e65970d1fbc303dbf1e2d2e919a	JCB 16 digit	37.8064050165986103	-122.437595119509666
34452	2020-07-01 07:14:40	2020-07-01	Kennedi Gerlach MD	kennedi.gerlach.md@geemail.com	San Francisco	California	4129275427532639	0f0ad6c03e52e058e3db0021285e5642	Discover	37.7652993324876363	-122.415651640002238
34453	2020-07-01 07:15:20	2020-07-01	Kegan Mayer	kegan.mayer@woohoo.com	Vista	California	3491938909801061	f93465b64eeb6bc393e87e63858b5ff2	Maestro	33.1996175961550364	-117.210591282561793
34454	2020-07-01 07:32:18	2020-07-01	Kanesha Goyette	kanesha.goyette@geemail.com	Boston	Massachusetts	51504627436071139	28ba1bb59f611cc50a0ca712035628eb	VISA 13 digit	42.2686306094918436	-70.9967458206180453
34455	2020-07-01 07:59:13	2020-07-01	Mrs. Haylee Fadel PhD	mrs.haylee.fadel.phd@geemail.com	New York	New York	4920813387973038	e6d809e54ddfa9c1d30cb5a6eb3eaf9a	JCB 16 digit	40.6482246507648384	-73.9737778340827674
34456	2020-07-01 08:06:15	2020-07-01	Miss Ever Stokes	miss.ever.stokes@woohoo.com	Nashville	Tennessee	4570744024417	83e1d3373f0851f6bda101a68cfefbb6	VISA 16 digit	36.0920842801343653	-86.8003153224848205
34457	2020-07-01 08:12:15	2020-07-01	Pratt Aufderhar	pratt.aufderhar@warmmail.com	San Antonio	Texas	869937048652397411	a4ccd41ff8b7f1465f5a6a06d0fc682e	Diners Club / Carte Blanche	29.3973998770654212	-98.5218860659584408
34458	2020-07-01 08:12:16	2020-07-01	Ms. Burnice Wunsch PhD	ms.burnice.wunsch.phd@geemail.com	San Francisco	California	6011261272502373540	2de2823d2fe2ad29ba75584aa3e8c7c9	Discover	37.7991684957474874	-122.467837593836038
34459	2020-07-01 08:13:03	2020-07-01	Miss Clem O'Hara DVM	miss.clem.o'hara.dvm@geemail.com	Pasadena	Texas	4692214551677	076b9c1344441a61756410d3a62c9670	JCB 15 digit	29.5698978953402474	-95.0730844438955103
34460	2020-07-01 08:27:46	2020-07-01	Salomon Nitzsche-Mills	salomon.nitzsche.mills@warmmail.com	Seattle	Washington	869932809586135275	898e122102e0b8c6770696ef9e9da809	Voyager	47.5581936730463042	-122.308250234687321
34461	2020-07-01 08:28:04	2020-07-01	Saniya Boyle PhD	saniya.boyle.phd@geemail.com	Mesa	Arizona	4566977161629	950a974cd3bddadc3c6c65112545238f	Maestro	33.3707367649447164	-111.684383763873569
34462	2020-07-01 08:47:08	2020-07-01	Lucero Botsford	lucero.botsford@geemail.com	Augusta	Georgia	3088412447261544816	e9a44086c7215606ecc7c5bc6860a5df	Mastercard	33.3828296371474806	-82.0542050067164013
34463	2020-07-01 08:56:55	2020-07-01	Harlan Langworth	harlan.langworth@geemail.com	Little Rock	Arkansas	6011673207506866414	c7e61b77c36d5046a6e0e7683a73e580	JCB 16 digit	34.6500401488315291	-92.3201558519959349
34464	2020-07-01 09:08:43	2020-07-01	Mr. August Moen Sr.	mr.august.moen.sr.@geemail.com	Miami	Florida	3052459918436649	ab4afa7b05c819a93f92bb6b46fbed82	Diners Club / Carte Blanche	25.7831093465115906	-80.1257000976581111
34465	2020-07-01 09:17:29	2020-07-01	Anika Hagenes	anika.hagenes@geemail.com	Oklahoma City	Oklahoma	3096508794295379817	9aeb805463e2b9178150b16c79749ef4	VISA 13 digit	35.4168072621714316	-97.4654390525434167
34466	2020-07-01 09:20:32	2020-07-01	Destry Haag	destry.haag@geemail.com	Omaha	Nebraska	869952090458316120	8b90ebb20f45109daa1fb066ce396299	Mastercard	41.3061128114495446	-95.9927687065791417
34467	2020-07-01 09:29:31	2020-07-01	Raymond Little	raymond.little@geemail.com	Chandler	Arizona	3337046203307539672	d3af7f349455f585136647db347daea3	American Express	33.2688056138899171	-111.822468246228624
34468	2020-07-01 09:29:45	2020-07-01	Marietta Romaguera	marietta.romaguera@woohoo.com	San Francisco	California	4428461904743	903784f1f3901853669cf11a8b3a9add	American Express	37.8016436515797167	-122.446405781219411
34469	2020-07-01 09:29:52	2020-07-01	Shasta Breitenberg	shasta.breitenberg@geemail.com	Dallas	Texas	210039846265082058	a6d3d406d19b37ca39ae352fe8f1397c	Discover	32.7807254081863917	-96.8146452180072572
34470	2020-07-01 09:30:25	2020-07-01	Delma Ankunding-Vandervort	delma.ankunding.vandervort@geemail.com	Vancouver	Washington	3434891819079791	9ad9ee808efa45b27bc5bcf3ae8a408d	JCB 15 digit	45.5654794666521283	-122.647611851298052
34471	2020-07-01 09:34:57	2020-07-01	Jeane Streich	jeane.streich@geemail.com	New York	New York	3485648664047382	49f78714a5e107c40cbab9987e99e21a	JCB 16 digit	40.6101521918773614	-74.036105215026808
34472	2020-07-01 09:38:22	2020-07-01	Cruz Ernser	cruz.ernser@geemail.com	New York	New York	3037760015885884	f1246538eb74f2cb3f593878fb38c823	VISA 16 digit	40.6761791270449748	-73.906210416219011
34473	2020-07-01 09:42:40	2020-07-01	Nikhil Murazik-Padberg	nikhil.murazik.padberg@warmmail.com	New York	New York	51328810008337054	82d0683ab6cb2521b78e33d5aa5266f3	VISA 16 digit	40.6741242241803533	-73.954730138963825
34474	2020-07-01 09:47:54	2020-07-01	Lindy Parisian DVM	lindy.parisian.dvm@geemail.com	New York	New York	4661492354357088	3feb6a003eb5378687bb15c5b80f4636	Diners Club / Carte Blanche	40.6678787179514742	-73.9132506907347562
34475	2020-07-01 09:57:04	2020-07-01	Julian Fadel	julian.fadel@warmmail.com	Raleigh	North Carolina	6011468780937278150	cbc8201f1cdaf5d3555ebefda929b36e	Diners Club / Carte Blanche	35.765136050353199	-78.5640593403421406
34476	2020-07-01 09:59:59	2020-07-01	Mrs. Frederica Nitzsche PhD	mrs.frederica.nitzsche.phd@geemail.com	Berkeley	California	3112918658035151832	32bade47a4e0978056d93dd2a82e252a	Mastercard	37.8878393264855262	-122.307595622737779
34477	2020-07-01 10:19:14	2020-07-01	Hattie Streich	hattie.streich@geemail.com	Baton Rouge	Louisiana	3112069794122216464	972848653f7e6763f89874ec7c7712ad	VISA 13 digit	30.5055815835695725	-91.2048669143222241
34602	2020-07-02 01:17:59	2020-07-02	Dr. Maddux Rowe Sr.	dr.maddux.rowe.sr.@geemail.com	Honolulu	Hawaii	6011884942415462468	090085879a4e7365bfd68a887f329e04	Maestro	21.3479169382929825	-157.940592501566186
34478	2020-07-01 10:22:25	2020-07-01	Miss Renata Monahan PhD	miss.renata.monahan.phd@geemail.com	Fort Worth	Texas	210031652576435920	f317f1dffaf3ffca12f5c4d441283784	Diners Club / Carte Blanche	32.8576565217282663	-97.2793357628218871
34479	2020-07-01 10:23:47	2020-07-01	Clemente Cartwright	clemente.cartwright@geemail.com	New York	New York	55358053754154620	8d7d75d960a8c02e6c0092b1693b34d1	JCB 16 digit	40.732591495731846	-74.0037394977070306
34480	2020-07-01 10:33:48	2020-07-01	Teddie Schaden	teddie.schaden@geemail.com	New York	New York	869920980236463914	a2ae4259030788a8f6ac62781efb79b8	VISA 13 digit	40.6628771578650898	-73.8895524357341174
34481	2020-07-01 10:44:25	2020-07-01	Joetta Heaney	joetta.heaney@geemail.com	San Diego	California	4155306627857091	0fb21cb1e91d83a4d41b1814fb3c7f17	Voyager	32.8208766039527973	-117.141913800397887
34482	2020-07-01 10:47:52	2020-07-01	Mrs. Toshiko Walsh	mrs.toshiko.walsh@woohoo.com	San Antonio	Texas	3528287720851394319	e7c7f5b382344fdceccb959d68010618	American Express	29.5332148785773683	-98.5356807784013426
34483	2020-07-01 10:49:15	2020-07-01	Aubree Dibbert	aubree.dibbert@warmmail.com	Baltimore	Maryland	3027650795008171	9ba556f2a6a7aa9403baa3e4bdc785f1	Mastercard	39.3112375855445819	-76.6208340758010706
34484	2020-07-01 10:53:25	2020-07-01	Donavon Kohler	donavon.kohler@geemail.com	New York	New York	6011801442035349930	a3b11da1256c4296f0fee52cd67f6c41	Discover	40.6609617660045615	-73.9110859175108317
34485	2020-07-01 11:09:16	2020-07-01	Bryton Hermann-Mills	bryton.hermann.mills@geemail.com	Santa Clarita	California	3528063068221463392	982dfb6862a082d0b8f1b33f6deedcb4	JCB 16 digit	34.40180527718924	-118.574519461543105
34486	2020-07-01 11:17:00	2020-07-01	Ms. Azaria Paucek PhD	ms.azaria.paucek.phd@warmmail.com	Philadelphia	Pennsylvania	4665714143928648	cc30c222a2091404aadc31fddaf57744	VISA 16 digit	39.9331071861978586	-75.0508161894410932
34487	2020-07-01 11:18:07	2020-07-01	Mr. Kamron Marquardt	mr.kamron.marquardt@geemail.com	Charleston	South Carolina	6011253964892561649	938cb1fb3a937b2f42eb003c1b309944	VISA 16 digit	32.834044372243433	-79.8746533413566624
34488	2020-07-01 11:32:55	2020-07-01	Kalie Rolfson	kalie.rolfson@geemail.com	San Francisco	California	3112426837273391921	c5a2078502dd7c7c72d627a8a7cc4632	Diners Club / Carte Blanche	37.7791158335077668	-122.436504688641065
34489	2020-07-01 11:38:46	2020-07-01	Lavona King MD	lavona.king.md@geemail.com	Fayetteville	North Carolina	3528315421351841570	02381222f1e73036eb797fa0c2f8c0b0	JCB 16 digit	34.9966628270942692	-79.0429824133533998
34490	2020-07-01 11:39:37	2020-07-01	Vic Reichel	vic.reichel@geemail.com	Denver	Colorado	4476515489111106	e7121e05323c7267098c290016cf1310	Maestro	39.6796269253879785	-104.823390039546794
34491	2020-07-01 11:43:52	2020-07-01	Brody Effertz	brody.effertz@woohoo.com	New York	New York	3096415224053439282	f9739280d41660a2c9b5a08b2ba33fe8	Maestro	40.7139046835470921	-74.0155613061401993
34492	2020-07-01 11:45:05	2020-07-01	Armstead O'Connell	armstead.o'connell@geemail.com	Fort Lauderdale	Florida	3437628757684225	de689582ecc6a1c16fd8f6ca82d5d22e	Maestro	26.1166648667294545	-80.1776678470715893
34493	2020-07-01 12:15:01	2020-07-01	Arvil O'Hara	arvil.o'hara@warmmail.com	New York	New York	3006180795291271	75ae1ef5c7e6f31fa533b5811726f6cb	JCB 16 digit	40.5992564012519992	-73.8543362299807313
34494	2020-07-01 12:15:21	2020-07-01	Jaheim Bruen-Batz	jaheim.bruen.batz@geemail.com	Woodbridge	New Jersey	4791651574612	ea76ade33c108a39646ea89d1708af67	JCB 16 digit	40.6380363129701436	-74.2125654145002329
34495	2020-07-01 12:38:03	2020-07-01	Rosina Cremin	rosina.cremin@geemail.com	Glendale	Arizona	4165729815385435	3e5ab4d5e5a1501d8f6f3e1acb008913	Diners Club / Carte Blanche	33.5276338220801193	-112.090690746090928
34496	2020-07-01 12:38:16	2020-07-01	Greg Armstrong	greg.armstrong@warmmail.com	Little Rock	Arkansas	869936772127724252	797fa1f2af322fe118a4d87308db4f25	VISA 16 digit	34.707653820495679	-92.2992350261531698
34497	2020-07-01 12:39:16	2020-07-01	Imanol Howe-Corwin	imanol.howe.corwin@woohoo.com	New York	New York	869905549068500843	8a93ca636c0e8eda8c0ff18ba01e27c6	American Express	40.7206167589630894	-73.9345953076042264
34498	2020-07-01 12:54:56	2020-07-01	Mose Rau	mose.rau@woohoo.com	Fargo	North Dakota	3405809135582061	c543831df1b931cd99579a20dd8b3d4c	VISA 13 digit	46.8451743351060941	-96.9088185879830206
34499	2020-07-01 13:02:42	2020-07-01	Omarion Haag	omarion.haag@warmmail.com	Murrieta	California	869961973120169069	4f75e6525c28a97fdaace5eca96c368b	JCB 16 digit	33.6113055217176679	-117.248723181979358
34500	2020-07-01 13:06:10	2020-07-01	Miss Tami Marvin DVM	miss.tami.marvin.dvm@geemail.com	New York	New York	4456892510883829	da80c9511ecbec38bf32d69b3e50df73	Voyager	40.6798706296589216	-73.9087959835201502
34501	2020-07-01 13:07:27	2020-07-01	Jenni Cole	jenni.cole@geemail.com	Houston	Texas	3528748212516164231	c0171e3682e0559f9967aef0d19c50b4	JCB 16 digit	29.69201316741146	-95.4383295618012539
34502	2020-07-01 13:09:58	2020-07-01	Sylvanus Jones I	sylvanus.jones.i@geemail.com	Portland	Oregon	3760321119480322	ab831b87d9f6053143fd117f26748242	JCB 15 digit	45.4636518599819368	-122.651925798412421
34503	2020-07-01 13:10:38	2020-07-01	Alaya Von	alaya.von@geemail.com	Hialeah	Florida	3096166474056280214	7ae4cba69771605b7a7ec2a150bd581e	Diners Club / Carte Blanche	25.873921400166676	-80.2433142802115498
34504	2020-07-01 13:19:35	2020-07-01	Garey Turcotte	garey.turcotte@geemail.com	San Francisco	California	3456586234298116	5ed974afab346b163400d07517305931	VISA 16 digit	37.8173281137396131	-122.422109880165152
34505	2020-07-01 13:19:59	2020-07-01	Elvera Hodkiewicz	elvera.hodkiewicz@woohoo.com	Sacramento	California	3158744053333508133	e8e648963c0e1775aa62631f18f9db67	VISA 16 digit	38.5689433724883983	-121.42820122961551
34506	2020-07-01 13:38:48	2020-07-01	Lenard Zieme-Grant	lenard.zieme.grant@warmmail.com	Chicago	Illinois	180061878435293951	fe0a44afb8c64877dfdd97832c693dc2	Mastercard	41.7495551911484455	-87.7780686617858663
34507	2020-07-01 13:49:04	2020-07-01	Ms. Krissy Adams	ms.krissy.adams@geemail.com	Albuquerque	New Mexico	3016265007268934	abf28222bb83350715e7039b50416a50	Mastercard	35.0949662866204974	-106.645342453529693
34508	2020-07-01 13:55:53	2020-07-01	Florance Shanahan	florance.shanahan@woohoo.com	San Diego	California	4169809164061260	ddd510cc23d753240a4599d7931f513f	JCB 15 digit	32.9026278464656343	-117.170996916145086
34509	2020-07-01 14:26:16	2020-07-01	Jonathan O'Connell	jonathan.o'connell@geemail.com	Rialto	California	4719143041979816	82314feeb9de3de938f64b77fecf7147	American Express	34.1871208519890928	-117.42098336579204
34510	2020-07-01 14:45:08	2020-07-01	Mrs. Verona Stiedemann	mrs.verona.stiedemann@geemail.com	Aurora	Colorado	180068605412285103	9a491adda93d54796b4f95673d381776	VISA 13 digit	39.6543237771950672	-104.60065823529176
34511	2020-07-01 14:52:59	2020-07-01	Alex Daugherty	alex.daugherty@geemail.com	Reno	Nevada	4020056014937	a06da52472ff52c7f443627f9fa616a5	Diners Club / Carte Blanche	39.4719978925384609	-119.819603868776568
34512	2020-07-01 14:53:02	2020-07-01	Aron Turner	aron.turner@geemail.com	New York	New York	4242215395391	66f7ba6ba1a1be60be6ca96e2f97b0f3	Discover	40.6019893110487615	-74.0067720836389782
34513	2020-07-01 14:58:33	2020-07-01	Molly Nicolas	molly.nicolas@geemail.com	Louisville	Kentucky	589376859279226	5e072c6b50406149127e31ffa959cf66	VISA 16 digit	38.1666386218644647	-85.622977185815202
34514	2020-07-01 15:08:19	2020-07-01	Dow Legros Jr.	dow.legros.jr.@geemail.com	McKinney	Texas	55452981761235625	4d7b1e5663b9124fa512753d0fee526a	VISA 16 digit	33.108550699068239	-96.6569020022004963
34515	2020-07-01 15:12:05	2020-07-01	Leonard Rohan	leonard.rohan@geemail.com	Pittsburgh	Pennsylvania	3096246267943353150	f22b6deef9837618962cc3363ffcf26b	American Express	40.4028080529022944	-79.9144097997512688
34516	2020-07-01 15:19:14	2020-07-01	Taya Heller	taya.heller@warmmail.com	Memphis	Tennessee	6011122616000211207	fc793387658259474f6a077b18351fd3	Diners Club / Carte Blanche	35.1463161663219381	-89.9489201810933707
34517	2020-07-01 15:22:08	2020-07-01	Margurite Paucek	margurite.paucek@geemail.com	Berkeley	California	3467395915934081	74b829f29170b472d4763e486cae74bf	American Express	37.8495802870397924	-122.297031507067345
34518	2020-07-01 15:34:40	2020-07-01	Syreeta Boyle	syreeta.boyle@geemail.com	Baltimore	Maryland	3112570607616547453	2319e3482de0944367e69ab08235d9cc	JCB 16 digit	39.2788256040308568	-76.6013768996130722
34519	2020-07-01 15:40:36	2020-07-01	Dr. Maury Wyman	dr.maury.wyman@warmmail.com	Charlotte	North Carolina	54270511770314812	b3a9abea528305bad4a3ebb0a69da0ec	American Express	35.2976058091755931	-80.7565193659570042
34520	2020-07-01 15:48:33	2020-07-01	Marion Beatty-Dooley	marion.beatty.dooley@woohoo.com	San Francisco	California	4922260956547082	df08217b475c2336fe5d0408f63049ce	Voyager	37.7934130838887299	-122.447589186292447
34521	2020-07-01 15:53:25	2020-07-01	Emma Cassin	emma.cassin@woohoo.com	El Paso	Texas	180088219315082983	b73e616ee5eadbae2946ec8023d1345c	VISA 13 digit	31.8114206602625558	-106.519052377574155
34522	2020-07-01 16:00:23	2020-07-01	Kori Quigley	kori.quigley@geemail.com	Westminster	Colorado	3010724123572047	dc0f28f26b37cd407769a1212bbaf1b6	VISA 13 digit	39.8838259934753125	-105.115874448572853
34523	2020-07-01 16:09:49	2020-07-01	Dr. Jasmyn Kessler DDS	dr.jasmyn.kessler.dds@geemail.com	Chicago	Illinois	4037482396928985	a27e6cd307b29e4f89c20c040a284d7b	JCB 16 digit	41.9154979273047346	-87.6264825371589495
34524	2020-07-01 16:20:18	2020-07-01	Tomasa Parisian PhD	tomasa.parisian.phd@geemail.com	Paterson	New Jersey	3730260666634344	a5846e625721f6f5e617311e26779ece	American Express	40.9705393107097606	-74.2274204256452634
34525	2020-07-01 16:24:21	2020-07-01	Harper Bauch-Reilly	harper.bauch.reilly@woohoo.com	San Francisco	California	3088638341753754231	3832fd7c76fb1bf953ad19fa725ae7d7	Maestro	37.7999853147762224	-122.441073958546269
34526	2020-07-01 16:33:06	2020-07-01	Meaghan Haley	meaghan.haley@geemail.com	Grand Rapids	Michigan	4546474681121	fc85b2e174eefbf7f979bbb68cd6e0d5	Discover	43.035903465774652	-85.6672524301934999
34527	2020-07-01 16:36:59	2020-07-01	Kane Lockman	kane.lockman@warmmail.com	Pasadena	Texas	4294278701337856	fc71a7b7dc565a161766ced7b0c3d8ee	JCB 15 digit	29.5807429344266666	-95.1518353790458207
34528	2020-07-01 16:50:51	2020-07-01	Kylah Tromp-Rempel	kylah.tromp.rempel@geemail.com	Chicago	Illinois	675926497794425	42737acb5d01d1b8d85f99435907556a	Mastercard	41.933158356726544	-87.59144801805094
34529	2020-07-01 17:02:34	2020-07-01	Natalia Senger	natalia.senger@geemail.com	Chandler	Arizona	4804484611594684	a35dabc4a62b4363246a8bd6900e1844	Diners Club / Carte Blanche	33.3056773942984634	-111.83046683742441
34530	2020-07-01 17:20:30	2020-07-01	Mr. Emry Beatty III	mr.emry.beatty.iii@geemail.com	Tampa	Florida	6011246123381880701	e6185b419e61d8bd517cb2c85eca2da0	JCB 16 digit	27.999226656288279	-82.3960482204545173
34531	2020-07-01 17:20:55	2020-07-01	Wilda Ryan	wilda.ryan@geemail.com	San Antonio	Texas	4950963292764	e2a31eebeea7facb71d66b63eb55acda	VISA 16 digit	29.5140053303051744	-98.5787076260730544
34532	2020-07-01 17:31:41	2020-07-01	Jaylen Greenfelder	jaylen.greenfelder@geemail.com	New York	New York	51583476698322390	2967de7e69b933336a730b5fc35656cb	Voyager	40.7303291153386198	-74.0279398949712544
34533	2020-07-01 17:45:37	2020-07-01	Thomas Kemmer-Bins	thomas.kemmer.bins@geemail.com	San Francisco	California	503853078740296	b9c150d40b5cf4972f714a62b5d237d8	Voyager	37.756728933916591	-122.42280945077718
34534	2020-07-01 17:47:47	2020-07-01	Antoinette Johnson	antoinette.johnson@geemail.com	San Francisco	California	55061706020951305	659891b553fd451a81ff5ab59b6fe067	American Express	37.7594097583568882	-122.430897249589407
34535	2020-07-01 17:57:45	2020-07-01	Horatio Nolan-Schmeler	horatio.nolan.schmeler@warmmail.com	Fort Worth	Texas	3775104285267233	45daffc775ba733ae0eaf6878d9ef17a	VISA 13 digit	32.7108065879493992	-97.2469215789630965
34536	2020-07-01 18:00:35	2020-07-01	Polly Streich	polly.streich@geemail.com	San Francisco	California	210091615941105889	72647ca893c19a98f6c32e7cb0a362d7	VISA 16 digit	37.7623009094643507	-122.407262172881246
34537	2020-07-01 18:07:39	2020-07-01	Louann Romaguera	louann.romaguera@woohoo.com	Chandler	Arizona	3096765738482298544	6d2f5b55fb917c8cdb10b8666fe0b97c	American Express	33.2092245536945754	-111.909336962911865
34538	2020-07-01 18:11:08	2020-07-01	Mr. Koda Fadel Sr.	mr.koda.fadel.sr.@geemail.com	Houston	Texas	4416600260614	8ff5911e2981e153e08363d2cb4b2aca	Mastercard	29.7910283858034752	-95.3777013748899094
34539	2020-07-01 18:14:22	2020-07-01	Meghann Adams	meghann.adams@geemail.com	Newark	New Jersey	630424942952342	9a5fca1d14a1c27a28a6220483106d85	JCB 16 digit	40.686315206709132	-74.1415883079379796
34540	2020-07-01 18:23:29	2020-07-01	Bena Koepp PhD	bena.koepp.phd@geemail.com	Santa Ana	California	4759673001203	90a9abed561132d6b23a7c3fd0d5d8d5	JCB 16 digit	33.6702253226760746	-117.78591957128792
34541	2020-07-01 18:25:31	2020-07-01	Lindell Simonis	lindell.simonis@geemail.com	Charlotte	North Carolina	3528021433412944637	12d78f2db5a7eee8b269b10da8953956	JCB 16 digit	35.3005139745093857	-80.9140926685594053
34542	2020-07-01 18:37:12	2020-07-01	Bronson Schamberger	bronson.schamberger@geemail.com	Huntsville	Alabama	4102671429649192	aa9749a7e35b8b386539fbb5bc85a534	Maestro	34.6198031731192017	-86.5870810420736632
34543	2020-07-01 18:57:19	2020-07-01	Maudie Hammes	maudie.hammes@geemail.com	Chicago	Illinois	3044805379402736	cbc3fb81d9246b1f29013152fcb4d85d	Maestro	41.8461905433166805	-87.5911846167437744
34544	2020-07-01 19:02:16	2020-07-01	Jahir Block	jahir.block@geemail.com	San Antonio	Texas	6011499955764512185	59bce9322403cde40e6474f98ab0e813	Discover	29.5172460192419592	-98.6209785330876656
34545	2020-07-01 19:02:43	2020-07-01	Manda Huels	manda.huels@geemail.com	Charlotte	North Carolina	3044287522449734	0e388f0d8bb4c1b7b42869350da0d9bd	Mastercard	35.2945334199137974	-80.9185988931860862
34546	2020-07-01 19:14:29	2020-07-01	Jenny Rippin	jenny.rippin@warmmail.com	Santa Maria	California	54836228349775897	1884374c75a9a32bf627fb29266ee87f	Maestro	34.93580858507827	-120.537267294331642
34547	2020-07-01 19:15:41	2020-07-01	Dr. Mannie Kuhic	dr.mannie.kuhic@geemail.com	Los Angeles	California	869965986849896008	3f8b63965128918e8a23265dfc8e3fe7	Diners Club / Carte Blanche	34.0059568105131333	-118.445702420314021
34548	2020-07-01 19:35:09	2020-07-01	Olivia Nitzsche	olivia.nitzsche@geemail.com	Fort Lauderdale	Florida	503848862084422	c24560839e4d0743b24bbc40da871065	VISA 13 digit	26.1860494435753672	-80.1909388288211034
34549	2020-07-01 19:46:55	2020-07-01	Oneal Volkman	oneal.volkman@geemail.com	Davenport	Iowa	3019399119759667	0cb5d9082937aa702df441e1f9a64ee6	Maestro	41.5612776149328766	-90.5865718687847306
34550	2020-07-01 19:53:47	2020-07-01	Samual Block II	samual.block.ii@geemail.com	Charleston	South Carolina	55191653341691223	0e5cdb8ab4f1845bdd5510fd4e9af7da	Voyager	32.8201864397149521	-79.8902687313184146
34551	2020-07-01 19:58:25	2020-07-01	Andrae Wyman	andrae.wyman@woohoo.com	San Francisco	California	54533124647890619	837f9b88cb5e9390a47b42d71ec479b3	Maestro	37.7968701212621667	-122.437924667855171
34552	2020-07-01 20:06:10	2020-07-01	Mr. Della Rogahn Sr.	mr.della.rogahn.sr.@geemail.com	Las Vegas	Nevada	4666353650761115	44f16537b0e8d43e7f7816f9a8cd9b7a	JCB 16 digit	36.1714017795965077	-115.326330666125187
34553	2020-07-01 20:09:32	2020-07-01	Miss Dorene Barton MD	miss.dorene.barton.md@woohoo.com	Los Angeles	California	3768530629182432	685ac57c45da8be57bdbbddff47f6b31	VISA 16 digit	34.0939522986166139	-118.490945734082899
34554	2020-07-01 20:14:35	2020-07-01	Elsie Williamson	elsie.williamson@geemail.com	Richmond	Virginia	4031629413301606	f1f6a2e8a4dfde58d83c05f1d8e6d1ed	American Express	37.5024414447821641	-77.3998783008418911
34555	2020-07-01 20:16:11	2020-07-01	Jonah Corkery	jonah.corkery@geemail.com	Jacksonville	Florida	869998919533285809	c246a24fdbe09dbfa90778ec08519142	JCB 16 digit	30.3444883578509099	-81.7493781237475616
34556	2020-07-01 20:17:44	2020-07-01	Cole McGlynn	cole.mcglynn@geemail.com	Austin	Texas	3112614347324458697	d9329f7fafe574822e52a6a107ea0c66	Mastercard	30.3836729793470326	-97.7501482727244593
34557	2020-07-01 20:31:03	2020-07-01	Marin Haag	marin.haag@geemail.com	Fontana	California	4030369228528975	6e1fd05ba529bda3432931f18171e0ac	Mastercard	34.0492810301631721	-117.509041486102717
34558	2020-07-01 20:37:57	2020-07-01	Jobe Lubowitz	jobe.lubowitz@geemail.com	Corpus Christi	Texas	3004786717800783	a5ec8761415fe03a6d0b3ecb1171bb1d	JCB 16 digit	27.7079355851218097	-97.094326707983015
34559	2020-07-01 20:38:45	2020-07-01	Arlan Pagac	arlan.pagac@geemail.com	Raleigh	North Carolina	180036613332005543	1a74e3c75978dc1262b6217a7d6a3c6c	Mastercard	35.7605662451259789	-78.5907987586159322
34560	2020-07-01 21:00:55	2020-07-01	Miss Carleen Beahan DVM	miss.carleen.beahan.dvm@geemail.com	Berkeley	California	3762608792810900	469623f84d1cc32cd81bc4c7646b76c5	JCB 16 digit	37.8776309508600093	-122.29667779234606
34561	2020-07-01 21:01:06	2020-07-01	Douglas Bartell	douglas.bartell@geemail.com	Los Angeles	California	869954928154758756	66a76bc8089c91575e734edd30e07458	VISA 16 digit	33.9220856048963952	-118.47314755693003
34562	2020-07-01 21:01:31	2020-07-01	Lynsey Auer	lynsey.auer@geemail.com	Irvine	California	6011164340042028771	27e43392b41878b00df7893b80fc58c8	American Express	33.7237431557398324	-117.849828933040797
34563	2020-07-01 21:07:13	2020-07-01	Nikolas Cremin	nikolas.cremin@geemail.com	Berkeley	California	4156409953572026	a72f49f7a7aa9c2ced5cfba8f6f8b754	VISA 16 digit	37.8780524369109415	-122.263518356812554
34564	2020-07-01 21:09:02	2020-07-01	Darwin Stoltenberg	darwin.stoltenberg@woohoo.com	El Monte	California	210040418755558638	677276788ba7aa38a9248af6c27aa386	Maestro	33.9850669710621176	-118.022120132463428
34565	2020-07-01 21:12:19	2020-07-01	Yadira Nader	yadira.nader@warmmail.com	Concord	California	210044270332425922	be1b0d3c4be5cc518ffc177c57765576	Voyager	37.9854555651012831	-122.009777126012736
34566	2020-07-01 21:13:09	2020-07-01	Randal Koelpin	randal.koelpin@geemail.com	Oakland	California	6011241286968182224	432aba8fb6ba10e7e488eb1fa4bd1cdf	JCB 16 digit	37.8114692272991633	-122.268384938135938
34567	2020-07-01 21:30:45	2020-07-01	Shayna Hickle MD	shayna.hickle.md@geemail.com	Toledo	Ohio	4237670979580037	68b8c0e88bf191e45a87f22b9b4fd081	Diners Club / Carte Blanche	41.6662799742244161	-83.4976999488059448
34568	2020-07-01 21:46:46	2020-07-01	Zebulon Donnelly	zebulon.donnelly@geemail.com	Austin	Texas	3088293878001074033	11e913331d2733202c459decd1d8ffc8	Voyager	30.4026038066610695	-97.8489805361960094
34569	2020-07-01 21:48:44	2020-07-01	Elise Hilll	elise.hilll@geemail.com	Irvine	California	4081446853080270	3648fb7bb0783816eb6386a80515ff2a	Discover	33.7594293436050421	-117.828134717560559
34570	2020-07-01 21:57:58	2020-07-01	Quinn Halvorson	quinn.halvorson@woohoo.com	San Diego	California	6011170447220929365	2157e9eff1d72cef01b4783bcf728793	Diners Club / Carte Blanche	32.8344492983140057	-117.124007241558289
34571	2020-07-01 22:00:57	2020-07-01	Barbie Kshlerin	barbie.kshlerin@warmmail.com	Washington	District of Columbia	630441504348099	ee361488f5311e91e72e66be83cdbdbd	VISA 16 digit	38.9444644292149675	-77.0030148010913251
34572	2020-07-01 22:12:33	2020-07-01	Trista Beatty	trista.beatty@geemail.com	Mesa	Arizona	3337770970368871572	09dc62ded2de99b77ce3a811c8825b86	Voyager	33.4078905316214971	-111.663631614658613
34573	2020-07-01 22:20:10	2020-07-01	Sage Reynolds	sage.reynolds@warmmail.com	New York	New York	4945453228652300	7ecda97b19f157f8cebd33f0f1204c87	VISA 16 digit	40.5962810438349848	-73.888106443722549
34574	2020-07-01 22:27:22	2020-07-01	Linzy Baumbach	linzy.baumbach@geemail.com	Tucson	Arizona	180024560314008785	35c60404c6fa5a86fb39c9186365b4f1	VISA 13 digit	32.1666273678693955	-110.873117012786111
34575	2020-07-01 22:28:09	2020-07-01	Adriel Kshlerin	adriel.kshlerin@geemail.com	San Francisco	California	210063559021135347	80d3a8914b59fb8d29bedc7edd786352	Voyager	37.7588838158700426	-122.415185149474226
34576	2020-07-01 22:29:41	2020-07-01	Dr. Bartley McKenzie	dr.bartley.mckenzie@geemail.com	Corpus Christi	Texas	4476488165220031	d0e8d586664d6f98c95a84fab61a476f	Voyager	27.8425509419228874	-97.1949403012931299
34577	2020-07-01 22:34:16	2020-07-01	Augustine Predovic	augustine.predovic@geemail.com	Albuquerque	New Mexico	4153043595315131	358b686d69494e346c7685bc8153eca5	Maestro	35.1272867796611052	-106.649168300216644
34578	2020-07-01 22:37:52	2020-07-01	Lazaro Heaney-Donnelly	lazaro.heaney.donnelly@geemail.com	Springfield	Illinois	3096668069077332425	be56dff57739a34ed3a5a38dc0cac7aa	Mastercard	39.7823649000529187	-89.7156713328793671
34579	2020-07-01 22:39:26	2020-07-01	Dr. Clemens Schuster I	dr.clemens.schuster.i@warmmail.com	Los Angeles	California	3038318096547193	06ac5674b1d5275c5e35be68fa43650d	Maestro	34.0688119624607211	-118.419271578359599
34580	2020-07-01 22:43:03	2020-07-01	Crystal Powlowski DVM	crystal.powlowski.dvm@geemail.com	Austin	Texas	4183204942114478	fd2977146fe6c5d771eabdb898a78d4f	Maestro	30.2504858528390521	-97.7316880530916166
34581	2020-07-01 22:51:13	2020-07-01	Margaret Runolfsdottir	margaret.runolfsdottir@geemail.com	Dallas	Texas	4177055956660360	a517f8e948d3130f5dec8545a69c2743	JCB 16 digit	32.7777575457274963	-96.8012234090324455
34582	2020-07-01 23:01:17	2020-07-01	Grove Olson	grove.olson@geemail.com	San Francisco	California	4739380193348442	5992789d2c928dc840bc067e62ed46f0	Discover	37.7978978948918964	-122.432470127713529
34583	2020-07-01 23:02:12	2020-07-01	Carley Franecki	carley.franecki@geemail.com	San Diego	California	3435881012092542	6eb88d074c15478307622b6565f38548	VISA 16 digit	32.8637861695207647	-117.093338849199938
34584	2020-07-01 23:07:35	2020-07-01	Torrey DuBuque	torrey.dubuque@warmmail.com	Saint Paul	Minnesota	3039047954405744	4d7301f514b3f56f5f87b3759820efb2	Diners Club / Carte Blanche	44.8525757878959226	-93.1146476167518671
34585	2020-07-01 23:20:27	2020-07-01	Roderic Torp	roderic.torp@warmmail.com	Abilene	Texas	869995558581698167	16d85d3410dc75d522139c1f2d9329c5	VISA 16 digit	32.41445485908352	-99.7784333422727912
34586	2020-07-01 23:24:11	2020-07-01	Leander Gusikowski	leander.gusikowski@warmmail.com	Lewisville	Texas	4480303025754356	1bef546a03df28f55baafd833dd1f979	JCB 16 digit	33.0327725859809647	-96.9298204436462498
34587	2020-07-01 23:25:21	2020-07-01	Roena Volkman	roena.volkman@geemail.com	Charlotte	North Carolina	3036465185109310	22f90d1844540aa2c7a57de96f36c330	American Express	35.1356327695094066	-80.8046277883872364
34588	2020-07-01 23:28:01	2020-07-01	Ossie Osinski	ossie.osinski@woohoo.com	Chicago	Illinois	4991559033873	7dc26a13536c57a4d6aa7f96340d36dc	Maestro	41.8343160660307873	-87.6359533831041233
34589	2020-07-01 23:45:29	2020-07-01	Florian Hammes	florian.hammes@geemail.com	San Francisco	California	6011007737167039981	398714215be229ed6a925f2dd53d7b56	Discover	37.7793986408420395	-122.451198516468381
34590	2020-07-01 23:53:27	2020-07-01	Tollie McGlynn	tollie.mcglynn@geemail.com	Phoenix	Arizona	210018978770278056	dc5203cd2f9184291a7d3082c8413273	JCB 15 digit	33.5917195197593443	-112.108949762948242
34591	2020-07-01 23:59:54	2020-07-01	Miss Lorna Jakubowski DVM	miss.lorna.jakubowski.dvm@woohoo.com	Pompano Beach	Florida	4581193176049013	c332d7ea9348f43ff02defc1bc4e022a	JCB 15 digit	26.2843445725537812	-80.1915781766954723
34592	2020-07-02 00:12:08	2020-07-02	Vincenza Morar-Pfeffer	vincenza.morar.pfeffer@geemail.com	San Antonio	Texas	060414222896251	b40b5288160d29f4a83d2dc16eb631cd	JCB 16 digit	29.4407946641627696	-98.4520674921408272
34593	2020-07-02 00:25:12	2020-07-02	Chip Ward	chip.ward@warmmail.com	Las Vegas	Nevada	4589847702232	be7a1d678a61f6436d97caa64e6f4b66	Discover	36.1462136973261821	-115.272358760118848
34594	2020-07-02 00:27:16	2020-07-02	Bridger Fahey	bridger.fahey@geemail.com	San Francisco	California	4053819942836924	9c756e2b1da87b9b808da5a8a3248825	VISA 16 digit	37.8148889227960652	-122.416898482422127
34595	2020-07-02 00:31:29	2020-07-02	Christiana Ledner	christiana.ledner@geemail.com	New York	New York	676136915301349	57f70a33e1f7b2a9f45bdfe8c2f4e99d	Diners Club / Carte Blanche	40.6458982091620555	-73.9124417234107796
34596	2020-07-02 00:39:45	2020-07-02	Ogden Hessel	ogden.hessel@geemail.com	Antioch	California	4654082065195023	681e00a63aac6d038706a9b830faaaac	VISA 13 digit	38.0037794682461794	-121.779546877712761
34597	2020-07-02 00:44:05	2020-07-02	Wylie McGlynn IV	wylie.mcglynn.iv@geemail.com	San Francisco	California	52098962590294769	be33cfc15f620a1f62934b00d2b55228	VISA 13 digit	37.7713010539821497	-122.443959249870616
34598	2020-07-02 00:51:56	2020-07-02	Case Becker-Stracke	case.becker.stracke@warmmail.com	New York	New York	55401492767281813	a033f9a52f78caa0762bc9d928e86b83	VISA 16 digit	40.5835397936627231	-73.916503102741018
34599	2020-07-02 00:56:51	2020-07-02	Daneen Torphy	daneen.torphy@woohoo.com	New York	New York	4590106296884340	c0c74484ee0ce62b76ec28bb30a3e93a	American Express	40.5837013823203705	-73.9899920928653358
34600	2020-07-02 01:00:17	2020-07-02	Colie Bode	colie.bode@geemail.com	New York	New York	3473361713113247	38597e838171a08ac5c9264ecd71c327	Maestro	40.640900668757034	-73.8679613825295149
34601	2020-07-02 01:00:30	2020-07-02	Mr. Dwaine Bins V	mr.dwaine.bins.v@geemail.com	New Haven	Connecticut	869938435292279811	156ad57788dc26b2621da39835b27e27	Discover	41.2550508042790014	-73.0075210633687703
34603	2020-07-02 01:19:31	2020-07-02	Austyn Feest	austyn.feest@geemail.com	Gilbert	Arizona	6011017839168608752	a3ea4234c5542f039392202785aacc4c	Voyager	33.3614090294457952	-111.73388705552965
34604	2020-07-02 01:25:22	2020-07-02	Hermine Howell	hermine.howell@geemail.com	New Orleans	Louisiana	869984608448284108	6534a830d7af9c8f74b964260731e056	Diners Club / Carte Blanche	29.9580770898159585	-89.9778509040158241
34605	2020-07-02 01:28:33	2020-07-02	Ephraim Nienow-Legros	ephraim.nienow.legros@geemail.com	Houston	Texas	4591171148217569	87675b917e70a1b91ee828fb53347e0c	Maestro	29.8107806130390607	-95.4604339593105067
34606	2020-07-02 01:43:17	2020-07-02	Abbey Kling-Kutch	abbey.kling.kutch@geemail.com	New York	New York	675957262167612	3ce6b61bac8ed480111da1b3d37cc17f	JCB 16 digit	40.6384352028127722	-73.9324893873546216
34607	2020-07-02 01:56:45	2020-07-02	Adriane D'Amore MD	adriane.d'amore.md@geemail.com	Bakersfield	California	060453762348828	578e436665c4d9b3b7e421a4f0ee657f	Discover	35.3488045848615471	-118.944229701561099
34608	2020-07-02 01:57:46	2020-07-02	Emmet Bernhard	emmet.bernhard@geemail.com	Huntington Beach	California	503813291813809	b52d685f40b251f071e980e800b9810b	Diners Club / Carte Blanche	33.7276552728418295	-117.975631859538325
34609	2020-07-02 02:04:51	2020-07-02	Dr. Carlee Gorczany	dr.carlee.gorczany@geemail.com	Fort Worth	Texas	210000709388889624	37ef5e02c5f69a90465d25b16a56c333	American Express	32.8393921329695715	-97.3390973066266554
34610	2020-07-02 02:16:33	2020-07-02	Wilbert Herman	wilbert.herman@geemail.com	Palmdale	California	3096369124283620295	bad54b798c2f66dd510324a89b2179c7	Discover	34.5913535442519944	-118.1990541909352
34611	2020-07-02 02:35:07	2020-07-02	Kacie Lemke	kacie.lemke@geemail.com	Plano	Texas	869987266849122356	a89944023b5cc5ce2f630c177c99ed8f	Voyager	32.9608108040496717	-96.6775908877790044
34612	2020-07-02 02:48:37	2020-07-02	Lea Kirlin	lea.kirlin@geemail.com	San Francisco	California	4922809676951931	088335219727f2a8c01bfecb4f93fba0	JCB 16 digit	37.7634458759922964	-122.424197516783025
34613	2020-07-02 02:49:52	2020-07-02	Dr. Newton Shanahan	dr.newton.shanahan@geemail.com	New York	New York	630459331800223	e9b8b6421db42be71efa69224bc72361	Voyager	40.6775604858752331	-73.9157533934235573
34614	2020-07-02 02:52:56	2020-07-02	Babyboy Raynor	babyboy.raynor@geemail.com	Tucson	Arizona	4679399261321737	e4ddefc3bd6ab959f15f54550ac26858	JCB 16 digit	32.1856001529883642	-110.783776640775045
34615	2020-07-02 02:58:38	2020-07-02	Ms. Theola Konopelski MD	ms.theola.konopelski.md@warmmail.com	Dallas	Texas	210094710525786241	390ada166eb47884b79b0851fa4b6325	JCB 15 digit	32.81251546403319	-96.789608945135015
34616	2020-07-02 02:59:19	2020-07-02	Ira Steuber-Greenholt	ira.steuber.greenholt@geemail.com	San Francisco	California	52024991723665370	f5817ab9d3460736c585fb90ee08064a	Discover	37.814449792921593	-122.432828802079072
34617	2020-07-02 03:10:11	2020-07-02	Miss Sade Wehner PhD	miss.sade.wehner.phd@geemail.com	Greensboro	North Carolina	869939528058297909	9f82a13fc60ae96558992a2c89149dfd	VISA 16 digit	36.056570083985477	-79.8646845943275849
34618	2020-07-02 03:34:17	2020-07-02	Mr. Crockett Morar	mr.crockett.morar@woohoo.com	San Francisco	California	4168089725416078	3c983a8b75de608b37325bdb5a7c3a43	VISA 16 digit	37.7599703675597453	-122.402973515635864
34619	2020-07-02 03:46:12	2020-07-02	Carey Wisoky-Kuphal	carey.wisoky.kuphal@woohoo.com	San Francisco	California	3027179202029083	991a2551170fa00de6da78a899f6d9b3	VISA 13 digit	37.7922602830157572	-122.415009128571114
34620	2020-07-02 03:48:37	2020-07-02	Jordyn Goyette	jordyn.goyette@woohoo.com	Philadelphia	Pennsylvania	630463975408665	10f6d88b420831977f4dd71d4d76aa51	Maestro	40.0987188784830266	-75.0550410236131427
34621	2020-07-02 04:04:20	2020-07-02	Dayna Ebert-Torphy	dayna.ebert.torphy@warmmail.com	Jacksonville	Florida	3724538533928694	2cbdbadb0d70765ab3929e12276a84d8	Maestro	30.4164266212429837	-81.589381306998817
34622	2020-07-02 04:05:48	2020-07-02	Dr. Valentino Hammes II	dr.valentino.hammes.ii@geemail.com	San Francisco	California	3158403976039675016	d93e26247fbe920fe427f9f9999d8f65	VISA 16 digit	37.7787468087869911	-122.476876504991438
34623	2020-07-02 04:15:31	2020-07-02	Deshawn Howell	deshawn.howell@geemail.com	Bakersfield	California	3158935655019392803	d7ef7b6355c3dda28e1355fe4ec6943b	JCB 16 digit	35.3249089865188992	-119.061099826478582
34624	2020-07-02 04:20:56	2020-07-02	Launa Brekke	launa.brekke@woohoo.com	Gainesville	Florida	3015856810622969	f5a439a956b8f2146e6047d1e6b6b30e	Diners Club / Carte Blanche	29.7717348163772364	-82.3675828124735574
34625	2020-07-02 04:21:40	2020-07-02	Chasity Ruecker	chasity.ruecker@geemail.com	Baltimore	Maryland	4538593739161	08d02a9abbefa031d0bdac8e0f1e2e79	VISA 16 digit	39.2145036847330601	-76.6946523726936391
34626	2020-07-02 04:51:15	2020-07-02	Ms. Ronna Lockman	ms.ronna.lockman@woohoo.com	Pearland	Texas	3411064693011945	2fd7de5b3c7717f859d72ffc762f937e	Maestro	29.5644115290410845	-95.4018897615227814
34627	2020-07-02 04:51:24	2020-07-02	Gladys Strosin	gladys.strosin@geemail.com	San Francisco	California	3096835433113889533	dec8b13ccf0389e25ec088306da2b621	JCB 15 digit	37.7854128500351223	-122.460703697053404
34628	2020-07-02 05:03:41	2020-07-02	Hervey Conn	hervey.conn@geemail.com	Chicago	Illinois	3020174233121436	c8bf6160bfc407287b072c7b653fb5fd	VISA 13 digit	41.8262722667142768	-87.6449514200009361
34629	2020-07-02 05:23:44	2020-07-02	Micah Flatley	micah.flatley@geemail.com	San Francisco	California	4772027882308132	d6d99cb78a4753b953d9182c5d51571b	VISA 16 digit	37.8047231915297033	-122.406458686079617
34630	2020-07-02 05:49:33	2020-07-02	Donavan Crooks	donavan.crooks@geemail.com	Albuquerque	New Mexico	4060214347100	9fc8c4eba397be50a289c79bcdf1da42	VISA 16 digit	35.0473042863555264	-106.67682788656802
34631	2020-07-02 05:51:14	2020-07-02	Calista Lemke	calista.lemke@warmmail.com	Stockton	California	676221474969231	36fab5c22a8c88c88f192f15b7b3be19	Diners Club / Carte Blanche	37.9158330403931458	-121.224283931878574
34632	2020-07-02 05:56:48	2020-07-02	Trudie Auer	trudie.auer@geemail.com	Mesa	Arizona	210001680910584166	04b298300ed8bb285439ee0c520780b9	Mastercard	33.4618764495156711	-111.786874985217679
34633	2020-07-02 06:03:20	2020-07-02	Zettie Cartwright	zettie.cartwright@geemail.com	New York	New York	3088081581312756258	2a12b6c66ede88fd15f984f2ebf2ca78	VISA 13 digit	40.5988091556113204	-74.0325919942825976
34634	2020-07-02 06:09:49	2020-07-02	Mrs. Tiarra Murray	mrs.tiarra.murray@geemail.com	Ontario	California	3026070285750094	ab8e5b42c91e16c44ea568a8c237d660	JCB 15 digit	34.0462323380779495	-117.66943422342726
34635	2020-07-02 06:18:15	2020-07-02	Lyric Schiller	lyric.schiller@geemail.com	Milwaukee	Wisconsin	4565785358685322	960f2c536a9af2a107b23d58647a15ed	Maestro	43.1105483394667459	-88.0203469964776275
34636	2020-07-02 06:21:01	2020-07-02	Ovid Hessel	ovid.hessel@geemail.com	San Francisco	California	675909721890615	34e2c0d259c3227852a9aab677789e32	American Express	37.7788082352550703	-122.424998459668018
34637	2020-07-02 06:35:52	2020-07-02	Zaid Frami	zaid.frami@geemail.com	Tacoma	Washington	4111430837810	bd0cc73368393ca12b51a0831de03787	JCB 15 digit	47.2575689627908204	-122.508898845897249
34638	2020-07-02 06:36:09	2020-07-02	Britt Zulauf	britt.zulauf@woohoo.com	Columbus	Ohio	4859434037767	c58c2ba093df0a812f96bff1481fba35	VISA 13 digit	40.0393290605440697	-83.0622014115799345
34639	2020-07-02 06:47:57	2020-07-02	Kenna Prosacco	kenna.prosacco@geemail.com	San Francisco	California	3755891509446080	30c50e9c7f92573c2bbe436e2716a7ff	VISA 16 digit	37.7607099072266834	-122.435099883377688
34640	2020-07-02 06:56:41	2020-07-02	Alden Lynch PhD	alden.lynch.phd@geemail.com	New York	New York	3006442587377928	616e1ba9bd3222012643caf4aec26437	Diners Club / Carte Blanche	40.7386085043884805	-74.0022846740100562
34641	2020-07-02 07:04:40	2020-07-02	Sonya Lind	sonya.lind@geemail.com	New York	New York	6011162157747997494	7f3cea12a67ca35227e6a843cd4d9c4d	VISA 16 digit	40.7238311758954055	-73.9070823542203783
34642	2020-07-02 07:13:28	2020-07-02	Dr. Daniele Rempel PhD	dr.daniele.rempel.phd@geemail.com	Oceanside	California	180019178503461306	4873a7054c78f7933ea637d3e7e8a26c	Diners Club / Carte Blanche	33.1812606488708397	-117.337332253538818
34643	2020-07-02 07:43:13	2020-07-02	Hildegarde Roberts	hildegarde.roberts@geemail.com	El Paso	Texas	3337498194904414679	433efe99da30e0c8a2ca85c677e9517e	VISA 13 digit	31.8107679487966024	-106.452347311003138
34644	2020-07-02 07:43:34	2020-07-02	Makena Jenkins	makena.jenkins@geemail.com	Lafayette	Louisiana	3746890685129686	ef001d57699786f67c108f670e093766	American Express	30.2164549086220546	-92.1086321726757973
34645	2020-07-02 07:47:40	2020-07-02	Dinah Hand	dinah.hand@woohoo.com	Chicago	Illinois	210026506162780924	b9ae4e40e34d5193ddfcb220b26c168c	Discover	41.8584447455428545	-87.5894200949959441
34646	2020-07-02 07:53:04	2020-07-02	Therman Klein	therman.klein@geemail.com	Milwaukee	Wisconsin	53204548060373000	87d25eab901e302a6b3804398f0688a6	JCB 16 digit	43.0087211588017624	-87.9177055128484994
34647	2020-07-02 08:00:03	2020-07-02	Delano Lakin	delano.lakin@geemail.com	New Orleans	Louisiana	54217297663209550	05558452dc761bce91646906abb7b191	JCB 16 digit	30.0210702396012827	-89.8824529558680894
34648	2020-07-02 08:08:51	2020-07-02	Dr. Beatriz Toy DVM	dr.beatriz.toy.dvm@geemail.com	Reno	Nevada	55086891565759395	daf9f8f0372ff6021b1f29fc54f95b80	VISA 13 digit	39.5503311034835932	-119.904828446235143
34649	2020-07-02 08:22:09	2020-07-02	Chaney Gaylord MD	chaney.gaylord.md@warmmail.com	New York	New York	4830200434008993	c3aacb6b34ab8d2cd8c893a7fe309604	VISA 16 digit	40.6873083802163578	-73.9044754650339399
34650	2020-07-02 08:38:07	2020-07-02	Carole Kohler-Buckridge	carole.kohler.buckridge@woohoo.com	Seattle	Washington	4745334307015274	690c4d2c73327c5d02fe8648f6a92cc3	Mastercard	47.7172637768480925	-122.2706686762549
34651	2020-07-02 08:39:17	2020-07-02	Yolonda Howell	yolonda.howell@warmmail.com	Lowell	Massachusetts	4497319531224164	8b1a8b0cb8be661ee0bfff11b04bbcf0	Voyager	42.6727870338931723	-71.231350938497485
34652	2020-07-02 08:56:09	2020-07-02	Mohammad Hagenes Sr.	mohammad.hagenes.sr.@geemail.com	Oklahoma City	Oklahoma	4752149277432	65c97e696c774f14d8e6be98cd07d18a	Discover	35.4835751437492704	-97.5736749875720619
34653	2020-07-02 09:17:33	2020-07-02	Dr. Dereon Langosh	dr.dereon.langosh@geemail.com	Anchorage	Alaska	4777552070728812	589f6aa4c4eb9f567fd3045339496002	VISA 13 digit	61.0761650695215934	-149.184636885638525
34654	2020-07-02 09:19:39	2020-07-02	Benjman Frami	benjman.frami@geemail.com	Tacoma	Washington	3736242396809432	f1fee0b31f70afafa6a89a2b1240c1f3	VISA 16 digit	47.1807437083337504	-122.481723561301081
34655	2020-07-02 09:21:12	2020-07-02	Polk Mueller	polk.mueller@geemail.com	Paterson	New Jersey	55065757824879917	24145f06a0c509f82073c75f61eb59dc	VISA 16 digit	40.8767919347576765	-74.1252930782709285
34656	2020-07-02 09:24:57	2020-07-02	Rogelio Cole-Rice	rogelio.cole.rice@geemail.com	New York	New York	3337399261648627682	04f0f1bde6ef739459717d751cdcc248	VISA 16 digit	40.6030961651578508	-73.9754013265844463
34657	2020-07-02 09:26:29	2020-07-02	Dr. Hakim Kling	dr.hakim.kling@geemail.com	Glendale	Arizona	4200466740715	0c1acfadd066e7a8ee6049979e2fcea5	JCB 16 digit	33.4463927981205273	-112.157819686948869
34658	2020-07-02 09:33:49	2020-07-02	Hattie Grant IV	hattie.grant.iv@woohoo.com	San Francisco	California	3002031199303333	f7ca206adc0b18abdcbcd6d7bb7e518e	JCB 16 digit	37.7813816529043152	-122.468473514750499
34659	2020-07-02 09:35:38	2020-07-02	Kendrick Kerluke	kendrick.kerluke@geemail.com	Mesa	Arizona	4726090618047553	c6abd5c21538133720842eac2d7b7d60	JCB 16 digit	33.3932085106760255	-111.794593488273762
34660	2020-07-02 09:41:13	2020-07-02	Rachel Legros	rachel.legros@geemail.com	St. Petersburg	Florida	210016898394183171	f9151d60adf9132ccb187cd51327f29e	JCB 15 digit	27.7516776600275179	-82.5667230830885472
34661	2020-07-02 09:45:48	2020-07-02	Mr. Steward Blick II	mr.steward.blick.ii@geemail.com	New York	New York	3463522857212275	31b534f6e18d16848e4a6f1c830639b2	JCB 15 digit	40.7585188792776307	-74.0264516243606749
34662	2020-07-02 09:52:59	2020-07-02	Karla Kreiger	karla.kreiger@woohoo.com	Charlotte	North Carolina	55823144361288815	6c2c3f5b068992934409dc1ad4728363	Voyager	35.1180452856954162	-80.9000351600293044
34663	2020-07-02 09:54:17	2020-07-02	Dr. Elodie Predovic DVM	dr.elodie.predovic.dvm@geemail.com	Philadelphia	Pennsylvania	502005560487521	09b628b8626cdd5b79b6f9c382442a86	JCB 16 digit	39.9892690891824643	-75.2121453854620512
34664	2020-07-02 09:59:27	2020-07-02	Melvin Smitham	melvin.smitham@geemail.com	Corpus Christi	Texas	210030327392479508	28ff5165251a31324dc785bd9d0a2452	American Express	27.7651878876548253	-97.0895110356915723
34665	2020-07-02 10:01:11	2020-07-02	Leo Dicki	leo.dicki@warmmail.com	Boise	Idaho	180060007965691977	7770b65fd86f3409099b0daa99559311	Diners Club / Carte Blanche	43.6660466356806438	-116.314864490666238
34666	2020-07-02 10:02:06	2020-07-02	Ellen Parker-Johns	ellen.parker.johns@geemail.com	San Francisco	California	53569964115301020	83ce0ad022b087935109a4d034ad9a20	JCB 15 digit	37.7771184230290871	-122.429327670571411
34667	2020-07-02 10:04:35	2020-07-02	Loree Hettinger	loree.hettinger@geemail.com	New Orleans	Louisiana	4391077240953	5f76cedaaa8b443ff77dd74456f05022	VISA 13 digit	30.0713023072123526	-89.9921685351319667
34668	2020-07-02 10:11:23	2020-07-02	Dr. Derrick Welch	dr.derrick.welch@geemail.com	Denton	Texas	180051823163860052	a21a976d8be3bf8c23f2c0825f522970	Diners Club / Carte Blanche	33.2845140880703951	-97.1916049679867911
34669	2020-07-02 10:15:12	2020-07-02	Dr. Wilfrid Mante	dr.wilfrid.mante@geemail.com	Kansas City	Missouri	869925206755688946	7ed92824d30e2eeaf0d134c003033663	JCB 16 digit	39.184318289982528	-94.6219089949261445
34670	2020-07-02 10:27:29	2020-07-02	Vergil Hackett	vergil.hackett@warmmail.com	Bakersfield	California	4902677204767	f3af966dbb944666c87da2a65866d95e	JCB 16 digit	35.2961625451397154	-118.997349360426142
34671	2020-07-02 10:34:53	2020-07-02	Selene Gutmann	selene.gutmann@geemail.com	New York	New York	6011664532825550089	6975491ff517b4a22250f51bdfdd7808	American Express	40.7407262904327325	-73.8463476084068446
34672	2020-07-02 10:37:31	2020-07-02	Zana Schaefer	zana.schaefer@geemail.com	Hayward	California	3031492386831554	2fda4a7c93e4fca99e636d85a9be2d60	VISA 16 digit	37.5634448036540292	-122.081872672333944
34673	2020-07-02 11:00:06	2020-07-02	Miss Alethea Pfeffer DDS	miss.alethea.pfeffer.dds@geemail.com	San Diego	California	3030169994607169	68f0dd31304385e616c11c2a197b2fd6	JCB 15 digit	32.7684741449143715	-117.15854885032401
34674	2020-07-02 11:19:35	2020-07-02	Dr. Ricardo Reinger III	dr.ricardo.reinger.iii@geemail.com	Nashville	Tennessee	4030471962354	7cb429c75e3612a2c296ee77b79ef47a	Discover	36.2515627017367592	-86.83093124426901
34675	2020-07-02 11:24:29	2020-07-02	Chalmer Ward	chalmer.ward@woohoo.com	Charlotte	North Carolina	4508616986974	6d9674760163145861a146e5adbbad01	Voyager	35.2829821847166869	-80.871632482292128
34676	2020-07-02 11:28:39	2020-07-02	Charlene Donnelly	charlene.donnelly@geemail.com	Dallas	Texas	3528244878036474927	b84ee559de16adefcba009c95e546f55	Discover	32.8530781681455721	-96.7431716566402429
34677	2020-07-02 12:01:29	2020-07-02	Asberry Hammes	asberry.hammes@geemail.com	Modesto	California	4243608184970	08a96aa400182a3456af8e300b31a756	Discover	37.6363828920759289	-121.018168848633763
34678	2020-07-02 12:03:47	2020-07-02	Johnson Huels	johnson.huels@geemail.com	St. Louis	Missouri	180097565855101149	93eaaec592a22a9ac442f569b3d693af	Voyager	38.6575580982647864	-90.1699885562531733
34679	2020-07-02 12:05:02	2020-07-02	Jordyn Howe	jordyn.howe@geemail.com	New York	New York	869939085551506757	62e211576b3d61d8c8ab5b724881bd55	Discover	40.7443380880393065	-73.9696017114806921
34680	2020-07-02 12:09:00	2020-07-02	Lavonda O'Reilly	lavonda.o'reilly@warmmail.com	Fort Lauderdale	Florida	53157177426647779	e3cf4c490a93533aede2274a99dd7c60	JCB 15 digit	26.0971425813145963	-80.1135914113659311
34681	2020-07-02 12:11:09	2020-07-02	Mr. Kymani O'Reilly	mr.kymani.o'reilly@geemail.com	Chandler	Arizona	3112870981287002867	78ec87d3e583b1ec1cc9a52c3ac7afed	Voyager	33.3242211261853569	-111.890792461659387
34682	2020-07-02 12:11:58	2020-07-02	Jamey Greenholt PhD	jamey.greenholt.phd@warmmail.com	Phoenix	Arizona	53657383584675918	057b895832488f1a48136ba1c4ea79fd	American Express	33.4862930202323952	-112.090778157433874
34683	2020-07-02 12:19:33	2020-07-02	Leonie Rempel	leonie.rempel@geemail.com	Beaumont	Texas	3337943712708895537	aeee120ec94688a04993bc3c7a1a447d	JCB 15 digit	30.100251315075532	-94.1545858395073623
34684	2020-07-02 12:20:13	2020-07-02	Miss Cheryll Davis	miss.cheryll.davis@woohoo.com	Minneapolis	Minnesota	3776476858342117	4f70f3447a493faaa013b41fabf4825d	Discover	45.0537436809476404	-93.2877800754543358
34685	2020-07-02 12:21:29	2020-07-02	Anastacio Buckridge PhD	anastacio.buckridge.phd@geemail.com	San Francisco	California	52739260006191157	b12d02904491816c1d701d0e612f0218	Mastercard	37.7448756025693939	-122.42362550745797
34686	2020-07-02 12:22:41	2020-07-02	Millard Kessler-Schoen	millard.kessler.schoen@warmmail.com	Phoenix	Arizona	3024987676539228	78bdb8dd8313274a5403030c009cae6a	VISA 16 digit	33.5040761231377715	-112.075905185930807
34687	2020-07-02 12:27:10	2020-07-02	Dr. Rocio Kunde	dr.rocio.kunde@geemail.com	San Antonio	Texas	6011055921545044142	4c88e62f50befec6bf623b8373311462	VISA 13 digit	29.428172713618352	-98.4976639605428943
34688	2020-07-02 12:42:28	2020-07-02	Irene Hammes	irene.hammes@geemail.com	Washington	District of Columbia	3035329807116643	807340a63c90d2a2e9d0c718707b9f24	Maestro	38.8908903833743196	-76.9235426722772502
34689	2020-07-02 13:00:11	2020-07-02	Domenico Block	domenico.block@woohoo.com	Macon	Georgia	3753143288967502	00ffb7f2c64b685ad48275ab0237c4fa	Diners Club / Carte Blanche	32.8034913803461947	-83.7009196215968529
34690	2020-07-02 13:21:36	2020-07-02	Alyvia Romaguera	alyvia.romaguera@warmmail.com	Corpus Christi	Texas	210099885455658803	dd6fb73b3fc6d9d4639606547c87772a	Mastercard	27.6639875705290592	-97.1741249083835612
34691	2020-07-02 13:34:15	2020-07-02	Amina Barton-VonRueden	amina.barton.vonrueden@geemail.com	Fort Collins	Colorado	502085006758362	7fd0ece1d87118cf53052a0f2df8cf6a	Mastercard	40.6454760260570822	-105.010500562931597
34692	2020-07-02 13:39:56	2020-07-02	Nathanial Mayert	nathanial.mayert@geemail.com	Tulsa	Oklahoma	4135468491686439	d1829cfffbcbbf7262cf88d6d4284c06	JCB 15 digit	36.0542435072731209	-95.8506392505440772
34693	2020-07-02 13:47:45	2020-07-02	Lee Schumm	lee.schumm@geemail.com	Concord	California	4316590926812	21a5e584540a7ebe3be1889ef0dd2781	American Express	37.9483052956804627	-121.909250054385879
34694	2020-07-02 13:54:11	2020-07-02	Einar Auer	einar.auer@warmmail.com	San Francisco	California	180005206456350295	f00f284bc76e89449e55336a32c41900	American Express	37.7962280824218766	-122.410089708026177
34695	2020-07-02 14:10:05	2020-07-02	Gladys Leannon	gladys.leannon@geemail.com	Killeen	Texas	3447663544916703	891169dde435f33cc22088578fdc6edc	JCB 16 digit	31.1042121322590859	-97.7342444196045363
34696	2020-07-02 14:10:15	2020-07-02	Buell Daniel	buell.daniel@geemail.com	Oakland	California	4243046150334324	7bbc041af9a5fac6011d404eace85d5b	JCB 16 digit	37.8203654523832284	-122.247592304654944
34697	2020-07-02 14:11:04	2020-07-02	Jo Prosacco	jo.prosacco@warmmail.com	Chicago	Illinois	4309843326247914	8232e51ac399f9db4316cd93f39f0ea7	VISA 13 digit	41.8424086336348253	-87.5869687194965678
34698	2020-07-02 14:16:20	2020-07-02	Edris Hauck	edris.hauck@woohoo.com	San Jose	California	501882348311133	458d0a1aa770d336087c0b24a8fccd56	Mastercard	37.3450255419414532	-121.803418063720315
34699	2020-07-02 14:46:48	2020-07-02	Joy Lemke	joy.lemke@geemail.com	San Antonio	Texas	180024924662934648	7313605830214d96d3b0cc5838b1b273	VISA 16 digit	29.4305801821943369	-98.589008865675325
34700	2020-07-02 14:48:24	2020-07-02	Ms. Leola Wisozk DDS	ms.leola.wisozk.dds@geemail.com	San Antonio	Texas	3528924541864295130	a12b8ee45cf9aa9753fe431dfc373cba	Maestro	29.5289778150688846	-98.6033377029303466
34701	2020-07-02 14:52:51	2020-07-02	Charle Gottlieb DDS	charle.gottlieb.dds@warmmail.com	Mobile	Alabama	4332475423947939	a96d916dcaf6f4879b7c810efe7b94f0	Discover	30.7340011752784221	-88.1756017300438089
34702	2020-07-02 15:03:09	2020-07-02	Marlena Braun DVM	marlena.braun.dvm@warmmail.com	Berkeley	California	3528483261133563779	8a4880723d97d0b7a75ca6377f037186	VISA 13 digit	37.8979215618467009	-122.250960309697106
34703	2020-07-02 15:12:34	2020-07-02	Sussie Strosin	sussie.strosin@woohoo.com	Reno	Nevada	4786793035172097	392ecd6338122756edb283b461ccbe14	Discover	39.4795271607194138	-119.781291569925472
34704	2020-07-02 15:18:24	2020-07-02	Marco Wolff	marco.wolff@geemail.com	Dallas	Texas	4992591893162543	9b9bcadfbcb1f4d8bd04f4ba3f2253f1	Mastercard	32.7453133138168653	-96.7305731710940506
34705	2020-07-02 15:20:52	2020-07-02	Dr. Tex Jast IV	dr.tex.jast.iv@geemail.com	Cedar Rapids	Iowa	869970876102558150	b35321e9d3887d32c48de942dc47ce6b	JCB 15 digit	42.0185955208335074	-91.7253140189751974
34706	2020-07-02 15:27:53	2020-07-02	Ginger Huel	ginger.huel@geemail.com	North Las Vegas	Nevada	6011293593383266525	85cc2f7eb95a2faeca8a347fec86c184	VISA 13 digit	36.3847816981066003	-115.084702574576809
34707	2020-07-02 15:32:56	2020-07-02	Ignacio Flatley	ignacio.flatley@geemail.com	Houston	Texas	3337571257087847757	c891ca21fcc512d90183b67581d73bd9	Voyager	29.697788339581713	-95.3895788401845834
34708	2020-07-02 15:35:15	2020-07-02	Leota Ebert-Torp	leota.ebert.torp@geemail.com	Baltimore	Maryland	6011276893332080444	356426b6c88ad99ec7b0d23bb7092331	American Express	39.3479899138212161	-76.5375140267442902
34709	2020-07-02 15:39:41	2020-07-02	Dr. Bishop Windler	dr.bishop.windler@woohoo.com	Dallas	Texas	4072120712913	148ec4ab181966c8aede4f343c6932d7	Diners Club / Carte Blanche	32.8350072956915966	-96.785983244372531
34710	2020-07-02 15:42:15	2020-07-02	Toivo Gulgowski	toivo.gulgowski@warmmail.com	San Francisco	California	3158944177211452219	a5ae75d846c4442d0708cb6bd6c7aa30	Mastercard	37.7958265265109077	-122.474669274766043
34711	2020-07-02 15:47:57	2020-07-02	Geoffrey Zieme-Hand	geoffrey.zieme.hand@geemail.com	Sacramento	California	869909296369990283	5ad946f6f13e6cda235e9afc1818051e	Maestro	38.6626426379926542	-121.505651950441674
34712	2020-07-02 15:56:13	2020-07-02	Alvan Bayer	alvan.bayer@warmmail.com	Fresno	California	3088725300909912774	f904ee04b8c4fc2942e7acdb2b5d4542	VISA 16 digit	36.7762434669643667	-119.837458271404358
34713	2020-07-02 15:57:47	2020-07-02	Mr. Jordyn Windler IV	mr.jordyn.windler.iv@warmmail.com	Chicago	Illinois	869912953904067234	f700735eae536ae00d0d78b148a8e024	VISA 16 digit	41.7840497730135922	-87.6532351314119893
34714	2020-07-02 15:59:45	2020-07-02	Thursa Kirlin	thursa.kirlin@geemail.com	New York	New York	869977105954651118	c77d6879db1035383837a0c180f3d079	Mastercard	40.6402681725788852	-73.931424138312039
34715	2020-07-02 16:02:53	2020-07-02	Ayaan Sporer	ayaan.sporer@warmmail.com	New York	New York	6011482459523047178	e8441c3df149ef413284c99f2b1f6b1d	VISA 16 digit	40.5932388785053035	-73.8802246421471267
34716	2020-07-02 16:08:38	2020-07-02	Buena Grimes	buena.grimes@warmmail.com	Rockford	Illinois	210015547531517996	1545700c4dd262859a83adf7eefc61c2	Mastercard	42.1859554872859306	-89.1101265100579667
34717	2020-07-02 16:22:01	2020-07-02	Donita Kautzer	donita.kautzer@geemail.com	Des Moines	Iowa	3088257913958986410	027a9e19d1d745fcd4e50d114d03c216	Diners Club / Carte Blanche	41.6454320098947761	-93.5867945198945819
34718	2020-07-02 16:29:24	2020-07-02	Edsel Romaguera	edsel.romaguera@woohoo.com	Lincoln	Nebraska	3701215873873692	f130210c991d7e9c0836e470c93ef5e4	JCB 16 digit	40.8089248274005953	-96.7012990459959951
34719	2020-07-02 16:37:36	2020-07-02	Columbus Crist-Wilderman	columbus.crist.wilderman@geemail.com	Phoenix	Arizona	4974802140443236	fcd772ddc644217e3a0a252a3c366190	VISA 16 digit	33.5612628954395689	-112.185921855450061
34720	2020-07-02 16:40:54	2020-07-02	Villa Schimmel	villa.schimmel@warmmail.com	Houston	Texas	4045566669995	6ad3f8432484cb2d0440859acef0f1e9	JCB 16 digit	29.7699019250072539	-95.4238463710542817
34721	2020-07-02 16:59:03	2020-07-02	Abigail Ankunding-Hammes	abigail.ankunding.hammes@geemail.com	Stockton	California	502090254443949	c38648254d81665d04d1a0802b2071b8	VISA 13 digit	37.9308869922731091	-121.218882626536484
34722	2020-07-02 17:04:09	2020-07-02	Joyce Labadie-Bednar	joyce.labadie.bednar@geemail.com	Anaheim	California	3528193774099216050	8e2044ee0f14107788ccd5a4263db7a4	VISA 16 digit	33.85651134357974	-117.686965456672382
34723	2020-07-02 17:05:29	2020-07-02	Ginger Kub	ginger.kub@geemail.com	Omaha	Nebraska	869999261119709459	ce548c12256465e83539ae0df35d8072	American Express	41.1987407992273589	-96.0162507741827511
34724	2020-07-02 17:14:22	2020-07-02	Dr. Ella Boyle	dr.ella.boyle@woohoo.com	Oakland	California	54780940272580666	b6a7de2fccd2449436b556b30cdfca91	Voyager	37.8011656407179473	-122.274741131732256
34725	2020-07-02 17:17:04	2020-07-02	Darell D'Amore II	darell.d'amore.ii@geemail.com	Ann Arbor	Michigan	4507578914172	25f3f90f4916bfc57be55501d96ff97d	Maestro	42.3012090339850602	-83.643986588587623
34726	2020-07-02 17:18:46	2020-07-02	Allean D'Amore	allean.d'amore@geemail.com	New York	New York	3337205269662509847	4e23630c68014c2a7a7b0f27697ae5a8	VISA 16 digit	40.6342436096854485	-73.8876175191614806
34727	2020-07-02 17:23:27	2020-07-02	Vicente Crist	vicente.crist@woohoo.com	Peoria	Illinois	3794388620137600	91816740bb127bd8f20291158f187dd0	JCB 16 digit	40.6950707953292863	-89.6551089740242872
34728	2020-07-02 17:29:19	2020-07-02	Dr. Monnie Stroman DDS	dr.monnie.stroman.dds@geemail.com	San Francisco	California	4995507456767277	2e55457fe5a6b97774338faa9719c82a	JCB 15 digit	37.7975900801731868	-122.422042009523466
34729	2020-07-02 17:30:19	2020-07-02	Dr. Rodger Parker	dr.rodger.parker@woohoo.com	New York	New York	4058778398851701	8023af3a2e144613faa5824de4a44289	Mastercard	40.6918523038029676	-73.8968077040638747
34730	2020-07-02 17:49:37	2020-07-02	Ulysses Kub-Dickens	ulysses.kub.dickens@geemail.com	Colorado Springs	Colorado	869959266962414246	0df9e8706075bb37c66d4a2c8b83e1ed	JCB 16 digit	38.890304139680417	-104.662766698577258
34731	2020-07-02 17:53:27	2020-07-02	Darius Shanahan	darius.shanahan@geemail.com	Fresno	California	869951815114659864	17d37cbe5c96395b0b321c3fe1f70eae	Mastercard	36.8475702626504003	-119.854338041424384
34732	2020-07-02 17:54:23	2020-07-02	Marques Spinka-Brakus	marques.spinka.brakus@geemail.com	Los Angeles	California	503837085418236	a079e7be4df0e8a3063f45cb2288ff25	Voyager	34.0632201017677758	-118.316314420568943
34733	2020-07-02 18:07:15	2020-07-02	Shania Gerlach	shania.gerlach@geemail.com	Sparks	Nevada	52786306364600578	c5635a25bdd8092fd0eb8e1c9ded4685	Voyager	39.5004512928664724	-119.799605021657797
34734	2020-07-02 18:11:16	2020-07-02	Landon Jacobs	landon.jacobs@geemail.com	San Diego	California	3528600582203653010	c1537e24063b71a75c9dd0a1ecf67ef9	Maestro	32.8256383802808855	-117.173582445913937
34735	2020-07-02 18:17:04	2020-07-02	Arra Schamberger	arra.schamberger@geemail.com	San Francisco	California	3112526373247458041	8e3efd96d3b05e3614f5e84ca732079b	Diners Club / Carte Blanche	37.7751677606719696	-122.439895924594524
34736	2020-07-02 18:17:49	2020-07-02	Dr. Crista Lueilwitz MD	dr.crista.lueilwitz.md@geemail.com	El Paso	Texas	3096391528168787023	f05b339ca2b19e95d8b66c3cb2be5ae7	JCB 16 digit	31.8795880777124339	-106.424056332044316
34737	2020-07-02 18:25:50	2020-07-02	Dr. Evert Ward	dr.evert.ward@warmmail.com	Tuscaloosa	Alabama	3777749410410674	59765870c1e3036da1a634c8d32fa8ba	Mastercard	33.173513061465691	-87.4473700000535672
34738	2020-07-02 18:38:58	2020-07-02	Miss Riya Schumm	miss.riya.schumm@geemail.com	El Paso	Texas	4952819844363284	17f79a9378b1cb7254f7d7227d38c93c	Voyager	31.753013344231622	-106.441332803478474
34739	2020-07-02 18:41:27	2020-07-02	Kem Baumbach	kem.baumbach@warmmail.com	Miami	Florida	3037640088212226	7d9d05bb0b27d7895ed6fb7ec499133d	Maestro	25.8091563717599968	-80.2330858011603425
34740	2020-07-02 19:11:08	2020-07-02	Nelie Ward DVM	nelie.ward.dvm@geemail.com	Knoxville	Tennessee	869914545236251805	0488c6ecbecd72916b3cbce2b5fa341b	Maestro	36.0234968339622057	-83.9934418191417933
34741	2020-07-02 19:11:16	2020-07-02	Miss Shelli Cormier DDS	miss.shelli.cormier.dds@geemail.com	Kansas City	Missouri	3158261912128861549	dc60dc598aa6fbc17f0a06e451568afc	Maestro	39.2130290884360733	-94.5382764413244985
34742	2020-07-02 19:13:13	2020-07-02	Marcia Thiel	marcia.thiel@warmmail.com	Austin	Texas	6011952845663173934	22dec3be8137cea2aa7f52f476ae5a2a	Diners Club / Carte Blanche	30.2598108491055662	-97.8303747055359167
34743	2020-07-02 19:23:14	2020-07-02	Dr. Lucky Grady PhD	dr.lucky.grady.phd@geemail.com	Los Angeles	California	51005635844099810	652b7c4bd1c094a7294186a4fc1260f5	American Express	34.0001971922680681	-118.426821079337216
34744	2020-07-02 19:24:22	2020-07-02	Danita Goldner	danita.goldner@geemail.com	Jacksonville	Florida	4990014981544	9b459a493d861f3a34bf0b1a4ffa327c	Mastercard	30.4023809202067561	-81.6843756815962507
34745	2020-07-02 19:26:22	2020-07-02	Khalilah Klocko DVM	khalilah.klocko.dvm@geemail.com	New York	New York	676246521022312	f85c5601f0269c137d041e8f0f77c98d	Maestro	40.568367918416854	-74.0165644476551563
34746	2020-07-02 19:28:07	2020-07-02	Cheryll Goodwin-Armstrong	cheryll.goodwin.armstrong@geemail.com	New York	New York	869918429142403329	52e6db73297fa02c0e0ffabf97bff83f	Mastercard	40.6381498312335481	-73.9526931857120218
34747	2020-07-02 19:35:57	2020-07-02	Mrs. Eugenia Leffler DVM	mrs.eugenia.leffler.dvm@geemail.com	San Francisco	California	3402401572515888	9aa38ca116cfff3d1a76622c4ae1762b	Discover	37.7849889310577822	-122.464617299462844
34748	2020-07-02 19:51:16	2020-07-02	Herman Wolf PhD	herman.wolf.phd@geemail.com	Sunnyvale	California	210097860564045707	42bcb1688a1a9caf23fd8c141d1849e8	Discover	37.3944834423709693	-122.100283695264906
34749	2020-07-02 19:53:08	2020-07-02	Larue Adams	larue.adams@woohoo.com	Indianapolis	Indiana	4992222192212025	48cf6f4d27429fbee8db4d332e8e2dbd	Diners Club / Carte Blanche	39.7619569539099942	-86.1563563833679922
34750	2020-07-02 20:09:26	2020-07-02	Shyheim Fahey	shyheim.fahey@geemail.com	Omaha	Nebraska	3767605461347912	5d6123f1b9254b0e101170c1a938ca3b	VISA 16 digit	41.2608204614516367	-96.060758442070707
34751	2020-07-02 20:26:03	2020-07-02	Duane Dooley DVM	duane.dooley.dvm@geemail.com	San Francisco	California	3019527893376106	c8590e717e7d8542f9c91534a47afebb	Maestro	37.8074939210461878	-122.380133922605623
34752	2020-07-02 20:31:52	2020-07-02	Angie Pagac	angie.pagac@geemail.com	San Francisco	California	060496110654637	0b0f9432897ed494efd0078d452105a4	JCB 15 digit	37.7891463246100088	-122.445705080286558
34753	2020-07-02 20:32:12	2020-07-02	Zoe Mosciski	zoe.mosciski@geemail.com	San Francisco	California	3096573297887739992	9788bc4807cd3cda9df212420218924e	Maestro	37.8057177487714853	-122.434099626775193
34754	2020-07-02 20:35:38	2020-07-02	Susie Emmerich-Rosenbaum	susie.emmerich.rosenbaum@geemail.com	Sparks	Nevada	4330451949494740	9a665f687aa1de3e5ca9f116758ddf71	Maestro	39.605795288622005	-119.636014842786267
34755	2020-07-02 20:37:51	2020-07-02	Kadyn Schinner	kadyn.schinner@geemail.com	New York	New York	4457646407918	4be9dd054d967617d8eceaa72d59f8fd	VISA 13 digit	40.6059492984544477	-73.9039564566116809
34756	2020-07-02 20:39:26	2020-07-02	Mrs. Clare Lynch PhD	mrs.clare.lynch.phd@geemail.com	Phoenix	Arizona	3482376583253450	5cae6b5b391b8f405543b32c057eec11	Mastercard	33.4915602054845536	-112.081594790837173
34757	2020-07-02 21:09:47	2020-07-02	Harriette Kertzmann	harriette.kertzmann@geemail.com	Oakland	California	180056409673553976	59f1af70c2ce0573901b8162512d0da2	Discover	37.80225517917426	-122.241338279097775
34758	2020-07-02 21:25:49	2020-07-02	Marland Carter V	marland.carter.v@geemail.com	Costa Mesa	California	3096600753041906866	07b09ecf062d2a3ee4171e75ddc6ced3	JCB 16 digit	33.7150019071545444	-117.847119722129037
34759	2020-07-02 21:48:21	2020-07-02	Hal Kunde	hal.kunde@warmmail.com	Los Angeles	California	180063754290210687	002996356af08741bd69b52d33b1c0d4	VISA 13 digit	33.9215829482633566	-118.387483912705619
34760	2020-07-02 21:50:35	2020-07-02	Broderick Konopelski	broderick.konopelski@warmmail.com	Murrieta	California	4588988207572864	165a9d8afe2886ff7b77fc57894db91b	VISA 13 digit	33.6661635461360191	-117.275565243176743
34761	2020-07-02 22:00:49	2020-07-02	Harlen Carter	harlen.carter@geemail.com	New York	New York	3007448740816768	b13f5164f83b9ce9888008b5c49e96e0	Mastercard	40.7333494716081788	-73.8867287021026016
34762	2020-07-02 22:01:16	2020-07-02	Garnett Hane	garnett.hane@geemail.com	Oakland	California	3088499247015614832	0ae0431f223ffb16eb60cc0135852533	Discover	37.8260747481058885	-122.255606571282613
34763	2020-07-02 22:03:11	2020-07-02	Fernand Wiza II	fernand.wiza.ii@woohoo.com	Buffalo	New York	3723146427643055	639d4960fd551d763956d40360bd32bc	Mastercard	42.9898957085050597	-78.9482117634665315
34764	2020-07-02 22:05:50	2020-07-02	Silver Kuhn	silver.kuhn@warmmail.com	Winston–Salem	North Carolina	503876321654071	9897fa7d295816be033ac90c905e1f5c	Diners Club / Carte Blanche	36.1313715464666458	-80.2010460344739187
34765	2020-07-02 22:28:38	2020-07-02	Victorine Feest-Satterfield	victorine.feest.satterfield@warmmail.com	Seattle	Washington	4991973447235101	c68a8d5a4685d1df9f1ffd9f0fbfe68d	JCB 16 digit	47.5801129613462805	-122.350779191862415
34766	2020-07-02 22:32:08	2020-07-02	Brigid Powlowski	brigid.powlowski@geemail.com	Raleigh	North Carolina	3044583737332693	80ecf8291b8013f94436c13cdc31c3ac	VISA 13 digit	35.7830562350008634	-78.5737860883988475
34767	2020-07-02 22:34:07	2020-07-02	Glennie Wolff DDS	glennie.wolff.dds@geemail.com	Elizabeth	New Jersey	3771520452567200	72a6847693286e3b1ba68be79b06034f	Diners Club / Carte Blanche	40.763526244381076	-74.1796990197561712
34768	2020-07-02 23:01:09	2020-07-02	Faustino Bogan	faustino.bogan@geemail.com	Salt Lake City	Utah	3528321218248237455	20b7ee161b336dd79c06b3ea98df77df	JCB 16 digit	40.8296010562829679	-112.00815968433767
34769	2020-07-02 23:01:32	2020-07-02	Mr. Linus Gislason DVM	mr.linus.gislason.dvm@geemail.com	Portland	Oregon	3010107227599902	3b7a7e03d7c9b00d8ba70fdba81ee586	VISA 13 digit	45.5700060568172489	-122.632186474138877
34770	2020-07-02 23:09:59	2020-07-02	Jovani Barrows	jovani.barrows@woohoo.com	Lincoln	Nebraska	4643786980063066	01fdd9a53c6356abae2bc93073642838	Voyager	40.8529713142681814	-96.6653254474207841
34771	2020-07-02 23:35:59	2020-07-02	Helene Braun	helene.braun@warmmail.com	Chicago	Illinois	4883062458182955	7dff36ee770b017def004ef2875e4318	VISA 16 digit	41.9266123852062975	-87.6668166839547354
34772	2020-07-02 23:39:16	2020-07-02	Concetta Lueilwitz	concetta.lueilwitz@woohoo.com	Fresno	California	4127479617657	d8e147cd5534f92cff59b073f79edbe3	JCB 16 digit	36.683630641304326	-119.818962888709834
34773	2020-07-02 23:40:30	2020-07-02	Easton Von	easton.von@geemail.com	San Francisco	California	869947477684206043	10e478fcbae26987f723473d6200affc	JCB 16 digit	37.7526785100795479	-122.426164446196879
34774	2020-07-02 23:59:40	2020-07-02	Jocelyne Labadie	jocelyne.labadie@geemail.com	El Paso	Texas	869990625909568169	933766de83343b2f716233272a58dcd2	Diners Club / Carte Blanche	31.8386205563150355	-106.526906114116315
34775	2020-07-03 00:13:47	2020-07-03	Remy Stiedemann	remy.stiedemann@geemail.com	Atlanta	Georgia	869919673352440161	b018c5d1889f9db7e87e8c92262393de	VISA 16 digit	33.700691327247398	-84.4935398870658219
34776	2020-07-03 00:24:43	2020-07-03	Mrs. Jazmyne Waters	mrs.jazmyne.waters@geemail.com	Columbus	Ohio	3414830515618423	28777b7bbef522f2a59c789e1dca8cb8	VISA 16 digit	40.0547104323327545	-83.0616320081755646
34777	2020-07-03 00:24:49	2020-07-03	Devante Cronin	devante.cronin@woohoo.com	Colorado Springs	Colorado	4250164207152	2e2bc74917bd9d89b80f739023dad97c	Maestro	38.9535920972984258	-104.822862936711687
34778	2020-07-03 00:32:08	2020-07-03	Mr. Davin Heller MD	mr.davin.heller.md@geemail.com	Toledo	Ohio	502078620182093	1faebd14cfddf2851c6f81a6c2d38b99	Maestro	41.5781903824474668	-83.6758081683754966
34779	2020-07-03 00:47:31	2020-07-03	Isidore Ortiz	isidore.ortiz@geemail.com	Huntsville	Alabama	869978556036269684	6f6ce654eab0295f25bd2a6dd0fad89d	Discover	34.7331742400079975	-86.6721962020751135
34780	2020-07-03 01:00:29	2020-07-03	Virgle Lockman	virgle.lockman@warmmail.com	Baltimore	Maryland	4886318428463967	024b08efd14b9a2c89d62d0d1bdaa64b	JCB 16 digit	39.3300689324270891	-76.6709400656186091
34781	2020-07-03 01:01:03	2020-07-03	Johnson Friesen	johnson.friesen@woohoo.com	Chicago	Illinois	180001866706012757	ac05f922341081bdbd6d2ef055494bf3	Discover	41.9374673449736122	-87.6682295543637053
34782	2020-07-03 01:08:14	2020-07-03	Torry Cormier	torry.cormier@geemail.com	Chicago	Illinois	210035320438353386	2d5489b0607f3a8cb7b6ef3bcaa5a832	Mastercard	41.7905460615944122	-87.6744542314700794
34783	2020-07-03 01:09:24	2020-07-03	Elick Hodkiewicz-Parisian	elick.hodkiewicz.parisian@geemail.com	Oxnard	California	676342240663718	6082cf8c01fb684cde81e701f918b9a1	VISA 13 digit	34.1112414666406849	-119.221825666949528
34784	2020-07-03 01:13:44	2020-07-03	Mr. Garrick Johnson	mr.garrick.johnson@geemail.com	Bakersfield	California	869913365770275727	89142eecba75129a38a03363456a26bc	Mastercard	35.3549774796411356	-118.932764537240558
34785	2020-07-03 01:17:37	2020-07-03	Phillis Eichmann DVM	phillis.eichmann.dvm@geemail.com	Austin	Texas	3337814467217431813	2ea9eced2eede444378a5c20422d6fbd	JCB 15 digit	30.3664374808907489	-97.6858996527973602
34786	2020-07-03 01:21:50	2020-07-03	Courtney Denesik	courtney.denesik@geemail.com	Houston	Texas	3004727125086011	fcf69d4b3e3162a316e0508c8daef7c7	VISA 16 digit	29.7606448557306074	-95.3117537635859122
34787	2020-07-03 01:22:28	2020-07-03	Sim Ward V	sim.ward.v@geemail.com	McKinney	Texas	4804015069938	a3c176f8d72b63912f1abb98bb484ef9	Discover	33.2305414403919173	-96.7561522940006142
34788	2020-07-03 01:27:22	2020-07-03	Jasiah Franecki I	jasiah.franecki.i@warmmail.com	Detroit	Michigan	4602931563798	f26df41265824536ccf99555f60b9a78	Diners Club / Carte Blanche	42.2857223843615557	-83.0622786516908462
34789	2020-07-03 01:49:23	2020-07-03	Alethea Krajcik MD	alethea.krajcik.md@geemail.com	Minneapolis	Minnesota	3528902546975372427	e796ba5ed5829e01537cf583da47e4b6	Diners Club / Carte Blanche	45.061050721871851	-93.2750795948591076
34790	2020-07-03 01:53:02	2020-07-03	Jaliyah Schneider	jaliyah.schneider@geemail.com	McAllen	Texas	3096381785291795990	7ba45ceb9836e4a69fcc0702debbef58	Discover	26.2963217370051865	-98.2481738506197928
34791	2020-07-03 02:02:23	2020-07-03	Jayme Bashirian	jayme.bashirian@woohoo.com	Long Beach	California	3019517855473199	e69e5a54f628378513b6b1862b71d89b	JCB 16 digit	33.9008118923108981	-118.188972542124986
34792	2020-07-03 02:09:50	2020-07-03	Qiana Keeling	qiana.keeling@geemail.com	San Francisco	California	869979277446639692	61fe43b45fcc704279d7cc6c5ee14372	VISA 16 digit	37.7649132864883939	-122.388339572818367
34793	2020-07-03 02:11:46	2020-07-03	Gustav Rogahn	gustav.rogahn@woohoo.com	San Jose	California	869964934677739396	e02179f0454a3501df9d27d21a7ac4e8	American Express	37.3360771922215804	-121.794452210304883
34794	2020-07-03 02:15:01	2020-07-03	Hiroshi Labadie	hiroshi.labadie@woohoo.com	San Francisco	California	4248107825640712	12037dc969762506172b8a6e21906888	Discover	37.7588090754932608	-122.379892970255341
34795	2020-07-03 02:32:33	2020-07-03	Manervia Lang	manervia.lang@geemail.com	San Francisco	California	3528746673427475465	dc883ecf3176f118f78dfac92c3bfaaa	JCB 15 digit	37.7419674989044651	-122.391076355665547
34796	2020-07-03 02:38:01	2020-07-03	Ivory Nitzsche-Jenkins	ivory.nitzsche.jenkins@geemail.com	Portland	Oregon	4805781370359970	856e96202aa4b96c809381057dd5dd3d	American Express	45.4985119610447413	-122.599360538227486
34797	2020-07-03 02:40:53	2020-07-03	Austin Thompson	austin.thompson@woohoo.com	San Francisco	California	3798592116298612	8c687e87c2f65770ffe18bfedc1640aa	VISA 16 digit	37.7578283806268615	-122.414389300556579
34798	2020-07-03 02:43:42	2020-07-03	Isabell Blick MD	isabell.blick.md@woohoo.com	Houston	Texas	3158873353670176400	a475faa6205220c85cff6d7d957e0708	Maestro	29.8411373182278119	-95.4230046800818315
34799	2020-07-03 02:45:41	2020-07-03	Ava Block	ava.block@geemail.com	Plano	Texas	180007951836751377	b1883c1e5ab1a8fbdac97985e737d9fe	JCB 16 digit	33.1427365068897615	-96.6782553306963308
34800	2020-07-03 02:54:28	2020-07-03	Delora Sporer	delora.sporer@geemail.com	Detroit	Michigan	3337237226075063343	4d420042a4e0ce4021d7bc7ec026f00b	Diners Club / Carte Blanche	42.4121534720920081	-83.1407132980067303
34801	2020-07-03 02:54:59	2020-07-03	Lovina Kuhn	lovina.kuhn@woohoo.com	Chicago	Illinois	3001671759127001	35e8ac782e6d534de8359d8582a358ec	American Express	41.8379794483374852	-87.7109633595712381
34802	2020-07-03 02:58:20	2020-07-03	Ike Tremblay	ike.tremblay@geemail.com	Oakland	California	180058142150249200	56a08edd37039dc93dab648f71102dde	Discover	37.8196417300408996	-122.281008012655917
34803	2020-07-03 03:26:18	2020-07-03	Chas Hermiston	chas.hermiston@warmmail.com	Miami Gardens	Florida	210041551890822888	88f8592a9506014f498c5da840d7b719	Diners Club / Carte Blanche	25.9937001783806814	-80.294658559399096
34804	2020-07-03 03:29:38	2020-07-03	Mr. Elige Schmeler V	mr.elige.schmeler.v@geemail.com	Berkeley	California	210042547134434844	365d81a2f212c683c0dc67389f1c2215	Mastercard	37.908103779633187	-122.284393890830941
34805	2020-07-03 04:06:23	2020-07-03	Malakai Hilll	malakai.hilll@geemail.com	Milwaukee	Wisconsin	3337881396497676284	2b4d185b896bd0873f4ea5d549cc385d	VISA 16 digit	43.0618668015200612	-88.0370329213429272
34806	2020-07-03 04:06:52	2020-07-03	Dr. Hosea Braun	dr.hosea.braun@woohoo.com	Salem	Oregon	503852569765051	3da63952eb5c5265cd4b285a2b2faa68	Maestro	44.8718051187962246	-123.052750963919607
34807	2020-07-03 04:10:08	2020-07-03	Melina Huel	melina.huel@geemail.com	Waco	Texas	3482028851917973	198e950f2a88571cb0e4da68b70cc246	Diners Club / Carte Blanche	31.6471751226320848	-97.1868443867322185
34808	2020-07-03 04:10:29	2020-07-03	Aida Kshlerin	aida.kshlerin@geemail.com	Anaheim	California	210099947500452143	520f524204824eafde181483f6583809	Voyager	33.9174462138507522	-117.756304322529957
34809	2020-07-03 04:18:50	2020-07-03	Gillie Jacobi	gillie.jacobi@geemail.com	Stockton	California	4024026615004451	5698af58cacd823629bdfe9bffae378e	VISA 16 digit	37.919904425713419	-121.354208917086197
34810	2020-07-03 04:27:41	2020-07-03	Rayne Fadel	rayne.fadel@geemail.com	Tampa	Florida	4247526487043	86fd1c3397ce57ff40f5bd8a512622d3	Mastercard	27.9328459124661954	-82.4052943481344613
34811	2020-07-03 04:29:39	2020-07-03	Arianna Gottlieb-Orn	arianna.gottlieb.orn@geemail.com	Norman	Oklahoma	3158064762735823294	c16dc58faf24a6f650331a9b8a8094b5	JCB 16 digit	35.214291853927449	-97.4114926629953004
34812	2020-07-03 04:34:23	2020-07-03	Ms. Ossie Jones	ms.ossie.jones@geemail.com	Thornton	Colorado	3112826222431077736	9fb1317bc35fe6f58725aa31f4dd7871	JCB 16 digit	39.8812859596550524	-104.983448840833461
34813	2020-07-03 04:37:52	2020-07-03	Mr. Harvie Hettinger	mr.harvie.hettinger@geemail.com	San Francisco	California	53819965565472938	2756e4d756ded3ccc43a7a61f8ca9e52	Mastercard	37.7601222480317702	-122.435604360011951
34814	2020-07-03 04:43:22	2020-07-03	Benjamin Adams	benjamin.adams@geemail.com	Chicago	Illinois	55487087641273627	078117b8e15f7b986886d8f4623ce162	VISA 16 digit	41.7431434043984879	-87.5878457530897094
34815	2020-07-03 04:48:12	2020-07-03	Genoveva Kunde	genoveva.kunde@geemail.com	Round Rock	Texas	53340626435728697	c299fd0ea535cd6cc5d17c099f55e8bd	Diners Club / Carte Blanche	30.4349385267727079	-97.5890925855226783
34816	2020-07-03 04:57:35	2020-07-03	Moira Pouros	moira.pouros@geemail.com	Milwaukee	Wisconsin	210087080448394526	7182420f57c76d5929fea4998cd4de9a	Mastercard	43.000088347968827	-88.0062705162081897
34817	2020-07-03 05:00:13	2020-07-03	Nichelle Quitzon-Roob	nichelle.quitzon.roob@geemail.com	Garden Grove	California	180063664625501090	1ffea3978ba15f2c3cdfd478aee051e2	VISA 16 digit	33.7583551185496091	-118.023346950115638
34818	2020-07-03 05:11:22	2020-07-03	Mimi Kling	mimi.kling@geemail.com	Los Angeles	California	51909030141765403	2d539319a9fb3485ded9f508716ae354	JCB 16 digit	34.0446117490395892	-118.505816422774643
34819	2020-07-03 05:13:36	2020-07-03	Gunnar Douglas-Smitham	gunnar.douglas.smitham@woohoo.com	Long Beach	California	3088013336205587143	7fa2391f51ecc03caa9d60182553f74f	VISA 16 digit	33.7861852910190805	-118.197175006677583
34820	2020-07-03 05:26:12	2020-07-03	Marolyn Daniel	marolyn.daniel@geemail.com	Baltimore	Maryland	4218177378559	9d88f942ac1d94614a5c3b312625dfff	VISA 16 digit	39.317977667739612	-76.6634791888780853
34821	2020-07-03 05:34:30	2020-07-03	Dr. Mannie Buckridge DDS	dr.mannie.buckridge.dds@geemail.com	Oakland	California	639074905807397	6f4dba388e7f9693d2af75eb93fc512c	Voyager	37.7698751942315241	-122.26453544082824
34822	2020-07-03 05:54:08	2020-07-03	Mrs. Elda Russel PhD	mrs.elda.russel.phd@geemail.com	Oakland	California	630462510706849	d5716e176d31c3e4880828a9e7411492	JCB 16 digit	37.7650368124071818	-122.294295625620506
34823	2020-07-03 06:03:19	2020-07-03	Emil Koss	emil.koss@geemail.com	Fort Worth	Texas	180020906370877635	61208c41060e0c8f452ac0478456ddf0	American Express	32.851418113946913	-97.3852372524615362
34824	2020-07-03 06:07:11	2020-07-03	Xavier Dooley	xavier.dooley@geemail.com	Berkeley	California	869945071004348676	1cae709da0fc037f685b8e9e7183d874	American Express	37.863279557717	-122.282528080195988
34825	2020-07-03 06:11:58	2020-07-03	Melony Schiller DVM	melony.schiller.dvm@geemail.com	San Francisco	California	3528140878745177824	6f0eeff374ac21b8a2a9ac3d0c388620	JCB 16 digit	37.8058000865441741	-122.437677986355027
34826	2020-07-03 06:12:08	2020-07-03	Diane Mann	diane.mann@geemail.com	San Francisco	California	4493971934453669	b4d541f7361e550d2169632c782c6a2e	VISA 13 digit	37.7496719765086368	-122.458041190890299
34827	2020-07-03 06:18:26	2020-07-03	Bode Powlowski V	bode.powlowski.v@geemail.com	Anchorage	Alaska	869970184910799250	8ef400ba3f1a927c8e5e2eba9653c644	Voyager	61.2051677331544468	-149.353295781056573
34828	2020-07-03 06:21:48	2020-07-03	Dabney Casper II	dabney.casper.ii@geemail.com	New York	New York	3337458261091347596	46fd95c42e4bf0d56d086aca7c3d9cf1	VISA 16 digit	40.641165078034625	-73.8493341580860232
34829	2020-07-03 06:22:51	2020-07-03	Colin Ritchie	colin.ritchie@geemail.com	Irving	Texas	3112061020118726748	c0334264628e0bc9c53e6faa090065cd	Diners Club / Carte Blanche	32.8703053403597352	-97.0483793965820212
34830	2020-07-03 06:27:25	2020-07-03	Ms. Johnna Brakus DDS	ms.johnna.brakus.dds@geemail.com	Alexandria	Virginia	3783753302728781	ac604193f26060707ebd766abb2cbbc0	VISA 16 digit	38.8135254811611006	-77.1055368849527127
34831	2020-07-03 06:29:53	2020-07-03	Ione Brown	ione.brown@geemail.com	New Orleans	Louisiana	3112248385297214238	970b42f1caa12302762a3c7162bbbe41	Maestro	30.0085892197225235	-89.8765325987972261
34832	2020-07-03 06:30:31	2020-07-03	Ms. Tricia Rogahn	ms.tricia.rogahn@geemail.com	Louisville	Kentucky	4289135038890220	2ceb9bc0ba923071252f37759b5542c1	VISA 13 digit	38.1492648503180547	-85.5946586794756428
34833	2020-07-03 06:38:17	2020-07-03	Dr. Meggan Haag DDS	dr.meggan.haag.dds@geemail.com	Mesa	Arizona	869936611004004323	24942ed4cea583a309400407f49e480c	JCB 16 digit	33.4949143556091897	-111.626180533727251
34834	2020-07-03 06:42:41	2020-07-03	Miner Lindgren	miner.lindgren@geemail.com	Fresno	California	6011417440324474415	c95c1ccd46f53f219866a57f0fb25fee	VISA 16 digit	36.8648688430305569	-119.717562032781174
34835	2020-07-03 06:47:36	2020-07-03	Viva Labadie	viva.labadie@geemail.com	San Francisco	California	180099281610125591	57d56c5d62d41f22882b1b20a290094d	VISA 16 digit	37.7594680927043811	-122.415461728551136
34836	2020-07-03 06:50:33	2020-07-03	Anjanette Marquardt DDS	anjanette.marquardt.dds@warmmail.com	Denver	Colorado	54787607910727933	183fbcf5fcd445b5cb53df9ae87f7b32	Diners Club / Carte Blanche	39.8167805431928485	-104.929023820186416
34837	2020-07-03 06:50:34	2020-07-03	Iza Dietrich	iza.dietrich@warmmail.com	Richmond	Virginia	180032592904783493	101e5c0e04f923d12ab9008f96f1480d	Discover	37.4958980954006265	-77.5443346077799731
34838	2020-07-03 06:50:54	2020-07-03	Oren Hermann	oren.hermann@geemail.com	Concord	California	55168419092104942	639d4d3b6234b61fd52d4c60277c3346	VISA 13 digit	37.9877342280864738	-122.048900092969092
34839	2020-07-03 06:51:52	2020-07-03	Tami Rolfson	tami.rolfson@geemail.com	San Francisco	California	4746881092040577	a65cb3109d4221562fb3ffd5857d19d0	Diners Club / Carte Blanche	37.7861525746278559	-122.456085040078364
34840	2020-07-03 07:00:35	2020-07-03	Elijah Schuppe	elijah.schuppe@woohoo.com	Edison	New Jersey	3088914807284804567	a2b5addfbeb3e16f72d8b4ce1d2f0091	JCB 16 digit	40.4950470132715949	-74.425823743739727
34841	2020-07-03 07:03:36	2020-07-03	Ms. Grace Gerhold	ms.grace.gerhold@geemail.com	Topeka	Kansas	869962719809970650	7b723c177faefd5ebd41ea92e64ab9c4	Mastercard	39.0623650663930917	-95.6694849933207081
34842	2020-07-03 07:04:54	2020-07-03	Elzada Gusikowski	elzada.gusikowski@woohoo.com	San Diego	California	3430100928649716	77a2c76b743ba1f93a6dbc2f7ac95d42	VISA 16 digit	32.7196554248753912	-117.220857716854667
34843	2020-07-03 07:05:41	2020-07-03	Ericka Herzog	ericka.herzog@geemail.com	El Cajon	California	210099074129434442	92113604809ee450db823c066fd7d187	Discover	32.7652172557551395	-116.912164835696672
34844	2020-07-03 07:08:15	2020-07-03	Mr. Derek Muller	mr.derek.muller@geemail.com	Irving	Texas	6011392777361152449	69e1daffad0a8fbe0c4566f3716f1246	JCB 15 digit	32.9303487825624686	-96.9658313552197058
34845	2020-07-03 07:12:48	2020-07-03	Harriet Klocko	harriet.klocko@woohoo.com	Boston	Massachusetts	3053932316648808	e122ff167be9fdc4112c380cd22e3f07	JCB 16 digit	42.2595784113910042	-70.9850799744434653
34846	2020-07-03 07:15:40	2020-07-03	Dr. Miriam McCullough	dr.miriam.mccullough@geemail.com	Chicago	Illinois	210089759409296998	9a6712fc1cce5f26a41e59ce0abe1881	VISA 16 digit	41.925221206836774	-87.632468736174701
34847	2020-07-03 07:15:48	2020-07-03	Wilmer Denesik	wilmer.denesik@geemail.com	Surprise	Arizona	4990553686109042	543d23cb515c233ca516a60477e82084	VISA 13 digit	33.7326800161734255	-112.45088577198311
34848	2020-07-03 07:19:58	2020-07-03	Jaquan Ankunding-Glover	jaquan.ankunding.glover@geemail.com	Los Angeles	California	6011214894767981903	f0a72c50e33c59c04b3e15b6adc1ba34	JCB 16 digit	34.0339822314079825	-118.368520090961084
34849	2020-07-03 07:22:39	2020-07-03	Drew Breitenberg	drew.breitenberg@geemail.com	Boston	Massachusetts	3096047307271152799	7e00f901de417a6d5a43198b9c194803	American Express	42.2490062930323163	-71.1118730347089496
34850	2020-07-03 07:30:18	2020-07-03	Yehuda Morar	yehuda.morar@geemail.com	Joliet	Illinois	3020434573109379	986a8e97216d81d011e518d7814f7331	Maestro	41.5166718445111016	-88.0834731023397239
34851	2020-07-03 07:31:31	2020-07-03	Oddie Moen	oddie.moen@warmmail.com	Syracuse	New York	3112484983912979301	5a5182df25e1518db230f6dca3fcb675	Diners Club / Carte Blanche	43.0181177298389343	-76.1382963367518073
34852	2020-07-03 07:33:25	2020-07-03	Miss Jalissa Batz MD	miss.jalissa.batz.md@geemail.com	Round Rock	Texas	3434124880121213	ae63a4b78ee8a209711b6232d62e8010	American Express	30.4727826668087403	-97.5750247464366254
34853	2020-07-03 07:34:12	2020-07-03	Buck Cummerata	buck.cummerata@geemail.com	Oakland	California	3402774390449955	17df6e4db62c6c50908a04a30d4aac0e	Mastercard	37.8080524447985482	-122.263869711662764
34854	2020-07-03 07:35:10	2020-07-03	Zakary Littel	zakary.littel@geemail.com	Rancho Cucamonga	California	4114210302155435	040cb5a813ae60a50623c0b6018145e6	Discover	34.0760705052401889	-117.65703969299868
34855	2020-07-03 07:42:06	2020-07-03	Mr. Roby Trantow	mr.roby.trantow@geemail.com	San Francisco	California	3528825272694322379	1cda67658e898f566c15f7e358632d58	Maestro	37.8244506738962585	-122.407038937485368
34856	2020-07-03 08:09:28	2020-07-03	Macie Bechtelar	macie.bechtelar@warmmail.com	San Francisco	California	060419880901103	0a96e12d2e7728094f5ac86962630a95	American Express	37.7865739951731356	-122.425222261940448
34857	2020-07-03 08:09:35	2020-07-03	Jena Schroeder-Yost	jena.schroeder.yost@woohoo.com	Ontario	California	4736709212863	0a12fa1436224c4175ac36b7ac685315	Diners Club / Carte Blanche	33.9967975203558836	-117.535586309955278
34858	2020-07-03 08:14:11	2020-07-03	Dijon Kozey	dijon.kozey@geemail.com	San Francisco	California	869924237412939274	854f57899d530ba01f63fb76e9d837eb	JCB 16 digit	37.7537626279040737	-122.430487190310998
34859	2020-07-03 08:30:06	2020-07-03	Ethie Rodriguez	ethie.rodriguez@geemail.com	Sugar Land	Texas	4134066686601204	099055e99ccc40bd064853a253d19dd5	American Express	29.573451565118134	-95.5323084533687705
34860	2020-07-03 08:39:28	2020-07-03	Trudy Konopelski	trudy.konopelski@woohoo.com	Allen	Texas	3435347192363723	c5d7b5bbd0d94deae39dd19d1a2a89a3	Maestro	33.1927324647575617	-96.5887630437914311
34861	2020-07-03 08:40:24	2020-07-03	Signa Predovic	signa.predovic@geemail.com	Raleigh	North Carolina	4825635922847906	e905322f09bcef718c3acfae49455eaa	JCB 16 digit	35.8436751173477575	-78.7402155635349459
34862	2020-07-03 08:44:33	2020-07-03	Jeanetta Kihn	jeanetta.kihn@geemail.com	Austin	Texas	675938639290923	c01e0daa9b904a7696e90b0d1c7cbf4c	Diners Club / Carte Blanche	30.3557953525461244	-97.802477423963694
34863	2020-07-03 08:53:08	2020-07-03	Dr. Camron Ziemann	dr.camron.ziemann@geemail.com	Houston	Texas	4603533976925	f0a0fb0b6cfc82bbf42b5151d53478ea	Mastercard	29.8556864055417464	-95.2968357354417464
34864	2020-07-03 09:14:35	2020-07-03	Ira Dooley	ira.dooley@woohoo.com	Laredo	Texas	4188353676613737	ce2d635a2a0397b7cbdebf4a9dfc9fcc	JCB 16 digit	27.5070150789521648	-99.4442671708770121
34865	2020-07-03 09:19:13	2020-07-03	Vic Kihn	vic.kihn@geemail.com	Davie	Florida	210077784465569512	b2d01abbcf8f02d3be2f2f7f20c834b4	Mastercard	26.0177644645594057	-80.1923427516966996
34866	2020-07-03 09:21:07	2020-07-03	Texie Ernser-Emmerich	texie.ernser.emmerich@geemail.com	West Jordan	Utah	51805898927603039	28620cbeb5a6ac71ce4a3777ceb700bc	Diners Club / Carte Blanche	40.6960482933349965	-111.90821660678759
34867	2020-07-03 09:25:56	2020-07-03	Lacey Mayer	lacey.mayer@warmmail.com	Santa Maria	California	4849014161263609	c7b639a5fb2babab482816547df8b8dd	Voyager	34.8952194878429154	-120.40161002216972
34868	2020-07-03 09:32:31	2020-07-03	Dr. Felix Quitzon I	dr.felix.quitzon.i@geemail.com	Baltimore	Maryland	4052123480348298	b0b4a9eb18abc7babaea23f0ae0e2b91	JCB 16 digit	39.2069638439454096	-76.7038791721705309
34869	2020-07-03 09:37:02	2020-07-03	Krystin Okuneva-Pollich	krystin.okuneva.pollich@geemail.com	Fontana	California	4057888048055	8b3c42a1e264b3877bce6c3b51228489	VISA 16 digit	34.1506680176276731	-117.415177339249851
34870	2020-07-03 09:44:57	2020-07-03	Mr. Ephram Feeney Jr.	mr.ephram.feeney.jr.@geemail.com	Columbia	South Carolina	3158615903454698301	c5190f6fa438ab2ca61d87a6f3cc356b	JCB 16 digit	34.0072265577301351	-80.8980789363402835
34871	2020-07-03 09:48:55	2020-07-03	Ida Leuschke	ida.leuschke@geemail.com	Palmdale	California	3469522172035199	22634d86a3a79d4c5e8056f980c603df	Voyager	34.5234196693953166	-118.051473848148817
34872	2020-07-03 09:54:15	2020-07-03	Mrs. Sarrah Heller MD	mrs.sarrah.heller.md@geemail.com	Washington	District of Columbia	3112782795648718194	8d9e5234635260c709e1e79130dec5cc	JCB 15 digit	38.8788932592406837	-77.116403114584088
34873	2020-07-03 09:56:57	2020-07-03	Mr. Dedrick Nienow IV	mr.dedrick.nienow.iv@geemail.com	Houston	Texas	3158522879218488183	a62d9e5860b6117c10a06e0d5a980949	Discover	29.8410966068584464	-95.3744350387729725
34874	2020-07-03 09:58:05	2020-07-03	Bambi Bernier	bambi.bernier@geemail.com	Greensboro	North Carolina	55299523219229557	08a36fb5b8f681f228cdcf76e387ee65	Mastercard	36.1557340568047039	-79.8236970735695195
34875	2020-07-03 10:30:42	2020-07-03	Lola Kerluke	lola.kerluke@geemail.com	San Diego	California	561290809963656	a97aacd12c5dfe56d12035b8c7b80e2f	VISA 16 digit	32.873417154845967	-117.073409684738152
34876	2020-07-03 10:37:59	2020-07-03	Shan Schaefer	shan.schaefer@geemail.com	San Francisco	California	3059594565357038	12dcd22743dfbd4873248ed6d9781f5b	JCB 15 digit	37.7789941217286938	-122.460320933910509
34877	2020-07-03 10:46:10	2020-07-03	Lina Ziemann	lina.ziemann@geemail.com	San Diego	California	869917266402133266	a9b08ea452e5d2f16a6796b8fb1f2053	Voyager	32.7330373198792373	-117.146192852817478
34878	2020-07-03 10:46:23	2020-07-03	Melville Rohan	melville.rohan@geemail.com	San Antonio	Texas	869999728772777965	13154c4d4cc1bfa0db9b578f0a7079af	Discover	29.4830346027459953	-98.5832785937771092
34879	2020-07-03 11:01:52	2020-07-03	Dr. Zenas Volkman II	dr.zenas.volkman.ii@geemail.com	Jacksonville	Florida	3798169937238406	a6336fdc031bb542c76f2a0a7b2d7ca2	Voyager	30.2771507813181735	-81.7084105675652665
34880	2020-07-03 11:06:17	2020-07-03	Aida Cummerata	aida.cummerata@geemail.com	Shreveport	Louisiana	4442870791534	b187e09d68eb7ebcb81fd49e4ab95ff8	VISA 16 digit	32.3759013531036715	-93.8251854436218622
34881	2020-07-03 11:14:45	2020-07-03	Mr. Rayan Hamill I	mr.rayan.hamill.i@geemail.com	Oxnard	California	6011785651307069386	c29b3b9101626df92e8abe92c284753e	Maestro	34.104935230869053	-119.147727820035442
34882	2020-07-03 11:18:45	2020-07-03	Dalton Dickens	dalton.dickens@geemail.com	Berkeley	California	3112818557616642832	48f237142e569381b4d6ba120679cc03	JCB 15 digit	37.8362263517897972	-122.275732337463253
34883	2020-07-03 11:22:25	2020-07-03	Quincy Bartoletti	quincy.bartoletti@geemail.com	Pembroke Pines	Florida	4164431597999191	a2566da592834aef28345e32388e9ff7	VISA 16 digit	25.9374308917243042	-80.389711854504057
34884	2020-07-03 11:23:33	2020-07-03	Osborn Carroll	osborn.carroll@geemail.com	Memphis	Tennessee	53567847954044565	a147e4e51528e1999e719e36e3fc54e5	VISA 13 digit	35.0080248946391066	-89.9232425126969872
34885	2020-07-03 11:40:35	2020-07-03	Brianna Ankunding-Wisoky	brianna.ankunding.wisoky@woohoo.com	Minneapolis	Minnesota	869986162091842679	8b7f3cfecb35765a3583f3581763969d	Voyager	45.0421322260603247	-93.2316641123305914
34886	2020-07-03 11:42:24	2020-07-03	Mrs. Devon Halvorson	mrs.devon.halvorson@geemail.com	Orange	California	3088535669755628134	26240105bb1332c4ab9958675d5f0aab	Mastercard	33.7661013228241345	-117.871084336714077
34887	2020-07-03 11:43:48	2020-07-03	Hakim Grimes	hakim.grimes@geemail.com	St. Petersburg	Florida	3337021239717081615	2dfa3419aafc35b7ab166e7163700932	Voyager	27.6927391709182409	-82.6342658077258534
34888	2020-07-03 12:08:43	2020-07-03	Maxine Lakin	maxine.lakin@geemail.com	New York	New York	3490114984035063	c8c714d202d127a936d0685800ab842e	VISA 16 digit	40.7513551302477737	-74.0347665867663949
34889	2020-07-03 12:09:28	2020-07-03	Rosie Effertz-Adams	rosie.effertz.adams@geemail.com	Reno	Nevada	3096779957942975012	ecd6f08999d45a1c8fd95ca6cd486a0a	JCB 15 digit	39.5171627212859704	-119.802153935905181
34890	2020-07-03 12:11:16	2020-07-03	Mr. Westley Rohan	mr.westley.rohan@woohoo.com	Grand Prairie	Texas	210054728697123736	231e56fbcc7730a53120c816152b132f	VISA 13 digit	32.5883356748666628	-96.9702590514313414
34891	2020-07-03 12:20:38	2020-07-03	Payton Ziemann	payton.ziemann@woohoo.com	Fort Worth	Texas	3450258527739786	94bdca9caa12e2a80a46d80935febac3	VISA 16 digit	32.8392557766810071	-97.4449412411365614
34892	2020-07-03 12:21:25	2020-07-03	Darold Stamm	darold.stamm@warmmail.com	San Bernardino	California	503806581005052	b5acbfc05dff3d6b1264f692833235f2	Diners Club / Carte Blanche	34.2109756252992838	-117.231702934602652
34893	2020-07-03 12:28:35	2020-07-03	Johny Lakin DDS	johny.lakin.dds@geemail.com	Arlington	Texas	869952068321305280	dd894565e689908dec11bbaa22a89112	JCB 16 digit	32.6969133919820152	-97.0331176513832077
34894	2020-07-03 12:33:12	2020-07-03	Daisey Hintz	daisey.hintz@geemail.com	New York	New York	6011763498808525672	569696424b3589131a5b0c571ec394ad	Diners Club / Carte Blanche	40.5732978453151887	-73.9637153667759151
34895	2020-07-03 12:34:43	2020-07-03	Ms. Juliette Bednar DDS	ms.juliette.bednar.dds@woohoo.com	Phoenix	Arizona	6011607595795145172	b18f38f06374aaf40c2b4c309537f0c1	Voyager	33.6454354928273744	-112.071091350719712
34896	2020-07-03 12:37:04	2020-07-03	Dr. Brogan Murray	dr.brogan.murray@warmmail.com	Washington	District of Columbia	4687057072492	3bb54e7322a80723718a8ac670ce112f	JCB 16 digit	38.9835803475029792	-76.9244842734865841
34897	2020-07-03 12:39:42	2020-07-03	Randall Bahringer	randall.bahringer@geemail.com	Los Angeles	California	3462299519258118	126da3782f2482a1a3adafbdb78cb93c	VISA 13 digit	34.0482183352909971	-118.457798842805616
34898	2020-07-03 12:39:46	2020-07-03	Darleen Goldner	darleen.goldner@geemail.com	San Francisco	California	180055254084126132	845d6b0a071713dcb821aab3e2682f9b	American Express	37.7544121047408652	-122.44083723289755
34899	2020-07-03 12:43:15	2020-07-03	Mr. Jessie Lind DVM	mr.jessie.lind.dvm@warmmail.com	Los Angeles	California	3088078113434616197	c06e50ffeff37721d986bc6c7aa5cf6b	Mastercard	34.0924577308684533	-118.40086248842924
34900	2020-07-03 12:46:06	2020-07-03	Erwin Runte	erwin.runte@woohoo.com	San Antonio	Texas	4707506419068	030b6be6f75346556367be6ca889b8cc	Discover	29.5617063253257442	-98.5734384280931124
34901	2020-07-03 12:49:04	2020-07-03	Sharday Runolfsson PhD	sharday.runolfsson.phd@geemail.com	Eugene	Oregon	4881368342577579	1bd33396f031a5434746c0e109c3ceef	Discover	44.1251852366801316	-123.213610252504054
34902	2020-07-03 12:49:23	2020-07-03	Malorie Wintheiser	malorie.wintheiser@geemail.com	Bakersfield	California	3026584871381098	06da8cda04a5ab2ec73d71b2e2f5b9b1	JCB 15 digit	35.298655606777217	-118.97688801212162
34903	2020-07-03 12:50:55	2020-07-03	Donal Murazik	donal.murazik@geemail.com	New York	New York	4376830369332768	e4c314b21df010de6a774811a5785f2e	Mastercard	40.6910663550477452	-73.9815891325369392
34904	2020-07-03 12:52:34	2020-07-03	Renard Koepp MD	renard.koepp.md@woohoo.com	Milwaukee	Wisconsin	54321971273772313	463876d7cd839085bc3b8a05207fd781	JCB 16 digit	43.0317365710709225	-88.016952580503002
34905	2020-07-03 13:13:17	2020-07-03	Bird Crooks	bird.crooks@warmmail.com	San Francisco	California	3485682046966332	fcc84aff2493d6db13742a39e8804cd6	JCB 15 digit	37.7753749815787785	-122.467595057033861
34906	2020-07-03 13:16:05	2020-07-03	Dr. Algot Crooks	dr.algot.crooks@geemail.com	Plano	Texas	4153214828961	524a6ee755f05515acfba988c787bb28	VISA 13 digit	33.0827261333439537	-96.7959305676348549
34907	2020-07-03 13:23:07	2020-07-03	Mr. French McLaughlin III	mr.french.mclaughlin.iii@geemail.com	San Francisco	California	676211726528745	33e8af3946fa9d1fa6098e4c2d74a5d0	Mastercard	37.76720626545778	-122.410830285456285
34908	2020-07-03 13:23:35	2020-07-03	Leonidas Murphy	leonidas.murphy@geemail.com	San Francisco	California	3528263908800298115	a6a763d35d5e5825d8730cfe07264835	VISA 16 digit	37.8272420117136292	-122.40446890889821
34909	2020-07-03 13:24:36	2020-07-03	Media Stanton	media.stanton@geemail.com	Naperville	Illinois	3088644646519379798	48a221db9cbb2074ffbf9bcaf4a59bf4	Maestro	41.7171886451922376	-88.1612658263072433
34910	2020-07-03 13:26:23	2020-07-03	Mr. Cordell Roob MD	mr.cordell.roob.md@woohoo.com	New York	New York	3009182946155972	39c7d5bd050dc5a11f9d3740af668bdc	Diners Club / Carte Blanche	40.5784506148882187	-73.9595355176728191
34911	2020-07-03 13:45:12	2020-07-03	Esmeralda Carter	esmeralda.carter@geemail.com	Saint Paul	Minnesota	6011003602648699916	a9efc97d82e0aadbbfadc858b34c7533	Diners Club / Carte Blanche	44.8985919540222724	-93.1065984462652381
34912	2020-07-03 13:47:33	2020-07-03	Norris Sawayn DVM	norris.sawayn.dvm@geemail.com	Nashville	Tennessee	6011093501258962195	c211b26062b1ede9b4b13a985288af46	VISA 16 digit	36.1715364407870865	-86.8142907099239522
34913	2020-07-03 13:50:57	2020-07-03	Miss Kristal Kovacek	miss.kristal.kovacek@geemail.com	Houston	Texas	3158129479202205292	67a74b418b1cb73d3278e6146e24d7ca	VISA 16 digit	29.7678961450777955	-95.4254625021029312
34914	2020-07-03 13:52:09	2020-07-03	Katie Donnelly	katie.donnelly@geemail.com	Phoenix	Arizona	180025403014729427	9f1b3224a8c2d81f3c202a33d5a51fe5	VISA 16 digit	33.4906242215473213	-112.183660120463372
34915	2020-07-03 14:04:41	2020-07-03	Al Kuhlman-Flatley	al.kuhlman.flatley@geemail.com	New York	New York	869964907919422567	830e72df7dec67b7a2f6bda146add2d2	Voyager	40.6429813442509626	-73.9704314287647549
34916	2020-07-03 14:29:44	2020-07-03	Marcell Stehr Jr.	marcell.stehr.jr.@geemail.com	Fort Lauderdale	Florida	3038119207670746	be525f27e39490f9e62052d41d3ddc44	American Express	26.1726690704923151	-80.1800010998088766
34917	2020-07-03 14:34:13	2020-07-03	Ms. Kaylin Bartell DDS	ms.kaylin.bartell.dds@warmmail.com	Rockford	Illinois	4143326599159719	7310bbbca8ee938d1bbea04b1c4ff229	American Express	42.2804491227503902	-89.0125094285052256
34918	2020-07-03 14:34:26	2020-07-03	Elex Parker-Osinski	elex.parker.osinski@woohoo.com	Antioch	California	6011254339197656437	c382631309c0eeb454df8c4825a2ea2f	American Express	38.0589289981670689	-121.855612580588826
34919	2020-07-03 14:35:46	2020-07-03	Ursula Jaskolski	ursula.jaskolski@geemail.com	San Antonio	Texas	3761120927214967	8d466f01f6752725c03216de4fa38f3d	Diners Club / Carte Blanche	29.4047752655647692	-98.57046904720589
34920	2020-07-03 14:50:31	2020-07-03	Tayler Mills-Pollich	tayler.mills.pollich@geemail.com	Moreno Valley	California	180087382039500168	56490661be5dbe5a4cdad9c62d51acda	VISA 16 digit	33.9418395451728259	-117.192981381059425
34921	2020-07-03 14:52:33	2020-07-03	Rhiannon Gulgowski	rhiannon.gulgowski@woohoo.com	New York	New York	6011756275440318669	e35f52ba290582a4cbda90a6c08ff29c	American Express	40.7396604530736823	-73.9161491117801432
34922	2020-07-03 14:55:01	2020-07-03	Mr. Travis Klocko	mr.travis.klocko@warmmail.com	San Francisco	California	4561408948425380	8dd017fd61061e0a8ad6ad8aa0886d84	VISA 13 digit	37.8121717623446827	-122.460823307723473
34923	2020-07-03 14:56:58	2020-07-03	Susanna Wolff	susanna.wolff@geemail.com	San Francisco	California	3764939180009567	07fd0984d1726819a5e34d99c06b0ddf	American Express	37.7815039642256991	-122.407622719134892
34924	2020-07-03 14:59:46	2020-07-03	Ephriam Torp	ephriam.torp@warmmail.com	San Francisco	California	3088509479517041390	b79c58b2367bdabaedfd307293218619	VISA 16 digit	37.7226822534081379	-122.419360137045217
34925	2020-07-03 15:03:43	2020-07-03	Dr. Sharday Carroll DVM	dr.sharday.carroll.dvm@geemail.com	Edison	New Jersey	4107513169078098	a39d225141cdc146dfcf9ee8a318e4af	JCB 16 digit	40.5821946274451903	-74.294350762065136
34926	2020-07-03 15:23:29	2020-07-03	Yasmeen Leannon DVM	yasmeen.leannon.dvm@geemail.com	Fullerton	California	4361102295274846	a4569686de2a85e00657413b742cb21a	JCB 16 digit	33.8911404803551761	-118.02645148772001
34927	2020-07-03 15:31:51	2020-07-03	Devyn Thiel	devyn.thiel@geemail.com	Buffalo	New York	3762403046031051	973db3c0d438aab49c05372ff1da5857	JCB 16 digit	42.8167310537490948	-78.7715000689893969
34928	2020-07-03 15:53:07	2020-07-03	Offie Gottlieb-Cassin	offie.gottlieb.cassin@geemail.com	Clovis	California	180056141847066318	8b4f3aa0790681c4c70045fa98076890	Maestro	36.8089556677144074	-119.762675266952812
34929	2020-07-03 16:14:05	2020-07-03	Dr. Vernelle Marks	dr.vernelle.marks@geemail.com	Glendale	Arizona	3112400387721228820	00547d14a768d0aaf3415a3fc90125bf	American Express	33.488464228785034	-112.240448445247111
34930	2020-07-03 16:16:23	2020-07-03	Mrs. Jerilyn Olson	mrs.jerilyn.olson@geemail.com	San Francisco	California	3040895719868807	b83be7a6a038094e020937422a3ec770	Discover	37.8048542342181122	-122.448487616453733
34931	2020-07-03 16:30:58	2020-07-03	Montie White	montie.white@geemail.com	Coral Springs	Florida	4495054564093	ac0bf3131b994204cd1f1b3498155f33	Diners Club / Carte Blanche	26.2109082601562164	-80.3135379917576842
34932	2020-07-03 16:33:50	2020-07-03	Marlys Wiegand	marlys.wiegand@geemail.com	San Antonio	Texas	869985632270887936	61ca2d99e7ebf12eb5f6648c703f2deb	JCB 15 digit	29.5437297494687137	-98.583264845500139
34933	2020-07-03 16:41:49	2020-07-03	Dr. Esperanza Batz	dr.esperanza.batz@geemail.com	Berkeley	California	3726459870383583	7cbeb108495def5cbba8520d33fb6415	VISA 16 digit	37.8831666691920574	-122.279824124613896
34934	2020-07-03 16:43:11	2020-07-03	Miss Antionette Botsford	miss.antionette.botsford@geemail.com	San Francisco	California	180031005864117835	7167e77a7ec10b77b97fca4292234e44	Voyager	37.765833992849501	-122.470859690723486
34935	2020-07-03 16:49:37	2020-07-03	Dr. Werner Willms III	dr.werner.willms.iii@geemail.com	Hollywood	Florida	3096008402034742247	ad4a7ae81f234e10f61f6da1f681bd95	VISA 16 digit	26.0775148580726217	-80.1164608564510843
34936	2020-07-03 16:52:18	2020-07-03	Presley Berge	presley.berge@woohoo.com	Houston	Texas	4190444222875411	9efe819d2ce8fa4a1da6094b0e97cf60	JCB 16 digit	29.7658285889387138	-95.3543785880800385
34937	2020-07-03 16:53:40	2020-07-03	Dr. Anfernee Rippin Sr.	dr.anfernee.rippin.sr.@warmmail.com	Phoenix	Arizona	3021229056707742	c8e3e1b10c8b28ea9301128690f6f0b4	American Express	33.6573741477381461	-112.180320276173205
34938	2020-07-03 16:56:46	2020-07-03	Dr. Tristen Koepp V	dr.tristen.koepp.v@warmmail.com	Springfield	Massachusetts	630402244798704	2df53e72fd88e76140fe23e55ff76d83	Mastercard	42.1966145161744208	-72.4592822616081804
34939	2020-07-03 17:02:27	2020-07-03	Benji Cummings DVM	benji.cummings.dvm@geemail.com	Memphis	Tennessee	4102024854485	fbd64fa6a53959084573b53cce767ebf	JCB 15 digit	35.0185621148042401	-89.9934469013266352
34940	2020-07-03 17:03:38	2020-07-03	Eliga Tromp	eliga.tromp@geemail.com	Columbus	Ohio	6011799719100651728	3eec80ef747ebc3ff774c061037c21d5	Diners Club / Carte Blanche	39.9646737664517033	-82.9453491952039315
34941	2020-07-03 17:05:51	2020-07-03	Deion Reynolds	deion.reynolds@geemail.com	Virginia Beach	Virginia	3337423300713071473	8aba5e33d702bf2fc57c016213481b44	Discover	36.7216055737994651	-76.0748396369766482
34942	2020-07-03 17:06:38	2020-07-03	Britany Kshlerin	britany.kshlerin@geemail.com	Baltimore	Maryland	4229576966705729	ac47d711a2fb9cb3c64b1e14b170426d	VISA 16 digit	39.3691411089152083	-76.5435559100024392
34943	2020-07-03 17:24:57	2020-07-03	Tatiana Gibson-Hand	tatiana.gibson.hand@geemail.com	San Francisco	California	4472746499119276	de999b038110544cedd945973f9f245b	American Express	37.7737433234117788	-122.432362298634501
34944	2020-07-03 17:38:46	2020-07-03	Ms. Bria Hermann PhD	ms.bria.hermann.phd@woohoo.com	Scottsdale	Arizona	4753585843191239	425e55c51b51dba3b5a97d6cf2b3d010	Voyager	33.7654749465763544	-111.913818178136268
34945	2020-07-03 17:49:09	2020-07-03	Champ Durgan	champ.durgan@geemail.com	Oakland	California	3096350696693693526	1e9326ff11ceb0192ca0283c8acd3a8d	American Express	37.7856574003314876	-122.264689789866424
34946	2020-07-03 17:54:56	2020-07-03	Dr. Kaden Rau DDS	dr.kaden.rau.dds@geemail.com	San Jose	California	4354757546743	14455460afb8b6c982e003c66fd713b3	VISA 16 digit	37.3464259097639513	-121.8373372367803
34947	2020-07-03 18:12:28	2020-07-03	Dozier Yost Jr.	dozier.yost.jr.@warmmail.com	Fort Lauderdale	Florida	210097970466082052	71b8bc4841175741143fc7dd205be92d	JCB 16 digit	26.2081800810515908	-80.1116492315482276
34948	2020-07-03 18:20:11	2020-07-03	Mariann Hamill-Schulist	mariann.hamill.schulist@geemail.com	Buffalo	New York	4976540985513	891e9f47328e5e94aaaf2cd4d6dff2f6	VISA 13 digit	42.9506405666656761	-78.799165910242877
34949	2020-07-03 18:38:27	2020-07-03	Byrdie Mayer	byrdie.mayer@geemail.com	Kansas City	Missouri	3775340311642649	cd1b64739dabf875d0418e494c108c2d	Diners Club / Carte Blanche	39.1412415707319994	-94.6439043153300901
34950	2020-07-03 18:39:17	2020-07-03	Elba Kuvalis-Hartmann	elba.kuvalis.hartmann@geemail.com	Detroit	Michigan	4930747909711823	e22412704e7628ed36467c11c447c34e	Discover	42.4477695331834255	-83.0263878820117469
34951	2020-07-03 18:53:49	2020-07-03	Jordi Welch	jordi.welch@geemail.com	Moreno Valley	California	639005426442348	f7c2cff6646e4375a013494f392c8b11	JCB 16 digit	33.9004011269651357	-117.29868329995945
34952	2020-07-03 19:03:11	2020-07-03	Claud Torphy	claud.torphy@geemail.com	Newport News	Virginia	3019465675040550	f1bba68d6797e08b4651c14334f38d5d	VISA 16 digit	36.9941986311588451	-76.5434907879941164
34953	2020-07-03 19:03:16	2020-07-03	Halbert Murphy	halbert.murphy@geemail.com	Macon	Georgia	4556798692290	75e67e7ee5168da805cc1ff0807c3d5a	Maestro	32.7612828095920392	-83.6344105803135704
34954	2020-07-03 19:09:01	2020-07-03	Banks Daugherty	banks.daugherty@warmmail.com	Corpus Christi	Texas	3761267798152923	7af793c40c353db45ebd95be0189a937	VISA 16 digit	27.8219664988510331	-97.1258699813686377
34955	2020-07-03 19:21:12	2020-07-03	Tammy Renner-Jenkins	tammy.renner.jenkins@warmmail.com	Houston	Texas	4776124279873	d47f1f8c68d13ecccdda84b78d7a888d	Discover	29.7444685299959026	-95.3437048906475297
34956	2020-07-03 19:22:48	2020-07-03	Zariah Schowalter	zariah.schowalter@woohoo.com	St. Louis	Missouri	4229034401793744	6d164dab3b0db6feb35ddfed1392e11a	JCB 16 digit	38.6009859564870581	-90.2546175218656686
34957	2020-07-03 19:25:06	2020-07-03	Nan Mayer	nan.mayer@woohoo.com	Cedar Rapids	Iowa	3096470843991873419	413267370ef1cecab0b6759ed9456219	VISA 16 digit	41.9958172240368981	-91.7159896103732279
34958	2020-07-03 19:35:41	2020-07-03	Miss Cleo Hoppe	miss.cleo.hoppe@woohoo.com	Mesquite	Texas	55348971359590380	58c6644718be3906dcbe3d995dd7f8fa	VISA 16 digit	32.8065530530452776	-96.6212206686113149
34959	2020-07-03 19:37:28	2020-07-03	Hudson Champlin	hudson.champlin@geemail.com	San Antonio	Texas	869922776327982715	73c7e42ac3aa5c72ee92a80831e16d2e	JCB 15 digit	29.3823230000749227	-98.5373613397892569
34960	2020-07-03 19:44:02	2020-07-03	Bama Gusikowski	bama.gusikowski@geemail.com	Fort Wayne	Indiana	3475943625825444	2ef1dce20e4d93c217945ca3f6088093	Mastercard	41.1828237610653076	-85.1197656557649367
34961	2020-07-03 19:51:14	2020-07-03	Sonya Bergstrom-Schroeder	sonya.bergstrom.schroeder@warmmail.com	Tucson	Arizona	869965924883780317	07114dea1bf0770d1226fce2ba8baeec	VISA 13 digit	32.1089189595118185	-110.909158273296796
34962	2020-07-03 20:00:16	2020-07-03	Mrs. Tatia Sawayn	mrs.tatia.sawayn@warmmail.com	Austin	Texas	4345954453198345	ef1e7616f3ef843eaacc587f88f45789	VISA 16 digit	30.2149231694765383	-97.7279838929191271
34963	2020-07-03 20:00:34	2020-07-03	Peggie Thiel	peggie.thiel@warmmail.com	Jersey City	New Jersey	6011631380230140777	68cc9fa3ecb06527068a4584d3128e9c	Mastercard	40.7963658416584138	-73.9820680769115739
34964	2020-07-03 20:01:30	2020-07-03	Tre Marquardt	tre.marquardt@woohoo.com	Pueblo	Colorado	3443035898715722	9c7a3d163c24dc3a351a7a6783850ab2	JCB 16 digit	38.3350358461473135	-104.55320596921743
34965	2020-07-03 20:09:20	2020-07-03	Beth Goodwin DVM	beth.goodwin.dvm@woohoo.com	Philadelphia	Pennsylvania	4573065885529776	bf48de95de8c7b50482240bc5cbfe298	JCB 16 digit	40.0251549059949809	-75.1725123078461763
34966	2020-07-03 20:11:19	2020-07-03	Mammie Little	mammie.little@geemail.com	San Francisco	California	4344209680849637	6d6505bce9eb55a1c42d4f4083bc0dbc	Voyager	37.8038720217872068	-122.423860019973318
34967	2020-07-03 20:13:59	2020-07-03	Adriana Boyer	adriana.boyer@geemail.com	Akron	Ohio	4093404532627298	847555be56d0f0363a3920405df25c0e	Voyager	41.0984719075560605	-81.4510036317944497
34968	2020-07-03 20:23:23	2020-07-03	Mrs. Marley Dietrich	mrs.marley.dietrich@woohoo.com	San Francisco	California	3709183078822165	1e3088f3b5c8ca26ac76e79961143b2a	Mastercard	37.8153111064370862	-122.409994102922326
34969	2020-07-03 20:25:51	2020-07-03	Mr. Chancy Strosin	mr.chancy.strosin@warmmail.com	Fullerton	California	3053460902895997	0a13fe9fa5a8f0df29a701295baae662	Discover	33.8142889197140946	-117.96716577254422
34970	2020-07-03 20:32:51	2020-07-03	Miss Joell Cummings DDS	miss.joell.cummings.dds@warmmail.com	San Francisco	California	4682427952342996	56bace0d5d9ccbfb08093a1cdceea4ef	American Express	37.7570863429890622	-122.449518779212198
34971	2020-07-03 20:34:47	2020-07-03	Billie Casper	billie.casper@warmmail.com	New York	New York	3010826735270165	c4ac8cb7c492ec0bd1fcd5155b8f220f	Discover	40.5995944929998345	-73.8437468936096906
34972	2020-07-03 20:36:48	2020-07-03	Jakobe Wiegand	jakobe.wiegand@geemail.com	San Francisco	California	3728818642865201	b35846057fb21546e45604b7cae1ca72	VISA 16 digit	37.8114240164208582	-122.425906751468688
34973	2020-07-03 20:36:57	2020-07-03	Kenisha Crona-Greenholt	kenisha.crona.greenholt@geemail.com	Oakland	California	3053035836099443	44e94833a278f62e050355a88b789d2c	VISA 16 digit	37.790785366359863	-122.265562020444804
34974	2020-07-03 20:41:35	2020-07-03	Dr. Rochelle Greenfelder	dr.rochelle.greenfelder@geemail.com	Lafayette	Louisiana	55768847209647433	43ad8a6a791f5527517f6cd91c41e7fc	VISA 13 digit	30.2007930508792413	-92.0543674976881476
34975	2020-07-03 20:51:46	2020-07-03	Jessi Blanda-Moen	jessi.blanda.moen@geemail.com	Jersey City	New Jersey	53138617822057440	eb5c4bae734b3d741af91595d3a5ccac	Diners Club / Carte Blanche	40.7292426236379868	-73.9829041096802911
34976	2020-07-03 21:05:48	2020-07-03	Mrs. Kelsie Gerhold MD	mrs.kelsie.gerhold.md@geemail.com	Pittsburgh	Pennsylvania	4825860861111	2c7872b60326cf9b37800e6d2af80881	VISA 16 digit	40.4575842788398248	-80.0315657793249926
34977	2020-07-03 21:23:07	2020-07-03	Nada Hirthe-Stark	nada.hirthe.stark@woohoo.com	Philadelphia	Pennsylvania	3158127048240053519	9cba73fa506278fefd6278949018949c	Voyager	40.0344495886895828	-75.088823783713579
34978	2020-07-03 21:28:30	2020-07-03	Dr. Kunta Reichert	dr.kunta.reichert@warmmail.com	Los Angeles	California	3158399918292651876	fe5f013967ff2adccf47c3810752d216	VISA 13 digit	34.0844413812138143	-118.403843804634363
34979	2020-07-03 21:41:59	2020-07-03	Dakota Johnston	dakota.johnston@geemail.com	Detroit	Michigan	3474632876039315	376a70b96f247e044664eebf929c410a	JCB 16 digit	42.3082284965012221	-83.0100831461723914
34980	2020-07-03 21:56:52	2020-07-03	Mrs. Perla Von	mrs.perla.von@geemail.com	Los Angeles	California	3158590833938575107	bc522a4a11f5096084960940089e90ff	Discover	33.9348243826400449	-118.418636526958267
34981	2020-07-03 22:00:22	2020-07-03	Kylene Crist PhD	kylene.crist.phd@warmmail.com	Laredo	Texas	3444646880019128	a06cd71af6b2e764569c084a11855676	VISA 16 digit	27.5528468884244582	-99.4530816206715969
34982	2020-07-03 22:00:58	2020-07-03	Zelda Hansen	zelda.hansen@geemail.com	Columbus	Georgia	4739780657485	b0902b94fd1d3d1b0c75b6eafc9e2edc	Discover	32.4171004711694977	-84.8638563896693228
34983	2020-07-03 22:03:20	2020-07-03	Burdette Cassin	burdette.cassin@geemail.com	Los Angeles	California	502026804956345	c15d8eed670ac4606851bb94bdcafe90	Mastercard	34.1098799644835253	-118.348609552717946
34984	2020-07-03 22:13:02	2020-07-03	Miss Barbara Heller DVM	miss.barbara.heller.dvm@geemail.com	Boston	Massachusetts	4910788821796348	347d35ffcf786e2e66388b4485d66b75	Maestro	42.431774278374391	-71.0720042032606898
34985	2020-07-03 22:18:29	2020-07-03	Mikhail Doyle-Mann	mikhail.doyle.mann@geemail.com	Austin	Texas	3011439909437484	37e72bcf366805c165b2d414c44c2b30	Voyager	30.2218870265070336	-97.8157803826272527
34986	2020-07-03 22:27:48	2020-07-03	Hal Dicki-Wiza	hal.dicki.wiza@geemail.com	Stockton	California	869931026460618117	5c51692c452209f17962142d54156cbe	Maestro	37.9015590788994032	-121.373945420523356
34987	2020-07-03 22:28:50	2020-07-03	Killian Schroeder	killian.schroeder@geemail.com	New York	New York	180086189593377789	f6fd866a985c97afc096116190f17545	Diners Club / Carte Blanche	40.634453327137976	-73.9984905692178785
34988	2020-07-03 22:32:29	2020-07-03	Dr. Alois Carroll	dr.alois.carroll@warmmail.com	Amarillo	Texas	3038867032997219	7de3c5f1b1199a9c7384faed720e47af	VISA 16 digit	35.1097162379581462	-101.738009770852329
34989	2020-07-03 22:35:50	2020-07-03	Janie Boyer	janie.boyer@geemail.com	Toledo	Ohio	3528260819084460748	aaf2067494a9a240e433c9ee835636e2	JCB 16 digit	41.7390613916501394	-83.5073606624133902
34990	2020-07-03 22:41:17	2020-07-03	Chrissie Heathcote	chrissie.heathcote@woohoo.com	Greensboro	North Carolina	210003590552135268	3f4aa52d4fb834257c8309f72f924c7f	American Express	36.1713379772029811	-79.7418504555225383
34991	2020-07-03 23:06:14	2020-07-03	Waylon Will PhD	waylon.will.phd@geemail.com	Tallahassee	Florida	3096110784758686295	4956b700f33db33c98828f5f89dcf894	JCB 16 digit	30.4156994751676919	-84.1554470146555502
34992	2020-07-03 23:10:01	2020-07-03	Chase Trantow	chase.trantow@geemail.com	Philadelphia	Pennsylvania	6011391867324342855	fcca1943e94c72fbb72f409c617ea8a4	VISA 16 digit	40.0932777031283791	-75.0588975372623679
34993	2020-07-03 23:17:22	2020-07-03	Alene Huel-Bartoletti	alene.huel.bartoletti@woohoo.com	Washington	District of Columbia	210088153551059985	3fcc4a6ba7450e6a753a4877b913a048	VISA 16 digit	38.9575472629427892	-77.1083245035938916
34994	2020-07-03 23:17:25	2020-07-03	Dr. Willis Ebert	dr.willis.ebert@geemail.com	Berkeley	California	3337946407734571346	469a2114655f5ce388571d64700e600d	VISA 16 digit	37.8684120436837048	-122.251000432982934
34995	2020-07-03 23:25:58	2020-07-03	Mr. Elmo Parisian	mr.elmo.parisian@warmmail.com	San Antonio	Texas	210074733741979626	5980a5fe35cf51f3f8ce8295b5a90100	Voyager	29.4982434629999091	-98.557113541739426
34996	2020-07-03 23:32:17	2020-07-03	Mr. Elbridge Blick	mr.elbridge.blick@geemail.com	Santa Rosa	California	869901367657288181	775b1c1dc7b5fdb306615144cc9d28cd	JCB 16 digit	38.4654774262227122	-122.616465713760263
34997	2020-07-03 23:37:14	2020-07-03	Raelynn McClure	raelynn.mcclure@geemail.com	St. Petersburg	Florida	4228239289900	19cb5fcfb7bc370aa8eaf389f9edcaee	American Express	27.8043041978850951	-82.7307861898452046
34998	2020-07-03 23:40:40	2020-07-03	Eola Hilpert-Heathcote	eola.hilpert.heathcote@geemail.com	Chicago	Illinois	3158203872814262462	4e8efae7bd14e84c199fdd59ff1b3bf4	Diners Club / Carte Blanche	41.9231004985816824	-87.7395878008130836
34999	2020-07-03 23:43:28	2020-07-03	Irving Dickens	irving.dickens@warmmail.com	San Francisco	California	869917075905191865	c5b93fe9351f829d1aff8e9c757c1623	JCB 16 digit	37.774068696539139	-122.435485663737154
35000	2020-07-03 23:46:45	2020-07-03	Ogden Hintz	ogden.hintz@geemail.com	Athens	Georgia	4267074596218191	739063ff0fc3db1f06e84cf9d44d82fb	Voyager	33.9154281741198105	-83.4035919796325231
35001	2020-07-03 23:47:12	2020-07-03	Miss Joetta Kuphal	miss.joetta.kuphal@geemail.com	Louisville	Kentucky	54204848692026632	c6bc9f2fd37b727579362368167dfc3b	American Express	38.2529614318065327	-85.6836877431791351
35002	2020-07-03 23:49:08	2020-07-03	Mal Fisher	mal.fisher@geemail.com	Indianapolis	Indiana	3088139898509569977	b5f9efa92378b3d6e2a2d03697bc5979	Voyager	39.8317740228965889	-86.1924085308998826
35003	2020-07-03 23:50:04	2020-07-03	Horton Murphy	horton.murphy@geemail.com	Paterson	New Jersey	561243040944514	3780622f9d1338753bb10a08a4c21fa8	VISA 16 digit	41.0057547192975846	-74.1079845729258011
35004	2020-07-03 23:55:17	2020-07-03	Ms. Debera Welch DDS	ms.debera.welch.dds@geemail.com	Philadelphia	Pennsylvania	869944942475755840	7030237c3fafa29e0879d1cee09e6787	Discover	39.9919694463681452	-75.210071068433308
35005	2020-07-03 23:55:52	2020-07-03	Salena Armstrong	salena.armstrong@geemail.com	Omaha	Nebraska	4748332420591913	068b089b29a1bd409ccc760e3f1cb43d	Mastercard	41.2886568589281282	-96.0653243097126506
35006	2020-07-04 00:00:39	2020-07-04	Jailyn Hessel	jailyn.hessel@geemail.com	San Francisco	California	55299343372876635	88f1158270d0bf7e85b0b71d500af0e2	JCB 15 digit	37.7721569334905496	-122.435042997062581
35007	2020-07-04 00:16:11	2020-07-04	Dr. Vollie Cartwright I	dr.vollie.cartwright.i@geemail.com	San Diego	California	3158620974169588858	a68e9b7951df585e1dee778df194b33f	VISA 13 digit	32.7261335007447727	-117.215169321829464
35008	2020-07-04 00:20:05	2020-07-04	Edwina Borer	edwina.borer@woohoo.com	Austin	Texas	503875497619934	4caf974450ee4a20fa5d0f157e536185	VISA 13 digit	30.3561675676736975	-97.7016769566811689
35009	2020-07-04 00:20:29	2020-07-04	Sherri Purdy	sherri.purdy@geemail.com	Newark	New Jersey	869974093817969971	8bd05a119600d42e701cdbbbc91bf523	JCB 15 digit	40.6996521530121598	-74.103035732332998
35010	2020-07-04 00:23:58	2020-07-04	Destin Kovacek	destin.kovacek@geemail.com	Richmond	California	4554876908944	aa7b688c0b89082cc611522ed76a2b2a	Diners Club / Carte Blanche	37.8665260380089279	-122.399572924696287
35011	2020-07-04 00:31:25	2020-07-04	Williams Harber	williams.harber@geemail.com	New York	New York	676199812105981	15fd34a7f18b841362c25e0feff53965	Discover	40.6198746969681252	-73.8705004467058899
35012	2020-07-04 00:40:24	2020-07-04	Dr. Hosea Douglas	dr.hosea.douglas@geemail.com	Miramar	Florida	4982352246010	70c33d3297f3cff358223bc97cc3a949	JCB 16 digit	25.9743971737548698	-80.3938830957274888
35013	2020-07-04 00:43:09	2020-07-04	Leslie Kerluke-Veum	leslie.kerluke.veum@warmmail.com	Tallahassee	Florida	676309762596071	30fe91db257a5ae7ff80b27f4971a3d3	Diners Club / Carte Blanche	30.4563285143137001	-84.1539981816910228
35014	2020-07-04 00:43:26	2020-07-04	Eleanore Koss	eleanore.koss@geemail.com	San Francisco	California	561263240349819	ad7289d6ae544179e83894a570c4095b	Diners Club / Carte Blanche	37.763822321358127	-122.451451165337119
35015	2020-07-04 00:51:35	2020-07-04	Mrs. Deedee Steuber	mrs.deedee.steuber@geemail.com	San Francisco	California	4540633448753	f55388b83b4bfa175c459bf2e4023bae	Diners Club / Carte Blanche	37.8135723340100256	-122.413609880623781
35016	2020-07-04 01:02:06	2020-07-04	Quinten Ward	quinten.ward@geemail.com	Berkeley	California	3734666573594981	18e575ab1e0f7a3cbc9e25350f993bb5	American Express	37.8986760153287108	-122.264423087348817
35017	2020-07-04 01:04:34	2020-07-04	Summer Becker	summer.becker@geemail.com	Tucson	Arizona	54649314866520663	4f3a68791220e37f182b21662728f8d4	Voyager	32.2289489335887183	-110.860198752325402
35018	2020-07-04 01:13:28	2020-07-04	Antwan D'Amore	antwan.d'amore@geemail.com	Lexington	Kentucky	4054907433755999	c7b27c326bcc1cf2a57f8230377afb99	Diners Club / Carte Blanche	38.0926171487540017	-84.5104733938250661
35019	2020-07-04 01:19:05	2020-07-04	Glenna Wuckert-Tremblay	glenna.wuckert.tremblay@geemail.com	San Francisco	California	210098925358374743	04378d47e66d743b45a82d2596a96bce	VISA 13 digit	37.7942938856819808	-122.459102683452699
35020	2020-07-04 01:21:53	2020-07-04	Kasandra Conn	kasandra.conn@geemail.com	Oklahoma City	Oklahoma	3088993098048574852	8effc7faa67221aab3a0f9c3c6011770	VISA 13 digit	35.5206864873323624	-97.5914645918540629
35021	2020-07-04 01:37:31	2020-07-04	Meagan Stroman	meagan.stroman@geemail.com	New York	New York	53709888607484963	0b962750279a1edd587cfefea897dc40	American Express	40.5905285781007237	-73.9400238213025034
35022	2020-07-04 01:48:01	2020-07-04	Branson Koepp	branson.koepp@geemail.com	Bakersfield	California	3528232829646923526	c1e96ad576a540e65ee985e903e710b2	Voyager	35.4204651895154257	-118.933716422812267
35023	2020-07-04 01:50:30	2020-07-04	Peyton Runte	peyton.runte@woohoo.com	Spokane	Washington	4921741572470	b13bb2c50f1435f64416c599e63b7ba4	Voyager	47.6736888573277753	-117.461785799767085
35024	2020-07-04 01:51:32	2020-07-04	Deegan Towne MD	deegan.towne.md@woohoo.com	Jacksonville	Florida	3024309383580397	003c191547f987bf61d10ceaca26b23b	VISA 16 digit	30.2643313794448972	-81.6839939830903035
35025	2020-07-04 01:51:40	2020-07-04	Cathi Haley	cathi.haley@geemail.com	Honolulu	Hawaii	4897961094981510	768adfbd84c2d7a3094faa906a39c186	American Express	21.4167246969167167	-157.840947887834545
35026	2020-07-04 02:00:13	2020-07-04	Adelard Goodwin PhD	adelard.goodwin.phd@woohoo.com	Houston	Texas	180046373863261167	4b82704bf2d525b3dad43c00bf20d41c	VISA 16 digit	29.7700047054406269	-95.3404508378837221
35027	2020-07-04 02:02:12	2020-07-04	Tobie Hane	tobie.hane@geemail.com	Oakland	California	3088642873583750900	d24d6182ac5df73eeea231a7c6692392	American Express	37.819481326512097	-122.263643971629918
35028	2020-07-04 02:14:00	2020-07-04	Sherron Crooks-Stroman	sherron.crooks.stroman@geemail.com	San Francisco	California	4404631836719025	ddbae80db75d25c643b0efe59656c2ed	Discover	37.8041968297185491	-122.446137335627824
35029	2020-07-04 02:15:50	2020-07-04	Precious Hermiston	precious.hermiston@geemail.com	Bellevue	Washington	4401643449531	b6b24cf6833bf84cef79c892bb176343	JCB 15 digit	47.5129987100321856	-122.182977784337467
35030	2020-07-04 02:39:30	2020-07-04	Miss Veta Kassulke DDS	miss.veta.kassulke.dds@geemail.com	El Paso	Texas	4128424465652070	bfce7d873178406222f0e0f0b86b9f9c	Maestro	31.9443861033596122	-106.391106715098033
35031	2020-07-04 02:45:04	2020-07-04	Seneca McDermott	seneca.mcdermott@geemail.com	Pittsburgh	Pennsylvania	869976974365556468	8a618780c4ebe0aa17ae12d6e6d35d74	Discover	40.5128718612670866	-79.9052197289824591
35032	2020-07-04 02:48:08	2020-07-04	Dotty Metz	dotty.metz@woohoo.com	Greensboro	North Carolina	503810786112457	c80e8eca532dba2b5be0590de14f87e0	Maestro	36.1436791262239225	-79.9017044970747037
35033	2020-07-04 02:57:00	2020-07-04	Eloy Oberbrunner	eloy.oberbrunner@warmmail.com	Palm Bay	Florida	4627818923898	4ad031a78dd71b115b158d71cc7f2130	JCB 15 digit	28.0420363813959064	-80.7135501991793518
35034	2020-07-04 02:58:01	2020-07-04	Missy Douglas	missy.douglas@warmmail.com	New York	New York	3055167718491659	a1e0250605a8622bb7baf27e9628d38c	JCB 16 digit	40.7089252072609966	-73.9639739296294749
35035	2020-07-04 03:00:37	2020-07-04	Jarod Funk I	jarod.funk.i@woohoo.com	Irvine	California	676321047404393	13f93ee05ee7ec556119b08c6bf33a7c	American Express	33.7351743663676089	-117.747980359849706
35036	2020-07-04 03:04:21	2020-07-04	Damaris Dooley-Okuneva	damaris.dooley.okuneva@warmmail.com	San Diego	California	4730666155835	c6eca0b7188beb673d36277b76e0fd6a	Voyager	32.784729745804519	-117.127198908608406
35037	2020-07-04 03:14:20	2020-07-04	Bettie Turcotte	bettie.turcotte@warmmail.com	Berkeley	California	3041325391105830	a5080b8592a3e83d324a4f4f7ad9d6b6	Mastercard	37.895040733848262	-122.293435769925892
35038	2020-07-04 03:17:13	2020-07-04	Jayla Roob	jayla.roob@warmmail.com	San Francisco	California	869917288595626799	4c13d4d9a45c5ec8fe44977366486aa8	Diners Club / Carte Blanche	37.774576702895061	-122.434496475659287
35039	2020-07-04 03:26:42	2020-07-04	Moises Grant-Rodriguez	moises.grant.rodriguez@geemail.com	New York	New York	3049889141048493	654de4f221904ae3dfcb82e53e5b38c8	Discover	40.6651166026238329	-73.9564111667580875
35040	2020-07-04 03:34:39	2020-07-04	Hazelle Hills	hazelle.hills@geemail.com	San Francisco	California	3528601341633670717	273c2f67cf1e36ae136c57262cf2fea0	JCB 16 digit	37.7707458989821347	-122.427112657880059
35041	2020-07-04 03:37:38	2020-07-04	Barb Stark	barb.stark@warmmail.com	Austin	Texas	676335941401297	5eac1beb920123f467af717b8b7e3bc4	Diners Club / Carte Blanche	30.3501518590036774	-97.7510482210438738
35042	2020-07-04 04:03:33	2020-07-04	Mrs. Darcy Kozey	mrs.darcy.kozey@geemail.com	Phoenix	Arizona	676120575839095	2120e1afec0b0ef4f4156895190ff1ac	JCB 16 digit	33.6288043441649549	-112.013416013533629
35043	2020-07-04 04:05:56	2020-07-04	Jones Considine	jones.considine@geemail.com	Tampa	Florida	3038063400744116	faf0d8c5f041748f5d41d8f32991d921	JCB 15 digit	27.8928498209103921	-82.4886538002852348
35044	2020-07-04 04:18:03	2020-07-04	Hoyt Spencer	hoyt.spencer@geemail.com	Los Angeles	California	4456074083258	6e436c2dd19367ff1ed31f9e99ff4d6c	Discover	33.9890764082182173	-118.472897813747821
35045	2020-07-04 04:22:12	2020-07-04	Orval Donnelly	orval.donnelly@geemail.com	San Francisco	California	3337309697412472160	3b7ff6f7adc5529498606a798d2bb468	Maestro	37.7933333967706346	-122.446885089161029
35046	2020-07-04 04:28:09	2020-07-04	Griselda Hirthe	griselda.hirthe@geemail.com	St. Petersburg	Florida	869919049284659824	bd4dff5b1e854229b05ecb1b8d3ee41e	Discover	27.7675862813722354	-82.7297474941596391
35047	2020-07-04 04:44:13	2020-07-04	Rahn Ritchie	rahn.ritchie@warmmail.com	San Francisco	California	180082066180553416	237e592c76a354c8771ad166ea2f7f3a	Maestro	37.7859556227742388	-122.433898313241656
35048	2020-07-04 04:52:33	2020-07-04	Kameron Waelchi	kameron.waelchi@woohoo.com	Gainesville	Florida	869930689200904203	dcf95a8dd00cffc1243ffe5f6935ed13	JCB 16 digit	29.6864350886840356	-82.2927957657598057
35049	2020-07-04 04:54:17	2020-07-04	Tamatha Hodkiewicz PhD	tamatha.hodkiewicz.phd@geemail.com	Providence	Rhode Island	3158982373350780410	faf4aad58e43920b10feacd959b5e1de	VISA 13 digit	41.8353539646923522	-71.421539723818384
35050	2020-07-04 04:56:15	2020-07-04	Dr. Clide Pagac	dr.clide.pagac@geemail.com	Greeley	Colorado	3096630286821327809	733369f1c05ca719423d540a81169f3b	Maestro	40.3961728333096985	-104.725176237554109
35051	2020-07-04 05:02:00	2020-07-04	Mr. Bishop Abbott II	mr.bishop.abbott.ii@woohoo.com	Clinton	Michigan	6011502928408347719	56f1edf9f2250d321db63a7fb3acfed2	Maestro	42.6198732522848971	-82.9416543778572191
35052	2020-07-04 05:04:50	2020-07-04	Marsha Marvin	marsha.marvin@woohoo.com	Houston	Texas	3422871885708550	fdbf03567c86a4aaf25b9af7ef4f11f4	Mastercard	29.8255366474933936	-95.4491246430218183
35053	2020-07-04 05:10:02	2020-07-04	Dr. Commodore Weissnat	dr.commodore.weissnat@geemail.com	San Francisco	California	4897376748958311	35b3c8453ca31f81d07c45ba76b87181	Discover	37.7643295947389035	-122.440243720368628
35054	2020-07-04 05:16:35	2020-07-04	Aric Thompson	aric.thompson@geemail.com	Anaheim	California	180095461834330003	e264570078cd4788435b50d0ca42ebfd	VISA 13 digit	33.9435548314191422	-117.73577700841463
35055	2020-07-04 05:23:27	2020-07-04	Miss Beyonce Bailey DVM	miss.beyonce.bailey.dvm@geemail.com	Berkeley	California	501845881480862	732bf6e169663c97e1c70677654656ab	JCB 15 digit	37.8819374241128912	-122.272257293334434
35056	2020-07-04 05:33:41	2020-07-04	Kaylee Wisozk	kaylee.wisozk@woohoo.com	Dallas	Texas	3528663903512004865	be5a565639c47b1d8c34a4108e94783d	Maestro	32.7476730142992025	-96.6791816635951307
35057	2020-07-04 05:38:01	2020-07-04	Mr. Lennon Grady PhD	mr.lennon.grady.phd@warmmail.com	Pomona	California	180065049951496412	82ef078066e37d8461b8fb303e349096	VISA 13 digit	34.089894337816169	-117.706559484541785
35058	2020-07-04 05:53:40	2020-07-04	Abel Heidenreich	abel.heidenreich@woohoo.com	San Francisco	California	54434270776886777	032b469992c065e9dbe5f6ea235105d0	VISA 16 digit	37.7458058425835503	-122.425582891253498
35059	2020-07-04 06:05:08	2020-07-04	Shelia Buckridge	shelia.buckridge@woohoo.com	Rockford	Illinois	3112606142169266366	61a1de7a625f6dcb63b1156f2d0dc82a	JCB 15 digit	42.320040541981534	-89.1014496812880026
35060	2020-07-04 06:16:14	2020-07-04	Jaylan Fritsch	jaylan.fritsch@geemail.com	Green Bay	Wisconsin	3528957661019789439	5816b5f34581d82d80cd336a0110dfe6	American Express	44.5875376808986061	-87.9998983660999698
35061	2020-07-04 06:16:33	2020-07-04	Eller Cartwright	eller.cartwright@geemail.com	Wilmington	North Carolina	4938239165361289	2307e83146e877b24b59f132bec1f2cd	VISA 16 digit	34.2356100464992252	-77.9243753696318748
35062	2020-07-04 06:24:17	2020-07-04	Pearl Bernhard	pearl.bernhard@geemail.com	Dallas	Texas	4543365512166118	37d9488a9289930e7e8062dde68c953a	JCB 15 digit	32.7518819489788271	-96.8498963536191724
35063	2020-07-04 06:37:46	2020-07-04	Linwood Doyle	linwood.doyle@geemail.com	Greensboro	North Carolina	3112310972584350925	91f243c64a8bc8df33b4f6d70e8f5bec	Maestro	36.0274257524054491	-79.9107516760919196
35064	2020-07-04 06:44:27	2020-07-04	Miguel Reichel	miguel.reichel@warmmail.com	San Francisco	California	4400239090477	bbac6eda2fba01310db803cea1587af1	Diners Club / Carte Blanche	37.7569744591324508	-122.463902940976084
35065	2020-07-04 06:50:48	2020-07-04	Kaylen Howe	kaylen.howe@geemail.com	Garden Grove	California	501868169666721	74d678db9867af7df37472ce4cf72888	JCB 16 digit	33.7733071463938757	-118.049932219881555
35066	2020-07-04 07:10:43	2020-07-04	Katerina Mante-Robel	katerina.mante.robel@geemail.com	Los Angeles	California	869921160620646148	9d59028aebc26c2108c9c0a165530c60	Diners Club / Carte Blanche	33.9445147761009594	-118.407289232312877
35067	2020-07-04 07:17:26	2020-07-04	Veta Kunde-Kling	veta.kunde.kling@geemail.com	San Francisco	California	54058476733506318	a27ddcde0543d94d5a76b6ac62cddcf0	VISA 16 digit	37.7426448443511049	-122.437385317382152
35068	2020-07-04 07:17:54	2020-07-04	Ms. Noretta Okuneva MD	ms.noretta.okuneva.md@geemail.com	Salt Lake City	Utah	3718687076176449	9c830969b17d035267a38199514f3aa5	American Express	40.809822036061064	-112.015630039706821
35069	2020-07-04 07:26:59	2020-07-04	Mr. Leandro Borer V	mr.leandro.borer.v@geemail.com	Fresno	California	6011321875047029464	27efc059c961e62dfa73fc4559956d37	JCB 15 digit	36.8801110649820387	-119.754906965663295
35070	2020-07-04 07:31:45	2020-07-04	Elias Kovacek	elias.kovacek@geemail.com	Plano	Texas	210061288261443219	1a12d7a08c87eb5c06d121168df36af0	JCB 16 digit	33.1392470504242951	-96.8099968483854099
35071	2020-07-04 07:33:44	2020-07-04	Mrs. Felicia Wilderman	mrs.felicia.wilderman@warmmail.com	Winston–Salem	North Carolina	4930336440605	fb816a6342efa460519a3b41de6f9d2a	JCB 15 digit	36.0434825952395812	-80.3558000967502579
35072	2020-07-04 07:56:56	2020-07-04	Alejandra Goodwin-Howe	alejandra.goodwin.howe@geemail.com	San Francisco	California	4463484810221	edd55916254decc611c67fbc199cbb04	Maestro	37.7822454813649529	-122.41303158714986
35073	2020-07-04 07:57:19	2020-07-04	Dr. Leopold Kunze II	dr.leopold.kunze.ii@geemail.com	San Jose	California	4722015792321866	e17e5cc17f265a6289c3d0ab67395775	VISA 16 digit	37.3868821393519681	-121.881440663732221
35074	2020-07-04 08:03:42	2020-07-04	Winter Frami-Kozey	winter.frami.kozey@warmmail.com	Los Angeles	California	6011373168610473518	709d3bb06e614674b5250458d76ec86a	Maestro	34.1166996746189852	-118.436690919100485
35075	2020-07-04 08:07:33	2020-07-04	Cathern Simonis-Paucek	cathern.simonis.paucek@geemail.com	Mesquite	Texas	180038741814603044	5f1e12fb0fa6157ba2e4ba6c3b72818e	Discover	32.6960268841400747	-96.531674272540215
35076	2020-07-04 08:25:50	2020-07-04	Dalvin Brakus	dalvin.brakus@warmmail.com	Fremont	California	4813092711872592	bc163a4fffe4b39569b49a1423324897	Maestro	37.4567145160101376	-121.937364769725875
35077	2020-07-04 08:28:41	2020-07-04	Joseph Thiel	joseph.thiel@geemail.com	Savannah	Georgia	676103382312886	bf357ef897affc9037d3d43ac3dc77e5	Discover	31.9202918431814737	-81.0674185699470371
35078	2020-07-04 08:30:10	2020-07-04	Dejon Walter II	dejon.walter.ii@warmmail.com	Seattle	Washington	3703582843106380	6da7de591ec939e0b0b4b2139fd61cdc	JCB 15 digit	47.6576923512313542	-122.431312867432453
35079	2020-07-04 08:35:11	2020-07-04	Maximo Padberg	maximo.padberg@geemail.com	Tallahassee	Florida	3112977587311131184	d9b0ea6b9c50fbddd0f9e3298aa8cdff	JCB 15 digit	30.4865971689600528	-84.230115319277715
35080	2020-07-04 08:50:48	2020-07-04	Dabney Stiedemann	dabney.stiedemann@warmmail.com	San Jose	California	3027674600116300	876e3fdf42fb983c8bd0de42558abbf0	American Express	37.280041823983936	-121.738476848857104
35081	2020-07-04 08:53:18	2020-07-04	Tatyanna Hills	tatyanna.hills@warmmail.com	Clearwater	Florida	3112505878071756505	cdfc0a19b201b84f45e0f29c77c49a56	Mastercard	27.9596300880085664	-82.8165007792677699
35082	2020-07-04 08:56:13	2020-07-04	Kaylah Orn	kaylah.orn@warmmail.com	Salem	Oregon	4380887889430	da5ab0b36cd001d61e48fff3b1ca25e0	JCB 15 digit	44.9591311015922557	-123.072565202244377
35083	2020-07-04 08:56:32	2020-07-04	Liller Ondricka	liller.ondricka@geemail.com	Bakersfield	California	3088240204120256530	3f8732bbd77a582c283117ce25e704c9	JCB 16 digit	35.3112207632686932	-118.990145780359583
35084	2020-07-04 09:01:42	2020-07-04	Belen Cartwright	belen.cartwright@geemail.com	Topeka	Kansas	4012450835405	9ca737f466e186f971d5172a9af3326f	JCB 15 digit	39.0619109009325527	-95.663284358213474
35085	2020-07-04 09:05:31	2020-07-04	Epifanio Schaefer MD	epifanio.schaefer.md@geemail.com	Lowell	Massachusetts	4548255125955	7a62390abcfc5d266266de6d7f3c2eee	JCB 16 digit	42.6762276489157273	-71.2527632713191252
35086	2020-07-04 09:11:14	2020-07-04	Lemmie Murray	lemmie.murray@geemail.com	Las Vegas	Nevada	3158989178691786072	716b7e0a69ac2c08338e2040ad8156a8	Maestro	36.2723102842558163	-115.211349918108795
35087	2020-07-04 09:19:18	2020-07-04	Cali Reilly	cali.reilly@geemail.com	Minneapolis	Minnesota	4380085400271574	7459a4dc3539b77d6a091bdacca658bb	Diners Club / Carte Blanche	44.9600848048079698	-93.2071295516371663
35088	2020-07-04 09:21:51	2020-07-04	Dr. Bret Considine I	dr.bret.considine.i@woohoo.com	Chicago	Illinois	3158945559467536226	03299b5b93181376a7e29bcbbfa6c939	JCB 16 digit	41.9292891190223429	-87.7596261643834339
35089	2020-07-04 09:32:54	2020-07-04	Mrs. Janine Reichel	mrs.janine.reichel@geemail.com	Los Angeles	California	6011764538022958511	934cd32fbd7cfa7ad1c582ef58f7c83d	JCB 16 digit	34.0040073719207143	-118.350824944907046
35090	2020-07-04 09:36:30	2020-07-04	Buster Halvorson II	buster.halvorson.ii@geemail.com	Yonkers	New York	4281255347441	773f584feac238f624c2e85f4197d537	Voyager	40.968472764568034	-73.9239128420479688
35091	2020-07-04 09:37:35	2020-07-04	Gustave Ernser	gustave.ernser@woohoo.com	Buffalo	New York	4080377154887	478d52777d6f98c746aade8095d9784a	Maestro	42.9739355599693909	-78.9167100856479351
35092	2020-07-04 09:48:36	2020-07-04	Ms. Gia Braun DDS	ms.gia.braun.dds@geemail.com	San Francisco	California	869932371543720558	ae4536883cdda41e1968076669c1da24	VISA 13 digit	37.7920821546279058	-122.432163877463537
35093	2020-07-04 10:00:52	2020-07-04	Hardie Rippin	hardie.rippin@geemail.com	San Francisco	California	6011273793103485678	27de78e7ad0a7c2f52f3b5fa9b5e7b35	American Express	37.7754424836288436	-122.437093834634027
35094	2020-07-04 10:02:14	2020-07-04	Talia Zboncak	talia.zboncak@geemail.com	Austin	Texas	54918213447627050	8696c2b76b688c970ee4b7ab08c03cc4	Discover	30.3149172010492514	-97.6984903356764534
35095	2020-07-04 10:03:01	2020-07-04	Leora Erdman	leora.erdman@geemail.com	Jacksonville	Florida	869968992625120982	1e9c9786fe3ffcd606822c1c235faa96	American Express	30.2472011026978507	-81.7098253853231711
35096	2020-07-04 10:05:16	2020-07-04	Jalissa Wuckert	jalissa.wuckert@geemail.com	San Francisco	California	4755218961456931	0a9defb4c6bf73fb58fed3696ae207a9	VISA 16 digit	37.7610210115973004	-122.433157366678415
35097	2020-07-04 10:05:33	2020-07-04	Mr. Keegan Grady	mr.keegan.grady@geemail.com	Toledo	Ohio	3112999573138316277	5670c4be237e5ec8327d956b5ebcd4dc	Maestro	41.6593425249852203	-83.674522781312092
35098	2020-07-04 10:05:35	2020-07-04	Germaine Kub	germaine.kub@geemail.com	Philadelphia	Pennsylvania	55376452598200011	9e6278bdebfe29aff3aeb2bd7a01193e	VISA 16 digit	39.9498000638518462	-75.0582060539528726
35099	2020-07-04 10:07:11	2020-07-04	Alver Cormier	alver.cormier@warmmail.com	New York	New York	3049861816400929	282c699077e375554b3e426806e29ea8	VISA 16 digit	40.6351908704489446	-73.8837684469193192
35100	2020-07-04 10:18:15	2020-07-04	Tamie Predovic	tamie.predovic@geemail.com	New York	New York	6011718067692797154	90199c6ac61c660a0a768c62f7ef264f	VISA 16 digit	40.6316661684997342	-73.8750533637952032
35101	2020-07-04 10:20:54	2020-07-04	Mr. Dale Wintheiser V	mr.dale.wintheiser.v@geemail.com	Nashville	Tennessee	3337864960425424553	c4d876d540466528fe7973801a1dabe9	Voyager	36.2466849375639057	-86.8798265422135501
35102	2020-07-04 10:33:27	2020-07-04	Mrs. Norma West	mrs.norma.west@woohoo.com	Pittsburgh	Pennsylvania	6011800835905672342	cb26889014c6c35383a69246672b1bff	Mastercard	40.4272267037957889	-79.8783188081517892
35103	2020-07-04 10:37:45	2020-07-04	Junious Kihn-Dooley	junious.kihn.dooley@woohoo.com	Pittsburgh	Pennsylvania	210033087590888416	356ce8e678cf0426c63eb5b6fda13a80	VISA 13 digit	40.4950909076679508	-80.0444184293210554
35104	2020-07-04 10:41:43	2020-07-04	Rocco Grady	rocco.grady@warmmail.com	Clovis	California	3528988003641567888	065c716f709931b70ec2b2a1c8059299	Voyager	36.881769464012983	-119.715675937950238
35105	2020-07-04 11:02:32	2020-07-04	Harlene Ratke	harlene.ratke@geemail.com	Oxnard	California	3773615329941204	0879d86f59f82646ac3833bb197336f5	Maestro	34.2003506905354584	-119.27254450487942
35106	2020-07-04 11:04:48	2020-07-04	Tristen Botsford	tristen.botsford@geemail.com	San Francisco	California	4828576930290423	33a0ab4c0d23d8464fa1f76513fe5ecd	Maestro	37.7976802018143303	-122.481647356535689
35107	2020-07-04 11:10:46	2020-07-04	Retha Mills	retha.mills@warmmail.com	Cape Coral	Florida	4305587717128	9d55ad185b335bac9994db1bea5756c2	American Express	26.6898342595871547	-82.0808151654504172
35108	2020-07-04 11:13:21	2020-07-04	Jaycie Simonis	jaycie.simonis@geemail.com	San Francisco	California	3096217953941004334	9d23f3b24fb0c46d0c215b2a6b06dc2e	JCB 16 digit	37.7478266058234837	-122.445843812955445
35109	2020-07-04 11:20:29	2020-07-04	Tamala Jerde	tamala.jerde@warmmail.com	Jacksonville	Florida	3700129655969548	4864d867fc7e24ebe4ddc2b98ee57a00	Diners Club / Carte Blanche	30.2668922715872526	-81.731335836982737
35110	2020-07-04 11:21:21	2020-07-04	Durward Fahey	durward.fahey@geemail.com	Jacksonville	Florida	4601981361340395	5a0e5ca340937c9404d5f293dd4972ce	Maestro	30.2844262535270303	-81.5768967332862331
35111	2020-07-04 11:27:01	2020-07-04	Earnest Brakus	earnest.brakus@geemail.com	Surprise	Arizona	869993840259994462	fe25a99da0ebfef5ef8215424b3a9892	Diners Club / Carte Blanche	33.7235905374627549	-112.403703161864343
35112	2020-07-04 11:38:53	2020-07-04	Nolie Tromp-Dare	nolie.tromp.dare@geemail.com	Seattle	Washington	6011926351929072393	3a1c11372fc4b3fc6d19c7f0630fd723	Mastercard	47.6933009026031911	-122.410396096102517
35113	2020-07-04 11:48:15	2020-07-04	Shelbie Witting	shelbie.witting@warmmail.com	New York	New York	3764717929728188	d7ab2da1722d5bf11fa6ab993bca7294	VISA 13 digit	40.6172931971717617	-73.8877412690676749
35114	2020-07-04 11:49:25	2020-07-04	Mr. Jadyn Dicki	mr.jadyn.dicki@woohoo.com	Columbus	Ohio	4248689616279	6a1ce9105eface2879e7300a28768175	VISA 16 digit	39.9965550556357954	-83.0774706879399787
35115	2020-07-04 11:56:12	2020-07-04	Quint O'Kon	quint.o'kon@geemail.com	Columbus	Georgia	869971869406211815	cb3b71df1b6a03091cb14517d6952bee	VISA 16 digit	32.5383327600590846	-84.8401650739997564
35116	2020-07-04 12:04:38	2020-07-04	Claud Rohan	claud.rohan@woohoo.com	Los Angeles	California	3096001175239862963	17c4f7d178abfdda4ab062173e5509f0	VISA 16 digit	34.087688967339318	-118.477346099120751
35117	2020-07-04 12:07:21	2020-07-04	Clyde Abernathy	clyde.abernathy@geemail.com	Sacramento	California	3439936303557599	edce7ba3802802f504635646e0f5260f	Maestro	38.5933963950056622	-121.418136782084034
35118	2020-07-04 12:10:11	2020-07-04	Sherwood Bogan	sherwood.bogan@woohoo.com	Austin	Texas	503807607502221	8992a54dc7eccd231b4938ac0ba80595	Diners Club / Carte Blanche	30.266975926294549	-97.7806235145084628
35119	2020-07-04 12:26:35	2020-07-04	Daria Cole	daria.cole@warmmail.com	San Antonio	Texas	676112164656170	39d31ca8f283a635a9eaa3e7bcb2e375	VISA 16 digit	29.5646650036402043	-98.5681993453599432
35120	2020-07-04 12:27:29	2020-07-04	Mr. Morton Stamm	mr.morton.stamm@geemail.com	Berkeley	California	3018197510455021	3f10f2d1ecf4c42f2c766b210e1b8bc3	VISA 16 digit	37.8587243407976715	-122.251507658726055
35121	2020-07-04 12:35:29	2020-07-04	Collier Jerde	collier.jerde@geemail.com	Modesto	California	4949266331352865	84d25c805ecb376b923069109c53599b	JCB 16 digit	37.7060960143338946	-121.021569441139704
35122	2020-07-04 12:46:52	2020-07-04	Ms. Cameron West MD	ms.cameron.west.md@geemail.com	Aurora	Illinois	54745516598425622	38190d90777c27d5b18af672bbfc86d3	Mastercard	41.6864263282380989	-88.2033680077571347
35123	2020-07-04 12:59:35	2020-07-04	Kimberlee Jenkins DDS	kimberlee.jenkins.dds@geemail.com	New York	New York	180068107765634045	dd59fc8341431dcd3fda8f4e1f1fbe09	JCB 16 digit	40.668462678859008	-73.8943623000185852
35124	2020-07-04 13:32:07	2020-07-04	Dexter Ryan V	dexter.ryan.v@geemail.com	Sparks	Nevada	6011236244999393390	f3b127d58a35bcda62c16d3349d28001	VISA 16 digit	39.4765262384671729	-119.810596401742103
35125	2020-07-04 13:34:27	2020-07-04	Roby Oberbrunner-Smith	roby.oberbrunner.smith@woohoo.com	Fremont	California	3337465774834482158	88e705ae2330b081b9e3de8db17bb1e2	Voyager	37.4288411513604231	-122.004716266830258
35126	2020-07-04 13:35:01	2020-07-04	Elvis Cummings DVM	elvis.cummings.dvm@geemail.com	San Diego	California	4229146899344	bda5ac4bdb736fce43e947c155986ede	Discover	32.8777631459359085	-117.050702242776751
35127	2020-07-04 13:39:11	2020-07-04	Flor Will	flor.will@woohoo.com	Providence	Rhode Island	3528025563207703305	3bdce1ad50cabb8c70b2287fc4668e4c	Discover	41.7926201385300544	-71.3960705965675402
35128	2020-07-04 13:40:17	2020-07-04	Prudie Ullrich PhD	prudie.ullrich.phd@woohoo.com	San Francisco	California	210084569760968852	aa0cf1229f2f06c0a0e1d9c25213eda7	Maestro	37.758560478314358	-122.414897077193132
35129	2020-07-04 13:48:45	2020-07-04	Rossie Rogahn	rossie.rogahn@geemail.com	Knoxville	Tennessee	4007288059648828	0d8216cdce9bc8df5342a45c11714685	VISA 16 digit	36.0127259532984354	-83.9686488759454335
35130	2020-07-04 13:52:38	2020-07-04	Ms. Nakita Stoltenberg DDS	ms.nakita.stoltenberg.dds@geemail.com	Garden Grove	California	869990681855757298	55d8723fc990dd6cfde8bd585288e5df	American Express	33.7246420713897734	-117.947197880178692
35131	2020-07-04 14:05:45	2020-07-04	Brisa Bartoletti	brisa.bartoletti@geemail.com	San Francisco	California	3112328066841271303	90b23ad39030825b2794829ea7a31266	Discover	37.7489554079606791	-122.416911796731327
35132	2020-07-04 14:07:10	2020-07-04	Griffin Hegmann	griffin.hegmann@geemail.com	Portland	Oregon	869921173951385020	c6ba9c7a13d3f7aeeb53b94e43368be2	Voyager	45.4711464077588161	-122.684266621526334
35133	2020-07-04 14:51:24	2020-07-04	Trevin Christiansen I	trevin.christiansen.i@woohoo.com	Fresno	California	51344227217651367	47402bcc666c6db21ca42723a1f08fd9	Mastercard	36.8759213526606544	-119.794093528028213
35134	2020-07-04 14:58:54	2020-07-04	Payten Stiedemann	payten.stiedemann@geemail.com	San Bernardino	California	3760955850633027	23f4cace7471ad8b7ce937418d44e1b5	JCB 15 digit	34.0818917637024015	-117.260670857854564
35135	2020-07-04 15:02:09	2020-07-04	Tempie Lynch	tempie.lynch@warmmail.com	San Diego	California	3337166734495734620	edae5e95b5d397b1987a57be06f1b54d	Mastercard	32.8798890864077933	-117.035456561800103
35136	2020-07-04 15:05:34	2020-07-04	Neppie Mraz	neppie.mraz@warmmail.com	Glendale	California	3337829250325172716	7a68afd815b3fd82d178f9a6b01abd1d	Mastercard	34.1315039899419972	-118.188052398515126
35137	2020-07-04 15:12:56	2020-07-04	Angelia Paucek PhD	angelia.paucek.phd@geemail.com	San Francisco	California	4879121874685508	1576e505a231e36f48a40ca28fe8027d	JCB 15 digit	37.732275897975569	-122.425766659066724
35138	2020-07-04 15:13:54	2020-07-04	Delois Wiza DDS	delois.wiza.dds@geemail.com	San Francisco	California	3425347425061302	eef0f6a66a3f9ff5f2a391f8feb56733	Voyager	37.8203777577300144	-122.469970358151869
35139	2020-07-04 15:14:11	2020-07-04	Rocky Zboncak	rocky.zboncak@warmmail.com	Albuquerque	New Mexico	3029310810417232	995cbfe7b4c675ec1cb3102d2b359c8b	American Express	35.0786439528822953	-106.732320093417172
35140	2020-07-04 15:22:03	2020-07-04	Logan Beer PhD	logan.beer.phd@warmmail.com	Durham	North Carolina	561296022637647	becfec1f355cc6537b71221131022a02	VISA 16 digit	35.9275451068080969	-78.8760053093914024
35141	2020-07-04 15:42:12	2020-07-04	Kanisha Boyle MD	kanisha.boyle.md@geemail.com	Honolulu	Hawaii	3528829965949274602	4d7a6883dd056d65d91db867e50c0ff8	JCB 16 digit	21.2425175176218168	-157.869242977045843
35142	2020-07-04 15:42:30	2020-07-04	Mr. Donovan Botsford	mr.donovan.botsford@geemail.com	Detroit	Michigan	4953062389663557	8f146aab8a4d9196df8a5ec8f67ae922	JCB 15 digit	42.3280086751021472	-83.0140287142366162
35143	2020-07-04 15:50:15	2020-07-04	Milburn Hermiston	milburn.hermiston@geemail.com	Ann Arbor	Michigan	3088054675547100259	75f9170f1288a4b4de76f8b8f7ec9f78	JCB 16 digit	42.3256597809553128	-83.7691233424577888
35144	2020-07-04 15:58:50	2020-07-04	Myah Miller	myah.miller@geemail.com	Fort Wayne	Indiana	3112172160893513204	4a494d4ceae4db155780d35f0d9e0d8c	VISA 16 digit	41.0023211145091793	-85.0760483829990051
35145	2020-07-04 15:59:59	2020-07-04	Brenna Balistreri	brenna.balistreri@woohoo.com	South Bend	Indiana	4445323957504557	f92e0e284eb8f6bce20360c3f6df30b7	VISA 16 digit	41.6568350977409665	-86.2117034309599575
35146	2020-07-04 16:05:28	2020-07-04	Erving Lowe DVM	erving.lowe.dvm@woohoo.com	Arlington	Texas	676176712575372	41bce0d296f1ae4ba242937979a57eba	Diners Club / Carte Blanche	32.6106891763646161	-97.0805107944671164
35147	2020-07-04 16:07:46	2020-07-04	Alondra Wyman	alondra.wyman@warmmail.com	Richmond	Virginia	4008198256373360	f930922625987569643d387fa79698bd	VISA 13 digit	37.4555088007576771	-77.443510111629962
35148	2020-07-04 16:19:53	2020-07-04	Tressa Ryan	tressa.ryan@woohoo.com	New York	New York	3088674898367504307	a3a9acb8562b1445d01de096141a8803	VISA 13 digit	40.6564331701248847	-73.8858854849718512
35149	2020-07-04 16:25:28	2020-07-04	Jake Willms I	jake.willms.i@geemail.com	New York	New York	4260824213552233	d52b54f53b1ed71b600624c8959a1027	Maestro	40.6123940778188413	-74.0303908275801632
35150	2020-07-04 16:34:34	2020-07-04	Mrs. Simone Simonis DDS	mrs.simone.simonis.dds@geemail.com	San Francisco	California	3009187930196965	d725cedee0b665f14d71af93490dafa7	American Express	37.7611543386143325	-122.462741114820062
35151	2020-07-04 16:52:15	2020-07-04	Shyheim Dare	shyheim.dare@geemail.com	Berkeley	California	210015434444208312	47decb7d0bbad0474de4432b13742dc4	VISA 16 digit	37.8654647312849661	-122.255884188210004
35152	2020-07-04 16:55:48	2020-07-04	Shelly Greenholt	shelly.greenholt@geemail.com	Louisville	Kentucky	3047799084121607	52bdc160faca5f724fc4d36c6b1f30d0	JCB 16 digit	38.2481276877127598	-85.6156712536770925
35153	2020-07-04 17:19:35	2020-07-04	Werner Schamberger	werner.schamberger@geemail.com	Jacksonville	Florida	4830545158766998	05976310ba4fa35136cff805c8700c75	American Express	30.3767010844830416	-81.5633740158829852
35154	2020-07-04 17:21:54	2020-07-04	Madelyn Heidenreich DVM	madelyn.heidenreich.dvm@geemail.com	New York	New York	4962067204541598	eddda3c8272c2f0479981a8275619aac	JCB 15 digit	40.6401634919214985	-73.9363359670050357
35155	2020-07-04 17:25:58	2020-07-04	Tashina Schulist DVM	tashina.schulist.dvm@geemail.com	Richmond	California	3112451571304937000	6d730908de245a740dfa7a46ece76296	VISA 16 digit	37.9715201048601401	-122.304472006470348
35156	2020-07-04 17:29:50	2020-07-04	Karly Ruecker	karly.ruecker@geemail.com	Saint Paul	Minnesota	6011069532493830228	a38bd311a4f51b2a98c72cb58b744d01	Mastercard	45.0058303058087859	-93.036105138136449
35157	2020-07-04 17:31:45	2020-07-04	Lawanda Quigley	lawanda.quigley@geemail.com	St. Louis	Missouri	561253790592538	471e1fbe68009618f832e8b46d9062ac	VISA 13 digit	38.5431192851781859	-90.2154987752906976
35158	2020-07-04 17:36:52	2020-07-04	Susanna Johns	susanna.johns@geemail.com	Clinton	Michigan	3088596462668873575	e9f642a4c623361664d0893aa5608d26	American Express	42.6139823212355395	-82.8942045995574404
35159	2020-07-04 17:55:31	2020-07-04	Lessie Effertz-Lang	lessie.effertz.lang@geemail.com	Vallejo	California	4885349333285782	26a280819ab434ddf2db98fe40bfe60b	VISA 13 digit	38.1767804848585257	-122.175112228641282
35160	2020-07-04 18:10:55	2020-07-04	Bo Herzog	bo.herzog@geemail.com	Temecula	California	6011934473871078259	055c2cac46609c9f9a798392aaddb006	VISA 16 digit	33.4927339363045959	-117.135963590695326
35161	2020-07-04 18:11:57	2020-07-04	Mr. Rudolf Shields	mr.rudolf.shields@geemail.com	San Francisco	California	3528678214658849573	204511904ff5932c43089869e6b1dd98	Maestro	37.7503180265721525	-122.439410015380631
35162	2020-07-04 18:33:59	2020-07-04	Roel Lind	roel.lind@geemail.com	New York	New York	3337495494676933309	a47e54e7257df191dcf9d76db0ace700	VISA 16 digit	40.5890762708373387	-74.0360818151280284
35163	2020-07-04 18:34:24	2020-07-04	Ruie Wiegand DDS	ruie.wiegand.dds@warmmail.com	Huntsville	Alabama	4150001741456	52809635325861037de9c78631ffa5f7	VISA 16 digit	34.7270779148917654	-86.5846791085805734
35164	2020-07-04 18:36:49	2020-07-04	Mariyah Grant MD	mariyah.grant.md@geemail.com	Alexandria	Virginia	3013472816337248	0f2587c236788489ca55b3b5ea9a7d9d	Mastercard	38.756623759970438	-77.1723407471071994
35165	2020-07-04 18:39:17	2020-07-04	Rube Zulauf	rube.zulauf@woohoo.com	Chicago	Illinois	3021402864148728	96e9a0bfca296a3a959f26f21448b30e	Diners Club / Carte Blanche	41.7403585548814391	-87.7479041062325251
35166	2020-07-04 18:55:06	2020-07-04	Oliver Bernier	oliver.bernier@geemail.com	Los Angeles	California	3158307223753246741	341681f36efe3c58a92fb1624f8a5eeb	JCB 15 digit	34.04014408596381	-118.401284759584058
35167	2020-07-04 18:55:18	2020-07-04	Anna Tillman	anna.tillman@geemail.com	New York	New York	3792474643959899	3e4cc9d11f467de5ff0dd1971ab29dc3	Mastercard	40.5918705899026264	-73.8884788821347058
35168	2020-07-04 19:03:14	2020-07-04	Grisel Turner	grisel.turner@geemail.com	San Francisco	California	3455000864381300	69a87afe805e3eba4269ed8f212981f6	JCB 16 digit	37.7633335872075904	-122.448395279322966
35169	2020-07-04 19:03:41	2020-07-04	Brett Howell III	brett.howell.iii@geemail.com	New York	New York	4150916851029467	bbe757a7e970e607dea1249789c68470	Discover	40.6445417553409953	-73.9436020375125054
35170	2020-07-04 19:04:11	2020-07-04	Valentine Lehner-Yundt	valentine.lehner.yundt@geemail.com	Los Angeles	California	3112049064718581951	2fdca262c7ed017fd2289533add75b49	Mastercard	34.0387465366959532	-118.390636204601449
35171	2020-07-04 19:11:12	2020-07-04	Siobhan Hermiston	siobhan.hermiston@geemail.com	New York	New York	180001557695880060	4231ebb8574b2effbb6ef307126cbc9b	Voyager	40.5976799895744733	-73.9918594054773422
35172	2020-07-04 19:20:48	2020-07-04	Jessie Rowe	jessie.rowe@warmmail.com	Berkeley	California	675963340679206	688f334577d397ed42298eff48a620b5	American Express	37.8668760523019614	-122.285715421855613
35173	2020-07-04 19:24:25	2020-07-04	Alla Prohaska DVM	alla.prohaska.dvm@geemail.com	San Francisco	California	54500902741556171	1526654209b500a399da76fab3675ea3	VISA 16 digit	37.723603563513997	-122.446155015014028
35174	2020-07-04 19:25:57	2020-07-04	Dr. Amie Brown	dr.amie.brown@warmmail.com	New York	New York	4474814283104	5257d95a04de12b0101b39727c406050	JCB 15 digit	40.622774707268924	-73.9210141607455853
35175	2020-07-04 19:34:11	2020-07-04	Dr. Edd Bergnaum PhD	dr.edd.bergnaum.phd@geemail.com	Little Rock	Arkansas	51862511822935741	f819a7027be6e979ca046b0fec7e5eee	VISA 16 digit	34.7369180114284148	-92.435722276416044
35176	2020-07-04 20:00:31	2020-07-04	Warner Hilpert	warner.hilpert@warmmail.com	Madison	Wisconsin	180076529637627834	9ba8587d1f39819c179335feccecfe59	VISA 16 digit	43.1533220673885225	-89.4051971702721033
35177	2020-07-04 20:01:19	2020-07-04	Kaia Crona	kaia.crona@geemail.com	San Jose	California	4915975969323986	564227c672f06efe78a20f41b78a9ed4	American Express	37.3110152028787923	-121.893478853370624
35178	2020-07-04 20:03:01	2020-07-04	Miss Imo Macejkovic	miss.imo.macejkovic@geemail.com	Davie	Florida	501846301024280	604a91d3a65b531e5d3ad27f6df6c5f4	VISA 16 digit	26.1204256471976635	-80.2179716262407538
35179	2020-07-04 20:06:12	2020-07-04	Damian Huel	damian.huel@geemail.com	Winston–Salem	North Carolina	6011777393596805697	480e059f88afbd0ffb9a493372f85204	Diners Club / Carte Blanche	36.1227435887090849	-80.2356252083685177
35180	2020-07-04 20:44:04	2020-07-04	Conley Reilly	conley.reilly@geemail.com	Houston	Texas	210010152622985437	3b797915b533aae326fedb6d2cef03cc	Mastercard	29.8429114722725011	-95.2974546260681024
35181	2020-07-04 20:48:56	2020-07-04	Dr. Roena Little	dr.roena.little@geemail.com	Alexandria	Virginia	4364532282030065	182196c296c20e7912df51f2a544158f	JCB 16 digit	38.7235914832096526	-77.1296598737113186
35182	2020-07-04 21:15:35	2020-07-04	Calvin Pfeffer	calvin.pfeffer@geemail.com	Detroit	Michigan	4968974392390643	bc758f172dae541078963d37341a6848	JCB 16 digit	42.392854435967287	-83.1017765854604562
35183	2020-07-04 21:26:14	2020-07-04	Oneida Effertz MD	oneida.effertz.md@warmmail.com	Sunnyvale	California	502016601897131	bffe6dabb8f0ceedd11c977b82b1ab22	Maestro	37.3699185980476472	-122.11259470928573
35184	2020-07-04 21:37:44	2020-07-04	Kaylyn Lueilwitz	kaylyn.lueilwitz@geemail.com	Philadelphia	Pennsylvania	210043883473932984	5ce4684de361b30081f06e2a660b19b6	VISA 16 digit	39.9393754318315501	-75.2236863058891174
35185	2020-07-04 21:41:42	2020-07-04	Hope Kunde	hope.kunde@geemail.com	Kansas City	Missouri	869917045167852967	7b239bfbf1b92a711366e1de7b52a4dc	Discover	39.0929432451095451	-94.4731211049240045
35186	2020-07-04 21:42:15	2020-07-04	Kya Kirlin	kya.kirlin@geemail.com	Berkeley	California	3158015153320538689	30ef9b7313a0ab435083ffa3c5a653fa	JCB 15 digit	37.8429796642593814	-122.302652109269758
35187	2020-07-04 21:42:18	2020-07-04	Ceasar McGlynn	ceasar.mcglynn@geemail.com	Midland	Texas	3403146619636325	a8864ed7acb6a608d194cb2506458cc2	Diners Club / Carte Blanche	31.9787341680567714	-102.190692454412584
35188	2020-07-04 21:52:30	2020-07-04	Miss Tamie Crooks	miss.tamie.crooks@warmmail.com	Escondido	California	3791120052740921	eb51eedca3f0b86ccf04626b1e2778c4	VISA 13 digit	33.2025974820595238	-117.004215281154956
35189	2020-07-04 21:55:00	2020-07-04	Dr. Lennie Jones	dr.lennie.jones@warmmail.com	Fremont	California	6011526698038482671	9064e32c7d4acb180f4150184ef94f55	Maestro	37.5393697437066578	-121.883462041615317
35190	2020-07-04 21:59:59	2020-07-04	Jessi Lemke	jessi.lemke@geemail.com	Garland	Texas	3497604582703982	ceba7bd503cd826ca797bc789ba816c0	VISA 13 digit	32.8191363259918987	-96.6268595433022881
35191	2020-07-04 22:29:05	2020-07-04	Kennth Raynor	kennth.raynor@warmmail.com	Boston	Massachusetts	4552204117576	b47adb10ce266a917007e14627a34e3a	VISA 16 digit	42.2347187878266013	-71.0386806189499822
35192	2020-07-04 22:34:31	2020-07-04	Adyson Goyette	adyson.goyette@warmmail.com	Gresham	Oregon	4188148708505392	302b28a392bfe56badc8b63156378cfa	Maestro	45.4469455005090666	-122.388794697801018
35193	2020-07-04 22:39:00	2020-07-04	Johnna Bechtelar	johnna.bechtelar@geemail.com	Rialto	California	55661352306618971	4bd8cdbf5d5c8eba5ce7470103f2c7b0	Voyager	34.0664522207092517	-117.312786093921588
35194	2020-07-04 22:39:54	2020-07-04	Annice Lesch	annice.lesch@geemail.com	Peoria	Illinois	6011279100554732927	6bde41d82e170ac3cf0480b38ac53bcc	Maestro	40.6553573539350168	-89.5196383793257269
35195	2020-07-04 22:42:32	2020-07-04	David Ferry	david.ferry@geemail.com	Fresno	California	869972941112985898	e864a91bf004f116312f44ec976071ac	VISA 16 digit	36.8008173196449846	-119.705727294796716
35196	2020-07-04 22:44:34	2020-07-04	Halsey Zemlak	halsey.zemlak@geemail.com	Eugene	Oregon	210095799266414013	878198a19a5f702dee9638fba827fd97	Voyager	43.9835012002576136	-123.062929539567605
35197	2020-07-04 23:05:18	2020-07-04	Gilda Stoltenberg-Blanda	gilda.stoltenberg.blanda@geemail.com	Lakeland	Florida	180054626954592371	2ef08ce4c4419afaea6ab741d91cdeab	JCB 16 digit	28.1515132167208932	-81.8943458570051916
35198	2020-07-04 23:09:12	2020-07-04	Dora Rice	dora.rice@geemail.com	Phoenix	Arizona	4448555858005963	fb74b178d7c7232b8595597b433c1743	Diners Club / Carte Blanche	33.596608547440546	-112.008384901417799
35199	2020-07-04 23:11:15	2020-07-04	Trumaine Boehm	trumaine.boehm@geemail.com	Fort Worth	Texas	210063304875292500	250f7738b58e150ce1d246ed59f69d24	Diners Club / Carte Blanche	32.8693746602218582	-97.4291536218773615
35200	2020-07-04 23:11:44	2020-07-04	Hjalmer Keeling	hjalmer.keeling@geemail.com	Phoenix	Arizona	3445371281169617	477125e5955e54df8ca260d16f8b34e4	American Express	33.6094201647609481	-112.017945441596595
35201	2020-07-04 23:17:51	2020-07-04	Kaelyn Macejkovic	kaelyn.macejkovic@geemail.com	Chula Vista	California	3499162151035557	8607126eadd3e040506a319919d5a9ea	JCB 16 digit	32.6942508852340268	-117.031542732729378
35202	2020-07-04 23:37:56	2020-07-04	Austyn Williamson DVM	austyn.williamson.dvm@woohoo.com	Louisville	Kentucky	3025227702171905	636316f7d8b58317c67038fbc4602055	Mastercard	38.2242750999420835	-85.7408255094733107
35203	2020-07-04 23:42:54	2020-07-04	Mrs. Crissy Fadel DDS	mrs.crissy.fadel.dds@warmmail.com	Houston	Texas	3337068269067986364	060a70309ba8f5390574aa38e6b55c67	Diners Club / Carte Blanche	29.6943108709607273	-95.3291296388968874
35204	2020-07-04 23:48:45	2020-07-04	Wanda Hermann DDS	wanda.hermann.dds@woohoo.com	Dallas	Texas	6011590252014745361	95c4b8f76a12897f6c39b03817bb5b78	JCB 15 digit	32.721630326732253	-96.7901047705169759
35205	2020-07-04 23:49:07	2020-07-04	Mildred Lebsack	mildred.lebsack@geemail.com	Surprise	Arizona	869926232403346157	e638e408a500849da67c76d51675426e	JCB 16 digit	33.7460888655152189	-112.368585035134842
35206	2020-07-05 00:11:41	2020-07-05	Nola Brekke PhD	nola.brekke.phd@woohoo.com	Phoenix	Arizona	3337875866367959109	4991a9be3b7bdc2236274d0e8c9cecc4	JCB 16 digit	33.6099628581132777	-112.101803321756805
35207	2020-07-05 00:16:05	2020-07-05	Isom Durgan	isom.durgan@woohoo.com	Detroit	Michigan	3096456713734708636	92326e0b898a23b0197faf408bb6aabf	Diners Club / Carte Blanche	42.4653513637296882	-83.1082971636325141
35208	2020-07-05 00:17:40	2020-07-05	Oneal Leffler V	oneal.leffler.v@geemail.com	Anaheim	California	869959972035334226	50f230e900a190259059ff4d71de3cef	VISA 16 digit	33.8457945967856801	-117.830310681809109
35209	2020-07-05 00:30:59	2020-07-05	Mr. Kristen Kunze IV	mr.kristen.kunze.iv@geemail.com	San Francisco	California	180092686025709945	b124295df9c11514fc7cbcf7233c2677	Voyager	37.7884507183006946	-122.388262973660829
35210	2020-07-05 00:40:32	2020-07-05	Gustav Schultz	gustav.schultz@geemail.com	Oakland	California	3096485650359601180	06c031ed9f23096641db2a9fd3e478d4	VISA 16 digit	37.7846196131048941	-122.26040461345714
35211	2020-07-05 00:43:42	2020-07-05	Reginald Denesik	reginald.denesik@warmmail.com	Virginia Beach	Virginia	3401890339284989	2a2109453c1954f6abd7791bbb198cf3	JCB 15 digit	36.7285401390120398	-75.931313793747492
35212	2020-07-05 00:45:15	2020-07-05	Ms. Gayla Rosenbaum DVM	ms.gayla.rosenbaum.dvm@geemail.com	Berkeley	California	6011240121113652816	33c51de0508ef4b49c53977510b496b7	VISA 13 digit	37.8607916245597238	-122.253299085152193
35213	2020-07-05 00:59:01	2020-07-05	Giuseppe Schaden	giuseppe.schaden@geemail.com	San Francisco	California	3112687227734740250	b05059dd802619b136739f1dc044a4a2	American Express	37.7690809782865742	-122.434263827867696
35214	2020-07-05 01:03:15	2020-07-05	Angele Koch	angele.koch@geemail.com	San Antonio	Texas	869939589320596494	9131fea738ad8f25c26c4b3d1aad9536	VISA 16 digit	29.4789694722346951	-98.565668793565024
35215	2020-07-05 01:07:03	2020-07-05	Chaim Schroeder	chaim.schroeder@geemail.com	Topeka	Kansas	3337833032588059259	14d8710075fae34b56728126128e5579	Maestro	38.9686029371272795	-95.6350640948105593
35216	2020-07-05 01:09:07	2020-07-05	Mr. Durrell Prosacco	mr.durrell.prosacco@geemail.com	San Bernardino	California	3026145349793866	6a04277e9a687df0317bc1526381286e	Maestro	34.1253831358425259	-117.214689438721535
35217	2020-07-05 01:10:54	2020-07-05	Mr. Derald Schumm	mr.derald.schumm@geemail.com	Paterson	New Jersey	503875585934781	d668c4bb96ca1af67bc3d068364170ad	Diners Club / Carte Blanche	40.8316884094338874	-74.0950418143041531
35218	2020-07-05 01:15:10	2020-07-05	Lakeshia Schinner	lakeshia.schinner@geemail.com	Tempe	Arizona	869948189077598360	a161746070bb90699d9b0f31a0078a51	VISA 16 digit	33.296939972361173	-112.017321384002642
35219	2020-07-05 01:29:48	2020-07-05	Junie Gottlieb	junie.gottlieb@geemail.com	Berkeley	California	3706286047091755	20d90915738ed9cacfa057de3d89a565	American Express	37.8809758505929466	-122.270973984065506
35220	2020-07-05 01:31:09	2020-07-05	Everett Kutch-Cole	everett.kutch.cole@woohoo.com	Mobile	Alabama	3007241759043931	3378812efe28d1e5c35d05d4c4f2b8b3	Mastercard	30.5766694899290776	-88.0177217220559669
35221	2020-07-05 01:48:37	2020-07-05	Mr. Oswaldo Hand Sr.	mr.oswaldo.hand.sr.@geemail.com	Clovis	California	6011748435409702359	a7e76d3c56d7c207225a7424771e5fc8	Voyager	36.9082115136429678	-119.637000527379655
35222	2020-07-05 02:06:42	2020-07-05	Lemma Abernathy-Greenfelder	lemma.abernathy.greenfelder@geemail.com	Phoenix	Arizona	3417556712276437	52e7a54b975ba7b32fa1278c76074099	VISA 16 digit	33.4945241937346765	-112.001441724591331
35223	2020-07-05 02:12:26	2020-07-05	Loring Ferry	loring.ferry@geemail.com	San Francisco	California	3776003055823663	0a7f5e3145d0d5e703b8d2add07f3b4c	VISA 16 digit	37.7572888721450468	-122.42381983350127
35224	2020-07-05 02:27:18	2020-07-05	Aurora Powlowski-Ward	aurora.powlowski.ward@geemail.com	Frisco	Texas	4804052260253397	70df5ea345c29937f02e9270f1f0dd1b	Mastercard	33.2520147543396831	-96.8465265947602632
35225	2020-07-05 02:28:22	2020-07-05	Ms. Parlee Orn DVM	ms.parlee.orn.dvm@geemail.com	Austin	Texas	869999588012456857	8ab3881e8105d78ed484da2c5f9609d0	Discover	30.2811468713112149	-97.7620096152886759
35226	2020-07-05 02:38:27	2020-07-05	Austin Schinner	austin.schinner@warmmail.com	Phoenix	Arizona	3337000199919919191	38c1355f65edc0e0eed846443ed78e61	Discover	33.5596305585399293	-112.039365929544346
35227	2020-07-05 02:42:48	2020-07-05	Silver Grady DDS	silver.grady.dds@geemail.com	Nashville	Tennessee	4340320171218	4a968b008f327cc544d8d36dd6ff200d	Discover	36.1513604944694791	-86.7895522443950114
35228	2020-07-05 02:48:04	2020-07-05	Davis Gaylord	davis.gaylord@geemail.com	Seattle	Washington	4055337399509	5af657bdbed2c526aab1be69ca46ff94	Maestro	47.523543736517432	-122.353705106109004
35229	2020-07-05 02:49:32	2020-07-05	Karon Kunde-Lebsack	karon.kunde.lebsack@geemail.com	Glendale	California	4745038357658020	37f64f405674b4ba761c34c4ef1a7cee	VISA 13 digit	34.2493731647483983	-118.257256322669988
35230	2020-07-05 02:55:49	2020-07-05	Donald Runolfsdottir	donald.runolfsdottir@geemail.com	San Francisco	California	4722568110497	cfcbfb6b9c7371eadb0ac8d86217d425	JCB 16 digit	37.7739794669613858	-122.441402029870005
35231	2020-07-05 02:58:23	2020-07-05	Herb Huel	herb.huel@warmmail.com	New York	New York	4738898335779886	eba82eac1316c34f606cf3ef6066793d	American Express	40.6252893248796454	-73.9173061590071683
35232	2020-07-05 03:01:39	2020-07-05	Rayna Ebert	rayna.ebert@geemail.com	Jersey City	New Jersey	3461064033514060	348bb3b351b4836f980381a541a68e86	Discover	40.7022903999254098	-74.0476877577558241
35233	2020-07-05 03:06:11	2020-07-05	Anders Altenwerth-Turcotte	anders.altenwerth.turcotte@geemail.com	Beaumont	Texas	4840392872811927	7c9d50fc5f628ca3277d85f48641c779	VISA 13 digit	30.067246612773836	-94.1112688070882228
35234	2020-07-05 03:23:22	2020-07-05	Mr. Selmer Kemmer Jr.	mr.selmer.kemmer.jr.@woohoo.com	Lexington	Kentucky	53982115856446677	8c1a8bce8047163b1879c0428b74f8fb	VISA 16 digit	38.017441613401104	-84.4648222387202026
35235	2020-07-05 03:24:37	2020-07-05	Mr. Rohan Beahan	mr.rohan.beahan@geemail.com	Plano	Texas	6011172152507546639	e01370e335776293b86e6505f9105648	VISA 16 digit	33.0893689164046236	-96.7846134083528113
35236	2020-07-05 03:43:57	2020-07-05	Dr. Dell Hamill DDS	dr.dell.hamill.dds@geemail.com	Oakland	California	3049035072399683	b1c9d820f437f31c030e95a83cb9c7e4	JCB 16 digit	37.7951230594092422	-122.230513454880651
35237	2020-07-05 03:44:28	2020-07-05	Melodie Gulgowski-Harris	melodie.gulgowski.harris@geemail.com	Cape Coral	Florida	501894391788497	e0fffedd4ab9a178aac52a3d35a961c9	JCB 15 digit	26.5826699673168356	-82.0623344423785852
35238	2020-07-05 03:46:01	2020-07-05	Jaeden Rodriguez	jaeden.rodriguez@geemail.com	Simi Valley	California	4730752785407688	13ffe1bd37591e125de93e8a69cfcad4	JCB 16 digit	34.1691475709207353	-118.833345347609381
35239	2020-07-05 03:57:44	2020-07-05	Brittnay Emard-Hudson	brittnay.emard.hudson@geemail.com	Plano	Texas	53014331776942297	e93f2af7c3d36216e6da0a22ff757b69	JCB 16 digit	32.9881812793288418	-96.7543649745356333
35240	2020-07-05 04:09:24	2020-07-05	Karsyn Bosco	karsyn.bosco@warmmail.com	Riverside	California	210071382780218687	7bcef5da96a1122a464cae8615c07944	VISA 16 digit	33.9462140466965749	-117.420138279345622
35241	2020-07-05 04:10:11	2020-07-05	Ms. Shari Blick MD	ms.shari.blick.md@woohoo.com	St. Louis	Missouri	869940277620061776	5c67be81fddeb59902442aa56bf4d3e5	American Express	38.6315935987669974	-90.2850954945202915
35242	2020-07-05 04:25:27	2020-07-05	Bianca Waters	bianca.waters@geemail.com	Waco	Texas	4683705261611	7117f28cf154012382548bdbe205aef8	Maestro	31.4991193390659987	-97.2604403780903795
35243	2020-07-05 04:31:50	2020-07-05	Ardelia Monahan	ardelia.monahan@woohoo.com	Salinas	California	3088533702225703559	52926114438901d64effdf690ffb47fe	JCB 16 digit	36.7297242346916306	-121.665675215766584
35244	2020-07-05 04:34:55	2020-07-05	Annetta Hilpert	annetta.hilpert@geemail.com	Tampa	Florida	4258669083196510	56e502f90697f903dacb06378991016c	Diners Club / Carte Blanche	28.0267072164103368	-82.4238334462724538
35245	2020-07-05 04:48:31	2020-07-05	Hailey Kunde	hailey.kunde@geemail.com	Berkeley	California	6011650784721790907	0f4ad4795b6a0b88b60280b85cb3d5d1	Discover	37.9185731569525331	-122.287750929144948
35246	2020-07-05 04:53:56	2020-07-05	Wally Bogan-Koelpin	wally.bogan.koelpin@geemail.com	Scottsdale	Arizona	3027945240845130	58da3a522fc12a1ff6292ffc76855bf8	Mastercard	33.7589899956371653	-111.875303447476028
35247	2020-07-05 04:59:01	2020-07-05	Berlin Lehner	berlin.lehner@geemail.com	San Francisco	California	869999540134115283	d371bdf39ca73e2b9a0b0618221f9dc2	JCB 16 digit	37.7859222337648291	-122.418534878942722
35248	2020-07-05 05:01:10	2020-07-05	Dr. Patric Balistreri V	dr.patric.balistreri.v@geemail.com	Fullerton	California	3040816356772953	7918c9e0e6884e04ce95cd01aef4cd4f	Mastercard	33.9756959501810343	-117.95232153210975
35249	2020-07-05 05:02:30	2020-07-05	Francisco Herman	francisco.herman@geemail.com	New York	New York	4298989330374914	c5b57afcc57959750d3ff73cca72cc85	VISA 16 digit	40.6649462003950006	-73.9983761106979046
35250	2020-07-05 05:06:11	2020-07-05	Jarret Paucek	jarret.paucek@woohoo.com	New Haven	Connecticut	3112501276347734055	7c79aa33a4421fa88da4523e73306119	Diners Club / Carte Blanche	41.2378493692718422	-72.9800741176586598
35251	2020-07-05 05:12:45	2020-07-05	Mr. Dannie Trantow I	mr.dannie.trantow.i@geemail.com	San Antonio	Texas	4175598136869	816187790a42e3eb24a45106498611bd	JCB 16 digit	29.3799303234159943	-98.5515568757731444
35252	2020-07-05 05:33:46	2020-07-05	Sergio Haley	sergio.haley@woohoo.com	Berkeley	California	589369816682848	8fc8ae2e06d8cae444a856d8a21daca8	Mastercard	37.8737005107834008	-122.260117573947667
35253	2020-07-05 05:53:58	2020-07-05	Meadow Jenkins	meadow.jenkins@geemail.com	Long Beach	California	3786535042703720	56fdff773312b8ea19271789712b12f3	Maestro	33.8814170303575679	-118.167788102400678
35254	2020-07-05 06:07:59	2020-07-05	Abel Schroeder DDS	abel.schroeder.dds@geemail.com	Carrollton	Texas	869936616943492067	0540fe0011ff70e8064b79ebb67e9619	JCB 16 digit	32.9901065787222194	-96.8311004170544436
35255	2020-07-05 06:18:59	2020-07-05	Jasen Rodriguez V	jasen.rodriguez.v@geemail.com	Boulder	Colorado	4347725822922096	0d7d256a205e4713a6d6e85b774f343e	VISA 13 digit	39.9900566095933314	-105.247919357256592
35256	2020-07-05 06:19:46	2020-07-05	Coen Lesch III	coen.lesch.iii@geemail.com	Worcester	Massachusetts	4060290024599	237422bfa6a6613e120af7114d52c430	VISA 16 digit	42.293074727308003	-71.7771455400411043
35257	2020-07-05 06:23:39	2020-07-05	Yuliana Powlowski	yuliana.powlowski@geemail.com	Houston	Texas	4910448890939	b445d4f874864f3e263ed2c714eb9731	American Express	29.8031653862059116	-95.3646913012970288
35258	2020-07-05 06:24:51	2020-07-05	Hallie Reichert	hallie.reichert@woohoo.com	San Francisco	California	4377813874155048	aa6771414147e0bf4cdefc38b197b7b9	Discover	37.7768299214673888	-122.448865425291302
35259	2020-07-05 06:32:45	2020-07-05	Dr. Ricci Osinski PhD	dr.ricci.osinski.phd@warmmail.com	Chula Vista	California	589326459595620	389e375f81f907599db642d762c56e98	JCB 15 digit	32.7180563818894328	-116.948045600647845
35260	2020-07-05 06:36:30	2020-07-05	Joseph Towne	joseph.towne@geemail.com	Albuquerque	New Mexico	3022092124984308	d906e9f7a7aa103155a56ca67486367b	American Express	35.0312835933774736	-106.60834678388909
35261	2020-07-05 06:39:55	2020-07-05	Hollis Frami	hollis.frami@geemail.com	Wichita	Kansas	869976084470106934	0df2f191174e9dd321c9bb0b4d96d2e8	Voyager	37.7738251184921694	-97.2582977986164394
35262	2020-07-05 06:46:29	2020-07-05	Brady Schumm-Carter	brady.schumm.carter@geemail.com	Los Angeles	California	3337281864895745940	e59c1eba6ddb8d4eb83a2cf8f3e83ee2	Voyager	34.1153510460495895	-118.360141592285771
35263	2020-07-05 06:48:23	2020-07-05	Tilla Schiller	tilla.schiller@geemail.com	Stamford	Connecticut	3112959153421649425	3daa21a15a0887ced164071ad1f4bfc7	VISA 13 digit	41.1252593959566255	-73.5143750110678411
35264	2020-07-05 07:03:54	2020-07-05	Harold Strosin	harold.strosin@geemail.com	San Francisco	California	6011659219067832857	0cbc46c1f5b987a17e6badd858d4bd31	Maestro	37.7700201975067884	-122.424596515316054
35265	2020-07-05 07:12:48	2020-07-05	Kelli Auer PhD	kelli.auer.phd@geemail.com	San Francisco	California	3528528645590749748	d4c1793bdeb2bc18872aabcd27e6a9db	Discover	37.7678864198434212	-122.408210063418338
35266	2020-07-05 07:16:40	2020-07-05	Male Torphy	male.torphy@geemail.com	San Francisco	California	3707700509585178	8e0bcfa5ce501b1af4415eaccc36d5ee	Diners Club / Carte Blanche	37.797142086103392	-122.43170457127205
35267	2020-07-05 07:28:45	2020-07-05	Boyd Sawayn	boyd.sawayn@geemail.com	New York	New York	210019626401000477	1899132d645ab0436fa5a6935dbc4f91	JCB 16 digit	40.7454496969226767	-73.8477978643856972
35268	2020-07-05 07:31:14	2020-07-05	Warren Schuster	warren.schuster@geemail.com	Los Angeles	California	869969041231142086	f993065ba75804c91f99ccedd1be97f4	JCB 16 digit	33.9840171600092162	-118.419063167832036
35269	2020-07-05 07:32:06	2020-07-05	Enid Oberbrunner	enid.oberbrunner@warmmail.com	San Francisco	California	4045882394825473	1eaa63f6b6d1abef9137afb82a1f1063	VISA 16 digit	37.797270867985695	-122.430397767047594
35270	2020-07-05 07:46:35	2020-07-05	Florian Berge	florian.berge@geemail.com	Hialeah	Florida	6011823385777158015	9e96f6b891dc10828452cc26b9a8caba	VISA 16 digit	25.8676145985700217	-80.3446786628473433
35271	2020-07-05 07:51:16	2020-07-05	Moses Quitzon	moses.quitzon@geemail.com	Los Angeles	California	869955683107955285	3771f490ad3e7a52d344756e499af55a	Maestro	33.956399357677995	-118.419396890466288
35272	2020-07-05 07:54:33	2020-07-05	Shatara Bins PhD	shatara.bins.phd@geemail.com	Wilmington	North Carolina	869916203350698892	6dfd5aa81a9b3121a4b0ab3e03e49ef5	Discover	34.2142932643469422	-77.9289780186016117
35273	2020-07-05 07:55:42	2020-07-05	Jeana Kiehn-O'Conner	jeana.kiehn.o'conner@warmmail.com	Fremont	California	6011375543903409304	7bcbdc1aa946daf5c613ec3aab782541	American Express	37.542119040450082	-121.952733845728261
35274	2020-07-05 07:56:30	2020-07-05	Dillan Dickinson	dillan.dickinson@warmmail.com	Topeka	Kansas	3736782430761024	d7064ae6fcd8536dc2ff9bb60376a01f	VISA 13 digit	39.0558427854839749	-95.7089382152248191
35275	2020-07-05 07:57:20	2020-07-05	Ruthanne Hoppe	ruthanne.hoppe@geemail.com	San Francisco	California	589383923747212	af910222f034bce7bbb243ef9a6eafd3	Mastercard	37.8133795952150393	-122.462471511894208
35276	2020-07-05 08:02:41	2020-07-05	Keara Flatley	keara.flatley@geemail.com	Little Rock	Arkansas	6011341803304906881	115030984705ab01be6c1fc2da88dab2	Discover	34.6558109360091393	-92.3141855045095099
35277	2020-07-05 08:05:09	2020-07-05	Earle Pollich	earle.pollich@geemail.com	Milwaukee	Wisconsin	210023204228482551	1b3d04a97b9def105968aac9bbcd719a	JCB 16 digit	43.0563019002873446	-87.9735817251361993
35278	2020-07-05 08:06:05	2020-07-05	Lavenia Cronin	lavenia.cronin@geemail.com	Berkeley	California	180047053596409619	bab219daa79d803371a280713fc75892	JCB 16 digit	37.863454922846941	-122.284284941081708
35279	2020-07-05 08:06:50	2020-07-05	Shirlene Gaylord	shirlene.gaylord@geemail.com	Hialeah	Florida	180069550207843402	e829817ce3653baa3a8457c0e1402714	American Express	25.9584914760641752	-80.2716849715351941
35280	2020-07-05 08:13:49	2020-07-05	Dr. Regis Prosacco	dr.regis.prosacco@geemail.com	San Francisco	California	3058382623793589	b3b984271806db05d9c674a8ee1c8bd5	JCB 16 digit	37.8038291811173721	-122.42138512428734
35281	2020-07-05 08:18:17	2020-07-05	Cory O'Connell	cory.o'connell@geemail.com	Centennial	Colorado	4903136159436	25b2fe01388f893ddf9799e9a8d6f2d6	Mastercard	39.5353040906176005	-104.894246918976677
35282	2020-07-05 08:32:17	2020-07-05	Jordan Mills	jordan.mills@geemail.com	New York	New York	561257117870840	7a4c1716bb3a297ac758d8d1b7580ec5	Diners Club / Carte Blanche	40.7609558341782545	-73.9604178696300778
35283	2020-07-05 08:43:07	2020-07-05	Buddie Rowe	buddie.rowe@geemail.com	Berkeley	California	3008698183111221	af97842537793f74c7f5788570eee32a	Discover	37.855624364820045	-122.283938433534033
35284	2020-07-05 09:07:06	2020-07-05	Halsey Conn	halsey.conn@geemail.com	Buffalo	New York	3158610007297434232	b9f63bbb0def2563fc1fbce252ad02e8	JCB 16 digit	42.8483140497654631	-78.9419290848475015
35285	2020-07-05 09:10:20	2020-07-05	Denny Purdy	denny.purdy@geemail.com	Toledo	Ohio	589334907994999	650a9e370ad624a8fabd1b8f4fb2ce00	VISA 13 digit	41.676701543962956	-83.5505736618168697
35286	2020-07-05 09:14:07	2020-07-05	Mrs. Eulalia Hauck	mrs.eulalia.hauck@woohoo.com	Buffalo	New York	4646611863994	12af0caf36163f9326be4dfc1f6488c7	Mastercard	42.8026397099439038	-78.8476065242130346
35287	2020-07-05 09:15:04	2020-07-05	Denise Runte DVM	denise.runte.dvm@geemail.com	San Francisco	California	53497992004512214	9a23f0ee5cb0fc09f02c5d4dfb44efe3	JCB 16 digit	37.7857393775690795	-122.451563333823884
35288	2020-07-05 09:17:16	2020-07-05	Otha Kulas	otha.kulas@warmmail.com	New York	New York	3000794936006111	4418180dad65017a3cde8238a5a79ecc	JCB 16 digit	40.6467483372185399	-74.0236665861576739
35289	2020-07-05 09:18:08	2020-07-05	Ms. Leatha Bashirian	ms.leatha.bashirian@geemail.com	Las Vegas	Nevada	3018889486579129	acd48d72ef958a8bb7f4085e72f8fa88	JCB 15 digit	36.2709048178147526	-115.28156168914623
35290	2020-07-05 09:21:54	2020-07-05	Floy Ondricka	floy.ondricka@geemail.com	Virginia Beach	Virginia	3158616281222445746	a2de8414941a6be02dc47c8d5d153537	Maestro	36.7017504008673114	-75.9531880311805736
35291	2020-07-05 09:28:24	2020-07-05	Monique Spinka	monique.spinka@geemail.com	Jacksonville	Florida	3780574820059274	67b8691a152453d8818d9bb5ac2f4d6d	JCB 15 digit	30.3497657787572592	-81.6396046690255446
35292	2020-07-05 09:36:04	2020-07-05	Dr. Kimball Turner DVM	dr.kimball.turner.dvm@warmmail.com	New York	New York	3051390844394381	d08918be6321d1e8c019cf33a1c5cdae	Diners Club / Carte Blanche	40.7265095704458631	-73.9551280706550926
35293	2020-07-05 09:37:10	2020-07-05	Jasen Fisher-Emard	jasen.fisher.emard@geemail.com	Joliet	Illinois	4154552086805417	cd63fa1a3216497593db9eea8bc2f62d	Diners Club / Carte Blanche	41.5162576540231711	-88.0780010123375803
35294	2020-07-05 09:38:32	2020-07-05	Dr. Charla Parisian	dr.charla.parisian@geemail.com	San Francisco	California	6011610928406374961	f476bcf26cac0c1a823e203ec985f0cc	Discover	37.7811789144904679	-122.46850275785701
35295	2020-07-05 09:41:04	2020-07-05	Lyndsay Zboncak	lyndsay.zboncak@geemail.com	New York	New York	6011800948457790840	f1347db5b755cfae1a78d64903755912	Voyager	40.6051736107785217	-73.8603549451928529
35296	2020-07-05 10:07:47	2020-07-05	Otelia Bahringer	otelia.bahringer@geemail.com	Berkeley	California	53031649500128670	9283f810e9c19325a077644ae1343018	Maestro	37.8722879289002492	-122.278496357625727
35297	2020-07-05 10:16:29	2020-07-05	Mia Harvey	mia.harvey@warmmail.com	Louisville	Kentucky	4049188637211901	56267e6cfab56837637f7054ab7c3140	American Express	38.0911803042884927	-85.6626916582766995
35298	2020-07-05 10:20:10	2020-07-05	Eulah Rodriguez	eulah.rodriguez@warmmail.com	Garland	Texas	4657688500290885	024d09e960d7f96c1e224f690b62f0d7	Discover	32.9722844051897468	-96.6240642859295065
35299	2020-07-05 10:32:23	2020-07-05	Arlyn Howe	arlyn.howe@geemail.com	Houston	Texas	4150890698631142	78da8236455f08228a4bc989fbbcac33	Discover	29.7170274332243949	-95.4268569803811602
35300	2020-07-05 10:38:32	2020-07-05	Masao Will	masao.will@geemail.com	Berkeley	California	4958508458196	2694982602ed0b4b8345e95173ea2a13	VISA 16 digit	37.8815452009912264	-122.286127422487226
35301	2020-07-05 10:48:49	2020-07-05	Jayne Crist	jayne.crist@geemail.com	Chandler	Arizona	3088447040373904058	9c4b0b5e7eedc9f6aecd1fa70110e809	American Express	33.2530139839366043	-111.894842715875811
35302	2020-07-05 10:52:08	2020-07-05	Devyn Pacocha	devyn.pacocha@geemail.com	Phoenix	Arizona	210082121905815424	1bd7f49f87903cfd51d427d7518b0e13	Diners Club / Carte Blanche	33.5177127888359152	-112.003577602601055
35303	2020-07-05 10:55:26	2020-07-05	Mrs. Migdalia Goyette	mrs.migdalia.goyette@geemail.com	Olathe	Kansas	6011109139740988809	67ae34441964f8572e429620082d5a8a	VISA 13 digit	38.926729320048544	-94.8076810680963149
35304	2020-07-05 10:59:45	2020-07-05	Sincere Lindgren	sincere.lindgren@warmmail.com	New York	New York	6011725696513635390	132d85740c6022a15e22ee1e873d080a	VISA 16 digit	40.6272051999103283	-73.9134663396410616
35305	2020-07-05 11:12:57	2020-07-05	Monique Streich	monique.streich@woohoo.com	Yonkers	New York	4073671412711681	e4faa60b14430a1f082ab6db514c5314	JCB 16 digit	40.9300643994208428	-73.9372296778369673
35306	2020-07-05 11:23:10	2020-07-05	Konner Tillman-Rohan	konner.tillman.rohan@geemail.com	San Diego	California	869991015632035133	c7af9bd7c8aad6714dc4e3f4862868a2	VISA 13 digit	32.7332820351302658	-117.183630940075972
35307	2020-07-05 11:35:53	2020-07-05	Mrs. Sabina Denesik	mrs.sabina.denesik@geemail.com	Philadelphia	Pennsylvania	4642099826025187	3d2f94ec9a62344b6b4a722970297d5f	Mastercard	39.98091625305414	-75.0812823393747237
35308	2020-07-05 11:52:39	2020-07-05	Ms. Sharday Heaney DVM	ms.sharday.heaney.dvm@geemail.com	San Jose	California	3034156180494680	bf57a2f7b7b77554b685bd08a1f7055e	Discover	37.2794538768760901	-121.80137791179456
35309	2020-07-05 11:56:01	2020-07-05	Mr. Frank Ernser MD	mr.frank.ernser.md@geemail.com	Fort Worth	Texas	3497858921154600	17beb0e24684efb7a4c0dabd6315d844	Mastercard	32.7590514876004306	-97.420598504208769
35310	2020-07-05 11:56:23	2020-07-05	Olaf White	olaf.white@geemail.com	Grand Rapids	Michigan	4780288937579792	754a49856da4b5c9ce261618b6891e43	Discover	43.0247787970386426	-85.6261221562646426
35311	2020-07-05 11:56:25	2020-07-05	Loran Prohaska	loran.prohaska@warmmail.com	Austin	Texas	180000358907782413	a5ca4d7e135ee08675760a8521562f42	VISA 16 digit	30.3445241130083794	-97.7203745947923608
35312	2020-07-05 12:06:12	2020-07-05	Daija Carter	daija.carter@geemail.com	San Francisco	California	4609025715365799	1370c06c1a1ec809d53ad0514b4ca788	JCB 16 digit	37.7712490852971214	-122.450722484405091
35313	2020-07-05 12:06:20	2020-07-05	Valarie Pacocha DVM	valarie.pacocha.dvm@geemail.com	Chicago	Illinois	4726346595838	6e091274c33d45ca601bae6f150b3f48	JCB 15 digit	41.9118464004084501	-87.7079268014088171
35314	2020-07-05 12:11:36	2020-07-05	Shawn Bruen	shawn.bruen@woohoo.com	Philadelphia	Pennsylvania	630457730176484	2cfd2b132fd78cdb44b9d274a77b9ad9	JCB 15 digit	39.9859098726842532	-75.127881066444516
35315	2020-07-05 12:38:48	2020-07-05	Nolen Denesik	nolen.denesik@woohoo.com	Greensboro	North Carolina	4340347375411661	3fa07f6735d242a0edd9bb8ac7d70f12	American Express	36.0839646990526504	-79.8709763524569496
35316	2020-07-05 12:45:39	2020-07-05	Marilynn Schimmel	marilynn.schimmel@geemail.com	Charlotte	North Carolina	6011528356598684297	f6040ce0406f8d52ecc476350cfe47c4	VISA 16 digit	35.3048615045633127	-80.7796739377491235
35317	2020-07-05 12:45:42	2020-07-05	Ms. Vesta Yost DDS	ms.vesta.yost.dds@geemail.com	Tallahassee	Florida	869906488393232518	d0fe7bdc7524ce54e8e1c1164e0bd762	VISA 16 digit	30.4290086213056021	-84.1624612096246381
35318	2020-07-05 12:48:53	2020-07-05	Dr. Keenen Tromp	dr.keenen.tromp@geemail.com	Buffalo	New York	180014124236741635	5f038eea51a4db08f5e80df6fe9f1825	Discover	42.8020704963896392	-78.8030647177647836
35319	2020-07-05 12:50:10	2020-07-05	Alda Friesen	alda.friesen@woohoo.com	San Francisco	California	4377572825460143	60bdb7eeb699be7c949315f13666f04b	Discover	37.7601347679776538	-122.450461780868764
35320	2020-07-05 12:57:58	2020-07-05	Samir Schamberger V	samir.schamberger.v@geemail.com	Dallas	Texas	589380490968007	2675e90800fbd11eb813f3b933a4e2fc	JCB 15 digit	32.7827155217800339	-96.6742326988801324
35321	2020-07-05 13:02:27	2020-07-05	Britni Fay	britni.fay@geemail.com	Fullerton	California	3112056839058975644	c11f0d561a5e4f159da894384974af1d	Voyager	33.8904468737699105	-118.024527531044555
35322	2020-07-05 13:21:25	2020-07-05	Daniele Gleason	daniele.gleason@geemail.com	Kenosha	Wisconsin	6011344891258222253	04fad9436df941a09b5737c4aed49157	Voyager	42.5467676101557899	-87.9338111734710708
35323	2020-07-05 13:35:59	2020-07-05	Mack Goldner	mack.goldner@geemail.com	San Francisco	California	3007725232357256	4398e43d6e62240c608931e725f83049	Maestro	37.7433147496074639	-122.432817816403585
35324	2020-07-05 13:48:44	2020-07-05	Conrad Schimmel-Lang	conrad.schimmel.lang@geemail.com	New York	New York	3416870306935428	ebf28e704217a46314b3071c8b0a8278	Mastercard	40.6316054159067548	-73.9244263089623246
35325	2020-07-05 13:57:16	2020-07-05	Mr. Juston Rath	mr.juston.rath@geemail.com	San Francisco	California	3158828633088694516	c7042c0b73570da5ed5db0ef9d963b8e	VISA 16 digit	37.7917896001486326	-122.408970138174155
35326	2020-07-05 13:57:30	2020-07-05	Tye Kilback	tye.kilback@geemail.com	Tacoma	Washington	676370207380729	2da856847f7d335d23ab9941942f7f45	VISA 16 digit	47.3408412557680194	-122.551101252180715
35327	2020-07-05 14:01:55	2020-07-05	Mrs. Elwanda Bergnaum	mrs.elwanda.bergnaum@geemail.com	Los Angeles	California	3477380008597365	d7226ba2128bd01cb3091678d326188e	VISA 16 digit	34.0744302676390802	-118.414936651847512
35328	2020-07-05 14:33:40	2020-07-05	Johnathan Sipes	johnathan.sipes@geemail.com	Oakland	California	869941741684541311	3a36f12c2f7f7ff828d5d5d2d9666910	VISA 13 digit	37.8072777117103414	-122.256779412740229
35329	2020-07-05 14:35:36	2020-07-05	Dr. Haiden Davis Sr.	dr.haiden.davis.sr.@geemail.com	Austin	Texas	55205173836059707	2629cda6295c0fc58333a7d8fee8d277	VISA 16 digit	30.3094902152322234	-97.694326603855572
35330	2020-07-05 14:36:12	2020-07-05	Hasel Waelchi	hasel.waelchi@warmmail.com	Clovis	California	180031780291165538	4679febfdc5be21f9a4dde25eba9269f	Discover	36.8474883543204541	-119.759090905271094
35331	2020-07-05 14:38:22	2020-07-05	Abdul Powlowski	abdul.powlowski@geemail.com	New York	New York	6011300473448031357	6bd82e6a6e8d61076c0d2b72e5069ba9	Mastercard	40.7366297113932632	-74.0231818363897531
35332	2020-07-05 14:43:23	2020-07-05	Philomena Herman	philomena.herman@geemail.com	Indianapolis	Indiana	3112774720148229047	c8a7136c9cf9bab38688ab106cc22a56	Voyager	39.8737711051486414	-86.066801140803463
35333	2020-07-05 14:50:50	2020-07-05	Jo Armstrong DDS	jo.armstrong.dds@warmmail.com	Chandler	Arizona	3790134483186472	9f45a4e7d7543a0e6713ed27743c3eb3	Mastercard	33.2304672021042506	-111.890341482719037
35334	2020-07-05 15:07:36	2020-07-05	Tilla Nader	tilla.nader@woohoo.com	Rancho Cucamonga	California	4585570293290	aeeecc42e9a471f8eafc3b7636e85d05	American Express	34.090728578762338	-117.629066438508033
35335	2020-07-05 15:11:31	2020-07-05	Dayle Raynor	dayle.raynor@geemail.com	Berkeley	California	869952759406691236	23d9850cf04ac0b07bf2647cd24b77f6	VISA 16 digit	37.8581362770376231	-122.272948894735976
35336	2020-07-05 15:20:33	2020-07-05	Ples Senger	ples.senger@geemail.com	Philadelphia	Pennsylvania	4012298704012174	091b8fe6e61134b24f0246e12e4363c3	VISA 13 digit	39.9625587869394536	-75.0978633621607088
35337	2020-07-05 15:20:57	2020-07-05	Canyon Lockman	canyon.lockman@geemail.com	Fremont	California	3088523868840693459	e65533f06c068d09b7a786d872353379	American Express	37.4249994340520402	-121.969840829259525
35338	2020-07-05 15:21:14	2020-07-05	Rafael Crona	rafael.crona@geemail.com	Wichita	Kansas	3158897772299747121	54566663c4013a1de10355283b1a3b3c	Discover	37.6468583278700706	-97.418851867338276
35339	2020-07-05 15:24:09	2020-07-05	Wayman Boehm	wayman.boehm@geemail.com	Indianapolis	Indiana	6011435482093904766	1b7870af94741ae0d65bfd42a51d4bce	American Express	39.8224584323361483	-86.0646408125959255
35340	2020-07-05 15:35:24	2020-07-05	Rosemary Rath	rosemary.rath@geemail.com	New York	New York	4515225563964270	4ed74cf386c824e76647e24d25fff046	JCB 16 digit	40.748447040770202	-73.9038629872620021
35341	2020-07-05 15:38:31	2020-07-05	Stanton Price	stanton.price@geemail.com	Norman	Oklahoma	4234130991186845	ad9af3ec972480693db2db68195ebfcf	JCB 16 digit	35.157298155552148	-97.3853813926942564
35342	2020-07-05 15:50:04	2020-07-05	Deonta Leffler-Conn	deonta.leffler.conn@geemail.com	Philadelphia	Pennsylvania	4184763485457	46cc5fe22b1cfafabe4554409aa1e673	VISA 16 digit	39.9314468986313784	-75.2229914927754635
35343	2020-07-05 16:00:48	2020-07-05	Thorwald Bergnaum	thorwald.bergnaum@geemail.com	Chesapeake	Virginia	639069472846158	fbbd2cf21376f1c615546fa6dae681f0	Voyager	36.743352699396759	-76.2264105213183853
35344	2020-07-05 16:03:50	2020-07-05	Verona Oberbrunner	verona.oberbrunner@warmmail.com	Los Angeles	California	3088512122554519770	c8474494905472071609c58b0a475fc1	VISA 13 digit	33.9609148278232666	-118.425690201296646
35345	2020-07-05 16:04:15	2020-07-05	Sean Ankunding	sean.ankunding@warmmail.com	Denver	Colorado	55482346593039526	59105055e6e88e803d5760d178f4d495	Mastercard	39.6635404076013671	-104.96659497569911
35346	2020-07-05 16:15:29	2020-07-05	Areli Luettgen DVM	areli.luettgen.dvm@geemail.com	Lakewood	Colorado	4602170726304	95fdeeba8d2b793ef7590058d22fbff4	Maestro	39.6007156974576446	-105.131519564429667
35347	2020-07-05 16:29:31	2020-07-05	Phoenix Rolfson	phoenix.rolfson@geemail.com	Alexandria	Virginia	6011920848511841073	b2a9b2bcd8c62a86486487c44049eccf	JCB 16 digit	38.7671284083392464	-77.0348390004117078
35348	2020-07-05 16:34:43	2020-07-05	Willia Heidenreich	willia.heidenreich@geemail.com	Columbus	Georgia	4478853056248	f7fb2550b9090b9c6582ea8d4d5567bc	Mastercard	32.5738435580439827	-84.9717944516964252
35349	2020-07-05 16:49:40	2020-07-05	Wilfredo Lockman DDS	wilfredo.lockman.dds@geemail.com	Austin	Texas	4443017946650	a2b41c5015732d903bc9b8e4c6c96b8f	JCB 16 digit	30.3144115395039293	-97.7835679582558583
35350	2020-07-05 16:57:00	2020-07-05	Banks O'Kon	banks.o'kon@geemail.com	San Francisco	California	4845970297477	fc9ec7a2bb9563da900ea2b03495ee2a	JCB 15 digit	37.7581898922482395	-122.412715943646802
35351	2020-07-05 17:18:15	2020-07-05	Markel Hodkiewicz	markel.hodkiewicz@woohoo.com	Syracuse	New York	869933062412839269	c3f6aa7c7f46a5fc8355095b03f10009	VISA 16 digit	42.9466734283454699	-76.2407964953001596
35352	2020-07-05 17:24:15	2020-07-05	Hall Hackett	hall.hackett@geemail.com	New York	New York	210057195504208125	bff830fd455ccb4651657919c206ec30	Discover	40.7050470854379256	-73.945277132502568
35353	2020-07-05 17:28:01	2020-07-05	Shad Mueller	shad.mueller@geemail.com	West Palm Beach	Florida	502051048367885	51d5cef037940da6a955b8b55127f600	VISA 16 digit	26.7744085845384774	-80.1168637207545373
35354	2020-07-05 17:28:28	2020-07-05	Alexandria Schoen DDS	alexandria.schoen.dds@geemail.com	Los Angeles	California	3112801906038530373	55f5b903ceb91ac35706a3ff5baa890a	Mastercard	33.9440903918683503	-118.453239548531542
35355	2020-07-05 17:52:24	2020-07-05	Murl Windler	murl.windler@geemail.com	Phoenix	Arizona	4269518938973846	d2163897dd12c091de7a1a02e9577294	Diners Club / Carte Blanche	33.6630566056285048	-112.021504940783984
35356	2020-07-05 17:54:07	2020-07-05	Vicy Beatty-Dibbert	vicy.beatty.dibbert@geemail.com	Sacramento	California	4401474846068882	46bf7490455f341a861a2c47e7dabedf	Diners Club / Carte Blanche	38.6303274218723161	-121.434306554008643
35357	2020-07-05 17:56:48	2020-07-05	Adella Upton-Cruickshank	adella.upton.cruickshank@geemail.com	Fayetteville	North Carolina	6011298405361531041	78afc9718e456e349601d6c7008636b4	Discover	35.1204856628339712	-78.9753793489318383
35358	2020-07-05 18:01:46	2020-07-05	Jonnie Mann	jonnie.mann@geemail.com	Garland	Texas	6011836444470624156	bfdeb878273a6b9a46ae38fb4e7309b3	VISA 13 digit	32.8224076071523072	-96.6633215248745046
35359	2020-07-05 18:34:15	2020-07-05	Dr. Sidney Pollich	dr.sidney.pollich@geemail.com	Boston	Massachusetts	210001533089580251	b61399f534e09ded90fc73880a31395b	JCB 15 digit	42.2987913584969917	-70.9596827869255122
35360	2020-07-05 18:41:24	2020-07-05	Ms. Patti Robel DVM	ms.patti.robel.dvm@geemail.com	Las Cruces	New Mexico	3112614183473784264	47ce279f41e1b08ac65d9647ace0224e	Maestro	32.3439079807639089	-106.728246946924173
35361	2020-07-05 18:42:00	2020-07-05	Harper Anderson	harper.anderson@geemail.com	Scottsdale	Arizona	869991184107821805	62adc6dacf1afd4e96164c3283a89e01	JCB 16 digit	33.765281735512616	-111.946599778250231
35362	2020-07-05 18:44:14	2020-07-05	Francisca Dibbert PhD	francisca.dibbert.phd@geemail.com	Columbus	Ohio	4061824509231048	9c6ead5d2e43634c627e7d922bf1db34	American Express	40.0679969127800319	-82.9323571681279788
35363	2020-07-05 18:55:59	2020-07-05	Spurgeon Schultz-Jacobson	spurgeon.schultz.jacobson@geemail.com	Las Vegas	Nevada	4976627511970782	49e5d43d498f6815225e09ef345fe23c	VISA 16 digit	36.2017457955617417	-115.334236159662154
35364	2020-07-05 19:00:32	2020-07-05	Daisha Balistreri	daisha.balistreri@warmmail.com	Washington	District of Columbia	51962809142907237	745f7887f9fc19725e2335ad3a68067d	Diners Club / Carte Blanche	38.8203123450078067	-77.0095568253871079
35365	2020-07-05 19:00:57	2020-07-05	Asher Pagac	asher.pagac@geemail.com	New York	New York	4111468029215	9a43cd52e947f6facc92277979fe1862	American Express	40.6703760906811809	-73.9007264949276959
35366	2020-07-05 19:16:11	2020-07-05	Burley Orn	burley.orn@geemail.com	San Diego	California	3112089947483775934	4f8434bfe22b8aeb62e741c17575d60e	Diners Club / Carte Blanche	32.7553858742184971	-117.063549268003555
35367	2020-07-05 19:26:25	2020-07-05	Lorne Kris DDS	lorne.kris.dds@geemail.com	New York	New York	180037451291930867	90e575d8a0d0b3a12852a0873652c8c4	Discover	40.6674266482461206	-73.9253763345431452
35368	2020-07-05 19:26:55	2020-07-05	Neal Lueilwitz	neal.lueilwitz@geemail.com	Rochester	Minnesota	3096306574589821821	266a604f068dd177a8e7a249149dda1c	Discover	43.99079608627558	-92.5248295708212964
35369	2020-07-05 19:29:59	2020-07-05	Kiarra Bernier	kiarra.bernier@geemail.com	Augusta	Georgia	630424266859511	dce13d496ee66a48f9a2deff3fb42aae	Mastercard	33.4249426815398039	-82.1389068257823709
35370	2020-07-05 19:31:33	2020-07-05	Dr. Adrienne Lowe	dr.adrienne.lowe@geemail.com	Tyler	Texas	639097411649854	2ddfc44de596357482f9f9bec13eb9bb	Maestro	32.2207434162545994	-95.3048025945309547
35371	2020-07-05 19:33:18	2020-07-05	Mrs. Annette Sawayn MD	mrs.annette.sawayn.md@geemail.com	Chicago	Illinois	52868181207062943	776fa8ece5845f0dc198c15c3b15c434	Discover	41.7623936627827632	-87.7245121236920369
35372	2020-07-05 19:41:56	2020-07-05	Yurem Macejkovic	yurem.macejkovic@woohoo.com	Olathe	Kansas	3009729415534226	f183c6c6e4b78f083a22d8fe442fe28f	Maestro	38.9597485302139077	-94.8818417428228997
35373	2020-07-05 19:48:20	2020-07-05	Teagan Moen	teagan.moen@geemail.com	San Antonio	Texas	180038857979669461	50ad517a2664af81622c760845644caa	Discover	29.5695368322148937	-98.5492289768368011
35374	2020-07-05 19:49:11	2020-07-05	Cayden Doyle-Ritchie	cayden.doyle.ritchie@woohoo.com	Philadelphia	Pennsylvania	4836068947206	dbaa5237a0cb76643bb3f013f91f8900	VISA 16 digit	39.9812807460274513	-75.1202710575789325
35375	2020-07-05 19:56:52	2020-07-05	Corwin Botsford	corwin.botsford@geemail.com	Los Angeles	California	4185268376943775	4dfa0f0f1276f95e73950564f6520222	VISA 13 digit	33.955951550868896	-118.383205798733229
35376	2020-07-05 20:01:45	2020-07-05	Mr. Shellie Funk II	mr.shellie.funk.ii@warmmail.com	Jackson	Mississippi	4613005232334233	a4ea4c05df9b78785d4c0b24943dc942	Maestro	32.4139964121107056	-90.1574584807708845
35377	2020-07-05 20:06:44	2020-07-05	Dove Stracke	dove.stracke@geemail.com	New York	New York	3088613471750026678	79ca3792d6ca5fb804685d93872fbf7c	American Express	40.6783576192557774	-74.0300466275203917
35378	2020-07-05 20:14:11	2020-07-05	Jeane Gislason	jeane.gislason@woohoo.com	Boston	Massachusetts	589358736761857	bc8c8243184abb4ba51505c2bcd0cf51	VISA 13 digit	42.4202566887885339	-71.0692450008306622
35379	2020-07-05 20:23:05	2020-07-05	Zavion Schumm DDS	zavion.schumm.dds@woohoo.com	Albuquerque	New Mexico	3112281711995307107	21d480d83cce80a324e52639c76e6a70	JCB 16 digit	35.1857612151321035	-106.649670684624098
35380	2020-07-05 20:30:07	2020-07-05	Monnie Daniel	monnie.daniel@geemail.com	Columbus	Ohio	4957522899743377	82762d3467c8c19860c04175d4059c91	Voyager	40.0786936843346808	-83.0331516004402204
35381	2020-07-05 20:42:05	2020-07-05	Alonzo Eichmann	alonzo.eichmann@geemail.com	Tuscaloosa	Alabama	3420358678262427	3493964f7ba2b7993abf87bb2c9a5eb1	Mastercard	33.1889893666896967	-87.5909434905838253
35382	2020-07-05 20:46:35	2020-07-05	Stanton Koch Jr.	stanton.koch.jr.@warmmail.com	Augusta	Georgia	4561594675592748	36f32135375dc112db319994cd52707b	VISA 16 digit	33.3259959009215194	-82.1061442171517797
35383	2020-07-05 20:55:35	2020-07-05	Ms. Alycia Denesik	ms.alycia.denesik@geemail.com	Denver	Colorado	3112964766121176580	867b5f67f22cc0222c07b42cfdfc283f	VISA 16 digit	39.8145579126715603	-104.874781834358728
35384	2020-07-05 21:06:10	2020-07-05	Marcelina Swift	marcelina.swift@warmmail.com	Phoenix	Arizona	52338162554561556	4dc1fcf23ff3ae0ca4cdbccf8e2e8a41	JCB 16 digit	33.5032940757859521	-112.011163424181206
35385	2020-07-05 21:10:40	2020-07-05	Miss Isabela Hoppe DDS	miss.isabela.hoppe.dds@warmmail.com	Honolulu	Hawaii	6011529268655473960	b3464f00861d76c4ebc3725df2ee213b	JCB 15 digit	21.2874272432394349	-157.933232470995193
35386	2020-07-05 21:12:32	2020-07-05	Dr. Everet Grant	dr.everet.grant@geemail.com	Kansas City	Kansas	4960247898346684	cbb99e119e5b3a637a1eea15e4d3212f	VISA 13 digit	39.104852724997329	-94.646257864584399
35387	2020-07-05 21:15:50	2020-07-05	Cas Schmidt	cas.schmidt@geemail.com	Dallas	Texas	3112296050049946369	8d91246848b1fb7827ab995953de6999	Mastercard	32.7684200076658314	-96.6885548124983814
35388	2020-07-05 21:21:10	2020-07-05	Jerad Bruen	jerad.bruen@geemail.com	Phoenix	Arizona	676385703497454	52ac733e22147040a758471942d6462a	Maestro	33.5848885091420257	-112.060778871218119
35389	2020-07-05 21:22:17	2020-07-05	Miss Antonetta Morar	miss.antonetta.morar@geemail.com	Houston	Texas	210011627263701424	ff69f9d2766ac284c90419da548633fc	VISA 16 digit	29.8296463779252008	-95.3900384973749595
35390	2020-07-05 21:35:07	2020-07-05	Isom Block I	isom.block.i@geemail.com	Savannah	Georgia	869954105602379481	5c69adb2f76d48918f35638c054f2d8f	VISA 13 digit	31.9028340013790839	-81.179701129315788
35391	2020-07-05 21:40:56	2020-07-05	Arthor Leuschke	arthor.leuschke@geemail.com	San Francisco	California	4740003805711	f61b765dc565360ea2fc24e06e05ce56	Voyager	37.7438950024770534	-122.455929214459047
35392	2020-07-05 21:47:07	2020-07-05	Samual Bradtke	samual.bradtke@warmmail.com	Louisville	Kentucky	4437783287913200	87d70aaf590adbe21f42f40b8e90cce3	American Express	38.2496130344361021	-85.6158978348203021
35393	2020-07-05 21:57:15	2020-07-05	Mr. Omari Weissnat I	mr.omari.weissnat.i@geemail.com	Austin	Texas	869992908282435000	9d52c83300235794888b62ad83dc92ee	Diners Club / Carte Blanche	30.3052621737714851	-97.6618732718523574
35394	2020-07-05 22:05:24	2020-07-05	Odie Graham	odie.graham@geemail.com	Columbia	South Carolina	210043010664909817	83d2ca48ba94ae851f4a6ff2b0e839ac	JCB 15 digit	33.9903403375562263	-80.8776877074986658
35395	2020-07-05 22:05:57	2020-07-05	Burnice Cummings	burnice.cummings@geemail.com	Oakland	California	3468727607330450	1bb85f127692d8ab1ec2561ebd97a771	VISA 16 digit	37.8243784595182362	-122.242810443078099
35396	2020-07-05 22:09:30	2020-07-05	Mr. Gray White MD	mr.gray.white.md@geemail.com	Green Bay	Wisconsin	4073788738069287	62235a537a2095b941e30d3741607c7e	Voyager	44.5867006793215879	-87.9460696734774814
35397	2020-07-05 22:20:05	2020-07-05	Roslyn Stark	roslyn.stark@geemail.com	San Francisco	California	180071640746102521	93232153c772bedf7224ea065a919f51	American Express	37.7427554697551813	-122.410286132429619
35398	2020-07-05 22:32:46	2020-07-05	Somer Schmeler	somer.schmeler@geemail.com	Plano	Texas	3528057892346198759	827832df60d2e3d474d4f2589401044a	Diners Club / Carte Blanche	33.0664591737642937	-96.727481413697447
35399	2020-07-05 22:52:40	2020-07-05	Lish Cassin	lish.cassin@woohoo.com	Los Angeles	California	4645589227724666	ab1287ec328ddcb25a3f361f447e8c15	Diners Club / Carte Blanche	34.0219068992283198	-118.426932798464961
35400	2020-07-05 22:58:04	2020-07-05	Rose Emard-Botsford	rose.emard.botsford@geemail.com	Mesa	Arizona	3050554801678182	c98f21447bf31463a0e554bcd1abc9ca	JCB 16 digit	33.399722700301183	-111.776740121643613
35401	2020-07-05 23:04:09	2020-07-05	Kira Feeney-Cremin	kira.feeney.cremin@geemail.com	New York	New York	180091860113377193	80e35166b7145f4ed6d2d061e5291447	American Express	40.6135971079338347	-73.8704053842823924
35402	2020-07-05 23:36:20	2020-07-05	Veda Weissnat	veda.weissnat@geemail.com	Philadelphia	Pennsylvania	4787397238844293	5e784ac47d41021fc12c1ec8e0105502	VISA 16 digit	39.9119099230930203	-75.0561103138972072
35403	2020-07-05 23:47:12	2020-07-05	Dr. Brooks Howell	dr.brooks.howell@geemail.com	Berkeley	California	4802939312459	f6fe3d6dfcf4b793f58ff881c0c7629a	Discover	37.8323314493308516	-122.290077423048515
35404	2020-07-06 00:01:39	2020-07-06	Nita Treutel	nita.treutel@geemail.com	Long Beach	California	54979665103735681	8cd027a306095120c4488c35e9561d80	American Express	33.7160103407975242	-118.147679791336131
35405	2020-07-06 00:04:54	2020-07-06	Iva Bayer	iva.bayer@geemail.com	Anchorage	Alaska	869949782607154271	4adcd4e17e68d3cd824fec3f0bcd1b0d	VISA 16 digit	61.1822283702652925	-149.33859170425049
35406	2020-07-06 00:10:19	2020-07-06	Kiel Jenkins	kiel.jenkins@geemail.com	Philadelphia	Pennsylvania	4762217972392	b756ab4b3233b9f004981b7aabead298	Diners Club / Carte Blanche	39.9509652542840712	-75.0557615978077166
35407	2020-07-06 00:11:35	2020-07-06	Jerrold Dietrich	jerrold.dietrich@geemail.com	New York	New York	6011860582435968405	ecd9cd6078fb2a499372f7e55ba90642	JCB 15 digit	40.5735090771447844	-73.9532021675620257
35408	2020-07-06 00:16:34	2020-07-06	Benji Hagenes-Nicolas	benji.hagenes.nicolas@geemail.com	Los Angeles	California	3794144508481309	fb402fc880f4c82fec48e09ecc1df9b2	American Express	33.9698237756598687	-118.4009515294332
35409	2020-07-06 00:17:14	2020-07-06	Antione O'Hara	antione.o'hara@woohoo.com	Birmingham	Alabama	3096837370824512384	b2937ee457bc3b5fe7c72e33b66a5ed1	JCB 16 digit	33.5418272416364402	-86.8060328433066672
35410	2020-07-06 00:19:28	2020-07-06	Aggie Lang	aggie.lang@geemail.com	New York	New York	3528908659779944368	b4bdc5c9ce2bb0f5993e67b37556756b	Maestro	40.7116276538223048	-74.0360159473389388
35411	2020-07-06 00:22:58	2020-07-06	Deryl Hauck	deryl.hauck@geemail.com	Dayton	Ohio	4585421084303966	49f5b540d04a3b1e9bdf502fc5ce9083	JCB 16 digit	39.7440636111214758	-84.1320543190188772
35412	2020-07-06 00:51:44	2020-07-06	Sonja Lakin	sonja.lakin@warmmail.com	Louisville	Kentucky	6011132471807158609	a22451613b5928889c87d2fc142c7832	VISA 16 digit	38.1973242196157585	-85.5795961408481105
35413	2020-07-06 00:53:54	2020-07-06	Dafne Keeling	dafne.keeling@geemail.com	Salt Lake City	Utah	6011615443545751561	913ec70691a3011aae78e3dcb226f2fd	American Express	40.7362534678686359	-111.922071228077627
35414	2020-07-06 01:08:48	2020-07-06	Aubrey Glover	aubrey.glover@warmmail.com	Austin	Texas	3002917115138938	f918e984f1ac7f91e157f220105907c8	VISA 13 digit	30.2790221986953156	-97.8280830200999958
35415	2020-07-06 01:23:17	2020-07-06	Sharde Flatley-Bechtelar	sharde.flatley.bechtelar@geemail.com	Santa Clarita	California	52121192534422422	831e45739b78b39c9130114f8a5622ab	VISA 16 digit	34.3558967287391397	-118.56138845869414
35416	2020-07-06 01:54:38	2020-07-06	Atha Gerhold-Ullrich	atha.gerhold.ullrich@geemail.com	Bakersfield	California	869984010056907833	2709f3f2111446bd12008706058137ff	VISA 16 digit	35.3271340924024528	-118.954237525518238
35417	2020-07-06 02:06:22	2020-07-06	Candace Stracke	candace.stracke@geemail.com	Macon	Georgia	3046343830194096	0e366bbc8fbf2482bbf3d4298ffeba51	Discover	32.7730235769890257	-83.7208448814887447
35418	2020-07-06 02:07:17	2020-07-06	Vinson Labadie I	vinson.labadie.i@geemail.com	Stockton	California	4626603495939550	245429ef5f76d75319e1229654292c25	JCB 15 digit	37.9731032526783636	-121.279323699473593
35419	2020-07-06 02:10:40	2020-07-06	Matilda Kling-Ortiz	matilda.kling.ortiz@geemail.com	Jacksonville	Florida	52792182431632585	361728b2317e25dfcb7e791efedc14bf	Diners Club / Carte Blanche	30.342890878213197	-81.7017363837998403
35420	2020-07-06 02:17:14	2020-07-06	Alexina Ruecker	alexina.ruecker@warmmail.com	New York	New York	675904820381582	573410f4635bdd60c9c8bd2b9e2d18ab	Diners Club / Carte Blanche	40.6529583282992206	-73.9413020625140547
35421	2020-07-06 02:32:34	2020-07-06	Dr. Marcellus Auer	dr.marcellus.auer@geemail.com	Chicago	Illinois	3088419418663497930	e91187fd14440215d684755148d683ff	VISA 16 digit	41.7835987425711011	-87.7172924182407456
35422	2020-07-06 02:33:00	2020-07-06	Geri Swaniawski MD	geri.swaniawski.md@geemail.com	Jacksonville	Florida	180020879685830542	a81ca2a0c9f93fd2a9e1859f3782c5ac	JCB 16 digit	30.3892902985267348	-81.5773733181025875
35423	2020-07-06 02:48:37	2020-07-06	Dr. Arnav Gutkowski DDS	dr.arnav.gutkowski.dds@geemail.com	Detroit	Michigan	4999692128468	24d25af909893ec311a198a1e7f1e6f8	VISA 16 digit	42.3175313749741804	-83.0345883461765908
35424	2020-07-06 03:05:13	2020-07-06	Kaelynn Kuhn-Wilkinson	kaelynn.kuhn.wilkinson@geemail.com	Berkeley	California	54960281250618281	1e1dfd512308115a1cba879469665297	Voyager	37.8509596533406878	-122.272654093029374
35425	2020-07-06 03:13:50	2020-07-06	Demetric Hahn	demetric.hahn@woohoo.com	San Jose	California	630493559468314	80d24b8588e1c0ac5c97ea28997709d0	Mastercard	37.3578240671016317	-121.796476150838288
35426	2020-07-06 03:28:37	2020-07-06	Cassie Howe	cassie.howe@geemail.com	San Francisco	California	869932753692876747	83c6b87cbf6ae072d45dd27a1d9ef41f	Maestro	37.7615794294314213	-122.466356053370177
35427	2020-07-06 03:41:00	2020-07-06	Eino West I	eino.west.i@warmmail.com	San Francisco	California	3056763296287664	ba37beb044b2c900453c0af784d9697c	JCB 15 digit	37.752410773232647	-122.445296364148646
35428	2020-07-06 03:46:02	2020-07-06	Willis Mills	willis.mills@woohoo.com	Austin	Texas	3096331342508372154	1be3b0d3b6266fbfbbf36ada84e57797	Diners Club / Carte Blanche	30.319053920184821	-97.7334121105499634
35429	2020-07-06 03:50:55	2020-07-06	Mr. Dawson Pfannerstill DDS	mr.dawson.pfannerstill.dds@geemail.com	San Bernardino	California	3023684848258610	267874b35926d41ae80f92662a6f4ae9	Voyager	34.2317118598412691	-117.326354172943525
35430	2020-07-06 03:55:44	2020-07-06	Ocie Kilback	ocie.kilback@geemail.com	Peoria	Illinois	3056246809043303	b30dd1467d9b2d0b0af58474695c2a55	VISA 16 digit	40.7007693609558032	-89.6359298672411597
35431	2020-07-06 04:02:54	2020-07-06	Chynna Huel	chynna.huel@geemail.com	Riverside	California	180051903792086483	9e93c3960e20e97f38c571e66f98f14a	VISA 13 digit	33.8872791025269748	-117.322782421528174
35432	2020-07-06 04:09:18	2020-07-06	Gwyneth Dicki	gwyneth.dicki@geemail.com	Berkeley	California	53415529132152460	8c5524bec628a974e332c0dbba257733	Diners Club / Carte Blanche	37.8584206389528504	-122.270187441427723
35433	2020-07-06 04:12:50	2020-07-06	Ms. Nancie Leffler PhD	ms.nancie.leffler.phd@warmmail.com	Lancaster	California	4192454833794	fe721e696f9821003b13abff3f674269	VISA 16 digit	34.7328677721101826	-118.265952266703536
35434	2020-07-06 04:18:27	2020-07-06	Haywood Barton	haywood.barton@woohoo.com	St. Petersburg	Florida	3096708420486360121	687eb3ff21eabbf4b27c795a0d8172d6	Maestro	27.6993966917395582	-82.6990968171399032
35435	2020-07-06 04:29:21	2020-07-06	Dr. Shelli Nikolaus	dr.shelli.nikolaus@geemail.com	Henderson	Nevada	4542453827906385	f8630204a4372c7afccca9d29738dbd7	Maestro	36.0654825192343438	-114.949215372946867
35436	2020-07-06 04:44:09	2020-07-06	Dillon Toy	dillon.toy@woohoo.com	New York	New York	4589247826999837	45207add4308851900019d7cc730c036	JCB 16 digit	40.7493963926788396	-73.858283981810132
35437	2020-07-06 04:56:58	2020-07-06	Annette Ullrich-Rutherford	annette.ullrich.rutherford@warmmail.com	Oakland	California	4615169155340243	bf105b2c457d3416ef0251c7d2a21de8	Maestro	37.7785775702561324	-122.254777321132821
35438	2020-07-06 05:02:16	2020-07-06	Mendy Gerlach	mendy.gerlach@geemail.com	Bakersfield	California	589343947139069	2187e0432479c4812a1151528b2b0395	JCB 16 digit	35.3539036685310251	-118.991355518744513
35439	2020-07-06 05:26:50	2020-07-06	Amya Bayer	amya.bayer@geemail.com	Garland	Texas	589319978697746	83b16b9b531a2e082c30cf47e0fdbfb5	Maestro	32.8831136577997327	-96.5969623073164456
35440	2020-07-06 05:30:52	2020-07-06	Vicente Kshlerin	vicente.kshlerin@geemail.com	Wichita	Kansas	4650982792304919	de8c8eb1fc0597f28ae508947a6d3e34	VISA 13 digit	37.6147853399503944	-97.2955222144924079
35441	2020-07-06 05:32:45	2020-07-06	Jaclyn Hayes	jaclyn.hayes@geemail.com	Albuquerque	New Mexico	6011751905301079365	964060483ebadca5c422631ba8aa39d6	JCB 16 digit	35.060497285206246	-106.549827468309189
35442	2020-07-06 05:37:32	2020-07-06	Lugenia Ferry	lugenia.ferry@geemail.com	Mesa	Arizona	060491315875327	5bed408a9b13ee0fd29fdcc080033de8	Mastercard	33.4533737942721672	-111.62077193515151
35443	2020-07-06 05:41:56	2020-07-06	Adrienne Boehm-Schultz	adrienne.boehm.schultz@geemail.com	Pueblo	Colorado	3337854447276491065	60d83506ffdb9273c6c46a28401de8c6	JCB 16 digit	38.260651058701427	-104.702784044747432
35444	2020-07-06 05:42:47	2020-07-06	Dr. Liller Yundt	dr.liller.yundt@geemail.com	Charlotte	North Carolina	4536697548209440	9d7a0cd52c2b269feb023e427da5211d	Mastercard	35.1544836555860911	-80.7563225249704004
35445	2020-07-06 05:42:55	2020-07-06	Marty Leuschke III	marty.leuschke.iii@geemail.com	San Francisco	California	4638512151759671	26fe440e1e48a80aec25a9b1e4c011da	JCB 16 digit	37.7546023072172403	-122.39157819897386
35446	2020-07-06 05:43:45	2020-07-06	Rilla Pagac	rilla.pagac@geemail.com	Nashville	Tennessee	180078636792919019	3b75f0c0795b22d9287dcfd0bcee6299	Maestro	36.0847746406339098	-86.693652460388833
35447	2020-07-06 05:57:38	2020-07-06	Shiloh Quitzon PhD	shiloh.quitzon.phd@warmmail.com	Austin	Texas	3528257454922013171	dc657ef5bd95cbaa6d4ca88791c0c970	American Express	30.2275147648654858	-97.6689467524416841
35448	2020-07-06 06:16:46	2020-07-06	Brooks Lakin	brooks.lakin@geemail.com	Salt Lake City	Utah	561296323680171	00aa98d7dbf60d39ca064d4acf083c0e	Maestro	40.8262192423600681	-111.931394466845319
35449	2020-07-06 06:21:48	2020-07-06	Dr. Lena Stokes	dr.lena.stokes@geemail.com	Los Angeles	California	3057332032260291	a51a388c3120f76f40a9fb44c8b6c0d9	Maestro	34.0133971458632445	-118.326396966352306
35450	2020-07-06 06:40:02	2020-07-06	Wynona Schamberger-Harber	wynona.schamberger.harber@geemail.com	Pomona	California	180065572423843655	ad258913485e5ef4b54f63bd0639e2bf	JCB 16 digit	34.1327529818788165	-117.851066869773348
35451	2020-07-06 06:45:07	2020-07-06	Mrs. Verda Frami	mrs.verda.frami@woohoo.com	Mobile	Alabama	210029527248371493	ce6c8ba1ac354bdeb526a1b766f17f17	VISA 16 digit	30.6648551602024568	-88.1941885761123103
35452	2020-07-06 06:50:50	2020-07-06	Alois Gottlieb-Stark	alois.gottlieb.stark@warmmail.com	Austin	Texas	869956928975336954	fdb8095f4dab36e4f6b8c62305a02fa9	Diners Club / Carte Blanche	30.2463624183680864	-97.7658091313909807
35453	2020-07-06 07:07:53	2020-07-06	Dawson Stark	dawson.stark@geemail.com	Raleigh	North Carolina	4073720129574443	a8257d7009020df4c1be89be3884c99c	JCB 16 digit	35.8088927727326691	-78.6513230644103203
35454	2020-07-06 07:17:25	2020-07-06	Virgie Smith	virgie.smith@geemail.com	Beaumont	Texas	3337973586930947024	e1bea8b5b70aec15e5218b1dfbeea647	Mastercard	30.1798580251704927	-94.0775917547542662
35455	2020-07-06 07:32:01	2020-07-06	Horace Osinski	horace.osinski@warmmail.com	New York	New York	180053278649624911	372a8ee1c3002718744d902451a8c06b	VISA 13 digit	40.5656552478894596	-73.9767460666958243
35456	2020-07-06 07:36:39	2020-07-06	Jerrod Cartwright	jerrod.cartwright@geemail.com	San Francisco	California	4964818168293	6c4be9454885ce8c6aec736ae0f38f5e	JCB 16 digit	37.7553156735762485	-122.427327332657654
35457	2020-07-06 07:45:47	2020-07-06	Sibbie Bogisich-Nitzsche	sibbie.bogisich.nitzsche@geemail.com	New York	New York	3088749757099144793	f11fc2f4f7075498ffbd5b290395b1ce	VISA 16 digit	40.6163380674310019	-73.989317589382452
35458	2020-07-06 08:32:56	2020-07-06	Dr. Pansy Ryan	dr.pansy.ryan@warmmail.com	New York	New York	180048752049487820	4639d53c2f41009dc139d0ac7fc1486d	JCB 16 digit	40.7618727822545921	-73.9807355285052211
35459	2020-07-06 08:35:00	2020-07-06	Trevor D'Amore-Price	trevor.d'amore.price@geemail.com	Philadelphia	Pennsylvania	3528273942457092065	dbf477d639ae28fe6cab82d6d19c4e59	Discover	40.0537253959529096	-75.1137947704542484
35460	2020-07-06 08:45:43	2020-07-06	Conway Lockman IV	conway.lockman.iv@warmmail.com	Phoenix	Arizona	4097488991664807	89617418eb535c6e3416234752f885a2	VISA 13 digit	33.6491074669107846	-112.086140866710252
35461	2020-07-06 08:54:09	2020-07-06	Aida Pacocha	aida.pacocha@geemail.com	Santa Clarita	California	3406950919359372	02b4a52c2c73ee4d694b3f4305050533	VISA 16 digit	34.4055832458864899	-118.544810794536772
35462	2020-07-06 08:56:55	2020-07-06	Milton Nolan	milton.nolan@woohoo.com	Los Angeles	California	4401270726383478	8c46a35c6d3f2efc9aef363449a65bb7	Maestro	33.9258639451913524	-118.32734482767917
35463	2020-07-06 09:09:05	2020-07-06	Darvin Gerlach	darvin.gerlach@woohoo.com	Jersey City	New Jersey	55619884742348964	6e536c9fb2c15ad614fb4438893d242a	VISA 16 digit	40.6360518266387274	-74.1323991068128549
35464	2020-07-06 09:11:22	2020-07-06	Leia Wintheiser-Krajcik	leia.wintheiser.krajcik@geemail.com	Bridgeport	Connecticut	4582401666583725	6056a8e4620d82421f52a4497e203790	JCB 16 digit	41.1957994207903724	-73.1985087765745845
35465	2020-07-06 09:28:08	2020-07-06	Solon Hammes MD	solon.hammes.md@geemail.com	Phoenix	Arizona	3112593121205441329	0d4c076fa5e9a4ec6840ec0232f53cfd	VISA 13 digit	33.6191444032758469	-111.994298985826234
35466	2020-07-06 09:39:31	2020-07-06	Vanesa Robel	vanesa.robel@geemail.com	Scottsdale	Arizona	869954599765242553	5151e961ef790337e236ca41f5e37c0e	Mastercard	33.7513358913019275	-111.840597019108372
35467	2020-07-06 09:45:35	2020-07-06	Aidyn Bauch	aidyn.bauch@warmmail.com	Louisville	Kentucky	4698611317331	16ca4f0f0d418d3a8eb799611d904a30	Mastercard	38.2405741693820787	-85.563000903378807
35468	2020-07-06 09:52:12	2020-07-06	Kamren Mitchell	kamren.mitchell@geemail.com	San Francisco	California	53066519990682585	85a7545f106df5e375a8e1d96ab8f2dc	JCB 16 digit	37.81081717858725	-122.417820206050678
35469	2020-07-06 09:55:14	2020-07-06	Shelley Beier	shelley.beier@geemail.com	Tampa	Florida	3096112353482907969	d93fc95bf819e855db0d449803a23523	VISA 16 digit	27.9706007250234485	-82.5221635939300029
35470	2020-07-06 09:59:48	2020-07-06	Franco King	franco.king@geemail.com	Corona	California	54454744595800412	7bbffe09eca321418ce3f64df105297a	JCB 15 digit	33.7921673435140448	-117.579227103965351
35471	2020-07-06 10:28:07	2020-07-06	Dr. Norton Pagac	dr.norton.pagac@woohoo.com	San Francisco	California	54678408409409998	a030a2966cb81b0a594442ba63f6f227	JCB 15 digit	37.7896883131945245	-122.456124490129724
35472	2020-07-06 10:31:40	2020-07-06	Edythe Considine	edythe.considine@geemail.com	Grand Prairie	Texas	180057406198977333	18fdb603e20d5ea199e0994e613f2c92	Diners Club / Carte Blanche	32.6252294913452161	-96.9252440124157886
35473	2020-07-06 10:42:27	2020-07-06	Che Ullrich	che.ullrich@geemail.com	Daly City	California	3337017677379880715	68b43d1e09b6fc13d5b1b3965f573222	JCB 16 digit	37.6744660340171293	-122.47028566832654
35474	2020-07-06 10:43:27	2020-07-06	Trumaine Ondricka	trumaine.ondricka@geemail.com	North Charleston	South Carolina	3158997106116908740	a82bb15bf11434e13f3fa17f6e8ac698	Discover	32.8884619590055181	-79.9812624625489121
35475	2020-07-06 10:48:26	2020-07-06	Mrs. Zaida Daugherty DDS	mrs.zaida.daugherty.dds@geemail.com	Colorado Springs	Colorado	502047572353390	336bf8bdf843290231286b5e54fca069	Discover	38.8866278223741801	-104.70483113794289
35476	2020-07-06 10:53:45	2020-07-06	Drucilla Windler	drucilla.windler@geemail.com	Pittsburgh	Pennsylvania	4857782460907600	87b46bbbd19d860b5df5b1eeaeaf061c	JCB 16 digit	40.4505274337206018	-80.0270663263447659
35477	2020-07-06 10:58:13	2020-07-06	Jamarcus Pollich-Bins	jamarcus.pollich.bins@geemail.com	Colorado Springs	Colorado	180069274853602745	113b936646d0873f69085e8a0598a89f	VISA 13 digit	38.8937688470400857	-104.664262802122906
35478	2020-07-06 11:02:03	2020-07-06	Susanna Fadel	susanna.fadel@woohoo.com	Oakland	California	3029679066051360	36211efa6d8f4d18d8a2f7caffea432f	Discover	37.8158718136662344	-122.249981313740903
35479	2020-07-06 11:03:36	2020-07-06	Paul Muller-Goyette	paul.muller.goyette@woohoo.com	New York	New York	3057133406470536	1895efe5f400f441531e64d1a687c31a	American Express	40.6722923444341831	-74.0371566528815777
35480	2020-07-06 11:05:27	2020-07-06	Jalisa Krajcik PhD	jalisa.krajcik.phd@geemail.com	San Francisco	California	3028265810980533	9436be986f15505d3e052370829e1611	VISA 16 digit	37.7494190456959018	-122.400559134509294
35481	2020-07-06 11:07:53	2020-07-06	Tatiana Parisian	tatiana.parisian@geemail.com	Hialeah	Florida	3493030016876257	0f007062c790f2bdae69b49ce958df68	Maestro	25.7812977780099963	-80.2901620080597667
35482	2020-07-06 11:10:48	2020-07-06	Collis O'Kon-Blanda	collis.o'kon.blanda@geemail.com	Chicago	Illinois	869999944155538144	0a7b7e3b3ff3bc07270a9707a6b7bbbd	Discover	41.8310684399981056	-87.6497334890563025
35483	2020-07-06 11:19:40	2020-07-06	Danny Harber-Turner	danny.harber.turner@warmmail.com	Tulsa	Oklahoma	3491020730881578	64eeac031f509170589a1d9f64f3dbd5	VISA 16 digit	36.101970524331179	-95.8786998445589091
35484	2020-07-06 11:28:01	2020-07-06	Olie Jacobs	olie.jacobs@geemail.com	San Francisco	California	4942297763474403	562cbeafe0132a936f3030c4f0902225	VISA 16 digit	37.7683298316152047	-122.418621404833743
35485	2020-07-06 11:31:16	2020-07-06	Marsha Hayes	marsha.hayes@geemail.com	San Francisco	California	4748987070866483	e81fe793a3e842378942f3a7bb721807	American Express	37.7869395374075694	-122.450623985445105
35486	2020-07-06 11:40:26	2020-07-06	Dr. Mayo Cummings	dr.mayo.cummings@geemail.com	Fargo	North Dakota	3770259807878407	a3613bf268ab186a7dea617cd32dc18a	American Express	46.9389421517726078	-96.867451867178076
35487	2020-07-06 11:49:30	2020-07-06	Adelbert Mante	adelbert.mante@geemail.com	Hialeah	Florida	869948668264682202	7a289d205cba3e270d4689758acddbd0	Voyager	25.8424025906227541	-80.2284332306027324
35488	2020-07-06 12:11:46	2020-07-06	Cathie Glover	cathie.glover@woohoo.com	Philadelphia	Pennsylvania	3440909458206707	827dba20952ee4e48d85823b549faefb	American Express	40.0422345701098408	-75.0726328747712159
35489	2020-07-06 12:28:56	2020-07-06	Nikki Roberts	nikki.roberts@geemail.com	Atlanta	Georgia	4929657142782	d218f27e1b2fb917240424d912e2de8a	Mastercard	33.6665706368438933	-84.3247357897505196
35490	2020-07-06 12:29:19	2020-07-06	Shea Fadel-Lang	shea.fadel.lang@geemail.com	Richmond	Virginia	3021257513619655	11e265044adce5809310d04e8642599e	Mastercard	37.5832795501906389	-77.5243621863648258
35491	2020-07-06 12:54:47	2020-07-06	Etta Grant	etta.grant@geemail.com	Ontario	California	3528417054736160262	988a1b3022849b395d78faa9151b1e2e	VISA 13 digit	34.0433432740770314	-117.649626378864795
35492	2020-07-06 12:59:43	2020-07-06	Mr. Carl Wilkinson Sr.	mr.carl.wilkinson.sr.@geemail.com	Oakland	California	210093774027354727	2d889b45cc0041283c4815ae3ec29bec	JCB 15 digit	37.7936919429148617	-122.301233548117622
35493	2020-07-06 12:59:49	2020-07-06	Jace Lynch-Waters	jace.lynch.waters@geemail.com	Oklahoma City	Oklahoma	3763799542153573	2690d1b187cc8a1521178fa9d962e82c	JCB 16 digit	35.4000189005307888	-97.568912534777823
35494	2020-07-06 13:08:53	2020-07-06	Neal Moore	neal.moore@geemail.com	San Antonio	Texas	3767809731945717	01e9c5b0f737a814c22e399e7043abbb	Discover	29.571158852062748	-98.5001228851102297
35495	2020-07-06 13:13:32	2020-07-06	Dr. Myrtis Feest PhD	dr.myrtis.feest.phd@geemail.com	San Francisco	California	180070773028270574	0bc3d1a2373ca6062dbec62ab2db4c7d	VISA 16 digit	37.7591592454393066	-122.398845611199647
35496	2020-07-06 13:14:21	2020-07-06	Lawrance Kihn	lawrance.kihn@woohoo.com	San Francisco	California	180017251549845899	2d67b6b5c2da88a7356123524e10d87f	JCB 16 digit	37.7745078993400796	-122.412134754093259
35497	2020-07-06 13:17:54	2020-07-06	Keri Littel	keri.littel@geemail.com	Birmingham	Alabama	4578301703168546	9e31dae3ada09e3d6ca7d1ca0467ccc8	Diners Club / Carte Blanche	33.4471110873181345	-86.7453430551346401
35498	2020-07-06 13:19:38	2020-07-06	Alphonse Hickle	alphonse.hickle@geemail.com	Memphis	Tennessee	51917870787695640	1bc0b049fa4f5da1c900014f970141aa	VISA 13 digit	35.1885734943274429	-89.9682868120983272
35499	2020-07-06 13:20:08	2020-07-06	Kian Blanda	kian.blanda@woohoo.com	Los Angeles	California	869914258276272018	205cb2269e08e2cff18e5d1bc1f500cd	Diners Club / Carte Blanche	34.0993860689323398	-118.400389069969947
35500	2020-07-06 13:23:33	2020-07-06	Willow Steuber	willow.steuber@geemail.com	San Francisco	California	54668466279449652	d6ac35d2baa30113dcd969019b8332c5	American Express	37.7790393451006068	-122.441254573475263
35501	2020-07-06 13:24:22	2020-07-06	Booker Heller	booker.heller@geemail.com	San Francisco	California	3406748392216782	356b9c709e0415a073f7b4bcc9359c36	VISA 13 digit	37.7592942574119661	-122.459597922249898
35502	2020-07-06 13:24:35	2020-07-06	Dayna Leuschke	dayna.leuschke@warmmail.com	Los Angeles	California	4661853817053	0273282b5f627a0e8b1c6cc556f181cd	VISA 16 digit	33.9779063016973382	-118.314858262333274
35503	2020-07-06 13:34:32	2020-07-06	Lorrayne Stanton	lorrayne.stanton@woohoo.com	San Francisco	California	3158307168244248899	b96498a8fc798c4a66b1cbcff6d0d98b	VISA 13 digit	37.7687459689237812	-122.441957944639356
35504	2020-07-06 13:35:17	2020-07-06	Ms. Pamella Harris DVM	ms.pamella.harris.dvm@geemail.com	Saint Paul	Minnesota	3528941218847024312	fdcd397dfcb3fce3a19f725eda9dbc18	Discover	45.0322612133748876	-93.1745897775314802
35505	2020-07-06 14:04:50	2020-07-06	Kamryn Fay	kamryn.fay@warmmail.com	Huntsville	Alabama	869975323000314597	0eaae510227464a3e083ba84285dde9b	Mastercard	34.7056774033941338	-86.7565083178710239
35506	2020-07-06 14:14:50	2020-07-06	Dulcie Moen	dulcie.moen@geemail.com	Clinton	Michigan	3528434393458181232	ee1716684bfe1eb6b48bfaf4789ae444	Voyager	42.6243949024073743	-82.9656153013072952
35507	2020-07-06 14:26:44	2020-07-06	Love Larkin	love.larkin@warmmail.com	Elgin	Illinois	3435633264740918	53219dd36e22375e01ace20d5047a5c1	Maestro	41.993691851972045	-88.3799484628073913
35508	2020-07-06 14:27:33	2020-07-06	Herman Hessel	herman.hessel@warmmail.com	Baltimore	Maryland	3096499710607418136	329b1d977ed1f5ac897fb341e4180783	American Express	39.3026106633711549	-76.6731147639472113
35509	2020-07-06 14:39:51	2020-07-06	Elianna Hackett	elianna.hackett@geemail.com	Phoenix	Arizona	3742491199089674	d94a709ec1506de59619b46abcbaeb3f	Maestro	33.4869001693025226	-112.146496670220429
35510	2020-07-06 14:41:23	2020-07-06	Marlana Gerlach-Hane	marlana.gerlach.hane@geemail.com	Ventura	California	869995662953912147	7731c3500a70a97c391d79bee0526ea4	Mastercard	34.34393059044816	-119.274883074230331
35511	2020-07-06 14:51:47	2020-07-06	Sawyer Abernathy-Satterfield	sawyer.abernathy.satterfield@geemail.com	San Francisco	California	180079104218163299	a16c1ad475a3f81339ca7ce1a39f1063	Diners Club / Carte Blanche	37.786005356614659	-122.414760040878747
35512	2020-07-06 14:54:43	2020-07-06	Mr. Yahir Turner	mr.yahir.turner@warmmail.com	Fort Worth	Texas	3054318306840051	c685ee0e62d68060f38fc1d4e7ca475d	VISA 13 digit	32.8320937545560341	-97.2527787152033341
35513	2020-07-06 15:04:52	2020-07-06	Aubree Schuster-Heathcote	aubree.schuster.heathcote@geemail.com	Rochester	Minnesota	3337086928359638904	ce13465737554318cd45ae011de2f03a	Diners Club / Carte Blanche	44.0952736570402948	-92.5142765910949549
35514	2020-07-06 15:12:42	2020-07-06	West Crist	west.crist@geemail.com	Berkeley	California	3750796404437321	dfa170969a874ee12c456199a33dea0b	Maestro	37.8757767427937964	-122.278343788229876
35515	2020-07-06 15:12:49	2020-07-06	Lilah Sauer	lilah.sauer@geemail.com	San Francisco	California	52379917183969052	f872d11e2096a4581571f202bba16b85	Diners Club / Carte Blanche	37.7470825948147635	-122.399039773452628
35516	2020-07-06 15:13:41	2020-07-06	Dr. Aryana Upton MD	dr.aryana.upton.md@geemail.com	Miami	Florida	4028113090204	d66edb973adc8f1f4163858b256d799c	VISA 16 digit	25.8412480653867149	-80.1816818357318652
35517	2020-07-06 15:18:41	2020-07-06	Dani Lemke	dani.lemke@geemail.com	Henderson	Nevada	502063772332316	f7ccfcb42c3e25de75f15e96cf6462b4	VISA 13 digit	36.0721925657641194	-115.040355365878725
35518	2020-07-06 15:18:44	2020-07-06	Mr. Jamil Weimann I	mr.jamil.weimann.i@geemail.com	Newport News	Virginia	3013372288894173	f04d8413081690f974bb0795cdc60071	Mastercard	37.0182970975421384	-76.532400649346414
35519	2020-07-06 16:10:16	2020-07-06	Dusty Mills	dusty.mills@warmmail.com	Port St. Lucie	Florida	630461682052149	597fae22ef57eec4b83aa04d510a8f07	Mastercard	27.218040424319355	-80.4532482154287436
35520	2020-07-06 16:40:52	2020-07-06	Chyna Morar	chyna.morar@geemail.com	Memphis	Tennessee	4410717458878645	da32798c4782b1ca7d36bfc7918d0570	VISA 16 digit	35.060748209578172	-89.9267502375669778
35521	2020-07-06 17:14:25	2020-07-06	Itzel Harvey-Hegmann	itzel.harvey.hegmann@geemail.com	Fremont	California	6011252567802474232	a390ad8f27b3f55f5b8895f6a5bf211d	JCB 16 digit	37.5369739883746973	-122.015847841975088
35522	2020-07-06 17:21:59	2020-07-06	Malaya Friesen-Schaefer	malaya.friesen.schaefer@geemail.com	New York	New York	180016154727747146	96feb57bf43cbc25882420af5ffa98f3	Maestro	40.5726046715620896	-73.8665477838728606
35523	2020-07-06 17:22:36	2020-07-06	Samatha Boyer PhD	samatha.boyer.phd@geemail.com	New York	New York	869982475555738033	ca3591721699455972f9475d571ce806	VISA 16 digit	40.7002811466567209	-73.900511887891966
35524	2020-07-06 17:46:53	2020-07-06	Dr. Bryson Wilderman	dr.bryson.wilderman@geemail.com	San Francisco	California	180051135447256472	a6ced7ea4acaa92930fe0ffc0fe95ffb	VISA 16 digit	37.7864235740403487	-122.402198075568052
35525	2020-07-06 17:54:52	2020-07-06	Girtha Lockman	girtha.lockman@geemail.com	Philadelphia	Pennsylvania	3158826693423632466	2f28c0d26703e67ea97924110f0a6041	VISA 13 digit	39.9637798188678914	-75.1759830297801699
35526	2020-07-06 18:05:56	2020-07-06	Rosalind Sanford PhD	rosalind.sanford.phd@woohoo.com	Ontario	California	3724563099071226	885d5f341e14fd2a77d77ff560e407a7	Discover	34.0168582026526352	-117.544301133240396
35527	2020-07-06 18:08:47	2020-07-06	Trinity Waelchi	trinity.waelchi@warmmail.com	Santa Rosa	California	3031982956724858	8a89dbf9e006db612aad1885c212370f	American Express	38.3866458074778336	-122.618636504212773
35528	2020-07-06 18:09:25	2020-07-06	Daisye Rohan-Mohr	daisye.rohan.mohr@geemail.com	Los Angeles	California	3491077396201392	d3169b624e6c6f5629f72efacd9d5101	Diners Club / Carte Blanche	34.048432675735647	-118.470667579862464
35529	2020-07-06 18:18:31	2020-07-06	Miss Glinda Stamm	miss.glinda.stamm@warmmail.com	Houston	Texas	3483728016169704	0fede8d792778648d49b8da7e5b3ec4f	JCB 15 digit	29.8696396383535117	-95.3920330874636733
35530	2020-07-06 18:19:01	2020-07-06	Frances Schuppe-Shanahan	frances.schuppe.shanahan@geemail.com	Lakewood	Colorado	3158076475176338831	66089016537de7f6958bb56fcb8858f9	American Express	39.656848255864908	-105.06916877054833
35531	2020-07-06 18:26:13	2020-07-06	Jethro Denesik	jethro.denesik@geemail.com	San Francisco	California	6011710868519392741	d8ef04b9c1255036c3c4bc6a70161531	American Express	37.7624203632114259	-122.403810294410846
35532	2020-07-06 18:30:21	2020-07-06	Cale Hessel	cale.hessel@geemail.com	Milwaukee	Wisconsin	6011663187063604899	b478544ca209d0f2d58ad8e6c9da860e	VISA 16 digit	42.9915040011603367	-87.9766278109148203
35533	2020-07-06 18:32:12	2020-07-06	Mrs. Lucindy Gutmann MD	mrs.lucindy.gutmann.md@geemail.com	Birmingham	Alabama	3112914154997880430	3f8e3d0276365b006f469dccb948b197	Mastercard	33.4411032532598824	-86.8835214730128769
35534	2020-07-06 18:37:31	2020-07-06	Thaddeus Ryan	thaddeus.ryan@geemail.com	New York	New York	4959193781249	0da8e8f33c52da014e9359250a6feb30	VISA 16 digit	40.6266319937761864	-73.862035144761947
35535	2020-07-06 18:37:48	2020-07-06	Toya Konopelski	toya.konopelski@woohoo.com	Oakland	California	3528657794652377460	211b9b3e618a1092d702107bfb0466c8	JCB 16 digit	37.7801823143697462	-122.261401823114653
35536	2020-07-06 18:40:55	2020-07-06	Fredric DuBuque	fredric.dubuque@geemail.com	Cleveland	Ohio	3423123915455912	82c2ef18a694655a21ed2481ef966ac9	Mastercard	41.4668242290001317	-81.6941421795409184
35537	2020-07-06 18:41:16	2020-07-06	Diego Mann	diego.mann@warmmail.com	Akron	Ohio	869997336358105171	d608afdf6146fbd6e02c8ecc5c7f85b1	Diners Club / Carte Blanche	41.1506858235057464	-81.4974107225272775
35538	2020-07-06 19:05:30	2020-07-06	Kira Pfannerstill	kira.pfannerstill@warmmail.com	Greensboro	North Carolina	210060083607793091	b024283ce216f706903e6082dfd902e3	VISA 16 digit	36.1607503366772107	-79.7683891365285973
35539	2020-07-06 19:14:12	2020-07-06	Dr. Virgil Torphy DVM	dr.virgil.torphy.dvm@geemail.com	Lexington	Kentucky	869953718405983829	888c3ae6aa714832af22461549b57436	JCB 16 digit	37.9936756563715647	-84.4269478329356673
35540	2020-07-06 19:17:13	2020-07-06	Dewitt Mills	dewitt.mills@woohoo.com	Lewisville	Texas	3053366032417760	d6d451e11be15216f9e78334983daa8a	Discover	32.9524841341175119	-96.9362815101660829
35541	2020-07-06 19:21:41	2020-07-06	Yael Brown	yael.brown@geemail.com	Irvine	California	3464963195716727	70661369c049d6e484aec5484caf577f	VISA 13 digit	33.7279387178845766	-117.816048063245788
35542	2020-07-06 19:45:32	2020-07-06	Ms. Mariah Lemke	ms.mariah.lemke@geemail.com	San Francisco	California	3158753623454877166	8e7bb11a6a4198b821051a63593bbcd7	Mastercard	37.7777984499605637	-122.417377577012786
35543	2020-07-06 20:09:34	2020-07-06	Ms. Vesta Halvorson PhD	ms.vesta.halvorson.phd@geemail.com	Augusta	Georgia	869911482654424149	ceaf95499898d0661632df25975c6c30	Diners Club / Carte Blanche	33.4204588128924343	-82.0350470369044729
35544	2020-07-06 20:18:25	2020-07-06	Rocio Padberg	rocio.padberg@geemail.com	Houston	Texas	4336312626805	ce4fc877bb19216aaf31c11211519333	JCB 15 digit	29.8050927992522716	-95.4806228280548055
35545	2020-07-06 20:29:50	2020-07-06	Rance Grimes	rance.grimes@geemail.com	Killeen	Texas	3337449323493863976	3e24dcf6a6f1c9d96e900505f2c9401a	Voyager	31.083654295955597	-97.7682977575045129
35546	2020-07-06 20:35:54	2020-07-06	Maranda Price	maranda.price@woohoo.com	Chicago	Illinois	4999028983967070	38ca478b2279c87b6d442f034c6edcaf	VISA 16 digit	41.8493582452483466	-87.6266458563536332
35547	2020-07-06 20:38:43	2020-07-06	Ms. Benita Price DVM	ms.benita.price.dvm@geemail.com	New Orleans	Louisiana	52109459468407299	685de588a4d5ebec52be622887723fc7	VISA 16 digit	30.0788451306536793	-89.8373886855579968
35548	2020-07-06 20:43:53	2020-07-06	Estela Schamberger	estela.schamberger@geemail.com	Houston	Texas	4545064058579127	fe44dd3a4e2bdd78f1e55d68b431a5c7	JCB 15 digit	29.8107895921993986	-95.3553923463929465
35549	2020-07-06 20:55:10	2020-07-06	Dr. Mikhail Collier V	dr.mikhail.collier.v@warmmail.com	New York	New York	6011034613340500651	a17611766ffe6bbb582e79e99b9ac4bf	Voyager	40.6706261805482185	-73.9984988790366742
35550	2020-07-06 21:11:26	2020-07-06	Mr. Delphin Breitenberg DVM	mr.delphin.breitenberg.dvm@warmmail.com	Phoenix	Arizona	4771971739335106	96961a563747e7f8717c774405f5d9b8	Maestro	33.580680340987449	-112.128669702208043
35551	2020-07-06 21:23:21	2020-07-06	Jaleel Rutherford IV	jaleel.rutherford.iv@warmmail.com	San Francisco	California	4530250518392	914694e60011279a8ae4a3f6d5ac539e	JCB 16 digit	37.8003003937008657	-122.45145918304226
35552	2020-07-06 21:52:18	2020-07-06	Jeb Bechtelar-Muller	jeb.bechtelar.muller@geemail.com	San Francisco	California	52939216532753280	faeb7656d4f45b98ca37fd664a44d0f9	JCB 16 digit	37.7880170359267993	-122.431394972955516
35553	2020-07-06 21:52:29	2020-07-06	Arra Kulas	arra.kulas@woohoo.com	Atlanta	Georgia	3036903709859119	21000015f8f499cb8cb8fc0fc30faeff	Voyager	33.8220053846757907	-84.3643122804395915
35554	2020-07-06 21:55:35	2020-07-06	Dr. Wanda Marks DDS	dr.wanda.marks.dds@woohoo.com	Kent	Washington	4372593607145046	cb6a13f6aac8c41901e8d544957a6c89	American Express	47.4150573724992555	-122.133308438970516
35555	2020-07-06 22:06:38	2020-07-06	Mr. Alvie Gislason I	mr.alvie.gislason.i@geemail.com	Sugar Land	Texas	52143923429950018	b7452fa106dee1d02ccc1e65632f4e03	Voyager	29.57785132537186	-95.55628512171171
35556	2020-07-06 22:11:00	2020-07-06	Penny Jerde PhD	penny.jerde.phd@woohoo.com	Louisville	Kentucky	210077760978587019	6b1601ec0c619f772e8c41f357f47a74	Diners Club / Carte Blanche	38.0672716574646515	-85.5575085215341318
35557	2020-07-06 22:16:23	2020-07-06	Aurora Jaskolski	aurora.jaskolski@warmmail.com	Miami	Florida	4718473733175	9cf36e225e5ee054d001aa505cceb5fd	JCB 15 digit	25.8597452257432074	-80.1874451422471566
35558	2020-07-06 22:18:52	2020-07-06	Hortensia Okuneva	hortensia.okuneva@geemail.com	Visalia	California	4824266843491938	6283fccd6a7a269357586dc7552be9f0	Diners Club / Carte Blanche	36.2273917323399317	-119.230627896556257
35559	2020-07-06 22:21:29	2020-07-06	Margie Rath	margie.rath@geemail.com	Anchorage	Alaska	6011487786701801991	d9d79e0bd22e398ebb85acc5a841afe0	JCB 16 digit	61.2222678514879206	-149.260976673209285
35560	2020-07-06 22:32:32	2020-07-06	Emelia Stroman	emelia.stroman@geemail.com	Phoenix	Arizona	51876684746676388	38c76159efe5d803ca7075b0fa9deb1a	Discover	33.6375843292966508	-112.146389710244165
35561	2020-07-06 22:36:25	2020-07-06	Giuseppe Franecki DVM	giuseppe.franecki.dvm@geemail.com	Las Vegas	Nevada	3528266302645991018	c3a127502722e88c26fe12be0fc366b9	Mastercard	36.1949777956686916	-115.265736209296051
35562	2020-07-06 22:42:19	2020-07-06	Delois Krajcik	delois.krajcik@geemail.com	New York	New York	869962813599235000	0bf502cf0ab915766f856c3e06960c2a	JCB 16 digit	40.6426791429743162	-73.8711435219168635
35563	2020-07-06 22:49:10	2020-07-06	Marely Collins	marely.collins@woohoo.com	Seattle	Washington	3528275184625016597	e6747605c4498d414ca2be47708cfd17	Diners Club / Carte Blanche	47.6560632045771939	-122.389880715908106
35564	2020-07-06 22:52:27	2020-07-06	Myra Conn-Harvey	myra.conn.harvey@warmmail.com	Sacramento	California	6011335534579426309	d4dae92ee438ea67679c1323a3ce686f	Discover	38.6098103582192209	-121.515561570391426
35565	2020-07-06 22:52:40	2020-07-06	Marin Adams-Boyer	marin.adams.boyer@geemail.com	San Francisco	California	501832603150221	ee6a742d072fe80b2df8faccf4a4b47c	Maestro	37.7944332165803445	-122.423431379035449
35566	2020-07-06 23:18:02	2020-07-06	Meg Kub	meg.kub@woohoo.com	San Francisco	California	6011757238744749939	31cc958398f517fb8a5edbbee8dd5902	Voyager	37.7831477758902352	-122.452917016663534
35567	2020-07-06 23:20:59	2020-07-06	Reynolds Volkman	reynolds.volkman@geemail.com	Miami	Florida	3112395413600459851	f0cca19c8428504e4188f27f217a9fd6	Maestro	25.7912577712580564	-80.190830633636935
35568	2020-07-06 23:29:52	2020-07-06	Genoveva Cartwright	genoveva.cartwright@geemail.com	Columbus	Ohio	3000438009341316	f57270685ee6d6d60b0f372f28f42fb8	Diners Club / Carte Blanche	40.0609074090652157	-82.9791840916268626
35569	2020-07-06 23:30:56	2020-07-06	Dr. Isis Schiller PhD	dr.isis.schiller.phd@geemail.com	New York	New York	3088971096971433423	afad9f1df7c20bbde36809f0467419f8	American Express	40.7389777845460941	-73.8593059057265435
35570	2020-07-06 23:33:47	2020-07-06	Ms. Elianna Jenkins DDS	ms.elianna.jenkins.dds@geemail.com	San Francisco	California	6011640153315047806	69fb05f54dd5e355699d4d67bb8e43e0	Diners Club / Carte Blanche	37.7712296742316909	-122.433872861044563
35571	2020-07-06 23:47:43	2020-07-06	Dr. Kazuo Deckow	dr.kazuo.deckow@woohoo.com	Los Angeles	California	3158789489330846868	d69fa723d1924a6dd927be396a0686ab	JCB 16 digit	34.0383541497267785	-118.387432599439464
35572	2020-07-06 23:57:21	2020-07-06	Ms. Casandra Waters DDS	ms.casandra.waters.dds@geemail.com	Las Vegas	Nevada	4266654208344	94b7e3de8e4d9b6c69a6250ef26a2832	Voyager	36.2832369961410777	-115.228114129856593
35573	2020-07-07 00:02:53	2020-07-07	Alisson Auer	alisson.auer@geemail.com	Glendale	Arizona	3039384313420449	f9c3949de947f5f0bce3efeca973594d	JCB 15 digit	33.613821261631692	-112.133626609926665
35574	2020-07-07 00:11:17	2020-07-07	Lakesha Bechtelar-D'Amore	lakesha.bechtelar.d'amore@warmmail.com	San Francisco	California	3088123157352344873	801876f99ef510bf76fb7c3c79fc0e77	VISA 16 digit	37.769319033298828	-122.412183646375141
35575	2020-07-07 00:39:37	2020-07-07	Sharon Blanda-Dickinson	sharon.blanda.dickinson@geemail.com	Berkeley	California	51228677610491863	3a46c64aa791f4b55c10c5a65ee6b01c	VISA 16 digit	37.8242096837076076	-122.282891512075182
35576	2020-07-07 01:01:51	2020-07-07	Auguste Crona	auguste.crona@geemail.com	Tallahassee	Florida	3112405413539671509	cf15ac5ca7712dd57569cae756a5872a	VISA 16 digit	30.4537032799351977	-84.2743994804114038
35577	2020-07-07 01:03:49	2020-07-07	Dr. Rasheed Satterfield	dr.rasheed.satterfield@geemail.com	Denver	Colorado	060454079602030	297968603a1af1ff3aa5719eea9766d4	Discover	39.779424077184494	-104.877455371596298
35578	2020-07-07 01:14:21	2020-07-07	Germaine Price	germaine.price@geemail.com	New Haven	Connecticut	4866814079384845	58cfdb6d8594907c858e899fe8eae8cc	Voyager	41.3997489582274127	-72.9429603203199832
35579	2020-07-07 01:19:14	2020-07-07	Mrs. Octavia Heller MD	mrs.octavia.heller.md@woohoo.com	Centennial	Colorado	53989597858444979	170918c7ba65f23dda41c0c2bb9f1820	VISA 16 digit	39.6880270649254356	-104.790547060164073
35580	2020-07-07 01:21:04	2020-07-07	Miss Elianna Heaney	miss.elianna.heaney@geemail.com	San Francisco	California	3112510823083266674	cd8bbccc0e0967b9a287794cac307f4a	Diners Club / Carte Blanche	37.7956201240813883	-122.454076541875637
35581	2020-07-07 01:27:26	2020-07-07	Dr. Deonta Wiza PhD	dr.deonta.wiza.phd@geemail.com	New York	New York	3012237962404824	c6fa2742d4ea1e652ee1dba4cb2eb2f4	VISA 16 digit	40.5850768908616146	-73.8475655792176724
35582	2020-07-07 01:29:25	2020-07-07	Lige Shields	lige.shields@geemail.com	San Francisco	California	6011079187624596038	ec88798e3947bf51f830f9cddb91f2ab	Mastercard	37.7536385508937897	-122.421181469596178
35583	2020-07-07 01:29:35	2020-07-07	Gilmore Schneider	gilmore.schneider@warmmail.com	Ontario	California	180011279125100252	2775684850aca3b5958a12ed51cb7b16	Diners Club / Carte Blanche	33.9829052389278985	-117.601550314864895
35584	2020-07-07 01:30:04	2020-07-07	Rhonda Brakus	rhonda.brakus@geemail.com	Los Angeles	California	3798701446472835	292e934466b3e1a2031966ed80551487	VISA 13 digit	33.9689641995221336	-118.424320763954142
35585	2020-07-07 01:34:17	2020-07-07	Miss Jailene Renner	miss.jailene.renner@geemail.com	Dallas	Texas	869926625711608723	8de30330abd47c3832479037fea320dc	VISA 16 digit	32.7296184256479137	-96.8620270176753309
35586	2020-07-07 01:35:40	2020-07-07	Jensen Beier	jensen.beier@woohoo.com	Chicago	Illinois	3022335959598325	719aee6a2ae656931dce1f7ac68603df	VISA 16 digit	41.9167579563170705	-87.668694097132601
35587	2020-07-07 01:37:09	2020-07-07	Wilhelm Bode	wilhelm.bode@warmmail.com	San Francisco	California	060494517878305	daef61fccf8352c5e6b2fb0d339104c6	JCB 16 digit	37.7814148276622674	-122.418867000852302
35588	2020-07-07 01:43:25	2020-07-07	Penni Mitchell	penni.mitchell@geemail.com	New York	New York	4532349158255	7ba4ff97fe3c61185584a6bd458111c8	JCB 15 digit	40.6899336773659996	-74.0306556449167346
35589	2020-07-07 01:47:33	2020-07-07	Titus Wyman-Donnelly	titus.wyman.donnelly@geemail.com	Lansing	Michigan	4384233218302	f0d2e0b5dad77260089b22e3abc5ed07	American Express	42.7709247012466207	-84.6048583331175053
35590	2020-07-07 01:59:25	2020-07-07	Ermina Simonis	ermina.simonis@geemail.com	Anaheim	California	6011653577460984757	4f02d21eb42d05ceff0f4d376e344d0a	Mastercard	33.94608354808949	-117.723198462112236
35591	2020-07-07 02:00:12	2020-07-07	Pleas McKenzie	pleas.mckenzie@geemail.com	Los Angeles	California	869904166275396369	78eddbc8f8a731a1c81e52e300005db2	JCB 16 digit	34.0387142605014148	-118.380341796902187
35592	2020-07-07 02:01:52	2020-07-07	Karly Conroy	karly.conroy@geemail.com	Aurora	Colorado	4433188851254680	e0bca7d72fdf9ffb83cdeb41ce35b140	VISA 16 digit	39.6902431449499034	-104.682436035212874
35593	2020-07-07 02:01:57	2020-07-07	Hannah Harris	hannah.harris@warmmail.com	San Francisco	California	3054939891901915	d40b19b840a7820977dc738463208986	American Express	37.7506272432386325	-122.408139264498431
35594	2020-07-07 02:05:18	2020-07-07	Felecia Tremblay MD	felecia.tremblay.md@geemail.com	Saint Paul	Minnesota	3046413662105617	22b8524d5d94bf7589cd524ddf48b72c	JCB 16 digit	45.037177227943765	-93.1946941341072375
35595	2020-07-07 02:10:06	2020-07-07	Mervyn Hills-Sawayn	mervyn.hills.sawayn@geemail.com	Louisville	Kentucky	3013634610793518	ed06c90384c60bee43c73ad9b0d55d28	Voyager	38.1591314606271652	-85.6397396369908108
35596	2020-07-07 02:24:26	2020-07-07	Mrs. Emery Becker DVM	mrs.emery.becker.dvm@geemail.com	Philadelphia	Pennsylvania	210025062986226059	c09cee8473fe4256ad2c8cc2d736ff89	JCB 16 digit	40.0751209801021986	-75.1509108702085911
35597	2020-07-07 02:27:41	2020-07-07	Kameron Hauck	kameron.hauck@geemail.com	Austin	Texas	55516195756664905	373c2a60fa70a48d6f80ba47a78895af	VISA 16 digit	30.3429280584339054	-97.7665581849642109
35598	2020-07-07 02:32:43	2020-07-07	Bayard Kuvalis	bayard.kuvalis@geemail.com	Louisville	Kentucky	54256253790029819	da9be45f948701a028bb4fdd491f23f6	VISA 16 digit	38.1344054878126784	-85.6258912406001258
35599	2020-07-07 02:47:22	2020-07-07	Libby O'Kon	libby.o'kon@geemail.com	San Francisco	California	869915151943880967	43b82574f52a8b5865ac3f87957cd92b	Mastercard	37.7857670600487339	-122.404296075350274
35600	2020-07-07 02:48:07	2020-07-07	Alexandra Wilderman	alexandra.wilderman@woohoo.com	Chicago	Illinois	210098395118358040	5b5eb958d12293b3974ff49a50659239	VISA 16 digit	41.8316540200565044	-87.7486951231520607
35601	2020-07-07 02:53:55	2020-07-07	Harris Abernathy	harris.abernathy@geemail.com	Indianapolis	Indiana	6011077476378193494	ce1cb444c71214818b4d36dbf788d8da	JCB 16 digit	39.8197617350153621	-86.1481117591463033
35602	2020-07-07 03:19:17	2020-07-07	Amma Muller	amma.muller@geemail.com	San Diego	California	54946866410383229	818a5ac7fdb2bf6ea6db160b8b98193a	VISA 16 digit	32.7469067418083526	-117.094012017352512
35603	2020-07-07 03:29:50	2020-07-07	Joni Stamm	joni.stamm@woohoo.com	Los Angeles	California	869958488102744826	c51037044a668ec17a8b79051a5adaa0	VISA 16 digit	33.9530607914883618	-118.348427254845575
35604	2020-07-07 03:37:29	2020-07-07	Aurelio Satterfield	aurelio.satterfield@geemail.com	Tucson	Arizona	4812898503774	436c6bab28dfc0cd600429aa27cdde82	VISA 16 digit	32.1985733043909121	-110.908857314730426
35605	2020-07-07 03:45:27	2020-07-07	Ray Considine-Koelpin	ray.considine.koelpin@woohoo.com	New York	New York	502016151046477	3cad1ceae96e369344bba29c4fdbae4b	VISA 13 digit	40.6597135484907781	-74.0306054299127254
35606	2020-07-07 03:55:12	2020-07-07	Luther Hyatt	luther.hyatt@warmmail.com	Pittsburgh	Pennsylvania	4180831849383369	491573d459f9f8ef3fbbc1f700c4d03f	JCB 16 digit	40.5240497752979394	-79.8815973451998076
35607	2020-07-07 04:04:26	2020-07-07	Natalya Swaniawski-Pouros	natalya.swaniawski.pouros@geemail.com	Nashville	Tennessee	501853010501376	26ddfd6d748316a1d9c8d25bb9da4598	Discover	36.2173733216833327	-86.8144736281968648
35608	2020-07-07 04:07:15	2020-07-07	Red Kihn	red.kihn@warmmail.com	Port St. Lucie	Florida	503812730490229	0d27cb96362948eee9192972ca4c2db9	JCB 16 digit	27.2561084408912819	-80.4061753233049075
35609	2020-07-07 04:10:25	2020-07-07	Beadie Anderson	beadie.anderson@warmmail.com	New York	New York	3400372412508445	a1e91f4367ed779ad809ff3984cca800	JCB 15 digit	40.6344561826661206	-73.9394839799392969
35610	2020-07-07 04:13:26	2020-07-07	Shirley Spencer	shirley.spencer@geemail.com	Palmdale	California	869945169852802677	6a56c693cc0070ee195b3aef08c784f6	Discover	34.6655549574494373	-118.099540225276357
35611	2020-07-07 04:13:41	2020-07-07	Madonna Muller MD	madonna.muller.md@geemail.com	New York	New York	4165512552127	711bfe09be3009403aab0d2db9906769	VISA 16 digit	40.7097354465387724	-74.0024751420028508
35612	2020-07-07 04:16:22	2020-07-07	Finley Ullrich DDS	finley.ullrich.dds@geemail.com	Durham	North Carolina	4683857537984434	10993c8578f835e886207e982ab21ee5	Diners Club / Carte Blanche	35.9462109082624295	-78.9191259703502084
35613	2020-07-07 04:17:25	2020-07-07	Ione Nader	ione.nader@geemail.com	Odessa	Texas	3158277339100746559	95b8efa591a78e2d69cc28a8a743664d	Discover	31.8991248946648085	-102.330982247662163
35614	2020-07-07 04:22:12	2020-07-07	Otha Thompson	otha.thompson@warmmail.com	Clovis	California	210028486317654753	517396456ed8abfac27b963dab5c58fa	Discover	36.8896978987723614	-119.617824499781804
35615	2020-07-07 04:23:20	2020-07-07	Tamekia Zboncak	tamekia.zboncak@geemail.com	San Francisco	California	4659369660835	39981fd2a6b69780cb44d971ba3e7205	Discover	37.7719466584663479	-122.41865083555183
35616	2020-07-07 04:29:15	2020-07-07	Kris Rippin	kris.rippin@geemail.com	San Francisco	California	4895764794939891	b6c22b8f87b557a59f54fe8419986307	JCB 15 digit	37.7736490067032165	-122.483799538305945
35617	2020-07-07 04:29:37	2020-07-07	Carmelo Beer III	carmelo.beer.iii@woohoo.com	Ann Arbor	Michigan	4132329332054976	7ac9e0e57d68bf89779e83fb949fa010	VISA 16 digit	42.3231278316643085	-83.6995421507503892
35618	2020-07-07 04:33:06	2020-07-07	Breanna Kris PhD	breanna.kris.phd@geemail.com	Tallahassee	Florida	6011193247624630905	48990902f82a17d78c84fa013cabd616	VISA 16 digit	30.4201655859150009	-84.1957861192073693
35619	2020-07-07 04:33:37	2020-07-07	Neha Hudson	neha.hudson@geemail.com	Long Beach	California	180075105772445034	f0f6bf56a75a0c4bbc956433ab0d2749	Mastercard	33.8366005742277949	-118.217260633285335
35620	2020-07-07 04:43:26	2020-07-07	Ginny Hilpert	ginny.hilpert@warmmail.com	Clearwater	Florida	3158623510284254013	68ccc09632b9cac551000e1f72b6a2a8	Mastercard	27.8907624451570193	-82.6925283409453868
35621	2020-07-07 04:50:25	2020-07-07	Mrs. Mackenzie Reilly DVM	mrs.mackenzie.reilly.dvm@geemail.com	New York	New York	3528549966527106819	18dd2ad7102c989fe79fcfd3014f7958	JCB 16 digit	40.7008088572174316	-73.9545505894709407
35622	2020-07-07 04:56:26	2020-07-07	Rich Gaylord	rich.gaylord@warmmail.com	Boston	Massachusetts	4612519618617	40cff753602cc0df5efd73a4744c0a40	JCB 16 digit	42.3219562808684984	-70.9724733640857011
35623	2020-07-07 05:04:12	2020-07-07	Kody Goyette-Durgan	kody.goyette.durgan@woohoo.com	Vista	California	3158641032386413080	e177e576856fd9b8aa7322b0c1e10bdc	JCB 16 digit	33.1038960395362238	-117.281001840072136
35624	2020-07-07 05:09:19	2020-07-07	Phoenix VonRueden	phoenix.vonrueden@geemail.com	Albuquerque	New Mexico	3158248177559282957	9e4487a97a4be534c5c8bb6f020a086d	Mastercard	35.091281255534291	-106.60210912335441
35625	2020-07-07 05:16:52	2020-07-07	Kiley Kris	kiley.kris@geemail.com	Los Angeles	California	502056422455644	b353df306f37c5d411f76e3d7d5689ad	VISA 16 digit	34.0929856512095739	-118.438479939009241
35626	2020-07-07 05:22:46	2020-07-07	Kasen Lockman	kasen.lockman@geemail.com	Mesa	Arizona	676336371071022	22c66bfeaf105bf374b8238e8fa338ea	VISA 16 digit	33.4329499144252367	-111.661027690989528
35627	2020-07-07 05:26:09	2020-07-07	Junie Ritchie	junie.ritchie@woohoo.com	New York	New York	3088963910860779953	a00c2a036729c5f75315732c799dd6a2	JCB 16 digit	40.5701261180210864	-73.9190481503855352
35628	2020-07-07 05:32:43	2020-07-07	Gayle Lynch-Kshlerin	gayle.lynch.kshlerin@geemail.com	Boston	Massachusetts	3030762294635938	b337d995fce4942066a29f3b21b875f0	Discover	42.2981893019918331	-71.0436512439928975
35629	2020-07-07 05:38:20	2020-07-07	Dr. Peyton Marvin	dr.peyton.marvin@woohoo.com	Oklahoma City	Oklahoma	3405266401727799	f8e80fc8693c97e8e5c18bf20d79739e	Voyager	35.4495810228310546	-97.5613780930534062
35630	2020-07-07 05:38:53	2020-07-07	Danniel Weber	danniel.weber@woohoo.com	Detroit	Michigan	4021729567202	cc139acc4b9fced4ee8cb7a821ebed3e	JCB 16 digit	42.3797933974694487	-83.0911082500245328
35631	2020-07-07 05:52:55	2020-07-07	Alex Bernhard	alex.bernhard@geemail.com	Fort Collins	Colorado	3480084325153812	40e136fdc2a98f402ce547ea434a28f5	JCB 16 digit	40.5920395014032707	-105.060941860960057
35632	2020-07-07 06:00:33	2020-07-07	Dr. Kem Heaney DVM	dr.kem.heaney.dvm@woohoo.com	New York	New York	6011741431720959171	634ab2c7ef8832bb2901febec2b6eef2	Discover	40.6843811940625315	-73.8553366706136529
35633	2020-07-07 06:06:52	2020-07-07	Albertine Lehner	albertine.lehner@geemail.com	San Francisco	California	3426968721717161	ac26c0c1330bf8061c1cfbad658e477a	American Express	37.7592485135451881	-122.431682332552711
35634	2020-07-07 06:11:26	2020-07-07	Carleigh Runte PhD	carleigh.runte.phd@geemail.com	Fremont	California	54891283255057055	bd67c64852772d0ecbf9fdc88255f7a2	Mastercard	37.4039474374316683	-121.90124503099247
35635	2020-07-07 06:23:15	2020-07-07	Berton Greenholt	berton.greenholt@geemail.com	Corpus Christi	Texas	4818911784467318	295f5e1318484aeff8ff302232698dc6	Voyager	27.7343333148334175	-97.0944897836834144
35636	2020-07-07 06:27:07	2020-07-07	Beckie Waters	beckie.waters@warmmail.com	Plano	Texas	869939706934866812	7c9c3b37db4ceab82ac0705f6eda2786	JCB 16 digit	33.0034670278515705	-96.8288707040432826
35637	2020-07-07 06:38:52	2020-07-07	Adele Ankunding	adele.ankunding@geemail.com	Houston	Texas	3705437175612455	7cd2061c12dc4634e6d736c520033e9f	Voyager	29.798355844857543	-95.3092965050615391
35638	2020-07-07 06:39:37	2020-07-07	Estill Armstrong-Hane	estill.armstrong.hane@woohoo.com	New York	New York	3337586338469883496	87f4560caf7478b068848be8026a19a3	Diners Club / Carte Blanche	40.7308051158431894	-73.8941095380939572
35639	2020-07-07 06:44:37	2020-07-07	Ms. Paulette Turner PhD	ms.paulette.turner.phd@warmmail.com	San Francisco	California	869951923474118024	0a99cc2191adbd4d10b9f9a98f1f7331	JCB 16 digit	37.7713217040564899	-122.430774356777476
35640	2020-07-07 06:56:27	2020-07-07	Miss Ammie Bahringer	miss.ammie.bahringer@geemail.com	New York	New York	53595516414295705	814400969342937cec5f42614ac278c7	JCB 16 digit	40.73207135812752	-74.0187478986464384
35641	2020-07-07 07:03:14	2020-07-07	Gennie O'Conner	gennie.o'conner@geemail.com	Simi Valley	California	4021076227413981	9520b00c210b38f6779c068ffff4fb8a	JCB 15 digit	34.1924256282165615	-118.660896153248856
35642	2020-07-07 07:04:25	2020-07-07	Janessa Mann	janessa.mann@woohoo.com	San Francisco	California	3474807340359446	08a5740465972c7e13b71fb1b69cb1c8	American Express	37.7701467644966939	-122.443494763339061
35643	2020-07-07 07:05:57	2020-07-07	Alexis Wyman	alexis.wyman@warmmail.com	San Antonio	Texas	4589259748188076	067f787a78f24cdcf7ac4dafb390ac3f	JCB 16 digit	29.5242422858323899	-98.5918553292587347
35644	2020-07-07 07:08:51	2020-07-07	Armond Hackett	armond.hackett@geemail.com	Omaha	Nebraska	4038368093713334	349f9bad18a00fb63a8617270ffdbde7	JCB 16 digit	41.3626190865091985	-96.0820173387996874
35645	2020-07-07 07:13:11	2020-07-07	Mikayla Ward-Larkin	mikayla.ward.larkin@warmmail.com	Los Angeles	California	869906177500567938	07dc1b8c0bf5c67807b023030fc13c3e	VISA 16 digit	34.0721388523798439	-118.42883381172939
35646	2020-07-07 07:25:26	2020-07-07	Carmel Lebsack	carmel.lebsack@geemail.com	San Francisco	California	3528990625747791651	5c715d232a160c96e1fb692c8374e3e4	Mastercard	37.7600388398300808	-122.425919841891627
35647	2020-07-07 07:26:17	2020-07-07	Carson Feil-Rau	carson.feil.rau@geemail.com	Worcester	Massachusetts	869932054735773193	760a94911a5fd18051d3cfa048ad4299	VISA 16 digit	42.3093421403486261	-71.8780433387748872
35648	2020-07-07 07:28:23	2020-07-07	Vassie Mosciski	vassie.mosciski@geemail.com	Little Rock	Arkansas	3472049470684648	08f304a767c2d97517e8045504bddfbe	Mastercard	34.6327375697247675	-92.387106286721675
35649	2020-07-07 07:41:21	2020-07-07	Bryon Will	bryon.will@geemail.com	San Francisco	California	4969963754995	fff8852f56a482ce92ff0882d5769445	American Express	37.792695938485906	-122.44063902227407
35650	2020-07-07 07:46:47	2020-07-07	Mrs. Tracey Hayes	mrs.tracey.hayes@geemail.com	Chicago	Illinois	501802944548847	729da1cabc4bcb29b837240aa27dc952	VISA 13 digit	41.8836297343321178	-87.7104240527871895
35651	2020-07-07 07:55:54	2020-07-07	Sylvan Collier Sr.	sylvan.collier.sr.@geemail.com	New York	New York	3088036571462207810	ec1d81a7713b9c8a23f08920820461eb	American Express	40.6002725763004264	-74.0086648431967973
35652	2020-07-07 08:01:30	2020-07-07	Nona Ebert	nona.ebert@geemail.com	Bakersfield	California	869981406599906568	d6d184580088bf64580c9424de57811d	Maestro	35.3728732364427287	-119.030599046013506
35653	2020-07-07 08:03:33	2020-07-07	Irvin O'Keefe	irvin.o'keefe@woohoo.com	Fayetteville	North Carolina	4059732075302909	6cc44eb26fdb2af772c225a748c1326e	American Express	35.0728402731262108	-78.900304909901692
35654	2020-07-07 08:20:02	2020-07-07	Tavion Schmitt	tavion.schmitt@geemail.com	Chicago	Illinois	210035854660460576	a97ab5f31eaa0a0c7c4c69b29b0feffb	VISA 16 digit	41.8815497657120233	-87.611112718287103
35655	2020-07-07 08:31:51	2020-07-07	Jeanna Baumbach	jeanna.baumbach@warmmail.com	Frisco	Texas	3528015316623074203	92bab16665bc4c12436271caf6b54a4f	Voyager	33.1628779908172788	-96.8129307643718988
35656	2020-07-07 08:36:07	2020-07-07	Sylvia Price	sylvia.price@warmmail.com	New York	New York	4450707834041092	d95cd195811e8004f9c00a62c7860c4f	JCB 16 digit	40.6412875322382874	-74.0129146496661008
35657	2020-07-07 08:36:23	2020-07-07	Dr. Josef McLaughlin	dr.josef.mclaughlin@geemail.com	West Palm Beach	Florida	3457040738686649	12d56aa3a4a34e04ca994ec94ba8b1cf	JCB 15 digit	26.7512847616650191	-80.119917620515821
35658	2020-07-07 08:48:23	2020-07-07	Dr. Milford Weimann II	dr.milford.weimann.ii@woohoo.com	Los Angeles	California	180053535910548131	90e6bb594093ab46b390645cd5662dd5	Diners Club / Carte Blanche	34.0370097283139827	-118.44287886442541
35659	2020-07-07 09:00:29	2020-07-07	Cleta Schmeler-Brown	cleta.schmeler.brown@geemail.com	Reno	Nevada	3014204676979168	1e274a80e43f766ec2a5021527ee4f86	VISA 16 digit	39.4973968316413462	-119.872247556054603
35660	2020-07-07 09:02:22	2020-07-07	Tab Ondricka-Hoeger	tab.ondricka.hoeger@geemail.com	Boston	Massachusetts	6011667835776525092	00f1724526e73fa9d87ca1b48ce95320	Maestro	42.267110001079736	-70.9453054146327133
35661	2020-07-07 09:27:00	2020-07-07	Clifton McDermott	clifton.mcdermott@warmmail.com	Phoenix	Arizona	4958301274840	6e78dc4ddf8098fd66ca7e4ff7bf8146	JCB 15 digit	33.5321686263594785	-112.130330211569003
35662	2020-07-07 09:42:23	2020-07-07	Dr. Dino Weber	dr.dino.weber@woohoo.com	San Antonio	Texas	4116890472891	e51aceb9e7a7d902b1087ff540718e96	Voyager	29.4049361730065186	-98.4651580705143488
35663	2020-07-07 10:01:56	2020-07-07	Arvo Green-Carter	arvo.green.carter@geemail.com	Pompano Beach	Florida	4195338874014284	6f1bedeee723a11d13803c1cc384f024	JCB 16 digit	26.1436434856414763	-80.2020303699500801
35664	2020-07-07 10:05:50	2020-07-07	Dr. Randall Ortiz	dr.randall.ortiz@geemail.com	McKinney	Texas	4334865833096384	6d76202930c0e5158cbef70800691292	VISA 16 digit	33.2342847810257283	-96.6783019366506551
35665	2020-07-07 10:08:41	2020-07-07	Beckham Weissnat	beckham.weissnat@geemail.com	Sioux Falls	South Dakota	3019506292038855	42eb2ac0215b46255106c82a2df5b6bb	JCB 16 digit	43.5677042047578809	-96.636060396738344
35666	2020-07-07 10:12:44	2020-07-07	Hassan Kovacek	hassan.kovacek@warmmail.com	Richmond	California	6011487845358052744	0238d7c4c20383bdbed4d2417be7f59b	JCB 16 digit	37.9750801123168316	-122.383362119909748
35667	2020-07-07 10:28:11	2020-07-07	Roxann Hansen	roxann.hansen@geemail.com	Washington	District of Columbia	4249488579347095	9ae9203a16c956fba71b32c35481e5c0	Voyager	38.9767785991340858	-77.0374898788265909
35668	2020-07-07 10:29:30	2020-07-07	Azaria Goodwin	azaria.goodwin@geemail.com	Augusta	Georgia	3014502891198468	1643bc3aa4e91db53ab3fe999b723ce8	JCB 16 digit	33.3695314770769329	-82.0946238535285033
35669	2020-07-07 10:36:37	2020-07-07	Nash Dickens	nash.dickens@geemail.com	Las Vegas	Nevada	54849812833797023	f9db6799ba183cea0860ee1cf6add148	JCB 16 digit	36.2738646792814095	-115.165292639539018
35670	2020-07-07 10:46:06	2020-07-07	Akeem Bode-Beier	akeem.bode.beier@geemail.com	Arlington	Texas	3780588185078166	d8c2630cbc7f0f440a554ed78a227b3a	VISA 16 digit	32.6990905100729279	-97.0547441007129947
35671	2020-07-07 10:53:28	2020-07-07	Edwina Howell	edwina.howell@woohoo.com	Tucson	Arizona	54375095202695745	0dabd8675bbc823782414060884d2b1d	Discover	32.0976238822605495	-110.911825788276644
35672	2020-07-07 10:59:30	2020-07-07	Dr. Lea Daniel IV	dr.lea.daniel.iv@warmmail.com	Baton Rouge	Louisiana	675915012478317	c9ed16f3ed368c084103ee7bf0f2bd65	JCB 16 digit	30.4260472758419809	-91.1939863159894912
35673	2020-07-07 11:05:45	2020-07-07	Mrs. Reyna Baumbach DVM	mrs.reyna.baumbach.dvm@woohoo.com	Houston	Texas	4085643411145092	f69e74c1895c9a9371280bcb141b2d03	VISA 16 digit	29.7027650721915073	-95.2999316787362147
35674	2020-07-07 11:08:29	2020-07-07	Chloe McCullough-Kuhlman	chloe.mccullough.kuhlman@warmmail.com	San Francisco	California	869902960888139675	869aab72ffe0d90fc4db0c5e7d149b20	JCB 16 digit	37.7582988308418237	-122.451180988193016
35675	2020-07-07 11:15:38	2020-07-07	Miss Ana D'Amore	miss.ana.d'amore@geemail.com	Greensboro	North Carolina	4329387997505420	2602a2051e5c049da314e5e7480d59de	Diners Club / Carte Blanche	36.1867399321053185	-79.7626370999012124
35676	2020-07-07 11:26:41	2020-07-07	Linzy Reinger	linzy.reinger@geemail.com	Anaheim	California	6011084203757005201	1f5bd0d5a628096365438ac890e08e8e	JCB 16 digit	33.7815305779520401	-117.713435080388933
35677	2020-07-07 11:41:12	2020-07-07	Maddox Will	maddox.will@warmmail.com	Seattle	Washington	52238484524229390	5b252df7886df07885eaaa7097cc6acd	Discover	47.5500090320054412	-122.385068410766863
35678	2020-07-07 11:41:37	2020-07-07	Dr. Devin Paucek Jr.	dr.devin.paucek.jr.@geemail.com	Berkeley	California	4826870651608729	383c7e54bd4099ab3573a69ab85d4a1d	Mastercard	37.8625640580559306	-122.25909101377772
35679	2020-07-07 11:49:05	2020-07-07	Jordin Kerluke	jordin.kerluke@geemail.com	Phoenix	Arizona	869998108753075989	c7571eb3764aba6a333610d07887af90	VISA 16 digit	33.5748906822808095	-112.047040036965541
35680	2020-07-07 12:05:06	2020-07-07	Lennon Barton	lennon.barton@geemail.com	San Francisco	California	180026506512898103	a1a276aa6f87497480d35f1525cede19	VISA 16 digit	37.8041378507811814	-122.449101087806611
35681	2020-07-07 12:07:12	2020-07-07	Jaidyn Hodkiewicz	jaidyn.hodkiewicz@geemail.com	Garland	Texas	6011354053380288184	d9aaf87ff10294c9bae62c4cc91ccafb	Diners Club / Carte Blanche	33.0027277413524658	-96.696328550220656
35682	2020-07-07 12:11:51	2020-07-07	Albin Hansen	albin.hansen@geemail.com	Pembroke Pines	Florida	589326179218198	2ed54b7c61e05f97a614db9e66ca493f	JCB 15 digit	26.1167575594540686	-80.3805770098134929
35683	2020-07-07 12:16:05	2020-07-07	Sylva Renner MD	sylva.renner.md@woohoo.com	Bellevue	Washington	6011865515263237571	86dea8622c0fcf4237a7fa210751ee8b	American Express	47.5065467057000888	-122.105388955730945
35684	2020-07-07 12:23:31	2020-07-07	Willian King	willian.king@geemail.com	Seattle	Washington	4143397886734738	f7880de0f068c04873f9df15afedcc57	VISA 16 digit	47.6220264824032782	-122.378814783405133
35685	2020-07-07 12:24:06	2020-07-07	Loula Wehner	loula.wehner@geemail.com	Knoxville	Tennessee	3528063664960314430	9628b8f31ff9043db4d28b1b756fcb90	Mastercard	35.9246751461241374	-83.8661669570703054
35686	2020-07-07 12:25:51	2020-07-07	Mr. Marlyn Jakubowski III	mr.marlyn.jakubowski.iii@geemail.com	San Francisco	California	4099780890470676	41f91e60a49a25ffad1a86a00714ae08	Mastercard	37.7866227819353497	-122.415766826717757
35687	2020-07-07 12:31:11	2020-07-07	Dr. Maddox Hand II	dr.maddox.hand.ii@geemail.com	Lafayette	Louisiana	630489646906860	dd14386542c06a116c2afa624c72981c	VISA 16 digit	30.1529938098952179	-91.9962780146244796
35688	2020-07-07 12:49:35	2020-07-07	Lonna Kunde MD	lonna.kunde.md@geemail.com	Stockton	California	6011260344634801952	c82d9a0c2d45945ab8b198d35d977b5d	VISA 16 digit	37.9499147952266043	-121.332351925232629
35689	2020-07-07 12:56:16	2020-07-07	Dr. Tanja Ryan	dr.tanja.ryan@geemail.com	West Covina	California	869969421414941662	f2c4e1e8fa129ccf0742a2efb0446137	Discover	33.9736896508947055	-117.982574303082743
35690	2020-07-07 13:02:55	2020-07-07	Brock Macejkovic	brock.macejkovic@geemail.com	St. Louis	Missouri	3096411258306217636	2b751d7bbbb2aacdce23bd289785ba82	American Express	38.5765514376264065	-90.3397272249221857
35691	2020-07-07 13:03:57	2020-07-07	Cleva Gottlieb	cleva.gottlieb@geemail.com	Memphis	Tennessee	3401625237005627	3de77c012adedc1851cdb5b04355e83c	Discover	35.0583770209059153	-89.9004019654612989
35692	2020-07-07 13:08:03	2020-07-07	Halsey Kris	halsey.kris@warmmail.com	Las Cruces	New Mexico	52618619951367292	1d01aeaf1ec6ab0439e36e2034d6d293	Voyager	32.3220919198390106	-106.887863177911186
35693	2020-07-07 13:13:53	2020-07-07	Mr. Austin Bosco	mr.austin.bosco@geemail.com	San Francisco	California	54031762465956959	311fa310b6b2797854d1d1a8416be83e	VISA 13 digit	37.7504550920824613	-122.455196726338244
35694	2020-07-07 13:20:11	2020-07-07	Rylee Miller	rylee.miller@warmmail.com	Fort Wayne	Indiana	3421205556344620	7219f9fadb0e402da54cf4ef64d595f6	Diners Club / Carte Blanche	41.0491841792844241	-85.1558319061282987
35695	2020-07-07 13:24:04	2020-07-07	Ms. Dahlia Bosco MD	ms.dahlia.bosco.md@geemail.com	Indianapolis	Indiana	3528204696042816644	ccf6a7e13e4819af8e18739e8ef91ba1	Mastercard	39.7078633985955278	-86.0826130361497377
35696	2020-07-07 13:43:43	2020-07-07	Emmit Padberg	emmit.padberg@geemail.com	Oakland	California	3088582785761547274	587b977a1d45d6fddefc06228c5f3079	Maestro	37.7667876501039004	-122.251644316390681
35697	2020-07-07 13:44:00	2020-07-07	Josephus Waters Sr.	josephus.waters.sr.@warmmail.com	Roseville	California	869953837258829564	529c57179ed4c55c805ec11e777b7350	JCB 15 digit	38.827353997068478	-121.354180213924124
35698	2020-07-07 13:47:08	2020-07-07	Romello Murphy	romello.murphy@woohoo.com	Oakland	California	3112390837625326668	7e3146b368861d2dc90047b406851945	American Express	37.7891680269063244	-122.293009779704064
35699	2020-07-07 13:57:04	2020-07-07	Krysten Paucek	krysten.paucek@warmmail.com	Fort Wayne	Indiana	4904692241134114	ac67de19326a8ffbe70331eacc1ac6a6	JCB 16 digit	41.1768880158446748	-85.2198348743595204
35700	2020-07-07 13:57:33	2020-07-07	Atlas Barton	atlas.barton@warmmail.com	League City	Texas	675936129053330	5ccde1c7470b9d1d19b0320f921ac42b	JCB 15 digit	29.4320883834663789	-95.1229827194925406
35701	2020-07-07 14:00:11	2020-07-07	Jeri Rutherford-VonRueden	jeri.rutherford.vonrueden@geemail.com	Cape Coral	Florida	869964239927371838	55eed136d6b6e0dd7a46bd867bd63f66	Diners Club / Carte Blanche	26.6196052907470602	-81.9601989116590488
35702	2020-07-07 14:11:59	2020-07-07	Nehemiah Hane-Schaden	nehemiah.hane.schaden@geemail.com	Chicago	Illinois	4542254551204	37db757601470776a6d6b108d18f55d4	Discover	41.7562971539631533	-87.6219768120005682
35703	2020-07-07 14:14:47	2020-07-07	Miss Ximena Hackett	miss.ximena.hackett@geemail.com	Oakland	California	4630937894966	ecadea4ac3e91de14c2b0de77c73e147	JCB 16 digit	37.8182279136500625	-122.279939087159562
35704	2020-07-07 14:17:02	2020-07-07	Thresa Pfeffer	thresa.pfeffer@woohoo.com	Honolulu	Hawaii	869939341071903895	be8df00171dd5cfffc1652b3b0fbd644	VISA 16 digit	21.3303248923953639	-157.947326393725717
35705	2020-07-07 14:19:14	2020-07-07	Carlotta O'Kon-Kemmer	carlotta.o'kon.kemmer@geemail.com	Escondido	California	55421053165364738	536a4076a6fa9d71db7014532f7a651a	Maestro	33.0618430563010293	-117.038425172377373
35706	2020-07-07 14:21:38	2020-07-07	Minta Fadel	minta.fadel@geemail.com	San Diego	California	869940780610602384	b8dd89e4b480dbed1a251ab9406ab197	VISA 16 digit	32.8190494561634978	-117.191676249112945
35707	2020-07-07 14:24:09	2020-07-07	Miss Zoey Herman PhD	miss.zoey.herman.phd@woohoo.com	New York	New York	869987809122327026	81b1b3318be81e581834043ce2e3a951	JCB 16 digit	40.7589755216836949	-73.8936095521215321
35708	2020-07-07 14:26:54	2020-07-07	Mr. Orvin Spinka	mr.orvin.spinka@woohoo.com	Charlotte	North Carolina	869901206638727232	c55dab8424510c9719810dc2b1265698	JCB 15 digit	35.1393396555699411	-80.8034714293144702
35709	2020-07-07 14:28:46	2020-07-07	Almeta Pouros-Johnston	almeta.pouros.johnston@warmmail.com	El Paso	Texas	6011607417051188632	9e4da8c8c19a46cd72d5422ed684669b	Diners Club / Carte Blanche	31.8348352651406081	-106.345737576110295
35710	2020-07-07 14:31:22	2020-07-07	Mr. Orlin Jones	mr.orlin.jones@geemail.com	Vancouver	Washington	3745018322609735	0d5daffdb3d0f6253ab70d3d33621767	VISA 16 digit	45.7289616858191792	-122.5618429408472
35711	2020-07-07 14:33:13	2020-07-07	Ms. Cari Hamill PhD	ms.cari.hamill.phd@geemail.com	Los Angeles	California	3088174678202765593	0cb4b74b7e54523ac78bf53929873a54	JCB 15 digit	33.9867688143491691	-118.422581239043922
35712	2020-07-07 14:45:43	2020-07-07	Mrs. Luana Walsh	mrs.luana.walsh@geemail.com	New York	New York	589326222526662	e49f02fb83b1bc0ffa71620ffc7410d9	VISA 13 digit	40.6687291705273068	-73.874291784818098
35713	2020-07-07 14:57:48	2020-07-07	Garnett Corkery PhD	garnett.corkery.phd@geemail.com	Houston	Texas	180040178982586931	bd123e235ec2c81247918d78cb2129ee	Mastercard	29.7542290796604014	-95.4289715928971845
35714	2020-07-07 15:03:13	2020-07-07	Joleen Vandervort	joleen.vandervort@geemail.com	Inglewood	California	3771022485974461	22561e9ee7f503b10b35d2a5bb62b0b6	Discover	33.9127188624594353	-118.37079866137654
35715	2020-07-07 15:23:33	2020-07-07	Danna Buckridge-Konopelski	danna.buckridge.konopelski@geemail.com	New York	New York	4389818564553515	23164ed4bf04e212d8567248bf66e801	Discover	40.6539590115882419	-74.002059144981942
35716	2020-07-07 15:25:12	2020-07-07	Dexter Abshire	dexter.abshire@warmmail.com	Miami	Florida	4142589253409354	51c3986d1f20f972c9571b1029ba1abb	Voyager	25.8601414033815296	-80.1907480929385912
35717	2020-07-07 15:26:27	2020-07-07	Dr. Wade Streich PhD	dr.wade.streich.phd@geemail.com	New York	New York	4114471784098028	423bb31fc7b8d0736d7a3a9f4c42ebce	American Express	40.7360731309503308	-73.9484582180518686
35718	2020-07-07 15:27:54	2020-07-07	Jovani Blick	jovani.blick@geemail.com	Long Beach	California	3528167738398984157	6fd5c762a1ed5246f30044c4c0161536	Maestro	33.8546427835531532	-118.113342846526947
35719	2020-07-07 15:33:54	2020-07-07	Naima Fisher DVM	naima.fisher.dvm@woohoo.com	Los Angeles	California	4439795959003837	919228b0b37f0343e6fb890086190f9e	JCB 16 digit	33.9958974730554928	-118.390127923851082
35720	2020-07-07 15:43:47	2020-07-07	Lilia Mosciski	lilia.mosciski@warmmail.com	Charleston	South Carolina	3051422801054326	db7ccdf2d02ce62c1fbe5f0d727f18b3	JCB 15 digit	32.9141715067900762	-80.0549586199373095
35721	2020-07-07 15:57:54	2020-07-07	Billy Aufderhar DDS	billy.aufderhar.dds@warmmail.com	Meridian	Idaho	3158218405989469399	e0fc9665ce582c8863db009d7bcac2e6	JCB 16 digit	43.629978762567788	-116.464883583219347
35722	2020-07-07 16:09:16	2020-07-07	Phyllis Boehm	phyllis.boehm@warmmail.com	Berkeley	California	3766973962321039	1bf652ff35ad40a83f44c6dff308f211	Mastercard	37.8918237115317496	-122.296816775361421
35723	2020-07-07 16:19:53	2020-07-07	Ms. Marisela Ferry	ms.marisela.ferry@geemail.com	Garden Grove	California	3497494309034956	4968c274e5a0d048b2f8b22946897d31	JCB 16 digit	33.7839164980512052	-117.917629436172547
35724	2020-07-07 16:37:30	2020-07-07	Mr. Tilman Orn	mr.tilman.orn@geemail.com	New York	New York	3438689242305841	7921c9caa85a2d47c398cb3271d6f636	Maestro	40.6075751893445869	-74.0257794303249597
35725	2020-07-07 16:38:35	2020-07-07	Arianna Feest	arianna.feest@geemail.com	New York	New York	3158736576312317332	94371f68963607e2dcc83a40fa5febfc	VISA 16 digit	40.6920869488492585	-73.9940869401104777
35726	2020-07-07 16:41:17	2020-07-07	Kaleena Rogahn	kaleena.rogahn@warmmail.com	Tucson	Arizona	4283515097467356	fb4e395ee19ee131ddb3c656862793a2	VISA 16 digit	32.1942175128538182	-110.945471611362322
35727	2020-07-07 16:54:22	2020-07-07	Kaylynn Stanton	kaylynn.stanton@geemail.com	Lexington	Kentucky	3112337419277028680	0efe13873d67352b2dcea46e28303bbe	Diners Club / Carte Blanche	38.0700465786147859	-84.5175973455320957
35728	2020-07-07 17:03:08	2020-07-07	Dr. Sadye Conroy	dr.sadye.conroy@warmmail.com	Virginia Beach	Virginia	4434300432887271	4a0527e9135de3fcdcbb5f8e88c44cff	JCB 16 digit	36.7813219136744749	-76.0954036141883563
35729	2020-07-07 17:09:12	2020-07-07	Clark Hilpert-Cormier	clark.hilpert.cormier@geemail.com	New York	New York	3039804284809353	fcd19c8c11f397ebf88dea9dd12f8082	JCB 15 digit	40.74799801807292	-74.0303100490838233
35730	2020-07-07 17:10:42	2020-07-07	Norval Quitzon	norval.quitzon@geemail.com	Phoenix	Arizona	52173171018946624	d004a419b6988a5df053756f7eeeddf7	JCB 16 digit	33.5304847237121351	-112.031605622165287
35731	2020-07-07 17:13:16	2020-07-07	Mr. Ernesto Douglas DDS	mr.ernesto.douglas.dds@geemail.com	Oakland	California	3025176888811638	2379e26e3a3abdebd19f21fd4d69ea25	VISA 13 digit	37.8259071845739712	-122.26723023118609
35732	2020-07-07 17:16:22	2020-07-07	Moises Armstrong IV	moises.armstrong.iv@geemail.com	San Antonio	Texas	4065409244605213	15397c214c75678ae7af8a3d925542cd	Voyager	29.5197230979871001	-98.484083191614971
35733	2020-07-07 17:24:05	2020-07-07	Germaine Miller MD	germaine.miller.md@geemail.com	Daly City	California	4054550719630658	d8905e5ac75a2a28d775fa08c68b48ad	VISA 13 digit	37.7723872592594461	-122.392750980248678
35734	2020-07-07 17:33:16	2020-07-07	Octa Bechtelar-Walsh	octa.bechtelar.walsh@geemail.com	Fresno	California	639066846020320	a04a397de3eb5fe76d8699c7da0909e7	JCB 16 digit	36.8126381011553079	-119.747059028280532
35735	2020-07-07 17:36:33	2020-07-07	Georgiann Metz	georgiann.metz@geemail.com	San Francisco	California	3158483409377021372	c2c10d7f6aba5d5fcdd8935fbcc45a21	American Express	37.772234445709465	-122.425410650878561
35736	2020-07-07 17:40:14	2020-07-07	Karol Batz-Torp	karol.batz.torp@geemail.com	San Francisco	California	4291444212187247	a9dcf6b8f5536ed79d27f1386f55079d	VISA 13 digit	37.7488873488054608	-122.420586425937316
35737	2020-07-07 17:42:19	2020-07-07	Christopher Sawayn	christopher.sawayn@geemail.com	Louisville	Kentucky	4648851795112162	d7a476a12af73e700a511ac69dc75564	American Express	38.111250878208871	-85.7345090971399202
35738	2020-07-07 17:43:14	2020-07-07	Glenna Upton-Morar	glenna.upton.morar@geemail.com	Kansas City	Missouri	3764436158696418	b21f09bf1e9c12ed8c0a311be6a9c771	JCB 16 digit	39.1728301978040534	-94.454091010218491
35739	2020-07-07 17:48:55	2020-07-07	Rodger Keebler IV	rodger.keebler.iv@woohoo.com	New York	New York	869983386735083977	5156d9f333f3405dddf1d1d4bb26b920	VISA 13 digit	40.6433775260802364	-73.9034216129582404
35740	2020-07-07 17:53:57	2020-07-07	Davin Glover-Kovacek	davin.glover.kovacek@geemail.com	San Francisco	California	503853069556552	6b35474665f156868453fdcf5ddb5e04	JCB 16 digit	37.7566017859569811	-122.439574573082893
35741	2020-07-07 18:04:04	2020-07-07	Davie Franecki-Erdman	davie.franecki.erdman@woohoo.com	San Francisco	California	4547170801600421	56beed514c22e25a09ec59953b34a1cc	VISA 16 digit	37.7588520400722274	-122.417625726464237
35742	2020-07-07 18:31:19	2020-07-07	Inez McGlynn PhD	inez.mcglynn.phd@warmmail.com	Cape Coral	Florida	869999976447591085	f6c0253e8a1d3cbc6623dc0eba562d90	Discover	26.6984667224314052	-82.003306926887106
35743	2020-07-07 18:36:57	2020-07-07	Dr. Ricci Grady	dr.ricci.grady@geemail.com	Detroit	Michigan	3337353332610497596	619c94b295c71e59f572723bc67f48d6	VISA 16 digit	42.3776750998962726	-83.0874784788235985
35744	2020-07-07 18:48:40	2020-07-07	Miss Aryanna Abbott PhD	miss.aryanna.abbott.phd@geemail.com	Virginia Beach	Virginia	869953379254927670	749939bfd198efc6e7582831308a51e5	VISA 16 digit	36.7795183723513048	-76.1007414701532525
35745	2020-07-07 18:54:56	2020-07-07	Wallace Carter-Mohr	wallace.carter.mohr@geemail.com	Houston	Texas	4879340180212	383d6eb9891dcecf96e6caf541835652	JCB 16 digit	29.8236517151430256	-95.3763707597289283
35746	2020-07-07 18:57:15	2020-07-07	Margarite Smith	margarite.smith@geemail.com	McKinney	Texas	3700125861244262	9cf5053603c6bad8837127dbdbe1a802	JCB 16 digit	33.1602471129167853	-96.6991180743388838
35747	2020-07-07 18:59:59	2020-07-07	Lilianna Ward DDS	lilianna.ward.dds@geemail.com	Albuquerque	New Mexico	869914468115171160	b7cc7a4f76663326db9ae45f1c669a37	VISA 16 digit	35.0118525561545084	-106.64831448081658
35748	2020-07-07 19:03:29	2020-07-07	Reilly Kerluke	reilly.kerluke@geemail.com	Los Angeles	California	4643128798684835	c77ca93e95fed18ed9327ed67d3eed22	American Express	33.9941547929640819	-118.458047075755147
35749	2020-07-07 19:07:36	2020-07-07	Kaleigh Haag	kaleigh.haag@geemail.com	Milwaukee	Wisconsin	503814212599105	5f6f48a11e783de9c652a862b5dc1d69	Diners Club / Carte Blanche	43.0334747323852014	-87.9047949433893052
35750	2020-07-07 19:24:17	2020-07-07	Dr. Darl Terry	dr.darl.terry@warmmail.com	Wilmington	North Carolina	869963907502192024	2debc898e2d60fe3b52b1b03285cf600	VISA 16 digit	34.1215740350827588	-77.971045601134378
35751	2020-07-07 19:26:48	2020-07-07	Elnora Hodkiewicz	elnora.hodkiewicz@geemail.com	Port St. Lucie	Florida	676250192427065	f123696aaba40e201a475de1f70b6b63	VISA 16 digit	27.3138673103548584	-80.466930140516908
35752	2020-07-07 19:28:45	2020-07-07	Dr. Britt Jerde Sr.	dr.britt.jerde.sr.@geemail.com	Macon	Georgia	4702548856757074	d5fe8e4b26a8c3284ba6ba4400d207e4	VISA 13 digit	32.7417306310508351	-83.7812927114039638
35753	2020-07-07 19:32:48	2020-07-07	Wayne Pfeffer-Prosacco	wayne.pfeffer.prosacco@woohoo.com	Fresno	California	210069379882912963	df1830d8ee81afa477e6a71b9ea00854	Discover	36.6907430706419078	-119.703326841361459
35754	2020-07-07 19:33:15	2020-07-07	Ayden Bailey	ayden.bailey@geemail.com	Savannah	Georgia	3006212395565489	bed597c41a6a0d748bed9e9d117d6334	Mastercard	31.9641878471802912	-81.0707705845277786
35755	2020-07-07 19:42:38	2020-07-07	Dr. Savon Becker	dr.savon.becker@geemail.com	Tampa	Florida	4292246748087935	a6189f7d020e4dc63c1213ad4a35836f	American Express	27.8872125545632095	-82.5792905345771402
35756	2020-07-07 19:46:27	2020-07-07	Delos Mann	delos.mann@geemail.com	Columbus	Ohio	3045567118510604	2a68cd3605703548233f58dafa997820	JCB 16 digit	39.967594374068824	-83.0425073448337656
35757	2020-07-07 19:49:45	2020-07-07	Yajaira Torp-Murray	yajaira.torp.murray@warmmail.com	Miami	Florida	180023986631806919	1a05b8669a2c1f1a87e3efb96e99e97f	Mastercard	25.7068355363465848	-80.2112688949205079
35758	2020-07-07 19:58:49	2020-07-07	Shirleen Halvorson	shirleen.halvorson@geemail.com	Elgin	Illinois	4596075125360943	9b5ae00d065c1266a06d225c7635189e	VISA 16 digit	41.9999873732034104	-88.3452125143546709
35759	2020-07-07 20:09:01	2020-07-07	Mila Quigley	mila.quigley@geemail.com	Honolulu	Hawaii	3040179195513231	d76b266cb6ea1b211041fce8c5c8ce9a	JCB 16 digit	21.2894603838428864	-157.945276047170523
35760	2020-07-07 20:10:17	2020-07-07	Abigayle Haley	abigayle.haley@geemail.com	Charlotte	North Carolina	3112293581737744347	e3ed5164986da3ee8802a193f97cfabc	JCB 15 digit	35.1154470576226672	-80.8142276808563622
35761	2020-07-07 20:16:58	2020-07-07	Chandler Ryan	chandler.ryan@geemail.com	Scottsdale	Arizona	4614821214724046	5a12ce2faf7a5e01e6713cb44023a1a8	American Express	33.6519724411547188	-111.898473786047091
35762	2020-07-07 20:17:38	2020-07-07	Delphia Denesik PhD	delphia.denesik.phd@geemail.com	Anchorage	Alaska	3112029763343211546	21bb2b89cc6b38b7aae6dc7f46a73298	Voyager	61.1105098127137865	-149.243315142964207
35763	2020-07-07 20:19:09	2020-07-07	Zandra Parker	zandra.parker@geemail.com	Berkeley	California	675959706669914	cda5d2273f4f2a50afb4bf2d8af96bf4	Diners Club / Carte Blanche	37.874255550195258	-122.266250949615838
35764	2020-07-07 20:19:42	2020-07-07	Janene Stoltenberg	janene.stoltenberg@warmmail.com	San Francisco	California	3528008232399370577	e6f1a91a4e839660edbb37c3ede35c12	Discover	37.8086746624179355	-122.427823822087646
35765	2020-07-07 20:36:39	2020-07-07	Saint Larson	saint.larson@geemail.com	Houston	Texas	3737004068058931	1d3eb61894162440c31b5a72872633a7	Discover	29.7701566671099513	-95.449995679176979
35766	2020-07-07 20:41:01	2020-07-07	Cinthia Hoeger MD	cinthia.hoeger.md@geemail.com	Washington	District of Columbia	3052176089520932	fdc09476cf38f2831ce29d19dcd5265b	JCB 16 digit	38.8254565225247319	-77.0723851771771962
35767	2020-07-07 20:50:08	2020-07-07	Dr. Ace Funk PhD	dr.ace.funk.phd@geemail.com	Toledo	Ohio	3432275954742540	f45b144deb97c37e62a70e88923f7077	JCB 16 digit	41.7335654681719816	-83.5488830885715856
35768	2020-07-07 20:56:35	2020-07-07	Hildegard Lowe	hildegard.lowe@geemail.com	Boston	Massachusetts	869903078360193836	2a3f2017f316d95f09ef6be6a14e7a32	American Express	42.3881955077573664	-70.9949547991108147
35769	2020-07-07 21:13:13	2020-07-07	Mrs. Heidy Bode	mrs.heidy.bode@geemail.com	Reno	Nevada	3528779736811150232	8ce5c1c77df9c66123457d36f952c1b3	JCB 16 digit	39.6001851629078416	-119.835773127169915
35770	2020-07-07 21:18:37	2020-07-07	Allisson Bauch DDS	allisson.bauch.dds@geemail.com	Ontario	California	4302479349195975	1f52193488c96637c966477d9cabb076	VISA 16 digit	34.11393402155079	-117.576523468793184
35771	2020-07-07 21:20:07	2020-07-07	Juana Konopelski-Kshlerin	juana.konopelski.kshlerin@woohoo.com	Fort Collins	Colorado	6011844058687921492	1b24bb31b6dd9c7513cb3422e3963345	Maestro	40.5162263963993681	-105.131013220404469
35772	2020-07-07 21:20:12	2020-07-07	Dewitt Dickens	dewitt.dickens@warmmail.com	New York	New York	3096849190086892639	22876374533c68fe658e64d7bc2c9ced	JCB 16 digit	40.6276098612919441	-73.9431850836042344
35773	2020-07-07 21:26:51	2020-07-07	Adam Leffler	adam.leffler@geemail.com	Orlando	Florida	6011056692838165964	cc5ffa987adab3bd6481332e84e9c332	Discover	28.3410446961674829	-81.1839625107090939
35774	2020-07-07 21:35:33	2020-07-07	Derik Moore	derik.moore@woohoo.com	Phoenix	Arizona	3042458213193962	9ef5307be71a8290a0ae8bd20f214319	VISA 16 digit	33.6428896711140908	-112.012572297307116
35775	2020-07-07 21:40:14	2020-07-07	Nathan Wehner	nathan.wehner@geemail.com	Joliet	Illinois	6011251062437281781	402f38a255bcad1ab30a7b309b2c3f34	VISA 16 digit	41.5825685895837793	-88.1083056637655915
35776	2020-07-07 21:41:01	2020-07-07	Sherita Kulas	sherita.kulas@geemail.com	Springfield	Massachusetts	3096578899997622243	fd01933e4a5f4a6e6ddc02ce8d02170a	VISA 13 digit	42.0954295152537483	-72.5781465828511898
35777	2020-07-07 21:50:44	2020-07-07	George Feil	george.feil@geemail.com	El Paso	Texas	3088507708884658952	b3a20d99d87883fcb8d8fd6ddda4aa6a	Diners Club / Carte Blanche	31.9205610022243143	-106.412542635573075
35778	2020-07-07 21:55:10	2020-07-07	Ms. Tanisha Schumm DDS	ms.tanisha.schumm.dds@geemail.com	Thornton	Colorado	3776065711245458	a2e09501fea6cea9b041ccc60ce9fdc8	JCB 15 digit	39.8618133454915196	-105.009401164080202
35779	2020-07-07 22:00:07	2020-07-07	Kaye Roob	kaye.roob@geemail.com	Cincinnati	Ohio	3014359952945679	ba67a4a262e4bdd4ecbc32f7ca0607a7	VISA 16 digit	39.1371209118280561	-84.4613058782454544
35780	2020-07-07 22:06:40	2020-07-07	Kadin McCullough	kadin.mccullough@warmmail.com	Dayton	Ohio	3793166033523496	15194681607cf6ea31e8b37f3dd44470	Diners Club / Carte Blanche	39.7890143167950185	-84.2384312468305296
35781	2020-07-07 22:07:15	2020-07-07	Mitzi Buckridge	mitzi.buckridge@geemail.com	Pomona	California	4340996888509237	bb988f550b3d357d9ff0a06301941b4e	VISA 16 digit	34.0639407366551481	-117.717746636687224
35782	2020-07-07 22:08:51	2020-07-07	Miss Savilla Pacocha	miss.savilla.pacocha@geemail.com	San Diego	California	4251746939212092	4fc56376feafc00e0f2a34bd6e35d9ec	Discover	32.7284940568797325	-117.175284992288809
35783	2020-07-07 22:09:31	2020-07-07	Hailee Wunsch	hailee.wunsch@geemail.com	Lansing	Michigan	3743117563975367	2df576e2a10800880c9f93daf2e8ec4d	Mastercard	42.6195969174459606	-84.5391936821054628
35784	2020-07-07 22:14:48	2020-07-07	Dr. Tosha O'Conner MD	dr.tosha.o'conner.md@woohoo.com	San Francisco	California	3158494996630686337	e1de03b2ae620f346bee897cc193a3e2	Voyager	37.7753495855876409	-122.408509289229727
35785	2020-07-07 22:17:38	2020-07-07	Miss Kadijah Gislason DVM	miss.kadijah.gislason.dvm@geemail.com	Visalia	California	639020095142087	a842b88c66b8f2d29f656482541b8d77	Diners Club / Carte Blanche	36.2538531327575484	-119.307809604437651
35786	2020-07-07 22:19:09	2020-07-07	Jarred Konopelski	jarred.konopelski@warmmail.com	Reno	Nevada	3021792823083085	7c6059af3837cddc8b0732e238a6fc87	Mastercard	39.6181772245172468	-119.945132620695617
35787	2020-07-07 22:37:33	2020-07-07	Tyree Skiles	tyree.skiles@woohoo.com	Fort Worth	Texas	869962937525351795	9054e5977663bea8ee24b4887ccbc21d	Diners Club / Carte Blanche	32.7666087201386702	-97.2770496510256066
35788	2020-07-07 22:46:46	2020-07-07	Dr. Frank Johns DDS	dr.frank.johns.dds@geemail.com	Chicago	Illinois	4226363853525970	89478a2b6d8b884c454cdc74e4433685	Maestro	41.7618135676555369	-87.6700958451285857
35789	2020-07-07 22:46:55	2020-07-07	Lottie Barton	lottie.barton@geemail.com	Los Angeles	California	3112773337865170626	5554aff9eb2456e07b9b50ce635caee3	Discover	34.0706305505108062	-118.458180391415198
35790	2020-07-07 22:47:38	2020-07-07	Irena Hodkiewicz DDS	irena.hodkiewicz.dds@woohoo.com	New York	New York	210075690168197968	70bb99a151f57360964ff36b14f43d2a	Mastercard	40.622345542185009	-73.9856661890063378
35791	2020-07-07 22:49:53	2020-07-07	Mrs. Biddie Champlin DDS	mrs.biddie.champlin.dds@geemail.com	Toledo	Ohio	3032835909471457	62a5800ed15d078d8a8422d013821b50	Diners Club / Carte Blanche	41.5906654747839966	-83.5194465170946074
35792	2020-07-07 22:58:10	2020-07-07	Merri Parker	merri.parker@geemail.com	Fullerton	California	4685258968110060	2935ec5d82072e77939d9f387d598a60	Discover	33.9693536644026608	-117.918430296352128
35793	2020-07-07 23:05:41	2020-07-07	Dr. Amy Romaguera	dr.amy.romaguera@geemail.com	Edison	New Jersey	180053162499286007	1b492783e6034967fdca312925e7f449	JCB 16 digit	40.4491821219641707	-74.3434534250345109
35794	2020-07-07 23:20:18	2020-07-07	Dr. Izaiah Schuppe	dr.izaiah.schuppe@geemail.com	Orlando	Florida	3005507739228673	ff5bb2c512f4b200907c27fd9fc7ce71	JCB 16 digit	28.3940795475881522	-81.1840670105502085
35795	2020-07-07 23:26:16	2020-07-07	Miss Ayana Schamberger DVM	miss.ayana.schamberger.dvm@geemail.com	Houston	Texas	180005111052880309	ce3c108d11fb5427bd3b30f1265ac140	JCB 16 digit	29.691914883869142	-95.340527787619834
35796	2020-07-07 23:29:06	2020-07-07	Bobby Wilderman	bobby.wilderman@geemail.com	Scottsdale	Arizona	869910815234246147	df3a3ee2c0019f8ba405b483eef4b682	VISA 16 digit	33.6395319215610655	-111.791743035424872
35797	2020-07-07 23:46:16	2020-07-07	Mr. Nicklaus Farrell DDS	mr.nicklaus.farrell.dds@geemail.com	Charlotte	North Carolina	3337852108619305592	b3c4cc69b0c94c2e3feac0bc4be3185d	Discover	35.1485152418978473	-80.8524788387529583
35798	2020-07-07 23:50:14	2020-07-07	Casimir Shanahan	casimir.shanahan@geemail.com	Madison	Wisconsin	6011965531702146199	7e731cfd54e527d230e8fdd8ddaca2c5	Voyager	43.0107916305746869	-89.4779602849274909
35799	2020-07-07 23:51:31	2020-07-07	Keyla Farrell	keyla.farrell@woohoo.com	St. Petersburg	Florida	6011826191913306253	ecd818d8c0874992af49d7ee735ee718	American Express	27.8138453716766101	-82.6095378466773695
35800	2020-07-08 00:05:16	2020-07-08	Keegan Blick DVM	keegan.blick.dvm@geemail.com	San Francisco	California	4654565640749	e99980daec4c824aa402e2c955af5fc5	JCB 16 digit	37.7650218194708813	-122.418356879842179
35801	2020-07-08 00:07:52	2020-07-08	Dr. Blane Dach	dr.blane.dach@warmmail.com	San Antonio	Texas	869984165999539596	043b92f1aee659b4db9f6233a79ef7cf	Discover	29.3992882197793577	-98.5858203052379167
35802	2020-07-08 00:09:20	2020-07-08	Gustie Homenick	gustie.homenick@geemail.com	Stockton	California	3088672501692334331	082b2a44ace09b83942284663c6ced3e	JCB 15 digit	37.9066347127046441	-121.386985863148425
35803	2020-07-08 00:12:14	2020-07-08	Emett Lakin	emett.lakin@geemail.com	Atlanta	Georgia	869960078041413512	a818488633bb321f01de00540856a9c8	JCB 16 digit	33.7903600533768582	-84.4878174395345241
35804	2020-07-08 00:12:56	2020-07-08	Dr. Betha Bauch	dr.betha.bauch@geemail.com	San Francisco	California	4589578431936	f65d5866886de7562f43d7dae45eed67	VISA 16 digit	37.7436398647851021	-122.440203582321814
35805	2020-07-08 00:18:08	2020-07-08	Ms. Sister Deckow	ms.sister.deckow@warmmail.com	Yonkers	New York	6011370688166577043	50419e6396008ebfbc592035ff8ce9b1	VISA 16 digit	40.9381021145466732	-73.9288327342715093
35806	2020-07-08 00:20:30	2020-07-08	August Dach	august.dach@warmmail.com	Oakland	California	869906764184120272	2eb19c35af06e884338905345ac81599	American Express	37.7758501147341121	-122.272229252661091
35807	2020-07-08 00:28:36	2020-07-08	Shaquana Bogisich	shaquana.bogisich@geemail.com	Seattle	Washington	55805332883285029	6bc465cb254b7d784305631c5436e1c2	JCB 16 digit	47.603671915914866	-122.422269409048923
35808	2020-07-08 00:28:54	2020-07-08	Jeane Smitham	jeane.smitham@geemail.com	Oakland	California	6011643718876373853	c0d49a4b225fccbefb48262287412293	Discover	37.7717213814378923	-122.272598854455239
35809	2020-07-08 00:41:59	2020-07-08	Tressa Bruen	tressa.bruen@geemail.com	Atlanta	Georgia	869940689168569012	11b3486c85ff61c72000e52a2f7378f9	American Express	33.8365265874467838	-84.3958843838933888
35810	2020-07-08 00:43:22	2020-07-08	Isadore Labadie	isadore.labadie@geemail.com	San Francisco	California	869906025609458659	2082f1fcf3fe31dd8018b1667b642814	Mastercard	37.7408850505298332	-122.418466756838527
35811	2020-07-08 01:04:42	2020-07-08	Neveah Heathcote-Harvey	neveah.heathcote.harvey@warmmail.com	Cape Coral	Florida	3112601213325483578	040a55baecadbbcd860e2dc331f55e3e	Discover	26.6285916778229179	-81.9485344181839395
35812	2020-07-08 01:04:50	2020-07-08	Mikhail Wilkinson II	mikhail.wilkinson.ii@geemail.com	San Francisco	California	51300518599899000	6c587a456158aa90968b1fd4ea14b84a	American Express	37.774987547129939	-122.43393866676638
35813	2020-07-08 01:04:58	2020-07-08	Ms. Chiquita Goldner	ms.chiquita.goldner@warmmail.com	Naperville	Illinois	4984412862117105	44a4e8835fa1364e7ad3f9ff5f60f4c6	VISA 13 digit	41.6645562308754762	-88.220711246028543
35814	2020-07-08 01:09:59	2020-07-08	Marian Hane-Thiel	marian.hane.thiel@geemail.com	Manchester	New Hampshire	53581361183500076	68304a9d8d3e93dcd8a95cd59cbd0947	VISA 16 digit	43.0799949968770193	-71.358490978636226
35815	2020-07-08 01:17:30	2020-07-08	Shaina O'Kon	shaina.o'kon@geemail.com	Berkeley	California	4671603508853834	0329ea6cb5cbeeb21c842c9396c2b5f8	American Express	37.8737164964863595	-122.248160750675595
35816	2020-07-08 01:24:11	2020-07-08	Erin Kutch	erin.kutch@geemail.com	Los Angeles	California	3112927977402130164	b58de04c8b54d1f12dde15a9e2e9e1c6	VISA 16 digit	33.9942949389904712	-118.490548201556493
35817	2020-07-08 01:25:51	2020-07-08	Dr. Terrill Hodkiewicz II	dr.terrill.hodkiewicz.ii@geemail.com	New York	New York	3158467248681745130	88988498a79db9af127c013c4fadf2b8	VISA 16 digit	40.5897967317365129	-74.0029378552816723
35818	2020-07-08 01:27:29	2020-07-08	Bode Maggio-Koch	bode.maggio.koch@warmmail.com	Lakewood	Colorado	4238310072802579	47ad33e8775c1418ba1a769c950417a4	Voyager	39.7590741997059425	-105.10900183706768
35819	2020-07-08 01:39:38	2020-07-08	Ever Terry	ever.terry@geemail.com	Denver	Colorado	3437406769585569	4615c4f542b070ee213709811383bb12	American Express	39.7082281759060862	-104.922480268428473
35820	2020-07-08 01:46:36	2020-07-08	Mr. Aedan Considine	mr.aedan.considine@geemail.com	Westminster	Colorado	3452626910151389	f6c157d53f14bf0c457967fe61cd909f	Diners Club / Carte Blanche	39.9111528217632312	-105.146375108804193
35821	2020-07-08 01:49:02	2020-07-08	Kori Hansen	kori.hansen@geemail.com	San Francisco	California	869912060718852940	f4300f6c3618900246a177ad65eb3ea2	Voyager	37.7559143882552206	-122.437962580844726
35822	2020-07-08 01:52:25	2020-07-08	Ken Fritsch PhD	ken.fritsch.phd@woohoo.com	San Francisco	California	180045394560816591	b6ff16995efc6ca7f6659972e9b88875	JCB 16 digit	37.7528535359914628	-122.439076107548203
35823	2020-07-08 02:30:30	2020-07-08	Barton Williamson	barton.williamson@geemail.com	Oakland	California	3112361510670010223	7adafe56212efb367cea096b40c070cf	Diners Club / Carte Blanche	37.8115214908185067	-122.330015597368629
35824	2020-07-08 02:40:10	2020-07-08	Jarrell Konopelski	jarrell.konopelski@geemail.com	San Francisco	California	676313553466999	64984c2832ffe98653e8ba4f4639aa54	JCB 16 digit	37.733918874696613	-122.449471700703299
35825	2020-07-08 02:47:57	2020-07-08	Carina Lynch-Rogahn	carina.lynch.rogahn@geemail.com	Knoxville	Tennessee	060424455132324	613e3431e0d3080b85d33a4569ddecdf	JCB 16 digit	35.9630548902384959	-83.8933406562294692
35826	2020-07-08 02:49:41	2020-07-08	Ms. Cassie Gislason PhD	ms.cassie.gislason.phd@woohoo.com	Hampton	Virginia	4424801833049	9a9a04368c518f01e3b673963905c713	JCB 16 digit	37.0866164144612895	-76.307992786085606
35827	2020-07-08 02:50:26	2020-07-08	Vicki Cremin-Marvin	vicki.cremin.marvin@geemail.com	San Francisco	California	3052031321214663	429a1330b833840233bc82fa956930c1	VISA 13 digit	37.8018688024101053	-122.451693445573611
35828	2020-07-08 02:53:13	2020-07-08	Najee O'Conner	najee.o'conner@geemail.com	San Francisco	California	52995983456186398	b35a01b6e72968ce3aa69f12a701a6dd	American Express	37.7558448654787355	-122.418326532385706
35829	2020-07-08 03:12:59	2020-07-08	Erin Blick	erin.blick@woohoo.com	McKinney	Texas	54479192122333377	88cb4ebf3a727854bbf6f55fe7600844	Discover	33.2372100347317811	-96.6084013775754755
35830	2020-07-08 03:15:47	2020-07-08	Dr. Terry Boehm	dr.terry.boehm@woohoo.com	Murrieta	California	4652525775805424	79c6dcecfdc1b34e16f5a61f4b62bbed	VISA 16 digit	33.6060302206411947	-117.136519484817612
35831	2020-07-08 03:17:27	2020-07-08	Dr. Glinda Donnelly	dr.glinda.donnelly@geemail.com	Fresno	California	4990449938101	bc538b69d87a64dd5feac897c896cf29	VISA 16 digit	36.8286475507881477	-119.726626623898383
35832	2020-07-08 03:25:36	2020-07-08	Linus Turcotte	linus.turcotte@woohoo.com	Houston	Texas	6011688363908869432	10291142b211ad3a2955144c75c071c4	Discover	29.7402449799779802	-95.4830632957644809
35833	2020-07-08 03:35:11	2020-07-08	Dr. Hamp Kohler V	dr.hamp.kohler.v@warmmail.com	St. Petersburg	Florida	3112539817646305349	1ca17accb2dc0890360ccff977edf5f1	American Express	27.8227554337475453	-82.5685589237496202
35834	2020-07-08 03:41:17	2020-07-08	Michale Kris	michale.kris@geemail.com	Chicago	Illinois	6011909251807710604	0ed6d35d0e75c9f7761a750ad1168c94	Discover	41.7660748641774049	-87.7524383314449352
35835	2020-07-08 03:44:04	2020-07-08	Cindy Mayert	cindy.mayert@warmmail.com	North Las Vegas	Nevada	180047931890014716	d36265b80f76c2b8ff2686adcc3b0315	Mastercard	36.3744366173323215	-115.165937420608103
35836	2020-07-08 03:53:02	2020-07-08	Callum Bogan Sr.	callum.bogan.sr.@warmmail.com	Fontana	California	6011885327588666435	8b87ea95ab7875fd827405c87fc5dc81	American Express	34.0592698691096203	-117.498171856375038
35837	2020-07-08 04:14:14	2020-07-08	Mrs. Blanche Hansen DDS	mrs.blanche.hansen.dds@geemail.com	Peoria	Arizona	4269534569314291	26d7a5d7201e9204f81597dd305e612a	Discover	33.7953348183341333	-112.386273642854775
35838	2020-07-08 04:17:51	2020-07-08	Rhona Walsh	rhona.walsh@geemail.com	Irving	Texas	6011179394816277968	89f4cdbc83364875b2d69833a1e47364	Mastercard	32.9089464686762554	-97.0584630190674176
35839	2020-07-08 04:17:56	2020-07-08	River Sawayn	river.sawayn@geemail.com	Washington	District of Columbia	869937664401071410	57c5ae443569f29bb4ae07131ba8012a	VISA 13 digit	38.9249840456325558	-77.0503764019094461
35840	2020-07-08 04:21:34	2020-07-08	Ula Purdy	ula.purdy@geemail.com	Downey	California	4360240992527	964cc388c1098863630ddf4addfdd191	Voyager	33.888752499480546	-118.06147373939082
35841	2020-07-08 04:22:33	2020-07-08	Jacki Durgan	jacki.durgan@warmmail.com	Pembroke Pines	Florida	210054231027080825	3047b5b0731b4328391c7f4a86139793	VISA 13 digit	25.959288316736	-80.3886615856919491
35842	2020-07-08 04:35:13	2020-07-08	Krish Monahan	krish.monahan@warmmail.com	Wilmington	North Carolina	4293940189823	840b2a71dea9520b4069fdbbe757a5af	Mastercard	34.1826392602462334	-77.8448380141977196
35843	2020-07-08 04:42:14	2020-07-08	Mr. Tevin Fadel MD	mr.tevin.fadel.md@geemail.com	Indianapolis	Indiana	4745287202668847	fa4278ea74662decfd5a9698e265ed3c	VISA 16 digit	39.8731825594332037	-86.1493794118255352
35844	2020-07-08 04:45:54	2020-07-08	Auston Lindgren III	auston.lindgren.iii@warmmail.com	New York	New York	676287039078420	cb59678e862f8aeb4d04f29754f59cfe	JCB 16 digit	40.5647600909918538	-73.8406606609363081
35845	2020-07-08 04:48:08	2020-07-08	Chaim Bailey	chaim.bailey@woohoo.com	Indianapolis	Indiana	6011532686153371821	8bf565d33fed5f9e447ecd40a267f8d0	VISA 13 digit	39.7481254927821439	-86.2170581223644348
35846	2020-07-08 04:51:50	2020-07-08	Mrs. Daija Barrows DVM	mrs.daija.barrows.dvm@geemail.com	Springfield	Illinois	869949157073477664	a5b1dd1cf4353715f1a40a9970e965f7	JCB 16 digit	39.8758499630879584	-89.7117865225769577
35847	2020-07-08 04:58:38	2020-07-08	Berlin Stanton	berlin.stanton@geemail.com	Chattanooga	Tennessee	4256758635385	645d8592f51bdbafb42dc74bdd971da8	Discover	35.1258922082223037	-85.2562393649775601
35848	2020-07-08 04:59:49	2020-07-08	Paulette Cronin-Huel	paulette.cronin.huel@warmmail.com	Portland	Oregon	4098043870082	763c9eb680f18ba63b98fbeb95f8b75a	JCB 16 digit	45.5800411555338627	-122.668758650589737
35849	2020-07-08 05:04:50	2020-07-08	Durward Skiles	durward.skiles@geemail.com	Odessa	Texas	501815616532568	abc89331a918852902190ef897f0d562	Voyager	31.9281062732927516	-102.415428165547922
35850	2020-07-08 05:06:24	2020-07-08	Mrs. Mikaela Lang	mrs.mikaela.lang@geemail.com	Sacramento	California	4779495481702026	69ab1129bb78fd261f5d9c980b8231b3	Voyager	38.495749279417474	-121.406724871766187
35851	2020-07-08 05:10:22	2020-07-08	Celestia Erdman	celestia.erdman@woohoo.com	San Diego	California	6011063141560128627	86c159b41680434193723cf534dd2df8	American Express	32.8522737457949674	-117.096742136813702
35852	2020-07-08 05:10:58	2020-07-08	Kalene Steuber	kalene.steuber@geemail.com	Nashville	Tennessee	4189212408873481	e019a8186e9f6cf8fc7cc7ccc6e5eed6	Maestro	36.2446767296764989	-86.8753604738414253
35853	2020-07-08 05:14:59	2020-07-08	Destini Emmerich	destini.emmerich@geemail.com	Eugene	Oregon	51569997593757396	46164ccd4d223b7e364ae9e02334f3ba	VISA 13 digit	44.026970811440421	-123.059928125561029
35854	2020-07-08 05:28:03	2020-07-08	Hoy Hermiston	hoy.hermiston@geemail.com	New York	New York	6011568802507114406	e0439090b6ca3481d50d0ab827ecdc84	VISA 16 digit	40.6117471601106246	-73.9791262760188459
35855	2020-07-08 05:29:45	2020-07-08	Mr. Lindsay Schmitt	mr.lindsay.schmitt@geemail.com	Berkeley	California	869962103891645902	2844abd468a2379d1e611f6f6ed5fe7f	Discover	37.8463448069376653	-122.274133832453813
35856	2020-07-08 05:42:54	2020-07-08	Anthoney Gibson I	anthoney.gibson.i@geemail.com	Bellevue	Washington	51122909508958431	d30de7a574d3a5db53ea99cbda99af5d	Voyager	47.6720426583379506	-122.059688229445356
35857	2020-07-08 05:43:37	2020-07-08	Shakira Rodriguez	shakira.rodriguez@geemail.com	Birmingham	Alabama	6011653516237668574	7da60cecdb020ec9ef05b106eaa316e3	VISA 16 digit	33.5898026784207673	-86.7311237348951494
35858	2020-07-08 05:57:39	2020-07-08	Leonel Ankunding-Boyer	leonel.ankunding.boyer@geemail.com	San Mateo	California	53067718777658953	097ee57cbe05b98a088e18dba9491162	JCB 15 digit	37.5076425375763307	-122.288222478501865
35859	2020-07-08 06:03:03	2020-07-08	Lewis Pouros	lewis.pouros@warmmail.com	Temecula	California	4187713174510944	a8024da607435544a98399a3f79e8eaf	VISA 16 digit	33.4538212941627933	-117.063124574600522
35860	2020-07-08 06:03:51	2020-07-08	Jewell Stark	jewell.stark@geemail.com	Des Moines	Iowa	4152199965871	92516aeda74d773e480aa2ce032bfe8b	JCB 16 digit	41.6387141198128461	-93.6334523635495515
35861	2020-07-08 06:06:16	2020-07-08	Dr. Karli Wolf	dr.karli.wolf@geemail.com	Everett	Washington	180083293712987487	352763b6d31ded99370f3bc95636bb17	American Express	47.9338263043560104	-122.099767057703431
35862	2020-07-08 06:06:49	2020-07-08	Osborne Kohler	osborne.kohler@geemail.com	Fontana	California	3528494642997594785	20e177f71047d9bffcdbb9f495746389	Diners Club / Carte Blanche	34.1043920490574095	-117.483822754146161
35863	2020-07-08 06:12:23	2020-07-08	Tawanda Crooks	tawanda.crooks@warmmail.com	Allen	Texas	3489082711574642	7fad1196a9aa62c87db9150c04cbef71	VISA 16 digit	33.0971897674750508	-96.6453185338474867
35864	2020-07-08 06:35:09	2020-07-08	Ludwig Kuhic	ludwig.kuhic@geemail.com	Carlsbad	California	3002470593337432	34ea4c85cd042ed6356dc8bca69c41e9	Discover	33.1253303860720223	-117.254853416632116
35865	2020-07-08 06:49:43	2020-07-08	Tilda Quitzon PhD	tilda.quitzon.phd@geemail.com	Carlsbad	California	6011288200434564463	aaa5b1900d9babe23afe9adf02afdd8b	Discover	33.1685669358294462	-117.213648851613698
35866	2020-07-08 06:58:31	2020-07-08	Hakim Terry	hakim.terry@geemail.com	Palmdale	California	6011212616019145918	742c85e128aa696076ba59df997b8a8e	VISA 13 digit	34.5598337902538475	-118.195108310319114
35867	2020-07-08 07:14:07	2020-07-08	Mrs. Alex Carter MD	mrs.alex.carter.md@geemail.com	Hampton	Virginia	3059086143818516	6e2782fa9dfca1e3590732c2f84de107	Maestro	37.0445784379281093	-76.3035394368324376
35868	2020-07-08 07:14:16	2020-07-08	Miss Simone Schulist	miss.simone.schulist@geemail.com	New York	New York	3043550932739015	509765f39680a99c2b0d1c9fac609072	Maestro	40.6268060963358693	-73.8388370387151838
35869	2020-07-08 07:21:19	2020-07-08	Kennedy Homenick	kennedy.homenick@geemail.com	Cape Coral	Florida	4193732796832470	ec0bcd64aeb3420a9c8eb37d79a16fe5	VISA 16 digit	26.5631326656758802	-82.0441308609746329
35870	2020-07-08 07:41:34	2020-07-08	Kirt Cole-Towne	kirt.cole.towne@woohoo.com	San Francisco	California	869914071226817786	fa6282c631e85d2e5c1f518c04ba9874	Diners Club / Carte Blanche	37.7518408093118651	-122.424854424095244
35871	2020-07-08 07:48:34	2020-07-08	Dr. Darrien Sanford V	dr.darrien.sanford.v@warmmail.com	Dallas	Texas	6011176197702102445	4dbc1b45800ffdcc8cb8e4f25f448f21	VISA 13 digit	32.8411673369158095	-96.865141816433507
35872	2020-07-08 07:59:14	2020-07-08	Emmaline Lebsack MD	emmaline.lebsack.md@geemail.com	Oakland	California	4609892750082	3e5bf808fa0b544ac80f5f1df1f00fb4	Maestro	37.7760606820752045	-122.296815819495961
35873	2020-07-08 08:00:51	2020-07-08	Desiree Homenick	desiree.homenick@geemail.com	Hillsboro	Oregon	6011863729904919461	4c5485aa60261a5f87a0e9d5573bef24	Voyager	45.4354150602798867	-122.838863656452673
35874	2020-07-08 08:04:17	2020-07-08	Simeon Kessler	simeon.kessler@geemail.com	Indianapolis	Indiana	3003158850966329	390743df2b496575fce60109c8cac823	Diners Club / Carte Blanche	39.7677134403500716	-86.0644998618602699
35875	2020-07-08 08:33:59	2020-07-08	Gerhardt McDermott	gerhardt.mcdermott@geemail.com	Portland	Oregon	3428697424286400	0114f5c308f72e76783643a7fe5385e2	Voyager	45.5826384927034383	-122.714890241669494
35876	2020-07-08 08:35:34	2020-07-08	Ms. Sibbie Borer DDS	ms.sibbie.borer.dds@woohoo.com	Columbus	Georgia	180012502132498644	875798c14217cd1466d1f48a850b1d42	American Express	32.6013271471995836	-84.8641466409131908
35877	2020-07-08 08:37:39	2020-07-08	Lakesha Schaefer	lakesha.schaefer@woohoo.com	Sugar Land	Texas	869919370083927463	2e6f1bf6a80f02ffa5880ea2257c633e	American Express	29.5125625394802533	-95.5354933197617555
35878	2020-07-08 08:37:40	2020-07-08	Rufus Stehr	rufus.stehr@geemail.com	Stockton	California	180064170715245571	abc3874cd680c4200679bfbb84b4bbbe	VISA 16 digit	37.9704307534463723	-121.293837954950703
35879	2020-07-08 08:42:48	2020-07-08	Rollin Mraz	rollin.mraz@geemail.com	Indianapolis	Indiana	3096527684396492956	9fd592d6c73fd6c3090beeef4e9aa0fd	VISA 16 digit	39.7224605393603412	-86.1482843538947378
35880	2020-07-08 08:46:12	2020-07-08	Lynette Kub	lynette.kub@woohoo.com	Houston	Texas	4665561847844450	6a81afa2f8a241785334daebc81ed80a	Diners Club / Carte Blanche	29.7484724082596586	-95.360903793807708
35881	2020-07-08 08:50:21	2020-07-08	Bonita Klein-Kemmer	bonita.klein.kemmer@geemail.com	Charlotte	North Carolina	4813685175886204	0228a42167dbc3e41f6c23274477ea4e	JCB 16 digit	35.1767524966292058	-80.9152992500867754
35882	2020-07-08 08:50:42	2020-07-08	Rodrick Hahn	rodrick.hahn@geemail.com	Los Angeles	California	3088879560240370180	f44860ccc5c2be2ef6b2bf958551e9d7	Discover	34.0971204759884614	-118.422313468250621
35883	2020-07-08 08:59:11	2020-07-08	Dr. Kalen Kulas Jr.	dr.kalen.kulas.jr.@warmmail.com	New York	New York	3014579423646974	ca87e1f4f3aec6888626e6531dc3dbd0	Voyager	40.6140860438570357	-73.9574225867528412
35884	2020-07-08 09:03:13	2020-07-08	Suzy Cremin	suzy.cremin@warmmail.com	San Francisco	California	210006363711613626	eb8aabdaf160e5caec6b6315ff25c680	Discover	37.7787239527730847	-122.435510570525736
35885	2020-07-08 09:05:24	2020-07-08	Stephenie Funk	stephenie.funk@geemail.com	San Francisco	California	3490126033225990	baf9a0e96ec5fe9477b9441a44fc9206	VISA 16 digit	37.7421119898883859	-122.435254194933933
35886	2020-07-08 09:34:56	2020-07-08	Dr. Jayce Nikolaus Sr.	dr.jayce.nikolaus.sr.@geemail.com	San Francisco	California	55695632998376099	95a4cee7055a47ed0b2d02d11749d1a7	VISA 16 digit	37.8074606532211419	-122.398168721821392
35887	2020-07-08 09:53:07	2020-07-08	Percival Greenholt	percival.greenholt@warmmail.com	Baton Rouge	Louisiana	6011865696134780393	36a1d9e5b63909b6883a6f7b4df70ade	VISA 16 digit	30.3765174315057678	-91.072140997519341
35888	2020-07-08 09:53:09	2020-07-08	Pierce Jenkins	pierce.jenkins@geemail.com	Kansas City	Missouri	3706969809925407	d8547599e1d30c37ad84958279d49c81	JCB 16 digit	39.1628610514406148	-94.649809526488184
35889	2020-07-08 10:00:11	2020-07-08	Jayvon Rosenbaum	jayvon.rosenbaum@geemail.com	South Bend	Indiana	561266388103864	bcd052da916b359f7b245ec4cf3b85d0	Maestro	41.6526944084238266	-86.3287190476022772
35890	2020-07-08 10:02:55	2020-07-08	Dr. Ayden Hyatt	dr.ayden.hyatt@geemail.com	Joliet	Illinois	55762508547572719	1efa230d2179a23c475a2d05b4266b11	Maestro	41.5024043617162803	-88.0889695678010582
35891	2020-07-08 10:04:33	2020-07-08	Fount Dickens	fount.dickens@geemail.com	Fort Lauderdale	Florida	6011783186029953395	1edf14ecf1dd10515a4b933452c85862	Discover	26.1100492020592121	-80.0961166378863112
35892	2020-07-08 10:07:58	2020-07-08	Thresa Parisian	thresa.parisian@warmmail.com	Palmdale	California	6011319567190673263	92ce3e5169876fbff8ca14a39887f0d6	Maestro	34.6876734468005594	-118.079453068831569
35893	2020-07-08 10:22:02	2020-07-08	Tristan Hermiston-Kilback	tristan.hermiston.kilback@geemail.com	Portland	Oregon	6011574589748340971	45347aa9c2e1870ca720236625a6e40d	Maestro	45.5747450829371772	-122.558975228574127
35894	2020-07-08 10:27:23	2020-07-08	Octavius Ullrich	octavius.ullrich@geemail.com	Baltimore	Maryland	4159377740139432	2ccffa69bafb0479dd8ecd05a911d0db	American Express	39.3403302098624366	-76.6582399406023285
35895	2020-07-08 10:29:04	2020-07-08	Mrs. Alma Smitham MD	mrs.alma.smitham.md@geemail.com	North Charleston	South Carolina	869965403647326865	84b64db8b840b37a02bb9530e97a7fb5	Mastercard	32.9828394794531192	-80.1387218698952353
35896	2020-07-08 10:29:27	2020-07-08	Dr. Immanuel Stiedemann III	dr.immanuel.stiedemann.iii@geemail.com	San Francisco	California	51862535715508133	f311defa669e148382d5995189c44710	VISA 16 digit	37.8033554256286166	-122.443989303781819
35897	2020-07-08 10:35:05	2020-07-08	Clyde Block	clyde.block@geemail.com	New York	New York	6011076760227787262	ef3c711d8934cc7926e9733fc6ad856b	Voyager	40.7597684708647421	-73.8429524869087999
35898	2020-07-08 10:40:13	2020-07-08	Daniel Robel MD	daniel.robel.md@geemail.com	Kansas City	Missouri	4469939200583329	2859b622b82eba222d4e87445e7a3653	VISA 16 digit	39.1217751119121928	-94.6421892435047738
35899	2020-07-08 10:53:01	2020-07-08	Germaine Murazik	germaine.murazik@geemail.com	Phoenix	Arizona	3732322147837421	cc3e37c18317b364c3f623da37c75205	Mastercard	33.6380909176941998	-112.121720853161449
35900	2020-07-08 11:05:06	2020-07-08	Columbus Quigley	columbus.quigley@warmmail.com	Austin	Texas	4417901451274183	a7e92a56d1e14a5d193b3904ea85a799	VISA 16 digit	30.3272774804044509	-97.7594549016334184
35901	2020-07-08 11:07:30	2020-07-08	Dr. Laurette Schaden	dr.laurette.schaden@geemail.com	Madison	Wisconsin	4098107692679	ecbff7d47246b8fa5b492539fdb3fd61	Discover	43.0261324900642066	-89.4997160717263824
35902	2020-07-08 11:10:36	2020-07-08	Vernon Goldner Jr.	vernon.goldner.jr.@woohoo.com	New York	New York	53902303570945474	7c847e82a32cf4fc82818a85fb9e6389	VISA 16 digit	40.659693886268883	-73.8431317509978982
35903	2020-07-08 11:15:15	2020-07-08	Whitney Pacocha	whitney.pacocha@woohoo.com	Hayward	California	55551943422237721	0b151918280b1fd40cb818c7f74ae99a	Diners Club / Carte Blanche	37.725330915114661	-122.124498156623545
35904	2020-07-08 11:17:38	2020-07-08	Dwaine Berge	dwaine.berge@woohoo.com	New York	New York	869990670299910506	077bfca6a626cb8d55c9773999dab41f	VISA 13 digit	40.7255216253679251	-74.0334248168755238
35905	2020-07-08 11:24:24	2020-07-08	Stan Simonis	stan.simonis@geemail.com	San Antonio	Texas	52320843997845009	4ebd9720738a125cb382bfe5241678dd	Maestro	29.4430726714968678	-98.4315947119448253
35906	2020-07-08 11:31:13	2020-07-08	Sheryl Bernier	sheryl.bernier@geemail.com	San Francisco	California	3753165751993244	65499eb3e90f2f604dc6ce796c8eaaa8	American Express	37.7830983242547802	-122.413564875921125
35907	2020-07-08 11:33:35	2020-07-08	Darron Ritchie PhD	darron.ritchie.phd@geemail.com	Newark	New Jersey	4003532041104844	31850b6a93f8ee093250aaeb282960c3	VISA 16 digit	40.6507768114011796	-74.078817473186561
35908	2020-07-08 11:34:16	2020-07-08	Dorian O'Kon	dorian.o'kon@geemail.com	Los Angeles	California	6011119169687206707	e078b7f893704135efc998204cf269c7	JCB 16 digit	34.0458067337382531	-118.316686969249687
35909	2020-07-08 11:45:46	2020-07-08	Dr. August O'Reilly PhD	dr.august.o'reilly.phd@woohoo.com	Albuquerque	New Mexico	3096068327738003967	670873192bbcb6d15f05d48681821f1d	Diners Club / Carte Blanche	35.1604151763156096	-106.741463758989795
35910	2020-07-08 11:46:33	2020-07-08	Dr. Jerrilyn Ferry MD	dr.jerrilyn.ferry.md@geemail.com	New York	New York	4373734781702	18e58d253167ab77ce5fe811342aa444	Voyager	40.7597903804145716	-73.9148006784625267
35911	2020-07-08 11:50:39	2020-07-08	Allen Jast	allen.jast@woohoo.com	Toledo	Ohio	3088537871820803019	0834e3189bde23c45ebea1e83ca145b9	VISA 16 digit	41.7500738518483914	-83.6716448101546604
35912	2020-07-08 11:58:52	2020-07-08	Mrs. Shyanne Kemmer PhD	mrs.shyanne.kemmer.phd@geemail.com	Laredo	Texas	6011649503412411613	3aa322aea28fd3b3446800c84211d90a	JCB 16 digit	27.6030185245160027	-99.4034744424752859
35913	2020-07-08 12:03:45	2020-07-08	Devon Schowalter	devon.schowalter@geemail.com	Philadelphia	Pennsylvania	4995113805611710	ada88dea281a24ffa0bb76db555dd6f2	Mastercard	39.9489063982345129	-75.171202257312089
35914	2020-07-08 12:07:46	2020-07-08	Phebe Koch	phebe.koch@woohoo.com	San Diego	California	210050107300748185	06aa20848975198d71a41fc065a1c05f	Maestro	32.7689828575190134	-117.217054915977641
35915	2020-07-08 12:13:28	2020-07-08	Margene Hahn	margene.hahn@geemail.com	Los Angeles	California	4009624593236431	b456b52df3739ede3b5f7e02046c33f6	VISA 16 digit	34.082424442363525	-118.427912314281983
35916	2020-07-08 12:20:53	2020-07-08	Zayden Gerhold	zayden.gerhold@geemail.com	Louisville	Kentucky	6011040722652509390	439173eb4f9fd974c9171f8fc9f3e113	Voyager	38.1758979232419264	-85.6286142151873548
35917	2020-07-08 12:39:43	2020-07-08	Ms. Darci Wintheiser	ms.darci.wintheiser@geemail.com	Reno	Nevada	4194497602234753	a1bdc2d882ffb1f312a4a71806ff97fa	VISA 16 digit	39.4797301720906049	-119.923183145809546
35918	2020-07-08 12:52:20	2020-07-08	Jaleel Smitham Sr.	jaleel.smitham.sr.@geemail.com	Kansas City	Kansas	4949620976850	b1ad04152e430e691ff463d3fdf2b09d	JCB 16 digit	39.1444218468759217	-94.7062615887664236
35919	2020-07-08 13:01:42	2020-07-08	Tomie Lemke	tomie.lemke@geemail.com	Philadelphia	Pennsylvania	060415241745098	eedc4c2b0470ef07c832871724372978	American Express	39.9897492080420278	-75.0378861868653502
35920	2020-07-08 13:08:00	2020-07-08	Imanol Ritchie	imanol.ritchie@geemail.com	Oklahoma City	Oklahoma	3045019879265929	b82854e80e917a394a576ccff5f05f39	Mastercard	35.5347723396871231	-97.5334689378168491
35921	2020-07-08 13:15:36	2020-07-08	Ms. Jaclyn Ernser	ms.jaclyn.ernser@woohoo.com	Berkeley	California	3053346740045061	afc4e6c65e0728a4efb99a9a379aeede	JCB 16 digit	37.8749812756045046	-122.244707962411141
35922	2020-07-08 13:26:54	2020-07-08	Sabina Fisher	sabina.fisher@geemail.com	Mobile	Alabama	676325727744135	b902f2c4f2f0ff3965cf69e7af45efc3	Diners Club / Carte Blanche	30.6183526432715354	-88.1511216437116332
35923	2020-07-08 13:34:55	2020-07-08	Mrs. Reanna West	mrs.reanna.west@geemail.com	Virginia Beach	Virginia	4177994743744	0ec91aef5592fe645e9f3c05e969ac69	JCB 16 digit	36.7569054769072707	-76.0498933029033282
35924	2020-07-08 13:38:57	2020-07-08	Buddie Cormier	buddie.cormier@geemail.com	Thornton	Colorado	6011856622485077784	1fba751ecc5a0c685e4fcc203539045d	JCB 16 digit	39.943518255032231	-105.023296603110808
35925	2020-07-08 13:44:08	2020-07-08	Nyree Bayer	nyree.bayer@geemail.com	Corpus Christi	Texas	3754776902564996	43ab5186a9d3191b6aba2ad18e46474b	JCB 16 digit	27.8519877714972957	-97.1120807325296056
35926	2020-07-08 13:44:10	2020-07-08	Mikhail Stoltenberg-Strosin	mikhail.stoltenberg.strosin@geemail.com	Virginia Beach	Virginia	6011913396198991489	9eb86c274f91bcc04e22610285a02a4c	Mastercard	36.7805195955745887	-75.9577222700834227
35927	2020-07-08 13:44:47	2020-07-08	Pink Raynor	pink.raynor@geemail.com	Saint Paul	Minnesota	51534671536565271	988a90bdce20f6e40242bf0191f776d8	VISA 16 digit	44.9728510676357942	-93.0134893894925767
35928	2020-07-08 13:56:11	2020-07-08	Miss Nataly Jast	miss.nataly.jast@geemail.com	New York	New York	3112666185974255873	b9c625cdf7c073968d8f321e76300634	VISA 13 digit	40.6340117076169705	-73.8959489932645113
35929	2020-07-08 14:04:14	2020-07-08	Joan Berge	joan.berge@warmmail.com	Orlando	Florida	180020834636258889	c6575e995dc6980b9c3c9be22403ce34	JCB 16 digit	28.3406938758011897	-81.3357344174258401
35930	2020-07-08 14:11:41	2020-07-08	Macarthur Gulgowski	macarthur.gulgowski@warmmail.com	Seattle	Washington	3775561505681347	d46465970e35cee48a2cacdc942c11a9	Diners Club / Carte Blanche	47.6954073654413193	-122.263975343286617
35931	2020-07-08 14:15:10	2020-07-08	Gregory Kunde	gregory.kunde@geemail.com	Fontana	California	4666921960911644	eedd8060d3b43474119990568e270574	Mastercard	34.1640486843101669	-117.495339061580225
35932	2020-07-08 14:17:58	2020-07-08	Romeo Corwin	romeo.corwin@geemail.com	New York	New York	53214961207144796	670b3431f2fbb102c739dba698b8ae7a	JCB 16 digit	40.6522244769372065	-73.9792414560809704
35933	2020-07-08 14:21:20	2020-07-08	Orland Kohler	orland.kohler@woohoo.com	Oakland	California	6011788285246724111	71d5be754ca679db5020d3209c0a03f0	American Express	37.8196900449112547	-122.269491899399142
35934	2020-07-08 14:22:45	2020-07-08	Albertine Kuhlman	albertine.kuhlman@woohoo.com	Sparks	Nevada	52708196470683195	1f53efb583fd67b8a60242e07d2c9ade	Diners Club / Carte Blanche	39.5334470050647866	-119.76365994236842
35935	2020-07-08 14:26:41	2020-07-08	Tinie Okuneva	tinie.okuneva@geemail.com	Frisco	Texas	6011910732800426873	c8e330784af8a0bb5631d7afd8a1d370	VISA 16 digit	33.0646276461888107	-96.7462571745481341
35936	2020-07-08 14:30:43	2020-07-08	Delmar Homenick	delmar.homenick@geemail.com	Tyler	Texas	4159122421495707	9550e7fdf5c887e3282ed123e1f2a750	VISA 16 digit	32.2263995243750543	-95.2647714048732013
35937	2020-07-08 14:31:14	2020-07-08	Antonette Rosenbaum-Hayes	antonette.rosenbaum.hayes@geemail.com	Pittsburgh	Pennsylvania	4280441004725336	cfaab60a6ca0360ccf4c0f725baa3088	JCB 16 digit	40.4599599177438733	-80.0253145711202194
35938	2020-07-08 14:53:48	2020-07-08	Mr. Ora Hand III	mr.ora.hand.iii@warmmail.com	New York	New York	210067238209413166	f03b5b7977ccdfd8e2da968227425476	Mastercard	40.7410040979497126	-73.9835120478540631
35939	2020-07-08 14:54:21	2020-07-08	Mozell Lakin-Carroll	mozell.lakin.carroll@geemail.com	Irvine	California	4560744778837547	73e229b62add328cb6b62b8cc32cc78c	Discover	33.7607524696286774	-117.68967038737722
35940	2020-07-08 14:57:18	2020-07-08	Bobby Williamson	bobby.williamson@geemail.com	Greensboro	North Carolina	3096083706578668792	f0685819e0b9cfd9153f2f605eca77f1	JCB 16 digit	35.9980133871663384	-79.8390633620303163
35941	2020-07-08 15:00:12	2020-07-08	Rich Schmidt	rich.schmidt@woohoo.com	Tallahassee	Florida	3112751890443775155	6ce9d2ca5aeef81575695b166f9fa5ea	Discover	30.5021403120853023	-84.2335982191391253
35942	2020-07-08 15:13:41	2020-07-08	Nanette O'Kon MD	nanette.o'kon.md@geemail.com	Daly City	California	3337722410247743626	dba7356f5edfc8a0cca9395e26de0c53	JCB 16 digit	37.6147717525638612	-122.564032196775088
35943	2020-07-08 15:15:30	2020-07-08	Soledad Gottlieb DDS	soledad.gottlieb.dds@warmmail.com	Minneapolis	Minnesota	3112695569406991053	247740d32ce367091b4847c95f65a7e2	Mastercard	44.9998239659324284	-93.1912306761175415
35944	2020-07-08 15:44:50	2020-07-08	Viviana Carroll DDS	viviana.carroll.dds@geemail.com	Atlanta	Georgia	4660674371167	8a5e81381aede69fc66c6dbf8ee27441	VISA 16 digit	33.7515514070909504	-84.3733909077521531
35945	2020-07-08 16:16:56	2020-07-08	Unknown Halvorson	unknown.halvorson@warmmail.com	Honolulu	Hawaii	869926584309979196	241dcf7275d8dad2772916065109b2de	Maestro	21.2618219684094214	-157.817904298866551
35946	2020-07-08 16:19:09	2020-07-08	Dr. Darci Frami	dr.darci.frami@warmmail.com	Anaheim	California	502054839847545	0c87e9f8c7a629374acb5abbfb925bb9	JCB 16 digit	33.8370153609029956	-117.735490015682203
35947	2020-07-08 16:20:14	2020-07-08	Patric Ferry Jr.	patric.ferry.jr.@geemail.com	New York	New York	3096315083389829348	d5108573c73833eaece9e2b7b99f3c08	American Express	40.7427445160448514	-73.8463780178118441
35948	2020-07-08 16:21:28	2020-07-08	Mr. Paulo Dicki PhD	mr.paulo.dicki.phd@warmmail.com	New York	New York	4735865761571791	d2d4133e031dc58853f312bfdcd4723f	JCB 15 digit	40.6904188923295607	-73.9691433189332486
35949	2020-07-08 16:33:31	2020-07-08	Johnathan Larson	johnathan.larson@geemail.com	Nashville	Tennessee	3112009649614024276	3ecee90e8e522499419db5241bb207da	VISA 13 digit	36.170471831330282	-86.7244934464711719
35950	2020-07-08 16:34:28	2020-07-08	Manford Douglas-Doyle	manford.douglas.doyle@woohoo.com	Modesto	California	3337624595673257478	33cd7e9d8c472ed0fcde677ebc54a99d	Mastercard	37.7059615639038412	-120.929310185110197
35951	2020-07-08 16:34:30	2020-07-08	Mrs. Shakira Balistreri DVM	mrs.shakira.balistreri.dvm@geemail.com	Fayetteville	North Carolina	3088217769484416598	a69675144d7bfad93c11f311cc988275	JCB 16 digit	35.1762260506182898	-79.0553037495017037
35952	2020-07-08 16:42:43	2020-07-08	Milda Boehm	milda.boehm@geemail.com	Bellevue	Washington	4244470927317439	772a64dde7014d07dc457d35e24ee6c9	Maestro	47.63515155624561	-122.164398291805753
35953	2020-07-08 16:46:37	2020-07-08	Kaela Kiehn PhD	kaela.kiehn.phd@woohoo.com	San Francisco	California	4910177679367685	56170b048568de5fc4b79c670b2edca0	JCB 16 digit	37.7653482400036467	-122.419143711010875
35954	2020-07-08 16:46:59	2020-07-08	Miguelangel Williamson	miguelangel.williamson@geemail.com	New York	New York	3482377545839840	d5bc16a3697e8f2d650bd8226f185455	Discover	40.7063420236799871	-74.0289447080705258
35955	2020-07-08 16:47:02	2020-07-08	Brien Ferry Sr.	brien.ferry.sr.@geemail.com	Minneapolis	Minnesota	3158630616815204376	6dbcdcec35992c6b82a298cd81fb9faa	Maestro	44.9246034314941554	-93.3622438830129795
35956	2020-07-08 16:50:55	2020-07-08	Aubree Farrell DVM	aubree.farrell.dvm@geemail.com	San Francisco	California	6011003105581717166	f1272ec9599d0bfbdc374f4f722234d0	VISA 13 digit	37.7771249959138942	-122.455803090747381
35957	2020-07-08 16:53:11	2020-07-08	Lyndia VonRueden	lyndia.vonrueden@geemail.com	New York	New York	4362816181785131	91eee4bb756fea0aaef72b1398dc1d1c	Mastercard	40.6485646751932777	-73.8531570844713627
35958	2020-07-08 17:00:20	2020-07-08	Louie Rogahn	louie.rogahn@geemail.com	Savannah	Georgia	3055081007280253	bd78e6d0446a4ad66e478b1ef376f847	Mastercard	32.1024234417919061	-81.0546302158072507
35959	2020-07-08 17:03:41	2020-07-08	Rasheed Hoeger DVM	rasheed.hoeger.dvm@woohoo.com	San Antonio	Texas	6011261652755750272	591f4dd9268d9ae759c3459457ed87c0	VISA 16 digit	29.3773946665298205	-98.4940609216991732
35960	2020-07-08 17:13:42	2020-07-08	Sanford Langworth	sanford.langworth@warmmail.com	Fort Worth	Texas	3001340233831717	790873a4d533c9c8ac2ab853d0d37912	JCB 15 digit	32.8311651782654224	-97.2842664148945317
35961	2020-07-08 17:22:03	2020-07-08	Nim Daniel	nim.daniel@woohoo.com	Aurora	Colorado	180082139027381364	646484ef862050ba9d72a56cdeb763ed	Voyager	39.6520569048933709	-104.61906869016849
35962	2020-07-08 17:26:30	2020-07-08	Josie Mueller	josie.mueller@warmmail.com	San Francisco	California	210046271245464287	9f16e1bea3d91e02c2d748d9c56198ee	Diners Club / Carte Blanche	37.7808827880271565	-122.428538181867793
35963	2020-07-08 17:27:02	2020-07-08	Kash Hodkiewicz	kash.hodkiewicz@geemail.com	Shreveport	Louisiana	3035700950603829	e0177a07f3b73f2f725a1cb103c2c76f	Diners Club / Carte Blanche	32.5426976941298705	-93.86507813867442
35964	2020-07-08 17:29:08	2020-07-08	Hughes Mraz MD	hughes.mraz.md@warmmail.com	Portland	Oregon	3158326789310341792	b200d8e78017b1de440f52eb430c82a8	Discover	45.5157997372448406	-122.595727990521127
35965	2020-07-08 17:53:43	2020-07-08	Mr. Kennard Strosin Jr.	mr.kennard.strosin.jr.@geemail.com	New York	New York	4457156922235385	b29a3d1069b9b26b42b4c8b362ec0092	American Express	40.6930926226302958	-74.0184668677289039
35966	2020-07-08 17:59:45	2020-07-08	Miss Cherie Hauck DVM	miss.cherie.hauck.dvm@geemail.com	San Francisco	California	3096293378597605282	098a3313fc5de69c2cd3ef671a022f78	American Express	37.8054963536613897	-122.40555727213291
35967	2020-07-08 18:55:45	2020-07-08	Kayson Rohan I	kayson.rohan.i@geemail.com	Allentown	Pennsylvania	3112381807701838283	d6c1b4606730881ed82159f3edd10101	American Express	40.5509748001828783	-75.4875864788439088
35968	2020-07-08 18:58:08	2020-07-08	Elvia Stoltenberg	elvia.stoltenberg@woohoo.com	Phoenix	Arizona	180006874550880043	4b3c957b8d8dcea7e44a281c2c95c2f9	VISA 13 digit	33.616346101316438	-112.188868156068409
35969	2020-07-08 18:59:52	2020-07-08	Mr. Lewis Davis V	mr.lewis.davis.v@geemail.com	Carlsbad	California	3793566403302431	0a79da9ae454f68db6bd9de68f8aea20	VISA 16 digit	33.0324462628863742	-117.326292187280202
35970	2020-07-08 19:07:39	2020-07-08	Marchello Murphy	marchello.murphy@warmmail.com	Tucson	Arizona	3421877461756898	7ac78cfef9d12545b93e23269bbf3561	VISA 16 digit	32.1752478946041336	-110.87763862896189
35971	2020-07-08 19:08:01	2020-07-08	Arne Ortiz	arne.ortiz@geemail.com	Glendale	California	869914133523399429	71996e37fa8088ba61fc959541306292	Discover	34.1619241994094054	-118.308586360271278
35972	2020-07-08 19:09:12	2020-07-08	Cheryll Leuschke DDS	cheryll.leuschke.dds@geemail.com	Oakland	California	869926336691893620	cf4179a7987d472dc20b024139376ff4	Voyager	37.7944819818683229	-122.236796737106133
35973	2020-07-08 19:09:41	2020-07-08	Shenna Maggio-Doyle	shenna.maggio.doyle@geemail.com	New York	New York	869919732361059543	d18f924e48884489cc4d2596c08c36c8	JCB 16 digit	40.6397216846458633	-74.0157111172925681
35974	2020-07-08 19:14:51	2020-07-08	Akeem McGlynn	akeem.mcglynn@geemail.com	Philadelphia	Pennsylvania	3088759117177253585	58b85006edd4679d50b5562621629ea1	VISA 16 digit	40.0312580727931078	-75.1565622289098911
35975	2020-07-08 19:20:33	2020-07-08	Ebb Pfannerstill	ebb.pfannerstill@woohoo.com	Fort Worth	Texas	4141866589683782	ec5f3e4325b950c3451d147b6b67ffda	VISA 16 digit	32.8356637971065979	-97.2723492528598683
35976	2020-07-08 19:29:57	2020-07-08	Terra Hyatt	terra.hyatt@woohoo.com	San Francisco	California	51801164296872570	a208c645f01640151b136dddcf4a9bed	JCB 16 digit	37.788326300758591	-122.456586071165347
35977	2020-07-08 19:33:58	2020-07-08	Dwain Murazik-Beahan	dwain.murazik.beahan@geemail.com	New York	New York	3088154982704098527	c6bda15dc059d290a56d1a25bafcf08f	VISA 16 digit	40.6113358072228721	-74.0156571221433524
35978	2020-07-08 19:48:10	2020-07-08	Dr. Dink Cummings	dr.dink.cummings@geemail.com	Austin	Texas	55137395544791650	75c39b8050408cc2049358968d930e55	JCB 15 digit	30.3230365870181444	-97.8440976843941996
35979	2020-07-08 19:48:28	2020-07-08	Mona Satterfield-Brekke	mona.satterfield.brekke@geemail.com	Augusta	Georgia	6011892799345778284	742fbdff0f22734a018b667c409fef17	JCB 15 digit	33.4300135778002385	-82.1703116018619397
35980	2020-07-08 19:49:57	2020-07-08	Mr. Zayden Leffler	mr.zayden.leffler@woohoo.com	Lancaster	California	869999187472407672	a00e1f1d95d7ebd718ae41f92f4ac15c	Mastercard	34.7024225380983253	-118.14194156471379
35981	2020-07-08 19:50:52	2020-07-08	Roderick Fay	roderick.fay@geemail.com	New York	New York	4172695373982	b28ba05df5ea0e4aa5982878eafc9933	Diners Club / Carte Blanche	40.6932586593311285	-73.8420461484126776
35982	2020-07-08 19:55:28	2020-07-08	Ms. Junie Ankunding DVM	ms.junie.ankunding.dvm@geemail.com	Gilbert	Arizona	4375927807426	f88a614fb42c593e85d7c26c46fbb86c	JCB 16 digit	33.3297856661371839	-111.809312176112456
35983	2020-07-08 20:01:02	2020-07-08	Burns Nitzsche	burns.nitzsche@geemail.com	New York	New York	3758267785609682	46934ee2ea848555f87351dc150fb90f	American Express	40.7083280435986836	-73.9278280523035676
35984	2020-07-08 20:12:03	2020-07-08	Thompson Koss	thompson.koss@geemail.com	Plano	Texas	3096159620763399916	c462deec8f4118d25f0a792909965f24	VISA 16 digit	33.1289537239905485	-96.7939882324725431
35985	2020-07-08 20:32:45	2020-07-08	Stasia Gibson	stasia.gibson@geemail.com	Riverside	California	3744755091487543	07733a576628ee84a4a65c6e6feef85d	American Express	33.9896737050678581	-117.430577115106203
35986	2020-07-08 20:40:55	2020-07-08	Cordell Renner	cordell.renner@warmmail.com	San Francisco	California	6011644014609014256	ee71533a525f704e6eb24615d5cabad8	American Express	37.7651996095444744	-122.389077996117706
35987	2020-07-08 20:43:37	2020-07-08	Jadyn VonRueden	jadyn.vonrueden@woohoo.com	New York	New York	4032486038587443	b6c6f86a89a909da37414588a83d81a7	VISA 16 digit	40.6687643107715999	-73.9699016142997863
35988	2020-07-08 20:51:16	2020-07-08	Ms. Alverda Huel PhD	ms.alverda.huel.phd@woohoo.com	Charlotte	North Carolina	676299768272793	700eaeb130cbcc8e7ee415ca179203dc	VISA 16 digit	35.2964419867631065	-80.8075096828341515
35989	2020-07-08 20:52:50	2020-07-08	Ms. Darian Huel PhD	ms.darian.huel.phd@geemail.com	Corpus Christi	Texas	3465295170288193	8c0eb90869fb97aabe595e4d8198f32e	VISA 16 digit	27.6875115750294185	-97.1480069448534351
35990	2020-07-08 21:13:07	2020-07-08	Brian Rogahn	brian.rogahn@warmmail.com	Oxnard	California	4919231707830247	c2b9716bf9133b43a428ec3498454083	Diners Club / Carte Blanche	34.1609611218284854	-119.164856776679301
35991	2020-07-08 21:24:37	2020-07-08	Dr. Gee Abernathy Jr.	dr.gee.abernathy.jr.@geemail.com	Los Angeles	California	4785027901906077	862516a70b107f0a8549f747153576f2	Diners Club / Carte Blanche	34.0063122495409047	-118.393543045268572
35992	2020-07-08 21:25:31	2020-07-08	Anatole Reinger PhD	anatole.reinger.phd@geemail.com	Mesa	Arizona	3112113707755614298	db696c194bcd48b9c7c081411128eb58	Maestro	33.4396373628783934	-111.734136275609586
35993	2020-07-08 21:38:50	2020-07-08	Sally Cronin	sally.cronin@geemail.com	San Francisco	California	869982195650582744	77cb74188bf88d86f81820ed4e3a04e1	Maestro	37.7725813890024966	-122.426493911086069
35994	2020-07-08 21:52:15	2020-07-08	Gaige Brakus	gaige.brakus@geemail.com	Philadelphia	Pennsylvania	4459521214165947	62cbddd2a06c49647143a2241c7749b5	Diners Club / Carte Blanche	39.9743856987409316	-75.223299000728133
35995	2020-07-08 21:52:50	2020-07-08	Dr. Esley Gaylord Sr.	dr.esley.gaylord.sr.@warmmail.com	Norman	Oklahoma	3003151210154629	8f09a963a23fb9c73c32b6e3f6a05caf	Discover	35.2030496328644489	-97.2892111601095593
35996	2020-07-08 21:53:25	2020-07-08	Silver Wyman-Hagenes	silver.wyman.hagenes@geemail.com	Fort Collins	Colorado	4760178108675	1b6e5161f872db2583e0aac85f37da7f	Voyager	40.5072528799686609	-104.981185827213537
35997	2020-07-08 21:55:37	2020-07-08	Faye Quigley	faye.quigley@geemail.com	Miami	Florida	639058906950066	9066caaa25321d0902c25f7a700421e2	American Express	25.8680308637347096	-80.1090520606715302
35998	2020-07-08 22:02:46	2020-07-08	Destiny Gusikowski	destiny.gusikowski@geemail.com	Elizabeth	New Jersey	4523703663139	c9ac85ebf2f9de76d7d5f4f06e7f7375	JCB 16 digit	40.7274306370537786	-74.277198042947802
35999	2020-07-08 22:18:46	2020-07-08	Miss Aliya Beier PhD	miss.aliya.beier.phd@geemail.com	San Jose	California	4336807736101398	d06b7c8dd8a774da1bcf83bfc7110994	Discover	37.2445015855886084	-121.893020031995704
36000	2020-07-08 22:20:04	2020-07-08	Mrs. Sydnie Keeling DDS	mrs.sydnie.keeling.dds@geemail.com	Pasadena	California	53293141680405238	3bc24ccfeb6b35e4e123e1422a40dd8a	JCB 16 digit	34.2390436249174215	-118.189544700254132
36001	2020-07-08 22:25:03	2020-07-08	Ms. Aletha Bashirian	ms.aletha.bashirian@geemail.com	Houston	Texas	4135496078124367	6ca5454eb029beebd8a8f6dc9df8d437	JCB 16 digit	29.8407828917805098	-95.3126663517687547
36002	2020-07-08 22:25:18	2020-07-08	Coretta Hansen	coretta.hansen@woohoo.com	Tuscaloosa	Alabama	210027363442873080	b41c453f2ac7244796ac0cc66995888a	Maestro	33.300149096880105	-87.4414572874646581
36003	2020-07-08 22:29:03	2020-07-08	Unknown Jerde-Ernser	unknown.jerde.ernser@geemail.com	Newport News	Virginia	4845608477747975	15f3b898532ecc10517e8a4a6721fe25	JCB 15 digit	36.9876143982995274	-76.4530116363223726
36004	2020-07-08 22:33:49	2020-07-08	Schley O'Kon	schley.o'kon@geemail.com	San Francisco	California	210018323979440720	1cd7fde69ffffeaf8aa6eface364a694	Diners Club / Carte Blanche	37.7749245681964823	-122.409386541178122
36005	2020-07-08 22:43:07	2020-07-08	Devyn Langosh	devyn.langosh@geemail.com	Montgomery	Alabama	180038578873443973	05a62a91770656fbb28167de92ef3dd0	American Express	32.3443613236237297	-86.2219659517671886
36006	2020-07-08 22:45:43	2020-07-08	Kamilah Grant	kamilah.grant@geemail.com	Chicago	Illinois	55863060220797716	34277f7c8c5ba2624ceacfd53e0a7eb3	Discover	41.8600564235191825	-87.5836094855360585
36007	2020-07-08 23:04:29	2020-07-08	Kecia Lang	kecia.lang@geemail.com	Riverside	California	676309928482893	6c57c887a9e761cb8ff2f1c7d91e4319	VISA 16 digit	34.0266762004647418	-117.404809631963062
36008	2020-07-08 23:10:14	2020-07-08	Mr. Oswald Von	mr.oswald.von@geemail.com	Fayetteville	North Carolina	4426066333793534	d39792e5c0244b0e83ef162165048830	Voyager	35.0104928185950968	-78.8889077142477078
36009	2020-07-08 23:12:27	2020-07-08	Adela Reichert	adela.reichert@geemail.com	Oklahoma City	Oklahoma	3337047502973903651	155a732ed54add59591af492953c52bc	JCB 16 digit	35.4705330244176125	-97.4988874981075497
36010	2020-07-08 23:12:33	2020-07-08	Mearl Maggio-Sipes	mearl.maggio.sipes@geemail.com	San Francisco	California	3158384260391565385	be8e6500a03cbc82fa7d6e77d603f193	Diners Club / Carte Blanche	37.7732820780405518	-122.442953852583599
36011	2020-07-08 23:12:39	2020-07-08	Justice Marvin-Thiel	justice.marvin.thiel@woohoo.com	Sacramento	California	3528689232950811528	1ef811d8f7d19a7e15566d15ccae8bfd	American Express	38.6030987635053719	-121.554825700844077
36012	2020-07-08 23:16:19	2020-07-08	Kaela Fadel	kaela.fadel@geemail.com	Lancaster	California	3446262421686835	91004d8950def68566a39bd7ae9584b5	JCB 15 digit	34.7528429915443127	-118.091775392272694
36013	2020-07-08 23:40:44	2020-07-08	Joseline Nitzsche	joseline.nitzsche@woohoo.com	Austin	Texas	6011836360989178866	cbdec411df0b94cd60128b45ff428867	VISA 16 digit	30.368932337466255	-97.711719151656709
36014	2020-07-08 23:41:39	2020-07-08	Sue Bruen DDS	sue.bruen.dds@geemail.com	Indianapolis	Indiana	4812878190557642	d77c392e6d3fc1d8d7222de7de147eaa	VISA 16 digit	39.748479589261855	-86.1077462482932958
36015	2020-07-08 23:48:23	2020-07-08	Willaim Hammes	willaim.hammes@geemail.com	Arlington	Texas	6011422938218803410	14af12c11539c97dfe6672a744bb73df	JCB 16 digit	32.648630261353027	-97.0433109544709396
36016	2020-07-09 00:01:38	2020-07-09	Niko Rohan	niko.rohan@geemail.com	Columbus	Ohio	4173694221605281	9e61cda7226e7c1404422c570c3412b4	Mastercard	39.9364401472311457	-82.9469556361205917
36017	2020-07-09 00:03:54	2020-07-09	Shana Metz	shana.metz@woohoo.com	Dayton	Ohio	4466963025278	be62f45acf9841dd4a7eac16cfc454be	Voyager	39.7654613624583959	-84.2047323453895729
36018	2020-07-09 00:06:53	2020-07-09	Mrs. Keli Moore DDS	mrs.keli.moore.dds@geemail.com	North Las Vegas	Nevada	6011135262330142179	a1c96cb3ed05d6b0f4266b103ce1db1c	Mastercard	36.2664352559175356	-115.047801379928003
36019	2020-07-09 00:15:14	2020-07-09	Dr. Glenwood Huel V	dr.glenwood.huel.v@geemail.com	Jersey City	New Jersey	3776340400989512	60a0552908f9fe144098a28f37202330	VISA 13 digit	40.7490588004641197	-73.9780991697639223
36020	2020-07-09 00:24:53	2020-07-09	Mr. Romeo Fisher	mr.romeo.fisher@woohoo.com	San Francisco	California	3158746147863677777	58f46482068d306972125336f7f2cfb8	VISA 16 digit	37.8051617757869494	-122.417057922743197
36021	2020-07-09 00:35:39	2020-07-09	Robbin Rutherford	robbin.rutherford@geemail.com	San Francisco	California	180052426817798568	79ed8d584d325928a1d2d0d187762115	American Express	37.7934812611926745	-122.438115928582292
36022	2020-07-09 00:37:38	2020-07-09	Miss Zena Kunze PhD	miss.zena.kunze.phd@geemail.com	Dallas	Texas	630452533564630	ef3856eea8f895ea99b3fd8b7ca8affc	Voyager	32.7050037987336566	-96.8541310129649844
36023	2020-07-09 00:42:03	2020-07-09	Cleora Barrows	cleora.barrows@geemail.com	Davenport	Iowa	4810097665560328	82f264084b55ad2bbf04171152b7be57	VISA 16 digit	41.6529526482600687	-90.6668133675083538
36024	2020-07-09 00:45:23	2020-07-09	Byrd Wunsch	byrd.wunsch@warmmail.com	San Francisco	California	869961227025528261	c0f6a6f660f5f1d890adb2398a6fb72f	JCB 15 digit	37.8115444207897582	-122.414785757230206
36025	2020-07-09 00:46:24	2020-07-09	Ivory Oberbrunner MD	ivory.oberbrunner.md@warmmail.com	Los Angeles	California	180038779582274747	ece3b57ad11a143ac3331a39620f231d	American Express	34.0723417824931403	-118.487152105475957
36026	2020-07-09 00:48:01	2020-07-09	Geralyn Paucek	geralyn.paucek@warmmail.com	Fremont	California	210015538906476348	c22339644ac8a02a9a12e647d3033730	Diners Club / Carte Blanche	37.4070244183465874	-121.851183284445469
36027	2020-07-09 00:51:01	2020-07-09	Adison Mante DDS	adison.mante.dds@geemail.com	San Francisco	California	561299425901545	9a9df954c2786ad08dedb1e1e9133eef	VISA 16 digit	37.7450820466054111	-122.444979529495967
36028	2020-07-09 01:03:39	2020-07-09	Anaya Spinka MD	anaya.spinka.md@warmmail.com	Phoenix	Arizona	6011972474691181177	b292bf8c83ae162db53653b3f6b7c79a	JCB 16 digit	33.612678297043594	-112.052092390966052
36029	2020-07-09 01:05:43	2020-07-09	Dr. Donaciano Waters	dr.donaciano.waters@geemail.com	San Francisco	California	3717375571826806	bf7121e32c20e99db2b5940df2b6a3a8	JCB 16 digit	37.764111562513115	-122.454980451805923
36030	2020-07-09 01:10:40	2020-07-09	Oscar Conroy	oscar.conroy@geemail.com	Atlanta	Georgia	4859481719775151	77f1a0152bf41f8a4a77e2174ceb7a04	VISA 13 digit	33.8413203681163495	-84.3969190735414685
36031	2020-07-09 01:31:53	2020-07-09	Nery Thompson	nery.thompson@geemail.com	Jacksonville	Florida	55842501279514706	501c8f8ef14a5ba2333f3e077f56a09b	Voyager	30.2879767712723478	-81.6189378754779824
36032	2020-07-09 01:38:24	2020-07-09	Brisa Erdman	brisa.erdman@geemail.com	Cambridge	Massachusetts	180087566498957089	12bf3aac0a8f0fbfc866228c5b0a7a62	Diners Club / Carte Blanche	42.2868837868086942	-71.1589545610442826
36033	2020-07-09 01:49:09	2020-07-09	Katlyn Bruen	katlyn.bruen@geemail.com	New York	New York	3709932677493525	925f821aae4081e94f40bb08b90fa138	VISA 16 digit	40.7085144371949141	-73.8813989940926348
36034	2020-07-09 01:53:22	2020-07-09	Orah Gusikowski DDS	orah.gusikowski.dds@warmmail.com	New York	New York	6011677531327844540	b30759d6e1e2e4016b9675241cff0126	Mastercard	40.625641724862156	-73.9622422495752545
36035	2020-07-09 01:53:32	2020-07-09	Kecia Smith	kecia.smith@geemail.com	Columbus	Ohio	180026237193354196	bcbf4907baf198e5417824fbfb479561	Diners Club / Carte Blanche	40.0442763021260504	-83.0766675910681585
36036	2020-07-09 02:00:09	2020-07-09	Harden Harris	harden.harris@geemail.com	Fayetteville	North Carolina	3528516124025759825	08905800a6509ae4292ffd92664fe625	JCB 15 digit	35.0574531893964831	-78.9534488531891299
36037	2020-07-09 02:13:13	2020-07-09	Fredy Prohaska	fredy.prohaska@geemail.com	San Mateo	California	6011443195652690705	babdd02010c55293ccfeb3925cafccd5	JCB 15 digit	37.6077455754738281	-122.253382616894683
36038	2020-07-09 02:16:03	2020-07-09	Mrs. Yamilex Ruecker PhD	mrs.yamilex.ruecker.phd@geemail.com	Frisco	Texas	6011702341382984242	724a63f3bc91db2890a0b94d5c0286e4	Diners Club / Carte Blanche	33.2196532592173668	-96.9143032168246776
36039	2020-07-09 02:19:54	2020-07-09	Clinton Pollich-Cole	clinton.pollich.cole@warmmail.com	Phoenix	Arizona	4403508577804862	94f3c4f2855c2b79ad7e61ee27287a65	Maestro	33.5198902448572227	-112.050953168601183
36040	2020-07-09 02:22:14	2020-07-09	Miss Vivian Dooley	miss.vivian.dooley@geemail.com	Norfolk	Virginia	52795992167369112	7093beefd42ea08c0cd298b8e06c6567	Discover	36.898959773967043	-76.1912029684990699
36041	2020-07-09 02:24:56	2020-07-09	Kaye Klocko	kaye.klocko@woohoo.com	Orlando	Florida	4104371556625481	31aec9bc5ef022a541cba60d5063d932	American Express	28.3916639964826381	-81.2495725630283374
36042	2020-07-09 02:40:44	2020-07-09	Teagan Bechtelar	teagan.bechtelar@woohoo.com	Akron	Ohio	676307397279725	11f5685ce0373a75b7072922686f4602	American Express	41.0676164332609659	-81.5656142004612832
36043	2020-07-09 02:41:08	2020-07-09	Eithel Torp	eithel.torp@geemail.com	Pearland	Texas	4421385230647337	38be08a744a4c3ff719e9b1f8db3037c	JCB 16 digit	29.5425847190238535	-95.295845959972965
36044	2020-07-09 02:44:29	2020-07-09	Almina Hills	almina.hills@geemail.com	Peoria	Arizona	3424686108489665	c7f644a368677f9173036667cbc48e18	VISA 16 digit	33.826736049380898	-112.240511006668214
36045	2020-07-09 02:48:12	2020-07-09	Sheree Steuber	sheree.steuber@woohoo.com	Berkeley	California	54206938887266107	b63244ccfc6b3b1de4d8cb32874e239c	Maestro	37.8628471721480011	-122.279295408192681
36046	2020-07-09 03:16:41	2020-07-09	Miss Dianne Christiansen PhD	miss.dianne.christiansen.phd@woohoo.com	Newark	New Jersey	4660675291448	2ef44489af86f16dcdde2f6cd19152ae	Diners Club / Carte Blanche	40.7659210368905249	-74.1384158329781116
36047	2020-07-09 03:45:19	2020-07-09	Dr. Darl Kovacek Jr.	dr.darl.kovacek.jr.@woohoo.com	New York	New York	6011410547816464626	1313ddef980c1a6476b9eddb8187476d	Voyager	40.6696458276119088	-73.8857389823429287
36048	2020-07-09 03:46:33	2020-07-09	Dr. Darby Blanda PhD	dr.darby.blanda.phd@woohoo.com	Fort Worth	Texas	869932268534108738	1ed3db58d8004c62ac39c78259d52753	VISA 13 digit	32.8209338641315682	-97.3075680624514803
36049	2020-07-09 03:50:27	2020-07-09	Noemi Shanahan PhD	noemi.shanahan.phd@geemail.com	New York	New York	3112671452457764331	f9f4fd287992f45e124a05baa0e6ef9a	Discover	40.6125267443936337	-73.9470754485938642
36050	2020-07-09 04:03:13	2020-07-09	Katerina Rolfson-Strosin	katerina.rolfson.strosin@woohoo.com	West Valley City	Utah	210087916489801111	7ae8f392804d330fc281d1cc2eb981bb	Diners Club / Carte Blanche	40.7876708837449513	-111.935893084316689
36051	2020-07-09 04:23:57	2020-07-09	Pauline Mante	pauline.mante@warmmail.com	Boston	Massachusetts	55522553044604095	d10a5033e006ac57d4b1172e25c57aeb	Diners Club / Carte Blanche	42.3368301429022083	-71.0791130154345154
36052	2020-07-09 04:27:55	2020-07-09	Dr. Emil Green Jr.	dr.emil.green.jr.@geemail.com	San Francisco	California	3096803097212867597	e4aec67ad078b262e4f61180402cf3f6	Maestro	37.7912356984374895	-122.441285898228415
36053	2020-07-09 04:29:09	2020-07-09	Dale Crona	dale.crona@geemail.com	Spokane	Washington	180073579793545760	805dca99099604bafabca32a9a95c721	American Express	47.5758922754559634	-117.404146883673221
36054	2020-07-09 04:39:48	2020-07-09	Ariel Yundt-Gulgowski	ariel.yundt.gulgowski@geemail.com	Sandy Springs	Georgia	869938765139884716	d7c4e0fc5a6513e7155d2a5dac34a8a4	JCB 15 digit	33.9124770000167217	-84.4621887399431301
36055	2020-07-09 04:52:10	2020-07-09	Ronda Fritsch	ronda.fritsch@geemail.com	Lincoln	Nebraska	3112181443028817941	212f92906388a3f31c4812eec80fa5d1	Discover	40.8665759508982305	-96.6668604303777244
36056	2020-07-09 04:52:23	2020-07-09	Brain Barrows I	brain.barrows.i@warmmail.com	New York	New York	502091446786468	431abf9dc9d782d6efaa3999cf0ed4de	Mastercard	40.7527540827393508	-73.8644675004191669
36057	2020-07-09 04:53:39	2020-07-09	Dr. Metro Parisian DVM	dr.metro.parisian.dvm@geemail.com	Evansville	Indiana	3112199597857296475	fc6a64a23d0aebeb1087b6ffb831ee36	Mastercard	37.9601979887250778	-87.5887113605558909
36058	2020-07-09 05:00:44	2020-07-09	Alver Rice PhD	alver.rice.phd@geemail.com	Temecula	California	869977130592871555	7978c9f41ab7d2c466b847fd561b5df8	Maestro	33.4270026765432178	-117.063079084615026
36059	2020-07-09 05:01:10	2020-07-09	Woody Kshlerin	woody.kshlerin@geemail.com	Santa Rosa	California	4936810184669563	7b975ac564f63a134740c45b03fda642	JCB 16 digit	38.4813233278349074	-122.635593231326354
36060	2020-07-09 05:05:52	2020-07-09	Erlene Bode	erlene.bode@geemail.com	Los Angeles	California	4146497328102234	934ffb579657488588ac2d4b64aee400	Voyager	34.0411970627825653	-118.355138498357675
36061	2020-07-09 05:25:47	2020-07-09	Talen Schneider	talen.schneider@warmmail.com	West Valley City	Utah	4954924079780109	8cd6f98a32f38542641428a50c721f79	Diners Club / Carte Blanche	40.6416242481898493	-111.916829647517943
36062	2020-07-09 05:32:36	2020-07-09	Louis Balistreri-Quitzon	louis.balistreri.quitzon@geemail.com	Fremont	California	3047823529792325	74b2c239027951ebbb4b61c5b485d561	VISA 13 digit	37.3958021231628948	-121.935441079920892
36063	2020-07-09 05:34:39	2020-07-09	Mr. Budd Zulauf I	mr.budd.zulauf.i@woohoo.com	Nashville	Tennessee	4538778883303374	e7adb12e6fb87f0fc8a16873f14c240b	Voyager	36.2097117897246008	-86.8787860846053803
36064	2020-07-09 05:35:06	2020-07-09	Philip Ferry	philip.ferry@warmmail.com	Houston	Texas	3112742958131794572	6573143f18b49f5be6e54697ae3339e1	Mastercard	29.8593456295397139	-95.4594600930824839
36065	2020-07-09 05:40:43	2020-07-09	Dr. Liam Botsford MD	dr.liam.botsford.md@geemail.com	New York	New York	869933952467368067	44b07a8f18bf6931a81f3c7063b9a852	Diners Club / Carte Blanche	40.7304857881497568	-73.9120257248997632
36066	2020-07-09 05:42:16	2020-07-09	Alani Hills	alani.hills@geemail.com	Lafayette	Louisiana	3528436693180221711	80fa3777c02cb52af5318033755ec96f	Maestro	30.1256633995544156	-92.04536435984447
36067	2020-07-09 05:49:37	2020-07-09	Kelcie Abbott	kelcie.abbott@geemail.com	Modesto	California	52607151254026774	64bd24b743ac9838dc03f0302a32e329	Maestro	37.5518675570841935	-121.081057421743864
36068	2020-07-09 05:52:47	2020-07-09	Ms. Haven Ernser	ms.haven.ernser@geemail.com	Miami	Florida	4411538724309614	fa26b957eb2b9afce4c7f0aae0ca9c5e	VISA 16 digit	25.8262005342774117	-80.1361151289068232
36069	2020-07-09 05:56:24	2020-07-09	Delphia Thiel	delphia.thiel@warmmail.com	Denver	Colorado	4205164094956312	8659561f31578afa3af0f326b01cede4	VISA 13 digit	39.7595192492525982	-104.832324015466867
36070	2020-07-09 05:57:47	2020-07-09	Etta Bailey	etta.bailey@geemail.com	San Francisco	California	3028813774609729	4c8033cd4482799c9459584a6be3e378	VISA 13 digit	37.7609377628360505	-122.405659118276077
36071	2020-07-09 06:00:36	2020-07-09	Orie Hodkiewicz	orie.hodkiewicz@geemail.com	Columbus	Georgia	4101999284457943	db9722758c162a8d42e00df3bd4a3528	JCB 16 digit	32.5230718328662221	-84.9674560762174451
36072	2020-07-09 06:10:17	2020-07-09	Eusebio Volkman III	eusebio.volkman.iii@warmmail.com	Rialto	California	4692855573675352	d505174d6a6f71c359d355312009fef7	Discover	34.069257298692321	-117.31033399268911
36073	2020-07-09 06:17:43	2020-07-09	Kendall Runolfsdottir MD	kendall.runolfsdottir.md@woohoo.com	Fremont	California	4378363728585	1d40f7345194be5d6387522fef576684	American Express	37.4423775373194374	-122.020558360730107
36074	2020-07-09 06:20:06	2020-07-09	Wayne Walker	wayne.walker@geemail.com	New York	New York	3059962101965533	c82b591d45b073dbbeea01057dab8b80	Voyager	40.7627216759826965	-73.9975226324878577
36075	2020-07-09 06:30:06	2020-07-09	Clemens Murphy	clemens.murphy@warmmail.com	San Francisco	California	6011341564728626733	5fb8a933b7f11cc5a0c928536c2370d5	Diners Club / Carte Blanche	37.8159680041169253	-122.420476608143062
36076	2020-07-09 06:37:21	2020-07-09	Amos Gulgowski	amos.gulgowski@warmmail.com	Chicago	Illinois	3049551929960709	8fdbe1860558642370ea292d2209cd85	Diners Club / Carte Blanche	41.7835835701622074	-87.6223570850241913
36077	2020-07-09 06:42:59	2020-07-09	Rafaela Swaniawski	rafaela.swaniawski@woohoo.com	New York	New York	4094799982199683	6711657e19b824050f2221cfe375b8e4	Voyager	40.737271932534874	-73.9222411120206147
36078	2020-07-09 07:02:38	2020-07-09	Ramon Toy	ramon.toy@warmmail.com	Bakersfield	California	55809553320240071	ab4ad021e07e7cc4c76991e73dca8a6b	Mastercard	35.3783786572691028	-119.081424544126904
36079	2020-07-09 07:22:05	2020-07-09	Mrs. Kerrie Ondricka PhD	mrs.kerrie.ondricka.phd@woohoo.com	Westminster	Colorado	6011456613495443201	d8b7070c6628dd4b0a2db4e06ea7fd0b	Discover	39.8747258805975306	-105.104658116554475
36080	2020-07-09 07:22:21	2020-07-09	Henriette Boyle	henriette.boyle@geemail.com	San Francisco	California	4250241197934828	a06ca47c9bbc0629bd41d9731b8c8e6f	Mastercard	37.7977746643883705	-122.443098757369171
36081	2020-07-09 07:31:40	2020-07-09	Dr. Dwain McCullough	dr.dwain.mccullough@woohoo.com	Fort Lauderdale	Florida	4787552024206848	731f8addfbde27485a2eef794bdaf662	Discover	26.1585624581191709	-80.1921783019144101
36082	2020-07-09 07:33:49	2020-07-09	Lenny Champlin	lenny.champlin@geemail.com	Boston	Massachusetts	3756920495357255	a7ee8d475c0c8417959833068be2dcc9	JCB 15 digit	42.258633487176148	-70.9371305448886034
36083	2020-07-09 07:50:36	2020-07-09	Dr. Ezekiel Schroeder I	dr.ezekiel.schroeder.i@geemail.com	San Jose	California	3039617038998367	cdde0f1bfc83e9f65956e9a8d17998a3	VISA 16 digit	37.2767362176727488	-121.796271199708428
36084	2020-07-09 07:54:33	2020-07-09	Miss Madora Kozey	miss.madora.kozey@geemail.com	Santa Ana	California	639024756917589	95f597ec1ae58ac49dd9cdb680d8aad5	JCB 15 digit	33.6452970641303821	-117.896180018542324
36085	2020-07-09 08:01:13	2020-07-09	Vina Eichmann	vina.eichmann@geemail.com	Milwaukee	Wisconsin	3717355993466365	08158e9e03255507438ce3c14ae0473b	Diners Club / Carte Blanche	43.0735588938549157	-88.0032794526878774
36086	2020-07-09 08:09:07	2020-07-09	Marshall Leuschke	marshall.leuschke@geemail.com	San Bernardino	California	3112540619565515040	5f3e9ac3f49eaa02aafeb18e4b10a196	Maestro	34.1566397189427136	-117.366312400183077
36087	2020-07-09 08:21:52	2020-07-09	Amado Block	amado.block@geemail.com	Tulsa	Oklahoma	3528112805651465319	231617cc4f8a39ec1f0c817739d43c61	Discover	36.039579948447269	-95.8953282119195904
36088	2020-07-09 08:22:03	2020-07-09	Leola Dickens	leola.dickens@geemail.com	Huntsville	Alabama	4667691220892103	8084a1e911c3c98c5c67f5d0739bac22	Mastercard	34.7379344098046374	-86.5973090892210564
36089	2020-07-09 08:31:11	2020-07-09	Maribel Kemmer	maribel.kemmer@geemail.com	Fairfield	California	53773393112871771	f1c302736ace9e69f5214dbc8a85b51d	Diners Club / Carte Blanche	38.2735078953795167	-122.015468816273284
36090	2020-07-09 08:32:44	2020-07-09	Mrs. Nana Larson PhD	mrs.nana.larson.phd@geemail.com	Anchorage	Alaska	210047125355949405	9c09f9544662d38ac3f5836952c5fd56	JCB 15 digit	61.2319912863645754	-149.311541842495274
36091	2020-07-09 08:36:07	2020-07-09	Mrs. Anissa Langworth DDS	mrs.anissa.langworth.dds@warmmail.com	Fayetteville	North Carolina	630433750134562	cdd543919774f60e18a5151e5bc07534	American Express	34.9931531965520222	-78.9466339279562277
36092	2020-07-09 08:43:23	2020-07-09	Rayburn Daugherty	rayburn.daugherty@geemail.com	Concord	California	54496235689035882	88014b19fed8d0127d0f767218b1b68a	JCB 16 digit	37.95073787848726	-121.982989122875409
36093	2020-07-09 08:47:56	2020-07-09	Erik O'Connell	erik.o'connell@geemail.com	Eugene	Oregon	3528287580385641597	51ca7a57e48decdf82f0e6b4e4d8f5de	JCB 16 digit	44.0040117777612068	-123.153905890927476
36094	2020-07-09 08:53:04	2020-07-09	Raoul Mills III	raoul.mills.iii@geemail.com	Winston–Salem	North Carolina	6011298093417582471	c39f9a1893e9ae6cbacb1cd841563c35	JCB 16 digit	36.0047141488406766	-80.2334038253072634
36095	2020-07-09 08:53:33	2020-07-09	Lonny Abshire Jr.	lonny.abshire.jr.@geemail.com	Chandler	Arizona	54691547930071042	0b593cd2b84ab311f77c03be6fc8eb31	Mastercard	33.2090747353244566	-111.759993418248001
36096	2020-07-09 08:54:44	2020-07-09	Angele Auer	angele.auer@geemail.com	Indianapolis	Indiana	6011142095524159869	c13e75b6ab75cce2a948a308f3cf73b5	VISA 13 digit	39.7666692677892755	-86.0720848140507968
36097	2020-07-09 09:01:10	2020-07-09	Sharlene Nienow-Heller	sharlene.nienow.heller@geemail.com	San Francisco	California	4454750861881	5204b415798037cf11a1774ef39152d5	Maestro	37.8186525338282991	-122.447944617475855
36098	2020-07-09 09:06:33	2020-07-09	Corinne Kozey MD	corinne.kozey.md@geemail.com	New York	New York	6011685116700859107	1cc33e9e1ab3f5657728270f8479aeee	Maestro	40.5637930740825823	-73.9979126553412527
36099	2020-07-09 09:08:20	2020-07-09	Diana Quitzon DDS	diana.quitzon.dds@geemail.com	Irving	Texas	501899231961436	0ee8ea16920641039e38eec59a21c226	Maestro	32.8502088958814724	-97.0379184983950154
36100	2020-07-09 09:13:43	2020-07-09	Evans Luettgen	evans.luettgen@geemail.com	Long Beach	California	4902230608678	1311785e7cf8e3e39692dec6ea5ef789	JCB 15 digit	33.7429588184047446	-118.107363015568993
36101	2020-07-09 09:19:22	2020-07-09	Mr. Arlo Emmerich Sr.	mr.arlo.emmerich.sr.@geemail.com	Stockton	California	3088143713502022300	c8221e958e3c1e37c0753946aa89ac5b	Mastercard	37.8796242755569565	-121.286968309114869
36102	2020-07-09 09:27:34	2020-07-09	Martha Smith	martha.smith@warmmail.com	Minneapolis	Minnesota	4186335910768528	89fad34743bdbc1cc22e8f2728f0e7f9	JCB 15 digit	45.0406540705908043	-93.3050409448139391
36103	2020-07-09 09:29:52	2020-07-09	Jaquez Davis	jaquez.davis@woohoo.com	Seattle	Washington	6011339441540813902	5088fa4bf3b17dd1871a69f1f2b816e5	JCB 15 digit	47.6395143495798123	-122.377838264537601
36104	2020-07-09 09:30:42	2020-07-09	Miss Leitha Legros	miss.leitha.legros@geemail.com	Grand Prairie	Texas	6011666512688730679	24d18b957efc0638e2394db83f00b004	VISA 13 digit	32.6811698481027051	-97.020160132214798
36105	2020-07-09 09:32:33	2020-07-09	Etha Metz	etha.metz@geemail.com	Berkeley	California	52444815276731861	4f290381de623479014cd8f34ee54257	JCB 16 digit	37.8730390371832897	-122.272918569933935
36106	2020-07-09 09:33:06	2020-07-09	Cherie Abbott	cherie.abbott@geemail.com	San Francisco	California	869963002601536659	399f3c7b8090b74f0d36d356f97652f8	VISA 13 digit	37.760383146226431	-122.431629671874603
36107	2020-07-09 09:36:24	2020-07-09	Zachariah Crona	zachariah.crona@warmmail.com	Chicago	Illinois	3112660301852817132	b4e0ea1717b2b806e9ccc307a4a29a97	VISA 16 digit	41.9083469630986443	-87.5897288829583687
36108	2020-07-09 09:40:49	2020-07-09	Campbell Mohr-Davis	campbell.mohr.davis@geemail.com	New York	New York	3735483695786852	ef6fadb44e33039171b8086ea8819026	JCB 16 digit	40.6453107840605057	-73.9876188436418687
36109	2020-07-09 09:41:11	2020-07-09	Fount Schuster Sr.	fount.schuster.sr.@geemail.com	Henderson	Nevada	3112556746144956659	09b4d432f92c53a052d4dadfe3aa1ce1	Diners Club / Carte Blanche	35.9228860464811319	-115.120961902678758
36110	2020-07-09 09:51:40	2020-07-09	Lynwood Nitzsche	lynwood.nitzsche@warmmail.com	Berkeley	California	869917988376216005	2bdf23e8237e5432ccef3dfcee7d0d55	Maestro	37.8707775589763855	-122.259099463682972
36111	2020-07-09 10:11:56	2020-07-09	Tracie Kemmer DVM	tracie.kemmer.dvm@geemail.com	Omaha	Nebraska	4981105582197828	fa031b9ecb0c29406dc45d508b86d134	VISA 16 digit	41.2863219968654249	-95.9863733742035947
36112	2020-07-09 10:23:29	2020-07-09	Rafael Feest II	rafael.feest.ii@geemail.com	Newark	New Jersey	3158094991950577814	e625c92c6cb9bc2592b4973b22643d5f	Discover	40.7886902566913534	-74.1309098576404182
36113	2020-07-09 10:30:40	2020-07-09	Jaime Brekke	jaime.brekke@geemail.com	Lakewood	New Jersey	180095007470824344	c3418445ba29974904c2cfd3ee4191aa	JCB 15 digit	40.0422480796281235	-74.2952229656089145
36114	2020-07-09 10:30:56	2020-07-09	Shay Osinski	shay.osinski@woohoo.com	Los Angeles	California	3484253016520862	eb910036ab830afb2e7e0c8827d91361	American Express	34.0703132130537156	-118.429058419679478
36115	2020-07-09 10:39:11	2020-07-09	Luanne Gulgowski	luanne.gulgowski@geemail.com	Hollywood	Florida	4429274760041	b69f95974f94a055511f657ef00a6962	VISA 16 digit	26.0800503906738008	-80.0989879682943098
36116	2020-07-09 10:41:55	2020-07-09	Clydie Strosin	clydie.strosin@geemail.com	Tucson	Arizona	3056283701224194	ad31aff0cef41caec4febed2e84ca4d7	Voyager	32.1631874718278681	-110.913810853170602
36117	2020-07-09 10:42:39	2020-07-09	Bettie Nienow	bettie.nienow@warmmail.com	Virginia Beach	Virginia	869994595168412589	4d247168dcd74ba8102aa09c33996ebc	Maestro	36.8454202142730338	-75.9410141406718679
36118	2020-07-09 10:42:43	2020-07-09	Elfie Zboncak-Nitzsche	elfie.zboncak.nitzsche@geemail.com	Columbus	Ohio	4074515406127	aaad9de3286aefe0c2751542163cf881	Mastercard	40.0151069270957223	-82.9898861004740098
36119	2020-07-09 10:42:53	2020-07-09	Mr. Solon Labadie DVM	mr.solon.labadie.dvm@geemail.com	Lincoln	Nebraska	4160082994138950	e39ed0ec2e4eabe69884fc755bbfd3fd	VISA 16 digit	40.8660134233087291	-96.7215880791351168
36120	2020-07-09 10:49:36	2020-07-09	Jaiden Monahan III	jaiden.monahan.iii@geemail.com	Santa Clarita	California	4242608594983858	8eb4e6f92538135621b558adc200a42c	JCB 15 digit	34.4252760289907442	-118.552738401583213
36121	2020-07-09 10:55:29	2020-07-09	Dale Schimmel DDS	dale.schimmel.dds@geemail.com	San Francisco	California	3337395999444077073	8818f5478f62c9c05e653e79fdee0ada	JCB 16 digit	37.8043968788868696	-122.41969621647111
36122	2020-07-09 11:00:01	2020-07-09	Baldwin Botsford DVM	baldwin.botsford.dvm@geemail.com	Houston	Texas	3112352646800307997	6fe80e9d22f8eef2b07e4f6454876351	VISA 16 digit	29.8089118233494474	-95.3355141996420912
36123	2020-07-09 11:10:48	2020-07-09	Mr. Wirt Friesen	mr.wirt.friesen@geemail.com	Plano	Texas	4624290411583	1fe12336ad39acf93e32513f251ac7b1	JCB 16 digit	33.0942737850911968	-96.6825719981171261
36124	2020-07-09 11:16:05	2020-07-09	Mr. Elihu Grady	mr.elihu.grady@geemail.com	Salt Lake City	Utah	51961365732437193	30ab418652d9e9fee602bfd233bed3a3	VISA 16 digit	40.7195541848573797	-111.966468698805201
36125	2020-07-09 11:17:28	2020-07-09	Dicie Brown	dicie.brown@woohoo.com	Boston	Massachusetts	869960260672768717	40151df26f020e82c3e5ef69ebcd29a9	Discover	42.3002934303302354	-70.9450587562237018
36126	2020-07-09 11:22:53	2020-07-09	Mena Fisher	mena.fisher@geemail.com	Berkeley	California	3096844650706508001	2164d3f2b1ff0635c73e7e3255141d7b	JCB 16 digit	37.9066499066646827	-122.280601042274384
36127	2020-07-09 11:23:14	2020-07-09	Mr. Frazier O'Conner	mr.frazier.o'conner@geemail.com	San Bernardino	California	869906145727751767	f60729bd695cec650517f04835828678	JCB 15 digit	34.2325187097102344	-117.300216565352301
36128	2020-07-09 11:39:34	2020-07-09	Damari Morar	damari.morar@geemail.com	Davie	Florida	3112711047076424176	135c95a0ec3cef71308c54db508f43a4	VISA 16 digit	26.1657034007165592	-80.3138698016200152
36129	2020-07-09 11:49:46	2020-07-09	Dr. Taylor Donnelly	dr.taylor.donnelly@woohoo.com	Tacoma	Washington	676193740412395	570e01a4d257bfb7b5858592d69eb072	Maestro	47.1674500843163571	-122.447143707075341
36130	2020-07-09 11:56:28	2020-07-09	Dr. Sina Keeling	dr.sina.keeling@geemail.com	San Francisco	California	869906868759213667	ca708374aef116b1459e3da469214ca7	VISA 16 digit	37.7917487501132285	-122.466683794930489
36131	2020-07-09 12:03:26	2020-07-09	Harding Pagac	harding.pagac@geemail.com	Richmond	Virginia	6011903127246818057	7e89deaf19091309c218f69cae840d4f	American Express	37.5538311458412508	-77.4669336979035279
36132	2020-07-09 12:10:56	2020-07-09	Nyla Farrell	nyla.farrell@geemail.com	Columbus	Ohio	210099968084382498	a57980ec7466f8955ce99dcfd21671f7	JCB 16 digit	39.9564002910673608	-83.0319647175494708
36133	2020-07-09 12:22:26	2020-07-09	Linnie Legros	linnie.legros@geemail.com	Berkeley	California	869990446632080293	3ab97caa909138164c209d83f4e46b75	VISA 13 digit	37.8997583078373736	-122.276357030181131
36134	2020-07-09 12:27:01	2020-07-09	Nicholas Dickens	nicholas.dickens@geemail.com	New York	New York	3528496087653351856	db3502478ee4a413b0d658d97fac70c5	VISA 16 digit	40.616906314970926	-74.0220366154693039
36135	2020-07-09 12:27:43	2020-07-09	Hali Feeney	hali.feeney@geemail.com	Daly City	California	4003365773179266	f12ecb020c1aae5d64c2b7b60e1f3f16	VISA 16 digit	37.6865565105263087	-122.517100174501536
36136	2020-07-09 12:27:55	2020-07-09	Allisson Kreiger	allisson.kreiger@geemail.com	West Palm Beach	Florida	4103842529754	d5454ec57227f48f3344c9f183bdfbfe	American Express	26.7393710763040957	-80.0990767706953051
36137	2020-07-09 12:29:12	2020-07-09	Shanice VonRueden	shanice.vonrueden@geemail.com	Tucson	Arizona	869926079539204259	7568c99c1f80f3a76a25eef3502a2e7b	VISA 16 digit	32.1272150875575875	-110.856421109684177
36138	2020-07-09 12:32:01	2020-07-09	Mr. Tomie Streich IV	mr.tomie.streich.iv@warmmail.com	Overland Park	Kansas	4598623533370752	7958a677419243adf21b1a5912a24887	JCB 15 digit	38.8063454695846914	-94.6943275807931997
36139	2020-07-09 12:33:00	2020-07-09	Yaretzi Walker	yaretzi.walker@geemail.com	Lexington	Kentucky	4463086723566	da4e9f48b239aa1f00f29eb8fb727518	American Express	38.0836141760338123	-84.3706879854101572
36140	2020-07-09 12:40:58	2020-07-09	Miss Tristen Kuhn PhD	miss.tristen.kuhn.phd@geemail.com	Washington	District of Columbia	4411507126632568	7a60256c2fa7df71dd162fed5594f73d	Diners Club / Carte Blanche	38.8186978081040053	-76.9633167624685939
36141	2020-07-09 12:57:26	2020-07-09	Logan Johns-Pollich	logan.johns.pollich@geemail.com	Chicago	Illinois	210006990300748452	31ca17b492983365689dcbedf5b0128c	VISA 16 digit	41.8235342414420117	-87.7766926538228915
36142	2020-07-09 13:08:57	2020-07-09	Carlo Lockman	carlo.lockman@warmmail.com	Philadelphia	Pennsylvania	4230144539148	61be996ddd3e7503e603a072b9c1ab50	Maestro	39.9399739447940121	-75.1748295240469275
36143	2020-07-09 13:11:57	2020-07-09	Mills Lemke	mills.lemke@geemail.com	New York	New York	3012111632277904	fc11034f07875505b66988e9be5fbc46	Mastercard	40.6781563720889352	-74.0250119375891984
36144	2020-07-09 13:23:23	2020-07-09	Abby Kulas	abby.kulas@geemail.com	Fort Worth	Texas	3715043141578131	e736baf69784749f7ac6abf1143a011e	Mastercard	32.8598014327287657	-97.2581227195270372
36145	2020-07-09 13:27:44	2020-07-09	Kwame Will V	kwame.will.v@warmmail.com	Overland Park	Kansas	869977740478956674	fffd9e2f3493d366bd20e1ecac724c0b	American Express	38.9037188495378956	-94.6926705489441787
36146	2020-07-09 13:27:58	2020-07-09	Miranda Glover	miranda.glover@geemail.com	Portland	Oregon	639004464880220	e36293c8c6782ea3ec425606cbb3c51b	JCB 16 digit	45.4988057306855893	-122.601671715732664
36147	2020-07-09 13:40:26	2020-07-09	Brandt Spencer	brandt.spencer@geemail.com	Raleigh	North Carolina	869931938797870007	3bdeb5bb684b898573357b9eec3fc32f	JCB 15 digit	35.7818357797939299	-78.681624206754563
36148	2020-07-09 13:47:21	2020-07-09	Dr. Brodie Wiza II	dr.brodie.wiza.ii@geemail.com	San Francisco	California	869911250776633586	08159bf3154b04f6f3cbb947a8fce754	JCB 16 digit	37.7382274909030002	-122.431366000431083
36149	2020-07-09 13:53:43	2020-07-09	Galilea Glover	galilea.glover@warmmail.com	New York	New York	54908690713001635	1bd73e164db05a288314e1b7173a28a3	VISA 13 digit	40.7508686933424329	-73.9625795512821469
36150	2020-07-09 13:55:25	2020-07-09	Rand Wisozk	rand.wisozk@woohoo.com	Omaha	Nebraska	3337158538215471631	e1d1384f712fab0e39e38c3158654bc9	Discover	41.2772054974135045	-95.9763377769965729
36151	2020-07-09 14:15:11	2020-07-09	Myrtice Schmidt	myrtice.schmidt@geemail.com	Oklahoma City	Oklahoma	3337308416003994586	c2e79e444b3c31d5c3c19a205e1e8fb8	American Express	35.507752373945344	-97.5277222269110382
36152	2020-07-09 14:15:32	2020-07-09	Jemal Smith	jemal.smith@geemail.com	Los Angeles	California	4690158480054056	3438a4bf02a54fc1613812134f0e8fc0	VISA 13 digit	33.9317040966689589	-118.421763638313109
36153	2020-07-09 14:17:52	2020-07-09	Albion Borer III	albion.borer.iii@geemail.com	Long Beach	California	53660414107387593	5d37d61c896eb9ae11d578df421a95c6	Mastercard	33.7935317406251983	-118.105296154103428
36154	2020-07-09 14:32:01	2020-07-09	Gia Thompson	gia.thompson@geemail.com	Los Angeles	California	54433948428859216	d8de974dfbaa3c44dfb56ab971f82900	Mastercard	34.1111028950527313	-118.414088922831411
36155	2020-07-09 14:35:19	2020-07-09	Samara Abbott	samara.abbott@geemail.com	Philadelphia	Pennsylvania	3158832611479084897	c22af17bfdb3dc70fa1b4ebd54d07947	Discover	39.9732288938440377	-75.1834124819275047
36156	2020-07-09 14:36:07	2020-07-09	Ingeborg Hettinger-Steuber	ingeborg.hettinger.steuber@geemail.com	Sunnyvale	California	501864566038598	a4ea0e530590bd5c30b9afe8abf06ea8	JCB 15 digit	37.3076513596337307	-122.093972506207606
36157	2020-07-09 14:43:00	2020-07-09	Dr. Paola Haley	dr.paola.haley@warmmail.com	Jacksonville	Florida	4948457990026	728a65c4359c499ae2f650f222ff4aaa	Maestro	30.3313252172019325	-81.6736111653581389
36158	2020-07-09 14:44:29	2020-07-09	Lucero Gulgowski-Grimes	lucero.gulgowski.grimes@geemail.com	Warren	Michigan	869923653149433251	98d845277a1f564994c44261a00e85ed	VISA 16 digit	42.5317932527042899	-83.0250162888784047
36159	2020-07-09 14:57:54	2020-07-09	Theresa Conn	theresa.conn@geemail.com	Jersey City	New Jersey	210085206210767217	382ad891873d56c0865a04ad2a3c4094	Maestro	40.6783635636266325	-73.9674303660590198
36160	2020-07-09 15:03:51	2020-07-09	Dr. Golden Harber DVM	dr.golden.harber.dvm@geemail.com	Tyler	Texas	3528517773052476825	ebe1a0b55f44f07b6ca28c478f4618f5	JCB 16 digit	32.3610061789911256	-95.3660825862657191
36161	2020-07-09 15:10:12	2020-07-09	Rayna Gutkowski	rayna.gutkowski@geemail.com	Woodbridge	New Jersey	210021046669894675	4dfc561f4fd1f9d6fe77ed849f2a654b	JCB 16 digit	40.5474270034737856	-74.3224653689514838
36162	2020-07-09 15:16:22	2020-07-09	Dr. Jaquez Funk MD	dr.jaquez.funk.md@woohoo.com	San Jose	California	869910150701451511	6eb900f85973dfeec5d7476e34590945	VISA 13 digit	37.3891275602679727	-121.736929270647096
36163	2020-07-09 15:20:16	2020-07-09	Melissa Lockman-Morar	melissa.lockman.morar@geemail.com	Baltimore	Maryland	4023803430144295	cdf9c16f26933ab9749e51cea3ccd8d8	Diners Club / Carte Blanche	39.3086273429915281	-76.64335294538364
36164	2020-07-09 15:20:36	2020-07-09	Christophe Boyer	christophe.boyer@geemail.com	New York	New York	3096366366476856318	f82ce7e1f1cee650a8317bcda273949b	VISA 13 digit	40.7110308630149831	-73.9869053437270168
36165	2020-07-09 15:21:16	2020-07-09	Miss Hasel Erdman DVM	miss.hasel.erdman.dvm@geemail.com	Birmingham	Alabama	3158593285450316286	34dd418c667227f8870ac3075296eba1	Diners Club / Carte Blanche	33.4538427387155579	-86.7793699675481776
36166	2020-07-09 15:27:01	2020-07-09	Ayana Dickens-Carter	ayana.dickens.carter@geemail.com	New York	New York	3337796634754062226	8055c3756117773e8597de806dac484f	Discover	40.6597499676272278	-73.9919679458148778
36167	2020-07-09 15:40:07	2020-07-09	Gerry Moen	gerry.moen@geemail.com	New York	New York	4123765191606	d3ec44bf61cddc94917bf0604dca8d03	VISA 16 digit	40.5654035534467567	-73.9142743052810403
36168	2020-07-09 15:55:15	2020-07-09	Rowan Lemke	rowan.lemke@geemail.com	Oakland	California	3158733997227180974	a1b34f1f153104cfaecf4f91eb9a9984	JCB 15 digit	37.7892620337773124	-122.303810021893341
36169	2020-07-09 16:05:21	2020-07-09	Yoselin Walker	yoselin.walker@geemail.com	Los Angeles	California	4411148536729569	c344aa57c86cee83e95c666b763b8a39	Voyager	33.9409171642601493	-118.446609135017908
36170	2020-07-09 16:15:14	2020-07-09	Pratt Reichel	pratt.reichel@geemail.com	Cape Coral	Florida	55158747712810064	08465a41100e57ba6d071659e7085233	JCB 16 digit	26.5573370425466457	-82.0848407936818916
36171	2020-07-09 16:23:56	2020-07-09	Demario Braun	demario.braun@geemail.com	Los Angeles	California	6011254739369508995	cce2428bc3074c61b58036d924ddc905	Maestro	33.9624067577399273	-118.46224119705073
36172	2020-07-09 16:40:49	2020-07-09	Ida Daugherty	ida.daugherty@geemail.com	Chicago	Illinois	503801883328971	f94237091c5c3e4c07477a8efa5fb8e5	JCB 16 digit	41.7718237248085487	-87.6533777740348086
36173	2020-07-09 16:44:07	2020-07-09	January Kozey-Hamill	january.kozey.hamill@geemail.com	New York	New York	4979844473430690	8679e9afa4112cef810d5c3cb52e3fa0	JCB 16 digit	40.614954842323435	-73.8945424736838703
36174	2020-07-09 16:44:51	2020-07-09	Dr. Imanol Hyatt DDS	dr.imanol.hyatt.dds@geemail.com	Rancho Cucamonga	California	180011358359767844	acfb160244cfcb1e088ea47115697a5a	VISA 16 digit	34.029415621514616	-117.477084279387071
36175	2020-07-09 16:49:44	2020-07-09	Dr. Jadiel Block	dr.jadiel.block@warmmail.com	El Cajon	California	3724842335166432	516a6fc5caf71f731307002acb989d84	American Express	32.7278214819736775	-116.974465342815606
36176	2020-07-09 16:55:09	2020-07-09	Dr. Dell Schumm Sr.	dr.dell.schumm.sr.@woohoo.com	Raleigh	North Carolina	6011283646759592163	9131b04206ffac90c977cc41f4b304b1	Voyager	35.858763782646875	-78.6918329810660424
36177	2020-07-09 17:02:25	2020-07-09	Nanette Rath	nanette.rath@geemail.com	Omaha	Nebraska	3020032803893190	16f5d3e274b04a707c0cffb07c5cce28	Discover	41.2371094116620753	-96.1007240684818527
36178	2020-07-09 17:05:38	2020-07-09	Alwine Yundt DVM	alwine.yundt.dvm@geemail.com	Stamford	Connecticut	180016230484594069	f2e94e6b804eb32c2b0180a318b59e30	JCB 15 digit	41.1220605732757605	-73.4484276911746718
36179	2020-07-09 17:06:08	2020-07-09	Isla Heidenreich	isla.heidenreich@geemail.com	Wichita	Kansas	54131603918711931	02c98d06c7b363447f356243869200c8	VISA 16 digit	37.6705378720413862	-97.4322873301539545
36180	2020-07-09 17:26:13	2020-07-09	Tanya Schultz	tanya.schultz@geemail.com	Palmdale	California	4905832232631	bd9402e5cb6e10b6542c797907fa6db6	Diners Club / Carte Blanche	34.6842116684038189	-118.156675829644882
36181	2020-07-09 17:30:31	2020-07-09	Napoleon Breitenberg Jr.	napoleon.breitenberg.jr.@woohoo.com	Dallas	Texas	210020528262764968	1bfbd80eec1e103a2da743f6c6b93419	Mastercard	32.759968114112695	-96.7843334933705535
36182	2020-07-09 17:38:37	2020-07-09	Jimmy Runolfsdottir Jr.	jimmy.runolfsdottir.jr.@warmmail.com	San Francisco	California	561228587788614	0dd28574e4af2a9718c3ea59c6d3036f	Voyager	37.7632145130656696	-122.458300397429326
36183	2020-07-09 17:42:24	2020-07-09	Alessandra Bauch DVM	alessandra.bauch.dvm@woohoo.com	Los Angeles	California	4431512053163	165241196531e70fabdb5fca0e6e0a3b	Voyager	34.0867870663624259	-118.458686698832736
36184	2020-07-09 17:48:32	2020-07-09	Brett Murray	brett.murray@geemail.com	Rochester	Minnesota	6011218029127226972	69139783abc6541914a39362eefcccc6	Voyager	43.9615838413029891	-92.3859967498227945
36185	2020-07-09 18:07:31	2020-07-09	Bluford Schaden-Leannon	bluford.schaden.leannon@geemail.com	Louisville	Kentucky	6011602043879802181	48739c033db986ef122c7fb69ee1410f	Voyager	38.105943983364476	-85.5542862048909143
36186	2020-07-09 18:10:13	2020-07-09	Dr. Rodger Schuppe	dr.rodger.schuppe@geemail.com	New York	New York	3743463669882390	b5afb3e384d2ed7d0990dbcd6664ece5	VISA 13 digit	40.6521444934178149	-73.8490571287356232
36187	2020-07-09 18:13:25	2020-07-09	Mr. Thurlow Schmeler	mr.thurlow.schmeler@geemail.com	Oklahoma City	Oklahoma	6011513984380887963	50c4e130f375fd10757e96e0c12734c6	VISA 13 digit	35.5189826968502302	-97.4220631990011725
36188	2020-07-09 18:20:40	2020-07-09	Ms. Bula Brekke	ms.bula.brekke@geemail.com	Berkeley	California	3013253357311168	8bd78d467fae114fd4a7c05bd5c04990	Voyager	37.8824316458450951	-122.252165279219255
36189	2020-07-09 18:32:32	2020-07-09	Von Harber	von.harber@geemail.com	Jersey City	New Jersey	210075330591228557	d217ac632de20d9a8625720b560fb70a	Discover	40.6889408281013374	-74.1615278986238025
36190	2020-07-09 18:47:21	2020-07-09	Adamaris Williamson	adamaris.williamson@geemail.com	Cape Coral	Florida	3158626491747203888	c69f29a6c459313fc4e7086dca13073a	VISA 13 digit	26.6384422147151092	-81.9928642395023246
36191	2020-07-09 18:52:05	2020-07-09	Prince Dach-Bartell	prince.dach.bartell@geemail.com	Raleigh	North Carolina	4390934712021508	8057d527520ebbe76dbc6cab32e13fc8	Maestro	35.7851502561144486	-78.6496910654410755
36192	2020-07-09 19:05:58	2020-07-09	Lady Bins	lady.bins@geemail.com	Hampton	Virginia	869907115959560078	58f85841e8b9acd1f8c0b87949de93e2	JCB 15 digit	37.0889554853104073	-76.307533886153621
36193	2020-07-09 19:11:37	2020-07-09	Evelyn Gerhold	evelyn.gerhold@warmmail.com	San Francisco	California	3016122308370739	11fa26450390cbfb993a5a4918d84d9e	JCB 16 digit	37.7658911735469616	-122.442243694978501
36194	2020-07-09 19:23:14	2020-07-09	Opal Bruen-Greenfelder	opal.bruen.greenfelder@geemail.com	Norwalk	California	3000389589476982	b7cd7cb099ffd46f0541085f2a46998a	Mastercard	33.8261424061492093	-118.00061116917432
36195	2020-07-09 19:33:44	2020-07-09	Iva Rosenbaum IV	iva.rosenbaum.iv@geemail.com	Newark	New Jersey	53930950057476013	e2261201446a39521cdc1edeecb08647	American Express	40.7106345200825501	-74.1933895478699412
36196	2020-07-09 19:34:10	2020-07-09	Myles Weber	myles.weber@geemail.com	New York	New York	3460152320997121	97ec1e20f1cc53bffc8f3ab59ba5d9fb	Diners Club / Carte Blanche	40.6358151353653483	-74.0234622906323523
36197	2020-07-09 19:36:42	2020-07-09	Carmel Deckow	carmel.deckow@geemail.com	Jacksonville	Florida	3035540949599906	1f141dc926ff9c2e8393e19dd8873fc0	Discover	30.3057942111097276	-81.6758199878580911
36198	2020-07-09 19:37:03	2020-07-09	Marge O'Connell	marge.o'connell@geemail.com	Phoenix	Arizona	869915909556865629	a2d0220f11c95d0f902e2c7089aad86f	JCB 16 digit	33.6312971270110452	-112.10733411469721
36199	2020-07-09 19:47:14	2020-07-09	Isham Braun	isham.braun@geemail.com	Fontana	California	4691279042549	17bc0dc37fd3e4e783b94839c07150ac	Discover	34.0554143308810922	-117.501789571279289
36200	2020-07-09 19:49:42	2020-07-09	Dr. Rush Streich	dr.rush.streich@geemail.com	Plano	Texas	210012534039079284	1485e3cba502c98dbcb1424c65ae8f08	JCB 16 digit	33.0343695383138964	-96.7719617337636606
36201	2020-07-09 19:52:01	2020-07-09	Mrs. Columbia Doyle DVM	mrs.columbia.doyle.dvm@geemail.com	El Cajon	California	869939894965203137	1cc07aa5eae378dd18e25774f8f70505	Voyager	32.7702915790963871	-116.893088825298108
36202	2020-07-09 19:53:34	2020-07-09	Sibyl Kilback	sibyl.kilback@geemail.com	San Francisco	California	180053735720295234	c78231f45b070d359242678836130ded	American Express	37.7861084355483712	-122.446555041612314
36203	2020-07-09 20:14:37	2020-07-09	Candyce Rippin	candyce.rippin@geemail.com	Sioux Falls	South Dakota	4618974398447	1b498e903db45e280568f0d50883288e	Diners Club / Carte Blanche	43.5606705617245282	-96.8229774069674249
36204	2020-07-09 20:25:30	2020-07-09	Dr. Jaylene Bergstrom	dr.jaylene.bergstrom@woohoo.com	Columbia	South Carolina	3528952588232203176	32793b42606fa0060151188ecd0a418a	Maestro	33.9619801122028377	-80.8924351613987227
36205	2020-07-09 20:27:09	2020-07-09	Rand Rowe Sr.	rand.rowe.sr.@geemail.com	Springfield	Missouri	630475877483216	ecf0fd0c0836b994596e0bae6c1707a1	Voyager	37.1694902172505905	-93.2302224171638585
36206	2020-07-09 20:30:59	2020-07-09	Keri O'Hara-Ledner	keri.o'hara.ledner@geemail.com	Corpus Christi	Texas	6011974358244636787	f2e5d7d2b5e74e29328e96dd30dc1ffa	JCB 15 digit	27.7961159372173263	-97.2356607979457834
36207	2020-07-09 20:41:09	2020-07-09	Dr. Jamarcus Koepp	dr.jamarcus.koepp@woohoo.com	San Francisco	California	3528880347688963941	5a3d60ff54e272dc94e26ee9f8c341f4	VISA 13 digit	37.7751985797633978	-122.409313474618173
36208	2020-07-09 20:45:35	2020-07-09	Tavion Schmitt	tavion.schmitt@geemail.com	Alexandria	Virginia	4734550268229132	466fe265476855fb1e78e27b56fb19e8	JCB 16 digit	38.7991809132158707	-77.027596009567759
36209	2020-07-09 20:46:30	2020-07-09	Namon Will	namon.will@geemail.com	Jacksonville	Florida	52807876785438761	bf40166996100aabd1956d6ab859ede1	VISA 16 digit	30.2517831864818945	-81.6855294632803748
36210	2020-07-09 20:51:30	2020-07-09	Rene Emmerich DVM	rene.emmerich.dvm@geemail.com	Berkeley	California	3770339776827286	3f60b0c25a9373513cad6a7f06ae5ca2	Discover	37.9025967788883094	-122.261005395004915
36211	2020-07-09 20:55:00	2020-07-09	Bennie Lowe	bennie.lowe@warmmail.com	Houston	Texas	3088054579116803410	9ae3e25a2ecec4f4d2314c17f92fe3d6	JCB 16 digit	29.7794020333871252	-95.3568351967740853
36212	2020-07-09 20:58:35	2020-07-09	Miss Krystle Hartmann DDS	miss.krystle.hartmann.dds@geemail.com	Pembroke Pines	Florida	4898866565183836	288bb290e7d225f350e5c4f3be57009b	VISA 16 digit	25.930356570988895	-80.2938774278290595
36213	2020-07-09 21:10:12	2020-07-09	Mr. Hartwell Rath	mr.hartwell.rath@geemail.com	Clarksville	Tennessee	6011195410927633509	ae64a72d4fbeab9ebde9a1bf52e101c2	VISA 16 digit	36.5329497639216498	-87.4211779908228692
36214	2020-07-09 21:15:30	2020-07-09	Mr. Jaime Keebler	mr.jaime.keebler@woohoo.com	Los Angeles	California	4380570824371	a699ec9f4de14d8b8af37d6f910b53a4	VISA 13 digit	34.0200274871528094	-118.389275607559085
36215	2020-07-09 21:29:20	2020-07-09	Jahiem Breitenberg	jahiem.breitenberg@warmmail.com	Chicago	Illinois	55397616657788646	c74f4bedb7c361a6a20247c0677d9ff3	American Express	41.9097164367161739	-87.7235286677286012
36216	2020-07-09 21:38:51	2020-07-09	Boss Kilback	boss.kilback@geemail.com	Fort Collins	Colorado	3096306870378118936	cb9764f6bbf9860940846ec8d89f578d	Discover	40.456056681710109	-104.9979943762023
36217	2020-07-09 21:43:07	2020-07-09	Dr. Berdie Crona	dr.berdie.crona@woohoo.com	San Jose	California	210061958258237747	c9db7835d535e933f62a51782841437a	VISA 13 digit	37.3372227814801079	-121.854290301141887
36218	2020-07-09 21:46:13	2020-07-09	Delphia Nienow	delphia.nienow@geemail.com	San Diego	California	869907283562303458	555142e37e54ab6729902ca09394ac32	Voyager	32.9111037484437219	-117.118812879165645
36219	2020-07-09 21:49:44	2020-07-09	Dr. Devante Rolfson V	dr.devante.rolfson.v@geemail.com	New Orleans	Louisiana	4193120545315841	7ad029a282ce97bf9b798e351cee2d57	Maestro	29.9852553890567286	-89.9800266349483309
36220	2020-07-09 21:53:06	2020-07-09	Mr. Martez Will PhD	mr.martez.will.phd@geemail.com	Long Beach	California	4507247391976	ea9a51fefe5bfed06fc817c1601a7bca	Voyager	33.7674199450582222	-118.131478726088247
36221	2020-07-09 21:53:53	2020-07-09	Linus Gorczany III	linus.gorczany.iii@geemail.com	Houston	Texas	3768023634724943	9276e61676e1fe5336429a2cff2d8491	American Express	29.7333604503501192	-95.4839644802283516
36222	2020-07-09 22:01:18	2020-07-09	Exa Swaniawski	exa.swaniawski@geemail.com	El Monte	California	4033927833842722	fb75c22346fdc881512caef26eefc137	Voyager	34.0486708922035959	-117.975953170031687
36223	2020-07-09 22:13:20	2020-07-09	Raymundo Hayes	raymundo.hayes@geemail.com	New York	New York	4687453551700884	4f3a1a9ec8136c56d26af317cd2b4bce	JCB 16 digit	40.5924634404703966	-73.9296214937593703
36224	2020-07-09 22:19:42	2020-07-09	Edmond Leuschke	edmond.leuschke@geemail.com	Buffalo	New York	4693629077415	fb6ad7effc938c8dc33e956d749920b9	JCB 16 digit	42.851463571488857	-78.827104538905246
36225	2020-07-09 22:27:44	2020-07-09	Ms. Bobbye Luettgen MD	ms.bobbye.luettgen.md@geemail.com	New York	New York	676391690068407	cf93f073cbb5cb1c8f79c5bec6da8e53	Diners Club / Carte Blanche	40.6881154612395903	-73.9562150739494655
36226	2020-07-09 22:45:50	2020-07-09	Zeta Kshlerin	zeta.kshlerin@geemail.com	Fort Lauderdale	Florida	4533364328484	d82ec50c08e7177480a578691938072a	Discover	26.1773430890392511	-80.1745519378975047
36227	2020-07-09 22:46:15	2020-07-09	Jaxton Strosin	jaxton.strosin@geemail.com	Columbus	Ohio	3088707268500597538	f6d7c51ba54b3ad7b90bb701dfe9e8e6	Maestro	39.9054895040623805	-82.9976744627349206
36228	2020-07-09 22:49:54	2020-07-09	Jair Ziemann	jair.ziemann@geemail.com	Houston	Texas	3158444484887740934	feaae19f398b6666bc6ee407140ffae3	VISA 16 digit	29.8298055469136685	-95.4387183127939664
36229	2020-07-09 22:56:30	2020-07-09	Marcelino Kub	marcelino.kub@geemail.com	Jacksonville	Florida	6011986156478229444	0787e70e6b8d957745cf557ca9851359	VISA 16 digit	30.4306937621958546	-81.6870558590240847
36230	2020-07-09 23:20:35	2020-07-09	Olie West	olie.west@geemail.com	New York	New York	180048835071921657	a13c451cfba9992c0f9d841e76a11aa2	VISA 16 digit	40.6936402030047049	-73.9227199510566919
36231	2020-07-09 23:21:49	2020-07-09	Sabra Tromp	sabra.tromp@warmmail.com	Boston	Massachusetts	639021482873102	b846e0b15b4d4350d427d22682fb4a82	JCB 16 digit	42.3740676331967094	-71.0877774612929727
36232	2020-07-09 23:26:18	2020-07-09	Saverio Sipes	saverio.sipes@woohoo.com	Pasadena	Texas	4936952005876405	dda992f7bbd1817e7b50b1069724810a	Maestro	29.7199092188723384	-95.095562434982881
36233	2020-07-09 23:35:51	2020-07-09	Sariah Keeling	sariah.keeling@geemail.com	Milwaukee	Wisconsin	4720177917880671	e5ee1dd4efc843b8ad1638e0bec8eb07	Diners Club / Carte Blanche	43.0533274790357794	-87.8760937342520805
36234	2020-07-09 23:39:12	2020-07-09	Monnie Smith DVM	monnie.smith.dvm@geemail.com	Irving	Texas	4936843882718	d6c8429b328c80e458fee163ea4c66fc	VISA 13 digit	32.9445414279073461	-96.9994845140539041
36235	2020-07-09 23:39:28	2020-07-09	Dr. Jettie Walter	dr.jettie.walter@geemail.com	San Francisco	California	4386907690983614	cc43abb18225a2d6dc359e79dff1c5e6	Voyager	37.7888322982964695	-122.404108777204598
36236	2020-07-09 23:41:23	2020-07-09	Ms. Rhiannon Tremblay	ms.rhiannon.tremblay@warmmail.com	Omaha	Nebraska	3096201308118070204	18bbec2b60ec383ec81a320cbb75476c	VISA 13 digit	41.1751356202323038	-96.103249035042154
36237	2020-07-09 23:44:02	2020-07-09	Kori Ryan	kori.ryan@geemail.com	Minneapolis	Minnesota	501827826956578	ab8d86a8ac524f249f62ae354b8eb381	Voyager	44.8925905635666069	-93.1699478160861787
36238	2020-07-09 23:47:03	2020-07-09	Makhi DuBuque Sr.	makhi.dubuque.sr.@geemail.com	Seattle	Washington	3015971311835851	3b4080f1db2cf773313974b7d4f2dc8f	JCB 16 digit	47.5872181666009126	-122.361613480226694
36239	2020-07-09 23:54:30	2020-07-09	Tommie Baumbach-Labadie	tommie.baumbach.labadie@geemail.com	Glendale	Arizona	4055699665181361	2f56874e8af5eb18889d2daf8ae6423a	VISA 16 digit	33.4846587241388818	-112.246327400512612
36240	2020-07-09 23:55:27	2020-07-09	Neil Welch	neil.welch@geemail.com	Phoenix	Arizona	3024344408135521	0bd788287e8694e8487272c4c03e9c14	Discover	33.6322972387939743	-112.094461052205787
36241	2020-07-09 23:57:04	2020-07-09	Lamonte Romaguera-Hartmann	lamonte.romaguera.hartmann@geemail.com	Tampa	Florida	55837247918232998	1b3fe8c955bd0ecaddecfab8acdfc2a2	JCB 16 digit	27.9266771006513359	-82.3819783326450619
36242	2020-07-10 00:06:42	2020-07-10	Erling Schmeler	erling.schmeler@woohoo.com	Columbus	Ohio	3707711801008173	c44250b032e94b97d82bca3b80702871	Maestro	39.9624588954307143	-82.9174495931483904
36243	2020-07-10 00:08:58	2020-07-10	Miss Pearla Corkery PhD	miss.pearla.corkery.phd@geemail.com	San Francisco	California	869969151847017786	12820e0631461da250b1a37cff3e818c	Mastercard	37.7559364728424711	-122.387128755109785
36244	2020-07-10 00:09:23	2020-07-10	Oneida Hudson-O'Kon	oneida.hudson.o'kon@geemail.com	San Francisco	California	180035743109678544	c13fd826166efaec18455168b32540db	American Express	37.7523328966697704	-122.414173926712394
36245	2020-07-10 00:16:12	2020-07-10	Donell Krajcik	donell.krajcik@geemail.com	San Diego	California	4627073822530820	a9384f0630fd13952e08d9a3f4b71356	JCB 16 digit	32.8983635443329803	-117.186821281574666
36246	2020-07-10 00:16:55	2020-07-10	Jayleen Wilkinson PhD	jayleen.wilkinson.phd@geemail.com	Bakersfield	California	55367973969931844	47633b587f3407a81bd20a6ee3b8c5d1	JCB 16 digit	35.2833854713186597	-119.069405396775522
36247	2020-07-10 00:18:18	2020-07-10	Vessie Pagac-Durgan	vessie.pagac.durgan@warmmail.com	New York	New York	3795034025151619	3c8e3b844fbb7b7d95522dfadf527966	Maestro	40.6971289491504393	-73.864377249114952
36248	2020-07-10 00:19:47	2020-07-10	Ahmed Koelpin	ahmed.koelpin@geemail.com	Philadelphia	Pennsylvania	869946038923191767	2d84738a187da97c801a9cf2feeaad00	American Express	40.017661243347078	-75.1220973404955146
36249	2020-07-10 00:25:39	2020-07-10	Drury Boehm	drury.boehm@warmmail.com	New Haven	Connecticut	3088339863126385957	15f14601ce2dd852cb1b145f6703c8a2	Maestro	41.2992103446267578	-72.8373853423632625
36250	2020-07-10 00:42:05	2020-07-10	Dr. Jens McDermott	dr.jens.mcdermott@geemail.com	San Diego	California	869902549569771193	b298e68dbd2735509970b560a91bb8cf	Voyager	32.8920352756578467	-117.20926857291721
36251	2020-07-10 00:44:19	2020-07-10	Colton Mraz	colton.mraz@geemail.com	Richmond	Virginia	4454223106344	77f1b059e3149d6cfc9f29899cbb1e64	Maestro	37.5548481922816464	-77.4864837478604187
36252	2020-07-10 01:10:28	2020-07-10	Huey Shields	huey.shields@geemail.com	Reno	Nevada	4203148594364061	d21fb4606abc4123825c5fb72cdf530b	Voyager	39.516148379126939	-119.781000335856902
36253	2020-07-10 01:11:23	2020-07-10	Max Stehr-Hackett	max.stehr.hackett@geemail.com	Arvada	Colorado	4375913528142939	f6b120d7957b2d0918811df97c5ee3dd	American Express	39.8742097671318803	-105.145689150874688
36254	2020-07-10 01:18:02	2020-07-10	Ailene Gislason-Kovacek	ailene.gislason.kovacek@geemail.com	Chattanooga	Tennessee	6011749372646972363	32dfcd01db1632494ae44691dc8765ce	American Express	35.0865985680688226	-85.3368949120227285
36255	2020-07-10 01:23:48	2020-07-10	Dr. Carleigh Stoltenberg	dr.carleigh.stoltenberg@geemail.com	Tuscaloosa	Alabama	3088243029240624441	08bc7851d6d689fc2a26cac2d0bef8d9	JCB 16 digit	33.2166278205867869	-87.5950576771613214
36256	2020-07-10 01:25:51	2020-07-10	Dr. Krysta Moore	dr.krysta.moore@geemail.com	Vacaville	California	3440777398299417	e275ffd5ee1419fad1453a8d66f4b2b5	JCB 16 digit	38.4449488233901562	-121.977881309797255
36257	2020-07-10 01:40:03	2020-07-10	Jazmine Yundt	jazmine.yundt@geemail.com	Seattle	Washington	4147884945813096	9519bc9d55c16c27902765268f52ba23	Maestro	47.5697776379454851	-122.310135662501295
36258	2020-07-10 02:00:11	2020-07-10	Madden Grady IV	madden.grady.iv@geemail.com	San Francisco	California	869961382784882639	44ad8893221cd306a75434712f236090	Voyager	37.765908740772943	-122.437525075399051
36259	2020-07-10 02:02:28	2020-07-10	Dr. Tai O'Connell MD	dr.tai.o'connell.md@woohoo.com	San Jose	California	3017648421031948	c6740746e000705c7a2c94e9c06f99e5	Voyager	37.2610161852378425	-121.84404120279811
36260	2020-07-10 02:10:13	2020-07-10	Dr. Fallon Watsica	dr.fallon.watsica@geemail.com	Miami	Florida	4340706668173009	02c86fe66797c80d3f4a5582d89f6d0b	Maestro	25.7373582113206396	-80.1435786099977889
36261	2020-07-10 02:13:24	2020-07-10	Saniya Flatley-Connelly	saniya.flatley.connelly@geemail.com	Berkeley	California	4685041323665162	89beefba55c260a1205573d81448934e	JCB 16 digit	37.8635500281342701	-122.248768947355387
36262	2020-07-10 02:15:34	2020-07-10	Casey Larson	casey.larson@geemail.com	Durham	North Carolina	869985894447463294	5e270ee6131c8eb9656ebc8461a7c6a4	Voyager	35.9323654189020374	-78.8055675359811687
36263	2020-07-10 02:29:36	2020-07-10	Benjman Mohr	benjman.mohr@geemail.com	Los Angeles	California	210015544619769599	c203815f04c06335f7434361dec953c0	American Express	33.9682783414941269	-118.433248305459685
36264	2020-07-10 02:31:00	2020-07-10	Josie Prosacco	josie.prosacco@warmmail.com	Milwaukee	Wisconsin	4887514827577162	96d85fd5f24add95b67000e9b9d860e5	JCB 15 digit	43.0781960279300762	-88.056743535782033
36265	2020-07-10 02:39:38	2020-07-10	Shay Balistreri-Wilderman	shay.balistreri.wilderman@geemail.com	San Francisco	California	3005517614792909	88fb552353fb74411b85d9ea87264043	JCB 16 digit	37.8058259300304798	-122.481815274148786
36266	2020-07-10 02:42:57	2020-07-10	Debby Schaefer	debby.schaefer@warmmail.com	San Francisco	California	4547666088380	68eaaa1eeac76619a57693e28fd4236f	Mastercard	37.7288421546594392	-122.407441205740483
36267	2020-07-10 02:50:42	2020-07-10	Nathan Schulist	nathan.schulist@geemail.com	Round Rock	Texas	3528849616821058946	ac7d371c43ee5c7030c30165ed8f7746	Discover	30.4261457274340117	-97.7078198205065007
36268	2020-07-10 02:50:52	2020-07-10	Elsworth Langosh Sr.	elsworth.langosh.sr.@geemail.com	Orange	California	4360849327160333	837293067efcd31998d326b4093442f1	JCB 16 digit	33.7027719943672395	-117.891960995701325
36269	2020-07-10 02:52:56	2020-07-10	Stephaine Gislason-Funk	stephaine.gislason.funk@woohoo.com	Columbus	Ohio	869980137048056272	fa4fa431d6905552db47e4d4d90bb5df	Discover	39.992580150305109	-82.9846981370590697
36270	2020-07-10 02:57:20	2020-07-10	Isabella McDermott-Conroy	isabella.mcdermott.conroy@geemail.com	Modesto	California	3737841159828320	a236be256f054d5daa7d4a8b21dd0679	JCB 16 digit	37.7262919871602236	-121.102402033863584
36271	2020-07-10 02:59:07	2020-07-10	Rossie Christiansen PhD	rossie.christiansen.phd@warmmail.com	Huntsville	Alabama	4638869647013	37f08fc4e76676ad8f0f5132421b11e2	Mastercard	34.7863641460202615	-86.5821356724034956
36272	2020-07-10 03:01:14	2020-07-10	Miss Kassie Dare	miss.kassie.dare@geemail.com	Madison	Wisconsin	4077290769262	6b49ef7d32b4aca76a86fbc76f60a480	JCB 16 digit	43.0460600431516767	-89.4345533897519118
36273	2020-07-10 03:09:21	2020-07-10	Mrs. Ronnie Huel PhD	mrs.ronnie.huel.phd@warmmail.com	Lincoln	Nebraska	51471393069422490	78d8433a5505f337c4aed3c8db04d09d	VISA 13 digit	40.7194040817692837	-96.6135261792849747
36274	2020-07-10 03:09:31	2020-07-10	Mr. Trumaine Champlin	mr.trumaine.champlin@geemail.com	Long Beach	California	3337867935719785213	4e1ef0481eb04109ba500a83e259fe63	VISA 16 digit	33.8536177638739346	-118.109931223669278
36275	2020-07-10 03:10:18	2020-07-10	Bradley Hodkiewicz	bradley.hodkiewicz@geemail.com	Los Angeles	California	6011208108247203145	c79bcaefcf4a218471d3dbc289875bc3	Maestro	34.0829110505390886	-118.487423305445532
36276	2020-07-10 03:15:13	2020-07-10	Miss Sylvia McLaughlin	miss.sylvia.mclaughlin@geemail.com	Cleveland	Ohio	6011635103685080603	475ba2f601fd003c2ee72801023a2f8a	JCB 16 digit	41.3791937625817923	-81.7789967932511104
36277	2020-07-10 03:20:28	2020-07-10	Lenon Schmidt	lenon.schmidt@geemail.com	Los Angeles	California	639074679202486	946719abda6355f9a993f049ae346c62	American Express	34.1119905577838409	-118.449720031115405
36278	2020-07-10 03:21:46	2020-07-10	Dequan Spencer	dequan.spencer@geemail.com	San Francisco	California	3727562812538815	7b1e9cc462dc844e9d27c21c2b0ec627	VISA 13 digit	37.7864004327242498	-122.419834337551364
36279	2020-07-10 03:27:20	2020-07-10	Daisye Koch-Kreiger	daisye.koch.kreiger@geemail.com	Phoenix	Arizona	4006846065164	b3219b52fd162d623c1cc8155a9b2ef3	VISA 13 digit	33.4754171681989021	-112.038775633594398
36280	2020-07-10 03:36:13	2020-07-10	Ms. Audrey Feeney	ms.audrey.feeney@warmmail.com	North Charleston	South Carolina	4342172164837738	74688bde7caa2295a6067432d64b33ba	Maestro	32.9550351516969471	-80.0128560073301145
36281	2020-07-10 03:43:38	2020-07-10	Omarion Legros	omarion.legros@geemail.com	San Antonio	Texas	3112266644242350001	050c4ac222748b440c96352a14546ac4	JCB 16 digit	29.4153333288222569	-98.601822871745
36282	2020-07-10 03:48:18	2020-07-10	Janel Dach	janel.dach@geemail.com	Oakland	California	4084213689751343	1bb1582e1f5f2057bcdce7cd7d3885c4	JCB 16 digit	37.7743053360578074	-122.270993126329913
36283	2020-07-10 03:49:21	2020-07-10	Firman Jenkins	firman.jenkins@woohoo.com	Las Cruces	New Mexico	639031795167779	f95ad7bcc3ecd679dea90256a672253b	VISA 13 digit	32.3215043504290307	-106.777550417895242
36284	2020-07-10 04:05:29	2020-07-10	Carma Kris-Davis	carma.kris.davis@woohoo.com	New York	New York	4887159703366981	badf4c45268bd4639a6ac12a159ff0e5	Diners Club / Carte Blanche	40.7005914739090926	-74.0102884282719344
36285	2020-07-10 04:06:19	2020-07-10	Cappie Mayer	cappie.mayer@geemail.com	Buffalo	New York	6011797933123972977	c3e5115011dcc9b20a58b51d55bfe5c4	JCB 16 digit	42.8328570152353478	-78.7663833538934597
36286	2020-07-10 04:06:43	2020-07-10	Raven Bradtke	raven.bradtke@geemail.com	Oakland	California	4473175823866759	998c0d3262f67365804465b6254b173c	Mastercard	37.8175157708918945	-122.26754718699425
36287	2020-07-10 04:11:04	2020-07-10	Willie Auer-Jacobson	willie.auer.jacobson@woohoo.com	Phoenix	Arizona	3039366788650212	dddef33253de41de0202c163d8ea6213	Diners Club / Carte Blanche	33.597836010477323	-112.11806343150549
36288	2020-07-10 04:23:48	2020-07-10	Jeremie Osinski	jeremie.osinski@woohoo.com	Mesa	Arizona	676156103915155	57fc1b75a8766b453c353cfa7a6f5d75	VISA 16 digit	33.3249242702178634	-111.726247487904132
36289	2020-07-10 04:24:37	2020-07-10	Juwan Zulauf-Herman	juwan.zulauf.herman@woohoo.com	McKinney	Texas	3021348548962549	31d896d3d4db426fdabb9bb27d31ab13	Voyager	33.145401826886463	-96.7353518944531743
36290	2020-07-10 04:27:41	2020-07-10	Talen Baumbach	talen.baumbach@geemail.com	New York	New York	3758224181011211	96c09d99986565ab14d00214d47a8813	JCB 15 digit	40.6931802088618255	-73.9960812027927517
36291	2020-07-10 04:37:47	2020-07-10	Eric Dare	eric.dare@warmmail.com	New York	New York	4216788614396	399497e826db9bfd818ebeb5b0bd51ed	Maestro	40.7445623932629815	-73.9223883324198425
36292	2020-07-10 04:47:38	2020-07-10	Terrance Considine	terrance.considine@woohoo.com	Phoenix	Arizona	52376500354218179	f6cb9cb7b2feb3e2eaa7e2c7fc3fff07	JCB 16 digit	33.5120379462305493	-112.060784665488086
36293	2020-07-10 04:54:06	2020-07-10	Myrtle Cassin-Mayert	myrtle.cassin.mayert@geemail.com	Glendale	Arizona	3528108371127561294	a1e8cf1b9cf80118933e2230ca443727	Maestro	33.5737344119459351	-112.216947694614149
36294	2020-07-10 04:57:39	2020-07-10	Breann Hyatt	breann.hyatt@geemail.com	New Haven	Connecticut	180096563474411073	ac775a74f2270b869581986c2ad0e6c1	Mastercard	41.2591351180329937	-72.99575639767572
36295	2020-07-10 05:06:18	2020-07-10	Kordell Gislason	kordell.gislason@geemail.com	Austin	Texas	53273026338292662	336623b659e092b2672d96c885580c07	American Express	30.2864189255643623	-97.8256229127995738
36296	2020-07-10 05:12:24	2020-07-10	Travon Christiansen-Dach	travon.christiansen.dach@geemail.com	Cincinnati	Ohio	589321026994216	04892d330e55e9c923ddfd2ab7b7b228	JCB 15 digit	39.2258932110618801	-84.5435109544817323
36297	2020-07-10 05:20:36	2020-07-10	Erla Breitenberg	erla.breitenberg@warmmail.com	San Francisco	California	51178318399535717	b277ca109bf2163ad3f23142b0573ed3	JCB 15 digit	37.7640812207529848	-122.437766031299049
36298	2020-07-10 05:29:10	2020-07-10	Evangelina Bode MD	evangelina.bode.md@geemail.com	San Francisco	California	501878637236825	a7aa910524082b8c600a12338c118c52	VISA 16 digit	37.7744114707379595	-122.408342390544036
36299	2020-07-10 05:32:01	2020-07-10	Candy Hartmann	candy.hartmann@warmmail.com	Berkeley	California	3088834089053223009	fbd33edb7491e7bd80d3d18b0cd7ad38	JCB 15 digit	37.8681145980260538	-122.266257129591764
36300	2020-07-10 05:32:08	2020-07-10	Arland Abshire-Kuhlman	arland.abshire.kuhlman@geemail.com	Huntington Beach	California	6011881557654561243	fb74eb4674b97083c0db9cd4b0435353	JCB 16 digit	33.7300006907939931	-117.936969385215264
36301	2020-07-10 06:00:34	2020-07-10	Wesley Boyle	wesley.boyle@geemail.com	Macon	Georgia	3027609307178377	ccbfceae855200a5fd9b499e56e927d2	Voyager	32.886667161156609	-83.6263293695364069
36302	2020-07-10 06:05:11	2020-07-10	Stormy Adams	stormy.adams@woohoo.com	Madison	Wisconsin	3481291309207691	d8976610ad22e5a09c1ebd5b9354640d	Discover	43.1804267415285139	-89.3345678844839313
36303	2020-07-10 06:10:31	2020-07-10	Danita Steuber	danita.steuber@warmmail.com	Lakeland	Florida	3464865268019527	af3e43fcf533f6b7454e3b792000a9e8	Voyager	28.0361393825914682	-82.0044957607868952
36304	2020-07-10 06:17:23	2020-07-10	Emanuel Nikolaus	emanuel.nikolaus@woohoo.com	Chicago	Illinois	060497540252877	6da6debfd6f192cdb5f710302db87e2b	Mastercard	41.7473379728220451	-87.6213076896063967
36305	2020-07-10 06:17:56	2020-07-10	Hertha Blanda	hertha.blanda@geemail.com	Lancaster	California	51190280544577776	27898f0ca3ff96ef6cdef245f2a2c963	Voyager	34.6780984441530009	-118.169213048412644
36306	2020-07-10 06:18:57	2020-07-10	Melonie Conn	melonie.conn@geemail.com	Escondido	California	3042949337178384	68a71fe521d4e5037f40f1547208f5e1	Maestro	33.1006102098844934	-116.976280178153885
36307	2020-07-10 06:19:09	2020-07-10	Jude Jones	jude.jones@geemail.com	San Jose	California	869950048466042312	903cad4f32fddccb3a0f93744bca284a	Maestro	37.1995325316961853	-121.855869149438661
36308	2020-07-10 06:20:54	2020-07-10	Linna Treutel	linna.treutel@geemail.com	San Antonio	Texas	4903204628072	ef81181f25f9ced79375defb289a0729	Diners Club / Carte Blanche	29.4180773571204384	-98.5607062908656815
36309	2020-07-10 06:22:27	2020-07-10	Chestina O'Hara	chestina.o'hara@woohoo.com	Hampton	Virginia	3490278569145785	c647006b250a96454f005f0d283edd6f	VISA 16 digit	36.981484412729742	-76.2625998572077606
36310	2020-07-10 06:25:20	2020-07-10	Clementine Wisoky PhD	clementine.wisoky.phd@geemail.com	San Francisco	California	3096183380173190146	0cd38a514588092b669311ce368fd60a	Maestro	37.7676489836243903	-122.403930987570092
36311	2020-07-10 06:29:17	2020-07-10	Somer Toy	somer.toy@geemail.com	San Francisco	California	3112816170660553384	4de789838d2b5e95359d31905b896d0a	JCB 16 digit	37.7741395201334811	-122.396480550556461
36312	2020-07-10 06:32:53	2020-07-10	Tory Jast	tory.jast@geemail.com	Augusta	Georgia	869941833400794876	71f9cba927fa8fdaa0fb5e2b88da00e1	VISA 13 digit	33.4114939364343826	-82.1048595791976936
36313	2020-07-10 06:36:19	2020-07-10	Lela Kuhlman	lela.kuhlman@geemail.com	San Jose	California	869954698505437455	50ed06455c8a316c4409ed47d58df4b0	JCB 16 digit	37.25333063079119	-121.73783778801895
36314	2020-07-10 06:37:30	2020-07-10	Francesca Carter	francesca.carter@geemail.com	Memphis	Tennessee	3088953250673651434	1ea068b7b241ed142b53aeb4064f7dda	VISA 16 digit	35.0305017125859877	-90.0542166375812201
36315	2020-07-10 06:58:38	2020-07-10	Othel Hansen	othel.hansen@geemail.com	Fort Worth	Texas	3088020415666293580	16c201986e75d2d6b71dff296c4e5025	JCB 15 digit	32.8030767289977518	-97.413898564577849
36316	2020-07-10 07:02:06	2020-07-10	Mrs. Juliann Mayert DVM	mrs.juliann.mayert.dvm@geemail.com	Peoria	Arizona	869919121793309447	bc9bfb8ef05fc12108e74cdd91b6e233	Diners Club / Carte Blanche	33.7123123048607241	-112.374120629291994
36317	2020-07-10 07:11:43	2020-07-10	Dr. Shasta Oberbrunner MD	dr.shasta.oberbrunner.md@woohoo.com	Columbus	Ohio	675902512772449	85d3b60d960a4887172a3c0945af569c	Discover	40.0606259773995745	-82.8983477456729929
36318	2020-07-10 07:12:47	2020-07-10	Dr. Waino Connelly	dr.waino.connelly@woohoo.com	Tampa	Florida	210086989825528715	37bf9bf0fb310dca17cdadd84c3af925	Diners Club / Carte Blanche	27.8862781908944228	-82.4854168863247992
36319	2020-07-10 07:14:58	2020-07-10	Jess Stroman	jess.stroman@warmmail.com	Anchorage	Alaska	4593968086492882	ba1686852037ee6f277552d66e857146	Diners Club / Carte Blanche	61.1199272229552264	-149.217334171164026
36320	2020-07-10 07:15:28	2020-07-10	Dicy Steuber	dicy.steuber@geemail.com	Berkeley	California	6011936826460285361	c53caba998152e63f069b07ac00c3f66	VISA 13 digit	37.8633513811166011	-122.289053480704283
36321	2020-07-10 07:22:15	2020-07-10	Christen Hudson	christen.hudson@geemail.com	Grand Prairie	Texas	3096018423786999478	17ee96f045ad9e610acb9ffdc080215f	Discover	32.7143206610862194	-97.0904342903163382
36322	2020-07-10 07:24:17	2020-07-10	Ms. Karla Runolfsson	ms.karla.runolfsson@woohoo.com	New York	New York	4300517609159371	b9a4f89f0df26b557a9d6d447e79fd0d	VISA 16 digit	40.6666391385942703	-73.9107578334294288
36323	2020-07-10 07:26:24	2020-07-10	Aurora Christiansen DDS	aurora.christiansen.dds@geemail.com	Santa Ana	California	3158855439340183173	69f9c3544620ec494ff4bdcc7bfbb63a	JCB 15 digit	33.8353767154376968	-117.9730596004445
36324	2020-07-10 07:26:54	2020-07-10	Evita Hirthe-Toy	evita.hirthe.toy@geemail.com	New York	New York	210035883491807556	ca0c4e5cc15e88992cf60d9c7c0d754b	VISA 16 digit	40.6064769811686119	-73.8613461005397056
36325	2020-07-10 07:28:59	2020-07-10	Ty Hamill	ty.hamill@geemail.com	Wichita	Kansas	869942066915511951	e4d70751855eb3e39a769118250afaf1	JCB 15 digit	37.6141109637793178	-97.2567028642367575
36326	2020-07-10 07:38:06	2020-07-10	Russel Kovacek	russel.kovacek@woohoo.com	Gilbert	Arizona	4398153011133	9067946a6ccbfd35626ee96fc979f267	Diners Club / Carte Blanche	33.243952627700935	-111.672415304663033
36327	2020-07-10 07:41:23	2020-07-10	Mateo Dooley II	mateo.dooley.ii@geemail.com	Denver	Colorado	180012060687004085	82f549a96fb06983943b3b6d78768aef	JCB 16 digit	39.7236814459372312	-104.802445319272948
36328	2020-07-10 07:53:33	2020-07-10	Deacon Abernathy MD	deacon.abernathy.md@woohoo.com	Baton Rouge	Louisiana	869934250243041317	e664c38c61f2cf457cf67c8ea394c69b	Mastercard	30.3445884554859262	-91.1543113833401293
36329	2020-07-10 07:55:20	2020-07-10	Winfield Koepp	winfield.koepp@geemail.com	Berkeley	California	4865735283262074	05572ac9c2a501b82f3970abd951da7d	Mastercard	37.8723850791709182	-122.288636036096207
36330	2020-07-10 07:58:41	2020-07-10	Marina Ryan-Cronin	marina.ryan.cronin@woohoo.com	Louisville	Kentucky	4769105340954	3a00c3789ee308604df95d708f88f139	JCB 15 digit	38.1287507661521445	-85.5764687184780826
36331	2020-07-10 07:59:57	2020-07-10	Clay Baumbach DVM	clay.baumbach.dvm@geemail.com	Glendale	Arizona	210066102650345619	07f1f7ebb38abc40b3db5c6ae80c220f	Mastercard	33.5383114690188293	-112.195392504918942
36332	2020-07-10 08:13:56	2020-07-10	Burnice Barrows-Walter	burnice.barrows.walter@geemail.com	San Francisco	California	3037447548851969	2eae1966c4860096e61e8e7a97a13b64	JCB 16 digit	37.7785710922407532	-122.433992116815091
36333	2020-07-10 08:22:21	2020-07-10	Idella Barrows	idella.barrows@geemail.com	El Paso	Texas	675912074946992	760dadfc4e3fc93f8f937510fa6d9160	Maestro	31.7825151144821199	-106.416111152850092
36334	2020-07-10 08:22:50	2020-07-10	Ms. Shaina Larson PhD	ms.shaina.larson.phd@warmmail.com	McKinney	Texas	210005640996974752	db093ab102beac27e43a0491beaabdfa	Maestro	33.1976597798652975	-96.6404318979308101
36335	2020-07-10 08:26:08	2020-07-10	Bartley Graham-Davis	bartley.graham.davis@geemail.com	New York	New York	561294865604212	64102e4db335ce53f1c6286b380e8cbb	JCB 16 digit	40.7577533164285128	-73.8864786636911361
36336	2020-07-10 08:29:39	2020-07-10	Harden Heller	harden.heller@geemail.com	Frisco	Texas	55746078956791870	f1654ef22729dfad9c1d3134bf5d58dd	JCB 15 digit	33.1563853391908125	-96.8854574078902573
36337	2020-07-10 08:32:53	2020-07-10	Ms. Allisson Lemke MD	ms.allisson.lemke.md@geemail.com	San Francisco	California	3044168293550506	22a57dc4a5488df1e9f76cf162690db3	Maestro	37.7663146794686142	-122.443021655701301
36338	2020-07-10 08:37:19	2020-07-10	Ireland Rath	ireland.rath@geemail.com	Portland	Oregon	3036668352489502	36f62c8a464b5fab151670571dc88ccb	VISA 16 digit	45.4515119224674962	-122.618483872292572
36339	2020-07-10 08:40:13	2020-07-10	Ms. Ophelia Lakin DVM	ms.ophelia.lakin.dvm@geemail.com	Long Beach	California	3057373499366841	c4212e9055bdd4f6caf1a33201df2ae3	Mastercard	33.7114346803452776	-118.064002199393883
36340	2020-07-10 08:41:22	2020-07-10	Dr. Melvina Christiansen	dr.melvina.christiansen@warmmail.com	Springfield	Massachusetts	3045163570092297	c419db6f0513ce9041b2872a3be202dd	VISA 16 digit	42.15815885436907	-72.538130683973435
36341	2020-07-10 08:44:57	2020-07-10	Lisbeth Wiza	lisbeth.wiza@geemail.com	Palm Bay	Florida	210006815183834253	c5e8d71a4cac42ac275a179b2224914b	Discover	27.9978893078252682	-80.7482471043545758
36342	2020-07-10 08:47:00	2020-07-10	Joretta Dibbert	joretta.dibbert@geemail.com	San Antonio	Texas	3056221465646228	70b36290232be8e8b6a6069b638fad3d	Discover	29.5080298162136216	-98.5620066043756822
36343	2020-07-10 08:47:18	2020-07-10	Wayman Doyle	wayman.doyle@geemail.com	Hollywood	Florida	3717907424691225	31ec31f954b79ee6eed0c1a092ddec1b	VISA 16 digit	26.0365431069806199	-80.2026837334319822
36344	2020-07-10 08:49:49	2020-07-10	Sophie Hand	sophie.hand@geemail.com	Milwaukee	Wisconsin	6011145174212409725	20dbb6adaedc0909b30d79a9add21828	Maestro	43.0992862542245518	-87.9899594833709386
36345	2020-07-10 08:51:38	2020-07-10	Iliana Stark	iliana.stark@geemail.com	Las Vegas	Nevada	675995466165016	17f2e0888fc9bc865949035707a547eb	VISA 16 digit	36.2269406733669328	-115.306998636128753
36346	2020-07-10 08:52:32	2020-07-10	Alysia Murray	alysia.murray@warmmail.com	Fremont	California	180065515095628201	d2c02ec3acd165353ca99062c4a38448	VISA 16 digit	37.5896583755202585	-121.975279565061257
36347	2020-07-10 08:56:14	2020-07-10	Essence Schmitt	essence.schmitt@geemail.com	Berkeley	California	6011922591003669317	86a183f8319ffa9c5dad49f585dde741	Mastercard	37.8730811781834973	-122.250087412148346
36348	2020-07-10 09:12:47	2020-07-10	Kieran Schmeler	kieran.schmeler@geemail.com	Cleveland	Ohio	4706294913211831	45a08aefe3e44da5780a3a1586e59837	Maestro	41.5244240316879001	-81.6013152141362497
36349	2020-07-10 09:17:54	2020-07-10	Barbie Mills	barbie.mills@geemail.com	Tucson	Arizona	3455587100442243	e0fb7e94ea712b69bfe6eca316e06b96	JCB 16 digit	32.0750316260889221	-110.852780371508004
36350	2020-07-10 09:18:51	2020-07-10	Lelia Franecki	lelia.franecki@warmmail.com	Glendale	California	3096656342635083986	63cb1df803d2fc9133316f0749d47b5d	Mastercard	34.169661407660314	-118.182230383240807
36351	2020-07-10 09:34:56	2020-07-10	Mikel Romaguera	mikel.romaguera@geemail.com	Gilbert	Arizona	3024732037655374	02298880ec84c11bb98e20d72953c95f	Diners Club / Carte Blanche	33.2198594706945087	-111.657219016146286
36352	2020-07-10 09:40:59	2020-07-10	Alla Bruen	alla.bruen@geemail.com	Detroit	Michigan	4765030115289	9b4e5f66d3db95826e53107186e788ca	Voyager	42.4766727981548797	-83.0219909424547069
36353	2020-07-10 09:43:43	2020-07-10	Melvyn Stanton III	melvyn.stanton.iii@geemail.com	Chandler	Arizona	3407890172971258	7097d1c8cb66bddb14c5331b7233e94f	JCB 16 digit	33.3326724829241599	-111.951453846262396
36354	2020-07-10 09:48:34	2020-07-10	Simmie Hills	simmie.hills@geemail.com	Gainesville	Florida	3780210464594132	73efab18b49b61fbf4e4f3ceff1fb052	Maestro	29.6527703749772158	-82.2688866738569118
36355	2020-07-10 10:00:39	2020-07-10	Merle Pouros	merle.pouros@geemail.com	Dallas	Texas	6011515880651857412	f0e0de235ca61b0873734f096cbdabc1	Voyager	32.8723166450198789	-96.8141814691908564
36356	2020-07-10 10:02:06	2020-07-10	Leanna Balistreri-Conroy	leanna.balistreri.conroy@geemail.com	New York	New York	4187197977327450	32de876083dc7cbd7ef8442e7d750c56	JCB 16 digit	40.7072751817051284	-73.9547100233741048
36357	2020-07-10 10:05:53	2020-07-10	Keagan Lakin	keagan.lakin@geemail.com	San Francisco	California	55214426808538796	4da2d1575b76f85b6d6a24e3d03a9d2e	VISA 13 digit	37.775915285389118	-122.419260045796889
36358	2020-07-10 10:08:20	2020-07-10	Ainsley Okuneva	ainsley.okuneva@warmmail.com	San Francisco	California	3790879167133717	c56b1ab3596bb038dfdb5382b7613501	JCB 16 digit	37.7691651019273422	-122.428705955758048
36359	2020-07-10 10:14:57	2020-07-10	Anatole Keebler	anatole.keebler@geemail.com	Rochester	Minnesota	52951047322917576	541b5e665c3dac983e7054e7bb00d83b	Discover	43.9401979708015915	-92.4626889052919978
36360	2020-07-10 10:17:26	2020-07-10	Liliana Dach	liliana.dach@geemail.com	Everett	Washington	4586262719876193	921fde2bb0ac3b13ffac0d6d037e85d2	JCB 15 digit	47.8738438912559303	-122.230822354614361
36361	2020-07-10 10:40:19	2020-07-10	Dr. Antione Williamson Jr.	dr.antione.williamson.jr.@warmmail.com	Worcester	Massachusetts	4114092281624	52c69f8165dca6a1eb44109b66acdfc5	JCB 16 digit	42.2472530892752118	-71.8724425862330918
36362	2020-07-10 10:41:41	2020-07-10	Harriet Cummerata	harriet.cummerata@woohoo.com	El Paso	Texas	3704427065421688	d666d40400942650409e62fbd1225bca	JCB 16 digit	31.8609515233725311	-106.451528066348288
36363	2020-07-10 10:52:27	2020-07-10	Adolfo Bashirian	adolfo.bashirian@geemail.com	San Bernardino	California	53435881454418565	a076bcfe27d691e3623f3cc805d9d323	VISA 16 digit	34.0818864360250515	-117.37970382881015
36364	2020-07-10 10:54:28	2020-07-10	Loren Kilback	loren.kilback@geemail.com	Chicago	Illinois	54673647223947205	359e8b4f831d1386698c0964ee552ee9	Maestro	41.7546995795633649	-87.7082955891296194
36365	2020-07-10 10:55:17	2020-07-10	Bishop Keeling	bishop.keeling@warmmail.com	Tempe	Arizona	3096850389350104574	3accc7474123b57647fe72d751e331d9	Mastercard	33.4024716996509525	-111.892585069409748
36366	2020-07-10 10:56:52	2020-07-10	Trever Nader	trever.nader@geemail.com	Knoxville	Tennessee	869926559298765095	cf15bb71270cf7ec8c74b3cde174b998	VISA 13 digit	35.8738166981905735	-83.9669781799644142
36367	2020-07-10 10:59:26	2020-07-10	Mauricio Champlin	mauricio.champlin@geemail.com	San Francisco	California	4573670351176	23a0f325069cb42a1d355528510f735f	VISA 13 digit	37.8031547484057313	-122.411644401032504
36368	2020-07-10 10:59:40	2020-07-10	Dr. Maxx McClure II	dr.maxx.mcclure.ii@warmmail.com	Phoenix	Arizona	676393828467790	ccd552450b0b39dd93a7019c78b6fcef	Diners Club / Carte Blanche	33.4730994287345567	-112.078011719921989
36369	2020-07-10 11:14:24	2020-07-10	Mackenzie Runolfsson	mackenzie.runolfsson@warmmail.com	Baltimore	Maryland	4005938933563740	2b476f8f76f8b8ede76bc387fef04cf7	Mastercard	39.3182407815009327	-76.6442813195772459
36370	2020-07-10 11:22:39	2020-07-10	Dr. Elzy Bergnaum	dr.elzy.bergnaum@geemail.com	Pueblo	Colorado	3039352535607143	8ac0bb5dc5b5a51a85719c9e317525cb	Mastercard	38.187192024334891	-104.658529574875914
36371	2020-07-10 11:31:14	2020-07-10	Paige Franecki	paige.franecki@geemail.com	Oakland	California	3038660585219713	17ea0c972f11799c12f4db1867516921	Discover	37.7819665603174641	-122.261135645797125
36372	2020-07-10 11:31:29	2020-07-10	Demario Jenkins	demario.jenkins@geemail.com	Cape Coral	Florida	55572994545833065	432559d4cad594f7853259c6a46f4d5a	Diners Club / Carte Blanche	26.7271286095462735	-82.0250189078576852
36373	2020-07-10 11:41:04	2020-07-10	Nakia Schulist	nakia.schulist@woohoo.com	Buffalo	New York	3158066754576969979	165f1645c5fb260b5851c840cd54a3f1	VISA 16 digit	42.7982044281158593	-78.8290291315808958
36374	2020-07-10 11:59:15	2020-07-10	Mercy Lueilwitz	mercy.lueilwitz@geemail.com	Westminster	Colorado	3088026656723151113	c6ca354d45057056c4754a9051aceb80	VISA 13 digit	39.7910698624167551	-104.990681107822439
36375	2020-07-10 12:06:59	2020-07-10	Eligah Maggio DVM	eligah.maggio.dvm@woohoo.com	Pasadena	California	4194070476487	83963c9a2fea3f671ae00b414c0fce56	Voyager	34.0618232501525426	-118.208199100690337
36376	2020-07-10 12:13:02	2020-07-10	Dr. Coby Konopelski PhD	dr.coby.konopelski.phd@woohoo.com	Mobile	Alabama	3337443740835182565	62c0323051376d77ef0ebff4a5bc33d9	Discover	30.616824859344959	-88.0988198549158881
36377	2020-07-10 12:16:54	2020-07-10	Estefany Watsica	estefany.watsica@geemail.com	Manchester	New Hampshire	3112098508130023513	99219ff7b0f829f4d6ae0c30c9a49762	Discover	42.9482765031583611	-71.3949510759100434
36378	2020-07-10 12:25:17	2020-07-10	Holland Leannon	holland.leannon@geemail.com	Fresno	California	869974665609614152	b5cdddba3fb8e96f7c33229e532627ca	VISA 13 digit	36.8576851727314292	-119.738838398513948
36379	2020-07-10 12:34:42	2020-07-10	Kaylyn Gaylord DDS	kaylyn.gaylord.dds@geemail.com	Jacksonville	Florida	676241104806603	48d708d5e7cf701b0701de29a6b0bb30	American Express	30.3627364157751209	-81.5915739166628668
36380	2020-07-10 12:34:59	2020-07-10	Alyce Bradtke	alyce.bradtke@warmmail.com	Raleigh	North Carolina	3032103824239669	4c1b99136a68c3ee86f714161c0e5d45	VISA 13 digit	35.7543611823715253	-78.5548819516722148
36381	2020-07-10 12:36:19	2020-07-10	Yehuda Macejkovic	yehuda.macejkovic@woohoo.com	Victorville	California	869980196178196084	0f543b313d8242957cade0957d2872ae	Diners Club / Carte Blanche	34.611450657737258	-117.392020137017965
36382	2020-07-10 12:45:51	2020-07-10	Miss Oneida Dickens	miss.oneida.dickens@woohoo.com	New York	New York	3445768331786649	4095ee58db178279fb379d8d4d0bc1d2	Mastercard	40.5982911329474305	-73.8671634143579752
36383	2020-07-10 13:00:27	2020-07-10	Nathanial DuBuque	nathanial.dubuque@woohoo.com	Arlington	Texas	52309830939990899	40cb85410d4b244277ba1aab494d2206	JCB 15 digit	32.7620208889961191	-97.0909638291716561
36384	2020-07-10 13:15:19	2020-07-10	Hermine Stoltenberg	hermine.stoltenberg@geemail.com	New York	New York	4587372181780333	03c6f1b15a50d129a8a27e210efd6906	JCB 16 digit	40.7624001939073182	-73.906029958314079
36385	2020-07-10 13:16:59	2020-07-10	Ms. Norah Wintheiser PhD	ms.norah.wintheiser.phd@warmmail.com	San Jose	California	54274610471739024	e555ff088082b99383f21463435d2a75	JCB 16 digit	37.326292872271317	-121.877934577943378
36386	2020-07-10 13:23:28	2020-07-10	Adah Erdman	adah.erdman@warmmail.com	Memphis	Tennessee	6011979618978524367	9f2e495f63641cc964c378057b913921	Voyager	35.1498362843014291	-90.0234443391930341
36387	2020-07-10 13:27:49	2020-07-10	Afton Barton	afton.barton@geemail.com	Chicago	Illinois	869990302816611520	59b17268bbb019a9f0f8df65466037a8	Discover	41.8979621437214362	-87.7567710022937462
36388	2020-07-10 13:29:02	2020-07-10	Kyree Grady	kyree.grady@geemail.com	Chicago	Illinois	6011184045433456558	514e6689f907362f88324829d77a1dc1	VISA 16 digit	41.7829849149402222	-87.6672401580989344
36389	2020-07-10 13:42:17	2020-07-10	Ms. Natalee Hauck DDS	ms.natalee.hauck.dds@geemail.com	New York	New York	3728659529288632	ff12e91df57c7dfc07f3fb1c2d797ee3	VISA 16 digit	40.7571452785972497	-73.8560975320067286
36390	2020-07-10 13:55:32	2020-07-10	Lita Johnston PhD	lita.johnston.phd@geemail.com	Jacksonville	Florida	3797874755037290	9fc5f330ca97844cc45eb1510585dff8	Mastercard	30.311539196088539	-81.6142460563298329
36391	2020-07-10 14:00:45	2020-07-10	Amiah McCullough	amiah.mccullough@warmmail.com	Chesapeake	Virginia	6011663517698921872	caa1830c9b3f6b90f22bec15aaa3a80a	Voyager	36.6858901670441071	-76.2705554656062219
36392	2020-07-10 14:04:18	2020-07-10	Margaretta Dietrich	margaretta.dietrich@geemail.com	San Francisco	California	6011258240417116135	1db4059eef89d98d5d36f5dbc60b1ade	JCB 15 digit	37.7553184418553087	-122.467660545546778
36393	2020-07-10 14:11:00	2020-07-10	Lissa Pfannerstill	lissa.pfannerstill@geemail.com	Anchorage	Alaska	55184823499807272	972331170075ede6740be3d4f50d1831	VISA 16 digit	61.2041632800579123	-149.21230579606555
36394	2020-07-10 14:19:10	2020-07-10	Ebert Ritchie	ebert.ritchie@geemail.com	Athens	Georgia	3447068444148151	6e254e1c6bdf5ce76d82925be3b3b659	Mastercard	33.8560640035852742	-83.3392812612581935
36395	2020-07-10 14:25:43	2020-07-10	Mr. Lovie Marquardt V	mr.lovie.marquardt.v@geemail.com	Santa Ana	California	4976288803093211	3f49e715ad6f04c09b10a54c353bf8f1	VISA 16 digit	33.7367408631008132	-117.884740677142517
36396	2020-07-10 14:26:44	2020-07-10	Elgie Steuber	elgie.steuber@geemail.com	Colorado Springs	Colorado	869973384899622609	4ae6e8990a6a4b822fea4cb744359a2e	Diners Club / Carte Blanche	38.8167176314212412	-104.788555008235207
36397	2020-07-10 14:31:31	2020-07-10	Dr. Lionel Stroman DVM	dr.lionel.stroman.dvm@geemail.com	Austin	Texas	210072646621345597	123804be6716a85be26d7df0c3208bad	American Express	30.2494994622781874	-97.7542318824451399
36398	2020-07-10 14:34:03	2020-07-10	Ms. Sydnee Rau	ms.sydnee.rau@geemail.com	Torrance	California	3045383140643557	854c41f55badfe3d01fcbfbcc5f33cd8	VISA 16 digit	33.8229621359519683	-118.363843938301869
36399	2020-07-10 14:39:53	2020-07-10	Anne Koch	anne.koch@geemail.com	San Antonio	Texas	4786077038424	f7809112bfceaa80fa6b748da194bc3c	JCB 16 digit	29.4959631204675894	-98.4501407349783904
36400	2020-07-10 14:49:12	2020-07-10	Lou Fadel PhD	lou.fadel.phd@geemail.com	San Jose	California	869980015092560508	31e1f242d38d28daa8d42a9ab5f73ebc	Maestro	37.2885868061620727	-121.890561049220707
36401	2020-07-10 15:10:23	2020-07-10	Stasia Thompson	stasia.thompson@geemail.com	Chandler	Arizona	3035040774066360	8647533b91c7301738a3c98b03a8e3ff	Diners Club / Carte Blanche	33.3379574742723221	-111.773411906918142
36402	2020-07-10 15:12:05	2020-07-10	Mr. Uriah Green Sr.	mr.uriah.green.sr.@warmmail.com	Philadelphia	Pennsylvania	4508238739787284	b87588b2d47b7eb1b99dc08f777234b9	VISA 13 digit	39.9656649586703594	-75.0662244917258619
36403	2020-07-10 15:22:50	2020-07-10	Gale Emard	gale.emard@geemail.com	Jacksonville	Florida	6011889171134916548	55428e2c813eaca7fec592de640cb66f	JCB 15 digit	30.2789778181869522	-81.6518574140578579
36404	2020-07-10 15:25:57	2020-07-10	Sol Windler	sol.windler@geemail.com	Portland	Oregon	3528519084123796300	17bd106c4f20ed398664755ec8eabe5b	Discover	45.4395345776695763	-122.56813379973174
36405	2020-07-10 15:38:34	2020-07-10	Dr. Newt Becker DVM	dr.newt.becker.dvm@geemail.com	West Covina	California	3158322105197748930	6b5b8dcc2c3b36d3f81d5bfdef2e5f69	Mastercard	34.0338181990306836	-117.815281549615406
36406	2020-07-10 15:56:39	2020-07-10	Terell Morar	terell.morar@geemail.com	Norfolk	Virginia	3528329573498654508	56387b99d4644ecc63699e12b7019aa9	Voyager	36.8655189011264639	-76.1458290790677097
36407	2020-07-10 16:04:30	2020-07-10	Abigayle Jakubowski MD	abigayle.jakubowski.md@geemail.com	San Francisco	California	3011822837686761	be66aa41f6d23f1fb79b8309715a3b22	Mastercard	37.7641457094794291	-122.448553384493081
36408	2020-07-10 16:09:34	2020-07-10	Mr. Waldo Hermann II	mr.waldo.hermann.ii@woohoo.com	St. Petersburg	Florida	3469741667698945	8ba632d74d458b44072cbb019a233efe	Maestro	27.8438059459794331	-82.6182217546164992
36409	2020-07-10 16:17:04	2020-07-10	Ms. Marin VonRueden	ms.marin.vonrueden@geemail.com	Wichita	Kansas	3112910802000366326	0ccef2df4b860904a4333dadf2049593	Voyager	37.7728574978064771	-97.3983811690673207
36410	2020-07-10 16:17:22	2020-07-10	Mrs. Sable Schaden	mrs.sable.schaden@geemail.com	Thousand Oaks	California	3747418875926726	017de1084cb5934de73009711a461d69	Discover	34.275471528646726	-118.926955273319777
36411	2020-07-10 16:31:31	2020-07-10	Sanjuanita Stehr	sanjuanita.stehr@warmmail.com	Costa Mesa	California	4654971262639686	ef6baef19c4b1ee1dad22b9a5b8dc529	Voyager	33.7579503221452271	-117.826227176920696
36412	2020-07-10 16:33:09	2020-07-10	Ozella Renner	ozella.renner@geemail.com	Oklahoma City	Oklahoma	869994346477055440	002948f13358273dbd2e1d868286e95f	VISA 16 digit	35.5164942467961495	-97.4619767016161234
36413	2020-07-10 16:35:24	2020-07-10	Joesph Wiegand	joesph.wiegand@geemail.com	Sioux Falls	South Dakota	4070775686067077	827365789f7f87cc63227ceb4afd635e	Voyager	43.545269324778765	-96.8144832967016811
36414	2020-07-10 16:36:47	2020-07-10	Yajaira Gottlieb	yajaira.gottlieb@geemail.com	Jersey City	New Jersey	6011530330861467157	38bb7ec4477cf637c6744ea7e169b6d5	Mastercard	40.7951542971130436	-74.1036566311448865
36415	2020-07-10 16:43:59	2020-07-10	Isadora Wiegand	isadora.wiegand@woohoo.com	Garland	Texas	869961273611805093	fe492695d339551859741a458833c6ca	JCB 16 digit	32.9736806679286047	-96.5556368645906531
36416	2020-07-10 16:48:01	2020-07-10	Gaven Beer	gaven.beer@geemail.com	Montgomery	Alabama	55751692873354232	5b109161c52b2de9a72f1ff0061a27b4	Maestro	32.2557342793725468	-86.3343572008110556
36417	2020-07-10 16:49:04	2020-07-10	Kaye Dickens	kaye.dickens@geemail.com	San Jose	California	4772833144789	402b6bc918ff6149a8fe8db42e3cd37b	Diners Club / Carte Blanche	37.3486647225737585	-121.841794140658905
36418	2020-07-10 16:49:34	2020-07-10	Zollie Rohan	zollie.rohan@geemail.com	New York	New York	3528953986519048802	5011e1430042361d996cd250ee3d9cd7	Mastercard	40.6845663925390681	-73.8847391980130226
36419	2020-07-10 16:52:40	2020-07-10	Kasey Marquardt	kasey.marquardt@warmmail.com	San Antonio	Texas	4917486462735955	eae56a6f70cf8218bf3bdf480a42a6fc	American Express	29.4307173795137551	-98.4806160716641585
36420	2020-07-10 16:58:49	2020-07-10	Olin Koss DDS	olin.koss.dds@woohoo.com	San Francisco	California	3337970319822779997	c884c61f9f8cbdee942cc16ffbe6efe5	Diners Club / Carte Blanche	37.7636090530347488	-122.442908060240939
36421	2020-07-10 17:05:09	2020-07-10	Ferman Mueller Jr.	ferman.mueller.jr.@warmmail.com	Saint Paul	Minnesota	3019483717784028	58fe41eb70138592f5795073610f0ffd	JCB 16 digit	44.8985730294544254	-93.0328355577107544
36422	2020-07-10 17:06:09	2020-07-10	Esta Erdman-Price	esta.erdman.price@geemail.com	Boise	Idaho	6011648326837676391	0d24da72f5f4636db9f4a987fdf7079b	Maestro	43.6309278180029239	-116.182744921530414
36423	2020-07-10 17:07:27	2020-07-10	Camille Strosin	camille.strosin@geemail.com	Pueblo	Colorado	3784068875529956	c06003fb63295ec747c9c174b1376a65	VISA 13 digit	38.3436131790258017	-104.654226172561948
36424	2020-07-10 17:14:47	2020-07-10	Mr. Irving Bauch Sr.	mr.irving.bauch.sr.@geemail.com	Berkeley	California	4861110373031603	0b745ce1de65efa7f74fbb793764f68d	VISA 13 digit	37.8667869654055522	-122.251883019887586
36425	2020-07-10 17:16:57	2020-07-10	Yamilet Mayer	yamilet.mayer@geemail.com	Fort Worth	Texas	52787802281076172	9cee072444a8986f874c9b086e1acb54	American Express	32.7147406555302425	-97.3328640257760895
36426	2020-07-10 17:19:05	2020-07-10	Cilla Reilly	cilla.reilly@geemail.com	Fremont	California	3478937162436273	780c046ab64defb0edff98aeae9fa616	American Express	37.4579174356237061	-121.88628556211367
36427	2020-07-10 17:25:49	2020-07-10	Mrs. Baylie Bechtelar	mrs.baylie.bechtelar@geemail.com	Philadelphia	Pennsylvania	3112128037952651932	76c795684c6dd749a336977b601b2875	VISA 16 digit	40.0919219465419658	-75.132043924405437
36428	2020-07-10 17:29:35	2020-07-10	Lesa Boehm	lesa.boehm@warmmail.com	Los Angeles	California	3758702616308369	e27d4b4b12e168aa6969b508409ed500	JCB 15 digit	34.1041540919668975	-118.382932513904933
36429	2020-07-10 17:39:37	2020-07-10	Antwain Satterfield	antwain.satterfield@woohoo.com	Boston	Massachusetts	3337662530328293142	9299bb2a0a9e579931d6fe881ec5c1a0	JCB 15 digit	42.3410456742793357	-71.108091370244324
36430	2020-07-10 17:40:01	2020-07-10	Hyrum Zemlak	hyrum.zemlak@woohoo.com	Thousand Oaks	California	3158394549212786537	c68d09031482d036a56e6e80b8431f9a	Diners Club / Carte Blanche	34.0968293748136588	-118.968067460964249
36431	2020-07-10 17:47:01	2020-07-10	Mrs. Buffy Gislason	mrs.buffy.gislason@geemail.com	Louisville	Kentucky	4258285144873	790becdbfd47b85fbb58b5e3cef60a95	VISA 16 digit	38.1772560256436435	-85.7126086363639672
36432	2020-07-10 17:51:30	2020-07-10	Mr. Avery Nitzsche II	mr.avery.nitzsche.ii@geemail.com	Edison	New Jersey	3528381551444429139	6fe8f8b9ff52abc9d31f5edef5b07bf1	American Express	40.5326712031345764	-74.3402947484102157
36433	2020-07-10 17:57:01	2020-07-10	Marilynn Toy	marilynn.toy@geemail.com	Los Angeles	California	3096098890774504747	f042c54b3717206e3b8dbab674a0f27f	JCB 16 digit	34.0421644286118408	-118.366071076597265
36434	2020-07-10 17:59:54	2020-07-10	Dorothea Howe-Kreiger	dorothea.howe.kreiger@geemail.com	Miami Gardens	Florida	3528243484672005439	60535fcfef449c334a340660fd8df032	Maestro	26.0053188664313382	-80.244893309498579
36435	2020-07-10 18:00:50	2020-07-10	Cherelle Torp	cherelle.torp@geemail.com	Jacksonville	Florida	3719489517389221	f4291cfa3538c838cda069e21a86eb44	Diners Club / Carte Blanche	30.3999637277849004	-81.6234044588714909
36436	2020-07-10 18:12:22	2020-07-10	Aedan Welch	aedan.welch@geemail.com	New York	New York	180008392054477586	46af995b4b34a26167478ca543205bbf	Diners Club / Carte Blanche	40.592581579064948	-73.8421926036372724
36437	2020-07-10 18:16:30	2020-07-10	Brigid Rodriguez	brigid.rodriguez@geemail.com	Sparks	Nevada	6011163589856088716	a0331777e22685d161e68af47dcc1467	JCB 15 digit	39.6426742736488578	-119.677822676286482
36438	2020-07-10 18:37:19	2020-07-10	Maximiliano Zboncak	maximiliano.zboncak@geemail.com	Jacksonville	Florida	4261736099372529	90ac026155faa5d32a530fa15cfc9c85	Maestro	30.3399111156869665	-81.5649720333594956
36439	2020-07-10 18:39:38	2020-07-10	Hezzie Waters	hezzie.waters@geemail.com	Richmond	Virginia	4696881852855065	14b50455cf170951e4b6b87dadefdee4	Maestro	37.4414966878700994	-77.3967736652344485
36440	2020-07-10 18:45:32	2020-07-10	Teresa Hayes	teresa.hayes@geemail.com	Lubbock	Texas	4161505932550257	ae791f56c6e1479e3afee030ef64104d	VISA 16 digit	33.6028139685787295	-101.886193636237465
36441	2020-07-10 18:47:40	2020-07-10	Orilla Cummerata	orilla.cummerata@geemail.com	New York	New York	3088088983811531385	1caf76bc4fb070953416c9c4450e1b52	Maestro	40.7514293721169238	-73.9929732769623314
36442	2020-07-10 18:51:11	2020-07-10	Dr. Butch Nitzsche	dr.butch.nitzsche@warmmail.com	Houston	Texas	55974596085608247	cd46ce7d542fc86b19f925496d94f7bf	Mastercard	29.7786934519264861	-95.349670995633673
36443	2020-07-10 18:52:09	2020-07-10	Florencio Rau Sr.	florencio.rau.sr.@geemail.com	Alexandria	Virginia	4342643487480489	c020b9fe1ddb57f7610d9673ab769373	Voyager	38.8890713894855224	-77.0355586670324328
36444	2020-07-10 19:02:03	2020-07-10	Sylas Ankunding-Ankunding	sylas.ankunding.ankunding@warmmail.com	Oklahoma City	Oklahoma	51811622255008237	e76ce0f93b01ee7f07bb2d05bf704608	Maestro	35.5649285714983989	-97.5702100534353463
36445	2020-07-10 19:03:09	2020-07-10	Geo Conn-Carroll	geo.conn.carroll@woohoo.com	El Paso	Texas	3528309128619451815	aa2f24e455d3782260bce4183657ba7d	JCB 16 digit	31.7501910902388396	-106.443813113680122
36446	2020-07-10 19:04:24	2020-07-10	Sina Yundt	sina.yundt@warmmail.com	Indianapolis	Indiana	676330447012268	47ff57c9b7e5927f9040a0bcdb9ea914	Mastercard	39.7271978525452312	-86.2172438551872915
36447	2020-07-10 19:05:19	2020-07-10	Tomas Ernser	tomas.ernser@geemail.com	Louisville	Kentucky	51386749705005326	50a91e4d593363d534a35a47aa0def18	Mastercard	38.0932456374071506	-85.615909726552303
36448	2020-07-10 19:06:55	2020-07-10	Mr. Jaylen Olson DDS	mr.jaylen.olson.dds@geemail.com	Richmond	Virginia	53710407945305702	2b1c8ef35c18879d7ddfeb748ba3256a	Diners Club / Carte Blanche	37.5374689080972175	-77.4467162160892002
36449	2020-07-10 19:43:26	2020-07-10	Nakita Pollich DDS	nakita.pollich.dds@geemail.com	West Jordan	Utah	4736682423554647	744e193d790d4def76d9fe39e4617cb8	Voyager	40.6408467211086304	-111.981953776729483
36450	2020-07-10 19:43:46	2020-07-10	Reina Zboncak PhD	reina.zboncak.phd@geemail.com	Chicago	Illinois	3096933579951262851	2fa6fcd41bc4f63758b293a329cd3c16	VISA 16 digit	41.8417131721809525	-87.7265101832367407
36451	2020-07-10 19:45:39	2020-07-10	Ms. Amara Friesen	ms.amara.friesen@geemail.com	Houston	Texas	54815738722192325	4b2f436513b2fc40e87857f504fc5da2	Maestro	29.8851364208929233	-95.4202346216902129
36452	2020-07-10 19:47:21	2020-07-10	Cori Bartell	cori.bartell@geemail.com	Philadelphia	Pennsylvania	4901876839655332	f989ab67f934c909bce5773fe6368fb2	Mastercard	40.0164366914849694	-75.1815697075232947
36453	2020-07-10 19:49:15	2020-07-10	Mr. Ewart Barrows	mr.ewart.barrows@geemail.com	Akron	Ohio	4259619446434552	a096d3618ec5dc49676e9681b965e2ad	JCB 16 digit	41.1251265439502873	-81.4761809875104603
36454	2020-07-10 19:51:30	2020-07-10	Mrs. Chelsey West PhD	mrs.chelsey.west.phd@geemail.com	New York	New York	4547954742359	fe978cb5df510a623a15cfcfe697cdf8	VISA 16 digit	40.6252438097018711	-73.9442724119767547
36455	2020-07-10 19:52:16	2020-07-10	Laura Tremblay	laura.tremblay@warmmail.com	Phoenix	Arizona	3000591365734993	7b5534c549c0efe70c863ab003437dee	American Express	33.598536523704233	-112.183319982692979
36456	2020-07-10 19:56:03	2020-07-10	Roman Mitchell	roman.mitchell@geemail.com	Cincinnati	Ohio	3032701225687889	a319c4dd838276e2b1a526e23b40bdf9	Diners Club / Carte Blanche	39.0673725573111312	-84.539153442093351
36457	2020-07-10 20:10:07	2020-07-10	Hamza Harber	hamza.harber@geemail.com	Midland	Texas	3415171183023730	dae0dee5010f7a0182c847355b0e756b	JCB 16 digit	31.9366793266221869	-102.210788855724033
36458	2020-07-10 20:10:33	2020-07-10	Belton Dare-Gerlach	belton.dare.gerlach@geemail.com	Oakland	California	6011745863794409475	03300522486355a3f5c6a34530354d59	JCB 15 digit	37.8132387242636128	-122.245482371891526
36459	2020-07-10 20:14:14	2020-07-10	Reagan Purdy DVM	reagan.purdy.dvm@warmmail.com	New York	New York	869949143586440092	48df7aec123522c090f43dfd9e623b6c	Mastercard	40.6259603609088771	-74.0030598368391423
36460	2020-07-10 20:14:42	2020-07-10	Karon Bernhard	karon.bernhard@geemail.com	Atlanta	Georgia	6011762012594703335	1333b72141a34d2e448769d1ead47194	VISA 16 digit	33.7527216010537003	-84.3495131550401567
36461	2020-07-10 20:15:55	2020-07-10	Meagan Volkman	meagan.volkman@woohoo.com	San Antonio	Texas	869922136824311563	70e7eaa124b47f2cd89634797ea6624e	American Express	29.5392786773923781	-98.59069387538581
36462	2020-07-10 20:19:52	2020-07-10	Neppie Torphy	neppie.torphy@geemail.com	Rancho Cucamonga	California	52979708873410216	af4803cfc5416d21a1cde503d2eea344	American Express	34.0970601289525632	-117.485865955241763
36463	2020-07-10 20:19:59	2020-07-10	Domenica Kirlin-Kuvalis	domenica.kirlin.kuvalis@geemail.com	Pasadena	Texas	3096308698312321243	40bc50261156e7c3a0c5dc036feb295e	JCB 15 digit	29.7419056671544908	-95.0807960050128429
36464	2020-07-10 20:23:48	2020-07-10	Dr. Evans Spinka	dr.evans.spinka@geemail.com	Los Angeles	California	180030910607378456	c94b154e59a716c760463e75a2ae391c	Discover	34.0790301668789226	-118.360575938689706
36465	2020-07-10 20:25:23	2020-07-10	Codi Brekke PhD	codi.brekke.phd@geemail.com	Dallas	Texas	4743931194642979	218f1545cc64d422bb562bc53f92a1a4	Diners Club / Carte Blanche	32.7649497002169525	-96.7822616917509464
36466	2020-07-10 20:26:22	2020-07-10	Kobe Murphy	kobe.murphy@warmmail.com	Philadelphia	Pennsylvania	4950883895654	e1d555f64564a5f75951c6d9c583a42e	Voyager	39.9308710797183224	-75.0842818356949948
36467	2020-07-10 20:29:10	2020-07-10	Dr. Durward Howe	dr.durward.howe@geemail.com	Berkeley	California	869903047226769121	23b157310c317701b2b5e5ea1a5f3f0d	JCB 15 digit	37.8781012806498367	-122.262561020718863
36468	2020-07-10 20:33:05	2020-07-10	Rosie Barrows-Schumm	rosie.barrows.schumm@warmmail.com	Oakland	California	3337722400893344753	380be69d06136e7713361b3c8f632df4	Voyager	37.8036597359462689	-122.259935654768839
36469	2020-07-10 20:33:10	2020-07-10	Ms. Logan Lang	ms.logan.lang@geemail.com	Lincoln	Nebraska	3337602100319243077	c912db44ada8d13a67778e252f89b087	American Express	40.7370375306829757	-96.6224490847133097
36470	2020-07-10 20:35:27	2020-07-10	Mr. Gianni Price Sr.	mr.gianni.price.sr.@geemail.com	Miami	Florida	6011007455272181479	491aa183341d4fceea216c82f4abd1db	VISA 16 digit	25.7189962166965032	-80.2521529475566098
36471	2020-07-10 20:50:22	2020-07-10	Mr. Cedrick Marks	mr.cedrick.marks@warmmail.com	Minneapolis	Minnesota	4825915869811754	47cb30c64595aa73bbc5313fe6bc32f3	VISA 13 digit	45.0104115398686346	-93.3313746399983728
36472	2020-07-10 20:51:01	2020-07-10	Robley Prosacco	robley.prosacco@woohoo.com	Berkeley	California	55117743175214936	48933ea262eeb5270154fc5075be8228	Discover	37.8789136801173356	-122.270642281506198
36473	2020-07-10 20:57:17	2020-07-10	Brad Klein-Durgan	brad.klein.durgan@geemail.com	Greensboro	North Carolina	3047179301166935	3f013f17f6960c9c065dbde265d449cb	JCB 16 digit	36.1726191861670472	-79.8846008488889794
36474	2020-07-10 21:02:04	2020-07-10	Cherryl Fadel	cherryl.fadel@geemail.com	Peoria	Arizona	210065354555575896	1dea670fad3157d9aa4f773e5272dbfa	JCB 16 digit	33.8469102138921656	-112.364668621161954
36475	2020-07-10 21:08:56	2020-07-10	Ruthie Grimes-Huel	ruthie.grimes.huel@warmmail.com	Fremont	California	4013420330410601	f3087b002a9d51821daf3ca82346c1da	VISA 16 digit	37.4500795442778625	-121.857910196901102
36476	2020-07-10 21:09:42	2020-07-10	Mrs. Brianda Beatty	mrs.brianda.beatty@geemail.com	Lincoln	Nebraska	52139322048059408	eeb4bf0c9f06f0ade7906847d0f26ff0	Mastercard	40.8745452973544587	-96.7703992211885833
36477	2020-07-10 21:15:37	2020-07-10	Michell Lebsack-Rohan	michell.lebsack.rohan@geemail.com	New York	New York	4818582237975270	5bc7b70d281255caa2d862aef87523f2	VISA 13 digit	40.6331594197768737	-73.9817840175133199
36478	2020-07-10 21:31:30	2020-07-10	Giovanni Jerde-Brekke	giovanni.jerde.brekke@geemail.com	Miami	Florida	4531605010116360	6faf49dd3eb2546b1b671a003768f01c	American Express	25.7250407529667022	-80.2061626911968091
36479	2020-07-10 21:36:55	2020-07-10	Dr. London Kiehn MD	dr.london.kiehn.md@geemail.com	Dallas	Texas	675920908809708	c6ff57269db8f6e8ce27e1b31fc6c87f	Maestro	32.7725857856024092	-96.7482531458102102
36480	2020-07-10 21:37:54	2020-07-10	Georgine Barton	georgine.barton@geemail.com	Atlanta	Georgia	3528927191773605578	ea468389a7bc9ee4636a2a0600f50edf	VISA 16 digit	33.8614617827624116	-84.3775422560561452
36481	2020-07-10 21:45:20	2020-07-10	Mr. Andreas Fritsch	mr.andreas.fritsch@geemail.com	Memphis	Tennessee	3017939292361138	0292836ef4ab458b88d76819f30881b8	Diners Club / Carte Blanche	35.0510259101234425	-89.8846245233692258
36482	2020-07-10 21:54:55	2020-07-10	Latanya Schuster	latanya.schuster@woohoo.com	New York	New York	180032577867382797	4746ad0b8d40bf953439070a54cb136c	Voyager	40.7150948463696949	-73.906876414445037
36483	2020-07-10 21:55:21	2020-07-10	Miss Shakira Collier DVM	miss.shakira.collier.dvm@geemail.com	Jersey City	New Jersey	4263166876741811	afda47e855353ec628a71751919d8406	JCB 16 digit	40.6504235269907852	-74.1121939185496501
36484	2020-07-10 21:59:07	2020-07-10	Dr. Lelar Brown DDS	dr.lelar.brown.dds@geemail.com	Louisville	Kentucky	4754457495556	e70672e508612ffff0c634736e02c0a6	JCB 15 digit	38.1194761773474511	-85.6140030838154331
36485	2020-07-10 22:03:37	2020-07-10	Ryley Bailey	ryley.bailey@warmmail.com	San Jose	California	869914787157326535	20bc7d42a426d4eca5c1beaaae476142	Maestro	37.3061140922650694	-121.745087342125927
36486	2020-07-10 22:04:07	2020-07-10	Mr. Leon Kerluke	mr.leon.kerluke@geemail.com	Torrance	California	6011498410571806512	4b4f03480fcdd9db8dd8d2ce4e365fe1	JCB 15 digit	33.8789220991451288	-118.374587871938559
36487	2020-07-10 22:04:45	2020-07-10	Denisse Gottlieb	denisse.gottlieb@warmmail.com	Seattle	Washington	4729610390764948	7ad807872108d21986e394cea9a3cf6d	JCB 15 digit	47.631464791197331	-122.274420505288617
36488	2020-07-10 22:11:35	2020-07-10	Dr. Verna Grady	dr.verna.grady@geemail.com	League City	Texas	3040595127196680	6f5bf99c0d4468f0e23f1b67bee23354	VISA 13 digit	29.5761939575359243	-95.0567953358855107
36489	2020-07-10 22:15:01	2020-07-10	Mr. Holland Rau	mr.holland.rau@geemail.com	San Jose	California	3112913840423350748	3125dc1fb4be6dc692de52804e55dbde	VISA 16 digit	37.214595286390562	-121.817448667086282
36490	2020-07-10 22:47:37	2020-07-10	Diandra Ruecker	diandra.ruecker@geemail.com	Anaheim	California	180079474250055202	679006ca20a63a72803bd19dc18f31e9	JCB 15 digit	33.8743743697013713	-117.68387781728282
36491	2020-07-10 22:53:07	2020-07-10	Darcie Murazik	darcie.murazik@geemail.com	Tempe	Arizona	4667602456457	2c0f36579da769e48323670459df4420	American Express	33.2975252917889506	-111.841959240849306
36492	2020-07-10 22:54:42	2020-07-10	Dozier Medhurst	dozier.medhurst@woohoo.com	San Francisco	California	3050288823641353	0d09476d96a30be3d968347532b5591f	VISA 16 digit	37.7671094836975954	-122.434876534162811
36493	2020-07-10 22:56:59	2020-07-10	Wally Gulgowski	wally.gulgowski@geemail.com	Phoenix	Arizona	3789494737600931	fdca72bd3856f8214b5abc0b16dda4ca	JCB 16 digit	33.4799962735667833	-112.089371527631215
36494	2020-07-10 22:59:57	2020-07-10	Miss Livia Hamill DDS	miss.livia.hamill.dds@geemail.com	San Francisco	California	4263275050439389	af01b09be11dd0e4d3e89d48ceb8b37a	Diners Club / Carte Blanche	37.7970946705964863	-122.45663715588276
36495	2020-07-10 23:11:42	2020-07-10	Mr. Darryll Legros DDS	mr.darryll.legros.dds@geemail.com	Memphis	Tennessee	4791540615146543	2e5bf7929b3469a2ec7f688819cf6291	VISA 16 digit	35.1087087969828389	-89.9716447770386907
36496	2020-07-10 23:11:50	2020-07-10	Dr. Jorden Schimmel	dr.jorden.schimmel@geemail.com	Bridgeport	Connecticut	180029367804765063	769f44771015286eb12aae4fde082e2e	VISA 13 digit	41.1783360558260227	-73.2716324905298677
36497	2020-07-10 23:12:58	2020-07-10	Tasia Mosciski	tasia.mosciski@geemail.com	Berkeley	California	4548994637784557	1edfc74ce615ac6e79dc3c67f80bf36c	American Express	37.9141015985682941	-122.288645147035808
36498	2020-07-10 23:13:55	2020-07-10	Estel Steuber	estel.steuber@geemail.com	Louisville	Kentucky	6011646479949110486	7175f81352007452b2bd52080a3ef8bf	Mastercard	38.1494569302905333	-85.6480146808620617
36499	2020-07-10 23:15:09	2020-07-10	Lorine Osinski	lorine.osinski@warmmail.com	Detroit	Michigan	4552491197538088	f4a552ffbe8097d2e1eae25c91adc1f4	VISA 16 digit	42.2921938076540869	-83.1615791451305171
36500	2020-07-10 23:21:54	2020-07-10	Celina Smith MD	celina.smith.md@geemail.com	Oakland	California	4539204038407	2a5a62700e277713369c70b8ec60de23	Mastercard	37.8252154273918464	-122.27146646987525
36501	2020-07-10 23:38:51	2020-07-10	Dr. Kathie Reichel PhD	dr.kathie.reichel.phd@geemail.com	Huntsville	Alabama	180065986947689743	a079ea71fac5fd1db642aa99f3ed22f2	VISA 16 digit	34.6630635477378917	-86.6252228405810882
36502	2020-07-10 23:46:37	2020-07-10	Lurena Champlin	lurena.champlin@geemail.com	Houston	Texas	675916900665817	1997379a4201e6706c43d0fd5891f63f	Voyager	29.7187850892156362	-95.4176275239806699
36503	2020-07-10 23:51:55	2020-07-10	Dr. Keagan Hermiston II	dr.keagan.hermiston.ii@geemail.com	Lincoln	Nebraska	6011008070298160073	5486776d4813f189a2812a5d5639662b	Maestro	40.841540336843579	-96.6003118739623545
36504	2020-07-10 23:55:23	2020-07-10	Odis Blick	odis.blick@geemail.com	Mesquite	Texas	3528878228955864851	bef0a5fdd24b1cf4ebeb7c4e9dfc386c	JCB 16 digit	32.7408143765103077	-96.6715846660278828
36505	2020-07-10 23:57:03	2020-07-10	Robby Kub-Bernier	robby.kub.bernier@geemail.com	Philadelphia	Pennsylvania	4558240111476485	515dad8e00bf1cb316c2a3d952302aa6	VISA 16 digit	40.0855188022792319	-75.2002962014537388
36506	2020-07-11 00:06:14	2020-07-11	Julious Konopelski Jr.	julious.konopelski.jr.@geemail.com	Henderson	Nevada	3782556758014049	3a23a7f1e99b60acf5ba8e6afe99d34b	Mastercard	36.0746296197108975	-115.063727451969683
36507	2020-07-11 00:12:25	2020-07-11	Mr. Keyon Lubowitz Jr.	mr.keyon.lubowitz.jr.@geemail.com	San Antonio	Texas	210011270701922565	f52a26fe4efdd96231f610882c64e5c5	Diners Club / Carte Blanche	29.5173521434027712	-98.5836577800869946
36508	2020-07-11 00:13:18	2020-07-11	Gaylon Fritsch	gaylon.fritsch@geemail.com	San Francisco	California	4694662007077504	8065d44ace6a7fae9c1213cb3079f456	VISA 13 digit	37.7809117626511153	-122.468168322670991
36509	2020-07-11 00:24:58	2020-07-11	Monroe Purdy	monroe.purdy@warmmail.com	Midland	Texas	180064692030617853	f6fec721601497ae91f8610906354cee	Voyager	31.9278137462403606	-102.158335554296158
36510	2020-07-11 00:28:43	2020-07-11	Dr. Sue Hills MD	dr.sue.hills.md@geemail.com	Los Angeles	California	676241150254799	5f2b3860106aa8374f0998acaf470868	JCB 15 digit	34.0711420194111767	-118.492878983727834
36511	2020-07-11 00:36:44	2020-07-11	Ms. Grisel Dare	ms.grisel.dare@geemail.com	Oakland	California	869977810289215535	a32b0888e86a5d062aed863fd22eb1b6	Maestro	37.8332073326837559	-122.258253001101068
36512	2020-07-11 00:52:09	2020-07-11	Dr. Seward Christiansen Sr.	dr.seward.christiansen.sr.@geemail.com	West Valley City	Utah	3018624924290421	70e2a549e73784820ebbd02df90bd087	American Express	40.7409426474701561	-111.947190332527455
36513	2020-07-11 00:53:14	2020-07-11	Kamron Rowe	kamron.rowe@woohoo.com	Tucson	Arizona	4549160881542	685ec6ec496a251a8e84728389012e3e	Diners Club / Carte Blanche	32.1905050294514794	-110.800965126486858
36514	2020-07-11 00:56:46	2020-07-11	Sharlene Schimmel	sharlene.schimmel@geemail.com	Austin	Texas	4985718905859290	8a6ad2bb50aae570c8dcc4ca630636d4	Diners Club / Carte Blanche	30.3275383981071407	-97.6604375447850686
36515	2020-07-11 00:59:09	2020-07-11	Dr. Kittie Bergnaum DDS	dr.kittie.bergnaum.dds@woohoo.com	Los Angeles	California	51737894600242065	6a98e0594e35e7ddd57e6cda5d6f4b1c	Maestro	34.0974739935114926	-118.386731295752526
36516	2020-07-11 00:59:13	2020-07-11	Gaye Rau	gaye.rau@warmmail.com	Hialeah	Florida	55214317841312705	1aac9bbcae3577def0151018b73641ac	VISA 13 digit	25.7836869408819851	-80.3407089300356745
36517	2020-07-11 01:04:30	2020-07-11	Miss Linsey Heller	miss.linsey.heller@geemail.com	Lakewood	Colorado	3096622709054331800	18e9f30ddae2247b370d1a73d5e8a624	VISA 13 digit	39.7919700434371819	-105.159603705352538
36518	2020-07-11 01:07:00	2020-07-11	Eunice Mraz	eunice.mraz@geemail.com	Denver	Colorado	3112515774665241491	c6887d9cd971d8dbb7c4ce3a3f72f4ae	VISA 13 digit	39.8544539332907632	-104.82919697191231
36519	2020-07-11 01:24:17	2020-07-11	Loris Lehner	loris.lehner@woohoo.com	Cambridge	Massachusetts	52480517108697006	31d33540a8ef6a2dbc6c1d91a467d814	JCB 16 digit	42.2863838097304097	-71.0538961608976223
36520	2020-07-11 01:29:06	2020-07-11	Theta Flatley	theta.flatley@geemail.com	Manchester	New Hampshire	3088194957062429466	d812396be480ba1173c359e32ba18b2a	Voyager	43.0254098451301488	-71.4566441586133152
36521	2020-07-11 01:29:22	2020-07-11	Orlin Casper	orlin.casper@geemail.com	Winston–Salem	North Carolina	3443454814728612	7170bb7579c7d5aa96ab78538bd906d5	Maestro	36.1307738481320442	-80.3375760819893259
36522	2020-07-11 01:31:18	2020-07-11	Dr. Jadiel Monahan PhD	dr.jadiel.monahan.phd@warmmail.com	Columbus	Ohio	3498854278837565	e10e30b86500f781defad4f4b6ea094e	Mastercard	39.9507052540823793	-83.0561945324067068
36523	2020-07-11 01:32:25	2020-07-11	Lucina Pfannerstill-Moen	lucina.pfannerstill.moen@geemail.com	Wichita	Kansas	3413663190784876	85c5162f6f5d1db8c09eb038ecdcb9c5	JCB 15 digit	37.6705009023070332	-97.2468416636545214
36524	2020-07-11 01:42:11	2020-07-11	Ms. Franc Kovacek	ms.franc.kovacek@geemail.com	San Francisco	California	6011329353589072187	bca263ffd1cc6c08ca3868f994f3a2c2	JCB 16 digit	37.7733479236637493	-122.438372666035107
36525	2020-07-11 01:51:56	2020-07-11	Micky D'Amore-Schiller	micky.d'amore.schiller@geemail.com	Tacoma	Washington	6011314385021012212	f6c3937909ed4a01f111863ba7b1ff49	JCB 16 digit	47.2062407983120522	-122.552528303419422
36526	2020-07-11 01:57:37	2020-07-11	Miss Irine Wilderman	miss.irine.wilderman@geemail.com	New York	New York	3706473965140398	2e77f6fedca365a41b373635d6637b84	American Express	40.5836669919304569	-73.8501321966655553
36527	2020-07-11 02:12:09	2020-07-11	Ms. Alpha Collins DDS	ms.alpha.collins.dds@geemail.com	Temecula	California	55741143005329554	026cc338ef9b77a5bfca0f3cff0b4196	Mastercard	33.3978698410227892	-117.204317509076361
36528	2020-07-11 02:13:11	2020-07-11	Eleanore Stehr	eleanore.stehr@geemail.com	Charlotte	North Carolina	3059697172000725	04dae715d2fe9f7870c6705a9c1a913f	JCB 15 digit	35.2379143084652711	-80.7468079028129608
36529	2020-07-11 02:17:27	2020-07-11	Sharron Raynor	sharron.raynor@geemail.com	Virginia Beach	Virginia	869976150109999278	8d1b782bc7100945c8bd197188b9587a	Maestro	36.8764839746709896	-76.1247141963940095
36530	2020-07-11 02:20:48	2020-07-11	Epifanio Bruen-Homenick	epifanio.bruen.homenick@geemail.com	Lancaster	California	3041159114049490	fbd152825c43bf98daeb9158d0310320	Mastercard	34.6411869156885928	-118.105736291778456
36531	2020-07-11 02:22:38	2020-07-11	Dr. Reinhold Roob I	dr.reinhold.roob.i@woohoo.com	Rialto	California	639061348482417	04be61f0b683d230c144d1e075f4f64d	American Express	34.0351937966637337	-117.475624535613875
36532	2020-07-11 02:33:47	2020-07-11	Josefita Kuhn PhD	josefita.kuhn.phd@geemail.com	San Francisco	California	4905256036731077	d519b16b537ebc71b3300b0e50567470	Maestro	37.7675944286349434	-122.449812750532772
36533	2020-07-11 02:37:47	2020-07-11	Kaylie Rippin	kaylie.rippin@warmmail.com	New York	New York	180052777395062391	f2207bfc93bf7c697c4714020ef7c457	VISA 16 digit	40.6226888447292112	-74.0194984368875595
36534	2020-07-11 02:40:39	2020-07-11	Oralia Fisher PhD	oralia.fisher.phd@geemail.com	Minneapolis	Minnesota	4409661070451	916b242d7aaef7cdb620dd773e3c73e2	JCB 15 digit	44.9823547030884754	-93.2214958417501265
36535	2020-07-11 02:50:34	2020-07-11	Wayman Cummings II	wayman.cummings.ii@geemail.com	Pompano Beach	Florida	3096194320669644666	81c05275132fbef0fa209a1b039a488f	JCB 15 digit	26.2395013142175948	-80.1605618159599516
36536	2020-07-11 02:58:27	2020-07-11	Dr. Maverick Hessel Jr.	dr.maverick.hessel.jr.@geemail.com	San Francisco	California	3739942447267319	800488140dfd099004b86932d375efc1	Voyager	37.7998155708839079	-122.409676205066006
36537	2020-07-11 03:16:08	2020-07-11	Oda Kertzmann	oda.kertzmann@geemail.com	New York	New York	869963565829099999	2961394023f979e73a4ab39c2dd102af	American Express	40.5670404840018577	-73.8497491082537891
36538	2020-07-11 03:33:08	2020-07-11	Myrtis Bode	myrtis.bode@woohoo.com	Clinton	Michigan	869922085089380856	03225164cc816eec2f71f1fde220c671	Mastercard	42.5550375927306703	-82.9682944939546303
36539	2020-07-11 03:43:16	2020-07-11	Ann Fisher	ann.fisher@geemail.com	Newark	New Jersey	4296929416092628	75e698a952a1ef622499f3be37bfef50	JCB 15 digit	40.7864852941975045	-74.1966905685816016
36540	2020-07-11 03:47:14	2020-07-11	Franklin Schneider	franklin.schneider@geemail.com	Rialto	California	4533725773469570	f0b0545aba90188e7a107f7ca3f86c47	Maestro	34.087566355218371	-117.331245191822944
36541	2020-07-11 03:47:55	2020-07-11	Kerry Bednar	kerry.bednar@geemail.com	Las Vegas	Nevada	3096409979427960150	aa77604bf57db72732324af0ff985b1f	JCB 15 digit	36.299968271386625	-115.272846167974535
36542	2020-07-11 04:01:04	2020-07-11	Author Hintz	author.hintz@geemail.com	Jackson	Mississippi	4568655329205	43e028a995712fadf2f27c91d436bd7e	JCB 15 digit	32.362845181551954	-90.139558019207044
36543	2020-07-11 04:09:20	2020-07-11	Shameka Kuhn DVM	shameka.kuhn.dvm@geemail.com	Lincoln	Nebraska	4450290130647235	e1e75d2613a01737adda1ec1bf551cc1	JCB 16 digit	40.7700207382459183	-96.7776805577028512
36544	2020-07-11 04:13:19	2020-07-11	Adel Hirthe	adel.hirthe@geemail.com	Anchorage	Alaska	54335400294638653	cc6fe202851e794b894d669b619f113e	VISA 16 digit	61.2682554146491043	-149.253453379788624
36545	2020-07-11 04:18:06	2020-07-11	Hunter Wisozk	hunter.wisozk@geemail.com	New York	New York	53844310176360272	4258d20b97220da9bdd3864ed74580fb	Voyager	40.6928289436958721	-73.9140572191111715
36546	2020-07-11 04:28:31	2020-07-11	Miss Cordie Hodkiewicz DDS	miss.cordie.hodkiewicz.dds@warmmail.com	Edison	New Jersey	210093461038564250	405e3c58c78c829d7736af6016023990	Maestro	40.4719346504155553	-74.3891425525821717
36547	2020-07-11 04:32:12	2020-07-11	Bristol Romaguera	bristol.romaguera@geemail.com	San Francisco	California	3158412178527400002	b868f8a597bd677967ba50ecf10d5a46	Voyager	37.825604756484978	-122.420530839009047
36548	2020-07-11 04:32:50	2020-07-11	Mariah Cruickshank	mariah.cruickshank@geemail.com	Indianapolis	Indiana	869952064286654028	65b1370635f0dd7987493b5d513790c6	American Express	39.8133727153304946	-86.1569527858138002
36549	2020-07-11 04:38:07	2020-07-11	Christeen Grady	christeen.grady@geemail.com	Providence	Rhode Island	869963252887770031	4ebaa684bcfd0b1b3c3299bc329f07d4	JCB 16 digit	41.7556132634490709	-71.4209295296028301
36550	2020-07-11 04:42:00	2020-07-11	Roy Weber	roy.weber@geemail.com	Frisco	Texas	4348730230437827	50e31ef5a2cdfcb7dd6be8b54e5261eb	American Express	33.126881333533305	-96.7538503991648469
36551	2020-07-11 04:51:32	2020-07-11	Roy Krajcik	roy.krajcik@geemail.com	Austin	Texas	4837987170243	7ac6a209f098a54173c3f7e819e87048	Mastercard	30.2463908929504441	-97.8445530562434413
36552	2020-07-11 04:54:33	2020-07-11	Texanna Mohr-McGlynn	texanna.mohr.mcglynn@geemail.com	San Francisco	California	3528165320751873301	f76c07e5c48635789025c0dd75740644	JCB 16 digit	37.8069642137310495	-122.444297233179071
36553	2020-07-11 04:55:14	2020-07-11	Goldie Cronin	goldie.cronin@warmmail.com	Salt Lake City	Utah	3771933173101078	87ed940866e30e47efbb6d5e38ddb556	JCB 16 digit	40.7253244193881727	-111.881329188769683
36554	2020-07-11 04:58:36	2020-07-11	Evalyn Gusikowski-Gaylord	evalyn.gusikowski.gaylord@warmmail.com	Sandy Springs	Georgia	4343685440409906	9896eedbca4b953275a32ed9ca262e50	VISA 13 digit	33.9521804913468657	-84.3998928993556632
36555	2020-07-11 05:03:50	2020-07-11	Jettie Johnston	jettie.johnston@geemail.com	Kansas City	Missouri	4300427193754	f2684c0425a6aa7b034e916f7e959488	VISA 16 digit	39.0471772074535508	-94.5991679475400673
36556	2020-07-11 05:05:31	2020-07-11	Mr. Case Trantow Sr.	mr.case.trantow.sr.@warmmail.com	Phoenix	Arizona	3528822924665802739	980507373302bb3584fa1369aebb1138	JCB 16 digit	33.4802018312670313	-112.011486935282505
36557	2020-07-11 05:06:05	2020-07-11	Marcos Hayes	marcos.hayes@woohoo.com	Baltimore	Maryland	503895008540809	d749c6e810d12cc5d2a6f9377722b3c3	Mastercard	39.3655268109403522	-76.5929048942420678
36558	2020-07-11 05:13:25	2020-07-11	Adriane Harris	adriane.harris@woohoo.com	Columbus	Ohio	6011933357904047616	47c199767e6bbaa031096ba7e2b65173	JCB 16 digit	40.0048646372321954	-83.0618947799086698
36559	2020-07-11 05:18:48	2020-07-11	Dr. Emilie Spencer	dr.emilie.spencer@woohoo.com	Los Angeles	California	3785846924892676	b6d122dcbb1310edb2b33bb440a23eba	VISA 16 digit	34.0588146064761972	-118.435031783859429
36560	2020-07-11 05:34:27	2020-07-11	Alois Kling	alois.kling@geemail.com	Broken Arrow	Oklahoma	210004516529470107	85cd1a4072ffe8725abdbec7098816c0	JCB 16 digit	36.0241912496052663	-95.7896120051331934
36561	2020-07-11 05:36:13	2020-07-11	Eileen Gusikowski-Koch	eileen.gusikowski.koch@geemail.com	New York	New York	3337882299078699460	dd53e27f97856f3e2707ad9c7687c2b1	Voyager	40.7554191801454877	-73.9766090519621997
36562	2020-07-11 05:51:18	2020-07-11	Fenton Rowe	fenton.rowe@geemail.com	New Orleans	Louisiana	4959462544963344	d47d7e1cfcfc142020fdd4ac7c3bb3d2	Diners Club / Carte Blanche	30.1099339961089179	-89.9644124172888695
36563	2020-07-11 05:53:28	2020-07-11	Maria Cruickshank DDS	maria.cruickshank.dds@geemail.com	Toledo	Ohio	4486635998591008	2712af235a22953fba054429487f325f	Discover	41.7104911310303947	-83.4997208270110178
36564	2020-07-11 05:58:13	2020-07-11	Nichole Gulgowski	nichole.gulgowski@woohoo.com	Orlando	Florida	3058386419993378	2e840d640732c7097f037b0bb0ce1cd0	Mastercard	28.3633807161621725	-81.2313572542708329
36565	2020-07-11 06:00:52	2020-07-11	Captain Quigley	captain.quigley@geemail.com	San Francisco	California	4572438797274	dc496cd29afd348f71530076f841f7ff	Diners Club / Carte Blanche	37.7789519658840902	-122.427959235393516
36566	2020-07-11 06:01:10	2020-07-11	Ernestine Pagac	ernestine.pagac@geemail.com	Philadelphia	Pennsylvania	3458547693930613	fd38b6b45ad0654b36831efe78d17acb	VISA 16 digit	40.0486289022915045	-75.208642115061366
36567	2020-07-11 06:16:49	2020-07-11	Fredericka Boehm	fredericka.boehm@geemail.com	Chicago	Illinois	3528049817826826463	561d7ab144459ad7c3311ce4fc77feb1	Maestro	41.8242261053364714	-87.6130925691250724
36568	2020-07-11 06:28:32	2020-07-11	Philo Hahn-Heaney	philo.hahn.heaney@woohoo.com	New York	New York	54441047181350834	d8121697f3881654178ae6c8e02a552c	VISA 16 digit	40.6418483407925777	-73.9445178064878945
36569	2020-07-11 06:29:35	2020-07-11	Press Rempel	press.rempel@geemail.com	Huntington Beach	California	3088679168635732873	790dc4a183cfabd72fbd8c5b675e90eb	Mastercard	33.7548035832163009	-118.063224033930524
36570	2020-07-11 06:30:25	2020-07-11	Dot Kuphal	dot.kuphal@geemail.com	Seattle	Washington	4351674740783169	b95ace3fa2d6adb449bb2b65efca1b83	Discover	47.6923783425632877	-122.361926019649573
36571	2020-07-11 06:40:29	2020-07-11	Jeremy Romaguera	jeremy.romaguera@warmmail.com	Nashville	Tennessee	869910310510905392	485965e38a9caef9981dda62bf04e8f2	Voyager	36.2524042977608687	-86.8750402560830111
36572	2020-07-11 06:41:20	2020-07-11	Xzavier Leannon	xzavier.leannon@geemail.com	Dayton	Ohio	3791134996117922	33cfa6e40b86376b4b7edc52ce5f54d4	Maestro	39.8116349735088662	-84.1120596538022198
36573	2020-07-11 06:48:59	2020-07-11	Edw Hilpert Jr.	edw.hilpert.jr.@geemail.com	Tucson	Arizona	676276001309806	2c8c5b98755325763174dd58c911c6a1	VISA 13 digit	32.0782023778691894	-110.957524722138785
36574	2020-07-11 06:55:00	2020-07-11	Cap Dickinson V	cap.dickinson.v@geemail.com	San Francisco	California	210024945648313268	d18b5e853f165b02ca7061d98c2189d7	JCB 16 digit	37.7782880867251905	-122.413662651713892
36575	2020-07-11 06:57:44	2020-07-11	Mrs. Ella Morar MD	mrs.ella.morar.md@geemail.com	New Orleans	Louisiana	3088637077346025124	7679d248b277899464948c3ebd06c3cf	Voyager	30.12825100259073	-89.9696936012040851
36576	2020-07-11 07:05:12	2020-07-11	Brianda Kerluke	brianda.kerluke@geemail.com	Brownsville	Texas	4778125185712101	72c3625a28c8d8361e82152a0a8b1564	Voyager	25.9851243096481994	-97.5470260052196636
36577	2020-07-11 07:21:27	2020-07-11	Corene Barrows-Zieme	corene.barrows.zieme@warmmail.com	San Francisco	California	4855060115069692	bb51aa7eddb575434dc1176b49fbf60b	Mastercard	37.766946399493257	-122.421699556724647
36578	2020-07-11 07:31:34	2020-07-11	Gilbert Cronin	gilbert.cronin@geemail.com	Detroit	Michigan	3041320976422171	c5a5ec3d5a8106ddaf5db3b05356df24	Mastercard	42.4014554633684497	-83.1683209303885604
36579	2020-07-11 07:35:54	2020-07-11	Dr. Magen Schimmel	dr.magen.schimmel@warmmail.com	New York	New York	6011449948936892438	b6fdfd58214cb3e32e8c662527cf0f07	Discover	40.6947756472732891	-74.0043219428870742
36580	2020-07-11 07:37:28	2020-07-11	Isom Effertz	isom.effertz@geemail.com	New York	New York	4017312890995954	c9c5b5ddd49d32bd493a852e6d3d17de	Discover	40.6088940405044667	-73.8700734863884776
36581	2020-07-11 07:37:38	2020-07-11	Mr. Doss Oberbrunner	mr.doss.oberbrunner@geemail.com	San Francisco	California	3158633100180096128	0eef3f3109cf01966fd9f0d98ad15be7	Mastercard	37.7478593101042179	-122.433914646567047
36582	2020-07-11 07:38:42	2020-07-11	Brandyn Johnston	brandyn.johnston@woohoo.com	Aurora	Colorado	630470035620486	94ec1bffc2ac4da466b115ac39cbb497	Voyager	39.6027769441362523	-104.67380024940968
36583	2020-07-11 07:41:45	2020-07-11	Mr. Namon Lynch	mr.namon.lynch@woohoo.com	Phoenix	Arizona	4122377075637	07a5245cef7df9ccbebc960ff52a3c24	VISA 16 digit	33.5673955336611769	-112.133279554212848
36584	2020-07-11 07:46:07	2020-07-11	Aiden Welch-Beier	aiden.welch.beier@geemail.com	Edison	New Jersey	630460623861121	c2d7a0dddd491460c2b62e9b42e48808	Voyager	40.4992224247157537	-74.4340165110822767
36585	2020-07-11 07:55:46	2020-07-11	Janelle Nienow	janelle.nienow@geemail.com	New York	New York	51162958254041182	afdcb8de84d6265bc3084343e74374a2	JCB 15 digit	40.7608041676916173	-73.8687360707566114
36586	2020-07-11 08:18:41	2020-07-11	Braedon Haag	braedon.haag@warmmail.com	Allentown	Pennsylvania	4936567036665	85812e738f05d41fa9aaf5a33dc02b04	JCB 15 digit	40.6626670039039126	-75.3957727970570204
36587	2020-07-11 08:21:45	2020-07-11	Winston Moen	winston.moen@geemail.com	Las Vegas	Nevada	4371261816602	610f1139363439f2884e777abd08de58	VISA 16 digit	36.1944610725257547	-115.280794477157656
36588	2020-07-11 08:22:36	2020-07-11	Emmitt Marvin	emmitt.marvin@warmmail.com	Chicago	Illinois	3088191870745688296	8a4f3d9991378b1fcaeead1211c3f36d	JCB 16 digit	41.8364917760085362	-87.5974835546716974
36589	2020-07-11 08:23:21	2020-07-11	Dr. Harold Kirlin	dr.harold.kirlin@warmmail.com	Charlotte	North Carolina	4850792468421	295aee4d5b771a68a12e79bcab04f0b5	Diners Club / Carte Blanche	35.1968451557934259	-80.7834053582456022
36590	2020-07-11 08:31:47	2020-07-11	Dr. Almira Kemmer DVM	dr.almira.kemmer.dvm@geemail.com	Evansville	Indiana	4662882525330528	5b45b01c5f70136678824e54417650a4	Voyager	37.9816242650754745	-87.5289970301955975
36591	2020-07-11 08:47:50	2020-07-11	Jake Hoppe	jake.hoppe@geemail.com	Berkeley	California	3088746439894470581	87584d3d63661c640267bbbfb79b837a	VISA 16 digit	37.8739900938329015	-122.243097498164914
36592	2020-07-11 08:58:40	2020-07-11	Shalon Gusikowski	shalon.gusikowski@woohoo.com	Dallas	Texas	060498062483924	5a09327c1bfee87d8860505e732bf83d	JCB 16 digit	32.7385073553111425	-96.7023100302051688
36593	2020-07-11 09:03:30	2020-07-11	Sherman Hills	sherman.hills@geemail.com	Cambridge	Massachusetts	869996042903877576	404900a84090b9621d50c7d604442db2	Maestro	42.2887299427520489	-71.2167939771048708
36594	2020-07-11 09:06:42	2020-07-11	Dr. Haven Goyette PhD	dr.haven.goyette.phd@woohoo.com	Colorado Springs	Colorado	3412456950489385	422882b97285e0a5bf573e4aa7e84a01	Mastercard	38.9167335287716227	-104.754883709146455
36595	2020-07-11 09:21:00	2020-07-11	Mr. Myer Halvorson	mr.myer.halvorson@geemail.com	Toledo	Ohio	4466665891631423	c4e7e69a00fca2d5889b76c172862b61	JCB 15 digit	41.5959487013690179	-83.5432782564178211
36596	2020-07-11 09:27:17	2020-07-11	Miss Estie Hickle	miss.estie.hickle@geemail.com	Tucson	Arizona	869969659358038058	98fa120765b3fddcea5050991a54d7c9	VISA 16 digit	32.1406157546252018	-110.866586387645825
36597	2020-07-11 09:33:25	2020-07-11	Earlean Emard	earlean.emard@geemail.com	Miami	Florida	210063942226097571	379d9cbfda57220d913086138f64496b	Maestro	25.7319850997205855	-80.304169336414347
36598	2020-07-11 09:38:36	2020-07-11	Ivah Christiansen	ivah.christiansen@geemail.com	Raleigh	North Carolina	4721670787434438	e4bbe52dfc479002ae0ab00e40fbedc1	Discover	35.7507670508831694	-78.5976989721816039
36599	2020-07-11 09:41:10	2020-07-11	Geoffrey Sporer	geoffrey.sporer@geemail.com	Burbank	California	4830332889337617	2e51b90764193bae3402d4c1a400edf2	Discover	34.2104522029798517	-118.389256591725726
36600	2020-07-11 09:46:04	2020-07-11	Wallace Barrows	wallace.barrows@geemail.com	San Diego	California	6011196943691478114	80c8df8483b0efa3600f6e113c9348e8	Diners Club / Carte Blanche	32.8771109756149329	-117.163446440026163
36601	2020-07-11 09:48:59	2020-07-11	Humphrey Hamill	humphrey.hamill@geemail.com	Palmdale	California	210030251849953586	cac8fc8bae10690c0155b7d28f113a84	VISA 16 digit	34.6274449642598654	-118.051265942584351
36602	2020-07-11 09:50:27	2020-07-11	Jed Kuphal	jed.kuphal@warmmail.com	New York	New York	502066615112993	20b92614235a826f541ad4ff244dbdc1	Maestro	40.6081965621784349	-73.9661694888386876
36603	2020-07-11 10:06:44	2020-07-11	Ms. Reatha Abbott	ms.reatha.abbott@geemail.com	New York	New York	51103926857287983	b9f1140ce4063ab4f99b34d6170cf009	VISA 16 digit	40.7506830034535383	-73.9880552809115528
36604	2020-07-11 10:16:08	2020-07-11	Willow Lehner MD	willow.lehner.md@warmmail.com	Grand Rapids	Michigan	4679926544132	9d80b71685d50ac1cff6b51a00e9b3b5	VISA 13 digit	42.9834508686128984	-85.7254754086624899
36605	2020-07-11 10:21:32	2020-07-11	Amiyah Cole	amiyah.cole@woohoo.com	Phoenix	Arizona	3493638502623668	1f0910414b834583aaa1adef353b2d69	American Express	33.4902522352457055	-112.024231622966383
36606	2020-07-11 10:25:12	2020-07-11	Ms. Lempi Renner PhD	ms.lempi.renner.phd@geemail.com	Joliet	Illinois	6011689154834987813	52831518ab89ec7ff8fbddb5f7b7569d	Maestro	41.5506005684703581	-88.1922479210060004
36607	2020-07-11 10:27:48	2020-07-11	Adolf Denesik	adolf.denesik@geemail.com	Bellevue	Washington	869978642979550817	a6ecce2ab27cae274f748b6ca923b941	Voyager	47.5601973829973517	-122.224736009776592
36608	2020-07-11 10:30:28	2020-07-11	Kesha Gottlieb	kesha.gottlieb@woohoo.com	Los Angeles	California	3096894245951333889	33ef767a6f867f188e1cb454368340c0	Voyager	34.0225635064631646	-118.487366311297933
36609	2020-07-11 10:32:43	2020-07-11	Kirstie Olson-Hermiston	kirstie.olson.hermiston@geemail.com	Meridian	Idaho	180075439593050776	6143a552b0550ba34905af24774ed572	JCB 16 digit	43.6267842307228548	-116.32335088583045
36610	2020-07-11 10:35:39	2020-07-11	Philomena D'Amore	philomena.d'amore@geemail.com	Berkeley	California	3337025445379811175	bf1118019174971c679b440a0d82455d	Voyager	37.868560866916205	-122.291093959628498
36611	2020-07-11 10:53:41	2020-07-11	Bailey Klein	bailey.klein@warmmail.com	San Francisco	California	3096411068229592001	1629930f2a355eb3561e373031216e85	JCB 15 digit	37.7616719657949815	-122.430883648453417
36612	2020-07-11 10:57:51	2020-07-11	Elmore Langosh	elmore.langosh@geemail.com	Ventura	California	4616728965177852	bcd29aa24cefb6a2d85f20812c5e678d	American Express	34.1957111235868183	-119.310616454166166
36613	2020-07-11 11:11:31	2020-07-11	Wenzel Reilly	wenzel.reilly@warmmail.com	Houston	Texas	6011897685471985683	a7345a897ad774afbaae3179c765ca84	JCB 15 digit	29.8669426618687801	-95.3974040095243652
36614	2020-07-11 11:12:07	2020-07-11	Suzette Herzog	suzette.herzog@geemail.com	New York	New York	3158470229732406455	b617f4aa472a5a2fa7ecb66a91a8d1db	Voyager	40.7075381183754672	-74.0054330402415275
36615	2020-07-11 11:13:06	2020-07-11	Jacob Hamill	jacob.hamill@geemail.com	San Francisco	California	4278148308819228	6236695c3ab23043e6d4e132e186b215	American Express	37.8010258758785014	-122.475460015768377
36616	2020-07-11 11:20:20	2020-07-11	Dr. Ibrahim Buckridge	dr.ibrahim.buckridge@geemail.com	Los Angeles	California	3337618420639768823	595d1b9f084a857c8cb1b2599630160e	American Express	34.0961214291263346	-118.387316775041811
36617	2020-07-11 11:25:27	2020-07-11	Rosalyn D'Amore	rosalyn.d'amore@warmmail.com	New York	New York	4211828397367	0a0668361697b1dbe7c36192eac1f951	Discover	40.658545538851989	-73.8892397747270735
36618	2020-07-11 11:28:39	2020-07-11	Ramiro Nienow I	ramiro.nienow.i@geemail.com	Raleigh	North Carolina	869973627001060807	acc9f8a692d7e143783abdfbb12ee259	Diners Club / Carte Blanche	35.8945494292903646	-78.7353395692940836
36619	2020-07-11 11:31:58	2020-07-11	Mr. Andrae Swaniawski DDS	mr.andrae.swaniawski.dds@geemail.com	Ann Arbor	Michigan	3112358965053698652	88a64397f449a74fe9dfd11243da13d3	Maestro	42.2254143035098934	-83.6976171358130898
36620	2020-07-11 11:38:12	2020-07-11	Mr. Linus Stamm	mr.linus.stamm@geemail.com	Surprise	Arizona	3112170807080563812	f88a3a9462ae3b0e854f682d08662ac0	Maestro	33.67239458106868	-112.503727774484815
36621	2020-07-11 11:42:02	2020-07-11	Mr. Wilson Hahn III	mr.wilson.hahn.iii@geemail.com	Macon	Georgia	3024003733940951	1fdbdb546ea5077a0609983738d28a71	JCB 16 digit	32.8811731884732836	-83.7705990320265244
36622	2020-07-11 11:43:38	2020-07-11	Audley Abshire DVM	audley.abshire.dvm@geemail.com	Baltimore	Maryland	6011499711963102991	d2378e42b3487a8db1692f103671a185	Discover	39.2480518298689276	-76.7064925068076775
36623	2020-07-11 11:53:57	2020-07-11	Thea Skiles DDS	thea.skiles.dds@geemail.com	Lakewood	Colorado	6011147132946814915	3e781679a8c0355df399f9b87101778b	Diners Club / Carte Blanche	39.7241018136437987	-105.183156582948186
36624	2020-07-11 11:56:47	2020-07-11	Mr. Colvin Pouros	mr.colvin.pouros@geemail.com	Fort Worth	Texas	3112589428651306856	9d3d68504ecb10db2ae6ef2aeda2fd86	JCB 15 digit	32.7595972834676488	-97.2984102611251132
36625	2020-07-11 12:18:52	2020-07-11	Lottie O'Hara-Hammes	lottie.o'hara.hammes@warmmail.com	Jersey City	New Jersey	6011980322821704055	147f7a29d76c3ce63ce190dd1dc798d6	American Express	40.7710008597873141	-74.1128071453843376
36626	2020-07-11 12:22:50	2020-07-11	Buddy Gibson	buddy.gibson@woohoo.com	San Antonio	Texas	180039794017336671	81606a7869ef9db60d4a525e160cd355	JCB 16 digit	29.39002423394248	-98.4323629407048202
36627	2020-07-11 12:24:34	2020-07-11	Mckenzie McKenzie	mckenzie.mckenzie@geemail.com	Renton	Washington	3337580817621433809	7bed126b40dddf6249ede3c176410921	Diners Club / Carte Blanche	47.398183551110705	-122.248672288104885
36628	2020-07-11 12:32:37	2020-07-11	Mr. Talon Batz Sr.	mr.talon.batz.sr.@geemail.com	Los Angeles	California	6011260474615460088	2b6f7388c8e025100d6c9a3ae4ae1585	Mastercard	34.0680146794166419	-118.461979748913265
36629	2020-07-11 12:55:36	2020-07-11	Dr. Linwood Durgan II	dr.linwood.durgan.ii@geemail.com	Antioch	California	53380564653576962	9c0da50a80d9349a24197423678bb227	JCB 16 digit	38.0169219047561313	-121.826084319426485
36630	2020-07-11 13:00:27	2020-07-11	Suzanne Kohler	suzanne.kohler@woohoo.com	El Paso	Texas	3055993494821508	6efe1717bba1078fb9c47e1b668fefea	VISA 16 digit	31.8289374957155466	-106.447723552769062
36631	2020-07-11 13:00:35	2020-07-11	Kailee Huel-Orn	kailee.huel.orn@geemail.com	Newark	New Jersey	3096020859002108640	73ed8251b4cc67c7b04b88f1d342ad5a	JCB 16 digit	40.7967395700894357	-74.2382718412414278
36632	2020-07-11 13:08:22	2020-07-11	Dr. Winfield Cartwright	dr.winfield.cartwright@woohoo.com	Orlando	Florida	3112085654667599049	4baa6fdb50c85ac5d2ab091b3bd89248	VISA 16 digit	28.4616628930702795	-81.1979231560569303
36633	2020-07-11 13:12:05	2020-07-11	Tatsuo Turcotte-Mosciski	tatsuo.turcotte.mosciski@woohoo.com	Santa Clara	California	3757710775055409	ad9e0506e6ad2eac4ba6ebc9e7bb936b	Voyager	37.3588243111319898	-122.038253011181581
36634	2020-07-11 13:17:47	2020-07-11	Eddie Krajcik-Ward	eddie.krajcik.ward@geemail.com	San Francisco	California	6011557946125790528	85efa486b3f416cd904cdef87ccd0437	JCB 16 digit	37.7743257314439447	-122.393726217760886
36635	2020-07-11 13:20:32	2020-07-11	Miss Louise Dare	miss.louise.dare@woohoo.com	Anchorage	Alaska	675982906292147	d2d1022af4fd6bc98cf30def6767cf7e	JCB 16 digit	61.2698496184062265	-149.273223228112982
36636	2020-07-11 13:23:57	2020-07-11	Dr. Arlin Hilll IV	dr.arlin.hilll.iv@geemail.com	Garland	Texas	51862523612550382	bc579ea29a6ecf686abfc08fa7dfaebb	American Express	32.9238997735783414	-96.5688645171627513
36637	2020-07-11 13:24:14	2020-07-11	Jaden Beier	jaden.beier@geemail.com	Irvine	California	3112193990720968717	ae889467c6b39e30f4a4dee02dd61aea	Diners Club / Carte Blanche	33.640850376199559	-117.844499944850057
36638	2020-07-11 13:29:22	2020-07-11	Ossie Hirthe	ossie.hirthe@geemail.com	Omaha	Nebraska	869982531800588977	3cbde841fa65568ed9768eba2233f5fa	Mastercard	41.172243726174905	-96.1379042728919586
36639	2020-07-11 13:41:08	2020-07-11	Rusty Gutmann	rusty.gutmann@geemail.com	Woodbridge	New Jersey	180019740945110971	5c6da06e4ff1c66581b0f815e29a13f6	VISA 16 digit	40.5626678465556338	-74.3009901640795078
36640	2020-07-11 13:43:12	2020-07-11	Andy Heidenreich	andy.heidenreich@warmmail.com	Norfolk	Virginia	3088055632775351319	c7eab319232604701d3b13885ffcc715	VISA 13 digit	36.8332263770066248	-76.279859075276562
36641	2020-07-11 13:57:10	2020-07-11	Dr. Deondre Pollich PhD	dr.deondre.pollich.phd@geemail.com	Eugene	Oregon	4915038310945625	947d8552c78d1a3df26fdbecc296dfe9	Voyager	44.0036173423945911	-123.125220370384682
36642	2020-07-11 14:03:22	2020-07-11	Mr. Augustus Quigley IV	mr.augustus.quigley.iv@geemail.com	New Haven	Connecticut	6011816257909277444	f89a02afff90667feb7c4bef582535d0	JCB 16 digit	41.2162999350570161	-72.8554667691234528
36643	2020-07-11 14:13:01	2020-07-11	Winton Quigley	winton.quigley@warmmail.com	Anaheim	California	6011712632214881640	7cf37d5c96ef945becd131b550d7edb9	JCB 15 digit	33.8796627054754609	-117.745481788294754
36644	2020-07-11 14:16:03	2020-07-11	Sullivan Wiza-Sanford	sullivan.wiza.sanford@warmmail.com	New York	New York	210085402792261949	457abd29aea069fd81d0b54d7ee5a149	Diners Club / Carte Blanche	40.7023000684790333	-73.8620440311625543
36645	2020-07-11 14:21:24	2020-07-11	Dr. Loren Gutmann PhD	dr.loren.gutmann.phd@geemail.com	Rochester	New York	4723845922258	fe051d6e2a99756ecee5541a1626484b	American Express	43.1756092177215933	-77.6255820338852658
36646	2020-07-11 14:28:48	2020-07-11	Camille Lang PhD	camille.lang.phd@geemail.com	San Francisco	California	54451179592350181	bec845a93215ff7de624cb6f3587c772	JCB 15 digit	37.7760975932329544	-122.428733696366677
36647	2020-07-11 14:30:21	2020-07-11	Mr. Gustaf Mayer	mr.gustaf.mayer@woohoo.com	Miami	Florida	4397246276128139	5c866ac6f379597c209c6f7058073e7f	VISA 16 digit	25.8037978655796501	-80.1825163348451326
36648	2020-07-11 14:32:58	2020-07-11	Ms. Annice Jenkins MD	ms.annice.jenkins.md@geemail.com	Modesto	California	3497206611872125	472d2b1d9db264a771995cef9efb3da8	Voyager	37.6889908277895316	-120.987490800788621
36649	2020-07-11 14:52:51	2020-07-11	David O'Connell Jr.	david.o'connell.jr.@geemail.com	San Antonio	Texas	869944688801869322	54741f12d7e8d2193f6e8db601cb9f91	JCB 16 digit	29.43110210933499	-98.5277262910105236
36650	2020-07-11 14:57:34	2020-07-11	Theron Osinski	theron.osinski@geemail.com	Philadelphia	Pennsylvania	4692381129877	e7675e64c29dc2e9b9ac9abe138cf6ef	Diners Club / Carte Blanche	39.9712329100310768	-75.1320606995739126
36651	2020-07-11 14:58:46	2020-07-11	Dr. Keaton Smitham	dr.keaton.smitham@woohoo.com	San Francisco	California	6011023083694805887	cd90d11c89654c76f6ab94905f6ccb86	Voyager	37.7779696549314394	-122.413033437253148
36652	2020-07-11 15:24:45	2020-07-11	Elihu Connelly	elihu.connelly@woohoo.com	Berkeley	California	53580185329473471	f108d38bcb0f9f017d09fad2b2ffbb43	JCB 16 digit	37.8718008111088054	-122.265842262631793
36653	2020-07-11 15:28:04	2020-07-11	Sam Dietrich	sam.dietrich@woohoo.com	New York	New York	3436366028266651	acd70f9d399d19a2baa76354ebb6f29c	VISA 13 digit	40.7094352644626056	-73.8777689548104917
36654	2020-07-11 15:36:17	2020-07-11	Dr. Lashonda Kihn PhD	dr.lashonda.kihn.phd@woohoo.com	Tempe	Arizona	3528485645310610189	086b2a178baedbbf6c02437f01ac5d66	American Express	33.3718000474307672	-111.849493504970511
36655	2020-07-11 15:36:31	2020-07-11	Elick Stoltenberg	elick.stoltenberg@geemail.com	Green Bay	Wisconsin	4280314561687	1d553d1e55d704e15ae14f730ea039b8	Discover	44.48021818465255	-87.9341155254103199
36656	2020-07-11 15:37:57	2020-07-11	Mr. Donnell Gleichner	mr.donnell.gleichner@geemail.com	San Francisco	California	3445796050676147	b03aefee8bfd481d77d64d710837e21a	JCB 15 digit	37.7937115670634824	-122.398630545843901
36657	2020-07-11 15:38:09	2020-07-11	Almer Pfeffer	almer.pfeffer@geemail.com	San Jose	California	4419376493013	8a3af001b79f1fe17a4f069f0e4cad52	Maestro	37.2248698313541695	-121.878306764898454
36658	2020-07-11 15:41:38	2020-07-11	Monty Koepp	monty.koepp@woohoo.com	San Francisco	California	639004794230047	680f72648fdc24d582909fbc5c90c8ed	JCB 16 digit	37.7431689971080644	-122.407976913972533
36659	2020-07-11 15:44:13	2020-07-11	Asher Smitham	asher.smitham@geemail.com	New York	New York	6011015356187645147	45333442a5d5970a745c14c8c97d165b	American Express	40.7183168179579056	-73.8913211747433962
36660	2020-07-11 15:49:09	2020-07-11	Dickie Murazik	dickie.murazik@geemail.com	Gilbert	Arizona	4392987871408	fcb505b6b30ef3094392a443ad788d3d	VISA 16 digit	33.2992686220791185	-111.808613121942059
36661	2020-07-11 15:52:16	2020-07-11	Ms. Lesli Krajcik	ms.lesli.krajcik@woohoo.com	San Francisco	California	869993743813024620	a68fffb202a31b0906f70c7e66a2943a	Discover	37.7604771748824533	-122.440079334889077
36662	2020-07-11 15:53:13	2020-07-11	Edla McKenzie	edla.mckenzie@geemail.com	Shreveport	Louisiana	4205376717455	067020acf1c343494d9477e0d77601e1	VISA 16 digit	32.3820017334777859	-93.8109227766029505
36663	2020-07-11 15:54:52	2020-07-11	Mr. Denis Witting Jr.	mr.denis.witting.jr.@geemail.com	New York	New York	3158728130148921675	130d9b90d31a44f096f9b46effa4723a	JCB 16 digit	40.7200459356177618	-73.9855341965228348
36664	2020-07-11 16:13:07	2020-07-11	Dr. Imanol Smitham I	dr.imanol.smitham.i@geemail.com	Minneapolis	Minnesota	4917562727137136	e4a1fa297b6b4423bc05bcca3c471ebf	JCB 15 digit	44.9309315188873555	-93.2275949376907107
36665	2020-07-11 16:20:21	2020-07-11	Ananias Stanton	ananias.stanton@geemail.com	Brownsville	Texas	4557025329448694	7952f9a0118676b9c5ef87111178cdfb	Diners Club / Carte Blanche	25.9991250624492736	-97.4093794421944779
36666	2020-07-11 16:23:07	2020-07-11	Niko Mayer	niko.mayer@geemail.com	San Antonio	Texas	51361311474430315	80efacd8ff43928eaaa0799fc381fe7b	JCB 16 digit	29.4485748889461156	-98.5500919601715992
36667	2020-07-11 16:23:28	2020-07-11	Mark Beier IV	mark.beier.iv@warmmail.com	North Las Vegas	Nevada	4741118898464551	61d3b8eb6dbc7e44c3c55ce46b72447a	Mastercard	36.3368415146291213	-115.146756461796912
36668	2020-07-11 16:28:49	2020-07-11	Jade Strosin-Terry	jade.strosin.terry@warmmail.com	Ann Arbor	Michigan	869969880607814277	e0d83f21aab4431a0912559e12da0a6f	VISA 16 digit	42.2155464167300636	-83.6772990181684548
36669	2020-07-11 16:38:24	2020-07-11	Jeanmarie Shields	jeanmarie.shields@geemail.com	Seattle	Washington	4561233771750054	65b0598561dc3e71d7ec449a8a75a6fc	JCB 16 digit	47.5529205036275116	-122.447350240397824
36670	2020-07-11 16:38:31	2020-07-11	Mr. Fount Harris	mr.fount.harris@woohoo.com	Atlanta	Georgia	869902235859370710	b311719aee47e9b495f3d51225fbfcab	JCB 16 digit	33.7677008036334101	-84.516125669055441
36671	2020-07-11 16:39:11	2020-07-11	Mrs. Clarissa Rau	mrs.clarissa.rau@warmmail.com	Albuquerque	New Mexico	180004327647538860	75590b8d7c028cbe5318229c3133153c	Diners Club / Carte Blanche	35.0926867500081698	-106.654261953902989
36672	2020-07-11 16:51:01	2020-07-11	Sol Beier	sol.beier@woohoo.com	Dallas	Texas	3400803238255704	9bf35f6251276c0ce261cfc74a6848ca	JCB 15 digit	32.7610403150592049	-96.8258500357586769
36673	2020-07-11 16:51:10	2020-07-11	George Emard	george.emard@warmmail.com	Scottsdale	Arizona	6011643423341579289	ba8315403cf8d74f4aff7de3510f7d52	Maestro	33.642226640333611	-111.913401063574838
36674	2020-07-11 16:52:47	2020-07-11	Alf Cummerata	alf.cummerata@warmmail.com	San Francisco	California	3088627177508314670	b374d7dd31a2c315a3e0cc9542f0e13f	Discover	37.7859991931475037	-122.438783708501362
36675	2020-07-11 16:53:29	2020-07-11	Vinton Hilpert	vinton.hilpert@geemail.com	New York	New York	6011699203823115908	b61703932a981bcb325f94607b04dbe2	VISA 13 digit	40.763269154144453	-73.9307343430712791
36676	2020-07-11 16:53:36	2020-07-11	Rita Dietrich	rita.dietrich@geemail.com	Tampa	Florida	869904348771892279	3ea0abf450ad20e0aee508b684f3357a	Mastercard	27.9222492537111044	-82.3857554162599115
36677	2020-07-11 16:55:01	2020-07-11	Savion Yost	savion.yost@geemail.com	Dallas	Texas	4616266010218223	51f78d1cb0af1fe6ec7b6ba31d0e5a1f	Maestro	32.7492841311071103	-96.7697592061441298
36678	2020-07-11 16:55:20	2020-07-11	Mariah Wilkinson	mariah.wilkinson@geemail.com	New York	New York	4350961294124747	5f9b53c29fd77f10a43bbca351319ff7	VISA 16 digit	40.6501893537342553	-74.0006860097765866
36679	2020-07-11 16:57:18	2020-07-11	Lucien Fay	lucien.fay@geemail.com	San Francisco	California	55121773404500932	b33fc876c3d56da8565114a14d28c2fc	Discover	37.776269605656644	-122.44762363125372
36680	2020-07-11 16:57:45	2020-07-11	Miss Besse Doyle PhD	miss.besse.doyle.phd@geemail.com	Reno	Nevada	180004554451760393	faa7dcce957f8488f522ecc187420034	VISA 16 digit	39.599339794980736	-119.763971260066711
36681	2020-07-11 17:05:00	2020-07-11	Ariane Pfeffer	ariane.pfeffer@woohoo.com	Fargo	North Dakota	4914956002879	83b000ef0e657da9b6f0bbe63cfd6687	Mastercard	46.868163737631221	-96.827451332049435
36682	2020-07-11 17:28:31	2020-07-11	Herbert Cartwright	herbert.cartwright@geemail.com	Los Angeles	California	869965552781851276	e8b4018996d3682b2ee17a7a0a9b0cb4	JCB 15 digit	34.1165067673526679	-118.451170251610876
36683	2020-07-11 17:32:07	2020-07-11	Johnnie Smitham	johnnie.smitham@geemail.com	New York	New York	3469833484122066	ccfeae917372f1b55600eaf0afcaf851	VISA 13 digit	40.614536526728422	-73.8411762180168125
36684	2020-07-11 17:41:01	2020-07-11	Ressie Blick-Hessel	ressie.blick.hessel@geemail.com	Visalia	California	3158212151191624019	2d026afcd306891f7690c291bf08ae9b	Mastercard	36.3556122331835354	-119.419230356452616
36685	2020-07-11 17:44:34	2020-07-11	Talan Kuhlman	talan.kuhlman@geemail.com	Lakewood	Colorado	4264023040720768	fc18b6b51719a5bf5ce7ab7ae4d2fce5	Diners Club / Carte Blanche	39.7858396363385012	-105.074963653695207
36686	2020-07-11 17:48:53	2020-07-11	Braiden Bode MD	braiden.bode.md@geemail.com	Long Beach	California	3158499572040284065	6f5459cc2bd383ed9504204a5682a5ce	Voyager	33.7687958408899576	-118.200662768042832
36687	2020-07-11 17:54:52	2020-07-11	Preston Hayes	preston.hayes@geemail.com	San Francisco	California	4316106861123	e21627f6bb81ffa5b3bf920d8a43820d	American Express	37.7795760027556184	-122.472187344115795
36688	2020-07-11 18:03:25	2020-07-11	Alonzo Rutherford	alonzo.rutherford@geemail.com	Gainesville	Florida	3007065270897206	f58ce28dbf8b962a7409b06889183833	Maestro	29.686130693770199	-82.2845595394134648
36689	2020-07-11 18:14:47	2020-07-11	Dr. Tristan Kohler DVM	dr.tristan.kohler.dvm@geemail.com	Charlotte	North Carolina	53563375273683719	9a30675fe8b3bd369122ff82bcf997b3	Diners Club / Carte Blanche	35.2217002624433491	-80.8636122368685903
36690	2020-07-11 18:19:55	2020-07-11	Dr. Marilou Littel PhD	dr.marilou.littel.phd@geemail.com	Indianapolis	Indiana	3088137896460865725	bdc82e935ba651637b8e3e1ee6875a73	Discover	39.8389473899740736	-86.1565836635153772
36691	2020-07-11 18:25:33	2020-07-11	Aden White	aden.white@geemail.com	Oakland	California	6011303101913538757	098e6253b0f1a7f022c5c8474e643d52	American Express	37.7954556218725912	-122.238815954606196
36692	2020-07-11 18:29:00	2020-07-11	Jaliyah Goldner	jaliyah.goldner@geemail.com	Jacksonville	Florida	3112110329991152265	06a35537129875fecd38eed0480207c6	Maestro	30.3950852138508125	-81.6875732669219445
36693	2020-07-11 18:46:17	2020-07-11	Raelyn Green-Botsford	raelyn.green.botsford@geemail.com	Houston	Texas	3158663744854952372	cadd19b05cdf454fee1b4b6155491250	JCB 16 digit	29.8206834149159477	-95.3852341657985079
36694	2020-07-11 18:51:44	2020-07-11	Mrs. Lenora Schmitt	mrs.lenora.schmitt@geemail.com	Mesa	Arizona	3088265436669189397	d87caa48b2c6f0fbd887fd915af2fc54	Mastercard	33.449924650057774	-111.794448690384257
36695	2020-07-11 18:56:15	2020-07-11	Theodosia Deckow	theodosia.deckow@geemail.com	Washington	District of Columbia	4860886664504	7a4fef64d647ce2f5f0d0ccdd3c42c2c	VISA 16 digit	38.9634725292012121	-77.0244418231982735
36696	2020-07-11 19:00:44	2020-07-11	Angie Wolf	angie.wolf@geemail.com	Milwaukee	Wisconsin	180021670149146719	6e7ba94c61d30e78e1ba10d1ec900b94	Discover	43.0345516027968387	-87.8762634357538133
36697	2020-07-11 19:05:19	2020-07-11	Deshaun Rowe	deshaun.rowe@woohoo.com	Modesto	California	51670478760743150	cc8c10f3134160c62521078e605e41ee	JCB 15 digit	37.617984580062334	-120.994890156129372
36698	2020-07-11 19:06:51	2020-07-11	Crockett Waelchi	crockett.waelchi@geemail.com	Denver	Colorado	869907698844332530	72ca0d11e274b5b9ead87e25a397e4fe	Diners Club / Carte Blanche	39.8338866785220773	-104.866256511794774
36699	2020-07-11 19:11:37	2020-07-11	Miss Daniele Rowe	miss.daniele.rowe@geemail.com	Minneapolis	Minnesota	3007765271398704	fc185978cbead7da847874686c4e48da	Maestro	44.9105224353812602	-93.3099491154581244
36700	2020-07-11 19:12:11	2020-07-11	Dr. Bernetta Hagenes MD	dr.bernetta.hagenes.md@geemail.com	Colorado Springs	Colorado	639092406174158	9536e8881b16c838eb46726708fd787e	American Express	38.9224626506261515	-104.846482323358586
36701	2020-07-11 19:17:38	2020-07-11	Vivian Altenwerth	vivian.altenwerth@warmmail.com	New York	New York	3096432838240707555	5aa5f5364cafe63332acd45fd2d6606b	JCB 16 digit	40.709110168762507	-73.9879342847865047
36702	2020-07-11 19:18:41	2020-07-11	Sheila Rempel	sheila.rempel@geemail.com	Wilmington	North Carolina	4971817698732288	fa06153c3eb8733561d287112eecce2e	Maestro	34.1615639765102443	-77.8864606791634202
36703	2020-07-11 19:20:44	2020-07-11	Carrol Homenick-Lind	carrol.homenick.lind@warmmail.com	Los Angeles	California	501849129491335	b6eea63986647dd3ed91be18d7297ae6	JCB 15 digit	34.0162198705930265	-118.416050191455696
36704	2020-07-11 19:29:43	2020-07-11	Inell Gleichner	inell.gleichner@geemail.com	Montgomery	Alabama	3528295600383401966	d4ef25ef1dfed4b06096d1a698aa479d	VISA 16 digit	32.4299127791475499	-86.3584651951830722
36705	2020-07-11 19:52:25	2020-07-11	Evelyn Dare	evelyn.dare@geemail.com	Oakland	California	3528586994183000815	3fcd4d9023483f71b931386d04302ce6	Discover	37.796650702333757	-122.283379772028326
36706	2020-07-11 19:54:00	2020-07-11	Hampton Rice III	hampton.rice.iii@geemail.com	San Francisco	California	6011098110759600471	233c43e67e89591efee128d872763f85	Mastercard	37.8042888690980305	-122.462106769471973
36707	2020-07-11 19:57:06	2020-07-11	Gael DuBuque Sr.	gael.dubuque.sr.@warmmail.com	Chula Vista	California	4813978966365359	0ce023180192969306f3ed3772d67f56	Discover	32.684095887350658	-117.052983899344497
36708	2020-07-11 20:04:37	2020-07-11	Miss Danelle Zboncak DVM	miss.danelle.zboncak.dvm@geemail.com	Henderson	Nevada	869969887835446590	07f1acfa0e3a83ddef165fcb4dd719ba	American Express	35.9184449569255122	-115.008690415152174
36709	2020-07-11 20:14:05	2020-07-11	Exie Turcotte-O'Conner	exie.turcotte.o'conner@geemail.com	Montgomery	Alabama	3492814688753915	7ead34de2d10a7dd7106d79922e7c191	JCB 15 digit	32.438877774861453	-86.3208018151730272
36710	2020-07-11 20:20:19	2020-07-11	Errol Walker	errol.walker@geemail.com	Clinton	Michigan	180016015809628860	980858e7851e6fd61e3de7df145a2b5b	JCB 15 digit	42.6829419842988216	-82.973728958897297
36711	2020-07-11 20:22:02	2020-07-11	Maura Davis	maura.davis@geemail.com	Miami	Florida	3528503774501095410	32b587edece4bf04d94ce40edf49a2dd	VISA 16 digit	25.7027018460582966	-80.2432550075803022
36712	2020-07-11 20:28:12	2020-07-11	Kaitlyn Hane PhD	kaitlyn.hane.phd@geemail.com	El Monte	California	3096690774856409052	82978fe5daa0d7d857db89b7cab64f83	JCB 15 digit	34.099746011775359	-117.940591094855591
36713	2020-07-11 20:29:16	2020-07-11	Alvie Kihn	alvie.kihn@geemail.com	Huntington Beach	California	3493062760795110	8f23175e592cfb000299a781671a6a70	Voyager	33.6081377086270621	-118.010174431058758
36714	2020-07-11 20:30:43	2020-07-11	Ebb Jast	ebb.jast@geemail.com	Reno	Nevada	51012699919982582	55a6fd256d52c30ddedd395a39d6df15	VISA 16 digit	39.6430493777696071	-119.941889011736592
36715	2020-07-11 20:35:55	2020-07-11	Ms. Joana Torp	ms.joana.torp@geemail.com	Memphis	Tennessee	55381044043327599	43665ffbc69e7d6cfe84865bafef2f70	American Express	35.0420660542391289	-89.9896292163316218
36716	2020-07-11 20:43:42	2020-07-11	Adalberto Batz	adalberto.batz@warmmail.com	Atlanta	Georgia	869902607089063069	70174f2e7593e13aab4ce9916933509e	Mastercard	33.6858792764410424	-84.4468238474380257
36717	2020-07-11 20:47:48	2020-07-11	Dr. Tyree Schuppe	dr.tyree.schuppe@woohoo.com	New York	New York	4952459892479	4b7ac4db454c8c57eaca4afd854cd323	VISA 16 digit	40.7445057977214447	-74.0094347040064662
36718	2020-07-11 21:01:35	2020-07-11	Benjamine Purdy	benjamine.purdy@geemail.com	Oakland	California	3021568393910158	c56d267e89b151b6bf7d21f999a11472	JCB 16 digit	37.8172861747562905	-122.294002246618376
36719	2020-07-11 21:02:03	2020-07-11	Dr. Reginal Kunze PhD	dr.reginal.kunze.phd@geemail.com	New York	New York	3428517703615865	e9ee5b57f9c977876bfd2da9bdc96e00	JCB 16 digit	40.7338468620777121	-73.9621941154718314
36720	2020-07-11 21:02:48	2020-07-11	Mr. Reason Kshlerin	mr.reason.kshlerin@geemail.com	Rancho Cucamonga	California	180068117679551052	397bed3830731ab002a015a5cab3849c	Discover	34.1356996768612433	-117.539689724334323
36721	2020-07-11 21:08:03	2020-07-11	Metro Hermann	metro.hermann@geemail.com	Berkeley	California	501859550599209	77a6e1556298039901c2266169296f4c	Discover	37.8549202609557511	-122.264924514114625
36722	2020-07-11 21:17:10	2020-07-11	Debbra Bahringer	debbra.bahringer@woohoo.com	New York	New York	3008598566760745	5036cba274d2853398780942f50c5205	Discover	40.5849745535049564	-73.9449035887967767
36723	2020-07-11 21:19:57	2020-07-11	Keshawn Ondricka-Hilpert	keshawn.ondricka.hilpert@geemail.com	Memphis	Tennessee	501801373508413	93ee060cf638882a373b6b0e24bab90c	JCB 16 digit	35.1147745262432878	-89.9336775066588103
36724	2020-07-11 21:22:16	2020-07-11	Halley Kozey V	halley.kozey.v@geemail.com	San Francisco	California	4262159238944	5ae51fe35a056329a4a9c7eb01ed989a	VISA 16 digit	37.7876431218466777	-122.424432076133996
36725	2020-07-11 21:24:27	2020-07-11	Cruz Howell	cruz.howell@geemail.com	San Francisco	California	3158691935101289396	2c63f4ce748ee27acb3f9d26fad9a0f5	VISA 16 digit	37.7656193704685137	-122.460681032286161
36726	2020-07-11 21:29:15	2020-07-11	Faustino Wiegand III	faustino.wiegand.iii@warmmail.com	Los Angeles	California	4849926405682932	99228a24ab42205fc2522b60fef159ea	Maestro	34.0834997363720049	-118.503466105879468
36727	2020-07-11 21:41:20	2020-07-11	Meta Gusikowski DVM	meta.gusikowski.dvm@warmmail.com	New York	New York	4833558199531237	98f36569290baee08eb9f088865b8f94	Mastercard	40.5886124250236904	-73.9322179611667991
36728	2020-07-11 21:42:47	2020-07-11	Page Tromp-Reynolds	page.tromp.reynolds@warmmail.com	Nashville	Tennessee	4952052653161	19b937c57d1d7f92cdece5fd160c7e91	American Express	36.213357980608194	-86.7879272461310052
36729	2020-07-11 21:46:20	2020-07-11	Maybelle McCullough	maybelle.mccullough@geemail.com	San Francisco	California	6011750139227729207	b2507e2f13c008a49b791313076a470b	JCB 16 digit	37.7773759656020829	-122.454141121994269
36730	2020-07-11 21:51:43	2020-07-11	Dr. Denice Torphy	dr.denice.torphy@geemail.com	Pittsburgh	Pennsylvania	210032574504366804	a360eab8276a10f951a7b03e3b40af37	Maestro	40.4487494275394823	-80.0340434945359931
36731	2020-07-11 21:54:47	2020-07-11	Ulysses Pfeffer	ulysses.pfeffer@geemail.com	Los Angeles	California	3528781820939464554	ec86dc88792bd7f6345f4fa604905691	VISA 13 digit	34.0298570078663474	-118.449822630732498
36732	2020-07-11 21:57:50	2020-07-11	Chyna Schoen	chyna.schoen@geemail.com	New York	New York	3737274671600078	e8be0fc17dd33648da47a9adc03ce614	Voyager	40.6154391866866504	-73.8584114350739895
36733	2020-07-11 21:58:16	2020-07-11	Ana Wintheiser	ana.wintheiser@woohoo.com	San Francisco	California	3096198095932765730	8106402203f179afeff3ab83ba80d72d	Diners Club / Carte Blanche	37.7834691892022505	-122.387075070640051
36734	2020-07-11 22:06:35	2020-07-11	Dr. Flem Cormier	dr.flem.cormier@geemail.com	Tyler	Texas	3008836598733086	ec4ff9a357e30b3631669feb70f6a659	Discover	32.3425088712528392	-95.2287577662724942
36735	2020-07-11 22:07:05	2020-07-11	Effie Runolfsson I	effie.runolfsson.i@geemail.com	Huntington Beach	California	210063563661841222	b3192a2bc6c616bb8bf4afbc39601767	JCB 16 digit	33.7251310464035754	-118.030575050332772
36736	2020-07-11 22:07:10	2020-07-11	Dorcas Ratke-Conn	dorcas.ratke.conn@warmmail.com	New York	New York	3158516538503463628	83f93c5aae320475cffc189b75a3e5b1	VISA 16 digit	40.623563959145919	-73.9325430365640699
36737	2020-07-11 22:16:44	2020-07-11	Denese Rempel	denese.rempel@woohoo.com	Paterson	New Jersey	3054888281064034	56fbe120b7f570b25b1e109274f9f02f	VISA 13 digit	40.8496112861160157	-74.1703249888934266
36738	2020-07-11 22:21:32	2020-07-11	Louise Dare	louise.dare@geemail.com	Oxnard	California	3717142548506972	265cfd2084550383eb298be664ec4c8e	VISA 16 digit	34.2518054326020192	-119.218495862596114
36739	2020-07-11 22:23:11	2020-07-11	Mrs. Siddie O'Conner	mrs.siddie.o'conner@woohoo.com	Detroit	Michigan	4276836477620565	4d454a283742e89d8c6edaf8e6bed7b8	Diners Club / Carte Blanche	42.4189137567691503	-83.1071867258407195
36740	2020-07-11 22:25:47	2020-07-11	Dr. Baylie Emard	dr.baylie.emard@geemail.com	Houston	Texas	3770622770002646	a84993c4f82b9300bb95b8d5a2a07acd	JCB 15 digit	29.8495775067325688	-95.3129592429395842
36741	2020-07-11 22:26:35	2020-07-11	Mrs. Elsie Rohan	mrs.elsie.rohan@woohoo.com	Austin	Texas	869923354275373714	b93014818e5ab382884083b0c7734458	VISA 16 digit	30.3786737543657424	-97.8523001469910128
36742	2020-07-11 22:27:15	2020-07-11	Mikayla Labadie	mikayla.labadie@geemail.com	Killeen	Texas	3732200413905843	4f725132d371eaf3ed2358d76cc5dc79	JCB 16 digit	31.1653106375828379	-97.7151249380949878
36743	2020-07-11 22:33:10	2020-07-11	Dr. Kaiden Jenkins V	dr.kaiden.jenkins.v@woohoo.com	Detroit	Michigan	3088947462581764808	3018c8d7cf71ee61f8c8d3cde63ee168	Mastercard	42.4757522658370448	-83.1105069472107942
36744	2020-07-11 22:34:10	2020-07-11	Winter Schmitt MD	winter.schmitt.md@warmmail.com	Nashville	Tennessee	3337420174208117007	24425bb702fdcb4d50d32f0f31b08796	Voyager	36.1705700636964238	-86.8237607768177924
36745	2020-07-11 22:34:34	2020-07-11	Harris Zboncak	harris.zboncak@woohoo.com	New York	New York	3528852055428855442	59346f3a5fe8873e889512b87521c4a5	VISA 13 digit	40.7475677213389389	-74.011001378333944
36746	2020-07-11 22:49:29	2020-07-11	Illa Russel-Reilly	illa.russel.reilly@warmmail.com	Alexandria	Virginia	210035768425034270	3a1809f4cc39fcae7278f53772f3774e	Maestro	38.7360831842407549	-77.113344751622904
36747	2020-07-11 23:02:51	2020-07-11	Rosalia Crooks	rosalia.crooks@geemail.com	Irving	Texas	52276270572311666	861014add711cdd28a2ecce10e5fecb8	Maestro	32.8452089568085981	-96.9986452795378824
36748	2020-07-11 23:13:30	2020-07-11	Early Boyer	early.boyer@geemail.com	Milwaukee	Wisconsin	4389552123504	0f941d83b69ea8bf11633f5053521d57	VISA 13 digit	43.0931341650981423	-87.9491940625578223
36749	2020-07-11 23:19:08	2020-07-11	Herma Hackett PhD	herma.hackett.phd@geemail.com	St. Louis	Missouri	3337783018300454050	b6f649e8ca02f48e7d56873e754d9ce1	Mastercard	38.6676908547680824	-90.2476757969711088
36750	2020-07-11 23:27:11	2020-07-11	Dr. Sing Mraz	dr.sing.mraz@geemail.com	San Diego	California	210021068978407908	ea03a7d9abe82e3aee03dfe75e6140cc	JCB 15 digit	32.7154034263055777	-117.118975598029792
36751	2020-07-11 23:33:29	2020-07-11	Arletta Murphy DVM	arletta.murphy.dvm@woohoo.com	Bakersfield	California	3112217325262076227	174cfe4c0b330cfac66a8b1c0ed169aa	Discover	35.3609758934181144	-119.008796236970639
36752	2020-07-11 23:36:29	2020-07-11	Mr. Marcus Hartmann	mr.marcus.hartmann@geemail.com	Los Angeles	California	3037548018782087	b9124473ec81cb67d2df043353b403ec	JCB 16 digit	34.094902037117258	-118.312622375878689
36753	2020-07-11 23:36:30	2020-07-11	Mr. Charle Pouros Sr.	mr.charle.pouros.sr.@geemail.com	San Francisco	California	4274246920523329	c0dfd029623f72ae80b90af8c98138be	VISA 13 digit	37.7799048472536256	-122.423373445634866
36754	2020-07-11 23:36:39	2020-07-11	Nikia Tromp	nikia.tromp@warmmail.com	Irvine	California	6011758412573515765	73891f822edec2f02412749adfc0775c	Diners Club / Carte Blanche	33.7722270383514527	-117.730531352293866
36755	2020-07-11 23:36:54	2020-07-11	Jena Emmerich	jena.emmerich@geemail.com	Surprise	Arizona	3096254983207418369	ee092fea505219bd60d8e97866005ee6	Discover	33.6781021414086226	-112.479788092220943
36756	2020-07-11 23:47:54	2020-07-11	Juliana Feest	juliana.feest@geemail.com	Overland Park	Kansas	4332710438678867	45dacb2f1b4aceef16e277524c15fec9	VISA 16 digit	38.9660378760527877	-94.6795843024779202
36757	2020-07-11 23:55:51	2020-07-11	Dr. Gus Corwin MD	dr.gus.corwin.md@geemail.com	Houston	Texas	4107482448746	93f3e976e047263069672eaeceb9b15c	Discover	29.7319266832511886	-95.3945541948095013
36758	2020-07-11 23:58:56	2020-07-11	Berkley Legros	berkley.legros@woohoo.com	Clovis	California	4027030604028213	69ef82b2f7ffbb641c57b518b37a1c3a	Discover	36.762377860012279	-119.675706088829415
36759	2020-07-12 00:07:52	2020-07-12	Esperanza Schmitt-Buckridge	esperanza.schmitt.buckridge@geemail.com	Los Angeles	California	210001038752007566	eb51daaf8cabcc6b5484a5a0394a1c8d	JCB 15 digit	33.9394978696346286	-118.374310023755953
36760	2020-07-12 00:12:14	2020-07-12	Filomena Klein	filomena.klein@geemail.com	Oakland	California	869947590672888034	60e458af2d728d6c772371520f8e80dc	Mastercard	37.7955009828302408	-122.249085158437481
36761	2020-07-12 00:12:25	2020-07-12	Doug Schmeler	doug.schmeler@warmmail.com	Denver	Colorado	869976591010782560	8b84c94af5f715b1eef20b2c2424f4e9	Maestro	39.6742613780830027	-104.897385049729053
36762	2020-07-12 00:16:12	2020-07-12	Herbert McDermott	herbert.mcdermott@geemail.com	San Francisco	California	3088382747110486523	2e7c448ecdf18f9c4085e9f8893be92b	JCB 15 digit	37.7728216637332039	-122.440847072458055
36763	2020-07-12 00:19:36	2020-07-12	Kallie Schmeler DDS	kallie.schmeler.dds@geemail.com	Chandler	Arizona	4746862421448517	8d128d452da2d8492c672858c365f8cf	JCB 16 digit	33.2804438639987268	-111.839446863287691
36764	2020-07-12 00:23:25	2020-07-12	Luke Cummings	luke.cummings@woohoo.com	Akron	Ohio	3704387120966343	a66898de2d552ab93a9fac3f93b5dac9	JCB 16 digit	41.0075743818487979	-81.4897916545007348
36765	2020-07-12 00:31:39	2020-07-12	Stetson Stamm	stetson.stamm@woohoo.com	Las Vegas	Nevada	210067786476325588	c39cdecc03481a1c9c74c7881d92cdf7	JCB 16 digit	36.1939554770577701	-115.254712929550919
36766	2020-07-12 00:33:16	2020-07-12	Eusebio Pacocha	eusebio.pacocha@geemail.com	San Francisco	California	180067182426579682	3ca8b9b5d17904e99ce4d9ab6f3bc7c9	Voyager	37.7899839608258716	-122.416885600688104
36767	2020-07-12 00:35:19	2020-07-12	Corey Durgan	corey.durgan@geemail.com	Berkeley	California	3450667122686558	cc215407c27a3f6839747e02021280a0	Maestro	37.8665055745234369	-122.265510739958287
36768	2020-07-12 00:36:49	2020-07-12	Dr. Genesis Kozey MD	dr.genesis.kozey.md@geemail.com	Durham	North Carolina	869990794409533121	d09d5a9b87e9640b5a80858e044bb4a6	American Express	35.931502165716509	-78.8240569286882931
36769	2020-07-12 00:43:42	2020-07-12	Dr. Sie Satterfield	dr.sie.satterfield@geemail.com	Richmond	Virginia	4874291313664	8f1d4713a0a355ad182a6691aa65dd28	Discover	37.5010933563798616	-77.3884001326970719
36770	2020-07-12 00:47:56	2020-07-12	Nim Rohan I	nim.rohan.i@geemail.com	Pompano Beach	Florida	6011557966743829326	68af1e132410f3e2de4f10997cb6b818	VISA 13 digit	26.1767440719328803	-80.178690692673996
36771	2020-07-12 00:53:45	2020-07-12	Mrs. Kate Fahey	mrs.kate.fahey@geemail.com	New York	New York	3112242368477212939	d0aa61086b85eda4ec1a2b19346047a3	Diners Club / Carte Blanche	40.6494795957338084	-73.8731806108623772
36772	2020-07-12 00:54:00	2020-07-12	Channing Torphy	channing.torphy@geemail.com	Ontario	California	3337876461454802088	5439675ebc5c0520cd9eb92f75a40847	Mastercard	34.1136703100666381	-117.520608666269865
36773	2020-07-12 01:01:21	2020-07-12	Donte Schmitt	donte.schmitt@geemail.com	Chesapeake	Virginia	4853313603166260	ddb027ac7684ecc648906c86041f24d7	VISA 13 digit	36.6064829190965781	-76.2357642570353988
36774	2020-07-12 01:05:29	2020-07-12	Zara Herzog-O'Connell	zara.herzog.o'connell@geemail.com	New York	New York	4435734857507288	74c661d3b1b20dda87c1792dab2ba7b2	VISA 16 digit	40.6490411511380216	-73.8596117102436693
36775	2020-07-12 01:09:26	2020-07-12	Tiney Hansen-Cassin	tiney.hansen.cassin@geemail.com	Rancho Cucamonga	California	210035453004019501	9aabea167a0888fea4c3702f4b76c040	Mastercard	34.168166599002852	-117.566152946372327
36776	2020-07-12 01:14:36	2020-07-12	Kandy Mosciski	kandy.mosciski@geemail.com	Los Angeles	California	3743351135278394	4aebaa1686c77f32038e6fbe16344b1f	JCB 16 digit	33.9372380541969036	-118.457986194173984
36777	2020-07-12 01:20:19	2020-07-12	Mr. Shedrick Bogan III	mr.shedrick.bogan.iii@geemail.com	Los Angeles	California	3112408945373256068	a987bd61869439007449779216af38ac	VISA 13 digit	34.0925197588145679	-118.442712315450606
36778	2020-07-12 01:24:40	2020-07-12	Mr. Donavon Ankunding II	mr.donavon.ankunding.ii@geemail.com	Modesto	California	4961268355434127	bb5a32fb361cc12a86c045798b7d7903	JCB 15 digit	37.5870249151717886	-121.067364534104243
36779	2020-07-12 01:25:08	2020-07-12	Randal Huels	randal.huels@geemail.com	Indianapolis	Indiana	4141047525510328	663b698206a6e0e5c2d614c542f75801	JCB 16 digit	39.7796575967229913	-86.1983669917300261
36780	2020-07-12 01:31:58	2020-07-12	Camden Zieme	camden.zieme@geemail.com	North Las Vegas	Nevada	869913409179303902	0cb0c7a4bbb2ca1488a380b49aad3d3a	JCB 16 digit	36.1876646522123337	-115.139831689720609
36781	2020-07-12 01:41:12	2020-07-12	Latanya Lowe	latanya.lowe@warmmail.com	Philadelphia	Pennsylvania	3750792000320169	b9a7b0a23f889401dd44fc2bfd9e53a2	VISA 13 digit	39.921291328124326	-75.0690722035143523
36782	2020-07-12 01:42:27	2020-07-12	Mrs. Christene Schumm	mrs.christene.schumm@woohoo.com	Virginia Beach	Virginia	51956697272164044	bda7ec6bb3b870d432c8923267a5f2e9	Discover	36.784176041251051	-76.0279196626178901
36783	2020-07-12 01:50:13	2020-07-12	Yoshio McGlynn	yoshio.mcglynn@geemail.com	Pueblo	Colorado	6011103774736760113	3eb5e6c1176b154af399d57c03f8c685	Mastercard	38.2931130089774712	-104.623292722585802
36784	2020-07-12 01:52:08	2020-07-12	Brittnee Jenkins MD	brittnee.jenkins.md@geemail.com	Sugar Land	Texas	3158789903435815016	bf27a86ef1c125b31510a86fb977e834	Voyager	29.6414214583165929	-95.6039606753278548
36785	2020-07-12 01:59:37	2020-07-12	Reva Weimann DVM	reva.weimann.dvm@warmmail.com	Milwaukee	Wisconsin	6011115323080905175	a475eb08be689923aa830900d4f98f48	VISA 16 digit	43.0950784209270026	-87.9938638961974533
36786	2020-07-12 02:02:41	2020-07-12	Yulissa Russel DVM	yulissa.russel.dvm@woohoo.com	Anaheim	California	3456659341653463	273cc91a3ef514fe9889b907b98e1750	American Express	33.7854186041578615	-117.824361621050528
36787	2020-07-12 02:23:13	2020-07-12	Larkin Jacobson	larkin.jacobson@geemail.com	San Francisco	California	4807043508835779	c5adc8d9c4621af747687fc29bd46803	Diners Club / Carte Blanche	37.8027386554004892	-122.424013072335214
36788	2020-07-12 02:25:07	2020-07-12	Arley Rath	arley.rath@geemail.com	Winston–Salem	North Carolina	502058638380335	fc949baf97504a100a96a1b8f8bc8a98	American Express	36.1687013209097046	-80.285952368531369
36789	2020-07-12 02:33:00	2020-07-12	Geary Cronin-Skiles	geary.cronin.skiles@geemail.com	New York	New York	869938822114388583	44b063267df51e62fb491550c3df2919	JCB 16 digit	40.6612844151668256	-73.8828702745854855
36790	2020-07-12 02:40:36	2020-07-12	Rolf Kilback	rolf.kilback@geemail.com	Newport News	Virginia	4354964259254	ef7b8e8b645b8c8f2f1efcf8ca90e18c	VISA 16 digit	37.1092574489664315	-76.5973935928922174
36791	2020-07-12 02:45:58	2020-07-12	Dr. Caswell Walter DDS	dr.caswell.walter.dds@geemail.com	Los Angeles	California	4614475778830317	9e0a8d2b192e94be9a27a517acc1a417	Discover	34.0395971243601281	-118.41239972487017
36792	2020-07-12 02:47:38	2020-07-12	Corrie Wisozk	corrie.wisozk@woohoo.com	Dallas	Texas	3460309069975409	f42a3aaf9f0f1a5d0a9a3235903ba3e2	JCB 16 digit	32.8315658224087201	-96.7000321125108684
36793	2020-07-12 02:48:56	2020-07-12	Paityn Beatty-Spencer	paityn.beatty.spencer@geemail.com	Arvada	Colorado	3088991968372928985	d9ccf616bf842828db68ab20b33d1572	VISA 16 digit	39.7744959942240257	-105.137307171334697
36794	2020-07-12 02:56:45	2020-07-12	Lakisha Wiegand DVM	lakisha.wiegand.dvm@geemail.com	San Francisco	California	3778769063995713	e6ed8c9cd307c1191bdb4357ce540239	Discover	37.8002255146765691	-122.430183037506069
36795	2020-07-12 03:03:50	2020-07-12	Ernest Schiller	ernest.schiller@warmmail.com	Montgomery	Alabama	060452455575549	8e9c012bd23fce02b1effbb6e40ae48b	VISA 16 digit	32.2853850567646319	-86.3337459227222865
36796	2020-07-12 03:08:28	2020-07-12	Enrique Konopelski III	enrique.konopelski.iii@woohoo.com	Boston	Massachusetts	53844189634122833	78c99395692a7e5511d455ade9c5569f	Voyager	42.3787228015884736	-71.0944744341958312
36797	2020-07-12 03:15:06	2020-07-12	Clemence Reichert	clemence.reichert@geemail.com	Durham	North Carolina	54863697140132951	b2b682c6978180ce7887b5bb53c4f72e	Maestro	35.994136543829363	-78.9404653596594983
36798	2020-07-12 03:38:03	2020-07-12	Demond Pacocha-Abshire	demond.pacocha.abshire@geemail.com	San Francisco	California	51383391160257523	e8a4fb0ef7ed43cdaee70c460c7acd31	JCB 15 digit	37.8014912097691607	-122.445515229954793
36799	2020-07-12 03:39:47	2020-07-12	Miss Kelli Williamson DVM	miss.kelli.williamson.dvm@geemail.com	Lafayette	Louisiana	4542497810805	70286a3961cba64a210938bff1df802a	VISA 16 digit	30.1210500570457427	-91.9475002636518326
36800	2020-07-12 03:42:15	2020-07-12	Emiliano Mohr	emiliano.mohr@geemail.com	Miami	Florida	180039405255122570	35c73caf720ea10294695374c27a4d10	Diners Club / Carte Blanche	25.7771360341131697	-80.2300016427751643
36801	2020-07-12 03:46:06	2020-07-12	Mr. Clemens Gulgowski II	mr.clemens.gulgowski.ii@geemail.com	Houston	Texas	4973900363410311	1ccfc411fe24397a13a8d998e26b1d6f	VISA 16 digit	29.6872195026449859	-95.4264818736832581
36802	2020-07-12 03:55:30	2020-07-12	Nada Parisian-Raynor	nada.parisian.raynor@geemail.com	Chicago	Illinois	869919442793278022	e1df925ccc181ae9ecb82c8768edf5c2	American Express	41.9361106050968218	-87.7469988712139326
36803	2020-07-12 04:06:52	2020-07-12	Manila Fritsch	manila.fritsch@geemail.com	Alexandria	Virginia	4110428134677	3fc4be3d0083a3d38d8ba1947061bc0d	VISA 16 digit	38.8408331445999409	-77.0391257234834228
36804	2020-07-12 04:12:03	2020-07-12	Dr. Chase Dibbert	dr.chase.dibbert@geemail.com	Los Angeles	California	4872303208807	8756e6e202aec4bf47092d556bd23982	VISA 13 digit	34.0555122752539816	-118.443181690572942
36805	2020-07-12 04:13:48	2020-07-12	Evelin Bechtelar	evelin.bechtelar@geemail.com	Denver	Colorado	3337700224877898436	6b0a9575801147fee1687749ab82b54e	Voyager	39.7289154163613887	-104.901711083041874
36806	2020-07-12 04:16:24	2020-07-12	Hardy Ankunding	hardy.ankunding@geemail.com	Springfield	Illinois	4106986199452106	f639e9ca29db004af81cedb8b604ce42	Diners Club / Carte Blanche	39.7140189981706442	-89.664140986651546
36807	2020-07-12 04:22:47	2020-07-12	Leopold Murphy-Nader	leopold.murphy.nader@geemail.com	Raleigh	North Carolina	6011191705978695222	863beee252276c681d373b95893b4ad6	American Express	35.9132531590893862	-78.7092249475356169
36808	2020-07-12 04:25:43	2020-07-12	Gisele Gerlach-Effertz	gisele.gerlach.effertz@warmmail.com	Allentown	Pennsylvania	54517797637320943	d0fab21248028f437a1020556b0561a1	VISA 16 digit	40.4977964950971341	-75.4425126413829616
36809	2020-07-12 04:35:48	2020-07-12	Miss Ava Cole DVM	miss.ava.cole.dvm@geemail.com	Temecula	California	3755640118136727	c4f6f534a43812b9806d2ade28b88f66	Discover	33.5203968291304975	-117.060128804362193
36810	2020-07-12 05:07:21	2020-07-12	Dr. Camilo Ernser MD	dr.camilo.ernser.md@geemail.com	Fort Worth	Texas	6011105832035172626	31cfe6a0c1e3f7e7eb3c668b14273739	Mastercard	32.782884231355041	-97.2864408501245066
36811	2020-07-12 05:11:10	2020-07-12	Dr. Doll Trantow IV	dr.doll.trantow.iv@geemail.com	Nashville	Tennessee	4598458853653531	32daf2a6295108e494d57f87b7e6bc05	VISA 16 digit	36.0959707485169119	-86.694114300552755
36812	2020-07-12 05:12:02	2020-07-12	Mr. Darian Sawayn DDS	mr.darian.sawayn.dds@warmmail.com	Pasadena	Texas	4509876253494560	175387c494580913c3d2ca523da125c2	VISA 16 digit	29.678124791836737	-95.2321895091276645
36813	2020-07-12 05:17:47	2020-07-12	Desean Hermann-Collins	desean.hermann.collins@geemail.com	Torrance	California	4415199070905103	b708705948e4769192eacbf12b252e11	JCB 16 digit	33.7602892340999077	-118.358073896042626
36814	2020-07-12 05:20:52	2020-07-12	Sophie Wiegand	sophie.wiegand@geemail.com	San Antonio	Texas	6011166901517512181	0b65eafe41c91e6b8eeafc7f90ac8416	JCB 16 digit	29.5269738580171008	-98.5657712053343573
36815	2020-07-12 05:50:30	2020-07-12	Richelle Wolf	richelle.wolf@woohoo.com	Honolulu	Hawaii	4672782877720722	51b0e7d9ccff3f163666c4294f6124ce	Maestro	21.226712978885697	-157.925351366235304
36816	2020-07-12 05:53:49	2020-07-12	Irving Kertzmann	irving.kertzmann@geemail.com	San Jose	California	676380264731599	d0fd8740ef57c9ae24694c2bd5a19c21	Voyager	37.2094321688923984	-121.784894125930592
36817	2020-07-12 05:54:40	2020-07-12	Seward Grady	seward.grady@geemail.com	Austin	Texas	3112300735725186934	1a529ba5ef78ebe982ecede2f659ddb4	American Express	30.2393733802378151	-97.6746752804383647
36818	2020-07-12 05:54:50	2020-07-12	Adam Runolfsson	adam.runolfsson@geemail.com	Stamford	Connecticut	4943176919919	65979d38e09bd37190262e935a443ab3	JCB 15 digit	41.1610449953820563	-73.5790835396889662
36819	2020-07-12 05:55:23	2020-07-12	Dr. Genaro Barton V	dr.genaro.barton.v@geemail.com	Albuquerque	New Mexico	4772954458467317	74dff097aeb1929d169b5aa3d446c7fe	Maestro	35.159191373981912	-106.631828198868419
36820	2020-07-12 05:58:11	2020-07-12	Carlton Rutherford	carlton.rutherford@warmmail.com	Newport News	Virginia	4185298858287300	e008e4b88d12a1a00ae8bb054d18098f	JCB 16 digit	36.9983776724793003	-76.5075551986955134
36821	2020-07-12 05:59:29	2020-07-12	Morton Hudson	morton.hudson@geemail.com	Pueblo	Colorado	3528202458492521204	3bc6e75641e32f8df6d869c48b3825ad	Diners Club / Carte Blanche	38.1912722317013902	-104.669578762897487
36822	2020-07-12 05:59:47	2020-07-12	Bertrand Ullrich	bertrand.ullrich@geemail.com	Simi Valley	California	54741627980802999	e2dc7d02afb550deb96c7209fb015bbb	JCB 16 digit	34.3477078006841268	-118.798984563969086
36823	2020-07-12 06:02:40	2020-07-12	Mrs. Cordia Frami	mrs.cordia.frami@geemail.com	Elgin	Illinois	869943099476812590	5b4871996340c8ea74bc609660bdf213	Mastercard	42.0007817507538945	-88.3309954199761194
36824	2020-07-12 06:23:19	2020-07-12	Rosalee Russel-Heller	rosalee.russel.heller@geemail.com	Lexington	Kentucky	210010413705342569	e9e086f76f41765c761e48be4adacba8	Maestro	38.0770566287793244	-84.4180282247152149
36825	2020-07-12 06:30:09	2020-07-12	Donn Bechtelar	donn.bechtelar@geemail.com	Tallahassee	Florida	51541588528648413	5c60c937925f59f46400c8757cf29b95	VISA 13 digit	30.4827332882698627	-84.171253611567991
36826	2020-07-12 06:31:33	2020-07-12	Dr. Cristian Maggio	dr.cristian.maggio@woohoo.com	Norwalk	California	869938105546123954	4a397653625ea4e3090522cb79d0287b	Maestro	33.9917307600028806	-117.995024361325434
36827	2020-07-12 06:33:03	2020-07-12	Lea Thompson	lea.thompson@woohoo.com	Wichita	Kansas	4645911935379924	dcc055888dfe739b5c919d66d5dd898e	Maestro	37.6612666767433311	-97.2621189173046474
36828	2020-07-12 06:42:13	2020-07-12	Ephram Littel-Barton	ephram.littel.barton@geemail.com	Springfield	Missouri	3042260014005431	e43dce76140bc0955dcf74f70ccb4229	Maestro	37.1757304038580543	-93.3613546285137659
36829	2020-07-12 06:42:20	2020-07-12	Nathanael Dickinson-Boyer	nathanael.dickinson.boyer@woohoo.com	Augusta	Georgia	3337509195100017056	d320cd4285fa6f12c4312ff08c5ee374	Voyager	33.3330887984223665	-82.1656956908121714
36830	2020-07-12 06:43:43	2020-07-12	Mr. Quintin Little	mr.quintin.little@warmmail.com	Columbus	Ohio	55215946704246128	352afad4f6c6a8ae6794c0b396fdd199	VISA 16 digit	39.9890698342163091	-82.991725581116242
36831	2020-07-12 06:45:36	2020-07-12	Miss Zara Larkin PhD	miss.zara.larkin.phd@geemail.com	San Francisco	California	4911106927920598	6f896c8923ddbf3618dc36b9b33ff351	VISA 16 digit	37.7555539093873946	-122.436656788830902
36832	2020-07-12 07:12:16	2020-07-12	Laverne Lowe	laverne.lowe@geemail.com	Indianapolis	Indiana	4303128195300	6cae9ade0a256017725484642b439722	Maestro	39.6837790344383521	-86.1020178920324923
36833	2020-07-12 07:13:23	2020-07-12	Gaetano Sporer-Friesen	gaetano.sporer.friesen@geemail.com	San Francisco	California	6011906596469410247	c5554bcac33451abb98c045b923e3995	VISA 16 digit	37.8077687946651153	-122.460303048895312
36834	2020-07-12 07:21:35	2020-07-12	Dr. Saint Cremin	dr.saint.cremin@geemail.com	Saint Paul	Minnesota	869948257664882420	b42383879f63c62c5114aa28cea245b1	JCB 16 digit	44.9698458225872386	-93.0337202777419208
36835	2020-07-12 07:23:47	2020-07-12	Latarsha Conn	latarsha.conn@geemail.com	San Francisco	California	4603997054070295	15851edd22a6e2bb0e9584948f974fbd	VISA 13 digit	37.7769206166206573	-122.441395354720882
36836	2020-07-12 07:25:37	2020-07-12	Clabe Braun-Schmeler	clabe.braun.schmeler@geemail.com	Lakeland	Florida	589316169647233	3630cc228b18e2691d7c67a92bd5c80e	VISA 13 digit	27.9991513999477029	-82.0548682532623417
36837	2020-07-12 07:32:06	2020-07-12	Sister Farrell	sister.farrell@woohoo.com	Dallas	Texas	4990525993680105	27b76fa8fb3a764233bf53d5432ce6f9	Diners Club / Carte Blanche	32.8390361738197498	-96.7954069261401884
36838	2020-07-12 07:58:45	2020-07-12	Jose Conroy	jose.conroy@geemail.com	Los Angeles	California	6011815168906289186	6a6ec2af9c1e0f6dc5fdee968968a276	Discover	33.992432996989784	-118.332678901636228
36839	2020-07-12 08:01:22	2020-07-12	Mr. Windell Walsh DDS	mr.windell.walsh.dds@warmmail.com	San Francisco	California	4004688539194603	ec57d4b492873b94b87e26143e922c9c	VISA 16 digit	37.7797026167739958	-122.425791990869357
36840	2020-07-12 08:02:12	2020-07-12	Dr. Garland Casper MD	dr.garland.casper.md@geemail.com	Chicago	Illinois	502074390559644	e0e71054ea74187b263c2f4a99c37e13	Maestro	41.935629179638255	-87.6760811991553766
36841	2020-07-12 08:06:03	2020-07-12	Adda Stokes-Adams	adda.stokes.adams@warmmail.com	Oakland	California	210024133218264209	325511dd63c3601959e98a7268f4e32b	JCB 16 digit	37.8264134193967578	-122.285720252423488
36842	2020-07-12 08:06:58	2020-07-12	Vinnie Rempel	vinnie.rempel@woohoo.com	San Mateo	California	676359198651685	ee785ded54def05be1e3a9313d6c8406	VISA 16 digit	37.5824102694515148	-122.268908655163273
36843	2020-07-12 08:09:09	2020-07-12	Mrs. Tayla Kuhlman	mrs.tayla.kuhlman@geemail.com	Augusta	Georgia	3437488367898248	093989e36ab8612a2acf798dd0f99902	Mastercard	33.361525040373202	-82.0222843034021594
36844	2020-07-12 08:25:40	2020-07-12	Franco Breitenberg-Kunde	franco.breitenberg.kunde@geemail.com	San Francisco	California	210076233825602531	fb887574a3ed8489bd2bcd7fe5b039bf	Diners Club / Carte Blanche	37.7367901492597682	-122.406891819169402
36845	2020-07-12 08:27:41	2020-07-12	Ms. Letta Kuphal DDS	ms.letta.kuphal.dds@geemail.com	New Haven	Connecticut	3055693053214380	7fb849a157722716ba5cfc62713f54cb	Discover	41.2139464299187068	-72.8918932328000579
36846	2020-07-12 08:46:47	2020-07-12	Lempi Morissette MD	lempi.morissette.md@geemail.com	San Francisco	California	3483499450107937	ad3202dd41ddfaed80736908114463d0	JCB 16 digit	37.7692649667124769	-122.450394377328095
36847	2020-07-12 08:56:19	2020-07-12	Dr. Stan Howe	dr.stan.howe@geemail.com	Garland	Texas	3112459386699368394	1321a410a4bb4580c52e2e6904258b12	JCB 16 digit	32.9823083030294626	-96.6540615454476324
36848	2020-07-12 09:00:19	2020-07-12	Sylva Denesik	sylva.denesik@woohoo.com	San Antonio	Texas	676355831930429	08ca92f6f57eb0fad8be164919b85f30	JCB 15 digit	29.4613782779384401	-98.4898844191174874
36849	2020-07-12 09:02:17	2020-07-12	Jade Leffler	jade.leffler@warmmail.com	Arlington	Texas	53731672885440349	c173b0ef3b4150f8e073e83153bc17aa	Voyager	32.6007804016832239	-97.0343547861117912
36850	2020-07-12 09:02:42	2020-07-12	Lorinda Mills	lorinda.mills@woohoo.com	San Francisco	California	869993391737031022	a37d9c474f60279e8c2c29f00f6bcc23	VISA 16 digit	37.7497928921469494	-122.427490449934496
36851	2020-07-12 09:02:43	2020-07-12	Jeptha Ernser	jeptha.ernser@woohoo.com	Mesa	Arizona	869925195394831274	774b5f3ee3ce9c864784d56cb951e950	JCB 15 digit	33.4067300729598813	-111.792395975010095
36852	2020-07-12 09:03:32	2020-07-12	Harlon Smitham	harlon.smitham@geemail.com	San Francisco	California	3528127674332002054	8d3378aa92d689beb49e082b476be132	Maestro	37.7702833010860886	-122.421222435095913
36853	2020-07-12 09:05:12	2020-07-12	Monserrat Schimmel	monserrat.schimmel@warmmail.com	Frisco	Texas	4410697451632	f2f59c02b78c8d2f009f71a75d994900	VISA 16 digit	33.1799668066665561	-96.7682572567112658
36854	2020-07-12 09:09:10	2020-07-12	Lars Runolfsson	lars.runolfsson@geemail.com	Bakersfield	California	630436424097321	df46633559ea5bcce07c79c5d29cc88c	Mastercard	35.2963977141946543	-119.038200518655771
36855	2020-07-12 09:11:58	2020-07-12	Kaycee Zulauf-Hintz	kaycee.zulauf.hintz@geemail.com	Las Vegas	Nevada	4949686336926670	36a483775710ae24b1241727c37d27ce	JCB 15 digit	36.2771486049152898	-115.312093550080803
36856	2020-07-12 09:16:08	2020-07-12	Jeri Price	jeri.price@geemail.com	South Bend	Indiana	869915067017587991	d7c43a5b8a586d239d4752e1bce32776	Voyager	41.7131319502513875	-86.262374394811701
36857	2020-07-12 09:30:40	2020-07-12	Bernhard Smitham	bernhard.smitham@geemail.com	New York	New York	4375214025823	c8c336d20bbb35703f80a9ecd1012fa7	VISA 16 digit	40.6744837234951575	-73.9441582740180223
36858	2020-07-12 09:32:29	2020-07-12	Byrd Oberbrunner	byrd.oberbrunner@woohoo.com	Modesto	California	869952973774742717	ba2409e2a485d6337fc9d5d0d7778749	Maestro	37.56664527594112	-121.064377569567412
36859	2020-07-12 09:43:34	2020-07-12	Mrs. Jailene Stroman MD	mrs.jailene.stroman.md@warmmail.com	Spokane	Washington	4914642584339455	19418754689b2ad084b8c107f298e6c8	American Express	47.754063286609572	-117.35751759534628
36860	2020-07-12 09:45:41	2020-07-12	Sherri Bartoletti-Mann	sherri.bartoletti.mann@woohoo.com	Phoenix	Arizona	6011857971781451493	fc6fa5544d4274bea8206839af4acdce	VISA 13 digit	33.5484155903503307	-112.046605518825729
36861	2020-07-12 09:50:18	2020-07-12	Heriberto Goodwin	heriberto.goodwin@geemail.com	Nashville	Tennessee	3058008374492911	f4b1d36f46862fa63aff2f2ba251ffaa	American Express	36.1590395786456753	-86.8439263694360761
36862	2020-07-12 09:53:25	2020-07-12	Kirby Quigley-Schneider	kirby.quigley.schneider@woohoo.com	Tempe	Arizona	3337994943512865295	b9f63335957cca4f8c4439ad9b6174b3	American Express	33.4045715572234201	-111.912792383044206
36863	2020-07-12 09:57:43	2020-07-12	Mrs. Mareli Beer DDS	mrs.mareli.beer.dds@warmmail.com	Phoenix	Arizona	4128188267897270	61e4d7f768a788de8d887b9d94f1addb	VISA 16 digit	33.6015799264822164	-112.115841026457403
36864	2020-07-12 10:02:17	2020-07-12	Thor Dare	thor.dare@geemail.com	Moreno Valley	California	4976465097209584	3261de04b41adcdee1322b7d9a3ef02c	JCB 15 digit	33.8743605633258795	-117.211896060311048
36865	2020-07-12 10:08:11	2020-07-12	Dr. Debora Larson PhD	dr.debora.larson.phd@geemail.com	Vista	California	6011272232153758123	d69d16216bed28efec41594507b5a3e9	VISA 16 digit	33.1037801095731581	-117.261152022803586
36866	2020-07-12 10:26:58	2020-07-12	Mrs. Kirstin Kutch PhD	mrs.kirstin.kutch.phd@woohoo.com	Salt Lake City	Utah	4894245059372664	2b0e079bf93c8d631ab1fa8bd0a8049c	Maestro	40.8746122791111475	-111.899253863137218
36867	2020-07-12 10:29:28	2020-07-12	Julisa Witting	julisa.witting@geemail.com	Rochester	New York	3034511096530821	888ff18195fc5e44e218c04ac7c79d87	Discover	43.1410105036083564	-77.6232172046095172
36868	2020-07-12 10:35:47	2020-07-12	Heber Denesik	heber.denesik@geemail.com	Peoria	Illinois	3485957316660074	58a2e505dcb6d40dd7a5c69bd9faf1ed	Voyager	40.6960646722801016	-89.5569943225361413
36869	2020-07-12 10:36:34	2020-07-12	Delfina Kreiger-Leannon	delfina.kreiger.leannon@warmmail.com	Los Angeles	California	3048284261169827	e3a7fc285fda9f1b19405753816514d8	JCB 15 digit	34.1169496119353894	-118.48253979873769
36870	2020-07-12 10:41:40	2020-07-12	Devin Casper	devin.casper@warmmail.com	New York	New York	3000777855040591	4161279ba23f5dbcba0a340397d80e4e	VISA 13 digit	40.6488682107757739	-74.0025092933688313
36871	2020-07-12 10:54:33	2020-07-12	Angela Jacobs	angela.jacobs@geemail.com	Knoxville	Tennessee	869930852935958155	70717161b0817a855a940426a9bb1cb2	Voyager	36.0017867901425817	-83.8572112121835289
36872	2020-07-12 10:56:18	2020-07-12	Becky Fadel DVM	becky.fadel.dvm@warmmail.com	San Francisco	California	4381269349092163	49ba6df242a335571acee30907967cf4	VISA 13 digit	37.7696666934348926	-122.456604098478294
36873	2020-07-12 11:00:18	2020-07-12	Dr. Jarrell Hermann	dr.jarrell.hermann@geemail.com	Los Angeles	California	4789433861259919	777de816303757c1374cc6d7d554af11	JCB 15 digit	33.9728662018530017	-118.380169415612883
36874	2020-07-12 11:02:33	2020-07-12	Osa Erdman	osa.erdman@geemail.com	San Francisco	California	3112712871447148043	92b5c16abd951db93b44c6bdafb137a5	JCB 15 digit	37.7856988141407797	-122.396387846514202
36875	2020-07-12 11:10:38	2020-07-12	Enriqueta Grant	enriqueta.grant@warmmail.com	Richmond	Virginia	3096650129341741924	8e3c5d82e3ac8b9f6d35863ff6c6e0ca	VISA 16 digit	37.4772445040509083	-77.4331591094601919
36876	2020-07-12 11:15:27	2020-07-12	Deidra Pollich-Bernier	deidra.pollich.bernier@geemail.com	Tacoma	Washington	3112185651411356659	bc79c61dc0b91af287bfe6198fc34613	JCB 16 digit	47.1992810015685862	-122.387125074700634
36877	2020-07-12 11:16:02	2020-07-12	Mills Klein	mills.klein@warmmail.com	Colorado Springs	Colorado	3004111879783737	69b8ba11ce53bbb48c31d7ddbdba06be	JCB 16 digit	38.769337301566452	-104.807498702375966
36878	2020-07-12 11:16:10	2020-07-12	Hershell Goyette	hershell.goyette@geemail.com	Boston	Massachusetts	501801648484499	90dfdba94fb59c36df77302942a18c33	VISA 16 digit	42.298191219165922	-71.1094520405352171
36879	2020-07-12 11:16:40	2020-07-12	Teddy Armstrong	teddy.armstrong@geemail.com	Los Angeles	California	54638422097908376	63f10c300a5645bab45d72c93c91e390	JCB 15 digit	34.0600052596867044	-118.498120346850897
36880	2020-07-12 11:18:35	2020-07-12	Rosita Dietrich	rosita.dietrich@geemail.com	Columbia	South Carolina	210062110836739112	a2009173a8dc8431b3e96dc30e56098e	VISA 13 digit	33.9457603948455287	-80.9410620984639877
36881	2020-07-12 11:21:28	2020-07-12	Melody Kulas	melody.kulas@woohoo.com	San Francisco	California	3528752710120863844	e96488a70dfb9bd2f37b2e1b0b5dcdcc	VISA 16 digit	37.8008621994154197	-122.412639600833046
36882	2020-07-12 11:22:08	2020-07-12	Miss Letta Ankunding	miss.letta.ankunding@geemail.com	Nashville	Tennessee	3799744491020801	839a8aa54bd14558a63345d2ded559aa	VISA 16 digit	36.1627587225411062	-86.8309401336498468
36883	2020-07-12 11:28:04	2020-07-12	Ollie Hickle	ollie.hickle@geemail.com	St. Louis	Missouri	4432575979351	9319bccf5935819f193433baaa19ef75	Maestro	38.6962017595458789	-90.3193217793948975
36884	2020-07-12 11:57:10	2020-07-12	Sean Shields-Hand	sean.shields.hand@geemail.com	Durham	North Carolina	676158687418903	2f0adb3615cb602cd70dcf69a36d93a3	JCB 16 digit	35.9791809798929805	-78.9054290667079385
36885	2020-07-12 11:57:16	2020-07-12	Colter Padberg-Rippin	colter.padberg.rippin@geemail.com	Oakland	California	3026819557900724	41d468b7fc725fb5aa23dd933ab23263	Maestro	37.7980919383496357	-122.284017568976566
36886	2020-07-12 11:57:32	2020-07-12	Geri Torphy	geri.torphy@woohoo.com	Dallas	Texas	869910060570443640	afe6408c89ac026775ce3ccbc9bb3d22	Discover	32.8517911682642989	-96.7678980972580547
36887	2020-07-12 11:59:47	2020-07-12	Chet Graham	chet.graham@warmmail.com	Corona	California	3030586526837008	251fc00fbc351924f6c5828c41e96755	American Express	33.8732657632678738	-117.500172638494519
36888	2020-07-12 12:11:42	2020-07-12	Junie Bechtelar DDS	junie.bechtelar.dds@warmmail.com	Anaheim	California	3007799224603035	f328398dab347d2b92261d7ad61105c4	American Express	33.7978283931799197	-117.758720355781165
36889	2020-07-12 12:29:08	2020-07-12	Sydell Reichel	sydell.reichel@woohoo.com	Virginia Beach	Virginia	4515386459348	5d3c797792ecd3526c0cc744ff930914	Discover	36.7403846682701243	-75.9310707180898561
36890	2020-07-12 12:33:58	2020-07-12	Aylin Fay MD	aylin.fay.md@geemail.com	Louisville	Kentucky	503815339678458	415a845ed615c1b028f48ba8660793f0	Diners Club / Carte Blanche	38.2070558397002529	-85.6950695438846992
36891	2020-07-12 12:37:16	2020-07-12	Arsenio Mitchell	arsenio.mitchell@geemail.com	Worcester	Massachusetts	52650012193468228	ddc38510c7ed750910568272e5f79ada	Maestro	42.2170100623909406	-71.8225086308337808
36892	2020-07-12 12:46:16	2020-07-12	Ezequiel Spencer-Daniel	ezequiel.spencer.daniel@geemail.com	San Francisco	California	4083267510111086	a11b2ecb3a93aab0fff5c4ebe7748075	Maestro	37.7841960129889785	-122.44876746337799
36893	2020-07-12 12:53:28	2020-07-12	Ansel Will	ansel.will@warmmail.com	San Francisco	California	3795100477525871	192e5f19edc6bef486185220c268c326	VISA 13 digit	37.7218976121998963	-122.426936210708732
36894	2020-07-12 13:11:52	2020-07-12	Dr. Zavion Rogahn	dr.zavion.rogahn@geemail.com	Tucson	Arizona	3468741040884858	ebb3aa98d655726075f29d2bf5b44e46	Diners Club / Carte Blanche	32.2342076820828041	-110.831638184259077
36895	2020-07-12 13:12:08	2020-07-12	Dr. Theodore Hoppe DDS	dr.theodore.hoppe.dds@geemail.com	Dallas	Texas	3495902214437157	77a945a96ba50c149b8be38f956ea552	JCB 15 digit	32.776177108873803	-96.844153842279681
36896	2020-07-12 13:17:59	2020-07-12	Mr. Romeo Mayert MD	mr.romeo.mayert.md@woohoo.com	Springfield	Missouri	3041179017776437	36c727c4072c72ea208422a852f6dfb3	VISA 16 digit	37.1573222633179299	-93.2306819528631934
36897	2020-07-12 13:28:31	2020-07-12	Marva Torp	marva.torp@geemail.com	Henderson	Nevada	51004001254765005	d9ead61364d7bbeb6f706bda9a5c386b	Voyager	36.0543401644498118	-115.130719048033285
36898	2020-07-12 13:37:08	2020-07-12	Loria Marks-O'Conner	loria.marks.o'conner@geemail.com	San Jose	California	54131381612159984	b41357d5d339d0ee7ea76959a92cff09	Diners Club / Carte Blanche	37.2263993348747491	-121.767453295107558
36899	2020-07-12 13:38:18	2020-07-12	Linsey Gusikowski	linsey.gusikowski@geemail.com	Akron	Ohio	3112918507026693833	894e4cc92ce30ac3cee098ba1570d77b	Voyager	41.0252069738060214	-81.5266005426026936
36900	2020-07-12 13:39:10	2020-07-12	Jessee O'Reilly-Miller	jessee.o'reilly.miller@geemail.com	Jacksonville	Florida	501846211148823	b6ddcc70bca27055b58367b3f0f79ecb	VISA 13 digit	30.2464210406463607	-81.715822716391088
36901	2020-07-12 13:43:18	2020-07-12	Miss Mireya Thompson DDS	miss.mireya.thompson.dds@geemail.com	Brownsville	Texas	561238609747019	64d478320b89c11b609920b44b5853a8	Discover	25.992102302106467	-97.378522361367942
36902	2020-07-12 13:49:19	2020-07-12	Yee Wyman	yee.wyman@geemail.com	Washington	District of Columbia	4771351756123869	0d1aa38e0ed032551910df2db0658f7c	JCB 16 digit	38.9775755087178197	-76.9676143245052629
36903	2020-07-12 14:01:54	2020-07-12	Meryl Borer	meryl.borer@geemail.com	Kansas City	Missouri	3006320456918032	ac0b948c4a1f3c14297c3ccb841c335c	JCB 16 digit	39.1621631499681655	-94.5094613204468033
36904	2020-07-12 14:06:26	2020-07-12	Rilla Kutch	rilla.kutch@geemail.com	Oklahoma City	Oklahoma	4749515766132826	ce9c780bc28d83c58562ee2c6cdbd3dc	VISA 13 digit	35.4074075796551995	-97.4716822063446102
36905	2020-07-12 14:11:10	2020-07-12	Murry Quigley	murry.quigley@geemail.com	Kansas City	Missouri	4128049832696169	a9d0a98c4646cebaf3b1d9c00965bcc8	Voyager	39.0355519866406979	-94.4935414652563708
36906	2020-07-12 14:20:40	2020-07-12	Odin Bailey PhD	odin.bailey.phd@geemail.com	Charlotte	North Carolina	676345594864063	b7f53470e348bdc028a43d5a53822558	JCB 16 digit	35.2758760845541914	-80.8949546951279075
36907	2020-07-12 14:23:34	2020-07-12	Mrs. Macy Morissette	mrs.macy.morissette@geemail.com	San Francisco	California	4523564920461	08eecdc035ff9022a48d5630703578f5	JCB 16 digit	37.7825256255950137	-122.419022766953077
36908	2020-07-12 14:35:10	2020-07-12	Tracie Wiza	tracie.wiza@geemail.com	Mesa	Arizona	6011612519693921792	ad00a121961e485c9992f4b4e3422d0b	Voyager	33.4066855909448108	-111.742822782870007
36909	2020-07-12 15:12:39	2020-07-12	Aleen Deckow-Dickens	aleen.deckow.dickens@woohoo.com	Overland Park	Kansas	869956788163169348	bd9a42ea0b65cdb65b3f37793ec3e7e1	Mastercard	38.8472107244059472	-94.6236357807222817
36910	2020-07-12 15:22:09	2020-07-12	Alex Herman	alex.herman@geemail.com	Berkeley	California	6011996785240411936	30c1b72ebb58ae22a2ddd0eb9778fad0	American Express	37.8632893913528648	-122.283028703405307
36911	2020-07-12 15:25:00	2020-07-12	Latonia Turner	latonia.turner@geemail.com	New York	New York	51607177328785418	0862dbc7b124fc8d3ab2f254cd2f2a45	Maestro	40.5923876864593467	-73.8927197634138082
36912	2020-07-12 15:28:40	2020-07-12	Evertt Ferry	evertt.ferry@geemail.com	New York	New York	869906349481613300	46523b4849bff4ce782c5b0c5300a91a	JCB 16 digit	40.6607356976941219	-73.8924361916154595
36913	2020-07-12 15:34:39	2020-07-12	Miss Sophronia Green DDS	miss.sophronia.green.dds@woohoo.com	Everett	Washington	502066155973671	484bbfd1a850510c81d4af87cfa06f2f	VISA 16 digit	47.8654080344721677	-122.253915001837171
36914	2020-07-12 15:38:29	2020-07-12	Jerod Roberts	jerod.roberts@warmmail.com	San Francisco	California	503878026844635	6c6c3f9276f126bb207637bbaa4dc019	JCB 16 digit	37.789159273047602	-122.410830414874582
36915	2020-07-12 15:40:10	2020-07-12	Josefa Pfannerstill	josefa.pfannerstill@geemail.com	Detroit	Michigan	3058726621406224	ab56c3e5c4418d3b57e2cb26d64a80e5	American Express	42.4669884698856634	-83.1800462333604713
36916	2020-07-12 15:41:26	2020-07-12	Mr. Orland Langworth	mr.orland.langworth@geemail.com	Chicago	Illinois	4396729090516	b7a3d6ef309ec3c08d2e950a47ff187b	Discover	41.8435541634749626	-87.625003322589393
36917	2020-07-12 16:10:22	2020-07-12	Ms. Leanna Hahn DDS	ms.leanna.hahn.dds@geemail.com	Los Angeles	California	210009699160951539	fcb2e0ac8ad0231422c61fe74419aa11	JCB 15 digit	33.9443146807007494	-118.320762461236853
36918	2020-07-12 16:12:15	2020-07-12	Ernestina Kling	ernestina.kling@geemail.com	Chicago	Illinois	4612672124332988	918bb162a445749246e11032fad77099	Mastercard	41.8364504508510251	-87.5993945072900431
36919	2020-07-12 16:12:36	2020-07-12	Gerald Streich Jr.	gerald.streich.jr.@geemail.com	Los Angeles	California	4342836497672984	c27cfb2f6ce3d794da0431b69b8985f6	Maestro	33.9390491746231859	-118.509494967199117
36920	2020-07-12 16:19:04	2020-07-12	Cristine Romaguera PhD	cristine.romaguera.phd@geemail.com	Boston	Massachusetts	3158561177907621954	d5f96923a53b5ba940981765860356cb	VISA 13 digit	42.2708052234426148	-71.109364033019915
36921	2020-07-12 16:21:42	2020-07-12	Mr. Gaines Hagenes I	mr.gaines.hagenes.i@geemail.com	Woodbridge	New Jersey	561212511063989	ab5e6ac323935c87e131534569f84e76	JCB 16 digit	40.6293073623597607	-74.2167990041755132
36922	2020-07-12 16:21:49	2020-07-12	Ms. Carmel Shanahan DDS	ms.carmel.shanahan.dds@woohoo.com	El Paso	Texas	54742509308477903	d5916db80c28db453cfa3b4447fcba3c	Voyager	31.7625705064103023	-106.353023843279118
36923	2020-07-12 16:52:27	2020-07-12	Serina Kling-Stoltenberg	serina.kling.stoltenberg@warmmail.com	Riverside	California	52351787241908828	212bf134941fcb5c011118f70c20c740	JCB 16 digit	33.8878063584625693	-117.41542916795872
36924	2020-07-12 17:09:50	2020-07-12	Zachary Deckow	zachary.deckow@geemail.com	Berkeley	California	3337446448710558597	21d14741f8695f0c06db6850aa3bcd83	Discover	37.8691087404142337	-122.288188448728278
36925	2020-07-12 17:17:30	2020-07-12	Ardell Stark	ardell.stark@geemail.com	Pompano Beach	Florida	4802159034475040	b2ba07adaeb9159496951852c19f0a9e	VISA 13 digit	26.2817575563941119	-80.1915722647994755
36926	2020-07-12 17:20:57	2020-07-12	Jacky Kihn	jacky.kihn@warmmail.com	San Francisco	California	502094457596362	83b773b2af9ad1658a103be92c1b2241	American Express	37.7658116561365418	-122.429413653322584
36927	2020-07-12 17:25:10	2020-07-12	Sarai Bayer	sarai.bayer@geemail.com	Brownsville	Texas	3035021205462329	fab61f9c9b2e62572fb46db20186d230	VISA 16 digit	26.0819315934631959	-97.4242926418501867
36928	2020-07-12 18:15:57	2020-07-12	Eulah Conroy	eulah.conroy@geemail.com	San Francisco	California	869961902634208931	eb171b4d9d2fbcbea84ad2ae5fc7714e	Mastercard	37.7772224478424903	-122.460115739347827
36929	2020-07-12 18:27:57	2020-07-12	Lorenzo Hills	lorenzo.hills@geemail.com	Paterson	New Jersey	4464548568309378	f2c337e2b9ad34a8ad2a94f81c0e3dd1	VISA 16 digit	40.9000495857048776	-74.133484137800707
36930	2020-07-12 18:28:59	2020-07-12	Marcell Hoppe II	marcell.hoppe.ii@geemail.com	Memphis	Tennessee	180016299253265672	c4d9c66659d88c6f28de52212f2603c3	JCB 16 digit	35.1182720596037825	-90.0226457666862814
36931	2020-07-12 18:43:37	2020-07-12	Villa Johnston-Cruickshank	villa.johnston.cruickshank@geemail.com	New York	New York	4669230644777	cba2b9ce99a649322394c8df7a34e085	American Express	40.6320328339226506	-73.9121230347443401
36932	2020-07-12 18:45:53	2020-07-12	Dr. Neoma Sanford MD	dr.neoma.sanford.md@woohoo.com	Santa Ana	California	4323114950212067	142b7c737f3e52bd377fd8ca1235ef14	JCB 15 digit	33.6613850788317635	-117.801289608275511
36933	2020-07-12 18:47:45	2020-07-12	Dona Franecki	dona.franecki@woohoo.com	New York	New York	3058644172409499	d811e3eb0e1a14d509471473df746164	Discover	40.5914500456061234	-74.0087483691412871
36934	2020-07-12 18:53:41	2020-07-12	Martina Predovic	martina.predovic@geemail.com	New York	New York	4679283765577	8f3471de8f214700227f173b34e19862	VISA 16 digit	40.5951592743620253	-73.9910451703600529
36935	2020-07-12 19:05:37	2020-07-12	Shaquan Aufderhar	shaquan.aufderhar@geemail.com	Las Vegas	Nevada	3444380333560559	315e99e31c08f4950f4123e945ddfad1	JCB 16 digit	36.1400107336331118	-115.265707343604788
36936	2020-07-12 19:08:33	2020-07-12	Sharon Bernier-Robel	sharon.bernier.robel@woohoo.com	San Francisco	California	4095806147681783	889b8be0c6ee35294f68bfff0dfc1531	VISA 16 digit	37.7490111260157732	-122.421618041560748
36937	2020-07-12 19:21:12	2020-07-12	Taylor Streich	taylor.streich@warmmail.com	Denton	Texas	4296885820414107	d4dadce751fa211a4c3e47c7786d10b2	VISA 13 digit	33.3110056721869867	-97.1243716635402308
36938	2020-07-12 19:24:26	2020-07-12	Kenneth Walker I	kenneth.walker.i@geemail.com	San Francisco	California	3004436116058670	e63111f9ce2523f486f5f6b530e1cab0	JCB 16 digit	37.7732160789225091	-122.4529852104139
36939	2020-07-12 19:26:38	2020-07-12	Ivey Effertz	ivey.effertz@geemail.com	Fresno	California	4253306861856636	c7f87849229ae04c9a1816462279b184	VISA 13 digit	36.6929610256910337	-119.857624294060841
36940	2020-07-12 19:34:39	2020-07-12	Wilburn Weissnat	wilburn.weissnat@geemail.com	Phoenix	Arizona	3470933143445408	af882d1dcf4aeaeca036e3f832ee68c6	JCB 15 digit	33.5241852080848091	-112.131272689013187
36941	2020-07-12 19:38:35	2020-07-12	Dr. Hector Mante	dr.hector.mante@warmmail.com	Riverside	California	210096549153753638	7a59a0db8317a4e7ef063a2f9313b501	Voyager	33.9591736232344061	-117.304449458603557
36942	2020-07-12 19:38:53	2020-07-12	Randal Labadie	randal.labadie@woohoo.com	Tulsa	Oklahoma	55637263601282663	3b2defd221c12eca84b49e9d2e4d7f40	JCB 16 digit	36.1587775514364225	-95.993964219694206
36943	2020-07-12 19:45:26	2020-07-12	Dr. Metro Ebert	dr.metro.ebert@warmmail.com	New York	New York	501830367748065	fb94e4bbe67b5e0a004ff0f5339eae80	Maestro	40.7030550859626388	-74.0110301355726961
36944	2020-07-12 19:57:18	2020-07-12	Mr. Lavern D'Amore	mr.lavern.d'amore@geemail.com	San Francisco	California	3053901456299706	75b045f08de4c28667ce722372dca703	VISA 16 digit	37.7551999378125842	-122.429109442317724
36945	2020-07-12 19:57:32	2020-07-12	Lilia O'Conner	lilia.o'conner@geemail.com	Visalia	California	4816139796968501	ed652737fc94cdffb6153747ee2a932d	VISA 13 digit	36.3728412047915199	-119.401791875263314
36946	2020-07-12 20:12:21	2020-07-12	Kunta Kunze	kunta.kunze@geemail.com	Richmond	Virginia	869998087530469915	a69c8d137eab1ce2432e740b5027ae4e	Mastercard	37.5798274782706017	-77.5610013316608899
36947	2020-07-12 20:24:56	2020-07-12	Koby Runolfsson	koby.runolfsson@geemail.com	Vancouver	Washington	4147050074060	f6b7f47be5088b3208e38299f67ff16c	JCB 16 digit	45.6054906616523894	-122.565115807817122
36948	2020-07-12 20:52:13	2020-07-12	Ally Wuckert	ally.wuckert@geemail.com	San Francisco	California	3003072667465427	6d7de9da732af33e270a332eb99ad6e6	VISA 13 digit	37.7388886287478797	-122.42119864272199
36949	2020-07-12 20:58:59	2020-07-12	Ayesha Rath	ayesha.rath@geemail.com	Detroit	Michigan	4667210379712572	81f13caa020981d5a4f5f6a4dc38f15a	American Express	42.4070274172741932	-83.0523588818617071
36950	2020-07-12 21:03:06	2020-07-12	Mrs. Kennedy Cummerata	mrs.kennedy.cummerata@geemail.com	Atlanta	Georgia	4981521472630	aa52a07c8746704ad7cca7776a0eaaa2	JCB 16 digit	33.8412744553104048	-84.3484288194261609
36951	2020-07-12 21:13:38	2020-07-12	Nicolas Herzog	nicolas.herzog@geemail.com	Columbus	Ohio	4996431447572499	b73293f050635d398775c599062a6995	American Express	40.0352954364892071	-82.9024058496348601
36952	2020-07-12 21:27:43	2020-07-12	Mr. Tilman Osinski PhD	mr.tilman.osinski.phd@woohoo.com	Jackson	Mississippi	54670456520141196	951a10970aee7b64de2543ac10c57110	JCB 16 digit	32.2189035706400873	-90.1258001607350963
36953	2020-07-12 21:38:44	2020-07-12	Tilden Sporer	tilden.sporer@geemail.com	Berkeley	California	3039589876595292	afa13fef3815436ce7e780072020238f	JCB 16 digit	37.8777514182264099	-122.266199478807536
36954	2020-07-12 21:46:23	2020-07-12	Shameka Labadie PhD	shameka.labadie.phd@geemail.com	Santa Maria	California	4285782071559503	ebe686dc1e6ecd80f8391571fd96c589	Voyager	34.8824438869085185	-120.440777368509387
36955	2020-07-12 21:46:37	2020-07-12	Dr. Jedidiah Hammes	dr.jedidiah.hammes@warmmail.com	Waco	Texas	4032917115855055	21f9df608a76eef4fc6d2ce4f9702aa7	Voyager	31.4624389018140711	-97.2786175599452179
36956	2020-07-12 21:49:59	2020-07-12	Quinton Barrows	quinton.barrows@warmmail.com	Fort Worth	Texas	3448196775285661	3fc395cf25c962e700be792aa5853d17	Mastercard	32.7727297453265649	-97.2805285517413125
36957	2020-07-12 22:03:51	2020-07-12	Mikayla Gleason	mikayla.gleason@geemail.com	San Francisco	California	3096634049508886786	eda8128701d41c299f92d7d1f388d5a4	Diners Club / Carte Blanche	37.735273701905534	-122.442507712180202
36958	2020-07-12 22:08:30	2020-07-12	Link Hammes	link.hammes@geemail.com	McKinney	Texas	3528960794245794728	5814f6d22cb87e960f4110f7f8b59ae7	Mastercard	33.1347839280627667	-96.6610794819258246
36959	2020-07-12 22:13:10	2020-07-12	Dr. Jordy Hodkiewicz	dr.jordy.hodkiewicz@geemail.com	Portland	Oregon	869949043000143381	eea610b67a81d3f92b16e6a8ad452def	JCB 16 digit	45.5625757307168087	-122.615920764300981
36960	2020-07-12 22:25:48	2020-07-12	Burney Douglas	burney.douglas@geemail.com	Providence	Rhode Island	4119836796751985	880ee13d2508ea86d961da8238e497f1	JCB 16 digit	41.9160927926044877	-71.3845535637263282
36961	2020-07-12 22:30:04	2020-07-12	Earlean Murphy-Carroll	earlean.murphy.carroll@geemail.com	Orlando	Florida	4543329832249160	aa36666f8df8f183ec0fd3acc7a39085	Mastercard	28.420236510763317	-81.186341275085141
36962	2020-07-12 22:32:08	2020-07-12	Manley Balistreri	manley.balistreri@geemail.com	Jersey City	New Jersey	210068712113056773	162b8842cdfd53640789573b8e1f25ea	Mastercard	40.6997740917313848	-74.0287096644241416
36963	2020-07-12 22:34:47	2020-07-12	Amon Jones	amon.jones@geemail.com	Memphis	Tennessee	6011138753325185725	d15c9574fab3c6df0a2bfb39de1768e6	VISA 16 digit	35.1341262567389805	-89.9544837877411396
36964	2020-07-12 22:35:33	2020-07-12	Marlo Larson	marlo.larson@geemail.com	San Diego	California	3088888621609403175	ab3be19a1dda839dbc427b910736ef90	VISA 13 digit	32.7936372109290204	-117.121936497176065
36965	2020-07-12 22:35:42	2020-07-12	Alisa Stokes	alisa.stokes@geemail.com	Los Angeles	California	3088163440525990397	f9d99d0fa5134815ac31159bc3ed22e4	VISA 16 digit	34.0340657834760805	-118.330667074256752
36966	2020-07-12 22:44:54	2020-07-12	Ms. Gena Gislason	ms.gena.gislason@warmmail.com	San Francisco	California	4025941545979	bc0ce90701e5d44776fe12d8b0faf94a	VISA 13 digit	37.7571150263421202	-122.416386987339095
36967	2020-07-12 22:45:43	2020-07-12	Estill Simonis	estill.simonis@geemail.com	Peoria	Arizona	210058001396326836	38d9de7ac5401ef7bc8bd5e459ae2020	American Express	33.7571696115460256	-112.36338387913257
36968	2020-07-12 22:50:51	2020-07-12	Dr. Clifton Bode	dr.clifton.bode@geemail.com	Austin	Texas	3112124046921935098	2fab6b5d9935886376f879fe4e74d841	JCB 16 digit	30.2480357016097727	-97.7138958681147614
36969	2020-07-12 22:56:36	2020-07-12	Buna Gutmann	buna.gutmann@geemail.com	New York	New York	3096722049389732664	4571a2382b13d690b5f162a3b6d84232	Mastercard	40.7013128368407493	-73.939451869939262
36970	2020-07-12 23:12:31	2020-07-12	Kandace Price PhD	kandace.price.phd@geemail.com	Salem	Oregon	3012760825735332	300714fbea3dad837beb44996f0e903f	Diners Club / Carte Blanche	44.9623160600930447	-123.096646704400712
36971	2020-07-12 23:20:08	2020-07-12	Tollie Morissette	tollie.morissette@warmmail.com	Fresno	California	4357162896730527	ce454e7315a9a9b7b700050623d516c7	VISA 16 digit	36.778266673662138	-119.761561738384515
36972	2020-07-12 23:22:20	2020-07-12	Lizabeth Mante	lizabeth.mante@warmmail.com	Richmond	Virginia	869971011422087081	dc3e7fff7f3da3d4c37122fed0da80bc	JCB 16 digit	37.4946925877347539	-77.529704831656062
36973	2020-07-12 23:30:49	2020-07-12	Dr. Sable Brakus PhD	dr.sable.brakus.phd@geemail.com	Rochester	New York	3337107063273567917	1b8506ed9781e3b2908ac9286023e476	Discover	43.1292221611343294	-77.6445212107855838
36974	2020-07-12 23:33:28	2020-07-12	Clem Conroy	clem.conroy@geemail.com	Aurora	Colorado	4650716863370882	40857db9e572bedf0ebd9fec56a2400f	VISA 13 digit	39.6635373681895445	-104.696637215058132
36975	2020-07-12 23:54:43	2020-07-12	Miss Anika Davis MD	miss.anika.davis.md@warmmail.com	Kent	Washington	3719649047465342	e3ecc8bdbf9c83ce3fbc5c141b9f4b82	Voyager	47.3811816212832895	-122.254278783653675
36976	2020-07-12 23:58:08	2020-07-12	Samual Frami	samual.frami@geemail.com	Grand Rapids	Michigan	4954877298198	5bc2456a295a01500773d416c2c2923e	Mastercard	42.9494077858317596	-85.6979293583095085
36977	2020-07-13 00:20:32	2020-07-13	Mr. Donald Gerlach DDS	mr.donald.gerlach.dds@geemail.com	Denver	Colorado	3528751435674880223	645fa818770e739ddc6f78f64054eabc	VISA 16 digit	39.8314751403458374	-104.935520284926895
36978	2020-07-13 00:21:48	2020-07-13	Yoshio Beer	yoshio.beer@geemail.com	Fontana	California	3021637699385603	66b69926cdd5067d2504b460011fa33d	Diners Club / Carte Blanche	34.1909255972281088	-117.525394741845886
36979	2020-07-13 00:48:55	2020-07-13	Shavon Koch	shavon.koch@warmmail.com	San Francisco	California	210010000168774964	4348655d8768dacc016b58f814ef0017	JCB 16 digit	37.7563463535656254	-122.401856229091138
36980	2020-07-13 00:51:15	2020-07-13	Emilie Reichel-Mills	emilie.reichel.mills@geemail.com	San Francisco	California	4939755519586957	abec5e6a0b63b81502230b3a2feb79aa	Diners Club / Carte Blanche	37.8132989864967328	-122.445338012050513
36981	2020-07-13 00:57:24	2020-07-13	Vic Spencer MD	vic.spencer.md@geemail.com	Chicago	Illinois	4254837715632947	0ca587754ef9c4277c936154ccc09983	Diners Club / Carte Blanche	41.7820679336622405	-87.7739163802035165
36982	2020-07-13 01:02:51	2020-07-13	Carmine Cartwright	carmine.cartwright@geemail.com	Miami	Florida	4473857324976860	e16df72de5907a2a4032de7e4bbe842b	VISA 13 digit	25.6843100101359205	-80.245960487366105
36983	2020-07-13 01:13:31	2020-07-13	Olan Schmeler V	olan.schmeler.v@geemail.com	New York	New York	3711658156832323	633e28e1bf763d637d916a8544e946f0	VISA 13 digit	40.5824624765422186	-73.9198262486502529
36984	2020-07-13 01:21:37	2020-07-13	Raven Ryan	raven.ryan@woohoo.com	New York	New York	4182484361705185	558037381f4c8fece9d729384e64f82b	American Express	40.7494633229207253	-73.9143251959595773
36985	2020-07-13 01:24:42	2020-07-13	Ora Emard	ora.emard@geemail.com	New York	New York	53440014160841994	7c85da565e829685d0abc56a990bc469	JCB 16 digit	40.6290233166180528	-73.8920356922678678
36986	2020-07-13 01:37:22	2020-07-13	Amelia Shields	amelia.shields@geemail.com	Houston	Texas	3050703260070411	143ab2db66a8d8259e91066fd651687e	JCB 16 digit	29.8414600263427943	-95.4338281782358848
36987	2020-07-13 01:40:18	2020-07-13	Melville Hermiston-Lind	melville.hermiston.lind@geemail.com	Wichita	Kansas	210014646769268461	cb5d7183d6e2fd01511b3b1f4aeb7c89	VISA 16 digit	37.7273263843607154	-97.2537843054827249
36988	2020-07-13 01:42:52	2020-07-13	Mrs. Carolann Sporer	mrs.carolann.sporer@geemail.com	Baton Rouge	Louisiana	3096906582954073336	5ff342d9db9fcec82afc67373c657306	Voyager	30.4228817447766673	-91.1373460895489842
36989	2020-07-13 01:52:41	2020-07-13	Dr. Randell Corwin	dr.randell.corwin@woohoo.com	Cape Coral	Florida	6011514297653724543	a046fc17f5c2fcd261225e03c599877a	Maestro	26.661610842353479	-81.9165108535043913
36990	2020-07-13 02:06:02	2020-07-13	Americo Spencer	americo.spencer@woohoo.com	Clarksville	Tennessee	3088037376595780744	e8d9e0131325031754540262af07d852	Voyager	36.6123036964457498	-87.370580024174231
36991	2020-07-13 02:06:36	2020-07-13	Tillman Crona	tillman.crona@geemail.com	Columbia	Missouri	3096165245606622142	fb409ebcf983fac69a94244778c4633e	VISA 16 digit	38.8674951042861352	-92.2485873824504239
36992	2020-07-13 02:10:31	2020-07-13	Eula O'Reilly-Christiansen	eula.o'reilly.christiansen@geemail.com	San Francisco	California	4460165989266	5cfa60aa66e324512c54617687e14787	Mastercard	37.7931588385399735	-122.444419896111228
36993	2020-07-13 02:11:46	2020-07-13	Wilfredo Stehr	wilfredo.stehr@warmmail.com	Tulsa	Oklahoma	4771457708000392	46c8916894044400e7032558f7765bd2	Mastercard	36.0716869508285072	-95.982925500017771
36994	2020-07-13 02:28:03	2020-07-13	Jennings Johns II	jennings.johns.ii@geemail.com	San Francisco	California	6011709681118016113	cec68c396b5dd1e03665e55b40d911d2	VISA 13 digit	37.7369409360148396	-122.434210148248965
36995	2020-07-13 02:34:45	2020-07-13	Maxie Beier	maxie.beier@warmmail.com	Colorado Springs	Colorado	3337082886819030910	d97db46c39c9aed833431985252db9a8	Discover	38.9020779030445993	-104.829129703451699
36996	2020-07-13 02:41:37	2020-07-13	Kati Smitham	kati.smitham@warmmail.com	Irving	Texas	3337513028799583688	3219829c148f7adccb767b6f87ca2238	American Express	32.8742633420925614	-96.9839670896809594
36997	2020-07-13 02:47:37	2020-07-13	Jonatan Beahan	jonatan.beahan@warmmail.com	San Francisco	California	4114499797911168	3150eeebdc28168b7c736fbeaaa1b6cb	JCB 16 digit	37.7643546393355152	-122.463335019919597
36998	2020-07-13 03:00:44	2020-07-13	Lucky Considine	lucky.considine@geemail.com	Cape Coral	Florida	3088942654771106155	93ca60bc5bacf2580ba380430a171865	VISA 16 digit	26.6579328319493669	-81.9382359301276466
36999	2020-07-13 03:05:45	2020-07-13	Skylar Gulgowski DDS	skylar.gulgowski.dds@geemail.com	Seattle	Washington	210031285443862321	55d0e47fc53fd22df59bc6e282bd78fa	Voyager	47.5626692017931489	-122.420868202710153
37000	2020-07-13 03:08:03	2020-07-13	Leonel Quitzon	leonel.quitzon@geemail.com	San Francisco	California	3031289378532210	7c9738b6afabc03b44f0a9c28ea5f0a5	JCB 16 digit	37.7793363657894972	-122.401340805816361
37001	2020-07-13 03:14:30	2020-07-13	Hadley Christiansen	hadley.christiansen@geemail.com	Salem	Oregon	3528556618012672975	584e40a60370e2735f005f17fdb0d7fc	JCB 16 digit	44.9409016693744761	-123.07707874515728
37002	2020-07-13 03:20:15	2020-07-13	Mrs. Edwina Kilback	mrs.edwina.kilback@warmmail.com	Honolulu	Hawaii	51524112443921861	7586f53a863c145e636c022526179dc6	Discover	21.3407210961200313	-157.771381492048874
37003	2020-07-13 03:20:19	2020-07-13	Kolten Kling	kolten.kling@warmmail.com	Long Beach	California	3158672800839756483	3ff0f02466c299ac20416bd461cdc643	VISA 13 digit	33.7242423733517498	-118.179517318370941
37004	2020-07-13 03:33:49	2020-07-13	Marybelle Block	marybelle.block@geemail.com	Moreno Valley	California	4441490702022179	54c25d123462813d2f813decb3e2281d	JCB 15 digit	34.004243077523256	-117.151850682168075
37005	2020-07-13 03:35:42	2020-07-13	Armani Stamm	armani.stamm@geemail.com	Phoenix	Arizona	3088393949701423579	f1b2f801b5ce832c9ff1e4aeafe36afb	American Express	33.670491476024317	-112.080670962708453
37006	2020-07-13 03:53:53	2020-07-13	Hanson Jaskolski	hanson.jaskolski@geemail.com	Cincinnati	Ohio	869959368329823844	e9a3c524d8f0e6dec98964ffce75039f	JCB 16 digit	39.1567162114426495	-84.5726758979067199
37007	2020-07-13 03:55:14	2020-07-13	Katelynn Kassulke	katelynn.kassulke@geemail.com	Seattle	Washington	869903657674072503	8a1eb0cf64e5c1762a7e2f6a44039d2f	Discover	47.5683819450829191	-122.319874171532319
37008	2020-07-13 04:08:33	2020-07-13	Ms. Lupe Feest DVM	ms.lupe.feest.dvm@geemail.com	Plano	Texas	54151799369785625	7d07ddc796d6dc958bcc99cce6c4639d	VISA 16 digit	32.985215696794171	-96.6958052206966983
37009	2020-07-13 04:23:38	2020-07-13	Todd Littel	todd.littel@woohoo.com	New York	New York	6011075778894167833	6584073747aa37dbba24be6bc0d89d4a	Mastercard	40.6668481893595271	-73.9218845739856363
37010	2020-07-13 04:41:34	2020-07-13	Sunshine Ferry	sunshine.ferry@geemail.com	Sacramento	California	3729242313334539	e8fd6371a69198928748f398b48c9858	Maestro	38.5684329337239262	-121.431358664879937
37011	2020-07-13 04:43:50	2020-07-13	Patrice McGlynn	patrice.mcglynn@geemail.com	Denver	Colorado	54337595132537187	f0eead8d0d868338a7a8e245d1d50956	VISA 13 digit	39.6845322846487107	-104.867833768600974
37012	2020-07-13 04:44:57	2020-07-13	Jaleel Zboncak	jaleel.zboncak@geemail.com	North Las Vegas	Nevada	4300784492355843	f2ef4892d8f2c2324fcc3443b8f3ed1b	JCB 16 digit	36.3756400583002701	-115.069959822831308
37013	2020-07-13 04:45:37	2020-07-13	Omar Douglas-Howe	omar.douglas.howe@geemail.com	Fresno	California	4890665083204183	40f9eea4327c258ac660504ac761561d	Maestro	36.7177047011315807	-119.836614144324884
37014	2020-07-13 04:46:08	2020-07-13	Mrs. Erna Huels MD	mrs.erna.huels.md@warmmail.com	Nashville	Tennessee	3012009799187843	8cce609048740d4bc4d212eb58bbce87	JCB 15 digit	36.1711793193250841	-86.7508924077637431
37015	2020-07-13 05:01:42	2020-07-13	Ms. Janie Abbott MD	ms.janie.abbott.md@woohoo.com	El Paso	Texas	52724977140636337	7188c4f502f3882a83bd6e643f8af42a	VISA 13 digit	31.885945614643024	-106.355273657383407
37016	2020-07-13 05:02:52	2020-07-13	Jayda Okuneva	jayda.okuneva@geemail.com	Pasadena	Texas	4354508980381	6e34f013f964ac88296a54ff0a3a1f99	VISA 13 digit	29.5979263535574084	-95.0655718839675217
37017	2020-07-13 05:22:33	2020-07-13	Santino Watsica	santino.watsica@geemail.com	Hollywood	Florida	4666117500858	31a7e7e8263f40f0bc37c92683810ae5	Mastercard	26.0632348022833469	-80.2189152584228538
37018	2020-07-13 05:24:46	2020-07-13	Okey Larson	okey.larson@geemail.com	Columbia	Missouri	4045786287495	5fd2acd1b871019dea8181ac34029ce3	JCB 16 digit	38.8899180978883621	-92.3780783659831712
37019	2020-07-13 05:34:44	2020-07-13	Lea Gutkowski-Bergstrom	lea.gutkowski.bergstrom@woohoo.com	Columbia	South Carolina	6011243028738913811	f30e988c497cc3abdd641c3e38e6ee55	VISA 16 digit	33.9752863637436207	-80.9122288805451149
37020	2020-07-13 05:36:59	2020-07-13	Dr. Carma Brakus PhD	dr.carma.brakus.phd@geemail.com	Fullerton	California	4744732888378873	409ad369c2bc09738e4a55fc5482f6e0	JCB 16 digit	33.8013579500995576	-117.868758795756847
37021	2020-07-13 05:44:21	2020-07-13	Chaney Graham-Yost	chaney.graham.yost@warmmail.com	Hialeah	Florida	3528629292407735863	85bce8bb3328d3751d66b0087d74e18e	Voyager	25.8120999143436549	-80.2152650039080442
37022	2020-07-13 05:49:11	2020-07-13	Collie Balistreri I	collie.balistreri.i@geemail.com	Stockton	California	4416335837275286	ccd138b36ba365c1c6a3244e8e5dc42e	VISA 13 digit	37.9386027525376548	-121.363686859849096
37023	2020-07-13 05:51:24	2020-07-13	Isai Pfannerstill-Ernser	isai.pfannerstill.ernser@geemail.com	Albuquerque	New Mexico	180088583078606324	f091fe845ac8dcd3ed2d9eb37ebdabf0	Voyager	35.1798228913120923	-106.564563455346601
37024	2020-07-13 05:57:35	2020-07-13	Vinson Becker	vinson.becker@woohoo.com	Cary	North Carolina	869996096962759455	24288c77337de573ebac8a666a41a45b	American Express	35.8716338878139851	-78.909637304217739
37025	2020-07-13 06:03:34	2020-07-13	Dr. Icie Kshlerin	dr.icie.kshlerin@geemail.com	Buffalo	New York	3088697778563459386	2a2dc50d3e2ae06193d016caca33010b	VISA 13 digit	42.9660922061372545	-78.9502555192846813
37026	2020-07-13 06:03:46	2020-07-13	Bridgette Dietrich-Runolfsdottir	bridgette.dietrich.runolfsdottir@warmmail.com	Norman	Oklahoma	3088967537488521206	3ccdca5dac89cead84d2ad41b1ae932d	JCB 16 digit	35.1845009390305705	-97.2697801348540878
37027	2020-07-13 06:25:39	2020-07-13	Jocelyn Morissette	jocelyn.morissette@geemail.com	Chicago	Illinois	3096886060872409704	1849f50fa2c727bd0ca7333c95191cd7	Diners Club / Carte Blanche	41.7466667099226285	-87.7556676122389661
37028	2020-07-13 06:33:10	2020-07-13	Kaylie Kutch	kaylie.kutch@geemail.com	Norfolk	Virginia	6011977278343787934	66fd3f75ab4f6771f1fed4b3651e6ac6	Voyager	36.99274280248396	-76.2001714601650946
37029	2020-07-13 06:35:32	2020-07-13	Dr. Kaitlyn Von	dr.kaitlyn.von@woohoo.com	Chicago	Illinois	3158839885807580916	3c50ed1395f61968f7f8563ecba485f3	American Express	41.937256050652266	-87.7084702508553846
37030	2020-07-13 06:48:31	2020-07-13	Mr. Hence Leffler	mr.hence.leffler@geemail.com	Oklahoma City	Oklahoma	869956302887551615	25d17c5754295252272530782d2f1384	VISA 13 digit	35.4730889441821731	-97.5915604850172969
37031	2020-07-13 06:51:54	2020-07-13	Sterling Herman-Bergstrom	sterling.herman.bergstrom@warmmail.com	Port St. Lucie	Florida	6011358889716181247	051404d32c957f465a1368491fcd3293	VISA 16 digit	27.2631427038129424	-80.3321798348419378
37032	2020-07-13 06:58:48	2020-07-13	Dr. Littleton Lueilwitz Sr.	dr.littleton.lueilwitz.sr.@geemail.com	Houston	Texas	4885727001448792	6274f4c9878c0c7d62eee7cd185b25a7	Discover	29.8039178153112516	-95.3147744173198959
37033	2020-07-13 07:00:14	2020-07-13	Esker Lueilwitz II	esker.lueilwitz.ii@geemail.com	New York	New York	6011353849901928278	688c67881d5240a2e70738456760908c	VISA 13 digit	40.6822031050212658	-73.8649656205333685
37034	2020-07-13 07:07:34	2020-07-13	Manly Krajcik	manly.krajcik@geemail.com	Worcester	Massachusetts	869929153108579628	4328c7c56c956fa8b1a951a9931a4686	VISA 16 digit	42.3455541861876839	-71.7657961769282764
37035	2020-07-13 07:09:24	2020-07-13	Mr. Red Nicolas I	mr.red.nicolas.i@geemail.com	Pompano Beach	Florida	3158120150679314052	c9a43a0c1c6c58393d2577f987dce167	VISA 16 digit	26.2226901083983464	-80.0752392841350229
37036	2020-07-13 07:23:17	2020-07-13	Helen Raynor	helen.raynor@geemail.com	Albuquerque	New Mexico	3052981830300827	0b1a7bcc93e31d214849897517655d22	JCB 16 digit	35.0972074583306934	-106.654095249071347
37037	2020-07-13 07:32:04	2020-07-13	Mr. Dorsey Rowe	mr.dorsey.rowe@geemail.com	Fort Worth	Texas	210085497351984584	905f3e6684b58381ea16cab91e230e9c	Maestro	32.7605595926344435	-97.3781294218085662
37038	2020-07-13 07:36:41	2020-07-13	Teri Berge	teri.berge@geemail.com	Inglewood	California	3003839719168898	5de36acf277cde5e18b8abc7c5933d65	Diners Club / Carte Blanche	33.8934205181211254	-118.331325955691938
37039	2020-07-13 07:40:04	2020-07-13	Shaylee Dooley	shaylee.dooley@woohoo.com	Las Cruces	New Mexico	3444773870936861	cd6df602472a77c99b148e41f7b81d27	JCB 15 digit	32.4209280359126595	-106.882018739974868
37040	2020-07-13 07:46:20	2020-07-13	Desi Rosenbaum	desi.rosenbaum@woohoo.com	Chicago	Illinois	3794651837212007	d9bf336d6a2b51e8d28feba6f5a62b13	Maestro	41.7746437557809074	-87.7215826199885385
37041	2020-07-13 07:58:22	2020-07-13	Miss Ashlee Greenfelder PhD	miss.ashlee.greenfelder.phd@geemail.com	Los Angeles	California	3044448523632625	42c7d35d38b87240c7dfd2fa5626f632	Maestro	34.0868242770764951	-118.456327562452472
37042	2020-07-13 08:04:40	2020-07-13	Ottie Gerlach Jr.	ottie.gerlach.jr.@geemail.com	Coral Springs	Florida	869993478702347929	198447e7fff24d1c6d10fb1aa0b8adcd	VISA 16 digit	26.256619216414915	-80.3191631934262773
37043	2020-07-13 08:14:35	2020-07-13	Brittaney Bruen	brittaney.bruen@geemail.com	Greensboro	North Carolina	3006873273033757	e49fcc05b3dbad40af994c1a950bd7d3	JCB 15 digit	36.173763806244736	-79.8311382940951688
37044	2020-07-13 08:24:16	2020-07-13	Kymani Ziemann Sr.	kymani.ziemann.sr.@woohoo.com	Louisville	Kentucky	6011539806162705412	3618c05a4827047361278980e0e6e7d3	JCB 16 digit	38.0849915031246837	-85.6303585510771796
37045	2020-07-13 08:25:12	2020-07-13	Ramiro Bartell	ramiro.bartell@geemail.com	New York	New York	4892765152234448	0ae802830ecade4fe1685d463dbddc0c	JCB 16 digit	40.6855734427217399	-73.9701864311832935
37046	2020-07-13 08:32:50	2020-07-13	Laurine Simonis-Rice	laurine.simonis.rice@woohoo.com	New Orleans	Louisiana	6011125278126202318	a4552c821b952582462f878470350372	VISA 13 digit	30.0973549442380666	-89.8473474046941902
37047	2020-07-13 08:39:52	2020-07-13	Marlyn Quigley-Blanda	marlyn.quigley.blanda@woohoo.com	Fairfield	California	3492442027499774	a9d7068391976da6d1243c39e4d334d3	Diners Club / Carte Blanche	38.1884091908700825	-122.027878339263054
37048	2020-07-13 08:49:47	2020-07-13	Ricki Kshlerin	ricki.kshlerin@geemail.com	Miami Gardens	Florida	4122590907396504	39ae5a7ce37cb85d53189c71d9a8acdd	VISA 16 digit	26.0287046684823906	-80.254816322099785
37049	2020-07-13 08:57:53	2020-07-13	Darien Osinski	darien.osinski@woohoo.com	New York	New York	51239744129332124	33f14309d473db88dc38224dc5c49a77	Mastercard	40.7606345462370641	-73.8848153873708071
37050	2020-07-13 09:04:28	2020-07-13	Ryann Hegmann	ryann.hegmann@geemail.com	Grand Rapids	Michigan	180043265912677539	fcee565fcf33afd41c6ece96c6940c81	Maestro	43.0501440633822199	-85.5961348216183495
37051	2020-07-13 09:23:24	2020-07-13	Keanu Jones	keanu.jones@woohoo.com	Stockton	California	210068957790514798	a1d55f7f6d4cf972b11d6ba2c53e4e2b	Mastercard	38.0244614525895557	-121.378035701633621
37052	2020-07-13 09:48:32	2020-07-13	Leatha Mayer	leatha.mayer@warmmail.com	Westminster	Colorado	180032805556553497	c7e8f79ef892e48592fdd56c49783c6d	JCB 16 digit	39.809783455434065	-105.053860300002256
37053	2020-07-13 10:00:43	2020-07-13	Jaycie Murazik	jaycie.murazik@geemail.com	Santa Ana	California	180020801709291337	1532ab7cd91d45c360eba96cb4047b4c	Voyager	33.7383672666840226	-117.955087797336276
37054	2020-07-13 10:09:44	2020-07-13	Davie Dicki	davie.dicki@geemail.com	New York	New York	3096895185200806443	ba65bcf6c31acae543255170012832a4	VISA 16 digit	40.7184328424036508	-73.9071573975391658
37055	2020-07-13 10:12:31	2020-07-13	Maddux Treutel	maddux.treutel@geemail.com	Los Angeles	California	4845323937766116	344bb2f18c909dc2792fca798e13c879	JCB 16 digit	34.0578552007075359	-118.393230569455028
37056	2020-07-13 10:14:31	2020-07-13	Azzie Pouros	azzie.pouros@geemail.com	San Francisco	California	3112652568692233007	981aef1bbffde7baca5912eef19f2878	Diners Club / Carte Blanche	37.7896356656444468	-122.448820684662607
37057	2020-07-13 10:25:59	2020-07-13	Elna Schimmel	elna.schimmel@geemail.com	Arvada	Colorado	869946088456643809	762ce39b5198845222d235214ee1a457	VISA 16 digit	39.7653497109364693	-105.177652381683885
37058	2020-07-13 10:27:06	2020-07-13	Ms. Laquita Nitzsche	ms.laquita.nitzsche@geemail.com	Vallejo	California	3096255761907511728	663c60733b32be750ec9d211410d25ab	JCB 16 digit	38.0747707068543875	-122.260102191973473
37059	2020-07-13 10:29:02	2020-07-13	Ms. Buelah Wilderman DDS	ms.buelah.wilderman.dds@geemail.com	League City	Texas	51334404374199108	5e8539250cb2adfe05335b6b90134c2f	Discover	29.5549754154332014	-95.184135280641172
37060	2020-07-13 10:29:19	2020-07-13	Mr. Wellington Larkin PhD	mr.wellington.larkin.phd@geemail.com	Fairfield	California	51188276319175964	7165a088097fa16eae7874b4af6500f0	Mastercard	38.194688495028025	-121.975182167813557
37061	2020-07-13 10:33:05	2020-07-13	Mr. Fabian Krajcik	mr.fabian.krajcik@geemail.com	San Francisco	California	3040580205023501	21ac2b8f383a6ba33bfae150e417dc39	American Express	37.7671517314964902	-122.436553098008403
37062	2020-07-13 10:38:11	2020-07-13	Mrs. Mahala Kihn MD	mrs.mahala.kihn.md@woohoo.com	Hialeah	Florida	3052706604819516	63c114e25f4cbb677a3b541812b6118e	Voyager	25.8486790354341274	-80.3358332632012662
37063	2020-07-13 10:49:13	2020-07-13	Allie White PhD	allie.white.phd@geemail.com	Virginia Beach	Virginia	210018730030052064	b65e08d867b80d59ef64ea19443b7f4e	Mastercard	36.8700028851814565	-76.0082524597316933
37064	2020-07-13 10:52:26	2020-07-13	Kiley Baumbach MD	kiley.baumbach.md@geemail.com	Oklahoma City	Oklahoma	210044186941791795	7dc68226db9814b0f33d186dade809ce	JCB 15 digit	35.5519175221588455	-97.4819992622721969
37065	2020-07-13 11:01:05	2020-07-13	Cary Wolf	cary.wolf@geemail.com	Los Angeles	California	4201766159566994	0140aa5b9ae320cff32815e77347ef28	Diners Club / Carte Blanche	34.1001593209668954	-118.5026195282109
37066	2020-07-13 11:08:35	2020-07-13	Dr. Darl Goyette DDS	dr.darl.goyette.dds@geemail.com	Albuquerque	New Mexico	630463244383616	aff590701294a01f02e2d51b7ec34ef3	Discover	35.1487964585091959	-106.560220837041371
37067	2020-07-13 11:13:56	2020-07-13	Mrs. Edla Cruickshank MD	mrs.edla.cruickshank.md@woohoo.com	San Francisco	California	869914712200444036	c5bf154ed5be21c8f826c87f6e685db9	Voyager	37.7962614558300487	-122.397975021082843
37068	2020-07-13 11:21:53	2020-07-13	Festus O'Connell	festus.o'connell@geemail.com	Chandler	Arizona	3088992166632371331	0e3736dad068457831bb7605d911f2ab	VISA 13 digit	33.3257280567750342	-111.882340820727492
37069	2020-07-13 11:23:44	2020-07-13	Farah Turcotte-Green	farah.turcotte.green@geemail.com	Oklahoma City	Oklahoma	3737553875591708	b73cdd7ca42366dc7a4a49d1a7220094	Diners Club / Carte Blanche	35.3883379442527897	-97.5916354441910983
37070	2020-07-13 11:24:11	2020-07-13	Vikki Koelpin PhD	vikki.koelpin.phd@geemail.com	Oakland	California	4495565353788	182aeac3ca8d61e732bdb14d28cf74aa	Diners Club / Carte Blanche	37.7748148026779162	-122.267311095957567
37071	2020-07-13 11:25:23	2020-07-13	Juliana Morar DDS	juliana.morar.dds@geemail.com	Arlington	Texas	869929593311344445	c9f0be08d09ac383d3c4d58e12f7b268	Mastercard	32.6690324930723719	-97.1426095979779944
37072	2020-07-13 11:25:41	2020-07-13	Kordell Wisozk	kordell.wisozk@geemail.com	Chesapeake	Virginia	4737566982622	b203a335867a7e993c10d5f8bab5ea9c	Mastercard	36.6196307936921741	-76.3130315280362908
37073	2020-07-13 11:26:28	2020-07-13	Wayne Macejkovic	wayne.macejkovic@woohoo.com	New York	New York	639032766168697	6a1dfafa74b1658799bac25d0238ebdc	Maestro	40.6156511892322456	-73.8763873894128977
37074	2020-07-13 11:33:18	2020-07-13	Theophile Volkman	theophile.volkman@geemail.com	Chicago	Illinois	210017270889946927	ec0e1d56e13b92b4e725693fd72b7846	American Express	41.7607386413797741	-87.586907328156002
37075	2020-07-13 11:35:20	2020-07-13	Dr. Branch Emard	dr.branch.emard@warmmail.com	Tampa	Florida	4911731206528	81e1b81360889ffc420ee6b253da9b0b	Maestro	28.0396171455852681	-82.3853700896937369
37076	2020-07-13 11:37:48	2020-07-13	Duff Lockman IV	duff.lockman.iv@geemail.com	Temecula	California	3029416594712423	cfdf73a3fc199b69a1eff004cc175198	Diners Club / Carte Blanche	33.5833869344223288	-117.108116990999122
37077	2020-07-13 11:38:55	2020-07-13	Mrs. Wava Hamill DDS	mrs.wava.hamill.dds@geemail.com	San Francisco	California	502084539637607	f278aa66d8599b2d34de52789c5a56c3	VISA 16 digit	37.7835343217874779	-122.451597853583479
37078	2020-07-13 11:50:25	2020-07-13	Ms. Kiara Hermann	ms.kiara.hermann@warmmail.com	San Francisco	California	210049429239516192	ebf9fad7a41435d49704743424688db4	VISA 13 digit	37.7665403582312109	-122.384871650060774
37079	2020-07-13 12:07:16	2020-07-13	Kristian Walsh	kristian.walsh@geemail.com	New York	New York	210077488133351895	d411a3cfe0be0f4e19f1879a244082f5	VISA 16 digit	40.744784246640279	-74.0023914847418638
37080	2020-07-13 12:19:45	2020-07-13	Sharyl Jenkins	sharyl.jenkins@woohoo.com	Chesapeake	Virginia	6011319290207421721	0f4512a16d20dd0bbcbc1e998e1da973	Discover	36.6397453464806091	-76.2145597786020517
37081	2020-07-13 12:22:13	2020-07-13	Dr. Sebrina Hessel	dr.sebrina.hessel@woohoo.com	Rockford	Illinois	3002109979395537	3ad509fcc4097ceaa49cbad1e0506d5f	VISA 16 digit	42.3501921807426953	-89.0387763185243983
37082	2020-07-13 12:36:34	2020-07-13	Darlene Hyatt	darlene.hyatt@geemail.com	Dallas	Texas	3088193105050109408	0e8b80040e7056dd1f689138daa56927	Voyager	32.8897302345644675	-96.7301520372703578
37083	2020-07-13 12:42:43	2020-07-13	Ole Kris	ole.kris@geemail.com	Oakland	California	3112039881894704475	f4a466cf355230639efd3a8259bb7ee7	VISA 16 digit	37.7845663770035642	-122.267087622742096
37084	2020-07-13 12:45:41	2020-07-13	Adrienne Lakin	adrienne.lakin@geemail.com	Oakland	California	4801089296118163	0b7ecffecc1ad6e51620b0247ea3d102	VISA 13 digit	37.7681729677536993	-122.246748356402406
37085	2020-07-13 13:04:28	2020-07-13	Misael Senger	misael.senger@geemail.com	San Francisco	California	4023236184501560	ef83af1708e3664ce01f37c19a9b81ff	American Express	37.7808390021631268	-122.440053100592678
37086	2020-07-13 13:04:33	2020-07-13	Mr. Neil Barrows	mr.neil.barrows@geemail.com	Charlotte	North Carolina	3158766733023834146	7249e837c11843ecff781721ddc9388d	Voyager	35.2603218563154357	-80.7677489655036567
37087	2020-07-13 13:05:56	2020-07-13	Metro O'Conner	metro.o'conner@geemail.com	Richardson	Texas	210060984249525785	44f84326a08854cc08b34516f3ae1ca2	Mastercard	32.977839335403587	-96.7430272698629636
37088	2020-07-13 13:14:39	2020-07-13	Dr. Tremayne Boyer DVM	dr.tremayne.boyer.dvm@woohoo.com	Omaha	Nebraska	676210939827704	35a838a02a902d5acfc6e82654c493ea	JCB 15 digit	41.2566656118404111	-95.9520080604240349
37089	2020-07-13 13:15:32	2020-07-13	Neola Miller	neola.miller@geemail.com	San Francisco	California	3158720969072656908	1da236c8152aee1f24e7f53ba64ffc19	JCB 15 digit	37.7546718264644809	-122.424771186357717
37090	2020-07-13 13:15:35	2020-07-13	Dr. Unnamed Johnson IV	dr.unnamed.johnson.iv@geemail.com	Philadelphia	Pennsylvania	210007616091495826	2a5efbab986a34351a5232c0f6410eaa	Mastercard	40.0729917038191132	-75.090832439846551
37091	2020-07-13 13:25:11	2020-07-13	Axel Crist	axel.crist@geemail.com	Lubbock	Texas	4175014946016	02677cd7d3ac5fc94fc972dbec5bd30c	Mastercard	33.6542326951906148	-101.958834523978467
37092	2020-07-13 13:33:22	2020-07-13	Juston Dicki	juston.dicki@geemail.com	Oakland	California	3035817813929488	99e77e716be08e7a340a3f5c6626170c	VISA 13 digit	37.8267346313726662	-122.268411150544196
37093	2020-07-13 13:40:57	2020-07-13	Mr. Orley Homenick DVM	mr.orley.homenick.dvm@woohoo.com	Fairfield	California	53518878761531072	70a7c5a1e90ac0cd55fbaf50884e0a9e	American Express	38.2997304814059305	-122.049065080332014
37094	2020-07-13 13:46:57	2020-07-13	Dr. Noreen Crist	dr.noreen.crist@geemail.com	Norman	Oklahoma	6011690766430908682	d43d20ed48817a9aecb7d95d502c5b78	Maestro	35.2586396279320127	-97.3110638289034284
37095	2020-07-13 14:04:25	2020-07-13	Patrica Terry DVM	patrica.terry.dvm@geemail.com	San Francisco	California	4723409982761719	34b56aa7271ecf630d4548ab479c918e	Discover	37.7516548343963478	-122.44417778651777
37096	2020-07-13 14:06:46	2020-07-13	Mr. Gerardo Hilll	mr.gerardo.hilll@geemail.com	Philadelphia	Pennsylvania	210077221695780593	d56ee2b74124d07ad628287d22590d4b	Diners Club / Carte Blanche	39.9548497590195382	-75.1520054153066184
37097	2020-07-13 14:08:23	2020-07-13	Dominic Kozey	dominic.kozey@geemail.com	Oakland	California	4572336451907790	32a62e98097f8ba6564602b61cc885c3	Maestro	37.8169887700723635	-122.303793978288525
37098	2020-07-13 14:19:20	2020-07-13	Travon Kessler	travon.kessler@geemail.com	Phoenix	Arizona	4394197059105	900b844af735800a1eb6c29c6705e64e	American Express	33.5854463965564989	-112.036080984298522
37099	2020-07-13 14:19:53	2020-07-13	Mr. Tavian Daniel	mr.tavian.daniel@warmmail.com	Berkeley	California	3112563522718182290	a6082bb826b431ed7982a323a3ec5f06	Voyager	37.8589427878158702	-122.279100052681528
37100	2020-07-13 14:37:09	2020-07-13	Burke Waelchi	burke.waelchi@geemail.com	Vacaville	California	4245842734386444	b3c84b9877bd1bc95c4727f1b817ed19	JCB 16 digit	38.406785503228754	-122.057647430232919
37101	2020-07-13 14:40:41	2020-07-13	Ashely Smitham	ashely.smitham@geemail.com	Spokane	Washington	4565578617666187	578e30a9f423c54f5c97f9eee0b55635	American Express	47.6120946120709192	-117.381513703138751
37102	2020-07-13 14:40:50	2020-07-13	Miss Georgiann Zulauf PhD	miss.georgiann.zulauf.phd@woohoo.com	Denver	Colorado	180029458611868941	1294d0c0316d2e6722425e0d3037903c	VISA 13 digit	39.7936989801987977	-104.891488203803448
37103	2020-07-13 14:53:21	2020-07-13	Chastity Grady	chastity.grady@warmmail.com	Boston	Massachusetts	3042130501160082	82f30b3e29eb2b5073cf29c07b022127	VISA 13 digit	42.2332468116357944	-70.9643468118224376
37104	2020-07-13 14:57:55	2020-07-13	Dr. Elbridge Williamson DVM	dr.elbridge.williamson.dvm@warmmail.com	Louisville	Kentucky	180012330730674642	2273c4b7a0584df84b9dc51d418bc0f5	JCB 15 digit	38.1147582356255512	-85.6305634773407149
37105	2020-07-13 14:58:54	2020-07-13	Jimmy Deckow-Russel	jimmy.deckow.russel@geemail.com	Los Angeles	California	869944936424196569	7868fdfa75ba789ebd546a9c696f06e8	VISA 16 digit	33.995635858863217	-118.463190396874396
37106	2020-07-13 15:03:44	2020-07-13	Maryjo Lueilwitz	maryjo.lueilwitz@geemail.com	Omaha	Nebraska	4072953817603593	a2b73e75cbf3e1d4a9066fe5dcff33be	Diners Club / Carte Blanche	41.3350252983305637	-96.0680183652903992
37107	2020-07-13 15:06:47	2020-07-13	Harland Rempel DDS	harland.rempel.dds@warmmail.com	St. Petersburg	Florida	639086217618007	dcf587e86d8ef9c0e76ec2011e8c4a61	JCB 16 digit	27.7653381056506205	-82.623894445587311
37108	2020-07-13 15:15:25	2020-07-13	Rhiannon Streich	rhiannon.streich@geemail.com	Fort Worth	Texas	6011343504914348765	03fcde3f2d692a9ab825dd4701a1c0b2	VISA 16 digit	32.8477167819682521	-97.3460980410974486
37109	2020-07-13 15:27:15	2020-07-13	Ms. Tamra Torp	ms.tamra.torp@geemail.com	Chicago	Illinois	4048294392297001	e1c044f3b46965c7c80f2a4ae9d2e313	VISA 13 digit	41.8909061712048967	-87.7735777117341769
37110	2020-07-13 15:29:32	2020-07-13	Casey Blick	casey.blick@geemail.com	Austin	Texas	6011342579041352170	9d37779ae055beb12bb1c74e34eb7b66	Maestro	30.2354972974989558	-97.7047071732353487
37111	2020-07-13 15:32:53	2020-07-13	Dr. Lindbergh Howell	dr.lindbergh.howell@geemail.com	Boston	Massachusetts	3088059872325727834	5dcd8f567434e8c5fc7f781cfc727a0b	Maestro	42.2427530746143347	-71.021761589352792
37112	2020-07-13 15:36:15	2020-07-13	Dr. Mariah Paucek	dr.mariah.paucek@warmmail.com	Las Cruces	New Mexico	589337079598761	024f5df649ddb495b40a0635a89ecdc5	Discover	32.3628183797501023	-106.833009158179905
37113	2020-07-13 15:40:09	2020-07-13	Aryanna Hackett	aryanna.hackett@geemail.com	Chicago	Illinois	869903843838183051	541a25f718f8241887495ec090637f00	JCB 15 digit	41.8613759918440138	-87.6548345881078319
37114	2020-07-13 15:40:46	2020-07-13	Miss Orrie Satterfield	miss.orrie.satterfield@geemail.com	Rialto	California	3528889546893300416	6efd5a5a1d8aeb1e29eed9a00401dd04	JCB 15 digit	34.0398025806278	-117.45730954144075
37115	2020-07-13 15:49:46	2020-07-13	Jaylyn Harris	jaylyn.harris@woohoo.com	Fairfield	California	3158257901822531256	0edc55de0d3f581967987f1cf13f10d1	JCB 16 digit	38.3009278382763299	-121.981599151343474
37116	2020-07-13 15:52:51	2020-07-13	Henri Towne MD	henri.towne.md@geemail.com	Los Angeles	California	6011685561543400447	ddd13070106533bd55fbf4f20909a614	Discover	33.9234459603071201	-118.498271042526881
37117	2020-07-13 15:59:55	2020-07-13	Scarlett Russel-Daugherty	scarlett.russel.daugherty@woohoo.com	Corona	California	4386691564242	6bc9209fe6355c8bd9154f2a7ca78563	VISA 16 digit	33.8719553134292397	-117.530292350819337
37118	2020-07-13 16:00:36	2020-07-13	Dr. Kamari McKenzie	dr.kamari.mckenzie@geemail.com	Austin	Texas	4638948596545707	2e7be650b77a2b2c9ba7d41b88ef7d06	Diners Club / Carte Blanche	30.3142522371500718	-97.6870051118783636
37119	2020-07-13 16:00:54	2020-07-13	Neoma Bergstrom DVM	neoma.bergstrom.dvm@geemail.com	Torrance	California	55438697773588038	2b53fed10590c542d0e0e7b285f8ffae	American Express	33.8778556744940573	-118.427978514985739
37120	2020-07-13 16:08:52	2020-07-13	Lisa Tillman	lisa.tillman@woohoo.com	Greensboro	North Carolina	3770023122249912	5fae85dd8b19071b49f76eaf3abb5979	JCB 16 digit	36.1840754907693736	-79.8415398796535953
37121	2020-07-13 16:19:24	2020-07-13	Briana Rodriguez	briana.rodriguez@geemail.com	Los Angeles	California	4444262088354	7fa2bfeb39d42059d1cd697348231969	American Express	33.9438418471585948	-118.436349934664733
37122	2020-07-13 16:19:39	2020-07-13	Axel Brekke	axel.brekke@warmmail.com	Wichita Falls	Texas	4910491816088	ff05d715ffab96e52c73924f40aa5a13	VISA 16 digit	33.956580586285142	-98.4742528286684262
37123	2020-07-13 16:28:00	2020-07-13	Billye Glover	billye.glover@geemail.com	San Antonio	Texas	3158576689097587269	ab581d3267900136426d1e2731c595b2	Mastercard	29.4669475159678598	-98.4696372735615739
37124	2020-07-13 16:28:03	2020-07-13	Miss Loretta DuBuque DDS	miss.loretta.dubuque.dds@geemail.com	Norfolk	Virginia	6011968124205839911	bb4610955a5bdec812e08a84e43ddef2	JCB 16 digit	36.9004921770207588	-76.2718174736484968
37125	2020-07-13 16:36:03	2020-07-13	Haven Howell	haven.howell@geemail.com	Lancaster	California	3707511293407291	dab9a0887df743c557ecd6a2c2755551	Diners Club / Carte Blanche	34.5959388267494745	-118.084856813770898
37126	2020-07-13 16:36:03	2020-07-13	Dr. Darin Hahn	dr.darin.hahn@geemail.com	Des Moines	Iowa	3458041671372212	e9f3d33a2e540efc281b5a3410cb4820	Diners Club / Carte Blanche	41.5314176558259902	-93.6316844068978043
37127	2020-07-13 16:40:22	2020-07-13	Bayard Beer	bayard.beer@geemail.com	Chicago	Illinois	4541420031777853	99363fdbe8670e94d7496b844e3ef2ea	VISA 13 digit	41.8937834292020668	-87.6780219156790537
37128	2020-07-13 16:46:54	2020-07-13	Odell Keeling Jr.	odell.keeling.jr.@warmmail.com	Philadelphia	Pennsylvania	4422172022162835	2065882ff9725675765af963929cc484	American Express	40.0144925151444966	-75.115069879022613
37129	2020-07-13 16:47:12	2020-07-13	Dr. Candice Smith	dr.candice.smith@geemail.com	Tempe	Arizona	4774207668840304	19515b9cb6dd83039fcb5ae49f485f5c	American Express	33.3301400352656785	-111.970273333977161
37130	2020-07-13 17:01:07	2020-07-13	Randolph Dicki III	randolph.dicki.iii@geemail.com	Berkeley	California	6011026847791386075	19e3c9e1d20e986a7975a2a3ac623dd6	Discover	37.8462094370777535	-122.293725806968411
37131	2020-07-13 17:08:20	2020-07-13	Ms. Lesta Hickle DDS	ms.lesta.hickle.dds@geemail.com	Dallas	Texas	3752615387636592	93b71c79dbac30e96ef0c429553eecba	JCB 15 digit	32.7886566848766066	-96.7907121691349772
37132	2020-07-13 17:32:58	2020-07-13	Alto Price I	alto.price.i@geemail.com	Irvine	California	3088522845758992058	d7b58c658727fc10e30667699abe929e	Mastercard	33.7101403302993674	-117.845127065806835
37133	2020-07-13 17:37:40	2020-07-13	Posey Witting	posey.witting@warmmail.com	New York	New York	676109661530833	baa90647a2749f41d0931e374035f5e6	VISA 16 digit	40.6351973571572458	-73.8701917828421983
37134	2020-07-13 17:48:35	2020-07-13	Johnie Von DVM	johnie.von.dvm@geemail.com	Wichita	Kansas	3012535084677007	dd344d36525ed1d4ccb6b1a1d31c3cfe	Maestro	37.7164128650322539	-97.3240481102574648
37135	2020-07-13 17:49:01	2020-07-13	Marlen Wolf-Lueilwitz	marlen.wolf.lueilwitz@woohoo.com	San Antonio	Texas	3096809163261305469	dc9cd3dfedae3b0f358a4aef24e99db3	Voyager	29.4852119968343516	-98.567088277481858
37136	2020-07-13 18:04:33	2020-07-13	Bettylou Luettgen	bettylou.luettgen@geemail.com	Lansing	Michigan	180071322288800347	0b0d884e781d7ff7a5bd3c2ab8002b3f	Diners Club / Carte Blanche	42.6262119093287737	-84.61361784139946
37137	2020-07-13 18:05:20	2020-07-13	Mrs. Rennie Ullrich	mrs.rennie.ullrich@geemail.com	Temecula	California	676296041496967	327dac5485ae196d41e62b8266edf842	Discover	33.5660934209026394	-117.096547668539728
37138	2020-07-13 18:12:32	2020-07-13	Santiago Hoppe-Reichert	santiago.hoppe.reichert@geemail.com	San Francisco	California	3528868705061068446	49dfbba30372bc3825601903b7a77017	Diners Club / Carte Blanche	37.7490338830282681	-122.402584526667184
37139	2020-07-13 18:19:00	2020-07-13	Vernelle Farrell	vernelle.farrell@geemail.com	San Antonio	Texas	3736345427201139	04abf915d85a85e56cff2832684130c6	VISA 16 digit	29.5174859360396873	-98.4923476809006075
37140	2020-07-13 18:20:49	2020-07-13	Dr. Redmond McCullough I	dr.redmond.mccullough.i@geemail.com	Las Vegas	Nevada	53464050854303819	8a99486ca07f2556204d73c1332a84e5	Voyager	36.1800793056942496	-115.27952691663279
37141	2020-07-13 18:28:38	2020-07-13	Columbia Hoppe	columbia.hoppe@geemail.com	Orange	California	6011148924730730193	aa4a64b41563863276a0353f5fe836f2	VISA 16 digit	33.7937473377566775	-117.94029150452576
37142	2020-07-13 18:34:15	2020-07-13	Ronaldo Schumm	ronaldo.schumm@woohoo.com	San Francisco	California	060431818356060	485ed4bcd72446ff022a61a6a0b1e2a6	Discover	37.7423348017997782	-122.412481544414476
37143	2020-07-13 18:48:33	2020-07-13	Sanjuanita Mante	sanjuanita.mante@geemail.com	Chesapeake	Virginia	3010215377096932	a6dd43e2c25d054c8b63d4384c90fdae	VISA 16 digit	36.5865006407029938	-76.3846305759932847
37144	2020-07-13 18:49:24	2020-07-13	Octave Herman	octave.herman@geemail.com	Phoenix	Arizona	4059999335355	d6a086a7a52a3948a79ba74503c833f6	Voyager	33.4962912149660283	-112.186991729347412
37145	2020-07-13 18:49:35	2020-07-13	Jennie Carroll-Shanahan	jennie.carroll.shanahan@geemail.com	Houston	Texas	3158336738272262668	b7fd5f32ade0b3b979cf3dbecceff22a	Voyager	29.7021748378951109	-95.3072443809375187
37146	2020-07-13 18:56:20	2020-07-13	Erla Kshlerin	erla.kshlerin@woohoo.com	Boston	Massachusetts	180048599328616094	f3966bcda5edae0a18008c6730293c92	JCB 16 digit	42.3517504138574026	-70.9275466348461805
37147	2020-07-13 19:01:34	2020-07-13	Julisa Runolfsson	julisa.runolfsson@warmmail.com	Baton Rouge	Louisiana	3112664822012168732	acce997d5f300ea2378633874d54f149	VISA 13 digit	30.522113177527487	-91.1866589648757042
37148	2020-07-13 19:01:38	2020-07-13	Veola Satterfield	veola.satterfield@geemail.com	San Francisco	California	180083022054118611	93f4f5ea26d1722cf3c2f9546a6f659a	JCB 15 digit	37.8057635890556298	-122.46059792962447
37149	2020-07-13 19:07:35	2020-07-13	Manford Fahey V	manford.fahey.v@geemail.com	St. Petersburg	Florida	210081753233300256	2bf143103ad37e43f997d41f567302ba	American Express	27.7955124456323688	-82.7327335207149304
37150	2020-07-13 19:13:22	2020-07-13	Elinore Witting-Hickle	elinore.witting.hickle@geemail.com	San Francisco	California	3337153213509926139	1792c40d642d73b07e036990d31dd27b	JCB 15 digit	37.7508644066956052	-122.437255965101684
37151	2020-07-13 19:22:18	2020-07-13	Kelley Welch-Oberbrunner	kelley.welch.oberbrunner@woohoo.com	Buffalo	New York	3058400069389579	6e8ad7f62185c6b570bdf65bfee71efb	JCB 15 digit	42.9095109090395255	-78.9423060362625932
37152	2020-07-13 19:27:13	2020-07-13	Mrs. Marcella Emard	mrs.marcella.emard@woohoo.com	San Diego	California	4291479890548	e25f4da39770dcd3b0b55556ae4e208e	VISA 16 digit	32.8215148716300718	-117.128669048137965
37153	2020-07-13 19:31:37	2020-07-13	Sharde Gutkowski	sharde.gutkowski@woohoo.com	West Palm Beach	Florida	4914197736126839	a02df91606747edb225a5ff8c9b279b3	JCB 15 digit	26.8060499880310168	-80.1115106707740665
37154	2020-07-13 19:39:05	2020-07-13	Dr. Kasey Ernser	dr.kasey.ernser@geemail.com	Ontario	California	3528638005260482731	85eac89491376de380f17346e0dff77f	Voyager	34.094494522284343	-117.5487031454321
37155	2020-07-13 19:41:26	2020-07-13	Mcarthur Kunde	mcarthur.kunde@geemail.com	San Francisco	California	3017396387312114	ce31ec840b575d8a9bd0050149c866f6	JCB 16 digit	37.751156943008553	-122.439559825773173
37156	2020-07-13 19:53:35	2020-07-13	Miss Lanette Conroy PhD	miss.lanette.conroy.phd@geemail.com	Chicago	Illinois	3030579386269446	55bd36df081c0ffb64777fbfe56713b8	JCB 16 digit	41.8550598516896386	-87.64141161428131
37157	2020-07-13 20:05:53	2020-07-13	Shane Block DVM	shane.block.dvm@geemail.com	Akron	Ohio	3088697366278834125	de758353984743dc0c09a00da4f701fe	Voyager	41.0077198986262061	-81.6145070566643085
37158	2020-07-13 20:12:05	2020-07-13	America Bernhard	america.bernhard@warmmail.com	Oakland	California	4160650323852275	29b4230221dbf1e0e98568b2ea62887e	Voyager	37.7950672117833619	-122.272868837673272
37159	2020-07-13 20:12:44	2020-07-13	Julio Altenwerth	julio.altenwerth@geemail.com	Jacksonville	Florida	4733862744097	e9bc9cc130b5ec901da96f5c350898b8	Discover	30.3901874635886386	-81.6693981584705426
37160	2020-07-13 20:13:04	2020-07-13	Mr. Carlie Spencer	mr.carlie.spencer@geemail.com	Berkeley	California	51620746833603374	4b62be2ebd06835862c48f0a2a03ff83	Diners Club / Carte Blanche	37.8734029760313149	-122.255930553522106
37161	2020-07-13 20:13:28	2020-07-13	Connor Heidenreich	connor.heidenreich@geemail.com	Fort Worth	Texas	3793803309613243	a74c8e110876e5a4b1dcc3290db0ada6	JCB 15 digit	32.6982170122731475	-97.4156370373263911
37162	2020-07-13 20:28:23	2020-07-13	Dr. Herlinda Padberg	dr.herlinda.padberg@geemail.com	New York	New York	180050402062690182	9412592ef23659d9a1c8f46eeb0f89c5	JCB 16 digit	40.57123243876174	-73.948455913866681
37163	2020-07-13 20:37:22	2020-07-13	Dr. Jasen Christiansen	dr.jasen.christiansen@geemail.com	El Paso	Texas	3002762187715365	30b59c54ff3238d1bb266a8f2a036e48	Maestro	31.9039126782972389	-106.332550820240755
37164	2020-07-13 20:54:42	2020-07-13	Lacy Nicolas	lacy.nicolas@geemail.com	San Francisco	California	4209269117297325	7efc62a7d465eb83a3a1daca9a15145d	VISA 13 digit	37.7738147290494481	-122.401592962829355
37165	2020-07-13 21:02:11	2020-07-13	Dr. Jaylin Hintz	dr.jaylin.hintz@geemail.com	Chula Vista	California	675947772325180	162361bd1083af1b42a72ac302f726f7	American Express	32.6980979765064959	-117.090875942096858
37166	2020-07-13 21:16:35	2020-07-13	Ruffus Goyette	ruffus.goyette@geemail.com	Santa Clarita	California	3473028421135800	67a7ca9a44c49af482efa0df7222e5ca	JCB 16 digit	34.3541383252218324	-118.594739282141248
37167	2020-07-13 21:36:23	2020-07-13	Herlinda Reynolds	herlinda.reynolds@warmmail.com	Gresham	Oregon	3480243340169852	3971a5603026aa569bc664327ecae611	JCB 16 digit	45.5767969572406244	-122.466393142918491
37168	2020-07-13 21:36:48	2020-07-13	Darian Barton	darian.barton@geemail.com	Westminster	Colorado	6011622636210612148	f80e72781b2f604a7d310fc446b37862	VISA 13 digit	39.8569697096783671	-105.068543889015544
37169	2020-07-13 21:37:57	2020-07-13	Kiyoshi Nader	kiyoshi.nader@warmmail.com	Sioux Falls	South Dakota	6011397871728506069	1465b1125ae49553cd2d1c69beec0de4	Maestro	43.5242233242459591	-96.7428806762378599
37170	2020-07-13 21:43:36	2020-07-13	Kristofer Crona	kristofer.crona@geemail.com	Albuquerque	New Mexico	6011305870155111352	f2e16713ef80b5265ceb55662b5ab2d4	Voyager	35.1526408739522154	-106.587078820874552
37171	2020-07-13 22:10:23	2020-07-13	Dulcie Bogan	dulcie.bogan@geemail.com	Nashville	Tennessee	869925843403651189	b634d8aebb7853517d7f4d40c1946ba9	Discover	36.1690649553325017	-86.7947182868048515
37172	2020-07-13 22:20:56	2020-07-13	Shawanda Kunde	shawanda.kunde@geemail.com	Houston	Texas	060497478173475	67e81b9a4c379f173d1cbb332c174f15	VISA 16 digit	29.7320416936263427	-95.4053266933668453
37173	2020-07-13 22:29:14	2020-07-13	Ginger Sauer	ginger.sauer@geemail.com	Dallas	Texas	3528866649285136864	6e2251b3d7d95aa1472d4c7042ddef92	JCB 16 digit	32.751781021551416	-96.8063183539044019
37174	2020-07-13 22:31:56	2020-07-13	Luz Hoeger-Brekke	luz.hoeger.brekke@geemail.com	Woodbridge	New Jersey	3158962067837953103	a106ddfd5e5ad1b447d34e7a5539cb8b	Diners Club / Carte Blanche	40.4796272658899383	-74.2911823497012165
37175	2020-07-13 22:49:19	2020-07-13	Hali Witting	hali.witting@geemail.com	San Francisco	California	3337861985009623968	52bbb8e9a0eabd86b00a9c6b43612c57	Discover	37.7719483367707909	-122.450341812167864
37176	2020-07-13 22:51:25	2020-07-13	Mekhi Kuvalis	mekhi.kuvalis@geemail.com	San Francisco	California	501824026250084	de4868fc8ba7992f080512ac9ad7a5ed	VISA 16 digit	37.7505586834536118	-122.437416577442832
37177	2020-07-13 23:10:14	2020-07-13	Amiya Donnelly	amiya.donnelly@warmmail.com	San Mateo	California	589396476704323	fd3319a27d13d2f39cf3d2d7d78c137c	JCB 16 digit	37.480486805678531	-122.333903409805515
37178	2020-07-13 23:32:13	2020-07-13	Regenia Abshire	regenia.abshire@warmmail.com	Surprise	Arizona	53101731768397059	f1a609cdb8f3fc4851b794d6c504d323	Maestro	33.5883016375120746	-112.38706691900714
37179	2020-07-13 23:35:38	2020-07-13	Sawyer Douglas	sawyer.douglas@geemail.com	Detroit	Michigan	869970214826239594	434fbce9c5540e244de455f3b305a866	VISA 16 digit	42.3139953995514659	-83.0522837385654356
37180	2020-07-13 23:47:02	2020-07-13	Patsy Douglas	patsy.douglas@geemail.com	San Jose	California	3096657225079218367	f0cd354ee3ccd1e0042a7a57c48dfc4a	JCB 15 digit	37.370675469451399	-121.843865007742863
37181	2020-07-13 23:53:06	2020-07-13	Millicent Zboncak	millicent.zboncak@geemail.com	Stockton	California	3096402012895286614	30a330224de9059720c11e5acf4963ea	Mastercard	37.9138943246297586	-121.273092054630808
37182	2020-07-13 23:57:49	2020-07-13	Gerard Kemmer	gerard.kemmer@woohoo.com	San Francisco	California	6011156289538859191	1c75e21bd1f41a4ed02925bbf1b849cf	Discover	37.7535627523652622	-122.42342681381264
37183	2020-07-13 23:59:09	2020-07-13	Hugh Rau	hugh.rau@geemail.com	Sandy Springs	Georgia	6011602614054730072	7a062ef5de63625cf483feec1dfea984	American Express	33.9402120864540322	-84.3766923932440562
37184	2020-07-14 00:01:44	2020-07-14	Ninnie Crooks	ninnie.crooks@geemail.com	Fresno	California	180008344243961210	c2069993eed135dff2f102e2953d4ee8	JCB 16 digit	36.8609912456817952	-119.734616344386339
37185	2020-07-14 00:05:15	2020-07-14	Miss Candida Johnston	miss.candida.johnston@woohoo.com	Berkeley	California	4447089554931000	f34950a683e370f4a239655d1e3f2b1a	JCB 16 digit	37.9031156635305706	-122.283407356419204
37186	2020-07-14 00:06:42	2020-07-14	Oley Watsica	oley.watsica@geemail.com	Berkeley	California	3028276046922629	5cf57bb7a46e0dd39890a71b1433bfa9	JCB 15 digit	37.9039448494992612	-122.29257193136894
37187	2020-07-14 00:09:27	2020-07-14	Tobe Metz	tobe.metz@geemail.com	Oakland	California	869925200702904142	eee71e231ab758053a5bd1d75f284ed8	Discover	37.8096491594765141	-122.243061424795627
37188	2020-07-14 00:17:18	2020-07-14	Major Turner	major.turner@woohoo.com	Phoenix	Arizona	3528432143462542123	e6ed75854bcba5b2c95ca46a11bebb2a	JCB 16 digit	33.5639984833940872	-112.176561213417358
37189	2020-07-14 00:17:57	2020-07-14	Maddux Christiansen	maddux.christiansen@geemail.com	New York	New York	4426172358258	faf01253def3a1e1c1969548827db543	VISA 13 digit	40.666037698717787	-73.9725143939618022
37190	2020-07-14 00:19:25	2020-07-14	Luana Renner-Mills	luana.renner.mills@geemail.com	Garland	Texas	3528464400263731599	19be4e68edb0999628bd5e19f637ae11	JCB 16 digit	32.8720256926260888	-96.6767432345703241
37191	2020-07-14 00:33:58	2020-07-14	Harrie Moen	harrie.moen@geemail.com	North Charleston	South Carolina	3405828461385485	af6908e43801f3ea2890018fe5e92853	VISA 16 digit	32.8205155983727437	-80.0310437858197758
37192	2020-07-14 00:45:26	2020-07-14	Luisa Batz	luisa.batz@geemail.com	New York	New York	6011079527368037394	38465c599360e23497efe3444d16bf3f	JCB 16 digit	40.5742416221871949	-73.9894055934518491
37193	2020-07-14 00:49:02	2020-07-14	Bo Schulist IV	bo.schulist.iv@geemail.com	Port St. Lucie	Florida	6011437996873349205	9d0f1cc98bcf6319b36c2dfac33446a8	Discover	27.3169699925132079	-80.3304776989940592
37194	2020-07-14 00:56:58	2020-07-14	Amari VonRueden	amari.vonrueden@woohoo.com	Sacramento	California	4236635480013290	2fd5b8c5cf7f8e2a1fb3949df41af499	VISA 13 digit	38.6043347545232649	-121.484670828307415
37195	2020-07-14 01:00:27	2020-07-14	Dannie Yost	dannie.yost@warmmail.com	Laredo	Texas	52859212430734122	f6ca2a8c75688442c487c3fbf55a8e6b	VISA 16 digit	27.5403660712014897	-99.5351912566002426
37196	2020-07-14 01:03:38	2020-07-14	Minerva Larson-Becker	minerva.larson.becker@geemail.com	Round Rock	Texas	4256853412292	fd8f677ecf2dbeb1e39054305f564f11	Diners Club / Carte Blanche	30.4977852838251771	-97.6891727906502751
37197	2020-07-14 01:10:05	2020-07-14	Jed Kertzmann-McGlynn	jed.kertzmann.mcglynn@geemail.com	San Francisco	California	869999271058707331	56b93e9dc315693cb9c6b78b8b71c63c	Discover	37.7508909866050288	-122.439403702350589
37198	2020-07-14 01:13:59	2020-07-14	Dicie Bartell	dicie.bartell@geemail.com	San Diego	California	4830884947958529	0f95f2782c0213e8c10bac2f671ff550	Maestro	32.7555492582797996	-117.138755912510689
37199	2020-07-14 01:18:23	2020-07-14	Ever Gibson	ever.gibson@geemail.com	Indianapolis	Indiana	4594477140504384	06f4da08b7227c888f0ad80b2bec8ee4	VISA 16 digit	39.8199874374091607	-86.1914663630273168
37200	2020-07-14 01:18:35	2020-07-14	Dr. Adolf Senger III	dr.adolf.senger.iii@geemail.com	Reno	Nevada	060424499865897	f759134f19664d6b275ac423c144ecf8	Diners Club / Carte Blanche	39.5769403228148846	-119.754802258608493
37201	2020-07-14 01:22:06	2020-07-14	Destinee Littel	destinee.littel@woohoo.com	San Francisco	California	4859322488494	5846a87031742196d4ae2e21e2abee92	JCB 16 digit	37.7583929371107274	-122.4357748544749
37202	2020-07-14 01:24:10	2020-07-14	Izaiah Simonis	izaiah.simonis@geemail.com	Ann Arbor	Michigan	210018636176344266	ed3257bab6189e034ae22ac72e451972	Diners Club / Carte Blanche	42.2690798986762744	-83.6783032403435669
37203	2020-07-14 01:32:35	2020-07-14	Omarion Schowalter-Rosenbaum	omarion.schowalter.rosenbaum@warmmail.com	North Las Vegas	Nevada	3448731271264735	d0bab30a1c9622f89bafed661731ceb5	JCB 15 digit	36.2687094764474764	-115.001609480589266
37204	2020-07-14 01:33:12	2020-07-14	Demarion Spencer	demarion.spencer@warmmail.com	El Paso	Texas	869909999101958803	732ae37733e9d626fd88f80d42c1c187	Discover	31.7929989161729836	-106.383948726437993
37205	2020-07-14 01:54:19	2020-07-14	Lydia Mosciski MD	lydia.mosciski.md@geemail.com	Atlanta	Georgia	4274457341516004	d57f46b83ca27c55d7064c419aff8635	JCB 15 digit	33.686077637346088	-84.371645667827508
37206	2020-07-14 02:02:00	2020-07-14	Kimberly Goldner-Boyer	kimberly.goldner.boyer@warmmail.com	San Diego	California	4334840592074823	23f70068b17e367654fb8ea1c3eb4a1c	VISA 13 digit	32.8878811321288325	-117.159530798429628
37207	2020-07-14 02:05:33	2020-07-14	Kamya Marquardt	kamya.marquardt@geemail.com	Oakland	California	4295487919676505	e4efafdcc2c8270c8fb128251dd13017	VISA 16 digit	37.8119002734381837	-122.278348359365722
37208	2020-07-14 02:21:51	2020-07-14	Keanna Boyle	keanna.boyle@geemail.com	San Antonio	Texas	53649405027165743	335fa7b4fc5bea111a810da64ce50568	JCB 16 digit	29.4083157123137262	-98.4744022838607407
37209	2020-07-14 02:41:44	2020-07-14	Lea Emmerich	lea.emmerich@geemail.com	Boston	Massachusetts	4059951359757	6ca5c739c3c08cceeda0824ecf80e2ff	JCB 16 digit	42.2992112256288522	-70.9837178717784667
37210	2020-07-14 02:58:00	2020-07-14	Romona O'Hara	romona.o'hara@geemail.com	Greeley	Colorado	6011088776009398868	26b7074b9e1839bbe61cacf8b7a43c85	Discover	40.4561015104942072	-104.855344650738687
37211	2020-07-14 03:06:10	2020-07-14	Ellison Parker	ellison.parker@geemail.com	Eugene	Oregon	55549175211263866	686029ac3fd985cbcb2670769bf712e7	VISA 16 digit	44.1147218537710586	-123.141010876417909
37212	2020-07-14 03:06:20	2020-07-14	Berton Wisozk	berton.wisozk@geemail.com	Austin	Texas	869944851200350670	81f562d09595be1caaaac20ba5791db7	VISA 16 digit	30.2856661763168873	-97.8291461058665135
37213	2020-07-14 03:22:19	2020-07-14	Mr. Davion White	mr.davion.white@geemail.com	Philadelphia	Pennsylvania	4984719840376276	22375db0cccc2b73cbe0ea81c840ea26	JCB 15 digit	40.0799319473054254	-75.123330095027768
37214	2020-07-14 03:22:31	2020-07-14	Osie Hoeger	osie.hoeger@geemail.com	Chicago	Illinois	3112986177203246131	a725ab028f091afe94887b6c77bd890b	Maestro	41.870154281875493	-87.6934287357639448
37215	2020-07-14 03:26:28	2020-07-14	Hiram Wiegand	hiram.wiegand@warmmail.com	Fontana	California	3088364678742661658	13e315e33a7449fb420353d5f3a44752	Discover	34.1722077259477217	-117.381029434483125
37216	2020-07-14 03:33:21	2020-07-14	Syreeta Raynor	syreeta.raynor@geemail.com	Philadelphia	Pennsylvania	3022725451277107	6b5457311743ca757e5017a91f975cf6	VISA 16 digit	40.0351976201828563	-75.1575255958262858
37217	2020-07-14 03:35:32	2020-07-14	Ms. Tania Cormier DVM	ms.tania.cormier.dvm@woohoo.com	Garden Grove	California	6011749454866497972	64c135ed09bc6fe1a3714d2348d1126c	JCB 16 digit	33.868103805585946	-118.052882695525881
37218	2020-07-14 03:54:27	2020-07-14	Miss Lorna Watsica	miss.lorna.watsica@geemail.com	Dayton	Ohio	676215106851551	96b269ef94f8ede7ab45c3a3f0ebd817	Voyager	39.8347046619538219	-84.1059045554794409
37219	2020-07-14 03:58:12	2020-07-14	Mr. Algie Doyle	mr.algie.doyle@woohoo.com	Arlington	Texas	3009160211936995	c2ef7222b59a57791b82d14c03f84972	Voyager	32.6864790483161798	-97.0934382465694199
37220	2020-07-14 03:58:31	2020-07-14	Isabelle Weber DVM	isabelle.weber.dvm@geemail.com	Fort Worth	Texas	4828852951296	be8e60aa4a8eb0f6ce2fa3fb84ad2c3e	VISA 13 digit	32.8151613484192666	-97.3278644241213726
37221	2020-07-14 04:05:53	2020-07-14	Corean Hermiston	corean.hermiston@warmmail.com	Port St. Lucie	Florida	4585321839094342	c2bef161859d90ddb6c084c49030aa32	JCB 16 digit	27.3572025333199633	-80.3657392802733881
37222	2020-07-14 04:15:46	2020-07-14	Cristal Jaskolski	cristal.jaskolski@geemail.com	Henderson	Nevada	3748973425442169	ebd4c92d754b332a4bb8e848fb63a306	JCB 16 digit	36.0582851563047626	-115.000134722485029
37223	2020-07-14 04:21:25	2020-07-14	Loney Crist	loney.crist@woohoo.com	Berkeley	California	210026870550480137	2dac4a6391eaf461c1e9ed96a5876e09	VISA 13 digit	37.8687012204986502	-122.250674747237539
37224	2020-07-14 04:24:48	2020-07-14	Mr. Wirt Thompson Sr.	mr.wirt.thompson.sr.@warmmail.com	San Antonio	Texas	3528925733062262215	0e79a7659a01ddb354e5561118f1c8aa	Discover	29.4775712206099172	-98.5370407106190811
37225	2020-07-14 04:30:25	2020-07-14	Mr. Easton Miller	mr.easton.miller@geemail.com	Billings	Montana	4835000693847015	7212652ace6b97eb83e73698b4809bb9	Maestro	45.828141846623268	-108.620935963203749
37226	2020-07-14 04:43:48	2020-07-14	Grove Hegmann	grove.hegmann@warmmail.com	Anaheim	California	6011858702220235919	7d265e3877f440e2e84fea848fb7d9b0	JCB 16 digit	33.7906810520980514	-117.739078037461638
37227	2020-07-14 04:52:24	2020-07-14	Genevieve Williamson	genevieve.williamson@geemail.com	Austin	Texas	180025225318108739	173b1e53b332fad2a2fb1ca1405f57b7	Mastercard	30.3690344441808762	-97.8001903881557269
37228	2020-07-14 04:53:34	2020-07-14	Mr. Bo Ondricka I	mr.bo.ondricka.i@geemail.com	San Antonio	Texas	4483540915517	8bd23e7948833463c6f7c63b6a9fd4eb	Discover	29.513835389127582	-98.6238973720766552
37229	2020-07-14 04:56:04	2020-07-14	Malcolm Halvorson	malcolm.halvorson@warmmail.com	Columbia	Missouri	4006195685608624	978cb62f626f34c75115604276e1f300	JCB 15 digit	38.8756682607226622	-92.3924410186295546
37230	2020-07-14 04:58:56	2020-07-14	Markell Morar Sr.	markell.morar.sr.@geemail.com	Meridian	Idaho	3739873529685435	47327ae82cb721143595a22a413f5f2e	JCB 15 digit	43.6204730095349191	-116.348821702221031
37231	2020-07-14 05:03:48	2020-07-14	Lexie Rempel	lexie.rempel@geemail.com	Visalia	California	3112963697121830838	f502bf6ce844b64a337ac15db7403d82	VISA 13 digit	36.3514311226040121	-119.40816401044242
37232	2020-07-14 05:15:31	2020-07-14	Mr. Lesley Dicki	mr.lesley.dicki@woohoo.com	San Francisco	California	3481886497421085	0eba193ef61709b90d5333915f17c7bf	Mastercard	37.7960851837011518	-122.44948953313056
37233	2020-07-14 05:29:58	2020-07-14	Ethelbert Fay Jr.	ethelbert.fay.jr.@geemail.com	Mobile	Alabama	4496093171320	7b8a00acf348cb5ddf7821ad17925a75	Voyager	30.5993274715371406	-88.0379267594914836
37234	2020-07-14 05:39:07	2020-07-14	Deshaun Balistreri	deshaun.balistreri@woohoo.com	El Paso	Texas	6011548981543763288	92ebd47ff913054795439e3ac0d7dbe0	VISA 16 digit	31.7660254840567724	-106.387011893278
37235	2020-07-14 05:46:58	2020-07-14	Alfonse Bins	alfonse.bins@geemail.com	Bakersfield	California	869933106642260034	19c6321c53b710755ac587fa0f7b6c15	Maestro	35.3078895860061053	-118.918849769401547
37236	2020-07-14 05:53:36	2020-07-14	Lane Donnelly	lane.donnelly@woohoo.com	Houston	Texas	3337668355747038538	500833f51f928431df51be5919a19d60	VISA 13 digit	29.7981500242449329	-95.4119740321781507
37237	2020-07-14 06:04:38	2020-07-14	Mr. Abdiel Kunze	mr.abdiel.kunze@warmmail.com	Fresno	California	869904484645529795	82770ccf6cea39ef63f0c78426aff864	VISA 16 digit	36.839170103274661	-119.797480741712832
37238	2020-07-14 06:13:53	2020-07-14	Salomon Walter	salomon.walter@geemail.com	San Jose	California	3088732034925503793	069a093975afbebe0bfd0cf2be9b5309	VISA 13 digit	37.3025306501712635	-121.823125928056982
37239	2020-07-14 06:13:55	2020-07-14	Hermine Mayert	hermine.mayert@geemail.com	Lewisville	Texas	4884972914551990	ae75b05cafc9705d1b920967e7a49dad	Maestro	32.9760127893634092	-96.8870600746508757
37240	2020-07-14 06:23:34	2020-07-14	Lulu Weimann	lulu.weimann@geemail.com	Thornton	Colorado	3053184293358445	4761625bb56069a4e233f6cfda6d6506	VISA 13 digit	39.9989659291558013	-105.009053795800739
37241	2020-07-14 06:30:25	2020-07-14	Everett Spencer V	everett.spencer.v@woohoo.com	Denton	Texas	3528327757882978183	8d12970c48c09e61efd463facaee26fa	JCB 16 digit	33.2307033590771255	-97.213153960708155
37242	2020-07-14 06:31:20	2020-07-14	Cordell King	cordell.king@geemail.com	Norfolk	Virginia	3003589278491880	8463b742c7cd58256226cbbfc185d0a4	American Express	36.8553094361461717	-76.1571437835231535
37243	2020-07-14 06:52:26	2020-07-14	Doll Maggio	doll.maggio@geemail.com	Cape Coral	Florida	3096593399845356699	f7129c133dfd9872f4436b8345cb76d2	Discover	26.5989505681179459	-82.0063580742176583
37244	2020-07-14 07:11:35	2020-07-14	Jules Hoeger PhD	jules.hoeger.phd@warmmail.com	Oklahoma City	Oklahoma	3337740455752387788	899c02ec2cc7fd7146b70f507b64cf69	American Express	35.3797374176237724	-97.4428904128156574
37245	2020-07-14 07:17:12	2020-07-14	Denis McLaughlin	denis.mclaughlin@geemail.com	Irving	Texas	4383904595920448	f0f2be425d28618e48c897e2a0649634	JCB 16 digit	32.9330138716332641	-97.0631440446060196
37246	2020-07-14 07:26:46	2020-07-14	Mrs. Tea Mitchell DDS	mrs.tea.mitchell.dds@warmmail.com	San Francisco	California	3413025961302967	fd729c2810e4aa46d35ad45b5a471601	Voyager	37.7708453088656739	-122.423051523306
37247	2020-07-14 07:45:39	2020-07-14	Bernardo Fisher-Lynch	bernardo.fisher.lynch@geemail.com	Berkeley	California	4551494835110733	f0b37752b83e9d1b218f45f7ea157f90	VISA 16 digit	37.8837574795354755	-122.27364481315719
37248	2020-07-14 07:50:37	2020-07-14	Kyle Jacobson-Schuster	kyle.jacobson.schuster@woohoo.com	Chicago	Illinois	4139563727721756	6938c1c416f6c0b407ecc49ea032ff4c	American Express	41.823343476822977	-87.5899305167637721
37249	2020-07-14 07:51:59	2020-07-14	Josefita Weissnat	josefita.weissnat@geemail.com	Berkeley	California	3158192585913935076	d64751e0a6b6e8f74b7bfe167643111c	VISA 16 digit	37.853545566639184	-122.271872647106449
37250	2020-07-14 07:59:14	2020-07-14	Trudy Bode-Boyle	trudy.bode.boyle@geemail.com	San Francisco	California	180025111366794408	11776854e5d13acd07691641d514abc3	VISA 16 digit	37.7892622699025154	-122.438412566462659
37251	2020-07-14 08:01:42	2020-07-14	Javier Rosenbaum-Weber	javier.rosenbaum.weber@warmmail.com	Virginia Beach	Virginia	3022893374542419	fdee598593f5e5bbe3a2cc7582da6ad8	JCB 16 digit	36.8682937145885106	-75.9809044436689476
37252	2020-07-14 08:05:44	2020-07-14	Ned Rutherford-Douglas	ned.rutherford.douglas@warmmail.com	Norfolk	Virginia	180048341169984558	3a0a74a6a013ab3cefcc5a140e5e05e0	VISA 13 digit	36.9625469220820833	-76.224317369889846
37253	2020-07-14 08:11:54	2020-07-14	Jaeda Herman	jaeda.herman@geemail.com	Minneapolis	Minnesota	4449620800084810	87adbaf6944f750aa8f3b6d30a89e309	VISA 16 digit	45.0438385555606331	-93.2808315499491982
37254	2020-07-14 08:16:27	2020-07-14	Adolph Waelchi	adolph.waelchi@geemail.com	Los Angeles	California	3096678413099913705	036a543465643f0cf28ebee196a9484a	JCB 15 digit	34.0714822680555258	-118.446522220782185
37255	2020-07-14 08:22:58	2020-07-14	Paulina Lind	paulina.lind@geemail.com	San Antonio	Texas	3088373812713419130	837ad65cb34cf41494a125164b1951f6	JCB 16 digit	29.506621457876264	-98.4994402747437334
37256	2020-07-14 08:32:38	2020-07-14	Shirley Stark-O'Kon	shirley.stark.o'kon@woohoo.com	San Francisco	California	869947312737632624	59d2e30eba8aa6933d8b83579a56614b	JCB 15 digit	37.7691551371677221	-122.45205321877269
37257	2020-07-14 08:38:26	2020-07-14	Ayana Hamill	ayana.hamill@warmmail.com	Broken Arrow	Oklahoma	4646737359232	2a6ef81c0dcd187e3d3ee03569a95c95	Voyager	35.9917394936326858	-95.8542710734475492
37258	2020-07-14 08:41:13	2020-07-14	Dewayne Kilback	dewayne.kilback@woohoo.com	Brownsville	Texas	4468730520442663	f8d15760eb1acf3fbaf7e36463e55b56	Mastercard	25.9103535258289419	-97.5539583636633978
37259	2020-07-14 08:48:15	2020-07-14	Keeley Rippin	keeley.rippin@warmmail.com	Edison	New Jersey	3112991112714111915	0794d233f00ac02c3d369739aa225c13	Diners Club / Carte Blanche	40.4236124048903562	-74.2587692786991624
37260	2020-07-14 08:53:31	2020-07-14	Billye Gottlieb	billye.gottlieb@geemail.com	Santa Ana	California	3022223741864355	a15168207e711927ea0267ebb486299e	American Express	33.753698034222424	-117.9686980734039
37261	2020-07-14 08:58:20	2020-07-14	Dr. Sterling Gleichner PhD	dr.sterling.gleichner.phd@geemail.com	Sacramento	California	4343202034517928	4557f9a1833b9b01590bba8d753b6b58	JCB 16 digit	38.5426090232826795	-121.533038138715924
37262	2020-07-14 09:07:09	2020-07-14	Kunta Ernser	kunta.ernser@geemail.com	Memphis	Tennessee	869918140934823612	22a9f52acf5d7de7befee643b0372a4c	Mastercard	35.1126718665074549	-89.9234967159364373
37263	2020-07-14 09:12:07	2020-07-14	Ali Casper-Watsica	ali.casper.watsica@geemail.com	Santa Clarita	California	4616758034360	bc27fef5025965790fe91098b2770a5b	VISA 16 digit	34.4466459957621964	-118.571085053645817
37264	2020-07-14 09:12:32	2020-07-14	Miss Evia Eichmann	miss.evia.eichmann@woohoo.com	San Francisco	California	3096096172225026154	fa178a891fb830eacb86a06429e10394	VISA 16 digit	37.7570969412550852	-122.415473621723535
37265	2020-07-14 09:25:19	2020-07-14	Lidia Swaniawski	lidia.swaniawski@geemail.com	Chesapeake	Virginia	3016530877985671	e7c6ad6d9468be59bbe26b1d0427621a	JCB 16 digit	36.7062187290988859	-76.2384336448118063
37266	2020-07-14 09:44:02	2020-07-14	Dorthea Legros-Donnelly	dorthea.legros.donnelly@geemail.com	Oakland	California	4628457551708773	fb21b6d6a021b726822a866372171ed4	Discover	37.7498066556826757	-122.279525412174181
37267	2020-07-14 09:46:41	2020-07-14	Chadwick Maggio I	chadwick.maggio.i@geemail.com	Berkeley	California	6011550744746046017	27e6f75faf7f0db31992e646356764b4	VISA 16 digit	37.8795519241082062	-122.25840914660499
37268	2020-07-14 09:52:57	2020-07-14	Lilla Franecki	lilla.franecki@geemail.com	San Mateo	California	3528009504769271067	f0935d3158d6439a84eede63e8d8d776	JCB 16 digit	37.5348050839614089	-122.331382580226659
37269	2020-07-14 09:53:22	2020-07-14	Lidia Ratke	lidia.ratke@woohoo.com	Chicago	Illinois	4240545716864	d7e75c61fe1d52d8cb6b903bf0a26819	Voyager	41.749806097226589	-87.6465977575659707
37270	2020-07-14 09:55:43	2020-07-14	Dori Hudson	dori.hudson@geemail.com	Minneapolis	Minnesota	54319592337463162	3ff79a5374dee4e5388cccd30424709b	Voyager	45.0081813667055215	-93.1923103926043979
37271	2020-07-14 09:59:55	2020-07-14	Gorden Schmitt	gorden.schmitt@geemail.com	San Francisco	California	6011546580666648391	34c9399dfa7f5f51b1fc93640db314b7	JCB 16 digit	37.8020969391616859	-122.448763764364529
37272	2020-07-14 10:05:08	2020-07-14	Mahalie Schmidt	mahalie.schmidt@warmmail.com	Houston	Texas	6011770465323649254	6831aa05fb941e3f01137e24ef02e3f9	Voyager	29.8727617749556913	-95.3525460534743985
37273	2020-07-14 10:43:28	2020-07-14	Dejon Welch MD	dejon.welch.md@geemail.com	San Francisco	California	4084852773575009	f38b7f7b101bb78eec59dea5d236dcb7	JCB 16 digit	37.7728181722229266	-122.434625965821937
37274	2020-07-14 10:45:46	2020-07-14	Keena Mosciski DDS	keena.mosciski.dds@geemail.com	Chicago	Illinois	3050342100388467	bd2f851db480abf4f0f0845b5da92f42	VISA 16 digit	41.8506716118495916	-87.6228004090517771
37275	2020-07-14 10:46:51	2020-07-14	Beulah Haag	beulah.haag@geemail.com	Nashville	Tennessee	52830348128764148	7dafdf4a1e05e2d974eae56c64fc8f73	VISA 16 digit	36.1987167253281896	-86.8043945383653011
37276	2020-07-14 10:57:25	2020-07-14	Mr. Stafford Bartell	mr.stafford.bartell@geemail.com	Madison	Wisconsin	676377610455865	b57f4ef8eafd0e4fe3617e9df4030d9a	Diners Club / Carte Blanche	43.0584840626895442	-89.5196362558171188
37277	2020-07-14 10:59:43	2020-07-14	Reece Larson	reece.larson@geemail.com	Manchester	New Hampshire	6011783914748149924	fe37419ee124c6e638dc06f9202237d9	JCB 15 digit	43.0772236597795057	-71.5395847296699969
37278	2020-07-14 11:00:56	2020-07-14	Mrs. Clemma Prohaska	mrs.clemma.prohaska@warmmail.com	Phoenix	Arizona	4506973322586188	0e6e673969d55302e0d734f4a1da46f1	Maestro	33.6002638654250703	-112.183466362527014
37279	2020-07-14 11:02:40	2020-07-14	Lamar Bode	lamar.bode@geemail.com	Richmond	Virginia	3528301041681153318	d67465824ddbd3e3c3490b8cdfaef9c9	VISA 16 digit	37.5008345181342193	-77.4123858181051929
37280	2020-07-14 11:15:43	2020-07-14	Mrs. Brea Kuvalis PhD	mrs.brea.kuvalis.phd@geemail.com	Oakland	California	180028388914548364	54c47ab970eedd9383a0e01e6a33e190	Voyager	37.7742165548032816	-122.268603972420067
37281	2020-07-14 11:20:51	2020-07-14	Domenick Veum	domenick.veum@geemail.com	Augusta	Georgia	4070644037728367	a80c1ba5c48776d339d10a6e13eb0e5d	VISA 16 digit	33.3741921485140907	-82.0061021983452179
37282	2020-07-14 12:10:04	2020-07-14	Erick Pagac PhD	erick.pagac.phd@geemail.com	Detroit	Michigan	4700326786497869	38f35469155aec50c6d0fb288ee3d232	Maestro	42.4196541235707727	-83.1383767619848157
37283	2020-07-14 12:13:20	2020-07-14	Ivette Bode	ivette.bode@geemail.com	Wichita	Kansas	3045322364720451	783553d8a05f053f52e52403457b40e3	JCB 16 digit	37.71727027118839	-97.3022833391759576
37284	2020-07-14 12:13:54	2020-07-14	Dr. Deshawn Bosco	dr.deshawn.bosco@geemail.com	West Jordan	Utah	4569425652314	542aa7a1917ef31d4e178dd604b4ed91	Diners Club / Carte Blanche	40.6058046241547927	-111.941733911269523
37285	2020-07-14 12:27:33	2020-07-14	Estel Rohan	estel.rohan@geemail.com	Philadelphia	Pennsylvania	3112438693972635142	03232782f019218cd0e00a1c8fbf0ffb	VISA 13 digit	40.073758648657801	-75.0465192512508565
37286	2020-07-14 12:44:10	2020-07-14	Jettie Goodwin-Effertz	jettie.goodwin.effertz@geemail.com	San Diego	California	4097741627133	4aafab60676f2e52d48460b4cd09c139	VISA 16 digit	32.8938768144763998	-117.04772064074875
37287	2020-07-14 12:46:15	2020-07-14	Buddie Schmitt	buddie.schmitt@woohoo.com	Atlanta	Georgia	3494009733728842	7a8a8fceb373990a7118c44a5f14255e	VISA 13 digit	33.8133443213809315	-84.4616803585596472
37288	2020-07-14 12:55:48	2020-07-14	Oren Will-Stoltenberg	oren.will.stoltenberg@woohoo.com	El Paso	Texas	3158271381653115846	6da1c7ae185f7a6ad9abdbd4771ece05	Mastercard	31.7829446511171767	-106.364681729393084
37289	2020-07-14 12:56:20	2020-07-14	Dr. Debbi Crist DDS	dr.debbi.crist.dds@geemail.com	San Francisco	California	3528261057737464598	77c499b60dffc0812e585ef36a4e5177	JCB 15 digit	37.7802062042144655	-122.432875191485877
37290	2020-07-14 13:04:35	2020-07-14	Montie Connelly III	montie.connelly.iii@woohoo.com	McAllen	Texas	501891251925110	ac2f93e6109aec7cf16c45730490a1cb	JCB 16 digit	26.2337360686462375	-98.3079066105034087
37291	2020-07-14 13:08:51	2020-07-14	Zechariah Fritsch-Jerde	zechariah.fritsch.jerde@geemail.com	Houston	Texas	6011145830410767400	efa9fef3ca9e4286ab7ea979e1544edb	JCB 16 digit	29.786960827054827	-95.4113858238343227
37292	2020-07-14 13:15:24	2020-07-14	Dr. Lethia Ruecker	dr.lethia.ruecker@geemail.com	Vallejo	California	3479369864489682	2f032f2dfc7dd9d322d8fd0363117de1	American Express	38.1321295811884085	-122.329961825568219
37293	2020-07-14 13:15:47	2020-07-14	Dr. Jahir Kohler	dr.jahir.kohler@geemail.com	Los Angeles	California	3716231105814951	cb04ecd15fcd4cb46884cbb751ff6b87	VISA 13 digit	33.9223824695084204	-118.460053765027965
37294	2020-07-14 13:18:55	2020-07-14	Brenna Treutel	brenna.treutel@woohoo.com	San Francisco	California	4614056657355152	e6fa14c68397b0c52465236a785ee4b9	VISA 13 digit	37.7429602088381344	-122.429377047897987
37295	2020-07-14 13:19:35	2020-07-14	Mrs. Lovina Conroy PhD	mrs.lovina.conroy.phd@geemail.com	Denver	Colorado	55604865409010069	fe75ce54b9697b1102e1d9f8202e37db	Discover	39.8293940300639662	-104.79110381759368
37296	2020-07-14 13:26:30	2020-07-14	Deirdre Crist	deirdre.crist@geemail.com	New York	New York	52804901428176702	25b8f6cf6dabfa4a2d4af2d9a623bd91	VISA 16 digit	40.6375791401825808	-73.966539149953789
37297	2020-07-14 13:26:50	2020-07-14	Miss Jaycie Moore	miss.jaycie.moore@geemail.com	Los Angeles	California	869902674363063074	c7703d3cd3b98a65cdaa6cae5b8536e3	JCB 16 digit	34.0368409058876296	-118.406596909742049
37298	2020-07-14 13:32:09	2020-07-14	Felton Corwin-Kassulke	felton.corwin.kassulke@geemail.com	Pasadena	California	3088179538755646282	76ff4dd0531b4ecbb1f72851161a4f16	JCB 16 digit	34.1732945490017528	-118.091692738403012
37299	2020-07-14 13:35:21	2020-07-14	Mr. Kimball Heaney	mr.kimball.heaney@geemail.com	San Francisco	California	3001456943802952	39315c24451da4bf384c28b526d7f316	Voyager	37.8035610899954619	-122.426560682891022
37300	2020-07-14 13:44:36	2020-07-14	Mrs. Makala Huels PhD	mrs.makala.huels.phd@geemail.com	Mesa	Arizona	501856788374033	b794f21fcd42c1290b7d966c84782c5e	Maestro	33.3779520778596392	-111.744092020660261
37301	2020-07-14 13:52:29	2020-07-14	Arturo Kuhn	arturo.kuhn@geemail.com	New York	New York	3776473657460083	f6c99f79348c061f60270b6098704c95	Voyager	40.6734372249096623	-73.8567962899234089
37302	2020-07-14 14:01:45	2020-07-14	Jacalyn Johnson	jacalyn.johnson@geemail.com	Miami Gardens	Florida	51054855612812471	7add237784790386b0f6e9e2a4f07251	JCB 16 digit	25.9156413223069144	-80.2483434645704961
37303	2020-07-14 14:12:25	2020-07-14	Cain Daniel-Conn	cain.daniel.conn@warmmail.com	McKinney	Texas	6011212271832346531	52c9379aca92a31198bb3c4442c23927	JCB 15 digit	33.2384593612179202	-96.6659597510304422
37304	2020-07-14 14:12:30	2020-07-14	Wallace Rice-Cormier	wallace.rice.cormier@geemail.com	Charlotte	North Carolina	675987231153955	5637609b9199514447374ed01eb4628e	VISA 16 digit	35.1197006061460826	-80.7625368482377439
37305	2020-07-14 14:16:32	2020-07-14	Whitley Pagac	whitley.pagac@woohoo.com	San Francisco	California	4925408806972	7fd6b9ecd228386c20c5ad2a42df982b	Diners Club / Carte Blanche	37.7853693834634257	-122.407504680500651
37306	2020-07-14 14:49:14	2020-07-14	Mrs. Karrie Baumbach	mrs.karrie.baumbach@geemail.com	Lexington	Kentucky	869998215907526732	96a3e7e92b34ccaed5f14ae419c368d6	Diners Club / Carte Blanche	38.054222451510654	-84.5184754943840204
37307	2020-07-14 15:03:14	2020-07-14	Rexford Abshire	rexford.abshire@geemail.com	Los Angeles	California	3404433995743381	507f1c5e283460afe8e6666ffea479ff	Voyager	34.0325364930886778	-118.409354694419719
37308	2020-07-14 15:04:23	2020-07-14	Amil Anderson	amil.anderson@warmmail.com	New York	New York	4509797167024535	a087b52b16b319cd3dfb4f57fa6d56b8	JCB 15 digit	40.7524911295846124	-73.9837387376826285
37309	2020-07-14 15:08:57	2020-07-14	Cruz Quigley	cruz.quigley@geemail.com	Mesa	Arizona	4080180115294426	e9be1ac353b509f3de7cb47334a08e06	Discover	33.3768298385344409	-111.706745284504819
37310	2020-07-14 15:09:44	2020-07-14	Ruel McCullough	ruel.mccullough@geemail.com	San Francisco	California	3012189909016700	445f2e95210dbc9c86ea226e0b13a148	VISA 13 digit	37.7848225521986194	-122.399609121299733
37311	2020-07-14 15:12:45	2020-07-14	Jermey Shanahan	jermey.shanahan@warmmail.com	Chicago	Illinois	52209173240430797	a798fa61f33053cf6c5604bc62c025e8	VISA 16 digit	41.8179788781631743	-87.7355016292568308
37312	2020-07-14 15:15:30	2020-07-14	Braelyn Williamson	braelyn.williamson@geemail.com	Columbus	Ohio	3528076232715564496	23a36d08b4cdfb4271fc306bab7fd287	Diners Club / Carte Blanche	39.9143728297248472	-82.9477131906665903
37313	2020-07-14 15:27:59	2020-07-14	Abbey Tillman-Schumm	abbey.tillman.schumm@geemail.com	Washington	District of Columbia	3019486719323406	0789a206ba762fad18e2b24311e7e7fa	Diners Club / Carte Blanche	38.8831394091512976	-76.919602791334313
37314	2020-07-14 15:42:19	2020-07-14	Dr. Ramon Mertz MD	dr.ramon.mertz.md@geemail.com	St. Petersburg	Florida	4569882456527682	0ee28a1809b87a2848aed9764cc814a7	JCB 16 digit	27.7742491216752683	-82.6754729959539958
37315	2020-07-14 15:43:55	2020-07-14	Treyvon Eichmann	treyvon.eichmann@geemail.com	Raleigh	North Carolina	51031118311349529	1b96d615c067cf66168fdec778b52441	JCB 16 digit	35.8915352823812484	-78.6459433102916989
37316	2020-07-14 15:46:23	2020-07-14	Marlena Kris-Fahey	marlena.kris.fahey@warmmail.com	San Francisco	California	210022252122536205	1360637964765692457becfcf1baf33a	American Express	37.7536119504841352	-122.44199055809932
37317	2020-07-14 15:50:38	2020-07-14	Maceo Barton DDS	maceo.barton.dds@geemail.com	Amarillo	Texas	4763815672137328	1fd91b66322a126a5af58684827cb4ba	VISA 13 digit	35.158469147577506	-101.799940683678543
37318	2020-07-14 16:03:38	2020-07-14	Estel Crooks	estel.crooks@geemail.com	Berkeley	California	3702929363221597	8d0123fda1f2fc153b73bf33d79b4470	JCB 16 digit	37.8552478179336092	-122.244937399291345
37319	2020-07-14 16:13:09	2020-07-14	Dr. Ayana Grady	dr.ayana.grady@geemail.com	Columbus	Ohio	3026728638533778	e1d39d16d92eb6a70084849c50390ccd	VISA 13 digit	39.9031572727065509	-82.9683876282770285
37320	2020-07-14 16:18:47	2020-07-14	Reba Fritsch DVM	reba.fritsch.dvm@geemail.com	Fairfield	California	3528300890014181045	daf862cac3fba8f6419f31b7b9284560	JCB 16 digit	38.3232897864311965	-121.962863790011411
37321	2020-07-14 16:21:44	2020-07-14	Almond Fritsch	almond.fritsch@geemail.com	Mesa	Arizona	210086662477266419	36e79a7750a7433a583f92fffdfa618f	VISA 16 digit	33.3424784741975344	-111.739593822171543
37322	2020-07-14 16:23:30	2020-07-14	Mr. Jessee Boehm	mr.jessee.boehm@warmmail.com	Houston	Texas	52131610620094209	8311f1d3891b642f5bb78943298824fc	Maestro	29.7993848730888224	-95.4837991500288297
37323	2020-07-14 16:27:36	2020-07-14	Citlali Towne	citlali.towne@warmmail.com	Cleveland	Ohio	3425108594078877	2fba7cc2669ff32e377e29a78bc2b2fb	Voyager	41.4623088841177463	-81.5832306631147901
37324	2020-07-14 16:29:38	2020-07-14	Maximillian Toy-Kohler	maximillian.toy.kohler@geemail.com	Tulsa	Oklahoma	4108758552934402	6b05a4c7d3c79b6d99fb71475deb7844	Maestro	36.140827406607194	-95.9625096803486315
37325	2020-07-14 16:33:19	2020-07-14	Dr. Launa Nitzsche	dr.launa.nitzsche@geemail.com	North Charleston	South Carolina	4851590008897902	39df8d1f1c3ecf71b4c6f861578e9041	American Express	32.9244599610261588	-80.0440405954699941
37326	2020-07-14 16:37:39	2020-07-14	Lindsey Aufderhar-Mayer	lindsey.aufderhar.mayer@geemail.com	Chicago	Illinois	060465145247659	454323831420b0130b8c80f95656916d	VISA 16 digit	41.7584988285623524	-87.6822114254377709
37327	2020-07-14 16:38:09	2020-07-14	Dakoda Kuhic	dakoda.kuhic@geemail.com	Las Vegas	Nevada	3007268842848984	cf1ea4f5e09e6edf3caf13367165345d	Voyager	36.1836713316485259	-115.343567574603853
37328	2020-07-14 16:42:15	2020-07-14	Dr. Lark Hermann Jr.	dr.lark.hermann.jr.@geemail.com	Los Angeles	California	3096321745418201945	15c1acb42bbb5e23f20d8c9a81c7ad82	VISA 16 digit	34.0099541311018143	-118.488649772991607
37329	2020-07-14 16:45:59	2020-07-14	Dr. Gustave Halvorson V	dr.gustave.halvorson.v@geemail.com	New York	New York	210076186216914875	9acc9ab26f8bbb6076da4343a1204f5b	Mastercard	40.7244844796825163	-73.8787482163764508
37330	2020-07-14 17:09:20	2020-07-14	Dax Kertzmann	dax.kertzmann@geemail.com	Los Angeles	California	3088748391519918635	677e8b07c687a9953f1a461ebb0bc65d	VISA 13 digit	33.9979017977934319	-118.388408109544955
37331	2020-07-14 17:15:40	2020-07-14	Vidal Marks IV	vidal.marks.iv@warmmail.com	Greeley	Colorado	4114288277850917	7cce62250b4b4ec563133f5e68338cf0	American Express	40.3743496934950343	-104.741118261807415
37332	2020-07-14 17:16:17	2020-07-14	Ms. Mechelle Macejkovic	ms.mechelle.macejkovic@warmmail.com	Philadelphia	Pennsylvania	4393594428854548	6c6ce30d6999d33096b13f44c80b0a2f	VISA 16 digit	39.9811040230054431	-75.0342672705549774
37333	2020-07-14 17:17:05	2020-07-14	Florance Rowe	florance.rowe@geemail.com	Henderson	Nevada	3724304716188212	9aa78a45aec1dfce4bf0a00c8648ec3f	VISA 16 digit	35.9529702324353195	-114.958142923765635
37334	2020-07-14 17:29:49	2020-07-14	Mara Schinner	mara.schinner@geemail.com	Los Angeles	California	210073107354340676	7ffd1cc9068bb6852820539d0bd6a924	VISA 13 digit	34.1029756184533213	-118.403846521348868
37335	2020-07-14 17:53:59	2020-07-14	Dr. Tiney Abernathy MD	dr.tiney.abernathy.md@geemail.com	Worcester	Massachusetts	4532183691734744	d22bd3e948a550017f767589484852a5	Mastercard	42.318178462114183	-71.7305126486599391
37336	2020-07-14 18:00:25	2020-07-14	Hope Hodkiewicz	hope.hodkiewicz@warmmail.com	San Jose	California	502079364970826	d206c4510d906c4e1fa443e42db2cff4	Maestro	37.1976720464702737	-121.863853005528071
37337	2020-07-14 18:46:00	2020-07-14	Verna Cole-Casper	verna.cole.casper@woohoo.com	New York	New York	52356875386871987	b840c5770067a81307eff91687aadc07	VISA 16 digit	40.6082374921292057	-73.8456367353338692
37338	2020-07-14 18:52:58	2020-07-14	Presley Emmerich	presley.emmerich@geemail.com	Fresno	California	4992278829727660	22b26fdf9860ae19e6d30b9c9d3d324c	Discover	36.8010136367160854	-119.86518663541564
37339	2020-07-14 18:58:12	2020-07-14	Teddy Kessler	teddy.kessler@geemail.com	Cleveland	Ohio	3528770924257309459	eb418a6003c09a9dbb7028e5c9d48cd7	JCB 16 digit	41.4221943152453704	-81.7371771668322395
37340	2020-07-14 19:17:32	2020-07-14	Stanford Murazik-Nikolaus	stanford.murazik.nikolaus@woohoo.com	Houston	Texas	210056196490488003	b06ce312d4fbc7ae35ae7d5a5ab66385	Maestro	29.8495454005509622	-95.3939980154871989
37341	2020-07-14 19:21:42	2020-07-14	Denis Borer II	denis.borer.ii@geemail.com	Detroit	Michigan	3096130970934119147	6426131f432ca6ef430f7d8d3f1468e2	Maestro	42.3690749894287464	-83.1380564187306845
37342	2020-07-14 19:33:55	2020-07-14	Edris Gislason	edris.gislason@geemail.com	Lowell	Massachusetts	4215553362040585	9b27c8bc80bb9846365ea1643fb53734	VISA 16 digit	42.6170069023370743	-71.3787257946435432
37343	2020-07-14 19:36:46	2020-07-14	Brandie Berge-Kirlin	brandie.berge.kirlin@geemail.com	San Francisco	California	210019819582575785	19ecddcaa1676b954fc26ca047da1fd9	Mastercard	37.7881023550391788	-122.469405133202628
37344	2020-07-14 19:51:48	2020-07-14	Matteo Braun-Bernier	matteo.braun.bernier@geemail.com	Phoenix	Arizona	51874373580305054	7b9c1d5b4a233ca078a39ce22e7b1836	Discover	33.4828185665354141	-112.18314065499456
37345	2020-07-14 20:12:07	2020-07-14	Ruth D'Amore MD	ruth.d'amore.md@geemail.com	Atlanta	Georgia	3096603850740185888	553bf43398424c2989e0d6578457459b	American Express	33.7876032262384882	-84.345522883632043
37346	2020-07-14 20:25:57	2020-07-14	Sunshine Monahan	sunshine.monahan@woohoo.com	Stockton	California	52260752500415717	ac4ca7f00ac8de860e4dea3b34104000	JCB 15 digit	37.9465364222146562	-121.271217367760087
37347	2020-07-14 20:35:39	2020-07-14	Margaretta Hills	margaretta.hills@geemail.com	New York	New York	51812648837000052	b0c4221dc028febc8c59b1e2297c1b59	Mastercard	40.5967375599537021	-73.8702148164518206
37348	2020-07-14 20:40:41	2020-07-14	Tammie Prohaska	tammie.prohaska@geemail.com	New York	New York	4580642024474030	0b5b44e6815c84e9f793d41d6d9e9221	VISA 16 digit	40.7211564318966097	-73.8642028092768044
37349	2020-07-14 20:40:42	2020-07-14	Isreal Greenholt	isreal.greenholt@geemail.com	San Francisco	California	676161371614464	376644d1304c0d672f3ddab1235a1693	Maestro	37.7965595419930551	-122.468360164251109
37350	2020-07-14 20:45:48	2020-07-14	Monroe Senger	monroe.senger@geemail.com	Waco	Texas	4668586883801905	1507ef86b46b7bc5447a278c8514a7a5	Discover	31.516504318148268	-97.1410283823628049
37351	2020-07-14 20:53:25	2020-07-14	Elihu Murphy	elihu.murphy@geemail.com	Hayward	California	869946513831582083	d27d0ffcb4e105e5c9af005f06a55516	JCB 16 digit	37.5360874988593167	-122.119337005426743
37352	2020-07-14 20:59:22	2020-07-14	Lori Rolfson	lori.rolfson@geemail.com	Fayetteville	North Carolina	869927943203820394	bfa7e9e1cd9656b326c30b8c86de36f3	JCB 16 digit	35.0841921966310579	-78.9761491685304833
37353	2020-07-14 21:05:30	2020-07-14	Parlee Mueller-Schmitt	parlee.mueller.schmitt@geemail.com	Greeley	Colorado	4104148397438211	b578267afedaf240b348eea16371c147	JCB 16 digit	40.3430417804114541	-104.796479018715019
37354	2020-07-14 21:05:58	2020-07-14	Lester Oberbrunner	lester.oberbrunner@geemail.com	Houston	Texas	210016751632697264	db8d0aa5c8ce5e4b35284d83e3759aeb	Voyager	29.7951381227079786	-95.4714058746132963
37355	2020-07-14 21:08:52	2020-07-14	Mr. Cooper Donnelly II	mr.cooper.donnelly.ii@woohoo.com	Oklahoma City	Oklahoma	4586562419385654	6558fe3209696bab3102f8abdce94005	American Express	35.5555044789243482	-97.5859606119699805
37356	2020-07-14 21:18:42	2020-07-14	Constantine Hyatt	constantine.hyatt@woohoo.com	Austin	Texas	4631867074520	e2214f589856ac87852b460da214b373	VISA 13 digit	30.2170148625630866	-97.6644809727795433
37357	2020-07-14 21:31:35	2020-07-14	Lise Schuppe	lise.schuppe@geemail.com	Raleigh	North Carolina	6011551808999331639	8c6dc6b82bcd57179b6de8b47c56e9dc	Mastercard	35.7647513899154958	-78.6994100075151835
37358	2020-07-14 21:32:19	2020-07-14	Lesly O'Connell MD	lesly.o'connell.md@warmmail.com	New York	New York	6011629923995124710	f92f5fa737a37467f975ddbc11b4f684	Maestro	40.6718168794866628	-73.9442677823722363
37359	2020-07-14 21:38:06	2020-07-14	Shenna Kuhn-Schumm	shenna.kuhn.schumm@geemail.com	Boise	Idaho	502034856215503	b0bd03c9523666fa7cc180529ebf2909	JCB 16 digit	43.5804471196278911	-116.323433026085425
37360	2020-07-14 21:58:02	2020-07-14	Karissa Reichel	karissa.reichel@geemail.com	San Francisco	California	4159851161871681	435845b223fc1d0f771bf77e9a1642ce	American Express	37.7666731988585198	-122.416005036740117
37361	2020-07-14 22:26:57	2020-07-14	Christina Mayer-Johns	christina.mayer.johns@geemail.com	Los Angeles	California	4739587646441943	7bcfc80f9e8bfa391fe61090b09ea255	VISA 13 digit	34.0404384323261624	-118.337451360094548
37362	2020-07-14 22:27:26	2020-07-14	Aryanna Wunsch DDS	aryanna.wunsch.dds@geemail.com	Richardson	Texas	675904158151730	e0e4bb9f83dabc1fca523f8d77ac2fe6	VISA 16 digit	32.9021413336276964	-96.7112855310779054
37363	2020-07-14 22:28:19	2020-07-14	Summer Ortiz	summer.ortiz@geemail.com	San Francisco	California	3528015826312141196	91aca5465cf65495cd819ea00a1c4ac0	American Express	37.7864153610768341	-122.445371187426659
37364	2020-07-14 22:34:38	2020-07-14	Travon Skiles	travon.skiles@geemail.com	Houston	Texas	4751928853105784	0469ab2671d9c40718df9be26d31531e	JCB 16 digit	29.8595957314208142	-95.3568477306995561
37365	2020-07-14 22:35:02	2020-07-14	Malcolm Purdy	malcolm.purdy@geemail.com	St. Petersburg	Florida	3481772292284797	6ac73c4f3a8cbb242445ad3655080064	Maestro	27.7758061960227778	-82.5740113132990814
37366	2020-07-14 22:41:00	2020-07-14	Cammie Murphy	cammie.murphy@geemail.com	Mobile	Alabama	4227195658043919	19fc75afd1f7334267124e8dc97e9039	American Express	30.5857325872980041	-88.004309445493675
37367	2020-07-14 22:52:14	2020-07-14	Miss Nancy Stark PhD	miss.nancy.stark.phd@geemail.com	Los Angeles	California	869914442046972756	c746943c191a4d80ea5d1a96ba10e95f	Mastercard	34.0727072271384301	-118.386687595349912
37368	2020-07-14 23:08:52	2020-07-14	Rafe VonRueden	rafe.vonrueden@warmmail.com	Fremont	California	53990883425932838	c291bed6f5a81dabfccd899b60458c73	JCB 16 digit	37.5484283365942559	-121.999174931923662
37369	2020-07-14 23:10:43	2020-07-14	Shalonda Bahringer PhD	shalonda.bahringer.phd@geemail.com	Provo	Utah	6011900541066253141	2dd813c855fd78f23aed3358916bef57	Voyager	40.293966342906657	-111.729560988922799
37370	2020-07-14 23:14:25	2020-07-14	Evangelina Bergstrom	evangelina.bergstrom@woohoo.com	Plano	Texas	869907940007435415	3eff59cf85d14d8b537eb20f593005ee	JCB 16 digit	32.9756352391179703	-96.7864687068570362
37371	2020-07-14 23:14:30	2020-07-14	Florentino Lemke	florentino.lemke@geemail.com	El Monte	California	53076865911181613	b7c3ace5e1aa8f9b1994cff59ebc2e56	JCB 16 digit	34.0064264491856036	-117.969568516526749
37372	2020-07-14 23:23:12	2020-07-14	Julie Stark	julie.stark@geemail.com	Newark	New Jersey	180022018115117125	9bb35dcd6209d3479695c9a01abed05d	JCB 15 digit	40.6490397953342679	-74.2696799007918713
37373	2020-07-14 23:25:10	2020-07-14	Miss Gianna Konopelski	miss.gianna.konopelski@woohoo.com	Lexington	Kentucky	4364996475927389	e56905881ae73e5d663af50a6a4f19be	JCB 15 digit	38.0884674554567795	-84.4172310803916304
37374	2020-07-14 23:57:49	2020-07-14	Rennie Koss	rennie.koss@geemail.com	Lincoln	Nebraska	4144668418940236	91d4d1ba01d2e74df5a6dd6eb2694ce6	Mastercard	40.8673524550180858	-96.6677437460675861
37375	2020-07-15 00:02:38	2020-07-15	Dr. Olivine Goodwin	dr.olivine.goodwin@geemail.com	Omaha	Nebraska	675916358187041	8e6194102c4ff9db4dfb35a573eb80c4	Voyager	41.2967177044745526	-95.9914708490133393
37376	2020-07-15 00:04:26	2020-07-15	Arly Boehm	arly.boehm@woohoo.com	San Jose	California	3448960718091027	0b8027721eff0ca4f9a005b0d5c21868	American Express	37.3301119415841995	-121.914560792710262
37377	2020-07-15 00:07:39	2020-07-15	Stephanie Hintz	stephanie.hintz@warmmail.com	Provo	Utah	3112853882413199646	80c9bff5d61cfe21f840b13091859d85	Discover	40.2191838173449057	-111.562208534698186
37378	2020-07-15 00:08:01	2020-07-15	Corinna Marquardt	corinna.marquardt@woohoo.com	Temecula	California	4125199129722534	782acc610ffbda13c383fcf0aa066597	VISA 16 digit	33.4991944668482944	-117.156079695439701
37379	2020-07-15 00:11:16	2020-07-15	Kalel Little V	kalel.little.v@warmmail.com	Philadelphia	Pennsylvania	675955768232138	c073661b98aba6deb0b3bd2494a4732d	VISA 16 digit	39.9244143440812849	-75.1390871972210732
37380	2020-07-15 00:12:16	2020-07-15	Gustaf Littel	gustaf.littel@woohoo.com	Winston–Salem	North Carolina	4077609344900986	528574423fae20d40b2184b375ad3048	JCB 15 digit	36.1342194079652401	-80.2795125970281589
37381	2020-07-15 00:12:42	2020-07-15	Elaine Treutel	elaine.treutel@geemail.com	Chandler	Arizona	210010653100473481	621197dab2d4427ed5e4145f97c239b4	VISA 16 digit	33.2287600755780943	-111.82091611846127
37382	2020-07-15 00:12:52	2020-07-15	Leola Labadie	leola.labadie@woohoo.com	New York	New York	6011626459359042662	a03f9a006c6cf05c2c56164e70855c5c	Mastercard	40.6946638064682489	-73.9946447309933575
37383	2020-07-15 00:15:07	2020-07-15	Jonas Rippin I	jonas.rippin.i@geemail.com	New York	New York	4349617614784107	33cf7aa5c0605f46af10df7f5714e14e	VISA 16 digit	40.6835902224984025	-73.9657288831554354
37384	2020-07-15 00:17:13	2020-07-15	Menachem Gleichner-Daugherty	menachem.gleichner.daugherty@woohoo.com	Dallas	Texas	4967969586617539	f59a825227b9b31fecae6221663f49b7	Diners Club / Carte Blanche	32.7635409094665206	-96.7154221316762204
37385	2020-07-15 00:24:21	2020-07-15	Jerimy Lesch	jerimy.lesch@warmmail.com	New York	New York	676169781583161	1b6d6e8fe813051d269f73d3445949b7	JCB 15 digit	40.6604087444711482	-73.8762148420222076
37386	2020-07-15 00:33:30	2020-07-15	Jailene Schultz PhD	jailene.schultz.phd@woohoo.com	Salem	Oregon	869981602694755732	e425986511b8b1ebb8d036fa48da7b83	VISA 13 digit	44.9153857901494931	-122.984381135149675
37387	2020-07-15 00:47:45	2020-07-15	Phylis Wehner	phylis.wehner@woohoo.com	Buffalo	New York	3096530494292676206	eaedd1cfb45c02e6060ac3b013b0a3b8	VISA 16 digit	42.9268314002733646	-78.7881383690450434
37388	2020-07-15 00:48:51	2020-07-15	Mr. Gilmore Tromp Sr.	mr.gilmore.tromp.sr.@geemail.com	San Francisco	California	4668748125322138	faf77f1cf0eb62e9da74422a194586e7	Voyager	37.7866006805808397	-122.481440804184601
37389	2020-07-15 01:15:54	2020-07-15	Jorge Kozey	jorge.kozey@geemail.com	Oxnard	California	3096720302148535098	b8649664e9d83788ffe9be04ca4bd3da	JCB 16 digit	34.1054587518285999	-119.28969986875579
37390	2020-07-15 01:17:07	2020-07-15	Maci Kerluke	maci.kerluke@warmmail.com	North Las Vegas	Nevada	54669513312444775	eb1b4dcd782a43535f9f66bcac8dbd60	Voyager	36.2030057035077348	-115.071398800214382
37391	2020-07-15 01:17:31	2020-07-15	Odus Abbott	odus.abbott@geemail.com	Houston	Texas	3427917655632044	9a40b36c815e228c5fc65b7b29476a39	VISA 16 digit	29.750299969695881	-95.4537116753418076
37392	2020-07-15 01:18:17	2020-07-15	Natalie Romaguera DDS	natalie.romaguera.dds@geemail.com	McKinney	Texas	52518685781958916	497292fcccaf2180674d86235cb1c5fe	JCB 15 digit	33.1203889147508903	-96.5828290980607278
37393	2020-07-15 01:30:26	2020-07-15	Matilde Upton-Wilderman	matilde.upton.wilderman@geemail.com	New York	New York	3462511057303092	75ccc53b7d31b26c827f413961ee5bb9	Mastercard	40.6796893480457342	-73.897890229466185
37394	2020-07-15 01:44:10	2020-07-15	Ms. Katlynn Klein MD	ms.katlynn.klein.md@warmmail.com	Tucson	Arizona	3337984630092569734	a6f6d7187a03caaaa8d55b6bc79882d9	JCB 15 digit	32.153613850152496	-110.883010431308662
37395	2020-07-15 01:46:16	2020-07-15	Alberta Hessel	alberta.hessel@geemail.com	New York	New York	4530028575612114	e3e3ece21c0c04c7e2821e54415bee42	JCB 15 digit	40.7143430262096189	-73.8537965986773344
37396	2020-07-15 01:46:46	2020-07-15	Gabrielle Kassulke	gabrielle.kassulke@geemail.com	Chicago	Illinois	54999802237334000	fd1b89fb50ed80f557cc29cec2549ff3	JCB 15 digit	41.8206560191534464	-87.5930852160818887
37397	2020-07-15 01:47:51	2020-07-15	Josefina Schaden	josefina.schaden@geemail.com	Louisville	Kentucky	3450018653949686	2100de7d8978feb7363891a26000f242	JCB 16 digit	38.2073427443761346	-85.5663624517224832
37398	2020-07-15 01:51:41	2020-07-15	Laisha Volkman	laisha.volkman@geemail.com	Garden Grove	California	6011882034277623957	fd0a51b98dc4cf923de4e118a038fe6b	VISA 16 digit	33.7671930390235033	-117.988261249756434
37399	2020-07-15 01:54:30	2020-07-15	Dr. Sie Kshlerin	dr.sie.kshlerin@woohoo.com	Cleveland	Ohio	3158712949221702373	9fda0e8ffeb0ab6d81b923b56bff008e	Diners Club / Carte Blanche	41.4432841122467011	-81.652369058621673
37400	2020-07-15 02:05:49	2020-07-15	Derald Hills	derald.hills@geemail.com	San Francisco	California	3467510546419167	f00ce2533e296510940f90e55e269078	Maestro	37.7561201492186882	-122.46580258599063
37401	2020-07-15 02:11:06	2020-07-15	Bentley Beahan	bentley.beahan@warmmail.com	San Diego	California	869907504286961226	99680dd6a9d111a43efb05beefca2e40	Diners Club / Carte Blanche	32.8869689446941038	-117.217211904786538
37402	2020-07-15 02:29:32	2020-07-15	Delois Von DVM	delois.von.dvm@geemail.com	Stockton	California	4946300801013799	955bf276918fd0d51ac10c02db894ab3	VISA 16 digit	38.0477342043269431	-121.235459171616654
37403	2020-07-15 02:31:31	2020-07-15	Ms. Arlene Champlin PhD	ms.arlene.champlin.phd@woohoo.com	San Jose	California	3528450929282989032	f083d5d253d574e1a6397393e859c691	VISA 13 digit	37.2784571283318087	-121.800789844685795
37404	2020-07-15 02:39:46	2020-07-15	Savannah Vandervort	savannah.vandervort@geemail.com	Sterling Heights	Michigan	675969982029048	39cf96fd6c8f75619996e516b6981e05	Diners Club / Carte Blanche	42.616936580286179	-83.0922286934845147
37405	2020-07-15 02:43:30	2020-07-15	Lillie Turcotte	lillie.turcotte@geemail.com	Washington	District of Columbia	3112373387169846938	e994fdde5d408c051eb0e456b28a565b	JCB 16 digit	38.9591253945868488	-77.0835640419952597
37406	2020-07-15 02:49:45	2020-07-15	Philo Johnston Jr.	philo.johnston.jr.@geemail.com	Detroit	Michigan	4437670596217383	184dd2d8fb54a921434d79529feadc85	VISA 13 digit	42.3913797856699688	-83.1542386703312388
37407	2020-07-15 03:24:32	2020-07-15	Ms. Dominique Gutkowski	ms.dominique.gutkowski@geemail.com	Baton Rouge	Louisiana	869950020120647604	327de84205f69e61ea3dbd20f139c6be	VISA 16 digit	30.5195481024894875	-91.1335342691853612
37408	2020-07-15 03:49:26	2020-07-15	Sydney Jacobson IV	sydney.jacobson.iv@geemail.com	Fayetteville	North Carolina	210038164313745705	f27542352c1c7746111e4afa619e3038	JCB 16 digit	35.0670973083723325	-78.9147322106771156
37409	2020-07-15 03:52:21	2020-07-15	Matthew Ebert	matthew.ebert@geemail.com	New York	New York	3778222936010906	406ac390b37fcf628180dfd48c0a5012	JCB 16 digit	40.7580104327052837	-73.9903238172072832
37410	2020-07-15 03:55:10	2020-07-15	Pearlene Zulauf	pearlene.zulauf@geemail.com	Long Beach	California	210083160435871811	7cd3eb805b5edc0d549983e7f29f23e1	Discover	33.805876309267056	-118.158007973308855
37411	2020-07-15 03:58:47	2020-07-15	Eleonore Medhurst	eleonore.medhurst@woohoo.com	Sacramento	California	6011325142613924701	a0f704c5174678fde853b3a9f262a120	JCB 15 digit	38.6376512637160729	-121.536876271177448
37412	2020-07-15 04:07:26	2020-07-15	Levar Pollich	levar.pollich@woohoo.com	San Francisco	California	210065367617509810	ab3d58d43e149b41e27e35d3b3fba8a0	VISA 16 digit	37.7771296788911997	-122.43008292058515
37413	2020-07-15 04:31:44	2020-07-15	Brandyn Herman-Goodwin	brandyn.herman.goodwin@geemail.com	Elk Grove	California	54483173008651383	d11dee7ca65acc0e154462e9282dab03	American Express	38.3902148345768452	-121.381503140684217
37414	2020-07-15 04:31:51	2020-07-15	Beckett Shanahan-Morissette	beckett.shanahan.morissette@warmmail.com	New York	New York	4804004165750183	6657ab2563490a514eb95a56896f39b2	VISA 16 digit	40.7231049534156924	-73.9111342273548217
37415	2020-07-15 04:40:37	2020-07-15	Prudie Spinka	prudie.spinka@geemail.com	Vacaville	California	3799147140615460	b60ca5e081720e127fc91b2911f19d11	VISA 16 digit	38.4418557793960005	-121.926638540101436
37416	2020-07-15 04:50:58	2020-07-15	Miss Madilyn Purdy DDS	miss.madilyn.purdy.dds@warmmail.com	New York	New York	6011422009380770256	484f447364dd63555e6929a1da2a621d	Voyager	40.7171987861618376	-73.8596772194735678
37417	2020-07-15 04:54:20	2020-07-15	Golda Boyle	golda.boyle@woohoo.com	Chula Vista	California	6011036459409948268	53333187348c2371196e726088e40e53	JCB 16 digit	32.5709126234285478	-117.039372477703537
37418	2020-07-15 04:58:03	2020-07-15	Griffith Donnelly	griffith.donnelly@geemail.com	Baton Rouge	Louisiana	6011144665115769520	1261d758a7b77ac08cab10ef6e957322	Voyager	30.4407144583974016	-91.0989998155847189
37419	2020-07-15 05:15:42	2020-07-15	Terese Larkin	terese.larkin@geemail.com	Simi Valley	California	3480141514064737	37003cabf134405bfe9c68b0a86b2d8d	American Express	34.2594764521118265	-118.823966392096139
37420	2020-07-15 05:19:35	2020-07-15	Shalonda Beier	shalonda.beier@geemail.com	Pittsburgh	Pennsylvania	210039381108294850	de69d9945c02ca35012bc0e5a488522f	Diners Club / Carte Blanche	40.5282902032557857	-79.9050545808564863
37421	2020-07-15 05:21:05	2020-07-15	Parrish Collins	parrish.collins@geemail.com	New York	New York	52768337149288274	4bba0a05583a7835ba4b9e180f4fb1ac	Discover	40.7443857399970284	-73.9331282393436879
37422	2020-07-15 05:22:05	2020-07-15	Cristobal Jacobson-Balistreri	cristobal.jacobson.balistreri@geemail.com	New York	New York	869979662653369762	a58d5d0ea3b27c094ee51d3716729faf	American Express	40.6939754170123464	-73.8794874460797786
37423	2020-07-15 05:34:25	2020-07-15	Tyquan Romaguera IV	tyquan.romaguera.iv@warmmail.com	Akron	Ohio	4541182331093	90448a5569bd2697886d0405ecc9e58d	JCB 15 digit	41.1202441873326876	-81.5118410887975244
37424	2020-07-15 05:34:41	2020-07-15	Julius Hintz DVM	julius.hintz.dvm@warmmail.com	Evansville	Indiana	6011451538342027219	c34dfe9b5d6c8956f91465d3d3c1a9a3	JCB 16 digit	38.0287752354655382	-87.6245547635413686
37425	2020-07-15 05:37:48	2020-07-15	Matteo Rempel	matteo.rempel@geemail.com	New York	New York	869902174495957947	f53746a53b0b21f08b3919598e582bd4	JCB 16 digit	40.6738427161928229	-73.9709271911427351
37426	2020-07-15 05:47:10	2020-07-15	Ura Kuvalis	ura.kuvalis@woohoo.com	Aurora	Illinois	4356261537118	77bafa9ca853f0797d44ef366e5d2772	Maestro	41.8519268081747029	-88.2182760929152323
37427	2020-07-15 05:50:14	2020-07-15	Syed Cormier	syed.cormier@warmmail.com	Charlotte	North Carolina	676352814905718	dcbb66f873eaa791c53cc6f2e1bc2ddc	Maestro	35.1628414055120189	-80.7433646948486654
37428	2020-07-15 05:56:53	2020-07-15	Deron Collins	deron.collins@geemail.com	New York	New York	4686553395677825	75e28e60232564179334201bfa6256dc	VISA 16 digit	40.6159329896084955	-73.8744550399843547
37429	2020-07-15 06:28:36	2020-07-15	Mintie Hamill-Trantow	mintie.hamill.trantow@woohoo.com	Chicago	Illinois	630481587917824	7bacc76aba66c843d2fc6bf5ce0c4ae2	VISA 13 digit	41.9326097632594426	-87.6026694294560713
37430	2020-07-15 06:31:40	2020-07-15	Tuan Bednar-Friesen	tuan.bednar.friesen@warmmail.com	Charlotte	North Carolina	4402366096566	08ab51a6223e168c2a619fed7a04600c	VISA 13 digit	35.2055192100137475	-80.8248465996179704
37431	2020-07-15 06:45:20	2020-07-15	Carli Padberg	carli.padberg@geemail.com	San Francisco	California	869986990382637279	0e477d30f2e4627277cbfbe9a57a4705	Mastercard	37.7681127446622611	-122.417855239363178
37432	2020-07-15 06:48:31	2020-07-15	Syreeta Kshlerin	syreeta.kshlerin@geemail.com	Renton	Washington	6011902303290614400	0500306d974fcfcbe873fb8dff0cc519	JCB 16 digit	47.4994238348737383	-122.202182385332875
37433	2020-07-15 06:55:27	2020-07-15	Melva Durgan-Schmeler	melva.durgan.schmeler@geemail.com	Davenport	Iowa	4295468069994377	c3a62d8909296958fc424acbc360c166	Mastercard	41.5223619773782744	-90.5604515145961244
37434	2020-07-15 06:57:04	2020-07-15	Neva Cummings	neva.cummings@geemail.com	Chicago	Illinois	4838679702573873	bc1b58b5cfaaaf998b12ddd7b9e924f0	JCB 15 digit	41.8345924560282398	-87.76797119137197
37435	2020-07-15 07:00:52	2020-07-15	Erving Schmidt	erving.schmidt@geemail.com	San Francisco	California	4889355490373309	484463f18dc4c44080e52a18bb9fe5c0	VISA 16 digit	37.7922902729952312	-122.451420984357881
37436	2020-07-15 07:02:54	2020-07-15	Mr. Claud Robel I	mr.claud.robel.i@woohoo.com	Riverside	California	3337847038735239151	21dcdb676906958fd49a37f9672aba6b	VISA 13 digit	33.8643208350468399	-117.488374359669905
37437	2020-07-15 07:04:29	2020-07-15	Davin Ryan	davin.ryan@woohoo.com	Washington	District of Columbia	54851254087476829	3041ef46efdc5929d2bbc708f3923681	VISA 16 digit	38.9202039937287552	-77.0899539381943697
37438	2020-07-15 07:40:12	2020-07-15	Walt Hane	walt.hane@geemail.com	Columbus	Ohio	501885473805399	fed1d78d4496838551d376ba54777cf7	Diners Club / Carte Blanche	39.9390890292867979	-82.9714880910005519
37439	2020-07-15 07:41:13	2020-07-15	Dr. Immanuel Thiel Sr.	dr.immanuel.thiel.sr.@geemail.com	San Francisco	California	869980554277031398	6e41d4773471e8e0fd52eb6bd26b6ada	Mastercard	37.7545159897578841	-122.450353182326623
37440	2020-07-15 08:04:11	2020-07-15	Myrl Hintz	myrl.hintz@geemail.com	Akron	Ohio	55890154424341517	7faa1e2d3c3a4cf0f28aef8638eaee46	VISA 16 digit	40.9967442216649687	-81.4480133549157586
37441	2020-07-15 08:08:37	2020-07-15	Tavian Crooks	tavian.crooks@geemail.com	Berkeley	California	3433624738035953	b3963d364d1b15a3dc23c9912f677315	American Express	37.8552407875297092	-122.264916170853937
37442	2020-07-15 08:25:46	2020-07-15	Aleta Kutch DVM	aleta.kutch.dvm@woohoo.com	San Francisco	California	3088869528504337163	dbfa75b744f28951ef4b38660a601a6e	JCB 16 digit	37.7593673563042103	-122.458623002903607
37443	2020-07-15 08:29:05	2020-07-15	Cordell Smith	cordell.smith@geemail.com	Fayetteville	North Carolina	4292146757029	9dc87fbd0c3d9fec24c37a0727117b59	Maestro	34.988894329990444	-78.9409673768691675
37444	2020-07-15 08:31:45	2020-07-15	Denisha Stokes DVM	denisha.stokes.dvm@geemail.com	San Antonio	Texas	502096325313839	31da6ab851b4e129bfabf96e2c9af979	VISA 16 digit	29.5261313027773049	-98.4551963860936468
37445	2020-07-15 08:33:01	2020-07-15	Rena Hamill	rena.hamill@geemail.com	Indianapolis	Indiana	3758117064387205	b9076d99102bbc1e8faf075c0cc0084c	VISA 13 digit	39.8526590476285634	-86.1589304547958079
37446	2020-07-15 08:39:35	2020-07-15	Mr. Delvin Waelchi Jr.	mr.delvin.waelchi.jr.@geemail.com	Baton Rouge	Louisiana	3042908714108794	d735635c42f7815a46870c6a16a8dcd4	American Express	30.4173961905043555	-91.0628163106381834
37447	2020-07-15 08:44:39	2020-07-15	Shellie Crooks	shellie.crooks@geemail.com	Oakland	California	3088910235752702085	76492fa9153324d12add7cc61e18f2e2	VISA 16 digit	37.7615813896183781	-122.261839567804145
37448	2020-07-15 08:44:51	2020-07-15	Aurthur Langosh	aurthur.langosh@geemail.com	Santa Ana	California	4707973754819625	eae795e0a4f6dbebe9dab7b0ca43138c	Mastercard	33.7781416441883877	-117.818745000373568
37449	2020-07-15 08:45:11	2020-07-15	Ashby Fahey	ashby.fahey@warmmail.com	Oxnard	California	3437138299895347	5efa95a9a266fd2717fa20c08523bab4	VISA 16 digit	34.1760474683206539	-119.211968066487827
37450	2020-07-15 09:00:02	2020-07-15	Ab Murray	ab.murray@geemail.com	San Bernardino	California	3022433681995867	5dc0204c9faa1ed79c5016491343f9ea	VISA 16 digit	34.0958074977420225	-117.288195703575752
37451	2020-07-15 09:07:46	2020-07-15	Gaylon Orn-Hegmann	gaylon.orn.hegmann@geemail.com	San Francisco	California	6011024439023894464	e5d34471ea8b3c911d1a92e362e6a831	Voyager	37.7977099585646101	-122.463243970173878
37452	2020-07-15 09:17:33	2020-07-15	Ivory Brown-Treutel	ivory.brown.treutel@geemail.com	New York	New York	3112209031581658121	7e2f5811a7083864a472d221bc4dc7a6	VISA 13 digit	40.6811599403377642	-73.9399560273986225
37453	2020-07-15 09:25:38	2020-07-15	Miss Vertie Goldner	miss.vertie.goldner@warmmail.com	Arlington	Texas	3054252346645941	cb0f9512eeebd5ddd444f27e6634a13a	JCB 15 digit	32.678367395304889	-97.1869601134702634
37454	2020-07-15 09:35:21	2020-07-15	Jeanine Kuhn	jeanine.kuhn@geemail.com	Surprise	Arizona	6011017584152090894	cffa743c8bde47dc6df4c83650beb867	Voyager	33.6846209173317988	-112.367866315576052
37455	2020-07-15 09:36:01	2020-07-15	Delisa Mueller	delisa.mueller@woohoo.com	Huntsville	Alabama	869921346864003118	455c4c657a1c2459facd16bc93941cd0	Discover	34.6511566069219228	-86.6715185777302821
37456	2020-07-15 09:37:34	2020-07-15	Ginger Kling	ginger.kling@geemail.com	Long Beach	California	060478644901429	9eecd8075c391aba899c1f6bace1fda7	JCB 15 digit	33.8928163825821116	-118.128414535305652
37457	2020-07-15 09:52:43	2020-07-15	Mr. Erland Howell	mr.erland.howell@woohoo.com	Lafayette	Louisiana	180067621663355884	0adb0fb286ad658fb4d08318f33f076e	JCB 16 digit	30.2028560105688868	-91.9671963967233808
37458	2020-07-15 09:52:48	2020-07-15	Miss Jerrica Kuhlman	miss.jerrica.kuhlman@geemail.com	Boston	Massachusetts	869935419253507298	57c6323847337f7e0c8e9541d5127b34	JCB 15 digit	42.3709781790319866	-70.9516031837973742
37459	2020-07-15 09:53:28	2020-07-15	Hervey Yost	hervey.yost@geemail.com	New York	New York	503803089118941	20e47079ef3e109298580c3aa6d1c61f	VISA 16 digit	40.7551268127504756	-74.0097153137799353
37460	2020-07-15 10:00:52	2020-07-15	Dr. Theda Koepp	dr.theda.koepp@geemail.com	Berkeley	California	4457154891721386	6b751684d7c64b8c343702653a5485c1	JCB 16 digit	37.8826906739575548	-122.298970925260463
37461	2020-07-15 10:05:06	2020-07-15	Tania VonRueden	tania.vonrueden@geemail.com	Carlsbad	California	3481253991937316	bcb86fb0026837766eb04cc439e96a3d	Diners Club / Carte Blanche	33.158661975612489	-117.279690595648432
37462	2020-07-15 10:05:37	2020-07-15	Bode Heller	bode.heller@warmmail.com	San Jose	California	4769712220888	45198aa6700544a3d979e4f4e482da74	JCB 16 digit	37.2005613625802098	-121.849592238407212
37463	2020-07-15 10:14:43	2020-07-15	Florentino Gleason	florentino.gleason@geemail.com	Washington	District of Columbia	6011348848578412507	acc12ddb43ead500e1715221b8e0b9bd	American Express	38.9396062995571626	-76.9918056961361401
37464	2020-07-15 10:19:45	2020-07-15	Claribel Herman	claribel.herman@geemail.com	Nashville	Tennessee	3096232678352001096	4acd7c6c5f203004beafbb7a308411eb	JCB 16 digit	36.0853565903037747	-86.8369623504020183
37465	2020-07-15 10:26:06	2020-07-15	Dr. Talmadge Cummerata DDS	dr.talmadge.cummerata.dds@geemail.com	Las Vegas	Nevada	4661262760282	c3e437b15cc5f2eab0c0ef26f96467d7	Voyager	36.2713348762698473	-115.348696514053643
37466	2020-07-15 10:27:53	2020-07-15	Shasta Schamberger	shasta.schamberger@geemail.com	Oxnard	California	210089654031848615	7638730d15ba2f1a75033a7e94768b17	JCB 16 digit	34.2646648533597613	-119.28440758533813
37467	2020-07-15 10:32:40	2020-07-15	Dr. Trinidad Grant III	dr.trinidad.grant.iii@geemail.com	Palm Bay	Florida	4953609336070300	248e9048c950db03bb62dea86e7e659b	VISA 16 digit	28.0561530490726234	-80.6209649252075735
37468	2020-07-15 10:35:16	2020-07-15	Ceil Hilll	ceil.hilll@geemail.com	Chesapeake	Virginia	6011803249676335294	b20cdc21e076c35e6e2d8d1824968fd7	VISA 16 digit	36.6377767940290298	-76.2747421837255359
37469	2020-07-15 10:56:20	2020-07-15	Rylie Ledner DDS	rylie.ledner.dds@geemail.com	Phoenix	Arizona	3096764849734225069	5b9f958215e585c70a0432e4512ab3dd	JCB 16 digit	33.5518435502357804	-112.098463846363501
37470	2020-07-15 11:07:08	2020-07-15	Killian Bergstrom	killian.bergstrom@warmmail.com	Los Angeles	California	4149852384407470	60d5f616dbbdf99f6f07cd72f4faf774	JCB 16 digit	33.9505795902438408	-118.4706789227195
37471	2020-07-15 11:12:42	2020-07-15	Debera Ernser	debera.ernser@warmmail.com	Lubbock	Texas	3528195494083083584	911304d1e47acb78d196f6d366129296	VISA 16 digit	33.5789547738194472	-101.806866074577727
37472	2020-07-15 11:25:24	2020-07-15	West Jenkins	west.jenkins@warmmail.com	New York	New York	3112796677481762741	554ebb05284ab908f77c1d23974d8443	Diners Club / Carte Blanche	40.5735671800319082	-74.0192141927674356
37473	2020-07-15 11:31:13	2020-07-15	Vaughn Bernhard	vaughn.bernhard@geemail.com	Centennial	Colorado	52600047501963008	40f48f5a33c0271e0fd6bb69eb880375	JCB 16 digit	39.6390130120836233	-104.77190816336163
37474	2020-07-15 11:31:36	2020-07-15	Gorge Tremblay	gorge.tremblay@warmmail.com	Pasadena	Texas	3794294049825132	135294d2e0bf43050105d079a5c2a23c	VISA 16 digit	29.720230311980842	-95.160555508075646
37475	2020-07-15 11:31:43	2020-07-15	Branch Rempel	branch.rempel@geemail.com	New York	New York	4800192572082	6e76cc3ccdf26a16a033ce040fd774ec	JCB 15 digit	40.6059737290479248	-73.8493293136719586
37476	2020-07-15 11:37:59	2020-07-15	Lum Braun	lum.braun@geemail.com	Fort Wayne	Indiana	3492713257242831	0c5c00ed2d893ff7e2990bce0d68a9a9	JCB 16 digit	41.0101228727277345	-85.1687508423101178
37477	2020-07-15 11:44:16	2020-07-15	Penelope Padberg MD	penelope.padberg.md@geemail.com	Denton	Texas	4947889881392221	65a87c960f8d6fc3c66bd22174a6b01c	American Express	33.2590858539365257	-97.1498197049029244
37478	2020-07-15 11:44:38	2020-07-15	Norris Thiel	norris.thiel@geemail.com	San Francisco	California	4472616100361379	591145f87f95950349bedc07b3c0f42a	American Express	37.7458626898738601	-122.437298420319706
37479	2020-07-15 11:45:28	2020-07-15	Ned O'Hara	ned.o'hara@warmmail.com	Nashville	Tennessee	3713877093502579	ef25ca50cbe4abab042739c24499270b	VISA 16 digit	36.1402916606172866	-86.6909710262808915
37480	2020-07-15 11:46:37	2020-07-15	Kenna Konopelski-Berge	kenna.konopelski.berge@geemail.com	Huntington Beach	California	4655239917758114	eb58de903f93fc29f7a62cfad408b525	Diners Club / Carte Blanche	33.6899121842853759	-117.994688634074478
37481	2020-07-15 11:50:10	2020-07-15	Mrs. Fallon Steuber DVM	mrs.fallon.steuber.dvm@woohoo.com	San Francisco	California	502072708256093	b32fddf5a1f11d0ea61a149f86f4b0e7	Mastercard	37.7845787073054353	-122.434551190883354
37482	2020-07-15 11:59:19	2020-07-15	Cortney Reynolds	cortney.reynolds@geemail.com	Huntsville	Alabama	6011434497650693967	ea92487b282ded3ce01a5f0a291c6b3f	VISA 13 digit	34.7385748117472986	-86.6887702704425891
37483	2020-07-15 11:59:44	2020-07-15	Dellar Luettgen	dellar.luettgen@geemail.com	Austin	Texas	3158649852993933143	0c70bd921799e1c36c9990f06dea0965	Maestro	30.2187896669037634	-97.7682422563206472
37484	2020-07-15 12:01:54	2020-07-15	Sydney Vandervort	sydney.vandervort@geemail.com	Akron	Ohio	54441652169441677	3836da88572c27e5cfaf4b216f7e37bd	Diners Club / Carte Blanche	41.1150647495705641	-81.552652052774647
37485	2020-07-15 12:11:03	2020-07-15	Arvel Wunsch	arvel.wunsch@warmmail.com	Albuquerque	New Mexico	6011819881334049446	277cba69d9510e2a65cfaa3ae2871617	VISA 13 digit	35.1688095323875558	-106.63309751936012
37486	2020-07-15 12:16:26	2020-07-15	Luda McDermott DDS	luda.mcdermott.dds@geemail.com	Omaha	Nebraska	869936261605954722	19dada184be042d59ac95fbe26516324	Diners Club / Carte Blanche	41.3443786600284326	-96.0676583032704912
37487	2020-07-15 12:20:31	2020-07-15	Shane Douglas	shane.douglas@geemail.com	Phoenix	Arizona	3799826769818410	c6b3f7b5dc71bed51f79130d6b922b42	JCB 15 digit	33.6055897748030716	-112.183941372709725
37488	2020-07-15 12:20:39	2020-07-15	Rudy Bernier	rudy.bernier@geemail.com	San Jose	California	4201895910827773	668f41464fd3267cfb6525f0833b67fd	Diners Club / Carte Blanche	37.3623390382908269	-121.839174177845564
37489	2020-07-15 12:33:39	2020-07-15	George Macejkovic IV	george.macejkovic.iv@warmmail.com	Sunnyvale	California	4526126525165	a34d8559fe724e6ce233d08510fdbc59	VISA 16 digit	37.4269311927251564	-122.013894074429956
37490	2020-07-15 12:43:36	2020-07-15	Foster Murphy II	foster.murphy.ii@geemail.com	Fort Worth	Texas	4387494631766	291d940d33121f823576eee62d945ee7	VISA 16 digit	32.7765059789232893	-97.3651914693236336
37491	2020-07-15 12:49:26	2020-07-15	Rudolfo Gulgowski II	rudolfo.gulgowski.ii@geemail.com	Hayward	California	4360957245762	3ba2a260955d2227e959ca08b9cda4c0	JCB 16 digit	37.5531817775208552	-122.082293384361648
37492	2020-07-15 13:00:10	2020-07-15	Elonzo Johnston	elonzo.johnston@geemail.com	Columbus	Georgia	51034604465594108	8ae8ac75175e083a3effbef679a9a849	JCB 16 digit	32.5669591398023073	-84.8994817031245645
37493	2020-07-15 13:03:13	2020-07-15	Mrs. Stacie Parisian	mrs.stacie.parisian@warmmail.com	Mobile	Alabama	54328596267013144	14fd4e987f706f09477e81410f277172	Diners Club / Carte Blanche	30.7465076497398293	-88.0673769180335171
37494	2020-07-15 13:06:33	2020-07-15	Florencio Collier	florencio.collier@warmmail.com	New York	New York	6011956442959380013	1852fe018611c0a7ca9125aba24fa65a	Maestro	40.6376811538580824	-74.0337949622783782
37495	2020-07-15 13:12:35	2020-07-15	Bascom Jast	bascom.jast@geemail.com	Chicago	Illinois	51587681640890891	789fd47e33c097b7cae0b547b75fc7ab	Discover	41.7805928329307577	-87.7500847986929102
37496	2020-07-15 13:13:48	2020-07-15	Beecher Schinner	beecher.schinner@geemail.com	Phoenix	Arizona	4483563141173	e1841f1ff9caab39b5547d9ed94860ae	Maestro	33.6119279877215646	-112.09591205529162
37497	2020-07-15 13:14:08	2020-07-15	Dr. Tambra Hettinger PhD	dr.tambra.hettinger.phd@geemail.com	Norfolk	Virginia	210098315372452453	703dad14cb0d4d7a2f2d72280eb7ac51	VISA 16 digit	36.8714651101753148	-76.2031936821531559
37498	2020-07-15 13:49:15	2020-07-15	Abie Quitzon-Morissette	abie.quitzon.morissette@geemail.com	Jersey City	New Jersey	675911771614408	afe8090cb45a31f20e7432da6defcdf8	JCB 16 digit	40.7448766158834061	-73.9731189580589614
37499	2020-07-15 14:04:00	2020-07-15	Braxton Murazik	braxton.murazik@woohoo.com	Rancho Cucamonga	California	210042608982090524	73c4c313be1138c0d748d3fdbcfcfd59	Maestro	34.1628235623698657	-117.643927120790636
37500	2020-07-15 14:07:09	2020-07-15	Emanuel Rogahn	emanuel.rogahn@warmmail.com	Las Vegas	Nevada	210041344275016023	5ce22ee6431f22cfa223e00933e81940	VISA 16 digit	36.1752141939576717	-115.280180853998658
37501	2020-07-15 14:14:53	2020-07-15	Miss Jacquline Hills DDS	miss.jacquline.hills.dds@geemail.com	San Francisco	California	869964016250292694	f57c6d55ebf695f173b6aaceaea9bf32	Maestro	37.7879784546770026	-122.430416632698169
37502	2020-07-15 14:21:34	2020-07-15	Mora Romaguera	mora.romaguera@warmmail.com	Amarillo	Texas	180086902873686731	280dd66050c0284b85b964e5446118d7	Discover	35.2411909018807137	-101.784939057691773
37503	2020-07-15 14:40:38	2020-07-15	Davis Schiller	davis.schiller@geemail.com	El Paso	Texas	3528217973673665417	7d17215d71f2916fbedeb22b210de272	VISA 16 digit	31.7488332761745902	-106.371522385345784
37504	2020-07-15 14:43:33	2020-07-15	May Treutel-Mayert	may.treutel.mayert@geemail.com	Dallas	Texas	3112505847408182875	08b65e79167a23dc2e85eaea6af33f40	Diners Club / Carte Blanche	32.8599395306587212	-96.7421337337195837
37505	2020-07-15 14:43:46	2020-07-15	Jalyn Heaney	jalyn.heaney@geemail.com	Detroit	Michigan	3337282583047268655	970d4f792278770f2d8fdb7c0f496412	VISA 16 digit	42.4346904962714788	-83.1747318794604382
37506	2020-07-15 14:44:02	2020-07-15	Brown Pfeffer	brown.pfeffer@geemail.com	Lexington	Kentucky	4402372978595947	8d787012b84f0977466b64f711a3d8ed	VISA 16 digit	38.1216097263962013	-84.4435503416128341
37507	2020-07-15 14:45:30	2020-07-15	Charlene Schultz	charlene.schultz@geemail.com	New York	New York	4462287186524	5eb7b5ad2f0943fe7c433c26ffd12e73	Voyager	40.5897449217028878	-73.853454913374776
37508	2020-07-15 14:58:01	2020-07-15	Jeb Schamberger	jeb.schamberger@warmmail.com	San Francisco	California	55892819466845785	3cbd29e66fc04cc865e7f78fba023ade	Mastercard	37.7776737189424665	-122.453572180739556
37509	2020-07-15 15:08:38	2020-07-15	Caswell Funk Sr.	caswell.funk.sr.@geemail.com	Murfreesboro	Tennessee	52443385896590759	a48cd5447396d380c6e11b8c50170407	Diners Club / Carte Blanche	35.9457636202804807	-86.3531623372193451
37510	2020-07-15 15:11:08	2020-07-15	Siddie Gerhold	siddie.gerhold@geemail.com	New York	New York	3027276221443574	43b9a0f66b01d927fe2f1702d7d9c096	American Express	40.6128420835584407	-73.8546901140257717
37511	2020-07-15 15:18:52	2020-07-15	Orville Willms-Schaden	orville.willms.schaden@geemail.com	Sparks	Nevada	3528018590736233008	a4cd5d680391676aaaeb26f25a7b6b6d	American Express	39.5797689271863575	-119.662286399104076
37512	2020-07-15 15:24:07	2020-07-15	Juliann Konopelski PhD	juliann.konopelski.phd@geemail.com	Omaha	Nebraska	180072680945010199	b45b612e2d2c1b76763aaa76ff2df3e9	VISA 13 digit	41.3342559274896999	-95.972056663839524
37513	2020-07-15 15:24:37	2020-07-15	Candyce Treutel	candyce.treutel@woohoo.com	Durham	North Carolina	3733794684302432	51a97166259585d7b49eebe17c096886	VISA 16 digit	35.9716633952468641	-78.962449978841093
37514	2020-07-15 15:24:53	2020-07-15	Barbie Johns MD	barbie.johns.md@geemail.com	Albuquerque	New Mexico	3727777010784678	cc2842856cb0e6e98a45c9c9bdb0be9b	American Express	35.0171523704793302	-106.634947327810906
37515	2020-07-15 15:31:02	2020-07-15	Denisse Bosco MD	denisse.bosco.md@woohoo.com	Laredo	Texas	4679595746794	1d4d0f5da034f4054da87b8827238dad	American Express	27.4615419852264253	-99.4788442360710263
37516	2020-07-15 15:36:53	2020-07-15	Miss Manila Crist MD	miss.manila.crist.md@geemail.com	Wilmington	North Carolina	869937187927970642	b691aec62bf881e44d9df1f3981264d7	Voyager	34.1269256341092344	-77.9142931524656746
37517	2020-07-15 15:39:22	2020-07-15	Zachariah Gusikowski-Anderson	zachariah.gusikowski.anderson@geemail.com	Cincinnati	Ohio	4610024835544	12054d9f44c20ddbb8d0c8185a37e4ff	VISA 13 digit	39.1288197976768046	-84.4212274701606447
37518	2020-07-15 15:42:01	2020-07-15	Charlie Dietrich	charlie.dietrich@woohoo.com	Fremont	California	4914483828895	a62bccc13690d89c9cd539a109a025cb	Voyager	37.5588762274645305	-121.963000957899538
37519	2020-07-15 15:44:21	2020-07-15	Mr. Tyron Heller	mr.tyron.heller@geemail.com	Garland	Texas	503829089324494	0fd629aa3c2113a3c6096b233ff4e4c7	Voyager	32.900762517261505	-96.5441542525936001
37520	2020-07-15 15:45:52	2020-07-15	Dr. Victoria Johnson MD	dr.victoria.johnson.md@geemail.com	Berkeley	California	4142787607857852	64a8f0ef0e9dd694e524cd1e50033574	Discover	37.8770675698843249	-122.286346192731401
37521	2020-07-15 15:54:06	2020-07-15	Emelia Bernier	emelia.bernier@woohoo.com	Fort Worth	Texas	210038150534397095	77afe65e05080a9c29c5e952a54f378d	Diners Club / Carte Blanche	32.7876269942671072	-97.2895836897481274
37522	2020-07-15 15:58:40	2020-07-15	Elmer Rau	elmer.rau@geemail.com	Houston	Texas	4879610720572	6804dac8726f0f0796dd5f9885744b0e	VISA 13 digit	29.7554006513752043	-95.2931603614255778
37523	2020-07-15 16:06:49	2020-07-15	Plummer Kutch	plummer.kutch@geemail.com	Phoenix	Arizona	3457581668548507	55ecca4f84001ab331dfc854d1406ab9	American Express	33.5592781070552775	-112.150835074616978
37524	2020-07-15 16:06:55	2020-07-15	Orie Harris	orie.harris@geemail.com	Las Vegas	Nevada	4722569677130	e52f8590b72d6ba397473caeedaae1a3	VISA 16 digit	36.2662215281844098	-115.284401047530025
37525	2020-07-15 16:06:57	2020-07-15	Clarissa Schaden	clarissa.schaden@geemail.com	Berkeley	California	3528471333080949501	91419f5a506260fd7bcfc50ce86213c0	VISA 13 digit	37.8809126940478578	-122.253582698769023
37526	2020-07-15 16:16:06	2020-07-15	Dr. Broderick Walter	dr.broderick.walter@geemail.com	Newark	New Jersey	210055582553530115	a4f43bfbf38e53b7e2e64577926d99f8	JCB 16 digit	40.6689614094242486	-74.2230640560131576
37527	2020-07-15 16:30:21	2020-07-15	Hamza Schuster	hamza.schuster@geemail.com	San Francisco	California	180048603129136870	b3c8c9d8ad9e689bfa528a74cca9791a	Voyager	37.7806594181053299	-122.426216974327843
37528	2020-07-15 16:31:10	2020-07-15	Ms. Sunday Konopelski MD	ms.sunday.konopelski.md@geemail.com	Killeen	Texas	210025715519914117	95c42edf2bffe5298a38b6137816aea9	VISA 16 digit	31.0268874412167825	-97.7853671570941856
37529	2020-07-15 16:35:35	2020-07-15	Linsey Cremin	linsey.cremin@woohoo.com	Chicago	Illinois	3088164472093801994	dee9fa7d435ac1b912bdae1e1283ff2b	VISA 16 digit	41.8848956636920562	-87.6809933732293558
37530	2020-07-15 16:36:40	2020-07-15	Carie Blick	carie.blick@warmmail.com	San Francisco	California	4021467122555721	b8b490ce4a3b6857cbe8572813792a42	JCB 16 digit	37.7810102588409151	-122.428861701373066
37531	2020-07-15 16:37:14	2020-07-15	Fran Waelchi MD	fran.waelchi.md@warmmail.com	San Francisco	California	869922009047856575	34465c645cf0e5a607cf267684185955	American Express	37.7402668038596829	-122.434030682745842
37532	2020-07-15 16:53:58	2020-07-15	Almon O'Keefe	almon.o'keefe@woohoo.com	San Francisco	California	6011537845430129809	7f76642e0ed46c1178f24204ea63bd27	Diners Club / Carte Blanche	37.8037173652814573	-122.409540789346579
37533	2020-07-15 17:04:42	2020-07-15	Olinda Braun	olinda.braun@warmmail.com	San Francisco	California	869929195692845931	c0d59c81a491cb9300f651926f083895	Discover	37.7934093759955942	-122.381509351892774
37534	2020-07-15 17:06:21	2020-07-15	Jeryl Marquardt-Hackett	jeryl.marquardt.hackett@geemail.com	San Francisco	California	502042212199097	e045b5dd4db24ebcd8d58419ffac7408	JCB 16 digit	37.7697646798202769	-122.427104152610809
37535	2020-07-15 17:13:37	2020-07-15	Mr. Jordan Ernser DVM	mr.jordan.ernser.dvm@geemail.com	Clinton	Michigan	869970274887826069	409d28695e6122522e18e271981af7c7	Maestro	42.5257366895277045	-82.8695510567706037
37536	2020-07-15 17:17:03	2020-07-15	Reilly Pfeffer	reilly.pfeffer@geemail.com	San Francisco	California	6011088080141329646	34a1cb1f35a6f7bbc9ccced75d1b7983	Diners Club / Carte Blanche	37.7487459942423484	-122.425178687451364
37537	2020-07-15 17:17:31	2020-07-15	Rosalind Ward	rosalind.ward@geemail.com	Wichita	Kansas	3337288373905386474	3de69018ddd46ee987e4afd996a917e0	JCB 16 digit	37.7247493288822469	-97.2901311256658232
37538	2020-07-15 17:26:22	2020-07-15	Dellie Weissnat	dellie.weissnat@geemail.com	Seattle	Washington	3025508964757402	dcd056d0b64856ae65462086744c2f3e	VISA 16 digit	47.5840548418853402	-122.360848935639112
37539	2020-07-15 17:35:11	2020-07-15	Aili Bergnaum	aili.bergnaum@geemail.com	New York	New York	561247134187542	3d047ac4e4a82f390297b3e891abe059	VISA 13 digit	40.5788127907309644	-74.0252606072824477
37540	2020-07-15 17:46:25	2020-07-15	Rex Ortiz	rex.ortiz@geemail.com	Huntington Beach	California	4863482056980614	d8f83380f4a8cce511fa7d16dd342fc8	VISA 16 digit	33.6078467943746659	-117.996104529698556
37541	2020-07-15 18:03:43	2020-07-15	Arletta Ankunding	arletta.ankunding@geemail.com	Rochester	New York	6011198662535986797	a534ff7c00535bc603ee4f9167376cca	VISA 16 digit	43.136413959597796	-77.537736472045637
37542	2020-07-15 18:05:33	2020-07-15	Donald Wintheiser	donald.wintheiser@geemail.com	Mobile	Alabama	4853192949037264	bfe4cb9589f1ce2823c9fa33fcd7876b	VISA 16 digit	30.7627922630511215	-88.1805158930502841
37543	2020-07-15 18:12:00	2020-07-15	Kaela Buckridge	kaela.buckridge@woohoo.com	Oakland	California	3464988603480616	6fb124ea48bf8f8a1099b2228b8a4a05	Maestro	37.7944846886069215	-122.260050361438601
37544	2020-07-15 18:21:24	2020-07-15	Colonel Abshire	colonel.abshire@geemail.com	Bakersfield	California	4239133267132	61db0e91c19d87d09e97a2a093395cd3	Diners Club / Carte Blanche	35.3263372667774505	-118.94807734468877
37545	2020-07-15 18:29:10	2020-07-15	Madison Ruecker-Jaskolski	madison.ruecker.jaskolski@geemail.com	New York	New York	869926913478145794	861498ed8e4225fd68fc7d57a29330ff	JCB 16 digit	40.6315390136782071	-73.9592302250571549
37546	2020-07-15 18:30:14	2020-07-15	Giovanna Feest	giovanna.feest@geemail.com	Tulsa	Oklahoma	55172862566020843	7b7d6f372b08b216cb0318c9b310d34d	VISA 13 digit	36.0517760036881967	-95.8906795400150145
37547	2020-07-15 18:30:30	2020-07-15	Jamar Okuneva	jamar.okuneva@geemail.com	Phoenix	Arizona	3421293043301007	e8954f1884a933fd0404047d13841cf5	Diners Club / Carte Blanche	33.6474826405223482	-112.078739380270619
37548	2020-07-15 18:34:15	2020-07-15	Brittny Feil	brittny.feil@warmmail.com	Modesto	California	3030564276971244	d18f6cb6d40d2369518c770056ca2798	JCB 15 digit	37.57053346843459	-121.089671732598916
37549	2020-07-15 18:34:49	2020-07-15	Mrs. Maria Kshlerin PhD	mrs.maria.kshlerin.phd@woohoo.com	Fairfield	California	6011726401814710573	821cb1ee52ef3acbbd7dc8654e088db5	JCB 16 digit	38.3359002055723224	-121.948275130009648
37550	2020-07-15 18:37:07	2020-07-15	Mr. Tyreese Hane III	mr.tyreese.hane.iii@geemail.com	Oakland	California	869963196029900990	12c2c1c1337cebe017911533a8911276	Discover	37.7976188567032878	-122.262785188573332
37551	2020-07-15 18:39:46	2020-07-15	Dr. Toby Mohr	dr.toby.mohr@woohoo.com	San Francisco	California	869942301935817512	0873e9fc069ef02ba2dd117d76d2c480	Discover	37.7632197439518862	-122.441907779286467
37552	2020-07-15 18:42:12	2020-07-15	Dr. Dequan Borer DVM	dr.dequan.borer.dvm@geemail.com	Los Angeles	California	4494078062502611	cf690140b0b9564b4437361be2a4bbd2	Diners Club / Carte Blanche	33.9278873197600248	-118.478197499550134
37553	2020-07-15 18:56:11	2020-07-15	Gary Klocko Sr.	gary.klocko.sr.@geemail.com	Hayward	California	3337084234986102816	a4c92f0b6474e7d87cf32f71763b9f43	VISA 16 digit	37.5318675461679732	-122.16389152060971
37554	2020-07-15 19:03:58	2020-07-15	Will Abbott	will.abbott@geemail.com	Spokane	Washington	3528017107475416883	69fb5ab625edcf3bcd03d3b324e9ab8f	JCB 16 digit	47.7112114557769118	-117.434774979100752
37555	2020-07-15 19:05:00	2020-07-15	Audy Wintheiser	audy.wintheiser@geemail.com	Norfolk	Virginia	676111541028426	15520313381d12bdc63917fc3b569519	JCB 16 digit	36.9037995131704974	-76.1787226497199441
37556	2020-07-15 19:05:17	2020-07-15	Edris Bailey	edris.bailey@geemail.com	San Francisco	California	3088598641045854600	d0e4bf7da9f6f2604b951e2e2f488710	Diners Club / Carte Blanche	37.743399379694516	-122.41929014370784
37557	2020-07-15 19:12:32	2020-07-15	Miss Neha Johnson MD	miss.neha.johnson.md@geemail.com	Round Rock	Texas	502038502267404	e9b9dc65064b8f1e969c5428c8917c5d	American Express	30.5148105958148861	-97.6241277393270224
37558	2020-07-15 19:20:21	2020-07-15	Kenyon Borer	kenyon.borer@geemail.com	New York	New York	6011219304866604294	4c4c48aca20c2e83049496fa271927f2	JCB 15 digit	40.7409070342537021	-73.9074087118159895
37559	2020-07-15 19:21:23	2020-07-15	Hartwell Gleichner-Heaney	hartwell.gleichner.heaney@geemail.com	Springfield	Massachusetts	4303087850994	3ab9a8edb583a1069884c84c4af92d08	Diners Club / Carte Blanche	42.0564956715069656	-72.5852042738907102
37560	2020-07-15 19:32:15	2020-07-15	Lorri Breitenberg-Powlowski	lorri.breitenberg.powlowski@geemail.com	Springfield	Missouri	3158166451965703171	c8e3dad072f1fdc97e86ea48e03a9b6c	Maestro	37.1658733297798776	-93.3009506115980543
37561	2020-07-15 19:46:46	2020-07-15	Mrs. Edyth Abshire DDS	mrs.edyth.abshire.dds@geemail.com	New York	New York	4426677409618460	266ae15219720c013ffdf43916baff1c	JCB 15 digit	40.6620985852312273	-73.8867837977957009
37562	2020-07-15 19:47:54	2020-07-15	Bryan Walter	bryan.walter@geemail.com	San Francisco	California	4773800436052920	d7e01b2c86dfbe68602c012f16b88110	JCB 15 digit	37.7799794426885711	-122.435538901126534
37563	2020-07-15 19:54:17	2020-07-15	Johanna Ankunding	johanna.ankunding@geemail.com	Fort Lauderdale	Florida	4241816656680	1fdf9df52c10a2394672bb2730e49629	JCB 15 digit	26.1468328557897358	-80.22866215704083
37564	2020-07-15 19:54:20	2020-07-15	Fidel Goyette	fidel.goyette@geemail.com	San Francisco	California	54693240080481157	d6e38b05a523b23f905a01c9a3899b29	JCB 15 digit	37.7844360068916174	-122.47705435083023
37565	2020-07-15 19:58:34	2020-07-15	Mr. Keion Carter	mr.keion.carter@geemail.com	Columbus	Ohio	3026809693372953	e0d134334754e7413265ebd6669bbe94	Mastercard	39.9384394534908225	-82.937429202231769
37566	2020-07-15 20:00:12	2020-07-15	Harmon Kessler	harmon.kessler@geemail.com	Winston–Salem	North Carolina	3158074120759444711	93d6013eba044587243386cb02bfdb43	Maestro	36.0486237692411962	-80.2046761873774159
37567	2020-07-15 20:06:38	2020-07-15	Gladstone Dibbert	gladstone.dibbert@geemail.com	New York	New York	501806630601158	6eeb480d094adcdf00491837f94ff464	Voyager	40.6008387001920497	-74.0300366124033928
37568	2020-07-15 20:09:43	2020-07-15	Val Cummings	val.cummings@woohoo.com	Montgomery	Alabama	3088970521793086704	62ca389aa29948fd8399482e5a3edbd3	Diners Club / Carte Blanche	32.2980831546176219	-86.3337697858143542
37569	2020-07-15 20:21:29	2020-07-15	Concepcion Bailey	concepcion.bailey@woohoo.com	Albuquerque	New Mexico	3096208895610644091	7f445aed4408485d0e7b681446cbc90f	Maestro	35.1409659882675882	-106.714452042717113
37570	2020-07-15 20:26:36	2020-07-15	Angel Cremin	angel.cremin@geemail.com	Sacramento	California	3056149478671992	450e21529531c392bb38370e979a37e6	Mastercard	38.6173313484326002	-121.542585156975676
37571	2020-07-15 20:30:34	2020-07-15	Ireland Boyer	ireland.boyer@warmmail.com	North Charleston	South Carolina	4180036550229245	23a1813555d993ef62c7fe39d64e92df	Mastercard	32.8516179389480527	-80.0910630347765959
37572	2020-07-15 20:44:50	2020-07-15	Mrs. Thyra Leannon PhD	mrs.thyra.leannon.phd@geemail.com	Miramar	Florida	6011965273980901819	659b5609f326a94c0c277ef4577c0472	JCB 15 digit	26.0578397893328209	-80.2642484395291689
37573	2020-07-15 21:01:40	2020-07-15	Verle Labadie	verle.labadie@geemail.com	Austin	Texas	869960083827440820	b4bd106ae09d984bbd79b52ec0b8965a	VISA 13 digit	30.3634348741393509	-97.720927285706253
37574	2020-07-15 21:04:20	2020-07-15	Loreen Labadie	loreen.labadie@woohoo.com	San Diego	California	6011868066341976290	150854276878f9bb33c35181dba540f2	Voyager	32.9050923159413031	-117.147417748291048
37575	2020-07-15 21:12:50	2020-07-15	Jillian Collier-Bartell	jillian.collier.bartell@warmmail.com	Pembroke Pines	Florida	3112306303964547417	94b438cca7a1de43f477d949e0f39398	Voyager	26.0568499741647415	-80.3908915128462098
37576	2020-07-15 21:30:56	2020-07-15	Osvaldo Keeling	osvaldo.keeling@woohoo.com	Raleigh	North Carolina	869970287688450459	70c80a10eda95b4703873bbcb80eb65e	American Express	35.9173202933877675	-78.5695638301253325
37577	2020-07-15 21:33:29	2020-07-15	Trena Deckow	trena.deckow@geemail.com	New York	New York	3019065393435361	4b447ff08f07995d7ab31c3e42b769ac	Diners Club / Carte Blanche	40.6742871371321399	-73.8759386445291284
37578	2020-07-15 21:38:08	2020-07-15	Rogers Ziemann-Schaden	rogers.ziemann.schaden@geemail.com	Washington	District of Columbia	4088836815683	9017f3a0c7e0bda94758e904a80098c0	American Express	38.8485038976915149	-76.9651800248518612
37579	2020-07-15 21:39:33	2020-07-15	Dannie Crist	dannie.crist@geemail.com	San Antonio	Texas	869914203512004817	4305954691c4c23d20e4b12d2d7c949a	American Express	29.3765346585378069	-98.5362714833415936
37580	2020-07-15 21:41:36	2020-07-15	Taniyah Gutmann	taniyah.gutmann@geemail.com	Grand Rapids	Michigan	6011405950222632959	4c78f43cd38dd90b37043472dd464aac	JCB 16 digit	43.0520806371968234	-85.6402738610416776
37581	2020-07-15 21:43:42	2020-07-15	Miss Elvie Schiller PhD	miss.elvie.schiller.phd@geemail.com	Houston	Texas	3049129273408680	c106d245b5d9144723ca92402bc1947e	VISA 16 digit	29.8018819943614304	-95.41297971839235
37582	2020-07-15 21:46:31	2020-07-15	Kellee Homenick	kellee.homenick@warmmail.com	Los Angeles	California	4336403325854405	6744d229aedd99fa2cb142e3fe0a1439	Diners Club / Carte Blanche	34.0063335047900637	-118.419049176386736
37583	2020-07-15 21:57:09	2020-07-15	Rich Kling	rich.kling@geemail.com	New York	New York	676121802001848	a2c9291c16e56a55f8e7879f96e0c70b	Voyager	40.6225946214273534	-73.9348297379806638
37584	2020-07-15 22:06:49	2020-07-15	Cathern Brown-Reichel	cathern.brown.reichel@woohoo.com	San Francisco	California	3039936266148457	c41ae7250eecd94ce44260a32938ef15	American Express	37.7788632336054988	-122.439080412934686
37585	2020-07-15 22:29:33	2020-07-15	Oda Doyle	oda.doyle@geemail.com	Austin	Texas	676330774067554	7104d37584d733799a46157c5074ca48	Mastercard	30.2274773223917919	-97.8415598735451795
37586	2020-07-15 23:00:40	2020-07-15	Orma Veum	orma.veum@geemail.com	Jurupa Valley	California	180032568358241675	a4a7d2a8404e6bfa84040c35a9dad08c	Mastercard	33.9459618247043338	-117.512599855943023
37587	2020-07-15 23:17:34	2020-07-15	Dr. Enola Jakubowski DDS	dr.enola.jakubowski.dds@geemail.com	Portland	Oregon	4846471461090889	e4fed9e22326ee4825eaf7eda3e84c75	JCB 16 digit	45.5553791239280272	-122.644546804204595
37588	2020-07-15 23:47:51	2020-07-15	Dr. Kathryn Mosciski	dr.kathryn.mosciski@geemail.com	Los Angeles	California	4794465432766975	b239803b0e2bdcd71d12a8eea3d91f6a	VISA 16 digit	34.0253247566387031	-118.456552277178687
37589	2020-07-15 23:54:55	2020-07-15	Anastacio Beier	anastacio.beier@geemail.com	Los Angeles	California	4255896868060016	d3c98181576344963c9d1033d131a73b	VISA 16 digit	34.0857377848919469	-118.311425972403214
37590	2020-07-16 00:08:38	2020-07-16	Breonna Ullrich	breonna.ullrich@geemail.com	New York	New York	51231626750126164	35d771fe1c2d37bf4cf99dddaa2ed52e	Voyager	40.6164903489164999	-73.8465278482891563
37591	2020-07-16 00:08:49	2020-07-16	Karan Berge MD	karan.berge.md@woohoo.com	Tampa	Florida	4421603366616	d75699295e085edc36fa84572aad7177	Discover	27.9246018305536339	-82.5664913773283331
37592	2020-07-16 00:12:49	2020-07-16	Christina Doyle	christina.doyle@geemail.com	San Francisco	California	3096514478653813250	c5a026ecb7c475621a1fe587a58f3622	JCB 15 digit	37.7729206820839849	-122.469642242247502
37593	2020-07-16 00:23:37	2020-07-16	General Bashirian	general.bashirian@geemail.com	San Antonio	Texas	3337296774104252187	669e23b5840596596aa4cd42a842159a	Voyager	29.5360626778636117	-98.6163963044363925
37594	2020-07-16 00:25:17	2020-07-16	Dwight Schiller	dwight.schiller@geemail.com	San Diego	California	3096306657183943842	48d3c6864ef61969b9d1bad6fbcdb122	American Express	32.752475509333614	-117.036851209532472
37595	2020-07-16 00:33:00	2020-07-16	Chip Bergnaum-Muller	chip.bergnaum.muller@geemail.com	Chicago	Illinois	55297513418206425	793f7c639ba2e91c0ee6a69ffd8deab3	VISA 13 digit	41.8988811474595266	-87.627281409179048
37596	2020-07-16 00:34:29	2020-07-16	Savana Hamill	savana.hamill@geemail.com	San Antonio	Texas	3112251693833122151	929f09c3dff5c725ef356efc49d12a7b	VISA 13 digit	29.5351003034576785	-98.4643314954660838
37597	2020-07-16 00:35:30	2020-07-16	Ms. Kylie Prohaska	ms.kylie.prohaska@geemail.com	Rochester	New York	52725373504933263	98021409ec718ad16885070f94fcbf23	Maestro	43.1624234400201559	-77.5181699544895508
37598	2020-07-16 00:38:36	2020-07-16	Chalmer Wolf-Zulauf	chalmer.wolf.zulauf@geemail.com	Cary	North Carolina	210034775787166880	46e5a52e024f18641cc80e76e1beadad	JCB 15 digit	35.7620131166759876	-78.7811747262339992
37599	2020-07-16 00:48:02	2020-07-16	Miss Lilly Crona PhD	miss.lilly.crona.phd@geemail.com	Kansas City	Missouri	3712885814261467	2ec987c3dfd285ccccfd60f7cb9c1f75	American Express	39.1047192340552812	-94.4694926238376667
37600	2020-07-16 00:54:19	2020-07-16	Barney Mertz	barney.mertz@warmmail.com	Los Angeles	California	6011472312321662593	68f236039d98fe80c73410db739d9277	VISA 16 digit	33.9851984999939774	-118.368033945839102
37601	2020-07-16 00:57:51	2020-07-16	Tate Gislason-Reilly	tate.gislason.reilly@geemail.com	Modesto	California	4455713773931	54a38c97a6234cdc4c2d2f4ab3bcb195	VISA 13 digit	37.5652706305962099	-120.935885131752116
37602	2020-07-16 00:58:05	2020-07-16	Charlie Kub	charlie.kub@geemail.com	Pasadena	California	4233901003214952	1e1b7cb068d924d18d713d8d7d78c1e4	Voyager	34.2564462273702048	-118.145458443444596
37603	2020-07-16 00:59:31	2020-07-16	Edrie Metz	edrie.metz@geemail.com	Dallas	Texas	54162608064229986	6d8bc3e6c6a6872589f726e9226b0465	JCB 15 digit	32.8616831454720355	-96.7305971700195215
37604	2020-07-16 01:10:04	2020-07-16	Jessy Konopelski	jessy.konopelski@woohoo.com	Mobile	Alabama	4353317102774057	526f26365c792d0199a7e3a460c8f0de	Discover	30.721881805929911	-88.0458691632047277
37605	2020-07-16 01:11:27	2020-07-16	Dr. Joy Bergnaum	dr.joy.bergnaum@geemail.com	Omaha	Nebraska	180097633928332594	e42b5fb86eee6557e5869fb0c28f8178	VISA 16 digit	41.326443631915005	-96.1240101181086146
37606	2020-07-16 01:14:46	2020-07-16	Alessandro Simonis-Murphy	alessandro.simonis.murphy@geemail.com	Austin	Texas	676375495982425	0d734399984a925ecb8e97fbe7f84176	JCB 16 digit	30.3601239721417429	-97.8504752402897964
37607	2020-07-16 01:14:49	2020-07-16	Zara Erdman DVM	zara.erdman.dvm@geemail.com	Laredo	Texas	4068513506839	3379b1f19d0658d1f58f9e695d917fdd	Discover	27.533912827698142	-99.4037298972260146
37608	2020-07-16 01:18:34	2020-07-16	Beula Bailey	beula.bailey@geemail.com	Jacksonville	Florida	52216128319273768	58d5a677b6ff9eb577d6ec03fe48393b	Maestro	30.3629719682555645	-81.7041723379943647
37609	2020-07-16 01:20:45	2020-07-16	Farrell Olson	farrell.olson@geemail.com	New York	New York	4000820010742550	7ba4a92251636cd4f016d1bdad577d8d	Maestro	40.7610220550317308	-73.8753044877562672
37610	2020-07-16 01:28:13	2020-07-16	Ms. Reece Altenwerth MD	ms.reece.altenwerth.md@geemail.com	Denver	Colorado	51419380117064858	78390860f4398b1a9637beccfb8bfceb	Discover	39.8199343468580338	-104.852960261121765
37611	2020-07-16 01:29:38	2020-07-16	Rosalinda Wunsch	rosalinda.wunsch@geemail.com	Milwaukee	Wisconsin	869977117571845551	21d81c7aea76d8ff115f26d9b0872218	VISA 16 digit	43.0054291847247612	-87.9050295070845635
37612	2020-07-16 01:44:41	2020-07-16	Britney Connelly	britney.connelly@geemail.com	Colorado Springs	Colorado	3088910016590829169	717bb60a4655363cd78c4ec2fd4101f0	Discover	38.9112775994513171	-104.678338807138431
37613	2020-07-16 01:47:08	2020-07-16	Katlin Kuhn	katlin.kuhn@geemail.com	Phoenix	Arizona	4526939658865492	076d1886311764bc0594c772eee2db9a	Discover	33.6096471099115917	-112.155470742138476
37614	2020-07-16 01:51:43	2020-07-16	Miss Aleta White DVM	miss.aleta.white.dvm@geemail.com	Grand Prairie	Texas	589309534031654	2dca852dfe892b381342a984924ec924	Voyager	32.6729525757074342	-96.9440693387635122
37615	2020-07-16 01:57:36	2020-07-16	Miley Robel	miley.robel@geemail.com	Renton	Washington	4522049849493	a1e623b0d9fbf48099ae95be5d51bd4e	Diners Club / Carte Blanche	47.4520904554579417	-122.18927351474575
37616	2020-07-16 01:58:13	2020-07-16	Pamella Schmeler	pamella.schmeler@woohoo.com	Allen	Texas	4244509826685	ec52a30975f039bdc06b4284e757130b	JCB 16 digit	33.025034155838938	-96.6574979572970392
37617	2020-07-16 02:03:32	2020-07-16	Dr. Jettie Gerlach II	dr.jettie.gerlach.ii@geemail.com	Philadelphia	Pennsylvania	3781349309933847	ef3cea3b589ab8f6427a9b5a41342156	VISA 13 digit	40.0102711580652723	-75.1386702543023972
37618	2020-07-16 02:05:48	2020-07-16	Adolphus Corwin	adolphus.corwin@woohoo.com	Los Angeles	California	3454312013354034	f2de1bf774f08f6f56603301cff70f03	VISA 16 digit	34.0540236124169056	-118.488406767090027
37619	2020-07-16 02:09:34	2020-07-16	Dr. Claud Mayert I	dr.claud.mayert.i@geemail.com	Anchorage	Alaska	869979448701362128	fd13578f02aff0f6c7c62758658603c1	JCB 15 digit	61.2061429434206374	-149.340580245026587
37620	2020-07-16 02:33:12	2020-07-16	Lillie McDermott DVM	lillie.mcdermott.dvm@warmmail.com	Surprise	Arizona	4138631934790848	52cc454eb7dce9ededb6bcebe46c71c6	Diners Club / Carte Blanche	33.7211583023186776	-112.431515539879712
37621	2020-07-16 02:34:23	2020-07-16	Ms. Margret Mayer	ms.margret.mayer@geemail.com	San Antonio	Texas	4248617972279494	79a7b91cf78661491b148cef96140217	VISA 16 digit	29.4187754600379634	-98.4466556156821468
37622	2020-07-16 02:40:40	2020-07-16	Dr. Marcelo Nolan V	dr.marcelo.nolan.v@geemail.com	Philadelphia	Pennsylvania	4370037309138133	fcfa0efd24b41175d1ef5006a6f9a2c2	Discover	39.9385482585482308	-75.1998219664108092
37623	2020-07-16 02:59:08	2020-07-16	Dr. Brain Stracke	dr.brain.stracke@geemail.com	Yonkers	New York	4298463394437	eb8f9baa025bb4824a10fb6f24ce1248	American Express	40.8686504926733676	-73.7992375588860341
37624	2020-07-16 03:01:27	2020-07-16	Ancel Koss	ancel.koss@geemail.com	Philadelphia	Pennsylvania	4484279332486	087323d69b3557671fa43b86f0e296c8	Discover	40.0888846760109061	-75.1682899680353813
37625	2020-07-16 03:15:06	2020-07-16	Lena Barton DVM	lena.barton.dvm@geemail.com	Miami	Florida	3487695964629557	a9fc98b436fc9ee52af0ecd53accc0d2	VISA 16 digit	25.8739450885120803	-80.2896145361349056
37626	2020-07-16 03:16:39	2020-07-16	Nathaniel Hoppe	nathaniel.hoppe@geemail.com	Durham	North Carolina	4446563011092979	6bb0486b4131a3671d831fa6aa0c555c	Maestro	35.9838030946686871	-78.8646468903772586
37627	2020-07-16 03:20:56	2020-07-16	Mareli Kemmer	mareli.kemmer@geemail.com	Lowell	Massachusetts	869903443572532215	3e952eea67a9d2713fee40bb69879fdf	Discover	42.6585316232275247	-71.2285728086125118
37628	2020-07-16 03:36:48	2020-07-16	Dr. Dola Kub	dr.dola.kub@geemail.com	Las Vegas	Nevada	4982987926268657	a3a2d325a0cbe17b55a2c4881d1970a4	VISA 16 digit	36.2268756183896201	-115.199809997782481
37629	2020-07-16 03:38:09	2020-07-16	Ephraim Blanda	ephraim.blanda@geemail.com	Oakland	California	3337515897817939736	2bd900a05903e9455c70b584c5bf50e5	VISA 13 digit	37.810834559063828	-122.287391640657276
37630	2020-07-16 03:38:58	2020-07-16	Destiney Kuvalis	destiney.kuvalis@geemail.com	Milwaukee	Wisconsin	3016442417221551	f7f143d9796ce075e61de9bca008b508	JCB 16 digit	43.057153678647424	-88.0187495235919926
37631	2020-07-16 03:42:03	2020-07-16	Alene Schumm-West	alene.schumm.west@woohoo.com	Everett	Washington	3042020852270376	a7c248b638c96e2ead1123cfc2c7d4fe	JCB 16 digit	47.9768092431951345	-122.224768379063903
37632	2020-07-16 03:47:41	2020-07-16	Vonda Anderson	vonda.anderson@geemail.com	Vista	California	4211026824595169	b0da99f62390341b5f6073286bf49528	American Express	33.2055099318251052	-117.2763420145087
37633	2020-07-16 03:49:43	2020-07-16	Baylie Glover	baylie.glover@geemail.com	San Francisco	California	3088071134756851946	63798787579a7091a8b3f595b471a021	VISA 16 digit	37.7906309865405206	-122.43815550046159
37634	2020-07-16 03:51:40	2020-07-16	Giancarlo Harris-Wilkinson	giancarlo.harris.wilkinson@geemail.com	Chicago	Illinois	3112643860265072777	dc5e00118b25043bc44f7b7175bdc4d9	JCB 15 digit	41.8144064729403695	-87.7143944524258359
37635	2020-07-16 03:55:06	2020-07-16	Fuller Lind	fuller.lind@geemail.com	Torrance	California	869979389008179072	d224414431c42fd67db961c9b7781e2e	JCB 16 digit	33.9235041994974011	-118.30089108898639
37636	2020-07-16 03:57:32	2020-07-16	Cato Little	cato.little@geemail.com	Philadelphia	Pennsylvania	4352556964415223	d52bfa4a1d0ed84882a36c305f925133	Mastercard	39.942605631980669	-75.1677165917020318
37637	2020-07-16 04:00:08	2020-07-16	Dr. Launa Murazik MD	dr.launa.murazik.md@geemail.com	San Francisco	California	3096550837381406072	860bb585e214a5609864e4a4bbadc73c	Mastercard	37.7578243099131612	-122.407265851165462
37638	2020-07-16 04:11:44	2020-07-16	Mrs. Elva Hermann MD	mrs.elva.hermann.md@geemail.com	Oakland	California	6011091545934504717	291e487891136871716b80d348c84f3c	JCB 16 digit	37.8200272869429028	-122.244688114043839
37639	2020-07-16 04:17:20	2020-07-16	Quinn Kutch	quinn.kutch@geemail.com	Dallas	Texas	3096056926242571205	8b8e99c552e03a9eb894d27201e58637	VISA 16 digit	32.7574703656874604	-96.6985221579633532
37640	2020-07-16 04:19:56	2020-07-16	Louetta Zemlak	louetta.zemlak@geemail.com	Salt Lake City	Utah	639058663025797	b2d0de637e8edc9b8b225e221945c633	JCB 16 digit	40.6985283257119335	-111.946687537053592
37641	2020-07-16 04:25:37	2020-07-16	Baylie Cassin MD	baylie.cassin.md@geemail.com	Norfolk	Virginia	4645606834523	73eb72a7874625f7c6a395d40a567f8b	VISA 13 digit	36.9334745599441234	-76.2529851517643777
37642	2020-07-16 04:32:56	2020-07-16	Mrs. Ada Sauer MD	mrs.ada.sauer.md@geemail.com	Dallas	Texas	4765188800112	5f7587a194268f154a1d9d49cc71dc4a	JCB 16 digit	32.6981162905499332	-96.7526694928724282
37643	2020-07-16 04:34:44	2020-07-16	Michel Collier III	michel.collier.iii@geemail.com	Colorado Springs	Colorado	3024919841605584	52dbe2db1bab45aab2feacc3b94075a4	VISA 16 digit	38.8019698166336866	-104.690970444555205
37644	2020-07-16 04:35:49	2020-07-16	Fiona Collier	fiona.collier@geemail.com	San Francisco	California	3528056523756175141	6700b0896bee9e97ea8d4df3215e5bd6	Voyager	37.7794459693036657	-122.433393017275876
37645	2020-07-16 04:42:31	2020-07-16	Shawnee Koelpin	shawnee.koelpin@woohoo.com	Boston	Massachusetts	4294736082621024	92d501cd9e8ac43cd84a5899130785b3	VISA 16 digit	42.2607377739325187	-71.0828398823689724
37646	2020-07-16 04:47:50	2020-07-16	Spurgeon Oberbrunner	spurgeon.oberbrunner@geemail.com	Abilene	Texas	639035454108974	d7e7762419375bc23a60b9d302136905	Diners Club / Carte Blanche	32.4950583352316187	-99.8007949788071187
37647	2020-07-16 04:52:43	2020-07-16	Kathy Balistreri	kathy.balistreri@warmmail.com	Knoxville	Tennessee	4547630251960666	bfd1ab9860ee098b89d148e8b695695d	Voyager	35.9315962655533099	-83.9060944139707772
37648	2020-07-16 04:56:26	2020-07-16	Miss Hortense Klocko	miss.hortense.klocko@geemail.com	San Francisco	California	4970028682203994	007df645351c16a1ec3ffeb1c3d8e3e7	JCB 16 digit	37.7593163998934642	-122.434625055843014
37649	2020-07-16 05:02:03	2020-07-16	Wong Lehner-Hackett	wong.lehner.hackett@warmmail.com	Ann Arbor	Michigan	869973012675856618	1b946687435c8847c1d266a41539b97d	Diners Club / Carte Blanche	42.2766845727398959	-83.7166075662352256
37650	2020-07-16 05:21:34	2020-07-16	Mrs. Millie Legros	mrs.millie.legros@geemail.com	Honolulu	Hawaii	4503644322235	7995613eee9835f211b08ba7568a332b	JCB 16 digit	21.3766177000228339	-157.813676668770995
37651	2020-07-16 05:23:54	2020-07-16	Donat Will	donat.will@woohoo.com	New York	New York	3158252573786255514	78446caaaa6e4f1aea9dea967b18b31e	American Express	40.5993447397593386	-73.9671691993612797
37652	2020-07-16 05:30:57	2020-07-16	Ms. Lita Buckridge	ms.lita.buckridge@warmmail.com	Las Cruces	New Mexico	869905861156031999	e25f0634895629c365862dbd0a07a131	American Express	32.2409746127702306	-106.71498921980411
37653	2020-07-16 05:35:11	2020-07-16	Amalie Casper-Littel	amalie.casper.littel@woohoo.com	Glendale	Arizona	180034959245967770	854219dc54c486d7602261cac0cebe22	JCB 16 digit	33.6162359301693741	-112.257695761441809
37654	2020-07-16 05:36:48	2020-07-16	Kiel Waelchi	kiel.waelchi@geemail.com	Kansas City	Missouri	3006494111691787	9fc0d3057efb1e37024f5ff3f6bce97a	VISA 16 digit	39.1143309919465381	-94.6026934676561524
37655	2020-07-16 05:39:46	2020-07-16	Chloie Olson	chloie.olson@geemail.com	Louisville	Kentucky	51188884896055887	9637f4ab513a0f237ec0ef50dc0c8768	VISA 16 digit	38.1779446721911384	-85.7069145693048853
37656	2020-07-16 05:41:18	2020-07-16	Ireland Fay	ireland.fay@geemail.com	Oakland	California	210068296609285229	1c996d84e7af3ef63269fc6b955af56e	JCB 15 digit	37.7902974176138642	-122.268273520975356
37657	2020-07-16 05:52:32	2020-07-16	Jeramie Jacobi IV	jeramie.jacobi.iv@woohoo.com	Tuscaloosa	Alabama	54357796987290873	3832c14e0c8abee7486cd087df6d688e	VISA 13 digit	33.2112405949328107	-87.5787838250029864
37658	2020-07-16 05:53:43	2020-07-16	Orvin Rodriguez	orvin.rodriguez@geemail.com	Jacksonville	Florida	4354787706028	8a881022771ec86dd21bb5cc714a7033	JCB 15 digit	30.3820870403252528	-81.6295467502981467
37659	2020-07-16 05:54:33	2020-07-16	Lera Daniel	lera.daniel@geemail.com	Green Bay	Wisconsin	4740815574141	b7fb099572ab90fd718d8f0db7309862	VISA 16 digit	44.4757069517456003	-87.9548007221248014
37660	2020-07-16 05:56:30	2020-07-16	Hank Glover	hank.glover@woohoo.com	Chicago	Illinois	3158211799945521021	0475006118e1b5e6fbe621b2b248f02f	Maestro	41.9240377074409309	-87.6168235416553927
37661	2020-07-16 05:58:09	2020-07-16	Erla Marvin	erla.marvin@geemail.com	Miami	Florida	3112011308232220560	468c30d71e7fed6a6e929a79b6d8edad	Maestro	25.6764951925396936	-80.1608456697188387
37662	2020-07-16 06:02:11	2020-07-16	Willard Hudson	willard.hudson@warmmail.com	Oakland	California	4115852587159	e1493bf39295151ffe0191f3b03b1ed6	Diners Club / Carte Blanche	37.807023768570275	-122.311736455861606
37663	2020-07-16 06:07:24	2020-07-16	Cannie Dickens DVM	cannie.dickens.dvm@geemail.com	Lexington	Kentucky	55303072014908167	8e92679e561ee57eb0c4a2cffb1a4725	JCB 16 digit	37.9614287783734525	-84.4471437733519821
37664	2020-07-16 06:13:59	2020-07-16	Shakira Kirlin-Pollich	shakira.kirlin.pollich@geemail.com	Lincoln	Nebraska	3018972745025223	c86d7a141ceb1360eef3b6fc84d79636	Mastercard	40.7886598230358217	-96.7595769013438343
37665	2020-07-16 06:24:22	2020-07-16	Haiden Hettinger	haiden.hettinger@woohoo.com	Colorado Springs	Colorado	210067319987981374	dc6dfeabb31b529325c5c3b4eb5e080a	American Express	38.9454946706585616	-104.854342870709303
37666	2020-07-16 06:51:09	2020-07-16	Florie Schoen	florie.schoen@warmmail.com	Aurora	Colorado	869931356888784013	3e051ae70c4234026f548ba05199cc48	VISA 13 digit	39.7622017119191611	-104.748694661876939
37667	2020-07-16 06:54:07	2020-07-16	Powell Mertz	powell.mertz@geemail.com	Chesapeake	Virginia	4245457946193	cb930e9402b7c6263e4834935ad72060	VISA 16 digit	36.6320050866115849	-76.3987603655859857
37668	2020-07-16 07:13:50	2020-07-16	Dr. Farris Kilback DDS	dr.farris.kilback.dds@warmmail.com	Plano	Texas	3096954283069702973	684f07ca8c63233c67447d633c2e883e	JCB 16 digit	33.023677901420001	-96.7918975812565492
37669	2020-07-16 07:14:31	2020-07-16	Robt Bradtke-Kshlerin	robt.bradtke.kshlerin@geemail.com	Dayton	Ohio	3088803910210669890	1307a5adfac44ddde71dd9f2e526de21	American Express	39.8729987832974615	-84.2438384683061372
37670	2020-07-16 07:17:49	2020-07-16	Dr. Hillard Streich I	dr.hillard.streich.i@woohoo.com	Oklahoma City	Oklahoma	3032859319147036	8224c23fe8f36a95f3d38f5a3ac85f73	Discover	35.5358140689697137	-97.4849036385200947
37671	2020-07-16 07:19:45	2020-07-16	Villa Flatley-Roob	villa.flatley.roob@geemail.com	Pembroke Pines	Florida	4887131256833311	a88e73ab1c873225a7620e5c78b558b9	VISA 13 digit	25.9533802317958333	-80.4119360687114266
37672	2020-07-16 07:25:25	2020-07-16	Werner Feeney	werner.feeney@geemail.com	Amarillo	Texas	4615020265687	96670da4ac4486187225b606a9d86be8	Maestro	35.1780731738708923	-101.785700067723923
37673	2020-07-16 07:40:13	2020-07-16	Sharen Flatley	sharen.flatley@warmmail.com	San Francisco	California	4771637983772	76bcf5572ebd78bbd5f97de53a0c4086	JCB 15 digit	37.7321027620771119	-122.383995540353411
37674	2020-07-16 07:41:12	2020-07-16	Kadence McKenzie PhD	kadence.mckenzie.phd@geemail.com	Atlanta	Georgia	503809731326097	31eaf6fb34f0bcf00191b433ea1d551a	JCB 15 digit	33.7519849531162563	-84.4426137766379981
37675	2020-07-16 07:49:34	2020-07-16	Dr. Maida Ratke	dr.maida.ratke@geemail.com	Charlotte	North Carolina	869950439453370891	c0e8b64aa8d9d9a19934a5dcf17402ae	American Express	35.2848319087896485	-80.7888903944697319
37676	2020-07-16 07:51:26	2020-07-16	Mr. Leeroy Anderson	mr.leeroy.anderson@geemail.com	Oakland	California	4292181617914085	25e002f7ad26046256e12c37aba7b6e3	VISA 16 digit	37.799649678109823	-122.294096853534356
37677	2020-07-16 08:08:53	2020-07-16	Alfreda Abbott	alfreda.abbott@woohoo.com	San Jose	California	561216732251158	c063ca0525dac7b9b45fc3c1fa944ff4	American Express	37.3118903503574444	-121.888992987408855
37678	2020-07-16 08:13:27	2020-07-16	Mr. Chip Torphy II	mr.chip.torphy.ii@geemail.com	San Francisco	California	3774314609776998	19f7bbf9c17706b0150ecea6c00ff57c	Maestro	37.7782504659501299	-122.447204172236653
37679	2020-07-16 08:14:52	2020-07-16	Salvatore Bogan	salvatore.bogan@geemail.com	South Bend	Indiana	4678718541835	0584073d970e097ae6f845bbecbbec0b	VISA 13 digit	41.7680656267941046	-86.1848731992356534
37680	2020-07-16 08:17:47	2020-07-16	Audie Kuphal	audie.kuphal@geemail.com	San Jose	California	676352009418295	fa8d46ff067505d95b4a3452371d593f	Discover	37.2853752330232453	-121.886855936305224
37681	2020-07-16 08:25:57	2020-07-16	Kyle Gislason-O'Connell	kyle.gislason.o'connell@geemail.com	Berkeley	California	3112602364862769116	8abd392201d76590df023c9e49b91411	Discover	37.8556761965268009	-122.263665344463107
37682	2020-07-16 08:27:03	2020-07-16	Mr. Elvin Goodwin II	mr.elvin.goodwin.ii@warmmail.com	Los Angeles	California	6011536759777206982	880b39b4e1f38e0622a1f9d609505a68	JCB 16 digit	33.9439531073305716	-118.407936839712036
37683	2020-07-16 08:41:41	2020-07-16	Isam Fisher PhD	isam.fisher.phd@geemail.com	Denver	Colorado	869986207325012886	199c183df9164624d94162c66a7a670f	JCB 16 digit	39.6663228984042959	-104.892944973964617
37684	2020-07-16 08:49:16	2020-07-16	Lucille Feil	lucille.feil@geemail.com	Lafayette	Louisiana	180062178545096504	8ca3ee0378954eaa2445f0f96a697fab	Diners Club / Carte Blanche	30.1237171320687978	-92.0693152808435258
37685	2020-07-16 08:51:13	2020-07-16	Omer Kutch	omer.kutch@geemail.com	Bridgeport	Connecticut	3088831259287695784	b3544355a80a384be1c3793a6c025702	JCB 15 digit	41.2774718972086845	-73.1693994971822974
37686	2020-07-16 08:53:09	2020-07-16	Johnna Mertz	johnna.mertz@geemail.com	New York	New York	4125769323630	4dbc46c90e823142e54cca1ccf84ef7d	JCB 16 digit	40.58930929589458	-73.8936977174028726
37687	2020-07-16 08:57:24	2020-07-16	Effa Torp	effa.torp@geemail.com	Pueblo	Colorado	3337779816464197167	ea788dc14d9dee1b435d4cc471f35f5e	Maestro	38.3604352576635748	-104.693211563104029
37688	2020-07-16 09:03:16	2020-07-16	Miss Amani Gaylord DDS	miss.amani.gaylord.dds@woohoo.com	Berkeley	California	3158843791983859260	d950c442564dd45caf18f0af03e81ce2	Diners Club / Carte Blanche	37.8658121300707649	-122.275457204459457
37689	2020-07-16 09:07:56	2020-07-16	Harrold Watsica	harrold.watsica@woohoo.com	Albuquerque	New Mexico	4546107367916	5d6b640f6a1ece370496fb55b0680eab	JCB 16 digit	35.1384077671118078	-106.602538276843362
37690	2020-07-16 09:11:45	2020-07-16	Jaime Thompson	jaime.thompson@geemail.com	Phoenix	Arizona	3158891577455756006	818656ba099b326edff1b9b688c910b5	VISA 13 digit	33.4993870011463812	-112.162770760843912
37691	2020-07-16 09:16:48	2020-07-16	Rakeem Pagac	rakeem.pagac@geemail.com	Philadelphia	Pennsylvania	3337761036283549965	0b2f3068d33b29557e32d28486b89aab	Voyager	40.1076348813209691	-75.2176523931689616
37692	2020-07-16 09:33:11	2020-07-16	Montel Kshlerin	montel.kshlerin@geemail.com	Baltimore	Maryland	6011803595115597922	c2ab2209d50f8b601287fa72930f1c25	JCB 15 digit	39.2422089308500261	-76.563807342156764
37693	2020-07-16 09:59:36	2020-07-16	Miss Juli Hills PhD	miss.juli.hills.phd@geemail.com	Chula Vista	California	51068019798823935	436474cc50710a19f1cb46f4939c98db	VISA 16 digit	32.5547313351880732	-116.928828958538162
37694	2020-07-16 10:00:06	2020-07-16	Richmond Smitham	richmond.smitham@geemail.com	Berkeley	California	3158215241418438025	f041c4af7f4254e07f9a50b9a7038683	VISA 16 digit	37.8769479949766747	-122.262471685037809
37695	2020-07-16 10:14:55	2020-07-16	Blair Langworth-Goyette	blair.langworth.goyette@geemail.com	Naperville	Illinois	4309043205066093	ff1313308627c87c22c71ff67665b630	Discover	41.8259844755668198	-88.1656351076327383
37696	2020-07-16 10:17:57	2020-07-16	Johney Fritsch	johney.fritsch@geemail.com	Los Angeles	California	3001863490928256	d2df012808a2150f02269c8684f3e2d5	Discover	33.9376505931239549	-118.458867378532133
37697	2020-07-16 10:24:13	2020-07-16	Miss Piper Rippin DVM	miss.piper.rippin.dvm@geemail.com	Springfield	Massachusetts	676155266711765	6505aff827b8f027889fe0e374860d95	Diners Club / Carte Blanche	42.1312550521194922	-72.5508706057071748
37698	2020-07-16 10:27:49	2020-07-16	Harry Boehm-Monahan	harry.boehm.monahan@geemail.com	San Jose	California	501802462203635	aaef496448595293dc9f2bddf6c4e87e	Voyager	37.2716998517800135	-121.856741674545773
37699	2020-07-16 10:28:08	2020-07-16	Tenika Stracke	tenika.stracke@geemail.com	Nashville	Tennessee	589375419784709	292576fc5a31004319306a177f37c401	VISA 16 digit	36.1673111888702934	-86.7479848245996976
37700	2020-07-16 10:39:30	2020-07-16	Dandre Jaskolski	dandre.jaskolski@geemail.com	Fayetteville	North Carolina	53862549864513992	cff59aca6e7575d1073a6fbf52d7ea48	VISA 16 digit	35.1049933752764005	-78.9301311076749101
37701	2020-07-16 10:52:22	2020-07-16	Julisa Jacobson	julisa.jacobson@geemail.com	New York	New York	3096037435931104702	95fdfb3d8230f8cbc1f08791c7a32c4e	Discover	40.6533282930720574	-73.8562483684055451
37702	2020-07-16 10:53:41	2020-07-16	Mr. Edson Price	mr.edson.price@warmmail.com	Moreno Valley	California	4389652765735971	a2b00c212b08c00d5015b6662caf3ccb	American Express	33.8746889276422536	-117.161489852654555
37703	2020-07-16 10:57:35	2020-07-16	Dr. Lyric Labadie	dr.lyric.labadie@warmmail.com	El Paso	Texas	502081672423076	f747329d78ee3940ce8725e3fcf56b1d	VISA 13 digit	31.8822934666477167	-106.439589616747583
37704	2020-07-16 11:04:42	2020-07-16	Gearldine Koepp	gearldine.koepp@geemail.com	San Jose	California	676323885015521	51cd3334666cb6fed82d5f2dfd234321	Mastercard	37.3321041730985073	-121.747989717101305
37705	2020-07-16 11:08:44	2020-07-16	Arturo Johns	arturo.johns@geemail.com	Oakland	California	210018667878080171	ad34fd254b9f81d590ef12b21992c417	VISA 16 digit	37.7739332180548431	-122.294295884610321
37706	2020-07-16 11:11:09	2020-07-16	Mrs. Evalyn Jacobi	mrs.evalyn.jacobi@geemail.com	Bakersfield	California	3723333911934287	1a2e48332d23b955fd7721efdba7e7c0	American Express	35.2560862165585149	-119.035828595170003
37707	2020-07-16 11:12:00	2020-07-16	Carnell Greenfelder	carnell.greenfelder@woohoo.com	Kansas City	Missouri	3705394996324002	c20aae051ef08c2f672cfe0df2999f95	VISA 16 digit	39.131817669451614	-94.4660152795482446
37708	2020-07-16 11:14:50	2020-07-16	Kasey Jacobi	kasey.jacobi@geemail.com	New York	New York	51612771022642934	b1ff4d856249c7579f5b35e3023fa977	JCB 16 digit	40.6926854952927641	-74.0056283826369707
37709	2020-07-16 11:15:37	2020-07-16	Jaeden Deckow	jaeden.deckow@geemail.com	San Diego	California	869970804626624621	5a7117d72d84c735047e381e242151ae	Maestro	32.8447272116851039	-117.065030686268585
37710	2020-07-16 11:22:44	2020-07-16	Wilber Friesen	wilber.friesen@geemail.com	San Jose	California	3096294790962122439	db8aded7f16a5c6842551084bf031976	JCB 15 digit	37.3233893570777013	-121.84988168852739
37711	2020-07-16 11:23:01	2020-07-16	Wash Wiegand-Boyle	wash.wiegand.boyle@geemail.com	San Francisco	California	3024640213377285	ddada3f9df197d30e978eca5e72278b7	VISA 16 digit	37.7479323674718898	-122.443169147580292
37712	2020-07-16 11:23:06	2020-07-16	Rickey Rogahn II	rickey.rogahn.ii@geemail.com	Plano	Texas	6011141882916695753	db484f07a218b28c9d0a59abb3444cc6	JCB 16 digit	33.1120572094425611	-96.7812998872898476
37713	2020-07-16 11:24:58	2020-07-16	Mr. Keenan Runolfsson II	mr.keenan.runolfsson.ii@geemail.com	New York	New York	3088004822274571077	ef9b5e9d14a6bb9c1b51bbeaa09dd3a1	JCB 15 digit	40.6148948577456181	-73.8660865547496854
37714	2020-07-16 11:28:51	2020-07-16	Chris Beatty	chris.beatty@geemail.com	Simi Valley	California	4496573823789174	459243e17f59e2c5ece9bf876184eedb	JCB 15 digit	34.2090314609237041	-118.698090273341165
37715	2020-07-16 11:31:03	2020-07-16	Katy Purdy-Pfeffer	katy.purdy.pfeffer@geemail.com	Cedar Rapids	Iowa	503896682935422	a40bbb469eb74d620a1e91ab8406aa76	Diners Club / Carte Blanche	41.9492594817727777	-91.7056777187224554
37716	2020-07-16 11:38:10	2020-07-16	Ophelia Von	ophelia.von@geemail.com	San Francisco	California	501871151797413	a1ab516e8c41284749f567348661dc46	JCB 15 digit	37.7683585900507168	-122.434443449456239
37717	2020-07-16 11:42:57	2020-07-16	Mr. Philo Corwin III	mr.philo.corwin.iii@geemail.com	Oklahoma City	Oklahoma	3033577628837316	548fce7608ffa3b6dcd7b0383ad18f91	JCB 16 digit	35.5308382051907472	-97.5031148498307942
37718	2020-07-16 11:43:49	2020-07-16	Clyde Bogisich	clyde.bogisich@warmmail.com	San Francisco	California	4276749119315736	f60cf7774ccde69d4160710620451880	VISA 16 digit	37.8016844206942721	-122.413948078887572
37719	2020-07-16 11:53:10	2020-07-16	Keith Kub	keith.kub@geemail.com	Norfolk	Virginia	3709740803620352	33d1144798d8cc3acbc49f648188e5ea	American Express	37.0088311991207348	-76.3272378579251551
37720	2020-07-16 12:13:53	2020-07-16	Barnett Batz-Zboncak	barnett.batz.zboncak@geemail.com	Coral Springs	Florida	3041505493229436	0348569eeb901fa88020665a39f8460e	JCB 16 digit	26.33289999114983	-80.1999496197450839
37721	2020-07-16 12:18:52	2020-07-16	Rey Rath	rey.rath@geemail.com	Winston–Salem	North Carolina	3088376435100558331	f218c52818cbce590b58896679124065	JCB 16 digit	36.1120998126219916	-80.2132520834580021
37722	2020-07-16 12:24:29	2020-07-16	Rock Lowe	rock.lowe@geemail.com	Tampa	Florida	4142506762803752	7d41c77235ebe84cba1e221da5b837fb	JCB 16 digit	27.9020253134541214	-82.4571087647907319
37723	2020-07-16 12:29:06	2020-07-16	Brisa Beatty	brisa.beatty@geemail.com	San Antonio	Texas	561239468125123	51a471f21e0f1b96baabbbb6981624e2	American Express	29.4166922751419264	-98.5729436782024777
37724	2020-07-16 12:33:23	2020-07-16	Dr. Cael Johnston	dr.cael.johnston@warmmail.com	Cambridge	Massachusetts	180063106386860364	968649607540cda3e0251a39f55b46c5	JCB 16 digit	42.3033319046478695	-71.1258892616339011
37725	2020-07-16 12:34:34	2020-07-16	Dr. Prince Kiehn	dr.prince.kiehn@geemail.com	Glendale	Arizona	6011827868013607925	0b530cc9bfec6d220004b08191830c15	JCB 16 digit	33.4813864210382093	-112.090154357792429
37726	2020-07-16 12:37:20	2020-07-16	Oland McLaughlin	oland.mclaughlin@geemail.com	San Antonio	Texas	4713922844141831	d5e5e05b9f6b297520245b7125215283	VISA 16 digit	29.5272787511885184	-98.5986515875741816
37727	2020-07-16 12:40:55	2020-07-16	Matilde Baumbach-Fisher	matilde.baumbach.fisher@geemail.com	Cedar Rapids	Iowa	6011620261614756482	0e979b7344cc0f58af33151078015ec8	VISA 13 digit	41.8867455035988243	-91.5999609469503184
37728	2020-07-16 12:49:51	2020-07-16	Jeanmarie Kirlin	jeanmarie.kirlin@geemail.com	San Diego	California	4709205487183674	99b1f6cf4ceaa36bed3101b7eaf336a1	VISA 16 digit	32.8856529326710856	-117.072142827175568
37729	2020-07-16 12:51:11	2020-07-16	Dr. Alonzo Kutch IV	dr.alonzo.kutch.iv@warmmail.com	Miami	Florida	639060720152374	a0d218f10d6df7e8c23fbe9ef78327f1	VISA 16 digit	25.680176509138942	-80.2884132550902763
37730	2020-07-16 12:52:34	2020-07-16	Dr. Rice McGlynn	dr.rice.mcglynn@geemail.com	San Francisco	California	4806850099650560	8b63e9f8488e789ea0aab296d66835fb	JCB 16 digit	37.7628023040335918	-122.442953187295842
37731	2020-07-16 12:58:13	2020-07-16	Manly Herman-Kuphal	manly.herman.kuphal@warmmail.com	Dallas	Texas	4420512803535901	85e2d21ab748dedadd25571c537a3293	VISA 16 digit	32.7173125945769243	-96.8640022528320515
37732	2020-07-16 13:07:59	2020-07-16	Kadeem Russel III	kadeem.russel.iii@geemail.com	Ventura	California	210011524276467046	b5bd98d8898c63ca0d4f460b5f473452	VISA 16 digit	34.2683445728078482	-119.199426371195159
37733	2020-07-16 13:10:59	2020-07-16	Flo Ernser-Goyette	flo.ernser.goyette@geemail.com	Colorado Springs	Colorado	6011091039859725648	81647b29a0b1a158fddd7d612342a191	Voyager	38.8059163057293759	-104.854897246013209
37734	2020-07-16 13:12:21	2020-07-16	Randall Klein	randall.klein@geemail.com	Winston–Salem	North Carolina	3337577182105413974	482c98a30241868da4cbba2cd01ee7dc	Maestro	36.1603018649619088	-80.2745396329685974
37735	2020-07-16 13:17:59	2020-07-16	Caesar O'Conner	caesar.o'conner@warmmail.com	Cleveland	Ohio	4688049918289105	7d4f05a7ba302c2036dbbc9b5ed728ce	American Express	41.5386212006527913	-81.5976521331589737
37736	2020-07-16 13:29:21	2020-07-16	Hebert Hagenes	hebert.hagenes@geemail.com	Los Angeles	California	6011548781509976456	b9b43df368d3d0a575cf00d6eb6e87b4	JCB 16 digit	34.0455784380767454	-118.314657519710437
37737	2020-07-16 13:29:26	2020-07-16	Elian Hirthe	elian.hirthe@warmmail.com	Henderson	Nevada	4798584708014625	1e44c1bae4ad59af55f07846e3bc4831	Voyager	36.0531529543388629	-115.063099954898291
37738	2020-07-16 13:37:01	2020-07-16	Flora Wiza	flora.wiza@geemail.com	New York	New York	4939802251305	c8aae89c6c98b44a28a62a5e25a6d690	VISA 16 digit	40.7462943257056196	-73.8888601208932698
37739	2020-07-16 13:37:53	2020-07-16	Alpheus Ankunding	alpheus.ankunding@geemail.com	San Francisco	California	4454924182412	11cb35f3ce2a0ad137baa1251ab06e53	Discover	37.7368936411164313	-122.447373480111196
37740	2020-07-16 13:46:02	2020-07-16	Jame Hilpert I	jame.hilpert.i@geemail.com	Milwaukee	Wisconsin	3337082272246672519	f67a05cd3d8c21e56b4d6466133f4b94	JCB 15 digit	43.0892821332525457	-87.9267472433958233
37741	2020-07-16 13:49:44	2020-07-16	Darlene Simonis	darlene.simonis@warmmail.com	New York	New York	4765896777429164	c25d256875b61b00935b9241359379da	Discover	40.6336042977161682	-74.0272284114163313
37742	2020-07-16 13:50:01	2020-07-16	Breonna Ferry-Bogan	breonna.ferry.bogan@geemail.com	Murfreesboro	Tennessee	4727967878716960	8948d3de3da26f26f3f87e4d718a481d	Discover	35.8989658884357681	-86.4446376625299422
37743	2020-07-16 14:03:50	2020-07-16	Pedro Bogisich	pedro.bogisich@warmmail.com	San Mateo	California	869972232200943332	ae89d3d60e68a2c9b7900fede78880e4	American Express	37.6261734836615602	-122.401670756874978
37744	2020-07-16 14:12:17	2020-07-16	Khiry Berge I	khiry.berge.i@woohoo.com	Irving	Texas	6011637437177565368	6f39d39f723c81a7425ca20387f96539	Diners Club / Carte Blanche	32.8830965938463819	-96.8767621015012281
37745	2020-07-16 14:14:51	2020-07-16	Dino Fritsch	dino.fritsch@geemail.com	Washington	District of Columbia	3789211489850187	8d623f83eb6e6d7eadd8de58e3115674	Diners Club / Carte Blanche	38.8557838259063644	-77.093017071879288
37746	2020-07-16 14:15:09	2020-07-16	Jeremey Goldner-Volkman	jeremey.goldner.volkman@geemail.com	New York	New York	51391069786098857	64fe204d53f6ddd27f3d12364a66198d	Voyager	40.6290160690192153	-73.977879054554549
37747	2020-07-16 14:17:01	2020-07-16	Dr. Pennie Bode	dr.pennie.bode@geemail.com	San Antonio	Texas	3045293129962623	5f8782fef69b2f24b89fa0617899409e	VISA 16 digit	29.4572301987629395	-98.4561602429322846
37748	2020-07-16 14:42:42	2020-07-16	Jacey Armstrong	jacey.armstrong@geemail.com	Overland Park	Kansas	3015884223902463	30066bd784ef08beca244829f3b23de9	Diners Club / Carte Blanche	38.8030585042536273	-94.7303849650587892
37749	2020-07-16 14:53:58	2020-07-16	Madeline Mills	madeline.mills@woohoo.com	Los Angeles	California	4475485223553875	cc1b2a6934fea95016268cd7ef01f01d	VISA 16 digit	33.9485002168320094	-118.413206734414388
37750	2020-07-16 14:54:43	2020-07-16	Huston Fisher-Weissnat	huston.fisher.weissnat@geemail.com	Aurora	Colorado	3096314115499171772	acc9fd1b0a594d2e1cbbd64126fb5024	JCB 16 digit	39.6734768512770586	-104.76713670460768
37751	2020-07-16 14:57:00	2020-07-16	Kadeem Boehm-Lehner	kadeem.boehm.lehner@geemail.com	Los Angeles	California	561211776926757	5165f746ace76bacb062c895178a8ec0	JCB 16 digit	34.0832777705375065	-118.399463405831895
37752	2020-07-16 15:01:00	2020-07-16	Alyvia Boehm	alyvia.boehm@geemail.com	Glendale	Arizona	6011217389297091254	07d99004acb3c43952ffaff77eb827bb	VISA 13 digit	33.5249407154735124	-112.202831737443432
37753	2020-07-16 15:03:24	2020-07-16	Bobbie Cruickshank	bobbie.cruickshank@geemail.com	Oakland	California	4053754528170408	0043e956afa771246e0686f08a31f787	Voyager	37.81786588442219	-122.270131047605986
37754	2020-07-16 15:16:54	2020-07-16	Gilman Prohaska	gilman.prohaska@geemail.com	Anaheim	California	54455703897933148	3c0fa223fc7e74ef04f4ad4724f27f26	Discover	33.8594716875646284	-117.802718371266863
37755	2020-07-16 15:33:00	2020-07-16	Price Langosh-Schuster	price.langosh.schuster@geemail.com	San Francisco	California	3158014777149921899	0e2e6ef9c6c35abaf4436794193db0d1	VISA 16 digit	37.7666748810250539	-122.456207941498278
37756	2020-07-16 15:37:30	2020-07-16	Mrs. Catina Grimes	mrs.catina.grimes@geemail.com	Charleston	South Carolina	4190187804361157	8fb90825023ac6723ad4e97e9611f357	Maestro	32.7699921361632676	-80.0215926129054367
37757	2020-07-16 15:39:01	2020-07-16	Vicie Kemmer-Fay	vicie.kemmer.fay@geemail.com	Memphis	Tennessee	180083128646066398	0bbca0b0f6040c77c6fbbca2b6a537ee	Maestro	35.109727271327003	-90.0138762600977032
37758	2020-07-16 15:39:18	2020-07-16	Nils Kuhn	nils.kuhn@geemail.com	Lexington	Kentucky	6011169767224307836	3dcbfa743e984f5f58c2137df7fe571d	VISA 16 digit	38.1189010545022811	-84.5381315094783901
37759	2020-07-16 15:58:39	2020-07-16	Stephon Gislason	stephon.gislason@woohoo.com	Kansas City	Kansas	3767807341893327	7666106fbb69ed6ad9043ec1c6c77a9f	American Express	39.0549024096131348	-94.7119099411584386
37760	2020-07-16 16:13:42	2020-07-16	Dr. Josef Buckridge III	dr.josef.buckridge.iii@geemail.com	New York	New York	3158568738215077412	9053b8bd3fe78d7b36280817c57594e0	VISA 13 digit	40.7203861112929886	-73.9587491508934676
37761	2020-07-16 16:19:19	2020-07-16	Carley Homenick PhD	carley.homenick.phd@woohoo.com	San Jose	California	3034665746238134	c6ab93d5f85a042f28d9032cbb8ceb59	Discover	37.3771207872133715	-121.911444857226314
37762	2020-07-16 16:26:54	2020-07-16	Rowan Huels	rowan.huels@warmmail.com	San Francisco	California	210094672243393769	f3806f0235ca74ec07a3fe663bd52a27	Diners Club / Carte Blanche	37.7939607572615941	-122.424167409847058
37763	2020-07-16 16:37:51	2020-07-16	Brandt Ernser	brandt.ernser@warmmail.com	Berkeley	California	589335377220047	660a5cbbb33b08ee85ade8ba921af07c	Voyager	37.8743444675900278	-122.270262575654726
37764	2020-07-16 16:55:17	2020-07-16	Maddox Krajcik	maddox.krajcik@woohoo.com	Berkeley	California	52842115570052934	d2b1d9b19f8488489074352ba367c8f5	VISA 16 digit	37.8766088797084493	-122.218031035011705
37765	2020-07-16 16:55:48	2020-07-16	Miss Margret Blick DDS	miss.margret.blick.dds@geemail.com	Sacramento	California	3036058225378993	a5dc9e03e3083504226fc421068a0afa	VISA 16 digit	38.5186475195720774	-121.448670635443548
37766	2020-07-16 17:03:54	2020-07-16	Maxx Jacobs	maxx.jacobs@geemail.com	Jacksonville	Florida	3712526438766826	7aa64293ad1f6338cb24e9c75b0c788a	Voyager	30.395098729390277	-81.5700504204802286
37767	2020-07-16 17:13:28	2020-07-16	Chandra Hoeger	chandra.hoeger@geemail.com	San Francisco	California	3112241224994713522	fac5852a28a103ca0d4adfdc4543cc9c	Discover	37.7839248706298747	-122.435013567255666
37768	2020-07-16 17:31:19	2020-07-16	Alberta Kihn	alberta.kihn@geemail.com	Los Angeles	California	3112862456386936109	ca4ffef24a9b42d86b414032f122fe2c	Maestro	34.0699274943076063	-118.372691100322825
37769	2020-07-16 17:48:48	2020-07-16	Harl DuBuque	harl.dubuque@geemail.com	Eugene	Oregon	561236018320410	b8596a17d55a8a7e49e77094a250e568	VISA 16 digit	43.9962722718443686	-123.128446656976649
37770	2020-07-16 17:49:17	2020-07-16	Gay Runte	gay.runte@geemail.com	Hialeah	Florida	6011771800885806851	30b51e60790622ee9ea287b886b3be93	Discover	25.9490228712070738	-80.298867058977109
37771	2020-07-16 17:50:05	2020-07-16	Braeden Olson	braeden.olson@woohoo.com	Minneapolis	Minnesota	6011195789743242326	a9fb519dfe6652c59861882ec2e94e91	Maestro	44.9717753063507359	-93.2459641409844124
37772	2020-07-16 17:51:40	2020-07-16	Zachery Koepp	zachery.koepp@geemail.com	Fremont	California	4375327189039435	8f59691ddf8fcd17c33ca76a2cdcb729	Discover	37.5778129679784172	-121.8473286191456
37773	2020-07-16 17:53:30	2020-07-16	Fernando Fay III	fernando.fay.iii@geemail.com	Dayton	Ohio	3096322415077672351	618741e1ca43b1ec515fe2cd518cc00e	Diners Club / Carte Blanche	39.7718014010019587	-84.1600956211522231
37774	2020-07-16 18:08:45	2020-07-16	Shirlie Gottlieb	shirlie.gottlieb@warmmail.com	Oakland	California	52149220140882750	6384142fec20c3714562f844bd2e869c	Mastercard	37.8071994051338152	-122.244973367578623
37775	2020-07-16 18:08:54	2020-07-16	Owen Turner	owen.turner@warmmail.com	Detroit	Michigan	4703014151287860	e3b3583971ee778ad8bb43a036bb64e7	Diners Club / Carte Blanche	42.3774283111486625	-83.1366365316443137
37776	2020-07-16 18:12:37	2020-07-16	Aria Trantow-Price	aria.trantow.price@geemail.com	Allentown	Pennsylvania	869976414440498048	e71bc6657b9dec6562b34da79503aa32	American Express	40.5250258443657358	-75.5300797840595237
37777	2020-07-16 18:26:31	2020-07-16	Cori Veum PhD	cori.veum.phd@geemail.com	Los Angeles	California	53801441228100613	c38b4219e07a2704752769adf0aa1512	American Express	34.083172567687555	-118.355923532880098
37778	2020-07-16 18:27:16	2020-07-16	Jerald Rowe DDS	jerald.rowe.dds@geemail.com	Oceanside	California	6011899634965015472	c030ac8852bb65b91d0214867e01cfbc	Voyager	33.1473317008819421	-117.271789432930575
37779	2020-07-16 18:31:18	2020-07-16	Soren Kemmer	soren.kemmer@woohoo.com	Tacoma	Washington	3158456922739047490	f82e0d89bdf15b024e5e110cc68f42ce	Mastercard	47.345327801921222	-122.511590720270945
37780	2020-07-16 18:31:52	2020-07-16	Marge Berge	marge.berge@geemail.com	Fontana	California	4646012043940753	0b58f024b5e8ecd2396cd45d8bf1e1af	Maestro	34.1224484822396192	-117.475635760584481
37781	2020-07-16 18:33:33	2020-07-16	Debera Heidenreich-Greenfelder	debera.heidenreich.greenfelder@geemail.com	Tucson	Arizona	3158077401600893968	275a5806fec44de5b5e8a5a334080b3b	JCB 16 digit	32.0632305765099872	-110.77552919306271
37782	2020-07-16 18:36:21	2020-07-16	Shay Bergnaum	shay.bergnaum@geemail.com	Surprise	Arizona	4454327277750921	1ad1ead9ab44f41ae4782f11d0417ebc	VISA 16 digit	33.7082449376344684	-112.514223500038298
37783	2020-07-16 18:49:42	2020-07-16	Ms. Vernita Stracke DVM	ms.vernita.stracke.dvm@geemail.com	Salinas	California	3112794459195026586	4bbb2985c8ed27b53de611bead8a41bc	JCB 16 digit	36.6574530190087842	-121.63856282836646
37784	2020-07-16 19:17:34	2020-07-16	Mrs. Yazmin Cole PhD	mrs.yazmin.cole.phd@geemail.com	Dallas	Texas	4440021070651181	fddc4f97f9c963781ba239b3f0ff187b	VISA 16 digit	32.7343512405447683	-96.7539777845572644
37785	2020-07-16 19:39:40	2020-07-16	Myer Bogan	myer.bogan@geemail.com	Los Angeles	California	4438583296761	1a997ba119c69e2bc84107d8f9702e02	VISA 16 digit	34.0954546365287143	-118.368957678553826
37786	2020-07-16 19:54:04	2020-07-16	Mose Williamson V	mose.williamson.v@geemail.com	New York	New York	502017468167121	fe54fd54de05662d7847750280973e01	Maestro	40.5780420784596316	-73.9231778470229273
37787	2020-07-16 19:55:13	2020-07-16	Geraldo Anderson-O'Conner	geraldo.anderson.o'conner@geemail.com	San Antonio	Texas	4307443587288764	830d5cc30b0861856caa8fd0444368e4	VISA 16 digit	29.5068902081415061	-98.4433727076578862
37788	2020-07-16 20:00:22	2020-07-16	Schuyler McDermott	schuyler.mcdermott@geemail.com	Chicago	Illinois	502020457226684	7efaf3e15c166630908171634deda41e	JCB 16 digit	41.9347664892975232	-87.7737915703125253
37789	2020-07-16 20:02:11	2020-07-16	Landon Von-Veum	landon.von.veum@geemail.com	Fort Worth	Texas	4409437500575	703bca1e27fbbbcbd7186c5f87582dd2	Diners Club / Carte Blanche	32.8688098769225192	-97.3918867905445325
37790	2020-07-16 20:03:32	2020-07-16	Rudolf Bauch	rudolf.bauch@geemail.com	Clearwater	Florida	3337635482152310325	e1c2ffb0322fe35a417a5ab56252d57d	Discover	28.0096704834733146	-82.7747827013287605
37791	2020-07-16 20:11:55	2020-07-16	Ivey O'Kon-Upton	ivey.o'kon.upton@warmmail.com	Arlington	Texas	4500451538608894	c578f8bca2f1cc8561775de25a901633	JCB 15 digit	32.7716316446445859	-97.0729577140908759
37792	2020-07-16 20:21:19	2020-07-16	Mychal Wilderman-Littel	mychal.wilderman.littel@geemail.com	Huntsville	Alabama	4405595563116	4832983caf928f88ff5ea7c3097ffcca	Maestro	34.6875876728221755	-86.7001388464607317
37793	2020-07-16 20:23:34	2020-07-16	Mrs. Dove Ledner	mrs.dove.ledner@geemail.com	Arvada	Colorado	210028496592033631	c46208ccb5f68437d67f531e0fbce824	JCB 15 digit	39.8926102975558479	-105.236546362188832
37794	2020-07-16 20:34:55	2020-07-16	Dr. Erica Hilpert DVM	dr.erica.hilpert.dvm@warmmail.com	Orlando	Florida	3096903809992396574	aa6d78bc6001a7c9d70517a176a513ce	VISA 13 digit	28.4918423905767497	-81.2443247483078466
37795	2020-07-16 20:35:44	2020-07-16	Armando Lueilwitz	armando.lueilwitz@geemail.com	Omaha	Nebraska	4895516400178946	580764bb7a860c159bd20e7ffc4c80ab	VISA 16 digit	41.2608534484781373	-95.9851139979086838
37796	2020-07-16 20:37:42	2020-07-16	Ilona Will MD	ilona.will.md@geemail.com	San Bernardino	California	4127417967714423	5fa8be9b336e51a8ae957e19939c0582	VISA 16 digit	34.0834559715151784	-117.239564602427549
37797	2020-07-16 20:44:33	2020-07-16	Kaelyn Wolf	kaelyn.wolf@geemail.com	Newark	New Jersey	6011865426080532311	663894172342fc35d7d4eca493967ac8	VISA 13 digit	40.7976324808698152	-74.2437577500682409
37798	2020-07-16 20:44:56	2020-07-16	Fabiola Schamberger-Kessler	fabiola.schamberger.kessler@geemail.com	New York	New York	180061702218335708	d342633329ce09b70d955fe6eeb8d8f1	Discover	40.6807411442734264	-74.0090402090817605
37799	2020-07-16 20:54:43	2020-07-16	Silas Little Jr.	silas.little.jr.@warmmail.com	Miami	Florida	869929250613271566	474be1ff4b12b877ed7fcdf7380e5a38	Diners Club / Carte Blanche	25.6805151117637784	-80.1467408265326213
37800	2020-07-16 21:00:32	2020-07-16	Chloie Pfeffer	chloie.pfeffer@warmmail.com	Oceanside	California	51555920401476351	b4f8760c19b0aef18e1cf07cf6b786ca	VISA 16 digit	33.2966054137684395	-117.311849670446293
37801	2020-07-16 21:05:27	2020-07-16	Mr. Ozell Murphy	mr.ozell.murphy@geemail.com	Irvine	California	4280447509141440	08833d221b10710c5e63a28e88bb492f	Voyager	33.5960981403026793	-117.863307211456075
37802	2020-07-16 21:13:45	2020-07-16	Maren Batz	maren.batz@warmmail.com	Wichita	Kansas	3528883459289741332	a08bfb99c8807e814988ab7e7a00beb1	Voyager	37.7235286282252531	-97.2677586654867952
37803	2020-07-16 21:16:28	2020-07-16	Sherree Gutkowski PhD	sherree.gutkowski.phd@geemail.com	San Antonio	Texas	4002775691371061	4e9457111920629caa874d496c829280	JCB 16 digit	29.478706020310149	-98.486172092922402
37804	2020-07-16 21:18:56	2020-07-16	Alphonse O'Reilly-Kirlin	alphonse.o'reilly.kirlin@geemail.com	Milwaukee	Wisconsin	3024222589822358	823c0131c8ce5b94c857f74e63b87f03	JCB 16 digit	43.0439934568099645	-87.8938500336471975
37805	2020-07-16 21:20:27	2020-07-16	Metro Nitzsche	metro.nitzsche@woohoo.com	Albuquerque	New Mexico	6011075574039788249	c6f858abe8afab908e1ecd645a16d5fd	JCB 16 digit	35.2050879250880371	-106.670193983202438
37806	2020-07-16 21:22:03	2020-07-16	Miss Kristi Eichmann	miss.kristi.eichmann@geemail.com	Indianapolis	Indiana	869928427657959915	debe2bca6d83334d461553ed415e34be	JCB 16 digit	39.8425658944535996	-86.1388646216798577
37807	2020-07-16 21:37:36	2020-07-16	Lovey Graham	lovey.graham@woohoo.com	Denver	Colorado	4426897115648409	6a97bce3783eddbd9419f1216f159989	JCB 16 digit	39.7238525551795902	-104.95455995628275
37808	2020-07-16 21:40:08	2020-07-16	Kaleena Reichel	kaleena.reichel@woohoo.com	Minneapolis	Minnesota	4451194103571001	d8b37ec8decf0b5840bf2810c6d61836	American Express	44.9452570034276633	-93.2033653589237474
37809	2020-07-16 21:46:12	2020-07-16	Prince Littel	prince.littel@geemail.com	San Jose	California	3112869477948829635	76a4c844b1add292068575edc34790ad	JCB 15 digit	37.3926409987553967	-121.737630174982925
37810	2020-07-16 21:50:07	2020-07-16	Rogelio Kilback	rogelio.kilback@woohoo.com	Laredo	Texas	4737901711504	0d34981b4bc69c91d30edbc314ee517c	Mastercard	27.4910315593887127	-99.4832585798118174
37811	2020-07-16 21:53:41	2020-07-16	Vida Waters	vida.waters@geemail.com	Houston	Texas	4106436340313120	6589789d490bee2469f83ae05540c09f	JCB 16 digit	29.6995021820146583	-95.2968540217276683
37812	2020-07-16 21:55:00	2020-07-16	Citlali Lang-Tremblay	citlali.lang.tremblay@geemail.com	New York	New York	3158618132456085559	5df8a665873a1f8f413b9480f73aa9fb	Discover	40.7175668304543947	-73.966343248578525
37813	2020-07-16 22:00:40	2020-07-16	Hortensia Bosco	hortensia.bosco@geemail.com	Gilbert	Arizona	54247044565664746	2af44ff0ddc9657a333de03273e6febf	Discover	33.2702344736896407	-111.81713088207357
37814	2020-07-16 22:01:44	2020-07-16	Luca Bahringer	luca.bahringer@woohoo.com	San Francisco	California	52455787243501410	ac6f21ab0a39d080f5cdd1ad5dd794e7	Maestro	37.7996422388593132	-122.435853379917631
37815	2020-07-16 22:06:52	2020-07-16	Chloie Konopelski	chloie.konopelski@warmmail.com	Chicago	Illinois	3158844299281894947	9030be170696ebb63663e78c767b3ee8	JCB 16 digit	41.7485315195120918	-87.7295486455347344
37816	2020-07-16 22:21:02	2020-07-16	Linnie Jerde	linnie.jerde@warmmail.com	Downey	California	3112483212293159353	2fbc7fe2669883a35c9a2943e8e0fb1a	Maestro	34.0381191239010548	-118.087842261010408
37817	2020-07-16 22:33:04	2020-07-16	Menachem Kris	menachem.kris@geemail.com	Miami	Florida	3416127178836246	d57854f34de4bcd803d322bcd43576a2	JCB 15 digit	25.7520048395402732	-80.1446798106528888
37818	2020-07-16 22:34:43	2020-07-16	Ashli Nolan	ashli.nolan@geemail.com	Sacramento	California	4588366002607187	05b52a071a615af21eb1e22ae58d10ed	Maestro	38.4862377336978909	-121.420468233410631
37819	2020-07-16 22:46:09	2020-07-16	Blanche Muller	blanche.muller@geemail.com	Seattle	Washington	676229326660163	3e6a520fdc7f5b2899a3ec1d5f37147c	VISA 16 digit	47.7082692519687086	-122.418534224984796
37820	2020-07-16 22:52:27	2020-07-16	Araceli Carter	araceli.carter@geemail.com	San Antonio	Texas	502036738623242	058cdf7f76aab528200e55503acbf30f	Discover	29.3858630230255429	-98.5529050378896301
37821	2020-07-16 22:54:18	2020-07-16	Zeb Monahan-Hills	zeb.monahan.hills@geemail.com	Seattle	Washington	3491774762057339	509c4c8a7172454ef3806100d3e47065	JCB 15 digit	47.558146067654711	-122.327776984909178
37822	2020-07-16 23:00:57	2020-07-16	Katherin Spinka	katherin.spinka@geemail.com	San Antonio	Texas	4662302349625565	6f9c48bfdb443b4d7a8008fa8b4d409f	JCB 15 digit	29.4597738360125589	-98.4784928763121314
37823	2020-07-16 23:01:14	2020-07-16	Davin Satterfield	davin.satterfield@geemail.com	Dallas	Texas	3752538473105563	b9aa07a97a606464b2bfb90025f66573	Mastercard	32.8053737092569477	-96.7222978564873301
37824	2020-07-16 23:07:19	2020-07-16	Ms. Easter Streich MD	ms.easter.streich.md@geemail.com	Kansas City	Kansas	4372438797334622	d708b5b508599ee22b76c5ca7bc8e9c0	VISA 16 digit	39.214118541395294	-94.7127891581442185
37825	2020-07-16 23:23:09	2020-07-16	Britt Will-Dickens	britt.will.dickens@geemail.com	Boston	Massachusetts	3015184988532336	91d7cd29eaa45adb1da3713ca98ca5ae	VISA 13 digit	42.2959768340159243	-71.0806318967089084
37826	2020-07-16 23:31:16	2020-07-16	Mrs. Susann Yundt MD	mrs.susann.yundt.md@geemail.com	San Francisco	California	3001971723933603	78dbee07321a8284e7d3ce75fe7aba4a	JCB 16 digit	37.780207267438378	-122.450283514177684
37827	2020-07-16 23:35:25	2020-07-16	Mona Conn	mona.conn@geemail.com	Pomona	California	4931605850037	1f36d622a186830e95cfffb5f2fe3739	VISA 16 digit	34.0200756550803831	-117.717273923099413
37828	2020-07-16 23:45:33	2020-07-16	Mr. Taj Schumm DVM	mr.taj.schumm.dvm@woohoo.com	Plano	Texas	210066453508771476	be5cb7feedbf5bdee36988d33989e5e6	Diners Club / Carte Blanche	33.114443673388287	-96.751815618453179
37829	2020-07-16 23:53:55	2020-07-16	Lanie Spinka	lanie.spinka@woohoo.com	Denver	Colorado	3096307217016694895	1e98385047afba609a3df43231fc3019	American Express	39.681154456367338	-104.786692129658917
37830	2020-07-16 23:58:45	2020-07-16	Dr. Emit Shanahan	dr.emit.shanahan@geemail.com	Berkeley	California	52728469146659543	b3c0af99495ddd5aa94bde35a19610b1	JCB 16 digit	37.9000264114841201	-122.270297676406173
37831	2020-07-17 00:13:48	2020-07-17	Alondra Turner	alondra.turner@geemail.com	Chicago	Illinois	4491542811397709	7680aa0cebed73a1ec24f4f309a1dc6d	VISA 16 digit	41.8898006505168965	-87.7602424635116023
37832	2020-07-17 00:28:18	2020-07-17	Ericka Bernier-McCullough	ericka.bernier.mccullough@warmmail.com	Oklahoma City	Oklahoma	180009103193829002	acc9fe622a28c328952f7f8a9a83b2c2	Voyager	35.4889236918561153	-97.527922689019519
37833	2020-07-17 00:37:23	2020-07-17	Mr. Ewing Haag III	mr.ewing.haag.iii@geemail.com	Waco	Texas	3158791078045072724	040af4dc29404d0e4320284acf86cdfe	Voyager	31.5667197320353239	-97.1672645432539355
37834	2020-07-17 00:39:58	2020-07-17	Dr. Arvid Bosco	dr.arvid.bosco@woohoo.com	San Francisco	California	4003064520454458	2122c1cfef97753bc9b6ba22c4ed6001	Diners Club / Carte Blanche	37.7748640655631505	-122.438452244941786
37835	2020-07-17 00:43:52	2020-07-17	Alyssia Harvey	alyssia.harvey@geemail.com	Little Rock	Arkansas	55947925149176061	f033ca72477d3e1223dbd15314812d54	Mastercard	34.6658303793795426	-92.335365987463291
37836	2020-07-17 00:44:13	2020-07-17	Mr. Marlyn Collier	mr.marlyn.collier@geemail.com	Ontario	California	3528309277550043337	9721641341bd0e29dcbf9d58abb2e08f	VISA 16 digit	33.9714043337531422	-117.673598765638474
37837	2020-07-17 00:51:26	2020-07-17	Danita Rosenbaum	danita.rosenbaum@geemail.com	New York	New York	180056192337080053	2797f9825b3afe74690029a65c0ddc25	Discover	40.6384214558862169	-73.9675471482694178
37838	2020-07-17 00:55:34	2020-07-17	Tamya Wilkinson DVM	tamya.wilkinson.dvm@geemail.com	New York	New York	3096106918998387142	51d39419868463aeb5c4bfdbebbdbd3f	JCB 16 digit	40.7045007235594056	-73.9901687149319827
37839	2020-07-17 00:58:54	2020-07-17	Alijah O'Kon DVM	alijah.o'kon.dvm@warmmail.com	San Francisco	California	4420355156353146	93ece2f86fed1dfb0e33f2cb9e321b6e	American Express	37.7905042521770014	-122.438511921174097
37840	2020-07-17 00:59:40	2020-07-17	Gaige Farrell	gaige.farrell@geemail.com	Boston	Massachusetts	4474352317706879	284dde7e02f3eebc169285a136b4f000	JCB 16 digit	42.2651520935054847	-71.0926372581578789
37841	2020-07-17 01:11:05	2020-07-17	Dr. Contina Reinger MD	dr.contina.reinger.md@geemail.com	Boise	Idaho	676129036586427	89e93ca18f915799b459e9caee7dadd6	Discover	43.6115226966466736	-116.19661900794209
37842	2020-07-17 01:12:55	2020-07-17	Keri Waters	keri.waters@geemail.com	Cape Coral	Florida	3737280917395472	fbc7c9c4a757fc86c603a5b2205f8f7d	VISA 13 digit	26.6624075957544164	-82.0205488198507595
37843	2020-07-17 01:21:23	2020-07-17	Merton Kreiger	merton.kreiger@warmmail.com	San Francisco	California	3096032756082047183	2ee70e9cee3a294e52a4af3a110d13ca	American Express	37.8003742554156901	-122.453854298236607
37844	2020-07-17 01:24:17	2020-07-17	Britney Cruickshank-Krajcik	britney.cruickshank.krajcik@geemail.com	Houston	Texas	3761704968245269	31753b97a81faf2c3d7edc6b95c9a41f	JCB 16 digit	29.7564527658823863	-95.440816322669022
37845	2020-07-17 01:25:11	2020-07-17	Roddy Kuhlman	roddy.kuhlman@warmmail.com	Santa Clarita	California	3739080918751741	acedb8fbffefbb59937b82e032c3a488	Voyager	34.4362377222366618	-118.58026304958463
37846	2020-07-17 01:35:02	2020-07-17	Wilbur Hudson	wilbur.hudson@woohoo.com	Milwaukee	Wisconsin	3528403587713061363	ce297c08b6d7faef8a5e22931ddfeaa6	VISA 16 digit	43.0743613827127945	-87.9632490336529997
37847	2020-07-17 01:35:59	2020-07-17	Dr. Marolyn Douglas DDS	dr.marolyn.douglas.dds@geemail.com	Nashville	Tennessee	3096385945365186551	795e71b5800f31162b6ab88fc11a1fc3	Diners Club / Carte Blanche	36.2378531284753223	-86.8653733160719241
37848	2020-07-17 01:39:13	2020-07-17	Jabbar Kutch	jabbar.kutch@woohoo.com	San Francisco	California	4955976746573	0caa4c9fc7b2f937f34fb9a6440421d5	Diners Club / Carte Blanche	37.7730584735545563	-122.44271194625783
37849	2020-07-17 01:46:12	2020-07-17	Ariane Reichert	ariane.reichert@warmmail.com	San Francisco	California	3088401694933602661	5e8217b9797de9fc7139967119ddc033	VISA 16 digit	37.7860288183759891	-122.393546861861779
37850	2020-07-17 01:52:40	2020-07-17	Randi Rosenbaum-Kulas	randi.rosenbaum.kulas@geemail.com	Louisville	Kentucky	4788938100066652	e10d1378b3a8366abc840d194b3e7d2c	Voyager	38.0816170628551376	-85.6184775196552295
37851	2020-07-17 02:06:57	2020-07-17	Norah Roberts	norah.roberts@geemail.com	Sacramento	California	6011238080570937231	1e966d6648be819e2c51d26348eeea9e	VISA 16 digit	38.5579625561632255	-121.451561742579926
37852	2020-07-17 02:07:18	2020-07-17	Aldona Cronin DDS	aldona.cronin.dds@geemail.com	Killeen	Texas	3528151050577689377	eb5ae8ca53e2796d97c198d5982b7efb	VISA 16 digit	30.9976335855897531	-97.8256947117559577
37853	2020-07-17 02:08:14	2020-07-17	Rasheed Gaylord	rasheed.gaylord@warmmail.com	Pasadena	Texas	3158591582114668876	65bf086bf581826c03a14d8c9f487d1a	VISA 16 digit	29.5784438642080865	-95.1449063932005288
37854	2020-07-17 02:23:38	2020-07-17	Charity Toy	charity.toy@warmmail.com	Irving	Texas	3006920229165116	36828a3098f564f62dd01d5747a4f868	VISA 13 digit	32.8469311257775871	-97.0625412738230011
37855	2020-07-17 02:23:49	2020-07-17	Scot Champlin	scot.champlin@geemail.com	Las Vegas	Nevada	4919498932059310	467fc7b058c0c65bae4ded9261fa52d2	JCB 16 digit	36.3081174904115471	-115.181823027946422
37856	2020-07-17 02:35:06	2020-07-17	Orma Johns	orma.johns@geemail.com	Sandy Springs	Georgia	4076283638858507	946ede514955824f60faeedc074a3473	JCB 16 digit	33.8436176991611717	-84.4574049944140057
37857	2020-07-17 02:43:03	2020-07-17	Hilario Shields	hilario.shields@warmmail.com	Oakland	California	4061050769553950	47a52597bc174110dd7289bcafeb37dc	American Express	37.7800059157990731	-122.243597546497782
37858	2020-07-17 02:47:21	2020-07-17	Roy Collins	roy.collins@geemail.com	Los Angeles	California	501819830552378	25a6130f6282378e12fdf279e55f8ffc	Voyager	34.1178834492206562	-118.378028770535437
37859	2020-07-17 02:48:37	2020-07-17	Lashanda Kshlerin DDS	lashanda.kshlerin.dds@warmmail.com	Anaheim	California	4198093572750	fa2cd4ccdb389c5a4b8b5c1a080bb807	JCB 15 digit	33.8267244614027405	-117.843000102576241
37860	2020-07-17 02:50:51	2020-07-17	Itzel McDermott	itzel.mcdermott@geemail.com	San Francisco	California	210058075916906673	87fcfa6284ed79613d8c869195e3931f	JCB 16 digit	37.7950194076977084	-122.447114176138854
37861	2020-07-17 02:54:17	2020-07-17	Shelia Rosenbaum	shelia.rosenbaum@geemail.com	Scottsdale	Arizona	3434918177125666	2454fe0f6f3345a60e1a088527eef3f9	Diners Club / Carte Blanche	33.6093715243164439	-111.880031746389704
37862	2020-07-17 02:57:52	2020-07-17	Dr. Tyrek Koepp V	dr.tyrek.koepp.v@geemail.com	Oakland	California	3751279506403003	4920431943954df25bf41eb7a7698204	VISA 16 digit	37.7995425365234397	-122.263731735602676
37863	2020-07-17 02:58:47	2020-07-17	Shonna Kerluke	shonna.kerluke@geemail.com	Oakland	California	3096082011961957972	4bb0ba587494f002b2661895eadd4752	JCB 16 digit	37.8328680365915062	-122.291681234404336
37864	2020-07-17 03:00:32	2020-07-17	Dr. Caden Stanton V	dr.caden.stanton.v@woohoo.com	New York	New York	4760264905521	9b1fae930d64664dd2dfc8a308044d86	VISA 16 digit	40.5679094559270865	-74.0194635109405965
37865	2020-07-17 03:23:07	2020-07-17	Dr. Alden Corkery PhD	dr.alden.corkery.phd@warmmail.com	Bridgeport	Connecticut	4935052617284188	8a64d7a9fdff272ec32f8fdb1ca28cd3	VISA 16 digit	41.1413654884487343	-73.1037008709173648
37866	2020-07-17 03:24:37	2020-07-17	Tristen Huel	tristen.huel@geemail.com	Chandler	Arizona	675913187437861	ba9bfc4d5daa01128b01c55e4281f1c5	Maestro	33.3008157226346384	-111.940890818543366
37867	2020-07-17 03:26:18	2020-07-17	Waldo Heathcote	waldo.heathcote@geemail.com	Santa Maria	California	4943395772063248	81ba997766215b1443299f5c2a425cf4	VISA 13 digit	34.9144778212595739	-120.368263568534701
37868	2020-07-17 03:26:43	2020-07-17	Aiyana Barton DVM	aiyana.barton.dvm@geemail.com	San Antonio	Texas	3096859448573397976	0afba716f20ea5c0f4402096a44c0131	JCB 15 digit	29.3925447296421964	-98.452466734994573
37869	2020-07-17 03:28:32	2020-07-17	Dr. Denisse Nolan	dr.denisse.nolan@woohoo.com	Los Angeles	California	180067881253780335	0d23dd3462840df0211225cda6518a64	American Express	33.9907873600587251	-118.355816128756103
37870	2020-07-17 03:28:45	2020-07-17	Quinn Stroman	quinn.stroman@woohoo.com	Houston	Texas	4718578489799849	90a40c21a69490e1f526787061701ddf	VISA 13 digit	29.8357872582118944	-95.4254822561066618
37871	2020-07-17 03:30:34	2020-07-17	Jonatan Lakin	jonatan.lakin@geemail.com	Vancouver	Washington	6011470265026849646	d4aa16449f28734b493dac8ea202ae89	Voyager	45.6637283141795578	-122.566174778069183
37872	2020-07-17 03:31:04	2020-07-17	Ivana Metz	ivana.metz@geemail.com	Brownsville	Texas	180028017521631434	c77c7f782469900d05ba459616b0714a	Diners Club / Carte Blanche	25.9487174254920312	-97.3606713219732001
37873	2020-07-17 03:35:52	2020-07-17	Slade Krajcik	slade.krajcik@geemail.com	Santa Ana	California	3426380798738296	fdcaffa2cf065281ac8a13f588175a83	Voyager	33.6596907273970558	-117.94090513567626
37874	2020-07-17 03:46:40	2020-07-17	Hattie Metz-Pfeffer	hattie.metz.pfeffer@geemail.com	Cincinnati	Ohio	3049860324048618	f32401e7a314573eda05c7a99a2b4e4e	Mastercard	39.1370921115156278	-84.5519699884850411
37875	2020-07-17 03:47:21	2020-07-17	Diya Hermann	diya.hermann@geemail.com	Sacramento	California	4809511147286	078d23860cb5717135b7789876625776	JCB 15 digit	38.4867825493015374	-121.494892267115787
37876	2020-07-17 03:53:36	2020-07-17	Elbridge Herman	elbridge.herman@warmmail.com	Gainesville	Florida	3088882156048994852	2c137d096552034d26c7e59fd83736af	Mastercard	29.6230621550988396	-82.4342610821001358
37877	2020-07-17 03:53:52	2020-07-17	Micheal Konopelski MD	micheal.konopelski.md@woohoo.com	Downey	California	869993134103517970	21ff92a29ae837c5d9e2125614d163c4	VISA 16 digit	33.9115105251565581	-118.218858581931883
37878	2020-07-17 03:57:22	2020-07-17	Madora Halvorson-Willms	madora.halvorson.willms@warmmail.com	New York	New York	4421702515301390	258d653e62ef7077e0b259863dc411ea	JCB 15 digit	40.6939272861685595	-73.8973079830769422
37879	2020-07-17 04:03:07	2020-07-17	Burrel Bogan	burrel.bogan@geemail.com	San Francisco	California	4394991253492163	1343c22d65962303fd9ebdb0935625f7	VISA 13 digit	37.8005869405904917	-122.464649096457677
37880	2020-07-17 04:06:04	2020-07-17	Mrs. Kandi Christiansen DVM	mrs.kandi.christiansen.dvm@geemail.com	San Bernardino	California	6011553693796361155	c5f9971601bb67df31d1895974ac63f6	Mastercard	34.1508592208646178	-117.248471722357351
37881	2020-07-17 04:17:01	2020-07-17	Jaquez Crooks	jaquez.crooks@warmmail.com	Knoxville	Tennessee	675929654278224	9e1c6fde30a6e26a1acee50ee7e20f9b	American Express	35.9951946401566261	-83.8736054762016892
37882	2020-07-17 04:19:11	2020-07-17	Adriane Corkery	adriane.corkery@woohoo.com	Richardson	Texas	180031901366555367	37cfbdc173366b59e99d574f6aa64480	VISA 16 digit	32.8966902448099106	-96.7144057192135591
37883	2020-07-17 04:19:23	2020-07-17	Orilla Hudson	orilla.hudson@geemail.com	Phoenix	Arizona	180099737442793070	75760379ea6358fcd5b5b6018ef9a1f8	Discover	33.4944242392599634	-112.040508848468221
37884	2020-07-17 04:19:40	2020-07-17	Mr. Welton Gislason MD	mr.welton.gislason.md@geemail.com	Lewisville	Texas	060417269053819	24538682a38d02da6c4b9c9fa2d7add6	American Express	33.0457503352764945	-96.8831356645125936
37885	2020-07-17 04:24:42	2020-07-17	Randal Howell MD	randal.howell.md@geemail.com	Berkeley	California	6011412130208120565	545c35357998628f332621b7244ee912	JCB 16 digit	37.876120713594851	-122.288930729379018
37886	2020-07-17 04:28:29	2020-07-17	Florene Douglas	florene.douglas@geemail.com	Charleston	South Carolina	180079288007897637	71308adc46f1df95ca61d4f8379570ff	JCB 16 digit	32.8105348917651938	-79.9367624813839797
37887	2020-07-17 04:53:17	2020-07-17	Alexis Klocko	alexis.klocko@geemail.com	San Francisco	California	3528167191756770893	ee006c6122ebf5060225dde3e47d3dcc	VISA 16 digit	37.7792727686422722	-122.430392971136214
37888	2020-07-17 04:55:42	2020-07-17	Whitney Beier	whitney.beier@warmmail.com	New York	New York	4173138792358	9880518eb25b33f621996e5c86ae9e4d	VISA 16 digit	40.6440813376791752	-73.8992797388590787
37889	2020-07-17 05:08:14	2020-07-17	Finley Zulauf	finley.zulauf@geemail.com	Colorado Springs	Colorado	54606406422257250	907d77bc4e1d8c22b9d23707bd9f7e74	JCB 15 digit	38.8600491330075997	-104.753629835384714
37890	2020-07-17 05:10:29	2020-07-17	Abdiel Schulist-Schultz	abdiel.schulist.schultz@geemail.com	Los Angeles	California	4396058166034017	fd955fddc2b55a0a27a2181e99364e0a	Mastercard	34.0112667958117996	-118.318573320889101
37891	2020-07-17 05:19:55	2020-07-17	Barron Windler-McKenzie	barron.windler.mckenzie@geemail.com	San Antonio	Texas	561248755580692	e80bd5ae1ec6315d1bcfbb5b43a7c7ae	JCB 16 digit	29.5118416276365529	-98.5011098208207585
37892	2020-07-17 05:20:23	2020-07-17	Dr. Patric Gulgowski	dr.patric.gulgowski@geemail.com	Bridgeport	Connecticut	4738258455562	7946f5b9965db2a1876ff535823131ce	JCB 16 digit	41.1873829616397558	-73.1406947052937113
37893	2020-07-17 05:26:41	2020-07-17	Mrs. Shyla Hansen MD	mrs.shyla.hansen.md@warmmail.com	Santa Ana	California	180093078245565472	f92ea80f96dc9f7e7e1484cf4fbcbbf9	JCB 16 digit	33.6766876172378673	-117.935546122996129
37894	2020-07-17 05:27:39	2020-07-17	Dr. Merle Rohan II	dr.merle.rohan.ii@geemail.com	New York	New York	869963010591252328	a534960e01116b83fbd90c4423910c3b	Mastercard	40.5801769050993002	-73.9920598685637145
37895	2020-07-17 05:30:17	2020-07-17	Miss Maxie Bartoletti	miss.maxie.bartoletti@geemail.com	Austin	Texas	6011162175138916410	3525ce93fef1ec8828c691406dbc60a4	VISA 16 digit	30.2949906015895287	-97.7470926127169264
37896	2020-07-17 05:34:13	2020-07-17	Torrey Rogahn DDS	torrey.rogahn.dds@geemail.com	Visalia	California	502090050440636	bb4e0f223c4808abfdd88229c02011bd	American Express	36.3284192013975229	-119.301737664978589
37897	2020-07-17 05:37:03	2020-07-17	Yoshio Schowalter	yoshio.schowalter@geemail.com	Chicago	Illinois	4478251931127536	7a7db67f66d5c1da27d1c09611fcb964	Discover	41.9360147890470927	-87.5939703051030563
37898	2020-07-17 05:38:29	2020-07-17	Alexandrea Hessel	alexandrea.hessel@woohoo.com	Denton	Texas	4940471434305	2abafbf0284bca1eb5072771dedf0d50	VISA 16 digit	33.1977382059939217	-97.2218761712439346
37899	2020-07-17 05:50:34	2020-07-17	Lylah Ankunding	lylah.ankunding@geemail.com	Kansas City	Kansas	210042881497803521	7f67dd78d5ad356765efe77a0b4446cf	VISA 16 digit	39.0696329269930729	-94.7571264685999637
37900	2020-07-17 05:51:30	2020-07-17	Miss Louisa Welch	miss.louisa.welch@geemail.com	Moreno Valley	California	3337479087821262200	3ebe32626cd599b1d18d465f500537f5	Diners Club / Carte Blanche	33.8924881393548105	-117.132433011985185
37901	2020-07-17 05:56:47	2020-07-17	Chancey Jacobs Sr.	chancey.jacobs.sr.@geemail.com	Montgomery	Alabama	3528131558670030534	db8b94272b649b49321a12794a80ccf4	JCB 15 digit	32.2992062242168956	-86.2040753326997162
37902	2020-07-17 05:59:56	2020-07-17	Mr. Leonidas Hagenes	mr.leonidas.hagenes@geemail.com	El Paso	Texas	6011636194104470219	f32900f855109eb744bac83d3a03b978	Voyager	31.8921863106839361	-106.485218227000914
37903	2020-07-17 06:01:48	2020-07-17	Marc Collins-Robel	marc.collins.robel@warmmail.com	Huntsville	Alabama	4200172037635070	eddcf6a2b83d0c83a74402ab80ad4930	JCB 16 digit	34.6062806458454588	-86.6073597709666956
37904	2020-07-17 06:07:22	2020-07-17	Julissa Moen	julissa.moen@geemail.com	Santa Clarita	California	3053950780035773	564d72eb9eb697555c2a2ae406938c5a	Voyager	34.33128387678601	-118.490530509558312
37905	2020-07-17 06:17:48	2020-07-17	Olga Altenwerth-Runte	olga.altenwerth.runte@geemail.com	Seattle	Washington	3789464235863109	6e9fe55a3ac378b2d48026142f37b953	VISA 16 digit	47.6927938634920849	-122.387754436947034
37906	2020-07-17 06:17:52	2020-07-17	Quinton Farrell	quinton.farrell@woohoo.com	Dallas	Texas	4342788716781	91ba62d149a6ca005a5fa9ed38170799	VISA 16 digit	32.7481285131342759	-96.8277043632659939
37907	2020-07-17 06:20:31	2020-07-17	Mr. Kory Erdman Sr.	mr.kory.erdman.sr.@geemail.com	Las Vegas	Nevada	4515485306893927	a5af8109f62780672aed4b997b8e415b	JCB 16 digit	36.312126357630639	-115.304723532984397
37908	2020-07-17 06:27:58	2020-07-17	Miss Twyla Mertz	miss.twyla.mertz@woohoo.com	San Francisco	California	3788886123857929	055250226ab6632363faa5cda5459754	JCB 16 digit	37.7347838552451336	-122.464099419220915
37909	2020-07-17 06:32:27	2020-07-17	Dorene Lueilwitz	dorene.lueilwitz@warmmail.com	San Francisco	California	180078986655407390	521654233a959ae7b621c5e963751860	Mastercard	37.7906083640193273	-122.42210772377608
37910	2020-07-17 06:44:52	2020-07-17	Jarrett Heller	jarrett.heller@geemail.com	Indianapolis	Indiana	3528296989544953042	e6fc18a64467b9a7884f455cca5960bb	VISA 16 digit	39.8597123242456419	-86.1119129171796089
37911	2020-07-17 06:45:30	2020-07-17	Dr. Albin Smitham Jr.	dr.albin.smitham.jr.@geemail.com	New York	New York	3528664358602600537	800505e5d9c0a6fa63e46e4ba9e7ca21	Mastercard	40.6976028860304524	-73.9505318437598618
37912	2020-07-17 06:49:04	2020-07-17	Mr. Lemuel Hahn PhD	mr.lemuel.hahn.phd@geemail.com	Colorado Springs	Colorado	4975862991696091	527b56d5e562ea87ea9329742cb5c290	Mastercard	38.829245445230228	-104.667474768372998
37913	2020-07-17 06:56:12	2020-07-17	Isidore Mertz	isidore.mertz@geemail.com	Charlotte	North Carolina	639083930944166	2b729ffb18fe6f055e424ac85044cf6b	VISA 13 digit	35.2723638344343726	-80.8611896809134691
37914	2020-07-17 06:58:32	2020-07-17	Larue Fahey	larue.fahey@geemail.com	Oakland	California	3088879747680030859	a10828fa38fc8c5d027f1d2c06b511b0	Maestro	37.7884500703796604	-122.259915191421186
37915	2020-07-17 07:03:58	2020-07-17	Danny Erdman I	danny.erdman.i@warmmail.com	San Francisco	California	52612127717852256	6a326184614d962d15ea6ef2a8092f0b	VISA 16 digit	37.8143129616014591	-122.453714269442528
37916	2020-07-17 07:05:02	2020-07-17	Georgie Dach	georgie.dach@geemail.com	Salt Lake City	Utah	52476868056350080	28968c43abdd0d0b57f955d56ad82e68	American Express	40.6860776018496608	-111.918354809651149
37917	2020-07-17 07:12:23	2020-07-17	Isis Herman	isis.herman@geemail.com	Detroit	Michigan	4439280567528004	a092582c7b35fc5fc4237eacf83d9075	Diners Club / Carte Blanche	42.377845856772737	-83.0768282593812728
37918	2020-07-17 07:20:51	2020-07-17	Jamari Daniel	jamari.daniel@geemail.com	Riverside	California	3024453460549071	2f2c64f5e95a67c8ef74e07b936c5111	American Express	33.8568993404455441	-117.45886791711375
37919	2020-07-17 07:23:22	2020-07-17	Dr. Delcie Abshire DVM	dr.delcie.abshire.dvm@geemail.com	Kansas City	Kansas	53344592949133970	142b7ff990a7cb557a3f41f9aa8339fd	JCB 15 digit	39.1627846222743443	-94.6903333234537428
37920	2020-07-17 07:35:02	2020-07-17	Tyler Kovacek	tyler.kovacek@geemail.com	Houston	Texas	4317841791791713	8cf14539b823345677825c7ad694670a	JCB 16 digit	29.7289127274028964	-95.3901882002145101
37921	2020-07-17 07:42:36	2020-07-17	Ms. Angelic Quigley	ms.angelic.quigley@geemail.com	Memphis	Tennessee	55677640254627263	b1c4c1f6e50e81ccf896c9a196debf14	VISA 16 digit	35.1230860428020364	-89.921094484140724
37922	2020-07-17 07:52:51	2020-07-17	Ignacio Berge	ignacio.berge@geemail.com	Fort Wayne	Indiana	3003739168656940	6f35ae7beca98cbe4dc2a473fa0c26d3	JCB 15 digit	41.0439950370945041	-85.1309382308494378
37923	2020-07-17 07:56:53	2020-07-17	Dr. Heidi Orn DVM	dr.heidi.orn.dvm@geemail.com	Plano	Texas	4174185460832	4d1c7d7face9a0ebd5c51c349fa9898e	American Express	32.9796681113161156	-96.7986046440150574
37924	2020-07-17 08:22:11	2020-07-17	Val Pfannerstill	val.pfannerstill@geemail.com	Seattle	Washington	3042148310034702	28cf20ec458dad0d5944d6a8e7e7e5bd	Discover	47.6156114582829204	-122.320225383612879
37925	2020-07-17 08:31:13	2020-07-17	Dewitt Deckow	dewitt.deckow@warmmail.com	Indianapolis	Indiana	53664307002979595	d2123f3e295afd037c31838569226f99	JCB 15 digit	39.7127235252417634	-86.2152239072803326
37926	2020-07-17 08:45:18	2020-07-17	Elliott Schaefer	elliott.schaefer@warmmail.com	Baton Rouge	Louisiana	4917485888675910	00318877f036c2d327f97f492ba82ec9	JCB 16 digit	30.4351751791991276	-91.1109929690245508
37927	2020-07-17 08:58:51	2020-07-17	Burnett Rippin	burnett.rippin@geemail.com	El Paso	Texas	4602316831661	e43a81f1c1349482fcbd633a7890353e	JCB 16 digit	31.847507555113733	-106.525561875848112
37928	2020-07-17 09:00:44	2020-07-17	Elfreda Mann	elfreda.mann@geemail.com	Gilbert	Arizona	3053281118929390	5222ffd7c377440cc004c822e969c15f	JCB 16 digit	33.2257669932089712	-111.666016249185802
37929	2020-07-17 09:04:42	2020-07-17	Levin Schmeler	levin.schmeler@geemail.com	Little Rock	Arkansas	869912866660202243	610a84dcdb506246f11121fcf28a1945	JCB 16 digit	34.7109109270196399	-92.2873420300766725
37930	2020-07-17 09:08:02	2020-07-17	Wardell Fisher	wardell.fisher@geemail.com	Oklahoma City	Oklahoma	3337806101249059579	138a6e7b54497390501f5c3d9209745b	Mastercard	35.3748375504188246	-97.4680704502284527
37931	2020-07-17 09:08:45	2020-07-17	Gracelyn Bergnaum	gracelyn.bergnaum@geemail.com	Dallas	Texas	501844080028572	66c5ac84807f555ea919c1edae08daf2	VISA 16 digit	32.7885590275090237	-96.7406033873055122
37932	2020-07-17 09:24:24	2020-07-17	Dr. Allyssa Corkery	dr.allyssa.corkery@geemail.com	Lexington	Kentucky	869979065325187861	5b9678f3dde8966253df12a9a7223f1b	JCB 15 digit	38.0348346103325525	-84.5054885301638308
37933	2020-07-17 09:30:21	2020-07-17	Marsh Harber-Connelly	marsh.harber.connelly@woohoo.com	Oakland	California	561234497659507	41d66c710e10fcec94118b8f0d375980	VISA 16 digit	37.7772477279394252	-122.270508970166787
37934	2020-07-17 09:43:40	2020-07-17	Ms. Andrea Mueller MD	ms.andrea.mueller.md@geemail.com	Vancouver	Washington	180097722841142444	03f0e65a291024ea3d6592189e7ee8b1	Maestro	45.5366401992809031	-122.631028304115674
37935	2020-07-17 09:44:13	2020-07-17	Grace Erdman	grace.erdman@geemail.com	Houston	Texas	3158513171170473283	48cbdd02c39c92ae11ea24458008f054	VISA 16 digit	29.8615464431777582	-95.34337453600169
37936	2020-07-17 09:51:39	2020-07-17	Miss River Halvorson PhD	miss.river.halvorson.phd@geemail.com	Frisco	Texas	3026158296164197	5d29e132deb2f32af80771b72a106e55	VISA 16 digit	33.1369030666533888	-96.8978786662895146
37937	2020-07-17 09:54:19	2020-07-17	Armstead Harvey	armstead.harvey@warmmail.com	Eugene	Oregon	6011741621272026896	6c72309ba93990dc01a0b9dd2bd55a4c	Mastercard	44.1246459542036078	-123.096240152883169
37938	2020-07-17 09:59:22	2020-07-17	Male Sporer	male.sporer@geemail.com	Stockton	California	675925974540566	875852aa7deb5f3b02e0695ec9a48790	American Express	38.0145475025951853	-121.353691599573196
37939	2020-07-17 10:14:11	2020-07-17	Trevion Koss-McCullough	trevion.koss.mccullough@woohoo.com	El Paso	Texas	869931708516172112	8e2f6ab13c1dd8262ec561d9122eb6c4	Diners Club / Carte Blanche	31.8983487393070035	-106.412385206853983
37940	2020-07-17 10:16:59	2020-07-17	Jaeda Connelly	jaeda.connelly@geemail.com	New York	New York	4750797686599	7ac7a42fd1069308d95fe2ad2ae4bac1	VISA 16 digit	40.7472320669554193	-73.8712389735866282
37941	2020-07-17 10:17:34	2020-07-17	Ilo Wolf	ilo.wolf@warmmail.com	Warren	Michigan	4283792823796131	b3c88e17e338a4cada083e6675ffa303	JCB 15 digit	42.4037573906123626	-82.9287494338117597
37942	2020-07-17 10:24:53	2020-07-17	Hartley Kreiger	hartley.kreiger@geemail.com	Peoria	Arizona	6011788444801119288	dfd563fdce7e48dbdbdbb63d190095cb	VISA 16 digit	33.7800183949794643	-112.259299184095127
37943	2020-07-17 10:28:02	2020-07-17	Boysie Gislason	boysie.gislason@geemail.com	Little Rock	Arkansas	3449274425022377	cac6f9a6c5c446c77962cc7a6083e192	Voyager	34.6946083678673958	-92.2776395006444261
37944	2020-07-17 10:32:52	2020-07-17	Laisha Quitzon-Bayer	laisha.quitzon.bayer@geemail.com	Oxnard	California	3026826575276888	015e17ee05c2e38600c46768e14c617a	VISA 13 digit	34.1608136092267927	-119.294404168511178
37945	2020-07-17 10:38:57	2020-07-17	Alvy Franecki PhD	alvy.franecki.phd@geemail.com	Sunnyvale	California	869981260174050148	8095d7d0d995d768fa495485d596ddb9	JCB 16 digit	37.3919418416444245	-122.096586099100492
37946	2020-07-17 10:46:56	2020-07-17	Mr. Gideon Kautzer	mr.gideon.kautzer@woohoo.com	Cedar Rapids	Iowa	3528822264796457339	2c840a4c8e8a4818a861a6fa6a6fed33	VISA 13 digit	41.9243271433822784	-91.6911102527353989
37947	2020-07-17 10:48:54	2020-07-17	Lesley Bogisich	lesley.bogisich@woohoo.com	Shreveport	Louisiana	3013516011455856	d076334c12b7f74d455d305051a9b8c6	American Express	32.3712835998978505	-93.8712428315754863
37948	2020-07-17 10:53:25	2020-07-17	Dr. Almina Wilkinson	dr.almina.wilkinson@geemail.com	Huntington Beach	California	6011024751643003742	4491b649d7ff9ce6a5d0236fd46d733a	VISA 16 digit	33.7435986184556072	-118.005513660947969
37949	2020-07-17 10:56:26	2020-07-17	Uriah Pagac	uriah.pagac@warmmail.com	Tulsa	Oklahoma	54040501220638299	23a7e28ec41e8187e2d7267e1d510008	JCB 15 digit	36.18138305027	-95.9441819804210212
37950	2020-07-17 11:01:28	2020-07-17	Mr. Ruby Parisian	mr.ruby.parisian@warmmail.com	San Jose	California	6011394399938758026	c07410378644c453ff3c47e8f3ee41ac	VISA 13 digit	37.232494005030766	-121.83255822446533
37951	2020-07-17 11:17:38	2020-07-17	Keshaun Streich III	keshaun.streich.iii@geemail.com	San Francisco	California	6011783751012868296	18ed7ef2aad226a0521c1ce9908272f4	Diners Club / Carte Blanche	37.768548835797418	-122.449732502695369
37952	2020-07-17 11:19:44	2020-07-17	Cher Goodwin DDS	cher.goodwin.dds@geemail.com	New York	New York	51163901272012305	1620fff6244c0a8158874b9609bf7f3e	Maestro	40.5638105019219211	-73.9736975899793237
37953	2020-07-17 11:20:02	2020-07-17	Kerrie Abshire	kerrie.abshire@geemail.com	Lakewood	New Jersey	3112260794388241146	ddc8fdd046c1d1aaaaf07a025f98f5b0	VISA 13 digit	40.0355883349016324	-74.1031150247246018
37954	2020-07-17 11:21:17	2020-07-17	Leana Aufderhar DVM	leana.aufderhar.dvm@geemail.com	Boston	Massachusetts	4169629023868006	64fd1b42f7274b48b02acde8b137268f	Discover	42.316734755987305	-70.9670730834312735
37955	2020-07-17 11:25:28	2020-07-17	Mr. Eusebio Adams I	mr.eusebio.adams.i@geemail.com	San Francisco	California	6011753260951776102	5fb291e31f4712dd1f6af32d2b49bbbc	JCB 15 digit	37.8015332397055843	-122.413616531566319
37956	2020-07-17 11:26:50	2020-07-17	Hermina Streich	hermina.streich@geemail.com	Clovis	California	4084497706527279	3e23947d09658505b914ec2172627a4a	Maestro	36.7914455151993778	-119.768785805914177
37957	2020-07-17 11:40:08	2020-07-17	Thos Johns	thos.johns@geemail.com	Lowell	Massachusetts	6011513460898749953	08f20d029a1715b4b3924f0ec1e0062f	VISA 16 digit	42.7174598216414481	-71.2743529768999622
37958	2020-07-17 11:46:16	2020-07-17	Mrs. Amber Oberbrunner MD	mrs.amber.oberbrunner.md@geemail.com	New York	New York	3432484227417514	644bc8cad6e8c7c25382f1ffadcd0573	JCB 15 digit	40.6285280057452596	-73.8523173609644203
37959	2020-07-17 11:46:20	2020-07-17	Pearlene O'Connell	pearlene.o'connell@geemail.com	New York	New York	4911913239760939	2c0369c6f385b78bf090f2a6662aa14d	JCB 16 digit	40.6432729060985167	-73.9965711135312887
37960	2020-07-17 11:49:22	2020-07-17	Dr. Christena Lesch DDS	dr.christena.lesch.dds@geemail.com	Plano	Texas	4609058535932217	50385a05598384873d32afce2fe4e181	JCB 16 digit	33.0070927362974729	-96.8191297600228324
37961	2020-07-17 11:49:49	2020-07-17	Yetta Baumbach-Shields	yetta.baumbach.shields@geemail.com	Knoxville	Tennessee	3051878917853390	f723d0da43a298096efe28d4b1cd1b0c	Maestro	35.9797706994757078	-83.9090017600666727
37962	2020-07-17 11:52:22	2020-07-17	Chris Jerde-Heaney	chris.jerde.heaney@geemail.com	New Orleans	Louisiana	51427424592554429	ec4404fd0b89f30a5054360fd9c3bda4	Voyager	29.9550215458977966	-90.014861533211544
37963	2020-07-17 11:54:26	2020-07-17	Aili Marquardt	aili.marquardt@woohoo.com	San Antonio	Texas	3112248109171052070	8a94f555b7603de8394e79c9113e172b	VISA 16 digit	29.4171714757174243	-98.6073209544014162
37964	2020-07-17 11:55:34	2020-07-17	Mr. Jarett McLaughlin Jr.	mr.jarett.mclaughlin.jr.@geemail.com	Oklahoma City	Oklahoma	676137827612716	4e9c9fd418799aaa0ea1349b0cc64082	JCB 15 digit	35.3906802675597376	-97.4306718917924854
37965	2020-07-17 11:56:10	2020-07-17	Kaylin Marks	kaylin.marks@geemail.com	Tucson	Arizona	4159931571744759	e25f5877b6722d8125e59fcc1ab43db8	VISA 16 digit	32.2033453425899197	-110.93639997939988
37966	2020-07-17 12:02:13	2020-07-17	Bascom Cruickshank	bascom.cruickshank@geemail.com	San Francisco	California	3036186508625374	8e2ee80ea95d5c3e5b7fbfa4e5b051eb	Mastercard	37.7927530220862309	-122.450262790182705
37967	2020-07-17 12:04:49	2020-07-17	Keeley Little	keeley.little@geemail.com	Denver	Colorado	3088225501009441011	379e255dfddcc0b09df56cbed8ae8e35	JCB 15 digit	39.8552064155746208	-104.923075598316643
37968	2020-07-17 12:16:41	2020-07-17	Dena VonRueden PhD	dena.vonrueden.phd@geemail.com	Berkeley	California	6011001615235878059	cf79ae2429eefff42e96941c9e68eaa8	VISA 13 digit	37.876708842931059	-122.261978833645784
37969	2020-07-17 12:19:04	2020-07-17	Brooks Harris	brooks.harris@geemail.com	Augusta	Georgia	3460264667692155	12fcea13be981e4596dd8a7acbf93057	JCB 16 digit	33.4282986523788423	-82.1687821663279152
37970	2020-07-17 12:23:51	2020-07-17	Phyllis Lebsack	phyllis.lebsack@warmmail.com	Tampa	Florida	210031566653103088	ee3c88e89f01f34e362a75ffb6d48fdf	VISA 16 digit	27.9348016273345792	-82.4396544463679106
37971	2020-07-17 12:26:07	2020-07-17	Mr. Morris Rath DDS	mr.morris.rath.dds@geemail.com	Denver	Colorado	6011462092921129381	41571d4e52314590691575f105e01dd5	JCB 16 digit	39.7808815145451575	-104.878377241433043
37972	2020-07-17 12:29:15	2020-07-17	Golden Schmidt-Hauck	golden.schmidt.hauck@warmmail.com	Davenport	Iowa	6011837563732740101	8ec59729f0b0b69c4dd5da8898736c47	Mastercard	41.4844859699983104	-90.6351966006644005
37973	2020-07-17 12:32:20	2020-07-17	Rosabelle Runolfsdottir	rosabelle.runolfsdottir@woohoo.com	Phoenix	Arizona	3096468028929247043	4356d4fa4ec438b745a53bc063b0a49b	Diners Club / Carte Blanche	33.5888196434758655	-112.17264602174275
37974	2020-07-17 12:42:12	2020-07-17	Emry Schuppe	emry.schuppe@geemail.com	Aurora	Colorado	4760020284524673	b7dc3b3d58c3be895aa606a324dc8295	Mastercard	39.6921667921468639	-104.653661872737857
37975	2020-07-17 12:47:13	2020-07-17	Alec Murphy	alec.murphy@geemail.com	Tempe	Arizona	55201158397939888	d10c4c6e213fbc53b7b2ebe25c2ca834	Voyager	33.3729145760104018	-111.932698048421358
37976	2020-07-17 12:51:56	2020-07-17	Zina Wunsch	zina.wunsch@woohoo.com	Los Angeles	California	3158445180861761503	6aad767bb3d8b548db26c66362b8763a	JCB 15 digit	34.0545409769616967	-118.464948237220938
37977	2020-07-17 12:54:21	2020-07-17	Anahi Ritchie-Larkin	anahi.ritchie.larkin@geemail.com	Long Beach	California	55910198861398114	38c3d952608ea6200ec1a4f4c70a9e0b	JCB 16 digit	33.7236551633857147	-118.144249811318886
37978	2020-07-17 13:01:34	2020-07-17	Mr. Harris Baumbach I	mr.harris.baumbach.i@warmmail.com	Tucson	Arizona	6011976389761617726	1749769c85a82400b69a558432285d37	American Express	32.1872621726285715	-110.854449457278847
37979	2020-07-17 13:01:56	2020-07-17	Elida Koepp	elida.koepp@geemail.com	Aurora	Colorado	3004340622302566	2b026681f972e9baf18437926c24b9fa	VISA 16 digit	39.7699324120879183	-104.654535856482383
37980	2020-07-17 13:08:29	2020-07-17	Otelia Kuhn	otelia.kuhn@woohoo.com	Baltimore	Maryland	4510425909430607	69e6b586e5ecb95783dbb3f7b95f3b82	JCB 16 digit	39.3644545297604012	-76.6248761080224057
37981	2020-07-17 13:08:31	2020-07-17	Mrs. Brinda Lind MD	mrs.brinda.lind.md@geemail.com	St. Louis	Missouri	52575414486795782	cfae2e5ab6491bc88b2dff68308a37ab	Voyager	38.7077992273651077	-90.1792367160789752
37982	2020-07-17 13:18:12	2020-07-17	Davian Zieme	davian.zieme@geemail.com	Chula Vista	California	4697936846310269	57dffa3900737255a9c36fa8a4067061	Diners Club / Carte Blanche	32.556571407313271	-117.020698594325026
37983	2020-07-17 13:19:47	2020-07-17	Bethzy Strosin-Goyette	bethzy.strosin.goyette@geemail.com	San Francisco	California	53031550426423742	fcf96b2541256dac6f3bad5b9344ae2c	VISA 13 digit	37.7587275005012586	-122.410126226542786
37984	2020-07-17 13:21:59	2020-07-17	Rhoda Pollich	rhoda.pollich@geemail.com	Los Angeles	California	6011477077069701110	378a77d41e07c207b75161fc963d9dbc	JCB 15 digit	33.9453487983770614	-118.39807634758688
37985	2020-07-17 13:23:36	2020-07-17	Les Jast	les.jast@geemail.com	Houston	Texas	3088895334321000441	cc70b8530e59b3c64bceef1e54c0cbb6	JCB 16 digit	29.8531575674269334	-95.3781036796063262
37986	2020-07-17 13:26:35	2020-07-17	Elex Rutherford	elex.rutherford@geemail.com	Birmingham	Alabama	4755024359477756	bcffa03ca988ebe2da4e699a8d2303f5	JCB 16 digit	33.5017777491617963	-86.7839276822060413
37987	2020-07-17 13:30:02	2020-07-17	Reilly McKenzie	reilly.mckenzie@geemail.com	Kansas City	Missouri	6011034840890448920	c3fc78f42a210ed40ec48e2a9452cf82	American Express	39.0340020158164265	-94.5034460833519745
37988	2020-07-17 13:46:41	2020-07-17	Corda Gulgowski	corda.gulgowski@warmmail.com	Laredo	Texas	676140171134907	be9a27b36f838a19648bde9df77c94e9	VISA 16 digit	27.5466530768848976	-99.5048695861835029
37989	2020-07-17 13:49:25	2020-07-17	Adele White-Grady	adele.white.grady@geemail.com	Las Cruces	New Mexico	51935395734770385	13f8b32f4a959c37ff7ffd2d08987084	VISA 16 digit	32.2676058698013435	-106.847938856680685
37990	2020-07-17 13:56:32	2020-07-17	Pheobe Bernhard	pheobe.bernhard@geemail.com	Raleigh	North Carolina	6011345123190761555	de4771d48539db31e9bdf6461508e405	JCB 15 digit	35.8419130344077885	-78.7374349699758085
37991	2020-07-17 13:58:42	2020-07-17	Jason Gerhold I	jason.gerhold.i@geemail.com	Phoenix	Arizona	4957761355528621	5a270e8367c52ae4329ee709ef2bdc60	American Express	33.5841914370123291	-111.995033968652052
37992	2020-07-17 14:11:51	2020-07-17	Lindsey Lemke	lindsey.lemke@geemail.com	Fresno	California	869968647626662479	89d22e7a86ce2a4a81ed7e3a8496b67b	Voyager	36.7650841199200613	-119.814036251196271
37993	2020-07-17 14:16:49	2020-07-17	Wilfredo Windler	wilfredo.windler@geemail.com	Carlsbad	California	502030708509168	694e0b1b9d2339f35894d2ece22f05ff	JCB 16 digit	33.1423521738439817	-117.254275144522254
37994	2020-07-17 14:30:23	2020-07-17	Cristobal Huel-Thompson	cristobal.huel.thompson@warmmail.com	Winston–Salem	North Carolina	4821020930676585	e5d5832befe8e81bb02663b06ccccb9c	Diners Club / Carte Blanche	36.0932738069675878	-80.2078250080477346
37995	2020-07-17 14:36:40	2020-07-17	Marylou Gleichner	marylou.gleichner@geemail.com	Durham	North Carolina	180017271653127173	c7bc21431a304205eb035ce93d1d929f	VISA 16 digit	36.0031466402824947	-78.9919483372379148
37996	2020-07-17 14:36:58	2020-07-17	Madden Blanda	madden.blanda@geemail.com	San Francisco	California	6011867170022758372	e0a9bf1d64468e9725ec37ef47102672	JCB 15 digit	37.7871620787399962	-122.458786630237583
37997	2020-07-17 14:41:26	2020-07-17	Mercer Gaylord	mercer.gaylord@geemail.com	Lexington	Kentucky	060427399285132	eda8697e243f3831541963c0ee71b4fc	JCB 16 digit	37.9705692231532197	-84.544727772836751
37998	2020-07-17 14:44:51	2020-07-17	Alzina Lesch	alzina.lesch@geemail.com	San Antonio	Texas	869990815947110476	3b1cf17526b9880636b64d78bd706fc3	Diners Club / Carte Blanche	29.4690275087092068	-98.4915210283197382
37999	2020-07-17 14:48:22	2020-07-17	Vlasta Kerluke	vlasta.kerluke@geemail.com	Rochester	New York	55362521601037002	fc63924f712b528c820a3085f36140f6	Discover	43.2230828015111399	-77.6269598412100237
38000	2020-07-17 14:51:32	2020-07-17	Mrs. Gaynell Gerhold	mrs.gaynell.gerhold@geemail.com	McAllen	Texas	3037318979748885	a59564022d7e44a284d2ef4c192c7151	JCB 16 digit	26.157722251985966	-98.1981234055790964
38001	2020-07-17 14:59:45	2020-07-17	Mr. Troy Stracke MD	mr.troy.stracke.md@woohoo.com	Dallas	Texas	3088075569850185467	1d3d60c6d4bdb739e5cbb680a8302303	Mastercard	32.7863129438173075	-96.6907812236770923
38002	2020-07-17 15:06:42	2020-07-17	Ms. Lula Moore DDS	ms.lula.moore.dds@geemail.com	Corpus Christi	Texas	869995706397177690	e998cb138afdf7259e423d52232b904a	JCB 15 digit	27.7574976400408886	-97.1343394340775887
38003	2020-07-17 15:16:30	2020-07-17	Nicolette Keeling	nicolette.keeling@geemail.com	Omaha	Nebraska	3158672217346020032	cea714d47f822fb70048008ae0f548a7	JCB 15 digit	41.3411324357759256	-96.1311360863152942
38004	2020-07-17 15:21:24	2020-07-17	Nova Armstrong-Kilback	nova.armstrong.kilback@warmmail.com	San Francisco	California	3055008416468740	e4fc0df88ae8ad3ecd88d60ee6469640	JCB 16 digit	37.7555042715624651	-122.466548177997993
38005	2020-07-17 15:29:26	2020-07-17	Dr. Nolan Langosh	dr.nolan.langosh@geemail.com	San Francisco	California	869978827053375344	cdbf78fa4f3d8498f8685abeab8e4841	JCB 16 digit	37.7720719930339115	-122.430991977388729
38006	2020-07-17 15:29:32	2020-07-17	Cephus Schaden V	cephus.schaden.v@geemail.com	Virginia Beach	Virginia	210074031498687181	20da78249ac8decad21d9a142fa14da3	JCB 15 digit	36.8106805709376914	-75.9941440167043396
38007	2020-07-17 15:50:28	2020-07-17	Mr. Tollie Fisher Jr.	mr.tollie.fisher.jr.@woohoo.com	Allen	Texas	210078375026546955	9dcf37aa7287d78c3791c5908e4e26d7	Discover	33.1656413195215123	-96.6948175696138321
38008	2020-07-17 15:51:43	2020-07-17	Mr. Ethan Kris MD	mr.ethan.kris.md@warmmail.com	Jacksonville	Florida	54297959942598193	f362cbbb54849fd0c1c3a37de009993c	VISA 16 digit	30.3850480703689172	-81.5936039705839136
38009	2020-07-17 15:52:09	2020-07-17	Lovett Botsford	lovett.botsford@geemail.com	Reno	Nevada	180049499318632129	a4b36856e48ddd22b2866b6124c1e10d	Maestro	39.6391827064644602	-119.927412466255575
38010	2020-07-17 15:53:24	2020-07-17	Jace Effertz	jace.effertz@geemail.com	Omaha	Nebraska	4879601476853	6974ce9ebb55ce454c9c3043ac63f0e0	Diners Club / Carte Blanche	41.2744777178071445	-96.0516361987799456
38011	2020-07-17 15:57:22	2020-07-17	Brendon Kuhn	brendon.kuhn@warmmail.com	Jacksonville	Florida	4744710852841910	a1015d3791ea90bbd63aa5eb80ce1d92	Mastercard	30.4145464356109514	-81.6103145979888751
38012	2020-07-17 15:58:51	2020-07-17	Galen Kunze	galen.kunze@geemail.com	Houston	Texas	869995115069341727	c6cf7530e2e0bc3256c4b8dd106e7121	Diners Club / Carte Blanche	29.780027902273833	-95.3474779369324494
38013	2020-07-17 15:59:55	2020-07-17	Infant Gerhold	infant.gerhold@geemail.com	Houston	Texas	869983214224353117	3e73379c97d76a92acfcef6374ebc2b4	Discover	29.7978831552978605	-95.4437043470811091
38014	2020-07-17 16:12:08	2020-07-17	Mavis Mosciski-Mueller	mavis.mosciski.mueller@geemail.com	New York	New York	561223214218192	613e6639d8aa0bc37d2b0d8c74630284	Maestro	40.6622488085404044	-74.0089835744246756
38015	2020-07-17 16:12:14	2020-07-17	Dr. Willaim Herzog	dr.willaim.herzog@geemail.com	Chicago	Illinois	4769637066137985	4e05bb63678a0f1a6957eaa7473f01ed	Voyager	41.7485230418223878	-87.7322936908371673
38016	2020-07-17 16:14:19	2020-07-17	Arvilla Ledner	arvilla.ledner@geemail.com	Akron	Ohio	4874065930556507	48e2a38a21ae71e7bc4c12e990d27bf7	Maestro	41.1328711305111625	-81.5358651235081311
38017	2020-07-17 16:26:28	2020-07-17	Nelia Lubowitz	nelia.lubowitz@geemail.com	San Francisco	California	3014953177863665	96928641fab8752d2b4412202423f54b	JCB 16 digit	37.7936538234593584	-122.435276676463573
38018	2020-07-17 16:30:35	2020-07-17	Catherine Dietrich DVM	catherine.dietrich.dvm@woohoo.com	San Francisco	California	54594415058585896	18fefc37e29da61493753ffc1becb2eb	Discover	37.7695228474297764	-122.446794515840239
38019	2020-07-17 16:49:30	2020-07-17	Yosef Gerlach	yosef.gerlach@geemail.com	Chicago	Illinois	4620805191132	419c94f8a7f5e4a5c18b571a2567db31	Maestro	41.8572922070812439	-87.5876949640486373
38020	2020-07-17 16:58:08	2020-07-17	Ms. Chantelle Kuhic PhD	ms.chantelle.kuhic.phd@woohoo.com	Modesto	California	3469214469575596	c0f2e86bc77d7434e9d4fa550af5a9c4	Mastercard	37.584386970894414	-120.954994466502214
38021	2020-07-17 16:58:49	2020-07-17	Karolyn Bartell DVM	karolyn.bartell.dvm@geemail.com	Columbia	South Carolina	180024864466133262	a2303abc7fbc9fdbdb4cc448ad8d74e7	VISA 13 digit	34.0532273657418756	-80.9083957580402426
38022	2020-07-17 17:14:55	2020-07-17	Lincoln Osinski	lincoln.osinski@warmmail.com	Seattle	Washington	4119653921101865	bf22b25f021d156375421e3b94562c38	VISA 16 digit	47.6142894864007857	-122.428279876328631
38023	2020-07-17 17:19:51	2020-07-17	Esley Stroman	esley.stroman@geemail.com	Oxnard	California	869972767345506916	1c53916b06a942518ae933fca87ed899	VISA 16 digit	34.1208236277990054	-119.289952812102058
38024	2020-07-17 17:19:56	2020-07-17	Curt Leuschke	curt.leuschke@geemail.com	Detroit	Michigan	3057415208026123	744f8be0edf5fa9b561c92ef28c76029	Maestro	42.2942392426002769	-83.1439585250455906
38025	2020-07-17 17:33:50	2020-07-17	Dr. Elza Krajcik	dr.elza.krajcik@geemail.com	Las Vegas	Nevada	4376036985485325	99066496fef9babedf9b324f2962f8bb	VISA 13 digit	36.1374586866803469	-115.305045128867391
38026	2020-07-17 17:40:14	2020-07-17	Keaton Strosin	keaton.strosin@geemail.com	Denver	Colorado	3337276891317275682	8d3ce345be48ef0e616e695447bbf14a	VISA 16 digit	39.6937302978761437	-104.915072964156423
38027	2020-07-17 17:47:16	2020-07-17	Denisha Collins	denisha.collins@geemail.com	San Francisco	California	210007354620986103	15310b98923fdc0327878c55a9df280d	JCB 15 digit	37.7937740408472251	-122.437602641109223
38028	2020-07-17 17:47:16	2020-07-17	Leyla Cassin-Bartoletti	leyla.cassin.bartoletti@geemail.com	New York	New York	3088134844642103790	0709fd85d53c0a747c93f2fd0e01ca30	VISA 16 digit	40.6432066843602797	-73.9400527084607546
38029	2020-07-17 17:50:04	2020-07-17	Azaria Reichert	azaria.reichert@woohoo.com	San Antonio	Texas	3088950021133913034	0d9e3ce0df34747cb477b633e9f5640e	VISA 16 digit	29.4209632202588018	-98.4968065582051793
38030	2020-07-17 18:01:06	2020-07-17	Jaycie Pagac PhD	jaycie.pagac.phd@woohoo.com	Wichita	Kansas	3158451799042739293	e65712bc99c29e4dbe1bbd49ab85f788	JCB 16 digit	37.7600273086100842	-97.3910608337927641
38031	2020-07-17 18:02:08	2020-07-17	Mr. Jerel Abshire Sr.	mr.jerel.abshire.sr.@warmmail.com	Norwalk	California	676280558992808	7d17d19922fc38717624db60cba0c9d6	VISA 13 digit	33.8121545769389726	-118.037128437267612
38032	2020-07-17 18:07:28	2020-07-17	Else White-Jakubowski	else.white.jakubowski@geemail.com	Detroit	Michigan	676142104439197	569c27373e8cde06b8bef4b2dd2170d4	VISA 16 digit	42.3667460558395845	-83.147735061834382
38033	2020-07-17 18:22:13	2020-07-17	Raiden Adams	raiden.adams@woohoo.com	Oakland	California	3528854842340600131	9ef4375a2699b8728aadfafc4235b941	Voyager	37.7598156217306666	-122.255014625219587
38034	2020-07-17 18:22:39	2020-07-17	Ora Hettinger	ora.hettinger@geemail.com	Santa Clara	California	4458577411759321	779add87dbdd04bf3a54d1fe7af50c02	Voyager	37.2774456803504393	-122.037501894868541
38035	2020-07-17 18:28:40	2020-07-17	Mrs. Nolia Koelpin DVM	mrs.nolia.koelpin.dvm@woohoo.com	Miami	Florida	4571540762499	dc35395a5e921d20fbc34a7c102bc4f2	American Express	25.8401582379497619	-80.1517248439010217
38036	2020-07-17 18:32:52	2020-07-17	Jeannine Heaney	jeannine.heaney@geemail.com	San Francisco	California	3015157713208364	8e7ed79b1c3a60838ccb1be77a296ba8	VISA 16 digit	37.7605428874808027	-122.403434213489334
38037	2020-07-17 18:32:57	2020-07-17	Lilie Labadie	lilie.labadie@geemail.com	Beaumont	Texas	4616771010611	f5624202b5dcc6ec07cb902b2b3c89d5	Voyager	30.0461981464248176	-94.1414959489155621
38038	2020-07-17 18:37:00	2020-07-17	Jovita Torphy	jovita.torphy@woohoo.com	Oakland	California	501822691164416	f9ad48ad0ca183d3fd0a64045b7c7de0	VISA 16 digit	37.8115661787620425	-122.240555628039985
38039	2020-07-17 18:39:56	2020-07-17	Dr. Freddie Hegmann DDS	dr.freddie.hegmann.dds@woohoo.com	Centennial	Colorado	180074733868303576	97b0b36d7a554507e0a6f4385ccde19c	American Express	39.6494284534867845	-104.913758867036933
38040	2020-07-17 18:41:19	2020-07-17	Jaelyn Weimann	jaelyn.weimann@geemail.com	Salt Lake City	Utah	869925233423195195	418b472c0b8211a81cac4434fe3a6071	Discover	40.828806985603272	-112.001039692055429
38041	2020-07-17 18:42:35	2020-07-17	Dr. Green Wisoky I	dr.green.wisoky.i@woohoo.com	St. Petersburg	Florida	4182429384521648	53d0e02f2980f8c317066e746ed4373a	VISA 16 digit	27.7473797183372071	-82.589182525722677
38042	2020-07-17 18:50:34	2020-07-17	Miss Ivah Funk	miss.ivah.funk@warmmail.com	Wichita Falls	Texas	180081755778598673	b7c9616e3aeb66b90819a20c0ee02619	JCB 15 digit	33.9769843826264122	-98.5602673572875432
38043	2020-07-17 18:57:54	2020-07-17	Wilma Hamill	wilma.hamill@geemail.com	Naperville	Illinois	676201378614414	0d2eb17b11afba0a09ed1cc4cbaea0c6	Mastercard	41.7133350307036181	-88.188695257239047
38044	2020-07-17 19:04:17	2020-07-17	Lavar Veum	lavar.veum@geemail.com	Chicago	Illinois	4515590859291	a8df2f2d72a725119a780874d94e8dcd	VISA 16 digit	41.885364949919655	-87.7638273880846782
38045	2020-07-17 19:05:33	2020-07-17	Mia Auer	mia.auer@geemail.com	Charlotte	North Carolina	869915338648532551	b62cc3111f66e2b29dc2895e45d2fa2a	Maestro	35.2603294409133454	-80.8114449163843034
38046	2020-07-17 19:06:31	2020-07-17	Campbell Raynor	campbell.raynor@geemail.com	West Jordan	Utah	4963074047592803	061c8d2b5c364e8b7816930644567171	Maestro	40.5242232517130674	-112.00024669771939
38047	2020-07-17 19:12:27	2020-07-17	Konner Tremblay	konner.tremblay@geemail.com	Wichita	Kansas	3033349588432623	ee40dd89a1d09c2953c5ca5d9791f094	Mastercard	37.730148137767614	-97.3709185507815391
38048	2020-07-17 19:12:43	2020-07-17	Priscilla Treutel-Hand	priscilla.treutel.hand@geemail.com	New York	New York	3158992047907115811	75fa855c9dfa1ff279919f873d3329b8	Diners Club / Carte Blanche	40.6357756531089507	-73.9332119143463586
38049	2020-07-17 19:15:42	2020-07-17	Natalya Conn	natalya.conn@geemail.com	El Paso	Texas	4495286540351456	5ead5bf400e4a0f5695804da6cb979db	Mastercard	31.7539671141948574	-106.344117028404028
38050	2020-07-17 19:17:35	2020-07-17	Jeana Nitzsche-Pagac	jeana.nitzsche.pagac@geemail.com	San Francisco	California	3337145707183078050	1c6cf5506c0259f18f9cb79b4190ad1a	Mastercard	37.7799751942856048	-122.435198055501203
38051	2020-07-17 19:28:25	2020-07-17	Washington Torp	washington.torp@geemail.com	Chicago	Illinois	3337759606811860995	349cef856ed13abd96f1b64715b89f5f	Maestro	41.8567425983794053	-87.7542217075388891
38052	2020-07-17 19:31:38	2020-07-17	Dr. Vere Paucek	dr.vere.paucek@geemail.com	Berkeley	California	4600227002358011	cb3eeeeafc417fa47fab88d25a454008	Mastercard	37.8599816168052357	-122.267422428757982
38053	2020-07-17 19:42:06	2020-07-17	Jeannette Hickle	jeannette.hickle@geemail.com	Lansing	Michigan	3716409986335581	8d7ff50dd27c1c5448b69334dbcff9bf	Mastercard	42.7123102176778033	-84.6350676430046462
38054	2020-07-17 19:48:12	2020-07-17	Danyel Heller	danyel.heller@geemail.com	Charlotte	North Carolina	4889576926745923	31182a6e335f6ca77f507b0da7650440	VISA 16 digit	35.1972858487881695	-80.9216362697482197
38055	2020-07-17 19:56:59	2020-07-17	Elia Rutherford	elia.rutherford@geemail.com	Anchorage	Alaska	3735706175055921	66120f319e9f675141d1b956a593f3ff	VISA 16 digit	61.249136109997707	-149.201831145503746
38056	2020-07-17 19:58:01	2020-07-17	Terry Windler	terry.windler@warmmail.com	Costa Mesa	California	4518524151043100	ac263ae5c02a1b342f6d06967ab7ea3e	JCB 15 digit	33.7023050237461916	-117.927188404496022
38057	2020-07-17 20:04:22	2020-07-17	Mahalie Konopelski	mahalie.konopelski@warmmail.com	Portland	Oregon	210005035034288960	573f1ff17e8539bed3c4598abc194381	JCB 16 digit	45.4481853376496545	-122.635051063308495
38058	2020-07-17 20:09:28	2020-07-17	Demetrius Durgan-Bergnaum	demetrius.durgan.bergnaum@geemail.com	San Diego	California	4743581309967686	6bde774456049e910b769b21e9ffa65b	VISA 16 digit	32.8094354359034455	-117.168863506233322
38059	2020-07-17 20:15:54	2020-07-17	Welton Jones	welton.jones@woohoo.com	Santa Ana	California	3461168484586285	aef31eb47946b49e6a53bfb03c0ef333	Voyager	33.8290282460965201	-117.93074649483151
38060	2020-07-17 20:16:29	2020-07-17	Dr. Odie Huels	dr.odie.huels@geemail.com	Gilbert	Arizona	52122824296507953	31e156b7d9cd8716e5f18e976c8b5ecf	Maestro	33.3425079072240749	-111.694986522024863
38061	2020-07-17 20:17:41	2020-07-17	Evert Larkin-Connelly	evert.larkin.connelly@warmmail.com	San Bernardino	California	3096620175032771719	226bebf4c49d3c9c056cb1ce668c6bbe	Maestro	34.2304161426410047	-117.260695024324946
38062	2020-07-17 20:18:23	2020-07-17	Dr. Delma Rowe II	dr.delma.rowe.ii@woohoo.com	Seattle	Washington	639032162017548	6adc87a6bf260fd42892eeebd084fac2	Diners Club / Carte Blanche	47.6017201587017595	-122.32440112935528
38063	2020-07-17 20:26:52	2020-07-17	Woody Wyman-Bergstrom	woody.wyman.bergstrom@geemail.com	Odessa	Texas	4118195006630	48510ccce8ef76707ec8ae52e406a091	American Express	31.9382355828780682	-102.334383273698762
38064	2020-07-17 20:30:11	2020-07-17	Clearence Rath	clearence.rath@warmmail.com	Philadelphia	Pennsylvania	210086540493229738	4338e6f98a4a1891ab243ed9627dea8d	JCB 16 digit	39.9762067149817923	-75.2287252268187814
38065	2020-07-17 20:31:22	2020-07-17	Kathrine Pagac	kathrine.pagac@woohoo.com	Los Angeles	California	4241485456206	3781979e5170fb886e24a1cdea2b8a82	VISA 16 digit	34.111297416580463	-118.361476634721456
38066	2020-07-17 20:33:40	2020-07-17	Mrs. Griselda Lynch	mrs.griselda.lynch@woohoo.com	New York	New York	54285545627776867	3e3f949f9a66f157aa7a596527e46184	Mastercard	40.5919255453385404	-74.031512148714441
38067	2020-07-17 20:45:28	2020-07-17	Uriel Ritchie	uriel.ritchie@geemail.com	Chicago	Illinois	501839635387820	dcf0bc8751f14d8107f969cc92aba838	JCB 16 digit	41.9269962865229715	-87.7729162875127003
38068	2020-07-17 20:48:31	2020-07-17	Burnice Cassin-Bayer	burnice.cassin.bayer@geemail.com	Brownsville	Texas	180035518798224671	a54331db3fd9c00c0b96bf5406d23ae6	JCB 16 digit	26.0750323620703064	-97.5538077783957078
38069	2020-07-17 20:57:24	2020-07-17	Kathleen Tillman	kathleen.tillman@geemail.com	New York	New York	4572415569310483	c0297288890d136726ea4a7d0105102e	Maestro	40.752167149608951	-73.9187862950272887
38070	2020-07-17 21:03:48	2020-07-17	Laylah Moore	laylah.moore@geemail.com	Chicago	Illinois	3033913794359506	ab0c4f62e7e4df7a5803323987ba81ab	Maestro	41.930165155122431	-87.6359359209455562
38071	2020-07-17 21:05:01	2020-07-17	Mr. Iverson Ryan	mr.iverson.ryan@warmmail.com	Kansas City	Missouri	180046771033639651	85de4f738a36d3961a352659580d1b0a	Maestro	39.0446099309552466	-94.6325646925941157
38072	2020-07-17 21:08:40	2020-07-17	Alena Huels	alena.huels@warmmail.com	Indianapolis	Indiana	52876360477294143	32601cc31b238c28e046b5fde1cb4af5	VISA 16 digit	39.7897913388449709	-86.1500103976313056
38073	2020-07-17 21:09:19	2020-07-17	Dr. Hezzie Balistreri	dr.hezzie.balistreri@woohoo.com	Boston	Massachusetts	6011044449129152887	ae43a0ac56f5cbe649e26a97351a89d3	VISA 13 digit	42.4214789129029981	-71.0098990992128876
38074	2020-07-17 21:10:05	2020-07-17	Leandra Trantow	leandra.trantow@geemail.com	Sioux Falls	South Dakota	869942373043047407	c5d43b6cee54143986714d969f477c03	JCB 16 digit	43.6106490484524514	-96.8037080598697059
38075	2020-07-17 21:13:31	2020-07-17	Worley Kovacek-Keeling	worley.kovacek.keeling@warmmail.com	Victorville	California	3088319888001645864	9976765b5b00e118c00644dd2c76ad5a	VISA 16 digit	34.4370548581935481	-117.362065812401852
38076	2020-07-17 21:16:44	2020-07-17	Almon Dietrich-Bechtelar	almon.dietrich.bechtelar@woohoo.com	Pompano Beach	Florida	3528793777955988252	b3d2f4f5d924b0f4e71f53f281d01bf6	American Express	26.175858422721177	-80.0545984730437397
38077	2020-07-17 21:17:47	2020-07-17	Evan Weimann	evan.weimann@geemail.com	Chesapeake	Virginia	55159982330780873	901df79627ebebe493830de0e7724acc	VISA 13 digit	36.62485907750726	-76.3518557939056279
38078	2020-07-17 21:19:32	2020-07-17	Stephaine Green	stephaine.green@warmmail.com	Fort Collins	Colorado	869990581199625617	440cf1ed76822eb2510824ffe8677446	American Express	40.477613494747132	-105.101830539195987
38079	2020-07-17 21:24:59	2020-07-17	Bailey Larson-Becker	bailey.larson.becker@geemail.com	Sterling Heights	Michigan	4820808001326069	47acee70b4563a49f3cbaab2c3920857	Diners Club / Carte Blanche	42.583965059424564	-82.932381103576347
38080	2020-07-17 21:25:53	2020-07-17	Dr. Kelsey Schumm	dr.kelsey.schumm@geemail.com	Houston	Texas	4855263672245	f94237856287354e56cb8383a6c16101	JCB 15 digit	29.722768665299192	-95.3844238026082536
38081	2020-07-17 21:28:24	2020-07-17	Jaheem Thiel	jaheem.thiel@geemail.com	San Francisco	California	4873064792174682	96eb909e7a7eccc7f3c9e205580e7b07	American Express	37.7688798929559084	-122.403170660286889
38082	2020-07-17 21:33:36	2020-07-17	Delphin Swaniawski	delphin.swaniawski@woohoo.com	Philadelphia	Pennsylvania	4076301979340	f7a89fed471df21fe918020a819d0eae	Mastercard	39.9552105857484037	-75.1628884113293196
38083	2020-07-17 21:34:57	2020-07-17	Savion Auer	savion.auer@geemail.com	Reno	Nevada	4944742207532	b19dbdd4c88592dd0ce56b06b8267e85	American Express	39.5198073371857461	-119.790317900355532
38084	2020-07-17 21:35:07	2020-07-17	Braiden Corwin	braiden.corwin@geemail.com	San Francisco	California	210060785838416199	2b6a294bc1f35c3d7271e718c93116c2	VISA 13 digit	37.7686775887633956	-122.440595249903055
38085	2020-07-17 21:55:50	2020-07-17	Starla Weissnat	starla.weissnat@geemail.com	Richmond	California	869986045065284715	3b3e7db7f3db788c65b33ac1a03b7111	JCB 16 digit	38.0069677910722774	-122.408786342697596
38086	2020-07-17 21:56:51	2020-07-17	Kaylah Dicki-Jacobson	kaylah.dicki.jacobson@geemail.com	Anaheim	California	210053529556271231	69a6a4b750c7270e3a5e09f6a9e15d65	Discover	33.7752401077020892	-117.786801205642888
38087	2020-07-17 22:08:49	2020-07-17	Mr. Porfirio Douglas	mr.porfirio.douglas@geemail.com	Fresno	California	869933110654207545	5102b0323b039d7ac71af7c39277567d	Diners Club / Carte Blanche	36.7669310445770634	-119.818727523052701
38088	2020-07-17 22:10:26	2020-07-17	Matt Senger	matt.senger@geemail.com	Carlsbad	California	4139776102454716	beffdf8b7bfe5d3709cc2312b5b77798	JCB 16 digit	33.0594776700191204	-117.306718053880331
38089	2020-07-17 22:23:28	2020-07-17	Dr. Rene Hills	dr.rene.hills@geemail.com	San Antonio	Texas	4049967049520011	dd4d0e7ce71364b921612c1967f53ee2	JCB 16 digit	29.5479801996216196	-98.4766954354777937
38090	2020-07-17 22:31:06	2020-07-17	Tanya Harris-Crooks	tanya.harris.crooks@geemail.com	Thornton	Colorado	210060063319818113	5acc5b3b791160aa5c2af1b0d47c92bf	Maestro	39.9362032859452114	-105.042480420989179
38091	2020-07-17 22:32:00	2020-07-17	Mr. Donta Rogahn PhD	mr.donta.rogahn.phd@geemail.com	Huntsville	Alabama	3043462649667945	c7b04d5d43f6f34f009e2f2f04daad82	Discover	34.7599379361383569	-86.7447428129632101
38092	2020-07-17 22:35:21	2020-07-17	Nealy Goodwin PhD	nealy.goodwin.phd@geemail.com	Kent	Washington	4022710697128146	4f798b83afca178990ebc8d26b523ab4	Mastercard	47.3321099106799821	-122.16692420962714
38093	2020-07-17 22:55:55	2020-07-17	June Hirthe-Spencer	june.hirthe.spencer@woohoo.com	Lakewood	New Jersey	3432945150567103	7b7bd6b25df2cb7c9d3b1012377b88af	JCB 16 digit	40.0163859418410794	-74.2620515583824385
38094	2020-07-17 23:07:06	2020-07-17	Lexus Berge	lexus.berge@woohoo.com	Honolulu	Hawaii	503855421673181	809fca0dd8d8bf8d2c4eecc23778856d	JCB 16 digit	21.3483045804996046	-157.946964585150027
38095	2020-07-17 23:07:24	2020-07-17	Yandel Padberg	yandel.padberg@geemail.com	Wichita Falls	Texas	53909684538556641	2c3368a94ce4687c654ea427cf18005e	Voyager	33.9241028920475429	-98.4452281107582081
38096	2020-07-17 23:22:55	2020-07-17	Amalia Graham	amalia.graham@geemail.com	Austin	Texas	4646687757882976	fe3efbc51d12a3d15d6db61175cd6c4b	VISA 16 digit	30.3152571007270346	-97.674744473607845
38097	2020-07-17 23:25:07	2020-07-17	Tyrell Lehner	tyrell.lehner@geemail.com	Irvine	California	6011011651061386857	23e4c5dfa93685e35d65a86960ec1988	Diners Club / Carte Blanche	33.7385221457123805	-117.826737080794942
38098	2020-07-17 23:30:35	2020-07-17	Cordelia Robel	cordelia.robel@geemail.com	Detroit	Michigan	4029937343515730	901b7ce23206162dbef0f1bd89a2df3e	Discover	42.4794026432484415	-83.1573226392853968
38099	2020-07-17 23:30:44	2020-07-17	Randall Kub MD	randall.kub.md@geemail.com	Tucson	Arizona	639060713699753	c439da33ad15bda8a0281a94ccb4cd6c	American Express	32.0624304352834812	-110.792575533943619
38100	2020-07-17 23:33:25	2020-07-17	Osie Corwin-O'Reilly	osie.corwin.o'reilly@geemail.com	New Orleans	Louisiana	4502867238924372	f990930979b100b26513f21eb0b852f2	VISA 16 digit	30.0821158773746333	-89.9243458259645791
38101	2020-07-17 23:33:42	2020-07-17	Ely Krajcik	ely.krajcik@geemail.com	Los Angeles	California	503860329065480	8ebf0f747f3959fde50210c5b274f1af	VISA 16 digit	34.0315777358464899	-118.351207669683916
38102	2020-07-17 23:34:24	2020-07-17	Christina O'Conner	christina.o'conner@geemail.com	Los Angeles	California	180002291238466984	2d7564499c7e69514580fc0ed3e543eb	JCB 15 digit	33.9259981119871128	-118.456266536190356
38103	2020-07-17 23:35:24	2020-07-17	Jonna Mraz	jonna.mraz@warmmail.com	Pembroke Pines	Florida	4689775685795	b33cd67dc0938aa35b0fdbede6552852	VISA 13 digit	26.031237265704199	-80.3537118107914949
38104	2020-07-17 23:35:58	2020-07-17	Rustin Haag-Shields	rustin.haag.shields@geemail.com	Glendale	California	180055599136143463	25010ca359d4d96ce2ffcf860572b9ac	Discover	34.0976827119231203	-118.224139133178824
38105	2020-07-17 23:36:59	2020-07-17	Mrs. Zetta Rohan PhD	mrs.zetta.rohan.phd@geemail.com	San Francisco	California	4299139608440869	c10e5ad5ebeb9f66376b001a7c5b1d1f	Discover	37.7479569837995541	-122.426760279754589
38106	2020-07-17 23:40:46	2020-07-17	Rodney Johns	rodney.johns@geemail.com	Jacksonville	Florida	52799282049093429	21a93a83f38713dbbacfb49fbd049440	JCB 15 digit	30.2536808851227157	-81.6893064410504053
38107	2020-07-17 23:50:13	2020-07-17	Hayley Lesch DDS	hayley.lesch.dds@geemail.com	New York	New York	3717541447490230	e6f6b46cfd680a40aea5d8c4990e4d17	VISA 16 digit	40.6447976440414749	-73.9137403676647722
38108	2020-07-17 23:55:28	2020-07-17	Jeanette Jakubowski	jeanette.jakubowski@woohoo.com	New York	New York	4928209081137750	31c3805dabf4cdaee024c4e08e8c2089	JCB 15 digit	40.7320618658550089	-73.8521803305845737
38109	2020-07-17 23:57:45	2020-07-17	Dr. Mitchell Powlowski	dr.mitchell.powlowski@geemail.com	Olathe	Kansas	6011698966156295924	9139a25a605425bc0722a471796a421b	JCB 16 digit	38.9335215307895126	-94.8969672882165867
38110	2020-07-17 23:58:37	2020-07-17	Cliffie Hane	cliffie.hane@geemail.com	Louisville	Kentucky	4988108521519360	0866c8f1cd6048ba113c9840b90e5e34	Diners Club / Carte Blanche	38.2415557979509231	-85.6963797448273823
38111	2020-07-18 00:04:56	2020-07-18	Makhi Schuppe Sr.	makhi.schuppe.sr.@geemail.com	San Francisco	California	3158613285522577259	0c72782dc92904aa16772ed9224f1c36	JCB 16 digit	37.7612911528906849	-122.421436681393246
38112	2020-07-18 00:07:52	2020-07-18	Jaxon Bergstrom	jaxon.bergstrom@geemail.com	Raleigh	North Carolina	4984685858289	c11d1333ac2159d65c7a7704725f2778	VISA 16 digit	35.7668396383192331	-78.7320966197580105
38113	2020-07-18 00:16:36	2020-07-18	Colbert Mayer	colbert.mayer@geemail.com	Gresham	Oregon	180072671253569413	08dfe5e3cccdcc24543a4cb486262d23	JCB 16 digit	45.5708433439444747	-122.390473634915793
38114	2020-07-18 00:22:48	2020-07-18	Sheryl Auer	sheryl.auer@geemail.com	Chattanooga	Tennessee	6011768709756111090	1682bcdc631251bec628a2231ed63253	Mastercard	34.9677808364238629	-85.206178390403835
38115	2020-07-18 00:22:56	2020-07-18	Randall Greenfelder	randall.greenfelder@geemail.com	Peoria	Arizona	869952025339460713	57199aab56257c8da3c468fcfa812cfb	VISA 16 digit	33.7711245349876563	-112.363048694182197
38116	2020-07-18 00:26:49	2020-07-18	Mr. Verner Veum	mr.verner.veum@geemail.com	Chattanooga	Tennessee	6011081293430445141	edd6c46a7b1135eb099d2dd9b7c9ce53	Mastercard	35.1181412890870135	-85.2901520615272233
38117	2020-07-18 00:29:16	2020-07-18	Kizzy Parisian-Cormier	kizzy.parisian.cormier@geemail.com	Hialeah	Florida	3052571406410173	5a500751472939893927ef7438df1496	JCB 15 digit	25.8015807804163551	-80.2348955960847405
38118	2020-07-18 00:31:36	2020-07-18	Ibrahim Bernier	ibrahim.bernier@warmmail.com	Chicago	Illinois	3096850927545491073	96180777ed1f5221c21327351e96fce2	JCB 16 digit	41.9316722858533311	-87.6079769081000137
38119	2020-07-18 00:43:41	2020-07-18	Mr. Dyllan Kling	mr.dyllan.kling@geemail.com	New York	New York	6011843814328063073	3907bc6344efa621c227d2f449e39b34	JCB 16 digit	40.6315211973842239	-73.9498608498729766
38120	2020-07-18 00:49:33	2020-07-18	Roselyn Herzog-Wuckert	roselyn.herzog.wuckert@geemail.com	San Francisco	California	6011818321001549825	2250d6e63dc2f5a758fc86454b2034e5	Maestro	37.7970303120567479	-122.451891849184733
38121	2020-07-18 01:08:18	2020-07-18	Norene Heathcote DDS	norene.heathcote.dds@woohoo.com	Newport News	Virginia	3437443648793122	b4a342f8db44968e94fd2da6d020e0f5	VISA 13 digit	36.9945327799197301	-76.5552258587703136
38122	2020-07-18 01:19:18	2020-07-18	Mr. Arland Lind	mr.arland.lind@warmmail.com	Denver	Colorado	3528895856222870092	03a1fb3cb364da5ddd1d8e8348b41046	Mastercard	39.7227667591586666	-104.96001279379837
38123	2020-07-18 01:26:26	2020-07-18	Annmarie Kemmer	annmarie.kemmer@geemail.com	Dallas	Texas	869917577320802729	d3d692e72f6a7fedfc3d711ac66efd40	American Express	32.8442938502218595	-96.8387413501236551
38124	2020-07-18 01:33:24	2020-07-18	Mr. Elbridge Auer IV	mr.elbridge.auer.iv@woohoo.com	Berkeley	California	3001903820411837	bb3ff7c06483ddbd9d475f5bb42767f1	Maestro	37.8389887896948878	-122.273106785124227
38125	2020-07-18 01:44:57	2020-07-18	Hughes Gusikowski	hughes.gusikowski@warmmail.com	Lansing	Michigan	180074628883919101	a4c49d70a57d20abc23646fde0165db4	Voyager	42.6306952670060113	-84.5332792006555849
38126	2020-07-18 01:50:22	2020-07-18	Lise Kiehn	lise.kiehn@warmmail.com	New York	New York	3774053886237361	41c1db2de57c4b1a4510f047a1dde95a	JCB 15 digit	40.726517868436872	-73.9209710007894785
38127	2020-07-18 01:55:29	2020-07-18	Charity Dicki	charity.dicki@geemail.com	Akron	Ohio	4171177378535	9b079ef1deaa2bf67a6e9bde8d49fb06	JCB 15 digit	41.0882183210290961	-81.4598054500144002
38128	2020-07-18 01:58:23	2020-07-18	Ella Lubowitz DDS	ella.lubowitz.dds@geemail.com	Buffalo	New York	4719125752054343	7b12a6fcf11612de4c91154d86b87909	VISA 16 digit	42.8399595468025609	-78.8292757151115779
38129	2020-07-18 02:02:24	2020-07-18	Isaac Hoppe	isaac.hoppe@warmmail.com	Rochester	Minnesota	3158583111527741300	f68fed37af3b9af3ec96d56224c91a1b	Voyager	44.1123149636570346	-92.5587050335135331
38130	2020-07-18 02:03:55	2020-07-18	Dr. Kelley Ondricka DVM	dr.kelley.ondricka.dvm@geemail.com	Wilmington	North Carolina	4453107953371189	9192a5543a22ab352278ec7e776ab697	VISA 16 digit	34.1908155014093964	-77.8435176347840638
38131	2020-07-18 02:18:59	2020-07-18	Mr. Juwan Towne	mr.juwan.towne@geemail.com	Rialto	California	869995597636958168	13a12149883817f66792c1202c64a75c	JCB 15 digit	34.0780455404643021	-117.455853591867907
38132	2020-07-18 02:21:02	2020-07-18	Mr. Antony Keeling PhD	mr.antony.keeling.phd@geemail.com	San Antonio	Texas	210021097240526153	11a53af75f317eeb7c8195ae5adbda1d	VISA 13 digit	29.419482625282928	-98.553573130287603
38133	2020-07-18 02:21:45	2020-07-18	Jonas Runolfsson	jonas.runolfsson@geemail.com	San Francisco	California	3040056607235597	c54eb4cee562f35612a8b3ee87c1c92f	VISA 16 digit	37.7953851508051315	-122.434313878514331
38134	2020-07-18 02:26:23	2020-07-18	Avery Tremblay DDS	avery.tremblay.dds@warmmail.com	Birmingham	Alabama	4937715829109710	53e5d9825c787dbae209e617a147cb6e	JCB 16 digit	33.4996269573714613	-86.7260495345350364
38135	2020-07-18 02:46:54	2020-07-18	Kalel Lehner	kalel.lehner@geemail.com	Oakland	California	3158321371110826853	f9c9c7cd3e4e3416687d78d201c9e375	Diners Club / Carte Blanche	37.7930655552516299	-122.266045860582835
38136	2020-07-18 02:52:40	2020-07-18	Cain Gulgowski	cain.gulgowski@geemail.com	Pueblo	Colorado	4222039193263001	f533406071983085216a441dd3687c1a	JCB 16 digit	38.270787137046085	-104.594466708540182
38137	2020-07-18 02:53:38	2020-07-18	Rowan Kozey	rowan.kozey@warmmail.com	Chicago	Illinois	3528226261377657123	96951db5d50a3eeee4f8bbe1afae0b54	Discover	41.9051481632817584	-87.7039881533507213
38138	2020-07-18 02:57:51	2020-07-18	Carly Feil-Hauck	carly.feil.hauck@woohoo.com	Cleveland	Ohio	4704309731579540	35f00f366ea4b16652acdc8d15ce5c3f	Mastercard	41.551596030717711	-81.7307399816583882
38139	2020-07-18 02:58:35	2020-07-18	Louis Ruecker	louis.ruecker@warmmail.com	New York	New York	501866349974726	4735b967ad0a9065f219682d6b2127ad	JCB 15 digit	40.5756842195745548	-73.9908557327359944
38140	2020-07-18 02:59:43	2020-07-18	Ellison Abernathy I	ellison.abernathy.i@geemail.com	Phoenix	Arizona	4781404715241526	c97c0db9d1e837396c25049d9245f308	Mastercard	33.6114990664113336	-112.027994626194612
38141	2020-07-18 03:11:20	2020-07-18	Cordelia Abernathy	cordelia.abernathy@woohoo.com	Los Angeles	California	54640691494224449	d15882b70dfd157b8e442ff2cb0e61e6	JCB 16 digit	34.0124726592894646	-118.495765805336831
38142	2020-07-18 03:11:42	2020-07-18	Gertha Fahey PhD	gertha.fahey.phd@geemail.com	Seattle	Washington	4185552477216649	7f5b38677777d8879f599378c9d9111e	JCB 16 digit	47.6540511875338879	-122.39159994702004
38143	2020-07-18 03:12:03	2020-07-18	Albin Okuneva	albin.okuneva@warmmail.com	Mesa	Arizona	53883085964690401	3ee4353a78b26062d2ec7a26eac5e427	American Express	33.3665728347055577	-111.660519121761993
38144	2020-07-18 03:14:32	2020-07-18	Gauge Bosco	gauge.bosco@geemail.com	Berkeley	California	3037911908304653	09a16f04f8cb679c2f275935a9224a66	VISA 16 digit	37.8648981197748498	-122.294270418833094
38145	2020-07-18 03:18:29	2020-07-18	Nova Beier	nova.beier@woohoo.com	Las Vegas	Nevada	6011125103383546084	411940cbf5d5859a07c0e47d8bbb411a	Voyager	36.185285677305238	-115.271992115045336
38146	2020-07-18 03:19:24	2020-07-18	Janell Labadie	janell.labadie@geemail.com	Wichita	Kansas	4864021313761	c2368f791756a8693ead94af45cb7674	Diners Club / Carte Blanche	37.6870698531966681	-97.2876075143195749
38147	2020-07-18 03:20:45	2020-07-18	Kiefer Boehm Jr.	kiefer.boehm.jr.@geemail.com	Oakland	California	4710951449993356	0159360e7a4b7463dee24a959d997f89	JCB 15 digit	37.7968751906802822	-122.255671384154013
38148	2020-07-18 03:27:49	2020-07-18	Dr. Carlie Marvin	dr.carlie.marvin@geemail.com	New York	New York	3046334643240762	2bb0c9bb014744e6afb2504bb67d2b3e	Diners Club / Carte Blanche	40.6985026747211833	-73.8995028355985824
38149	2020-07-18 03:28:45	2020-07-18	Dameon Fay	dameon.fay@geemail.com	Berkeley	California	55374588487852776	2d902b9327a8b1fea5e2fb781fd95619	VISA 16 digit	37.8670114993903866	-122.273556317632284
38150	2020-07-18 03:33:05	2020-07-18	Ruie Dooley	ruie.dooley@geemail.com	Raleigh	North Carolina	869912892196378380	7fae8bd014c6dda8a10864875a189cb2	VISA 16 digit	35.7705225995875864	-78.723837004036838
38151	2020-07-18 03:40:50	2020-07-18	Vivien Gusikowski	vivien.gusikowski@geemail.com	Stockton	California	210050723430481024	7bc052f7073c54e0f599ebadafffd151	VISA 16 digit	37.9781819193821448	-121.248277188426997
38152	2020-07-18 03:46:25	2020-07-18	Vernia Dicki	vernia.dicki@warmmail.com	Ann Arbor	Michigan	4174567559853450	57d370fbcb5dbfb79bccb1fe97fd9ace	VISA 13 digit	42.1898841251213099	-83.7737594919387334
38153	2020-07-18 03:50:20	2020-07-18	Jamin Barrows	jamin.barrows@geemail.com	Knoxville	Tennessee	6011296253959129634	6fd505f597a372bfd7c31ec721c01aa1	JCB 15 digit	35.9018262831557564	-83.8689133736520915
38154	2020-07-18 03:50:29	2020-07-18	Arline Nienow	arline.nienow@geemail.com	Kansas City	Missouri	869935074950291181	3983d9165d866422b61f655ca735d730	VISA 13 digit	39.2101913383066716	-94.5155846840925591
38155	2020-07-18 03:50:41	2020-07-18	Aloma Reynolds	aloma.reynolds@woohoo.com	Berkeley	California	4076440606874383	f7e4b1dedb753566148ec7f9ce28b45d	Mastercard	37.8845482578544264	-122.252957668731156
38156	2020-07-18 03:55:48	2020-07-18	Shelby Lueilwitz	shelby.lueilwitz@geemail.com	Los Angeles	California	3059605062133431	b6a655ce2a2b729cd86bbcf5e80deb59	Mastercard	34.0242635500483175	-118.422544983773676
38157	2020-07-18 04:07:57	2020-07-18	Clotilde Kihn DVM	clotilde.kihn.dvm@woohoo.com	Denver	Colorado	3446979009649022	b5d447d4f29f961a36dfc376eb56fb54	Voyager	39.7728326590318204	-104.809584927862886
38158	2020-07-18 04:15:07	2020-07-18	Ms. Alyvia Sauer	ms.alyvia.sauer@woohoo.com	El Monte	California	210098132420187894	d473366dacaebb5723050575dc4652ce	VISA 16 digit	34.0995867896549356	-118.11899679170773
38159	2020-07-18 04:22:30	2020-07-18	Neoma Hansen	neoma.hansen@geemail.com	Sacramento	California	180032646090813603	67901a588426e1f336d93199eec687e9	Diners Club / Carte Blanche	38.5368410825062568	-121.471520771902419
38160	2020-07-18 04:29:49	2020-07-18	Myrta Sporer	myrta.sporer@woohoo.com	St. Louis	Missouri	4363088851688479	a63e9a9981a0fba70c0b59e12474ba32	VISA 16 digit	38.6450399510718867	-90.3334492219615726
38161	2020-07-18 04:33:32	2020-07-18	Jenelle Hodkiewicz-Upton	jenelle.hodkiewicz.upton@warmmail.com	San Antonio	Texas	3337388934411337456	9bc512d910518a3391660951e1e93946	Discover	29.4320828524488967	-98.5818363120615402
38162	2020-07-18 04:34:43	2020-07-18	Elam Bednar	elam.bednar@geemail.com	Dallas	Texas	55608068180566666	abfc5b937beb781633b901a9c9346f6e	JCB 16 digit	32.7714145488377682	-96.7740434590689773
38163	2020-07-18 04:38:47	2020-07-18	Dr. Buddie Kuvalis	dr.buddie.kuvalis@warmmail.com	San Francisco	California	6011916896224084537	b4563edb82638f46cce945a7947e73ce	JCB 16 digit	37.7625162566334183	-122.428077297494042
38164	2020-07-18 04:40:40	2020-07-18	Eric O'Conner	eric.o'conner@warmmail.com	Cleveland	Ohio	630491358700713	c53a4f003b500466cd4b0a77c5569b8c	Diners Club / Carte Blanche	41.5617814579363909	-81.6276018814887863
38165	2020-07-18 04:44:32	2020-07-18	Kaylynn Hagenes	kaylynn.hagenes@geemail.com	Phoenix	Arizona	180053369080423861	7d01e9e2af5a65528ea869f50bef30cc	JCB 16 digit	33.5603198471877775	-112.171807767769707
38166	2020-07-18 04:56:56	2020-07-18	Ms. Georgia Friesen DVM	ms.georgia.friesen.dvm@geemail.com	San Francisco	California	3088886841197620210	394825b6c37ef785fcba82f4b2f1c2b7	JCB 16 digit	37.7691746719989112	-122.421121698446129
38167	2020-07-18 04:57:59	2020-07-18	Lemmie Lueilwitz	lemmie.lueilwitz@geemail.com	Chicago	Illinois	3158581823422053985	22cd182bc983968c88da3d0dca875ae7	Diners Club / Carte Blanche	41.7891714623965314	-87.6021253524377954
38168	2020-07-18 04:57:59	2020-07-18	Theodora O'Keefe	theodora.o'keefe@geemail.com	Norfolk	Virginia	3402855692502409	d43cfa6f0ba1554b272a3493415b91a8	VISA 16 digit	36.9206659953128593	-76.3153625821232851
38169	2020-07-18 05:06:24	2020-07-18	Corey Wiza	corey.wiza@warmmail.com	El Paso	Texas	4137313640426071	d47c13f16d8dcc55b7c2c35196d0fa83	JCB 15 digit	31.749910242233053	-106.499723913472153
38170	2020-07-18 05:09:00	2020-07-18	Dr. Shyheim Bailey DVM	dr.shyheim.bailey.dvm@geemail.com	San Antonio	Texas	3158145265545863578	3035b736bd56856055375b831a49ae18	Maestro	29.5235351119726914	-98.5763215858791
38171	2020-07-18 05:09:39	2020-07-18	Lizzie Brekke	lizzie.brekke@woohoo.com	Concord	California	6011362150974450509	ae8082c68d355a71b5667dbb524bbe6d	JCB 16 digit	38.0274299205679469	-122.019892669067161
38172	2020-07-18 05:15:42	2020-07-18	Eugenio Walsh	eugenio.walsh@woohoo.com	West Jordan	Utah	3088526148998205282	033d332b7d9c6b340bb26258698477c7	JCB 16 digit	40.6207060898445604	-112.076455757728965
38173	2020-07-18 05:18:03	2020-07-18	Talmage Haag	talmage.haag@geemail.com	Pearland	Texas	3528874730902369599	0b18d5dfd04766c24025144531ec8bd2	Mastercard	29.514519136891888	-95.3369071230612661
38174	2020-07-18 05:34:29	2020-07-18	Alverta Wunsch	alverta.wunsch@geemail.com	Baltimore	Maryland	869931111100578960	ac5ebf9960dbb49296a67ae770d32fa9	JCB 16 digit	39.2960392545442971	-76.6727899275738736
38175	2020-07-18 05:37:23	2020-07-18	Keagan Kilback	keagan.kilback@geemail.com	Honolulu	Hawaii	4630667948073	8406601c3b0eb6aa4a0643b8cb9a4099	VISA 13 digit	21.2655554342299702	-157.773134029165277
38176	2020-07-18 06:04:18	2020-07-18	Mr. Stanton Schamberger MD	mr.stanton.schamberger.md@geemail.com	Chicago	Illinois	53410858199684031	935165a7c778f1559e432717991f2a44	Discover	41.8688822679989059	-87.6986497192207679
38177	2020-07-18 06:07:28	2020-07-18	Luther Greenholt	luther.greenholt@warmmail.com	Spokane	Washington	3096129182994443846	5316cd775a588a0b237bfa0106f35f6d	Voyager	47.6678322409983721	-117.353508520069724
38178	2020-07-18 06:08:52	2020-07-18	Ezzard Fisher-West	ezzard.fisher.west@warmmail.com	Temecula	California	4872596515538	6bfbe740c166950ff4beaaa04c79434a	Discover	33.5470022684097273	-117.211458746176959
38179	2020-07-18 06:11:51	2020-07-18	David Bernhard-Rau	david.bernhard.rau@geemail.com	New York	New York	869907681916637465	e868234d81695ce5604d932aaaa1295b	VISA 16 digit	40.7266014750804715	-74.0302098992176383
38180	2020-07-18 06:20:41	2020-07-18	Roslyn Wolff-Ziemann	roslyn.wolff.ziemann@geemail.com	Jacksonville	Florida	4394091033215537	6d40f2cc32e73e0058473d2f36e28a5e	VISA 13 digit	30.3422227419499322	-81.5803283929437413
38181	2020-07-18 06:23:37	2020-07-18	Raina Quitzon	raina.quitzon@woohoo.com	Portland	Oregon	4704589884913451	a1ffd1cc1866c1cffed9037074685a2c	Maestro	45.556687873218209	-122.685464069526645
38182	2020-07-18 06:29:26	2020-07-18	Aloma O'Keefe MD	aloma.o'keefe.md@geemail.com	Chicago	Illinois	51116261647257756	4c94d5623b2da88f0560e0e0713a9ef4	VISA 16 digit	41.7509396983612362	-87.6776944201003658
38183	2020-07-18 06:32:50	2020-07-18	Tambra Anderson	tambra.anderson@geemail.com	Corpus Christi	Texas	501897885867073	06ccf775fcd9beb2c3f06ea1fba300de	JCB 16 digit	27.8202939779900014	-97.0798283529762216
38184	2020-07-18 06:34:55	2020-07-18	Sabra Kirlin-Ankunding	sabra.kirlin.ankunding@geemail.com	Chicago	Illinois	6011527007450048359	7661a2a909de28b775b180353ac74c55	JCB 15 digit	41.8016791074372875	-87.72733288612514
38185	2020-07-18 06:39:39	2020-07-18	Miss Eleanora Crona	miss.eleanora.crona@geemail.com	Scottsdale	Arizona	54079041035111228	ee28016b68660d54fdd266e7787eef49	Mastercard	33.7096049792721857	-111.944584067069357
38186	2020-07-18 06:44:01	2020-07-18	Marcos O'Reilly	marcos.o'reilly@geemail.com	High Point	North Carolina	53341426815386193	800120110216973e0707188866728925	Voyager	35.9356503153312943	-79.9094255374018019
38187	2020-07-18 06:46:22	2020-07-18	Liston Rau	liston.rau@geemail.com	Baltimore	Maryland	4923279676156403	79c42e46e2e307e4080158e35c4f5418	Voyager	39.381171319819984	-76.5564547888953228
38188	2020-07-18 06:46:46	2020-07-18	Coolidge Dietrich	coolidge.dietrich@geemail.com	Pomona	California	869906953588757223	71aa981c77f7298f5a5554f7a005b609	American Express	34.1557825057804578	-117.70904063614681
38189	2020-07-18 06:52:22	2020-07-18	Nathen Ziemann	nathen.ziemann@warmmail.com	San Antonio	Texas	53803783947907234	00bfbc4883c165ad9252e41e689bca93	VISA 16 digit	29.3828452039580803	-98.4526856184773038
38190	2020-07-18 07:00:29	2020-07-18	Dr. Dallas Feeney	dr.dallas.feeney@geemail.com	Columbia	South Carolina	676105150940210	0a4855d867732ec097f86bfb061f603d	JCB 16 digit	34.0686138824824241	-80.9515091576166412
38191	2020-07-18 07:02:49	2020-07-18	Camden White	camden.white@geemail.com	Fort Lauderdale	Florida	869918847723025304	204b54092d50d267a44e0ceda90503c7	Maestro	26.106298265605048	-80.0547580392386777
38192	2020-07-18 07:05:08	2020-07-18	Dayanara Morar	dayanara.morar@geemail.com	San Francisco	California	4385321671548308	4eb17a3e8fce53b50f9c78ab5cf73527	VISA 16 digit	37.8125834436363135	-122.458842676440639
38193	2020-07-18 07:08:41	2020-07-18	Frances Marvin-Lueilwitz	frances.marvin.lueilwitz@warmmail.com	Kansas City	Missouri	869993880120931087	6fd84a79f32058b51d218f1c6421c587	JCB 15 digit	39.1516467624645728	-94.5502973306216319
38194	2020-07-18 07:14:00	2020-07-18	Zoey Lockman	zoey.lockman@geemail.com	El Paso	Texas	3337559778586087864	3387f8df1f19ec8310e2c7b13027db42	Voyager	31.7750339778434494	-106.329480732509879
38195	2020-07-18 07:14:51	2020-07-18	Susanne Sporer	susanne.sporer@woohoo.com	Shreveport	Louisiana	3027899741386815	c61e7c71a0807f2107c19e73fd2e1fca	Maestro	32.4933603189658413	-93.847812089112395
38196	2020-07-18 07:21:14	2020-07-18	Clemence Brekke MD	clemence.brekke.md@geemail.com	Albuquerque	New Mexico	4509423846286	37a39f8b2b67354bb18eeec8b4e64005	Mastercard	35.1998053104285162	-106.632100179565697
38197	2020-07-18 07:22:16	2020-07-18	Ethie Koepp	ethie.koepp@geemail.com	Akron	Ohio	3337870946761259028	6282488ca3b9308e865d241ba0683f39	VISA 16 digit	41.1346476817801587	-81.4931579828575252
38198	2020-07-18 07:23:12	2020-07-18	Hermon Raynor-Fritsch	hermon.raynor.fritsch@geemail.com	Pembroke Pines	Florida	4359303547033188	a46b0cd4cc2ede3dc44f4217c21126c3	VISA 16 digit	26.0166435145344579	-80.3923968723878346
38199	2020-07-18 07:24:24	2020-07-18	Micah Harris	micah.harris@warmmail.com	Los Angeles	California	3337943637212190390	1df1f7e5cb6055b6c4c8040be91d6a30	JCB 15 digit	33.9554809623263765	-118.48345042746439
38200	2020-07-18 07:24:52	2020-07-18	Alston Tremblay	alston.tremblay@warmmail.com	Phoenix	Arizona	060454710310035	58578a0b5e56d926af56b0d265d5bedf	JCB 15 digit	33.5196771336652333	-112.062084004369012
38201	2020-07-18 07:25:33	2020-07-18	Ms. Kizzy Hermann DDS	ms.kizzy.hermann.dds@geemail.com	San Antonio	Texas	6011217488021719238	7e09ee50a7df2ca276a9cc27d8f320e5	American Express	29.3785098581179973	-98.6143532634548734
38202	2020-07-18 07:28:29	2020-07-18	Mr. Lemmie Wintheiser MD	mr.lemmie.wintheiser.md@warmmail.com	Philadelphia	Pennsylvania	4961519864154	5a8b04e2c36704fd13b24176fa97e2c3	Mastercard	40.0734543282963358	-75.1112472769703743
38203	2020-07-18 07:37:10	2020-07-18	Ms. Monserrat Keebler DVM	ms.monserrat.keebler.dvm@geemail.com	Raleigh	North Carolina	3706404334788666	ded91c9cf25a8167ca598b44402f6812	VISA 16 digit	35.7459267977759225	-78.6073240566004046
38204	2020-07-18 07:42:55	2020-07-18	Quinten Koepp	quinten.koepp@geemail.com	Oklahoma City	Oklahoma	869982320686274690	e79f81b2b5cfe82f3ea97d9f5c056503	Diners Club / Carte Blanche	35.566694266852366	-97.5692085594765786
38205	2020-07-18 07:43:04	2020-07-18	Collette Zulauf	collette.zulauf@geemail.com	North Las Vegas	Nevada	3006073141129271	3a4d16767e9b495b541c2fa95720fe21	VISA 16 digit	36.3575723929952801	-115.027287281605979
38206	2020-07-18 08:11:22	2020-07-18	Ms. Tomeka Wuckert	ms.tomeka.wuckert@warmmail.com	Baltimore	Maryland	3402780871259789	36f38158b7ff56df041dc83256451621	Maestro	39.2839621391147347	-76.6730262991990941
38207	2020-07-18 08:48:32	2020-07-18	Laisha Romaguera DDS	laisha.romaguera.dds@geemail.com	Albuquerque	New Mexico	4659864920069807	f7d709508ad6c5683486913ec18de9c6	Diners Club / Carte Blanche	35.0776627455972161	-106.672950673110421
38208	2020-07-18 08:51:30	2020-07-18	Thurman Crooks	thurman.crooks@warmmail.com	Rochester	New York	3034980176297496	a8fb9754117c13a42f54dbd6d6eef95e	VISA 16 digit	43.2283482087753725	-77.5323315261635884
38209	2020-07-18 09:22:11	2020-07-18	Sherie Bode	sherie.bode@geemail.com	Los Angeles	California	503899609161239	6c86e0c4b26a64b2ea0d64a06dabe6bf	JCB 16 digit	33.9982195363711526	-118.377234822324652
38210	2020-07-18 09:30:18	2020-07-18	Jessi Purdy DVM	jessi.purdy.dvm@geemail.com	McKinney	Texas	4601980420137446	151406e18d4604f968f9c4e4be743a6a	American Express	33.1824441854972392	-96.6737329595554655
38211	2020-07-18 09:37:55	2020-07-18	Gilberto Cassin	gilberto.cassin@warmmail.com	Berkeley	California	3792454798027072	3aa27681e9e7bcef27758d1e23157aba	Discover	37.888617706803295	-122.264434878597982
38212	2020-07-18 09:43:57	2020-07-18	Mr. Boone Kuhn	mr.boone.kuhn@geemail.com	San Francisco	California	3528334848800436205	d9bc10e06dfeca430867fc33e16a7ded	VISA 16 digit	37.7618613004620158	-122.41838857142551
38213	2020-07-18 09:46:50	2020-07-18	Phyliss Thiel	phyliss.thiel@woohoo.com	New York	New York	180007616409444011	e3ee01b36a939d52bf6207ea71303a23	VISA 16 digit	40.7165608227476454	-73.8817479078553561
38214	2020-07-18 10:00:06	2020-07-18	Miss Deasia Howe	miss.deasia.howe@geemail.com	Saint Paul	Minnesota	3112391165952102026	9a25e228ffc5078a11c2822da6bde7e4	VISA 13 digit	44.9873917011018847	-93.171461888289457
38215	2020-07-18 10:07:52	2020-07-18	Maura Medhurst	maura.medhurst@woohoo.com	Los Angeles	California	3112892979817776822	1ba62c1d724170e5ee3f0ef6cd1af56f	JCB 16 digit	33.9644774218421404	-118.328333004935828
38216	2020-07-18 10:11:22	2020-07-18	Signa Heller	signa.heller@warmmail.com	Little Rock	Arkansas	3112286410354321321	0ff5a9870df6c7e1b6bb603d03980fad	Discover	34.6843280730579053	-92.3492919060274886
38217	2020-07-18 10:11:43	2020-07-18	Dr. Ammon Donnelly Jr.	dr.ammon.donnelly.jr.@warmmail.com	Murfreesboro	Tennessee	3797789277578615	0fab25ac8bc51656cfeaa9bf94d9bab5	Discover	35.7723207768637721	-86.3466063550058749
38218	2020-07-18 10:13:32	2020-07-18	Itzel Gorczany-Armstrong	itzel.gorczany.armstrong@woohoo.com	Detroit	Michigan	52615877043480068	ce142023d93071ab06872a26f9fa886d	JCB 16 digit	42.3190068774782162	-83.0877673115234785
38219	2020-07-18 10:42:58	2020-07-18	Sanders Dare III	sanders.dare.iii@woohoo.com	New York	New York	6011137081854215916	1b6ad4158a1ecfdb0a112c48f86ff3f2	JCB 16 digit	40.6473166981469802	-73.9686776213243604
38220	2020-07-18 10:56:30	2020-07-18	Dr. Tarik Gulgowski Jr.	dr.tarik.gulgowski.jr.@geemail.com	Akron	Ohio	210053151322421931	e897e7250b2fa56702152935cd329782	Voyager	41.1774853402581087	-81.5337474523890791
38221	2020-07-18 10:57:29	2020-07-18	Carrol Simonis-Nolan	carrol.simonis.nolan@geemail.com	New York	New York	3049427839533060	be188e83b9a128ceaa4593af3b903cd5	VISA 13 digit	40.5651362537164246	-73.9132062410365762
38222	2020-07-18 11:01:33	2020-07-18	Tobias Shields	tobias.shields@geemail.com	San Diego	California	3055627387448884	0a6883e035531fb4114f4c6b8277dc24	Discover	32.8414111962143309	-117.217977299019694
38223	2020-07-18 11:28:26	2020-07-18	Lucinda Kautzer DVM	lucinda.kautzer.dvm@geemail.com	Fresno	California	6011118570456795864	c9ef9911752ebf8939bd1ec200e12d21	VISA 16 digit	36.8761829817075295	-119.790856131502991
38224	2020-07-18 11:28:40	2020-07-18	Roseanna Abernathy	roseanna.abernathy@geemail.com	San Jose	California	869988111199949975	516e0e659180c811e363813bd5045624	Maestro	37.2904931104563175	-121.742746478061747
38225	2020-07-18 11:39:03	2020-07-18	Phillis Kling	phillis.kling@woohoo.com	Chicago	Illinois	6011862258433059319	8d0c2600cee8cd20b1788d3a0205c6ac	JCB 16 digit	41.9293890547774737	-87.6518058421585664
38226	2020-07-18 11:39:14	2020-07-18	Francis Buckridge	francis.buckridge@geemail.com	Atlanta	Georgia	3158514279788151768	81fa6ea4219ac30070699a9287b277c0	Mastercard	33.7099046286471236	-84.4942319856070014
38227	2020-07-18 11:42:03	2020-07-18	Devan Grady	devan.grady@geemail.com	New Orleans	Louisiana	676250340587794	15ae68ef51b69990f275ce366b8a9d5d	VISA 16 digit	30.0490305922940379	-89.985398253219202
38228	2020-07-18 11:50:54	2020-07-18	Sebrina Kovacek-Collier	sebrina.kovacek.collier@woohoo.com	New York	New York	3056019864303908	db59ca95e3af7b764e65749a769acd16	VISA 16 digit	40.6728628499656892	-73.8913867387816339
38229	2020-07-18 12:03:51	2020-07-18	Marleigh Goyette-Conroy	marleigh.goyette.conroy@woohoo.com	Victorville	California	869929280788085798	ef61df11555a495b8bde92b7c0be3c67	Voyager	34.4552762978941232	-117.265501076836514
38230	2020-07-18 12:05:06	2020-07-18	Judd Osinski	judd.osinski@geemail.com	Omaha	Nebraska	4527193899657412	9950c04bb78fba4cdd2349b19eebdcf0	Maestro	41.3133149966742863	-96.1085072100278097
38231	2020-07-18 12:12:36	2020-07-18	Selina Walker DVM	selina.walker.dvm@geemail.com	Phoenix	Arizona	3488310345147324	4ac5c0c8f6519cf83e19314d7e728b1e	Voyager	33.5705976097311876	-112.14855681820066
38232	2020-07-18 12:17:45	2020-07-18	Mr. Tex Gutkowski III	mr.tex.gutkowski.iii@geemail.com	New York	New York	3036756172873904	e218e73d7259765d755446e8ec8c015c	JCB 15 digit	40.6886360325142746	-73.9272213226545603
38233	2020-07-18 12:18:57	2020-07-18	Shonna Harvey	shonna.harvey@geemail.com	Chicago	Illinois	3736988113217644	d5ab63e49083f31428329b8bfd9ce678	American Express	41.8370103821925809	-87.7208610438305811
38234	2020-07-18 12:20:27	2020-07-18	Lester Stoltenberg	lester.stoltenberg@geemail.com	Springfield	Missouri	3740779679387432	2c3b3839e2d1ebf13de4dc1e664627e6	Discover	37.1053109847668594	-93.2649700713168954
38235	2020-07-18 12:23:07	2020-07-18	Dr. Brooklynn Smith DVM	dr.brooklynn.smith.dvm@geemail.com	Surprise	Arizona	676268419593956	9410122836ab8ea5d0030a81d924a94f	VISA 16 digit	33.6711430891178551	-112.464818149502193
38236	2020-07-18 12:37:22	2020-07-18	Mrs. Albertha Von PhD	mrs.albertha.von.phd@geemail.com	Yonkers	New York	180074291455896478	25c0d00dfa5e35d4613c98cc89741bef	American Express	40.9663026022926005	-73.8068746561069133
38237	2020-07-18 12:49:07	2020-07-18	Cleve Weber	cleve.weber@geemail.com	Billings	Montana	3088350346439204093	474217bb3496ad3a712b3ad6df05a762	VISA 16 digit	45.7035946002453528	-108.548112647903707
38238	2020-07-18 12:54:52	2020-07-18	Encarnacion Schumm-Mills	encarnacion.schumm.mills@geemail.com	Nashville	Tennessee	4547808499640650	d19b6c2daad8548d7bdf5567b8b6edba	VISA 13 digit	36.2344258239150037	-86.7890282131172626
38239	2020-07-18 13:12:11	2020-07-18	Taft Hagenes-Wolf	taft.hagenes.wolf@geemail.com	San Francisco	California	503881749475943	a860baa2532f608f8c0bbdd0b2ae481a	VISA 13 digit	37.7963095209679665	-122.464351754579894
38240	2020-07-18 13:13:40	2020-07-18	Kurt Rutherford	kurt.rutherford@geemail.com	Phoenix	Arizona	869977206308957308	aeaa13da2f51edd09f3b3eed140af8f3	American Express	33.5922197397731281	-112.165889916142831
38241	2020-07-18 13:18:58	2020-07-18	Signe Osinski	signe.osinski@geemail.com	Milwaukee	Wisconsin	869960309480230939	b0942c6e9d49132b02e54a9551f58105	American Express	43.0581105943854894	-87.8954351371720435
38323	2020-07-18 21:01:08	2020-07-18	Alejandra Lowe	alejandra.lowe@warmmail.com	Lubbock	Texas	4375850389715	21948f629cc04354ac4471c9e759d717	VISA 13 digit	33.5423761318478739	-101.798808920747419
38242	2020-07-18 13:33:21	2020-07-18	Yuliana Reilly	yuliana.reilly@geemail.com	San Francisco	California	3088291175605557352	7c0b8b4d4f48104621e3bf43b854abbf	JCB 16 digit	37.7890533365851482	-122.425163470475766
38243	2020-07-18 13:36:49	2020-07-18	Tosha Goldner	tosha.goldner@geemail.com	New York	New York	51677819770371925	a2cced4d588b8c0912bc06c3e84c3c5b	VISA 13 digit	40.5874787579048402	-73.8958227653417765
38244	2020-07-18 13:45:28	2020-07-18	Mr. Clemon Orn IV	mr.clemon.orn.iv@geemail.com	San Francisco	California	4109908377939	3f0e2ef865cd38655e5e2d034ab9d379	JCB 16 digit	37.7645492186963807	-122.463989707065764
38245	2020-07-18 13:47:12	2020-07-18	Ebony Hauck	ebony.hauck@warmmail.com	San Francisco	California	55187605495217185	f02358de32e24d167a1da1e705c38833	Discover	37.794273552334495	-122.42617037531241
38246	2020-07-18 14:09:00	2020-07-18	Kimora Greenholt	kimora.greenholt@geemail.com	Pompano Beach	Florida	676370288871216	ec3d4756930d8a1c8e676ff729e5aa8d	American Express	26.2791924879219359	-80.0341953017130407
38247	2020-07-18 14:09:56	2020-07-18	Theophile Hackett	theophile.hackett@geemail.com	Sparks	Nevada	180084878626892325	10fddffa4a2d80419934afddc39ef374	VISA 16 digit	39.6255380277294691	-119.797005646475043
38248	2020-07-18 14:14:50	2020-07-18	Werner Rodriguez I	werner.rodriguez.i@geemail.com	Philadelphia	Pennsylvania	55843817658582448	ba7e8e4e5d5482d11dfec0ac335685d5	American Express	39.9250279224902371	-75.0393305520426566
38249	2020-07-18 14:17:47	2020-07-18	Herbert Kautzer	herbert.kautzer@geemail.com	Los Angeles	California	4701747198706	752500663bf9b103b0cbcb3ed52b8e75	JCB 15 digit	33.938585094675048	-118.47136959689594
38250	2020-07-18 14:20:29	2020-07-18	Elma Hilpert MD	elma.hilpert.md@woohoo.com	Los Angeles	California	4334480999146	5688523ac04b8c0313ff119456eb2368	VISA 16 digit	34.0205291719973033	-118.378121532731868
38251	2020-07-18 14:22:19	2020-07-18	Fawn Koepp	fawn.koepp@warmmail.com	Washington	District of Columbia	3462746706811489	2b478fc0869f87462663949b104a9ca7	Diners Club / Carte Blanche	38.9561553349051621	-76.9345258834984236
38252	2020-07-18 14:26:38	2020-07-18	Tammy Jakubowski	tammy.jakubowski@geemail.com	Lakewood	Colorado	3088269498314124951	10ef2f3881f7a50c86f553918d9b4260	Mastercard	39.7338772949237367	-105.11723698517531
38253	2020-07-18 14:29:48	2020-07-18	Anahi Tremblay	anahi.tremblay@geemail.com	Sunnyvale	California	4740766492780	3641b531ab7beb668a71f0abd5424f65	VISA 13 digit	37.3310081542462129	-122.059941320792959
38254	2020-07-18 14:29:59	2020-07-18	Dr. Stephon Jerde	dr.stephon.jerde@geemail.com	Henderson	Nevada	501858463121556	470ba690746f56723355878e2e763915	JCB 16 digit	35.9413937435418376	-114.96260162104555
38255	2020-07-18 14:45:45	2020-07-18	Newell Cronin	newell.cronin@geemail.com	Berkeley	California	51410965992091569	4af0e19eba1b00c7070b40fa650b1c9c	Diners Club / Carte Blanche	37.8959880086935144	-122.26313701080467
38256	2020-07-18 14:51:39	2020-07-18	Acie Barrows	acie.barrows@woohoo.com	Los Angeles	California	51776382157124201	e217610332f89b3d1f65c1a5e02dc1d2	JCB 15 digit	34.0070075312029516	-118.462132633849222
38257	2020-07-18 14:52:45	2020-07-18	Howell Huels-Lueilwitz	howell.huels.lueilwitz@geemail.com	Indianapolis	Indiana	502087984265089	2aa93e4ed759fc7fe4ac7addd69d28db	JCB 16 digit	39.8073729516480128	-86.1307586342297498
38258	2020-07-18 14:59:00	2020-07-18	Dr. Connie Stroman	dr.connie.stroman@geemail.com	Columbus	Ohio	869900966429717657	d2c77884d76820df1c6bb45f8b161501	Voyager	40.0095967251852116	-82.9169014505811077
38259	2020-07-18 14:59:44	2020-07-18	Richmond Davis-Roob	richmond.davis.roob@warmmail.com	San Francisco	California	3158558551967405711	f5e8171b2eacbcdaaa42d2b4745351ae	Voyager	37.79130541264702	-122.42185418721732
38260	2020-07-18 15:00:18	2020-07-18	Leighton Romaguera-Wiza	leighton.romaguera.wiza@geemail.com	Clarksville	Tennessee	3096273906384799126	754a004c7ddde091f8f3297749b0045f	VISA 16 digit	36.560038623040171	-87.4271464583881226
38261	2020-07-18 15:04:10	2020-07-18	Dr. Jeremiah Stracke PhD	dr.jeremiah.stracke.phd@geemail.com	Albuquerque	New Mexico	869915482715262559	29bdbe123996481aeb30e22a89c398df	American Express	35.1611602833162991	-106.547763277317955
38262	2020-07-18 15:07:19	2020-07-18	Arta Funk	arta.funk@geemail.com	Chicago	Illinois	4503700947494586	3920bdaaefb0017d9fb3b886375b319c	JCB 15 digit	41.770789410110936	-87.5925078863307789
38263	2020-07-18 15:16:10	2020-07-18	Kevan Runolfsdottir	kevan.runolfsdottir@geemail.com	Rancho Cucamonga	California	3024379768488540	e341d0a7393ec6c9c4909ea3ec2fbae6	VISA 13 digit	34.1922289806410689	-117.645218128385764
38264	2020-07-18 15:26:06	2020-07-18	Uriah Boyer	uriah.boyer@geemail.com	San Francisco	California	4165279983508442	bdcfcceef064225a6dd0c045f5571fb7	JCB 15 digit	37.7755848844897031	-122.44711747879829
38265	2020-07-18 15:34:26	2020-07-18	Zena Effertz	zena.effertz@geemail.com	Colorado Springs	Colorado	4645998035630827	6ca0be182a663896a23b038646c6c6d3	VISA 16 digit	38.922813850413263	-104.753302700227877
38266	2020-07-18 15:36:46	2020-07-18	Dabney Kertzmann-Koch	dabney.kertzmann.koch@geemail.com	Carlsbad	California	3018931383628748	bb13debb4dd519b0c937612ee7f0feca	Mastercard	33.214759484160318	-117.304748509151111
38267	2020-07-18 16:01:03	2020-07-18	Gretchen Johnson DDS	gretchen.johnson.dds@warmmail.com	San Francisco	California	180040038233750282	8b8048b63fff15d0ee293a7519b5ad6a	VISA 16 digit	37.7683614869879918	-122.43578167632694
38268	2020-07-18 16:11:17	2020-07-18	Mellisa Prosacco	mellisa.prosacco@geemail.com	San Francisco	California	55320325043005846	34ce03461067d627242c9efe18888e27	Voyager	37.7746825830618533	-122.446541673955494
38269	2020-07-18 16:15:28	2020-07-18	Winifred Ryan	winifred.ryan@geemail.com	Cleveland	Ohio	3088229577674100294	d6c76bcf5aa233620d55d7b23b49fdc5	JCB 16 digit	41.5284000810086695	-81.7441059399634611
38270	2020-07-18 16:19:30	2020-07-18	Irva Daniel	irva.daniel@geemail.com	Clearwater	Florida	4422557220510	82a61276dc45d4216bc6c9cf659664be	JCB 15 digit	27.9501504610419254	-82.8626001359228042
38271	2020-07-18 16:32:38	2020-07-18	Jaye Flatley	jaye.flatley@geemail.com	San Francisco	California	3112062203370601291	077abe9e29b32f115ee298e4d56e47e3	Diners Club / Carte Blanche	37.7558023840869765	-122.437810939861336
38272	2020-07-18 16:33:30	2020-07-18	Denise Friesen-O'Connell	denise.friesen.o'connell@geemail.com	New York	New York	3337897249068758282	dd009d2dd817905dfef893f031f93251	Voyager	40.6446588857322908	-73.9440722474258365
38273	2020-07-18 16:35:51	2020-07-18	Ira Spencer DVM	ira.spencer.dvm@geemail.com	San Jose	California	676344609556400	867a5595e35ced6402580530ad6b6df3	American Express	37.2416504011310678	-121.798444099979108
38274	2020-07-18 16:36:16	2020-07-18	Dr. Nathanial Block DVM	dr.nathanial.block.dvm@geemail.com	Costa Mesa	California	3088644185343966173	2a3b3a3cfbd5d9612cef2ed43c236c8a	Discover	33.7213954588878906	-117.866525819092246
38275	2020-07-18 16:44:46	2020-07-18	Efren Hayes	efren.hayes@woohoo.com	Columbus	Ohio	6011333437933463012	ddef0522a21ac6934bb3d675802c716c	American Express	40.0072398407429475	-83.0792128191564245
38276	2020-07-18 16:46:50	2020-07-18	Alda Hermiston	alda.hermiston@geemail.com	Orlando	Florida	4589997161513789	2acfe515d0c081644040205572dc6201	JCB 16 digit	28.5064884436115626	-81.3664956584073593
38277	2020-07-18 16:48:04	2020-07-18	Nikita Cartwright	nikita.cartwright@geemail.com	Fort Worth	Texas	180041752017983732	378a65ea516503f3196384f7f5694487	VISA 16 digit	32.6848593735657644	-97.3015943204805183
38278	2020-07-18 16:48:19	2020-07-18	Chantal Robel	chantal.robel@geemail.com	Minneapolis	Minnesota	6011358283267749463	a7b11efc1fd1dce85cebd13a498949e0	VISA 16 digit	44.9570571778893466	-93.3539211822479871
38279	2020-07-18 16:53:54	2020-07-18	Jaylyn Kessler	jaylyn.kessler@geemail.com	Huntsville	Alabama	210015323147545825	6a9809999aac0d265c7ad6d05ffc72d9	VISA 16 digit	34.6239395768158147	-86.6349377440307364
38280	2020-07-18 17:09:06	2020-07-18	Indiana Cremin	indiana.cremin@geemail.com	San Francisco	California	3337778150048843240	f2221bd01f354cdee71829e36e742abf	VISA 16 digit	37.7692956255083701	-122.421311343869689
38281	2020-07-18 17:09:37	2020-07-18	Dr. Kimberly Parisian	dr.kimberly.parisian@geemail.com	Fayetteville	North Carolina	3799629698338926	f493744d8ece23d1159a6ce8ff500622	VISA 13 digit	35.0853594826322066	-79.0496063306592447
38282	2020-07-18 17:14:06	2020-07-18	Ms. Abbie Cummerata	ms.abbie.cummerata@geemail.com	Oakland	California	180005945089392279	d4eaddce07472cbdc35d2b120eab976c	JCB 16 digit	37.7871734768551022	-122.246718857859577
38283	2020-07-18 17:17:25	2020-07-18	Donie Fritsch	donie.fritsch@geemail.com	San Francisco	California	503815699303200	bf2a43251612bd0782835df0eb71f50f	Discover	37.8090857214309679	-122.374185526599518
38284	2020-07-18 17:17:40	2020-07-18	Maximillian Gaylord	maximillian.gaylord@geemail.com	Washington	District of Columbia	4576806013508233	f48e6749ff9b86e58fcc9a051603a088	Voyager	38.931055716498193	-77.0970444977961478
38285	2020-07-18 17:25:05	2020-07-18	Lacy Langworth V	lacy.langworth.v@geemail.com	Syracuse	New York	180014777656542658	0ec7cdfaccb07950a606e74f1aede84e	JCB 15 digit	43.1073797989953249	-76.2379366911728056
38286	2020-07-18 17:40:09	2020-07-18	Wilton Runolfsdottir	wilton.runolfsdottir@geemail.com	Boise	Idaho	3158995101413955587	041909e61662c9a4b4fe3fa31651fdc2	American Express	43.6762701873805383	-116.252366166255257
38287	2020-07-18 17:58:02	2020-07-18	Washington Zboncak	washington.zboncak@warmmail.com	Alexandria	Virginia	589311292097372	09265fd235438671afe5e0f048d40c6c	VISA 16 digit	38.722780782508103	-77.0364748754058155
38288	2020-07-18 18:02:48	2020-07-18	Illya Schuppe	illya.schuppe@woohoo.com	Chicago	Illinois	54654769788952249	8322d97c811a909ce709c2952404e57f	VISA 16 digit	41.9154469488024759	-87.7261795447237773
38289	2020-07-18 18:15:05	2020-07-18	Dr. Kavon Wyman DDS	dr.kavon.wyman.dds@geemail.com	Syracuse	New York	210083424273216608	8ccb9a68cb3f96ed5b5b70dc8cce91a0	American Express	43.093496554423119	-76.0622645437032077
38290	2020-07-18 18:16:47	2020-07-18	Rosevelt Schaden	rosevelt.schaden@geemail.com	Columbus	Ohio	4727691711095800	fadb8cd88601b6c070d0c39280741f63	American Express	40.014983780220895	-82.9252519993811887
38291	2020-07-18 18:25:15	2020-07-18	Esther Thiel	esther.thiel@geemail.com	Abilene	Texas	6011946956501721047	910c85f4100ce96247f0349fbc8fb6ae	Mastercard	32.4911794427391172	-99.7414722238615212
38292	2020-07-18 18:26:04	2020-07-18	Miss Bree Crist DVM	miss.bree.crist.dvm@woohoo.com	Paterson	New Jersey	4419946171370	23b42993230892f86011287ee6b090d8	VISA 13 digit	40.9847800072237831	-74.0926005243297681
38293	2020-07-18 18:31:29	2020-07-18	Deborah Beahan	deborah.beahan@geemail.com	Moreno Valley	California	180070179134309183	bab3ac16f5597cc1a30faa226dbbd0e2	VISA 13 digit	33.9435635777648486	-117.114218235385408
38294	2020-07-18 18:32:04	2020-07-18	Renata Bins	renata.bins@geemail.com	Anaheim	California	4190771357080155	6e6d173372cd5167b796b274c3991efc	Maestro	33.876116658451032	-117.806407491045434
38295	2020-07-18 18:33:25	2020-07-18	Hakeem Windler	hakeem.windler@geemail.com	Honolulu	Hawaii	869913396046435050	71516f93b6e88a19992d47eb7d02e779	Maestro	21.2954817748844647	-157.922578461163113
38296	2020-07-18 18:33:29	2020-07-18	Tyreke Halvorson DVM	tyreke.halvorson.dvm@geemail.com	New York	New York	3088611075913727957	9ee9541dc3abc107e5e9092e1554ac9c	Diners Club / Carte Blanche	40.5779126487895851	-73.8812574206747144
38297	2020-07-18 18:35:04	2020-07-18	Willia O'Conner	willia.o'conner@woohoo.com	Santa Ana	California	180093781665816750	b8f354e30b63cab7a0829adc1d62a889	Maestro	33.6479169193759589	-117.814225247820829
38298	2020-07-18 18:35:23	2020-07-18	Mr. Garret Pouros DDS	mr.garret.pouros.dds@geemail.com	Laredo	Texas	869987289565883373	77268d10b7b255657e117acbe2f6e94e	JCB 16 digit	27.5963904921148	-99.3919359227649863
38299	2020-07-18 18:41:50	2020-07-18	Iverson Thiel III	iverson.thiel.iii@warmmail.com	Independence	Missouri	589373578343177	4289cd962e5382cabbb202c0a04ab71d	JCB 16 digit	39.0358371438477221	-94.2639161126971175
38300	2020-07-18 18:59:33	2020-07-18	Wendell Rolfson	wendell.rolfson@warmmail.com	San Antonio	Texas	869984986262061558	ce3d58bc6afdd8c04cceaeb955655332	American Express	29.4339012621972707	-98.5159388540614316
38301	2020-07-18 19:01:18	2020-07-18	Braelyn Wunsch	braelyn.wunsch@geemail.com	San Francisco	California	55873982347206685	a4e1c1993971f1a3e6da2df3146912b1	VISA 16 digit	37.7934078824847361	-122.40092922128953
38302	2020-07-18 19:04:23	2020-07-18	Belen Glover-Hirthe	belen.glover.hirthe@warmmail.com	Boston	Massachusetts	630494361887378	cc9c935ac701c55fcc3b03786f0f4390	VISA 16 digit	42.2888187718279696	-71.0007557632818873
38303	2020-07-18 19:05:21	2020-07-18	Mr. Raleigh Mann	mr.raleigh.mann@geemail.com	Anaheim	California	52190079475682435	9b2425238afe3aa1b162635952660aaa	American Express	33.8671489036474398	-117.769038122307876
38304	2020-07-18 19:07:03	2020-07-18	Caron Barrows	caron.barrows@woohoo.com	San Francisco	California	3048942602161874	d6c49aad988a826f4b31dbf76831be74	VISA 16 digit	37.7710579407640594	-122.385161921264626
38305	2020-07-18 19:13:12	2020-07-18	Earl Dooley-Howe	earl.dooley.howe@geemail.com	Denver	Colorado	3112778250854669398	01a507b9c7e98b4bbc2d68d3b3e45053	Voyager	39.8555228667851509	-104.916211088911069
38306	2020-07-18 19:17:22	2020-07-18	Javier Stracke	javier.stracke@warmmail.com	Reno	Nevada	3112269312983578159	9336d833586352ce6d7ae00d930df807	JCB 15 digit	39.4600296737238807	-119.818943087214237
38307	2020-07-18 19:43:51	2020-07-18	Isabella Mante DVM	isabella.mante.dvm@woohoo.com	Chandler	Arizona	54851333711470133	03507bed86a395192c4f246eb8491ab2	VISA 16 digit	33.3771908049095387	-111.884627653320877
38308	2020-07-18 19:44:44	2020-07-18	Yesenia Jones	yesenia.jones@woohoo.com	New York	New York	210089628077714089	d97070d79619c4202a0756c1f262f0b9	Mastercard	40.6543084752503745	-73.988603047317639
38309	2020-07-18 19:46:22	2020-07-18	Warren Nader II	warren.nader.ii@geemail.com	Rancho Cucamonga	California	4289391863940	1362434d3cd8584261ea854016c57e29	Maestro	34.1613236107856011	-117.56198426759876
38310	2020-07-18 19:47:39	2020-07-18	Gia Gutmann	gia.gutmann@geemail.com	San Francisco	California	3423847307289618	1d3b6377c4a45db3a12dc52ea0f7fdec	Voyager	37.753513213627869	-122.409655447671241
38311	2020-07-18 19:55:21	2020-07-18	Jaiden Schuppe	jaiden.schuppe@geemail.com	Houston	Texas	3489887119916587	9bd9dbb9b7fbffbbbbef4eecbf712bb1	VISA 13 digit	29.7501107115376726	-95.4663822944290956
38312	2020-07-18 19:56:38	2020-07-18	Santina Gulgowski PhD	santina.gulgowski.phd@warmmail.com	Kansas City	Kansas	180098853672755621	10ad2c9ec3a15f9d096f5f7085473f30	Diners Club / Carte Blanche	39.0315456904843501	-94.6434132541000821
38313	2020-07-18 19:59:42	2020-07-18	Ottie Kuhn	ottie.kuhn@geemail.com	Nashville	Tennessee	4912802873492447	d9c1fc01c30e1c79bee07d1a6f94cf03	Discover	36.0729665957514172	-86.8276303939893808
38314	2020-07-18 20:05:14	2020-07-18	Sumner Kerluke	sumner.kerluke@geemail.com	Los Angeles	California	4130826814958931	67e1453044cf772176a02e2712d46455	Maestro	34.0692771188780625	-118.50867868075072
38315	2020-07-18 20:15:26	2020-07-18	Tea Wilkinson	tea.wilkinson@geemail.com	Corona	California	4124902606600904	d957794cf93e4b645debff41656cb8ba	Mastercard	33.9264658164121258	-117.628936752976855
38316	2020-07-18 20:31:52	2020-07-18	Roni Casper	roni.casper@geemail.com	San Francisco	California	4312354735437448	4d57bb39f4bf2fc6514a94f01948dcb4	VISA 16 digit	37.7632884505338637	-122.434364648380921
38317	2020-07-18 20:35:21	2020-07-18	Jenilee McKenzie	jenilee.mckenzie@geemail.com	Billings	Montana	210089713032918080	516091433a3bc96c8d4d2cb9b9fa2a88	Discover	45.8862238534018374	-108.596702172763273
38318	2020-07-18 20:36:46	2020-07-18	Rondal Heidenreich	rondal.heidenreich@geemail.com	Fayetteville	North Carolina	4227174487341729	22b95161da005d1a794f1db026fcc35a	JCB 15 digit	35.1591570664916162	-79.0396041501909536
38319	2020-07-18 20:44:51	2020-07-18	Mrs. Lanie Gleichner	mrs.lanie.gleichner@geemail.com	Frisco	Texas	53221292437529965	34dd5f3e80317ce204b03786efb0f118	Discover	33.150325694679843	-96.8083634622603597
38320	2020-07-18 20:48:36	2020-07-18	Mindy Beatty	mindy.beatty@geemail.com	Waco	Texas	3337400636953709166	969a462ae59c96241918f08c74a1fe86	Voyager	31.4689031380902975	-97.1688926179092505
38321	2020-07-18 20:49:23	2020-07-18	Giuseppe Orn	giuseppe.orn@geemail.com	Los Angeles	California	210077983074200036	c9535d16f23b7b2ab018ad962685e022	JCB 15 digit	33.9405365996394295	-118.41279091443792
38322	2020-07-18 20:53:57	2020-07-18	Clemon Hoppe	clemon.hoppe@geemail.com	New York	New York	4738767053027028	c3afd408365b46681c67ed5681cda8b3	Mastercard	40.7275771850943542	-74.0161834341369484
38324	2020-07-18 21:10:31	2020-07-18	Alijah Leuschke	alijah.leuschke@woohoo.com	New York	New York	869920936943763442	6037999de2b2f1cfe59c70e939d5a671	JCB 15 digit	40.5875459199529161	-73.8709222516406356
38325	2020-07-18 21:26:02	2020-07-18	Talan Jast-Stanton	talan.jast.stanton@geemail.com	Los Angeles	California	676209470782054	67230ecf0725f5584125b5f408716944	Voyager	34.0492410760238755	-118.371918546547363
38326	2020-07-18 21:27:11	2020-07-18	Dr. Jenifer Weimann	dr.jenifer.weimann@geemail.com	New York	New York	3479846641555729	beec7d58d0cc92cc0a740ac250aa6529	Diners Club / Carte Blanche	40.7156938197780391	-73.9512173129141246
38327	2020-07-18 21:35:04	2020-07-18	Bowman Lakin	bowman.lakin@woohoo.com	Ontario	California	4325260360787335	1ae79326d9b42c94b5643314b4863032	VISA 13 digit	34.0706345787417177	-117.691652188134199
38328	2020-07-18 21:38:27	2020-07-18	Cristy Swift	cristy.swift@geemail.com	San Francisco	California	4190315267358697	50cd25813a5c4ee29ead40591115d865	JCB 16 digit	37.7859512619946827	-122.450246804160557
38329	2020-07-18 21:42:55	2020-07-18	Hattie Pagac	hattie.pagac@geemail.com	Pasadena	California	4520380708479198	db36e486901638df57b11ddd9109b4f3	JCB 16 digit	34.09190575376563	-118.07117850145363
38330	2020-07-18 21:47:20	2020-07-18	Adelard Padberg	adelard.padberg@warmmail.com	Greensboro	North Carolina	3096709051115019819	c9868726b977fc08589f78da9d0ffc09	JCB 15 digit	36.0958468714378782	-79.7762584163788659
38331	2020-07-18 21:50:21	2020-07-18	Shayla Bins MD	shayla.bins.md@woohoo.com	Phoenix	Arizona	3057059208251941	3ac257eb330fba46a4acb8baa40e9599	Voyager	33.655862532875318	-112.066918706560884
38332	2020-07-18 21:55:44	2020-07-18	Ms. Estrella Purdy	ms.estrella.purdy@geemail.com	Anchorage	Alaska	4434849000440475	038024a370e9cc3823c37806d47ea14c	Maestro	61.2548863277055347	-149.307348274498423
38333	2020-07-18 22:08:54	2020-07-18	Brayan Hyatt	brayan.hyatt@geemail.com	Salem	Oregon	4449094596375	2ea4f70f4b8d6df64d73446c45781e3b	Mastercard	44.8867967010743882	-123.113502008204165
38334	2020-07-18 22:25:10	2020-07-18	Nello Ortiz	nello.ortiz@warmmail.com	Thousand Oaks	California	210010481008578585	11deb3b06d0c4e4cea8f930e4e1433cd	VISA 13 digit	34.1965589638605749	-118.879440636039533
38335	2020-07-18 22:27:23	2020-07-18	Beatrix Prosacco	beatrix.prosacco@geemail.com	Elgin	Illinois	4738100420183565	e754ac61aba18e4c5a7fbfbbe3c9e409	JCB 16 digit	41.9909626975007342	-88.2539923600673717
38336	2020-07-18 22:27:36	2020-07-18	Kaci Boehm	kaci.boehm@geemail.com	San Francisco	California	4812386707809852	01ccefb121d2c7813f7f7cfec1f73b90	VISA 16 digit	37.7559757526009605	-122.447700881077679
38337	2020-07-18 22:30:01	2020-07-18	Mr. Darius Champlin	mr.darius.champlin@warmmail.com	New York	New York	676393998894526	cf20c1c98cb617ea5685e1a9e56b52dc	Voyager	40.6420807201173133	-74.0285234355729074
38338	2020-07-18 22:33:35	2020-07-18	Naoma Prosacco	naoma.prosacco@geemail.com	Philadelphia	Pennsylvania	4841668656126072	84a424eff71ebb7f04207cde4305eeac	VISA 13 digit	39.9135199232451612	-75.1991701441716458
38339	2020-07-18 22:40:58	2020-07-18	Arvin Gibson	arvin.gibson@warmmail.com	San Diego	California	3470018959521730	c83aa4b0bedb1f7b0b945fdd7cf5f7e2	Voyager	32.9000931279800852	-117.127710089543839
38340	2020-07-18 22:48:16	2020-07-18	Anahi Jast	anahi.jast@geemail.com	Springfield	Massachusetts	4079809145777710	1613283a3e6c209cf35dc0a1c2c9477f	VISA 16 digit	42.0657411633264218	-72.4921503704600099
38341	2020-07-18 22:52:53	2020-07-18	Azalee Schuppe	azalee.schuppe@geemail.com	San Antonio	Texas	3096453958103873957	bed6bb328fcfb8ed15662eacdb7b85a3	American Express	29.5166249689716835	-98.4565958198461573
38342	2020-07-18 23:15:13	2020-07-18	Soledad Wyman	soledad.wyman@geemail.com	Dayton	Ohio	54903610484706761	d54a3b67aeaa7f4ef78bc602d395fbd2	JCB 16 digit	39.792124825276062	-84.2009998792972425
38343	2020-07-18 23:15:21	2020-07-18	Winnie Robel MD	winnie.robel.md@geemail.com	Pittsburgh	Pennsylvania	4821969514768145	6a47a1d4d7b359329d1dcc341fafe308	JCB 15 digit	40.4478202503595483	-79.880203969700645
38344	2020-07-18 23:26:03	2020-07-18	Adrianna Kirlin	adrianna.kirlin@warmmail.com	Burbank	California	180060518178293757	d6197d6b00d6e7ac1316f5547e9a36f7	Mastercard	34.2242840746346886	-118.403766827987141
38345	2020-07-18 23:36:41	2020-07-18	Andre Breitenberg	andre.breitenberg@woohoo.com	San Francisco	California	4886306414089797	40c072b1d664e54a98bdea8449deb4d3	Diners Club / Carte Blanche	37.7811164775904373	-122.465432292281037
38346	2020-07-18 23:38:05	2020-07-18	Anya Okuneva	anya.okuneva@geemail.com	Santa Rosa	California	6011415905207549394	f0088367fc28d09b106afec6d2638eb0	VISA 16 digit	38.3527046476613762	-122.790706706351045
38347	2020-07-18 23:38:19	2020-07-18	Parley Walker I	parley.walker.i@geemail.com	Austin	Texas	3088836210775839744	35b2a2401b59e2a8d29498dde3adb7af	VISA 16 digit	30.3302409408275011	-97.7167541332781298
38348	2020-07-18 23:54:31	2020-07-18	Ms. Tasha Kulas	ms.tasha.kulas@geemail.com	Phoenix	Arizona	4349839583565842	3ec2a6e39dc5f82579bd9c11953ae1f1	VISA 16 digit	33.6555928747102655	-112.140584564248485
38349	2020-07-19 00:18:09	2020-07-19	Fletcher Emard	fletcher.emard@geemail.com	Des Moines	Iowa	6011165580898074804	41318971f8066fde9aa6e6ad11d13f0a	VISA 16 digit	41.6217780987475052	-93.5953665511727451
38350	2020-07-19 00:26:29	2020-07-19	Dr. Bartholomew Auer PhD	dr.bartholomew.auer.phd@warmmail.com	New York	New York	4893010565036406	47aa7ac998a3ea7c1b2f599f8547644d	American Express	40.7579792636670177	-73.9529477042507324
38351	2020-07-19 00:28:26	2020-07-19	Marcella Halvorson	marcella.halvorson@geemail.com	Santa Ana	California	210042756070554123	52bf19aca86f2c36e3d3a33cab3b085d	Voyager	33.7083985176973044	-117.855877997579043
38352	2020-07-19 00:43:59	2020-07-19	Huey Crona PhD	huey.crona.phd@geemail.com	Stamford	Connecticut	3412430084866198	6d51bda73810fedf57a4244f89c5c66b	Maestro	41.0903004300665131	-73.5579167182594631
38353	2020-07-19 00:47:25	2020-07-19	Jim Murray	jim.murray@woohoo.com	San Francisco	California	3013755499694459	a30118e9c21c3d8365f4faf487c90eab	JCB 15 digit	37.7840807612981351	-122.465747104484294
38354	2020-07-19 00:47:36	2020-07-19	Casen Ondricka PhD	casen.ondricka.phd@woohoo.com	Fort Wayne	Indiana	4518788112119	37e96b8a6123ce763ea0f49514c05e17	VISA 16 digit	41.1859826764807124	-85.2046839712873094
38355	2020-07-19 00:47:58	2020-07-19	Jacky Reynolds	jacky.reynolds@warmmail.com	Phoenix	Arizona	3337387377862340531	80be5486b77d492a11050a22d9739b60	Discover	33.6127095763038852	-112.08963069360928
38356	2020-07-19 00:48:08	2020-07-19	Elnora Ratke	elnora.ratke@geemail.com	Detroit	Michigan	3096908410527785194	4f7280f492540103f358c695a7f4e7ba	VISA 16 digit	42.4270624316222964	-83.1876480884969141
38357	2020-07-19 00:52:44	2020-07-19	Dr. Jaxton Bernier PhD	dr.jaxton.bernier.phd@geemail.com	Corpus Christi	Texas	4056849057239	5ab23a142847262f8250e5db23fefcbd	JCB 16 digit	27.7168473761931082	-97.2688081174451895
38358	2020-07-19 00:53:37	2020-07-19	Ms. Hessie Labadie DVM	ms.hessie.labadie.dvm@warmmail.com	Memphis	Tennessee	3036600597467431	343190fbe97406664dd2ebf1dc01df62	JCB 16 digit	35.079845911643659	-90.052621613794571
38359	2020-07-19 01:01:30	2020-07-19	Macie Lebsack	macie.lebsack@geemail.com	Fargo	North Dakota	6011979171575956244	ac331cf2dfff56d3fdded596d01c768c	American Express	46.8568284301318272	-96.9121211368553332
38360	2020-07-19 01:09:28	2020-07-19	Horatio Batz-Zieme	horatio.batz.zieme@geemail.com	Los Angeles	California	3023402089791094	6b90ee2b836550242c51583389c4e068	Discover	34.0404081917233725	-118.325824719340716
38361	2020-07-19 01:20:14	2020-07-19	Ima Mosciski	ima.mosciski@geemail.com	Knoxville	Tennessee	4768384574987483	44caf295de74a5f30588cde020a67ebf	VISA 16 digit	35.9997347450878493	-83.9948652801785585
38362	2020-07-19 01:22:55	2020-07-19	Harlen Koch	harlen.koch@warmmail.com	Lubbock	Texas	55343552924585025	276fe9ace4a56c9056350001462be260	Discover	33.5460130966309507	-101.865859153252842
38363	2020-07-19 01:30:30	2020-07-19	Francisca Kohler MD	francisca.kohler.md@geemail.com	West Valley City	Utah	3528951783159458306	0b600d8463aaafc9bbd00bb88745768f	JCB 16 digit	40.7159084433913208	-111.987123643395677
38364	2020-07-19 01:35:29	2020-07-19	Roxane Stracke	roxane.stracke@geemail.com	Orange	California	51524778382223400	daff76394900b96e4addb0a01cd1e990	VISA 16 digit	33.6996880045980234	-117.956337999609488
38365	2020-07-19 01:37:03	2020-07-19	Demetria Altenwerth	demetria.altenwerth@geemail.com	Spokane	Washington	6011628509129466910	cd6c27cc16337cae303032b8452d9f00	JCB 16 digit	47.757820370491217	-117.411995486159995
38366	2020-07-19 02:01:03	2020-07-19	Wells Johnston	wells.johnston@geemail.com	Chicago	Illinois	869971616281801230	eba4652ad4b46f38e67503704f4d0b39	Diners Club / Carte Blanche	41.8920485150836441	-87.5868153689458921
38367	2020-07-19 02:19:22	2020-07-19	Maryjo Heller MD	maryjo.heller.md@woohoo.com	San Francisco	California	55938974236342427	623a31fa796402888210cfd8f1a4f09d	VISA 16 digit	37.7348507041785552	-122.457290199945348
38368	2020-07-19 02:20:20	2020-07-19	Mikala Hintz	mikala.hintz@geemail.com	Chicago	Illinois	4862697333329530	e6ce0b9a0f3c19319f38c76c7ea86313	JCB 16 digit	41.7839819391094167	-87.6538661419909459
38369	2020-07-19 02:23:30	2020-07-19	Daron Effertz	daron.effertz@warmmail.com	Phoenix	Arizona	180068698485783799	1b0fe24c8c4d8c030b5e48c03db68055	Diners Club / Carte Blanche	33.5447560256280042	-112.173294449357698
38370	2020-07-19 02:25:00	2020-07-19	Pershing Jast	pershing.jast@geemail.com	San Francisco	California	676396671276622	d657868ec0a95a014691fd20719ca2ec	American Express	37.7747682565969924	-122.430668230137911
38371	2020-07-19 02:33:01	2020-07-19	Amaya Mosciski	amaya.mosciski@geemail.com	Roseville	California	3096357989696947897	a9c849857ffc9645eb6431ef645c1f0c	VISA 13 digit	38.8246896313093615	-121.284974186144396
38372	2020-07-19 02:38:59	2020-07-19	Liane Gorczany-McClure	liane.gorczany.mcclure@warmmail.com	San Francisco	California	4405060318191793	ada5357471405ad913db78bfae57d5f1	Mastercard	37.7544761732335914	-122.430751825224675
38373	2020-07-19 02:44:19	2020-07-19	Alexander McGlynn-Stokes	alexander.mcglynn.stokes@geemail.com	New York	New York	3773851229137896	2c054a41f3e62d4996e3facd8907ff70	Maestro	40.7222924781721076	-74.0242121554806829
38374	2020-07-19 02:44:43	2020-07-19	Darry Yundt	darry.yundt@geemail.com	Phoenix	Arizona	3434570822592798	17cc0488ad2d909bdd32be2ff6bee159	Discover	33.6164003229167321	-112.113508495867634
38375	2020-07-19 02:45:11	2020-07-19	Hyrum Emard-Yost	hyrum.emard.yost@woohoo.com	New York	New York	869984563976610655	cc9e6df54a5c068ebd4e5413a10c1870	JCB 15 digit	40.7127685262113772	-73.9650873670250206
38376	2020-07-19 02:48:14	2020-07-19	Dr. Saverio Lind	dr.saverio.lind@geemail.com	Oakland	California	4121108994522469	bbe1d38fd7d8d475709577fe1594d5a9	American Express	37.8229719664260742	-122.268081325222141
38377	2020-07-19 02:58:35	2020-07-19	Hilliard Cronin	hilliard.cronin@woohoo.com	Oakland	California	869947877912766256	cfe26acd0ac98e5db41ee455c094e68d	Maestro	37.7903361258118267	-122.269158763992706
38378	2020-07-19 03:08:06	2020-07-19	Miguel Rau III	miguel.rau.iii@woohoo.com	Arlington	Texas	4748874399151	7c47d71e20a6beb12d7b20e5e42d66b1	JCB 15 digit	32.7472549997519664	-97.1404513959798948
38379	2020-07-19 03:13:00	2020-07-19	Mr. Kenton Strosin DVM	mr.kenton.strosin.dvm@geemail.com	Lowell	Massachusetts	4184746291253	a2da20eb1ea5a6a9b2e3ffdfe793ad83	Maestro	42.6656992569435403	-71.2589218100871875
38380	2020-07-19 03:13:48	2020-07-19	Carolann Parisian	carolann.parisian@woohoo.com	Grand Rapids	Michigan	3058000689360610	2371c1527ad38aa13b69a20473b50847	Mastercard	43.0134819105535726	-85.7166220630653299
38381	2020-07-19 03:29:27	2020-07-19	Gracelyn Nolan	gracelyn.nolan@geemail.com	Philadelphia	Pennsylvania	3034729474055019	deea25a9ea02a961b2eae8dac49d58de	American Express	40.0035994370426948	-75.2044886635515866
38382	2020-07-19 03:32:35	2020-07-19	Cicero Orn	cicero.orn@geemail.com	Berkeley	California	4215893476279	68f7cc324f188083ad7f2e11c14817c0	Maestro	37.8865121703499597	-122.252842414840771
38383	2020-07-19 03:36:38	2020-07-19	Ethelbert Rogahn	ethelbert.rogahn@geemail.com	Murfreesboro	Tennessee	3054281179993177	6fba41d1584b9053290ac3c55e9382eb	JCB 16 digit	35.9154389625534449	-86.4478292587064203
38384	2020-07-19 03:39:50	2020-07-19	Mal Quigley-Abbott	mal.quigley.abbott@woohoo.com	San Francisco	California	3031269369947676	8989705aa9493f3bbbce6f0dcd47ad0e	VISA 13 digit	37.7430401567294851	-122.449786761399636
38385	2020-07-19 03:47:12	2020-07-19	Alfred Thompson	alfred.thompson@geemail.com	New York	New York	3337379767102145171	9c457afbb30f15dd8d0295d409713db3	Diners Club / Carte Blanche	40.7460054798740856	-73.9058715404838296
38386	2020-07-19 03:49:34	2020-07-19	Kelsi Jacobson MD	kelsi.jacobson.md@warmmail.com	Oakland	California	4791621957476829	825a84644a60bd47f49a45c4c5b75461	VISA 16 digit	37.7972014919330235	-122.262935763331654
38387	2020-07-19 03:49:54	2020-07-19	Harley Weissnat-Hane	harley.weissnat.hane@warmmail.com	New York	New York	3790139420522218	e7fc846aeb3d06ad24d8b86ccf38a05d	JCB 15 digit	40.6195739249456693	-73.9139815475221695
38388	2020-07-19 03:59:26	2020-07-19	Douglas Dooley	douglas.dooley@geemail.com	Sandy Springs	Georgia	3528732455690637492	ecf26d42680158121129de3d539dd761	JCB 16 digit	34.0046355154421178	-84.4240560370113684
38389	2020-07-19 04:00:05	2020-07-19	Diane Stracke	diane.stracke@geemail.com	San Antonio	Texas	3158124669218866773	67c7df0b227dd8e68443ccf3301cb076	VISA 16 digit	29.3773384785816063	-98.6232393033638601
38390	2020-07-19 04:08:36	2020-07-19	Pauletta Rutherford MD	pauletta.rutherford.md@geemail.com	Newark	New Jersey	53560926356690725	baa8ebc12dddae0f07c51f3845241b82	Maestro	40.8037932780485662	-74.2676022657867492
38391	2020-07-19 04:43:58	2020-07-19	Arba Walsh-Olson	arba.walsh.olson@geemail.com	Cambridge	Massachusetts	3477970909670319	af95fa1653be18a77570ff31213c23b3	VISA 16 digit	42.3129468040298633	-71.1073596777010692
38392	2020-07-19 04:46:56	2020-07-19	Hassan Homenick	hassan.homenick@geemail.com	Sandy Springs	Georgia	3528351120427521407	676a23bc15e5df4298d61f29f1a2f8d8	Diners Club / Carte Blanche	33.8822238575722992	-84.4436210138805308
38393	2020-07-19 04:50:39	2020-07-19	Ilona Harber	ilona.harber@geemail.com	San Francisco	California	55015921340959345	f552d0a5703f35d6f5b87a56de4d8c3d	Diners Club / Carte Blanche	37.7839587893263698	-122.463125837491404
38394	2020-07-19 04:53:37	2020-07-19	Marita Reichert-Hackett	marita.reichert.hackett@woohoo.com	Berkeley	California	210072052082126909	68814f8a84d75fd46c8a253f0097bc63	Discover	37.8740660396638447	-122.228676563707737
38395	2020-07-19 04:55:33	2020-07-19	Portia Dach	portia.dach@geemail.com	Dallas	Texas	4869565346199401	1354b6dfb6b4e0b658d89a41332ef0b8	VISA 16 digit	32.824706292039906	-96.7897708671595893
38396	2020-07-19 05:04:00	2020-07-19	Dr. Jerrold Wolff	dr.jerrold.wolff@warmmail.com	Fort Wayne	Indiana	3448207816972231	3b018827cb39206540282699b21a3651	JCB 15 digit	41.0592766229778547	-85.1953973534736804
38397	2020-07-19 05:06:37	2020-07-19	Lewis Harvey	lewis.harvey@woohoo.com	Lakewood	Colorado	3088010437400847978	6de3d99b1883dcb8bec4e7c39baf4635	Voyager	39.6765507164351661	-105.196832139047231
38398	2020-07-19 05:13:28	2020-07-19	Finn Parisian	finn.parisian@geemail.com	San Francisco	California	6011143242226966097	f57599299973287e11d128d253cfacb5	VISA 16 digit	37.7587559507942885	-122.408511318596425
38399	2020-07-19 05:22:15	2020-07-19	Mr. Erland Kunze I	mr.erland.kunze.i@geemail.com	Chicago	Illinois	3337413135322210654	e407da4e492833dccd964e06aa31c537	JCB 16 digit	41.7559139332104508	-87.6865980933450118
38400	2020-07-19 05:40:23	2020-07-19	Lark Leuschke MD	lark.leuschke.md@geemail.com	Glendale	Arizona	4973001350892619	f53677e3159ac7bbcb27b659148644fa	VISA 13 digit	33.6124680796865363	-112.111948369003457
38401	2020-07-19 05:43:44	2020-07-19	Unknown Schumm-Padberg	unknown.schumm.padberg@warmmail.com	Chicago	Illinois	869939500297888004	bc30796a46bc1853bc074d2e3ae4263b	JCB 16 digit	41.8794387089390341	-87.6608507263038206
38402	2020-07-19 05:45:09	2020-07-19	Ms. Alisa Zieme	ms.alisa.zieme@geemail.com	San Francisco	California	3022572720988142	f0ebf71a2a544da83885cadba51fbf48	American Express	37.7583458985263718	-122.454915876501602
38403	2020-07-19 05:47:03	2020-07-19	Keesha Cole	keesha.cole@warmmail.com	Houston	Texas	869930182529360224	1df344611e94a6ff3cf983f043e77ef9	Voyager	29.7924255057316287	-95.2958382042605479
38404	2020-07-19 05:52:02	2020-07-19	Madalynn Roberts	madalynn.roberts@geemail.com	San Francisco	California	6011697733181481965	4e2425ebb7e10d491a8d6e51ae0a9183	Voyager	37.760851062324214	-122.477217811691972
38405	2020-07-19 05:52:34	2020-07-19	Morgan Jones-Becker	morgan.jones.becker@geemail.com	Plano	Texas	6011845285784660389	f05204933a3da8a22cc690f40f3b28e0	Maestro	33.0354736303530672	-96.6652865524120699
38406	2020-07-19 05:57:37	2020-07-19	Inez Wintheiser-Bartell	inez.wintheiser.bartell@geemail.com	Austin	Texas	4868376352330190	a7039c0381beca39de71240ea8cefea9	VISA 13 digit	30.3505870492789889	-97.7640500690095138
38407	2020-07-19 06:01:40	2020-07-19	Kellie Toy	kellie.toy@geemail.com	Springfield	Illinois	869918171102000725	e7f0648933833cb638dabebaea17bd2c	Voyager	39.703556232868138	-89.6635455080311772
38408	2020-07-19 06:01:44	2020-07-19	Kale Kutch	kale.kutch@geemail.com	Midland	Texas	869960576106799485	f79e2c38fd57cb56e012b18a7f66ddbf	JCB 16 digit	32.088955274615806	-102.039273926218968
38409	2020-07-19 06:05:18	2020-07-19	Robbie Auer	robbie.auer@warmmail.com	New York	New York	210093575283336229	12bf8d776f862fbb7008e68b86e4e01a	JCB 15 digit	40.6548882615510365	-74.0050435099646364
38410	2020-07-19 06:14:21	2020-07-19	Mrs. Bethel D'Amore MD	mrs.bethel.d'amore.md@geemail.com	Milwaukee	Wisconsin	6011141558358548045	daa51abc567d292d0255ec5f4bba1d68	JCB 16 digit	43.0036329830151018	-87.9594903910167574
38411	2020-07-19 06:18:03	2020-07-19	Mr. Kimball Reinger	mr.kimball.reinger@geemail.com	Charlotte	North Carolina	3528258068733932087	7789f2bf1021df9bcf88ddab54377cf2	VISA 16 digit	35.2169539732646157	-80.7779356840010792
38412	2020-07-19 06:34:18	2020-07-19	Harlow Barrows	harlow.barrows@geemail.com	Columbus	Ohio	060475934662232	3e04e3ae651270eceef1fc25f0779c0d	Mastercard	39.9537670684091708	-83.0660591149937488
38413	2020-07-19 06:52:04	2020-07-19	Marlys Christiansen	marlys.christiansen@geemail.com	Greensboro	North Carolina	180049809669239615	14bded716a669077d0a909278317d926	Discover	36.1777271295081846	-79.7708511464744845
38414	2020-07-19 06:56:09	2020-07-19	Sergio Eichmann-Erdman	sergio.eichmann.erdman@geemail.com	San Diego	California	639089864715092	ea7be03c90ed8748a16798b01246edd4	Voyager	32.7796998132552986	-117.145424325522043
38415	2020-07-19 06:59:45	2020-07-19	Dr. Evans Lang DVM	dr.evans.lang.dvm@geemail.com	Indianapolis	Indiana	4842957521917743	9d2a285a2db2d0e832079d31e20540d9	Voyager	39.8673163519714038	-86.1875761589236475
38416	2020-07-19 07:22:23	2020-07-19	Coen Stehr	coen.stehr@geemail.com	San Diego	California	51820813112330828	747b09ef36e43ed4c3f0ece62c964f52	VISA 16 digit	32.8434692420132492	-117.115710207810636
38417	2020-07-19 07:27:31	2020-07-19	Vicky Walker	vicky.walker@geemail.com	San Francisco	California	51628058600258800	a877f663c9fab9651c5bf78da13dc1b4	American Express	37.7902564093735833	-122.440753265583268
38418	2020-07-19 07:31:12	2020-07-19	Toya Schmidt	toya.schmidt@woohoo.com	Los Angeles	California	3158257312261690936	1395d4f3e63bcc1144e49988cc4627ab	JCB 16 digit	33.9531570354342449	-118.421243919524542
38419	2020-07-19 07:44:02	2020-07-19	Ingram Gorczany-Grant	ingram.gorczany.grant@geemail.com	San Francisco	California	869971152512381271	5f770015b9ba8d4d0254a085a45be240	Maestro	37.774943028536228	-122.428574189303873
38420	2020-07-19 07:52:25	2020-07-19	Nora Rodriguez	nora.rodriguez@geemail.com	St. Louis	Missouri	4183217331307123	8696b4745de11efce79e08f6805a701f	Diners Club / Carte Blanche	38.7131740089662344	-90.2519904579505408
38421	2020-07-19 07:54:17	2020-07-19	Dr. Mya Klein	dr.mya.klein@geemail.com	Cape Coral	Florida	639046218143934	cc0f23a29aa6437b3a14647adc586751	Maestro	26.6280185202106843	-81.9152738084156056
38422	2020-07-19 08:06:16	2020-07-19	Ms. Love Leuschke	ms.love.leuschke@geemail.com	St. Louis	Missouri	503811010554217	3fb9dae5e0460ac5478c7aaecf96edae	VISA 16 digit	38.6523696307715028	-90.170660979394242
38423	2020-07-19 08:08:23	2020-07-19	Adelia Abshire	adelia.abshire@geemail.com	Glendale	Arizona	561271575246526	c47ac063c1e1c5357256bdb4edd2f3de	Mastercard	33.4747253514587868	-112.180209707494441
38424	2020-07-19 08:12:17	2020-07-19	Landin Brakus	landin.brakus@woohoo.com	Los Angeles	California	4880015802089873	35937b4c49bb3923ecfd2cdf35989e66	Diners Club / Carte Blanche	34.0677169002924103	-118.487838198988882
38425	2020-07-19 08:15:51	2020-07-19	Ardell Terry	ardell.terry@geemail.com	Boulder	Colorado	6011710291244849218	f77d0f801cfd852a8aeb2e96d1ede5da	JCB 16 digit	39.9545057182181651	-105.318948627743509
38426	2020-07-19 08:17:01	2020-07-19	Arch Jakubowski	arch.jakubowski@geemail.com	Austin	Texas	3017031893627354	d8928d00f3cf77251cfb5d547804d884	VISA 16 digit	30.3881954031657422	-97.8249261536408312
38427	2020-07-19 08:20:44	2020-07-19	Vonetta Nitzsche	vonetta.nitzsche@geemail.com	Newark	New Jersey	3021721959953951	73cb01c1b2dabf6242c3b434f4812fc5	JCB 16 digit	40.7154494007963734	-74.1817993332374925
38428	2020-07-19 08:24:40	2020-07-19	Valarie Towne	valarie.towne@geemail.com	Raleigh	North Carolina	503874139946177	02400dfda392e4da613b9b673fb82882	JCB 16 digit	35.7612133350357411	-78.6375864064723231
38429	2020-07-19 08:39:33	2020-07-19	Donavan Rath	donavan.rath@woohoo.com	Louisville	Kentucky	3112758008286074411	14566be8dce2f5e608294d997cde3fd3	Discover	38.1684395222362127	-85.6881713085412997
38430	2020-07-19 08:41:10	2020-07-19	Mr. Add Moen	mr.add.moen@geemail.com	Gilbert	Arizona	3528566840985394910	8c06eafe3c07993d2bbcee2c94ac8212	Mastercard	33.2540541640363614	-111.753648115428533
38431	2020-07-19 08:53:24	2020-07-19	Mr. Octavius Wolff	mr.octavius.wolff@geemail.com	Chicago	Illinois	4717166082372130	93df15dce364366bd916f7d79800415a	American Express	41.8098475857008296	-87.5849277860980493
38432	2020-07-19 08:58:21	2020-07-19	Else Willms	else.willms@geemail.com	Chicago	Illinois	3037828797037360	344308edcc6e18164ecfcdd97607f5a3	Mastercard	41.8546116903726002	-87.6501662953786536
38433	2020-07-19 09:02:15	2020-07-19	Yee Kemmer	yee.kemmer@warmmail.com	Houston	Texas	55891230960826217	ae06a393d4007af07762046e8893cda8	VISA 13 digit	29.7809037272430963	-95.3892710503671282
38434	2020-07-19 09:08:39	2020-07-19	Burney White	burney.white@geemail.com	El Paso	Texas	676204793925514	5047f88916a4e27e1c89e822d21b58f2	JCB 15 digit	31.8756491864860081	-106.452450685946275
38435	2020-07-19 09:11:19	2020-07-19	Rosanna Luettgen	rosanna.luettgen@geemail.com	Warren	Michigan	180064237726799423	c1a8dc1a23521f4d0150e88f5266db73	Voyager	42.4665520797014224	-82.986791247082877
38436	2020-07-19 09:17:11	2020-07-19	Rosabelle Dooley	rosabelle.dooley@geemail.com	Chicago	Illinois	180055353961640221	47c80a94590d140282984050efe9ee84	JCB 16 digit	41.9005935624077921	-87.6823891790147769
38437	2020-07-19 09:17:45	2020-07-19	Tarsha Jacobi-Homenick	tarsha.jacobi.homenick@geemail.com	Long Beach	California	6011040403001696515	74c6adfabaccde8a43cdae4868111075	JCB 15 digit	33.8441281443748565	-118.207904257408529
38438	2020-07-19 09:18:22	2020-07-19	Jenna Veum	jenna.veum@geemail.com	Charlotte	North Carolina	4643468101261412	1e6adab37333b00f6fa28235893f6126	Voyager	35.2741289519492511	-80.7364117676336406
38439	2020-07-19 09:24:13	2020-07-19	Jasmyn Bradtke	jasmyn.bradtke@geemail.com	New York	New York	675933768331705	23cddd410dd8ddfdd7d84df8e0da6173	Maestro	40.6701001968923919	-73.9102943002607589
38440	2020-07-19 09:39:31	2020-07-19	Lenny Cronin	lenny.cronin@geemail.com	New York	New York	503875654349101	0064400393a9105f9eb06be06d26fafe	JCB 16 digit	40.6853601213302483	-73.9312390949007039
38441	2020-07-19 09:45:33	2020-07-19	Clifton King	clifton.king@geemail.com	Aurora	Colorado	501848865893456	6a9d9bd00005daf325648036459670ce	VISA 16 digit	39.7484279224295207	-104.702948954294257
38442	2020-07-19 10:01:30	2020-07-19	Baylee Prosacco	baylee.prosacco@geemail.com	Temecula	California	210002078121156560	ef2c5ef91be783ba5aa9c9597856851a	VISA 16 digit	33.4361178242735519	-117.098869305402786
38443	2020-07-19 10:05:35	2020-07-19	Dr. Irvin Brown	dr.irvin.brown@warmmail.com	Albuquerque	New Mexico	4909100598166122	45e883e9fc7133ae05047faa858043ee	Mastercard	35.0278622108645763	-106.606212469616537
38444	2020-07-19 10:37:32	2020-07-19	Miriam Schultz-Beatty	miriam.schultz.beatty@woohoo.com	San Francisco	California	4858326269835	c37e84ddd81290f76ceeb749457e3629	Voyager	37.7968640573250738	-122.453873222286504
38445	2020-07-19 10:39:37	2020-07-19	Ms. Leonora Schimmel DDS	ms.leonora.schimmel.dds@geemail.com	Milwaukee	Wisconsin	869942458536599517	20b7c22cdb3988dafaa1dd9c315b3643	VISA 16 digit	43.0610420137263787	-87.9621719848930894
38446	2020-07-19 10:40:56	2020-07-19	Mekhi Lubowitz	mekhi.lubowitz@geemail.com	San Francisco	California	4476917460188030	4d3c567c61ed1a858b5dccf75c0c7c12	JCB 16 digit	37.7625079783141899	-122.426164860800114
38447	2020-07-19 10:46:55	2020-07-19	Nora Hayes	nora.hayes@geemail.com	New York	New York	869905027660982776	f6d8c3e2324d8b3abbf61d17892f5123	JCB 15 digit	40.6551435235645613	-73.8448491865199088
38448	2020-07-19 11:02:36	2020-07-19	Ms. Syble Stoltenberg MD	ms.syble.stoltenberg.md@warmmail.com	Cape Coral	Florida	4757511460344725	1c54960b5f1197bbb5b4254afeceac60	Discover	26.6685901229240017	-81.900085276791458
38449	2020-07-19 11:15:04	2020-07-19	Gene Von	gene.von@geemail.com	New Orleans	Louisiana	630460122295474	4f5f6183516110acfc9143ea21a9e3c2	VISA 16 digit	30.1224293518360717	-89.8758568466901835
38450	2020-07-19 11:15:44	2020-07-19	Giovani Keeling	giovani.keeling@geemail.com	San Francisco	California	6011987202169309092	4ce743624c589903dc2213c2874f25e0	Discover	37.7683577828288719	-122.432364606394998
38451	2020-07-19 11:18:37	2020-07-19	Miss Tangela Wisozk MD	miss.tangela.wisozk.md@geemail.com	Wichita	Kansas	180026618752939990	aaadab0d337e1ec03b49835416661aa4	VISA 16 digit	37.7608434406451892	-97.32979069088735
38452	2020-07-19 11:20:05	2020-07-19	Sanai Kautzer DVM	sanai.kautzer.dvm@warmmail.com	Abilene	Texas	561208864972164	78d2da5c687f50f222fa3b3087bd360c	Diners Club / Carte Blanche	32.4688242749851241	-99.7526504177082387
38453	2020-07-19 11:22:35	2020-07-19	Bonita O'Conner	bonita.o'conner@geemail.com	Los Angeles	California	4531487260188	798adfb25c3d03bf54fd751afe43b09f	JCB 16 digit	34.0289975494943562	-118.341176550415526
38454	2020-07-19 11:22:57	2020-07-19	Lorean Jacobi-Paucek	lorean.jacobi.paucek@geemail.com	Concord	California	3030183999439452	cd7aec4285517d37e42a86983358097c	JCB 16 digit	38.0151556902963677	-121.960266097978121
38455	2020-07-19 11:24:12	2020-07-19	Tawana O'Hara	tawana.o'hara@geemail.com	New York	New York	4678090569063631	160c4c9b055235dc7b1a98ee45530695	JCB 15 digit	40.5793217049669437	-73.9624090012989939
38456	2020-07-19 11:32:44	2020-07-19	Lute Gleichner	lute.gleichner@geemail.com	Berkeley	California	3528312533718319562	c37fa5148f44c4c41df459e0ff41a991	Discover	37.8589491223859227	-122.266647711525138
38457	2020-07-19 11:35:37	2020-07-19	Mahala Schuppe-Herman	mahala.schuppe.herman@geemail.com	Baltimore	Maryland	4572254674347100	abf6d667f7389e3f2de5d3c7642d3316	Mastercard	39.2333982353098634	-76.651476387914272
38458	2020-07-19 11:36:02	2020-07-19	Add Kertzmann	add.kertzmann@geemail.com	Las Vegas	Nevada	3427807144445092	235cd010dfc21a60dd0614e1bcc55fbb	Maestro	36.2427370725300122	-115.339276463419566
38459	2020-07-19 11:44:41	2020-07-19	Erie McGlynn	erie.mcglynn@warmmail.com	Worcester	Massachusetts	3528428250347632791	439beacdc7ccca3f582a47ab9b42deda	American Express	42.3605461075603955	-71.7415033788673639
38460	2020-07-19 11:46:06	2020-07-19	Mr. Ransom Beier DDS	mr.ransom.beier.dds@warmmail.com	Lubbock	Texas	3012826200882518	899f859d65ce1a0dbd1432b3ed83da50	Discover	33.543770476201928	-101.859601031281798
38461	2020-07-19 11:50:01	2020-07-19	Alford Boehm	alford.boehm@geemail.com	San Francisco	California	180042662901194578	71eefe77431c90c5833a13ce2cc096b7	VISA 13 digit	37.7715499113181394	-122.435534404123487
38462	2020-07-19 11:59:00	2020-07-19	Landen Breitenberg	landen.breitenberg@woohoo.com	Winston–Salem	North Carolina	4744092942805043	ef09e91bc345216e26ad1f80c3e8a68d	Mastercard	36.1666112380798879	-80.2343471223153131
38463	2020-07-19 12:09:31	2020-07-19	Mildred Yost	mildred.yost@geemail.com	Seattle	Washington	3009953686414443	01ecf5011061f000adcc1e84ede21795	JCB 16 digit	47.5327967810835688	-122.340002657372125
38464	2020-07-19 12:09:54	2020-07-19	Trinidad Reichert	trinidad.reichert@geemail.com	Baltimore	Maryland	869989387360994805	68b9c7a20a426d6d53c1203d681939c1	Voyager	39.3248140183277428	-76.5267350611761259
38465	2020-07-19 12:17:11	2020-07-19	Eusebio Donnelly	eusebio.donnelly@geemail.com	New Orleans	Louisiana	3034884670011009	ea4f6f45b7aefbf2bd108e8ea76b0b12	Mastercard	30.1340700372602797	-89.9672316413167863
38466	2020-07-19 12:22:18	2020-07-19	Miss Rachelle Gusikowski DDS	miss.rachelle.gusikowski.dds@geemail.com	Long Beach	California	869956601990017632	bc8bbb1bcb39cb77390511158bd264f2	JCB 16 digit	33.8081258267451048	-118.250877448233965
38467	2020-07-19 12:23:22	2020-07-19	Errol Luettgen IV	errol.luettgen.iv@geemail.com	Wichita	Kansas	4773984697652907	c68133f1285e4950dbd6e85e6d1ca228	Maestro	37.6444641884293389	-97.3764444900877777
38468	2020-07-19 12:38:48	2020-07-19	Levie Wintheiser	levie.wintheiser@geemail.com	San Francisco	California	869968395175532970	795b1b4cbe153fc0cb42f373b527cfe7	Discover	37.7361118794217631	-122.437222008369687
38469	2020-07-19 13:13:18	2020-07-19	Leandra Howell DDS	leandra.howell.dds@geemail.com	Oakland	California	869919217181372870	5ca9b67bac2d9906baf5e1964e75a7d2	JCB 16 digit	37.8135583997478264	-122.264369042815375
38470	2020-07-19 13:15:19	2020-07-19	Imelda Green	imelda.green@geemail.com	Kansas City	Kansas	502057230812620	69afe3d9e3bb59efbf88f8150168f3b4	Voyager	39.1527212872076831	-94.6948533339828202
38471	2020-07-19 13:16:50	2020-07-19	Bjorn Bosco III	bjorn.bosco.iii@geemail.com	Colorado Springs	Colorado	210025831132235275	100d6d21c4ce7b7151a55c8da8957961	JCB 15 digit	38.907615720811485	-104.788021132598445
38472	2020-07-19 13:25:22	2020-07-19	Miss Rebekah Gutkowski	miss.rebekah.gutkowski@geemail.com	Los Angeles	California	3007028964150076	0654424c6f919bdd1891371d5c7b4894	JCB 16 digit	34.0237915752787146	-118.477330631203202
38473	2020-07-19 13:33:17	2020-07-19	Kaia Kutch	kaia.kutch@woohoo.com	San Francisco	California	4731826160626390	62b1f699acb1e3974930bdd5cf35c343	VISA 13 digit	37.8020775641013529	-122.410691485495704
38474	2020-07-19 13:43:25	2020-07-19	Tamara Walsh	tamara.walsh@geemail.com	Long Beach	California	3729541541341418	d0b8b002f2cbad468a424e1fb1d01422	Diners Club / Carte Blanche	33.8147388818029313	-118.172491305896258
38475	2020-07-19 13:54:01	2020-07-19	Katlyn Swaniawski	katlyn.swaniawski@geemail.com	Vancouver	Washington	3112540329619534316	5132a8708426c314299dc75df7af7f7d	JCB 16 digit	45.6473387856572899	-122.6681424640648
38476	2020-07-19 14:04:13	2020-07-19	Suzanne Bogisich	suzanne.bogisich@geemail.com	Salem	Oregon	3096912397820207493	b1bef7d474b25bfa4a3959ba9c6d95f6	Discover	44.9589688476443285	-122.937514194442713
38477	2020-07-19 14:13:23	2020-07-19	Alston Shanahan	alston.shanahan@geemail.com	Kansas City	Missouri	3337289533152685170	da1099a5fcabdc5a8ffa876fc0d68f3c	JCB 16 digit	39.1774728128522653	-94.5936683405879961
38478	2020-07-19 14:13:38	2020-07-19	Jadyn Paucek	jadyn.paucek@geemail.com	Los Angeles	California	6011006637843950406	bac2c7ea8c991bafcf46d805ad1921b8	VISA 16 digit	34.0785256066225415	-118.410237204236154
38479	2020-07-19 14:15:20	2020-07-19	Alfred Gleichner	alfred.gleichner@geemail.com	San Diego	California	676296405496751	fb9098573a67e71d7ae5891f2089b586	VISA 16 digit	32.7602388211593052	-117.097674256227918
38480	2020-07-19 14:24:50	2020-07-19	Hyman Hyatt	hyman.hyatt@geemail.com	Nashville	Tennessee	55318495921658752	94d29bc56606f2c60727197969f36d29	American Express	36.191466152400892	-86.820439443169164
38481	2020-07-19 14:30:52	2020-07-19	Larissa Considine	larissa.considine@geemail.com	Denver	Colorado	51945849902749124	f98cadfb55c8690ef4e3914902cf239c	JCB 16 digit	39.7486820531129794	-104.955997730257366
38482	2020-07-19 14:36:46	2020-07-19	Marlana Bode	marlana.bode@geemail.com	San Francisco	California	676289930238665	da93c6a1af629ffac12d6e421569c75f	Maestro	37.7774581407169947	-122.454303761111746
38483	2020-07-19 14:40:01	2020-07-19	April Ward	april.ward@woohoo.com	Salem	Oregon	3337557516303408498	153e8e482e54a4d8798476fc50c7e6b2	Maestro	44.9158884564682808	-122.983632314034551
38484	2020-07-19 14:59:06	2020-07-19	Ms. Erlinda Gusikowski MD	ms.erlinda.gusikowski.md@geemail.com	Oakland	California	869929050014746137	d43b85fe78899a5a5ffaf33315278e28	American Express	37.8255414261444827	-122.256035127778262
38485	2020-07-19 15:00:20	2020-07-19	Manda Beahan	manda.beahan@geemail.com	Las Vegas	Nevada	6011998062562337273	2eddea9d8fd65d409138f972aa9399ef	VISA 13 digit	36.2708068217251451	-115.279732542971516
38486	2020-07-19 15:07:17	2020-07-19	Karis Bergstrom	karis.bergstrom@woohoo.com	Lansing	Michigan	51782988170557987	a18c2c6a83330f8ac272e4dde34d457e	JCB 15 digit	42.7417384327232881	-84.4616172756191332
38487	2020-07-19 15:32:39	2020-07-19	Orren Moore V	orren.moore.v@geemail.com	Denver	Colorado	3112798866709072888	0237dbe3ff059cefc737fb739fe62e20	Discover	39.6763952390342922	-104.83346199502833
38488	2020-07-19 15:35:46	2020-07-19	Dr. Rylan Durgan DDS	dr.rylan.durgan.dds@woohoo.com	Lexington	Kentucky	3056028255201225	f2714419f2e3131177845fe3dd62cd2a	Mastercard	37.9470739468343581	-84.3952430772960156
38489	2020-07-19 15:41:37	2020-07-19	Saint Torphy III	saint.torphy.iii@woohoo.com	Oklahoma City	Oklahoma	210089584246445768	1fd211b56a86c999cc18a898c9d589a2	Diners Club / Carte Blanche	35.5670055990017957	-97.4273215836741002
38490	2020-07-19 15:46:18	2020-07-19	Juan Gleichner DVM	juan.gleichner.dvm@geemail.com	St. Petersburg	Florida	869948475292165394	16c54cb24fc88a6db832f03067a4720c	VISA 16 digit	27.758781232114881	-82.6329018483295954
38491	2020-07-19 15:50:54	2020-07-19	Vonda Nikolaus DDS	vonda.nikolaus.dds@warmmail.com	Lubbock	Texas	210099399472075132	c6381b7729d2741439973384c996dc1f	Discover	33.6282324599608842	-101.896752445530893
38492	2020-07-19 16:00:49	2020-07-19	Ford Hammes	ford.hammes@geemail.com	Olathe	Kansas	3528473713083500823	eaf159c5c5b25529d1fa92a047680721	Voyager	38.855777709803732	-94.7450841328296889
38493	2020-07-19 16:01:37	2020-07-19	Declan Kassulke	declan.kassulke@geemail.com	Raleigh	North Carolina	501873843873222	d46e38fef1af7b69fe965732c9868291	Discover	35.8779704661708294	-78.6618470136944268
38494	2020-07-19 16:02:49	2020-07-19	Rueben Breitenberg-Balistreri	rueben.breitenberg.balistreri@geemail.com	San Francisco	California	4357235957684807	315d3636ea7e35ea8d1e42222be49fae	VISA 16 digit	37.7579565431345046	-122.42825302712744
38495	2020-07-19 16:03:07	2020-07-19	Dr. Macie Lynch	dr.macie.lynch@geemail.com	Fort Worth	Texas	3158468545290289296	b7d82b41e85b65b8b0d0807618f50bc6	Voyager	32.7161341439057125	-97.3134874374426886
38496	2020-07-19 16:04:54	2020-07-19	Jayne Eichmann	jayne.eichmann@woohoo.com	Evansville	Indiana	51162467363253704	68f963ddd86979b8ba5cfac3951ee256	Maestro	38.0555954734466937	-87.4386594534318959
38497	2020-07-19 16:11:52	2020-07-19	Corrie Lebsack-Abshire	corrie.lebsack.abshire@geemail.com	Oxnard	California	3047034177728062	a59c7a53316c8d795f535c923e46a273	JCB 15 digit	34.1593877042599061	-119.120937892133739
38498	2020-07-19 16:12:20	2020-07-19	Ida Heaney V	ida.heaney.v@warmmail.com	San Francisco	California	52931089829082848	1893feec5bdb7efdf817b7eb4b4c0cda	JCB 16 digit	37.7558137013283357	-122.440794341419959
38499	2020-07-19 16:18:39	2020-07-19	Corina Grant PhD	corina.grant.phd@geemail.com	New York	New York	6011467763044290780	4e8839b296d109e2fd03f584dab038e5	VISA 13 digit	40.6277559501808128	-73.9633087461244259
38500	2020-07-19 16:25:01	2020-07-19	Dr. Barbra Hilpert DDS	dr.barbra.hilpert.dds@geemail.com	Colorado Springs	Colorado	869968845793754455	eaec1726d4f542158ea763a69665d6a2	VISA 13 digit	38.9402882079176607	-104.840999075879154
38501	2020-07-19 16:37:35	2020-07-19	Maryellen Heathcote	maryellen.heathcote@geemail.com	Colorado Springs	Colorado	3703701650704588	7b78872b599fa7648b217fcaa216b3a8	JCB 16 digit	38.9559547710746514	-104.76433980061374
38502	2020-07-19 16:43:27	2020-07-19	Elwood Friesen	elwood.friesen@geemail.com	Tampa	Florida	3096530494651256525	77380a2b5d9d20c8cc1ed29e7f4604b3	JCB 15 digit	27.939479188679158	-82.3981060912113605
38503	2020-07-19 16:51:09	2020-07-19	Mrs. Londyn Brakus	mrs.londyn.brakus@geemail.com	Los Angeles	California	6011234606788503383	583a1f9ae669fa72dd9f46210bd09c75	JCB 15 digit	34.0391170889936348	-118.502202234183613
38504	2020-07-19 17:03:40	2020-07-19	Tiffanie Gleason	tiffanie.gleason@warmmail.com	St. Petersburg	Florida	3774256857399660	138c29b67a8c69a40d2dd71d4a50eec0	JCB 16 digit	27.8117204884421092	-82.5809498091120275
38505	2020-07-19 17:16:38	2020-07-19	Miss Ashlynn Klocko MD	miss.ashlynn.klocko.md@geemail.com	Albuquerque	New Mexico	53273908333852550	fdfa3639565043679ca20dbfcc052021	Maestro	35.0953337323520387	-106.622047949123754
38506	2020-07-19 17:20:36	2020-07-19	Juwan Corwin-Strosin	juwan.corwin.strosin@woohoo.com	Fort Collins	Colorado	3042252709416585	733ecc1865198172caf7938c778ba4eb	JCB 16 digit	40.4955380056675551	-105.043038367335882
38507	2020-07-19 17:25:33	2020-07-19	Alida Fahey	alida.fahey@woohoo.com	Oxnard	California	4346720020503336	8e4a1969be4cec67bf7cc439caf9f87c	JCB 16 digit	34.2241147984240186	-119.230143851591649
38508	2020-07-19 17:31:28	2020-07-19	Gerard Pfannerstill	gerard.pfannerstill@geemail.com	Palm Bay	Florida	3158756351046704394	a1eca2fdb591762b43e503171413cb91	Discover	27.8871706669073554	-80.7282284929253109
38509	2020-07-19 17:34:05	2020-07-19	Judy Yundt	judy.yundt@warmmail.com	Philadelphia	Pennsylvania	869917308301213557	1dd36ecf1924d99f7ebd0c35787bf640	Diners Club / Carte Blanche	39.9986778240609908	-75.157973243099832
38510	2020-07-19 17:37:36	2020-07-19	Dr. Kendell Gislason II	dr.kendell.gislason.ii@warmmail.com	San Francisco	California	3096191405851558510	81704404c198de1f240f595093c6629a	Diners Club / Carte Blanche	37.7264203376949467	-122.434548000581245
38511	2020-07-19 17:43:42	2020-07-19	Dr. Gay O'Reilly IV	dr.gay.o'reilly.iv@geemail.com	Houston	Texas	3023890870646909	ede98105bddf20aa2cd2321030c89d7e	JCB 16 digit	29.8140552000686512	-95.3107463940527282
38512	2020-07-19 17:48:58	2020-07-19	Braulio Labadie	braulio.labadie@geemail.com	Seattle	Washington	4856380923734272	742ecd83186d24de710ef308fca5cfc4	American Express	47.6101086539607508	-122.317351524337752
38513	2020-07-19 17:52:23	2020-07-19	Kayleigh Beahan-Bogisich	kayleigh.beahan.bogisich@geemail.com	Modesto	California	869960432610110373	8273806e86d4923f2418b6b3c235bc81	JCB 16 digit	37.7033386555500343	-120.919974848322568
38514	2020-07-19 18:08:26	2020-07-19	Melba Torp	melba.torp@geemail.com	San Diego	California	3477976766177140	473379eb62517244e8f39985779fd0ab	Discover	32.7802539260659387	-117.070565894236793
38515	2020-07-19 18:11:29	2020-07-19	Hasan Kuhic-Batz	hasan.kuhic.batz@geemail.com	Fayetteville	North Carolina	676315028816922	8f0f3ab232ddc79d0fa018e477a4bf7e	VISA 16 digit	34.9999489887405204	-78.8749987676870035
38516	2020-07-19 18:24:56	2020-07-19	Dr. Bedford Pagac	dr.bedford.pagac@woohoo.com	Waco	Texas	3112317917654640963	b94e6779ea9394b842dc2dd41ed5840b	JCB 16 digit	31.4641392376482472	-97.1734842214863761
38517	2020-07-19 18:28:32	2020-07-19	Ms. Gabriela Feil	ms.gabriela.feil@warmmail.com	Charlotte	North Carolina	589395201728706	f1facac99051dbef2fe8ad73c2d27cf6	VISA 16 digit	35.2599937564946728	-80.7974169841446042
38518	2020-07-19 18:31:12	2020-07-19	Cheryl Lubowitz	cheryl.lubowitz@geemail.com	Philadelphia	Pennsylvania	210015178327019094	77168ad45d2eab2d1ade8d0e3725704e	JCB 16 digit	40.1064769495703288	-75.1549072004754208
38519	2020-07-19 18:33:50	2020-07-19	Ronaldo Hoppe-Botsford	ronaldo.hoppe.botsford@geemail.com	Los Angeles	California	3782867341146028	41b0c923993a8de5680037adf001784f	American Express	33.9698792762454573	-118.499548099096117
38520	2020-07-19 18:40:05	2020-07-19	Toby White	toby.white@geemail.com	Memphis	Tennessee	4772942906906994	1cb4728a5162d5d716be53f200d8b32a	VISA 13 digit	35.0936122962806394	-90.0290989795025496
38521	2020-07-19 18:43:26	2020-07-19	Delina Paucek	delina.paucek@geemail.com	New York	New York	6011105276709773386	ea464dc9619b774cf75731f772c9724d	Diners Club / Carte Blanche	40.7125389328449927	-74.011807930412516
38522	2020-07-19 18:55:49	2020-07-19	Dallin Fahey	dallin.fahey@geemail.com	Pittsburgh	Pennsylvania	3528579566832748371	cf089fd15f29e19759bbea6a1387232f	JCB 15 digit	40.3783643885936598	-80.0321851865559921
38523	2020-07-19 19:09:55	2020-07-19	Marget Hudson	marget.hudson@geemail.com	Frisco	Texas	3019746416402039	e61dd61100563271933085dfdd222f38	VISA 16 digit	33.0694977629460425	-96.7279326123859704
38524	2020-07-19 19:13:23	2020-07-19	Latanya Runolfsson	latanya.runolfsson@geemail.com	San Francisco	California	4640105067460769	de0a73a0f2e820f1e6aeac2831fd0a7d	VISA 16 digit	37.7977189784619938	-122.414033877315944
38525	2020-07-19 19:19:20	2020-07-19	Odin Schimmel-Fay	odin.schimmel.fay@geemail.com	San Antonio	Texas	869977442813630003	783e263b00de7f9b5358472e4a86aece	VISA 16 digit	29.5573679363425832	-98.4783258529681689
38526	2020-07-19 19:22:19	2020-07-19	Clell Boehm	clell.boehm@warmmail.com	Seattle	Washington	3403788631092183	f0c86a0b97ca07f89bca8ae28b525804	JCB 16 digit	47.6131826038397818	-122.408875603174408
38527	2020-07-19 19:23:24	2020-07-19	Dr. Hallie Reichert	dr.hallie.reichert@warmmail.com	Waco	Texas	3057297335106469	32357831c3deb02b8e583ae9ffedc666	VISA 13 digit	31.6229392672631882	-97.2125867755748345
38528	2020-07-19 19:25:16	2020-07-19	Hollis Schuppe	hollis.schuppe@woohoo.com	San Francisco	California	53141419261927711	0ef8b4ce88b74c1e46df4559997c1fc2	VISA 13 digit	37.7661615754778452	-122.429423849404699
38529	2020-07-19 19:48:51	2020-07-19	Neil Hand	neil.hand@geemail.com	Chicago	Illinois	060405988685672	d814c0e440b6e88f390a14ad5eceeebb	VISA 13 digit	41.8218715424485552	-87.7796627508506191
38652	2020-07-20 12:19:08	2020-07-20	Kaye Champlin	kaye.champlin@geemail.com	Jacksonville	Florida	210088210322586207	67dd775a705fe28303f168e556206ea6	VISA 16 digit	30.2941444486897424	-81.6872381562911016
38530	2020-07-19 19:50:39	2020-07-19	Augustina Altenwerth	augustina.altenwerth@geemail.com	Fort Lauderdale	Florida	676129749213053	15dc8f403df7b807393313cfaae65b71	VISA 16 digit	26.2036424834735691	-80.1154796419020698
38531	2020-07-19 20:19:14	2020-07-19	Doretta Hodkiewicz	doretta.hodkiewicz@warmmail.com	Huntington Beach	California	869982253504089133	eb06e3b291d8cd0afc8b4daa7d121a6b	American Express	33.6967568804085289	-117.950871836266657
38532	2020-07-19 20:23:59	2020-07-19	Jessenia Wuckert-Fahey	jessenia.wuckert.fahey@geemail.com	San Jose	California	3777867036326411	be1a6eebffb95e9f8b997afee047f996	VISA 13 digit	37.2880683731108888	-121.836186900291224
38533	2020-07-19 20:33:57	2020-07-19	Sol VonRueden	sol.vonrueden@geemail.com	Portland	Oregon	561263139016248	e9c785746f7d2be9343419aa084a592b	JCB 16 digit	45.4912110299691577	-122.650646010320642
38534	2020-07-19 20:48:59	2020-07-19	Hung Ankunding	hung.ankunding@geemail.com	Murfreesboro	Tennessee	3036217074620208	a29ff6747829e2e83899301843e3d105	Voyager	35.8686825876709108	-86.3647885279115286
38535	2020-07-19 20:56:25	2020-07-19	Ernest Dach	ernest.dach@geemail.com	Phoenix	Arizona	4403813471705474	4291c6db22ce2639f846ef49b925768c	Diners Club / Carte Blanche	33.5635020414765961	-111.995084474880628
38536	2020-07-19 20:59:05	2020-07-19	Marchello Blanda PhD	marchello.blanda.phd@woohoo.com	Oakland	California	4950089309294216	93a4d193784a6de534b36698953ce814	Discover	37.8113960454062976	-122.252384427762124
38537	2020-07-19 21:08:01	2020-07-19	Aden Koch	aden.koch@geemail.com	Glendale	California	4072313162918	fa8b5ee55668fed523ad0ed31dd1e9d7	VISA 16 digit	34.2023669678471975	-118.169748442796248
38538	2020-07-19 21:08:42	2020-07-19	Odell Emmerich-Kunde	odell.emmerich.kunde@geemail.com	Overland Park	Kansas	4394541668825	7ec874fa171b918155559cb519938855	Voyager	38.9775196817573217	-94.6955638800323101
38539	2020-07-19 21:10:26	2020-07-19	Sanai Adams-Huel	sanai.adams.huel@woohoo.com	Thornton	Colorado	4402533726707	c79f6ec038ddef8d0ef3537a9018303c	American Express	39.9144051696971118	-105.017027790581068
38540	2020-07-19 21:16:44	2020-07-19	Alisson Feeney	alisson.feeney@woohoo.com	Fayetteville	North Carolina	3055951807947287	d47bb7cd0d983844fbfa4fc210519eb0	VISA 13 digit	35.0651919882066565	-78.9174949327614144
38541	2020-07-19 21:26:30	2020-07-19	Dulce Farrell	dulce.farrell@geemail.com	Los Angeles	California	675980827532146	ac19109d2d918454e814968d4b869c5e	JCB 16 digit	34.090741552957887	-118.334041409333423
38542	2020-07-19 21:27:18	2020-07-19	Marrion Kertzmann	marrion.kertzmann@geemail.com	Abilene	Texas	503884663287310	4e66f1096e17553732e0a00a459e3f88	JCB 16 digit	32.413771753905344	-99.7881002936925796
38543	2020-07-19 21:32:51	2020-07-19	Jerold Runte	jerold.runte@geemail.com	San Angelo	Texas	53661707290892132	1ca153890a168c0bd3c23799ff47ef08	JCB 16 digit	31.512825449571384	-100.51299331682921
38544	2020-07-19 21:39:07	2020-07-19	Elbert Leannon	elbert.leannon@geemail.com	Sugar Land	Texas	3738585075936886	63513fb59d99d84a952aaeb6958590ec	Mastercard	29.6356997314892716	-95.603761033109194
38545	2020-07-19 21:41:15	2020-07-19	Benedict Wisoky-Kovacek	benedict.wisoky.kovacek@geemail.com	Cleveland	Ohio	54249776231760550	b46704afe9f71db3daef345741652ca2	VISA 13 digit	41.4665625789985057	-81.6284889871958654
38546	2020-07-19 21:49:13	2020-07-19	Olena Cartwright DDS	olena.cartwright.dds@warmmail.com	San Jose	California	3088071754159942198	4fc253a81286095f6026f29fb01f8739	Voyager	37.3523072925683124	-121.869835918465256
38547	2020-07-19 21:58:51	2020-07-19	Ciara Kessler	ciara.kessler@warmmail.com	New York	New York	55947325801175297	ee16d7c98f51f349933ae87185db7497	Maestro	40.719891219515354	-73.8513794186420682
38548	2020-07-19 22:00:02	2020-07-19	Amari Gislason	amari.gislason@warmmail.com	Newark	New Jersey	3757659934926069	88d2fafbcdb55dedd7add991804d983a	VISA 16 digit	40.6525536252565729	-74.1272461431309608
38549	2020-07-19 22:00:17	2020-07-19	Ms. Else Hackett	ms.else.hackett@geemail.com	Pembroke Pines	Florida	6011626803509975299	06d8ef919e64e6abeda163d60a300983	Maestro	26.0716835320033127	-80.4090840276699481
38550	2020-07-19 22:07:36	2020-07-19	Noe Klein	noe.klein@geemail.com	Norman	Oklahoma	54798650617757941	22b314c94285d9aa679ddd6630cbb304	Maestro	35.3037590295117383	-97.4328068683177122
38551	2020-07-19 22:11:31	2020-07-19	Daja Hoeger	daja.hoeger@geemail.com	Mobile	Alabama	53476592195180311	dfa28693417bc8f219b9cb9f727b3194	JCB 15 digit	30.6282925802391013	-88.055689614745603
38552	2020-07-19 22:12:00	2020-07-19	Deyanira Bode	deyanira.bode@geemail.com	Houston	Texas	502048628063934	713a5b73cb23e70033f31b2098708160	Maestro	29.8098876216061406	-95.3561713390532901
38553	2020-07-19 22:14:21	2020-07-19	Bill Cruickshank	bill.cruickshank@geemail.com	Warren	Michigan	4403562105870	39948134dc27eaab4af2a0f2cf5bcddd	Voyager	42.4547737564887839	-83.1100155509542731
38554	2020-07-19 22:23:22	2020-07-19	Jordan Batz	jordan.batz@warmmail.com	Oakland	California	3337758558008673973	bb8da658d65f1b7222e4609d13898a5f	Mastercard	37.7999432197667247	-122.271447614208967
38555	2020-07-19 22:28:12	2020-07-19	Kendell Corkery	kendell.corkery@woohoo.com	San Francisco	California	51407605386165372	063425b93578162962349897c71beeb9	VISA 13 digit	37.7562693883824991	-122.440552259588941
38556	2020-07-19 22:32:28	2020-07-19	Treyton Roberts	treyton.roberts@geemail.com	Oakland	California	3096783684470246434	bf824045a91313e193b8f5e9617cfd8a	Mastercard	37.8069529894767058	-122.257124438836968
38557	2020-07-19 22:54:54	2020-07-19	Kurt Brown DVM	kurt.brown.dvm@warmmail.com	Charlotte	North Carolina	589388833286573	1a35c1c0cd5e2327fd1829103d546996	Maestro	35.2904766691636311	-80.9193379154838652
38558	2020-07-19 22:59:20	2020-07-19	Moses Ward	moses.ward@woohoo.com	Chandler	Arizona	3050923198401385	1cb4ea80bf3827c8f640efb076f26489	VISA 13 digit	33.3363978489857118	-111.821594541787732
38559	2020-07-19 22:59:52	2020-07-19	Ivie Hayes-Zemlak	ivie.hayes.zemlak@warmmail.com	Jacksonville	Florida	55950945599719701	f60b4fe55056ef5bb91b4b5080a540de	VISA 16 digit	30.3909639657061561	-81.6039994265031083
38560	2020-07-19 23:16:25	2020-07-19	Ada Denesik	ada.denesik@geemail.com	San Francisco	California	54686100620750801	7999f0c5d674e2e3e033e7e19fff91f2	Maestro	37.7671554195283861	-122.457249706050376
38561	2020-07-19 23:22:36	2020-07-19	Dr. Son Yundt DDS	dr.son.yundt.dds@geemail.com	Sugar Land	Texas	6011123649639383708	06e84712a34cbe90a291e843ff62a6f9	JCB 16 digit	29.5758817549381412	-95.6923091205775762
38562	2020-07-19 23:26:09	2020-07-19	Cephus Ryan	cephus.ryan@warmmail.com	Winston–Salem	North Carolina	676201000429454	6fcc8e6fcc831e6a0b27d64ed5dacb75	Voyager	36.1859413228694322	-80.2903024246115251
38563	2020-07-19 23:44:35	2020-07-19	Dewayne Osinski	dewayne.osinski@geemail.com	Los Angeles	California	503881938340940	4019ba7b34ec15e09244c030ab48a617	Voyager	34.0768176846537685	-118.335578774194417
38564	2020-07-19 23:50:43	2020-07-19	Marco Hamill	marco.hamill@warmmail.com	San Francisco	California	6011602501301693932	9b3c76107a660ce6564be10d2e6370cf	VISA 16 digit	37.7529360923365189	-122.438504579179607
38565	2020-07-19 23:53:14	2020-07-19	Domingo Gibson	domingo.gibson@geemail.com	San Francisco	California	6011938255012903198	ad37cc7de7b826571d211f16f3ace404	VISA 16 digit	37.7341841478408497	-122.419762352902922
38566	2020-07-19 23:56:51	2020-07-19	Mr. Dion Schuster	mr.dion.schuster@geemail.com	Anaheim	California	3112557374906025883	ec86a0d042eff87fe0e5229232a5e9b3	VISA 16 digit	33.7899584728125504	-117.825206543945143
38567	2020-07-20 00:08:04	2020-07-20	Olinda Zieme PhD	olinda.zieme.phd@warmmail.com	New York	New York	54734717302561982	abcf4307b126d12d29510ff7725e2da9	VISA 16 digit	40.5857906088922178	-73.9815569308482139
38568	2020-07-20 00:21:38	2020-07-20	Miss Natalia Doyle	miss.natalia.doyle@warmmail.com	Dallas	Texas	3049853689711714	b1c01dc0c13f3e509a8dae9cdc16b8de	Diners Club / Carte Blanche	32.773942659775912	-96.6909781394489016
38569	2020-07-20 00:25:06	2020-07-20	Osborne Kshlerin-Ankunding	osborne.kshlerin.ankunding@geemail.com	Berkeley	California	180018808199385572	f5901323768d24ed4cf1dac37d053d89	Mastercard	37.8756764084688839	-122.288185452995975
38570	2020-07-20 00:27:39	2020-07-20	Rodney Mills	rodney.mills@woohoo.com	San Francisco	California	3708001915394852	c2f963627bee43041dd5595d3c217c8e	VISA 16 digit	37.7908417109090919	-122.473878166141375
38571	2020-07-20 00:31:35	2020-07-20	Mirna Bergnaum-Mills	mirna.bergnaum.mills@woohoo.com	Chicago	Illinois	53537225608998824	b4abce605595ef9dce82e9fd89bdba7f	JCB 16 digit	41.9073559408843508	-87.6947966130014436
38572	2020-07-20 00:32:31	2020-07-20	Babe Homenick	babe.homenick@geemail.com	Chicago	Illinois	3112686782483845644	5cbd7ebe9a7135ce80de3b7a931e8a9a	Diners Club / Carte Blanche	41.7477511677727122	-87.6224655360944524
38573	2020-07-20 00:34:49	2020-07-20	Miss Keila Lockman	miss.keila.lockman@geemail.com	Miami	Florida	3528604793845630730	3f337a34ddf2d5fe2cd896fbcb2715bb	Maestro	25.8093535300482095	-80.2024697834033589
38574	2020-07-20 00:44:28	2020-07-20	Ananias Spinka-Reichert	ananias.spinka.reichert@warmmail.com	Los Angeles	California	180040972500078284	af6cf1804e6f124bada38336ec1ce055	American Express	34.06754296462573	-118.495153557555
38575	2020-07-20 00:55:11	2020-07-20	Rodrigo Ratke	rodrigo.ratke@woohoo.com	Moreno Valley	California	52528192032105023	79641606f64d2017be80f482ad8af652	JCB 16 digit	33.9152667295180237	-117.248705017284294
38576	2020-07-20 01:13:28	2020-07-20	Ms. Lorrie Abshire DDS	ms.lorrie.abshire.dds@geemail.com	New York	New York	3044095218488282	aed7fca7dd9b0a50fddf319e21d01847	VISA 16 digit	40.7597326957844217	-73.8571356981888414
38577	2020-07-20 01:33:33	2020-07-20	Lovie Leffler V	lovie.leffler.v@geemail.com	Reno	Nevada	3045998339286932	9888ad0ad8804ad4a39649fd9208c759	Voyager	39.6475401104040444	-119.859994586852949
38578	2020-07-20 01:40:04	2020-07-20	Deforest Roberts-Nienow	deforest.roberts.nienow@geemail.com	Phoenix	Arizona	55492945519481494	0b9e3dcd3eac636e128522c6b86bcb66	Maestro	33.5653902884971345	-111.99239969164357
38579	2020-07-20 01:42:34	2020-07-20	Mr. Jame Nienow	mr.jame.nienow@geemail.com	Las Vegas	Nevada	4489751903704607	b9b8629ad392e7a13dc701ea7f29c69f	JCB 16 digit	36.1784694507352995	-115.176296623770511
38580	2020-07-20 01:54:51	2020-07-20	Rebeca Stiedemann	rebeca.stiedemann@warmmail.com	San Francisco	California	4038369173588	dda38369264977bb1f427332fbb62573	VISA 16 digit	37.7451546645376368	-122.456263142371554
38581	2020-07-20 02:07:11	2020-07-20	Leah Stiedemann-Mueller	leah.stiedemann.mueller@geemail.com	Long Beach	California	3704036413066028	c99c2f94f7073e2df961fc461c6c6342	JCB 16 digit	33.88563197253346	-118.168972443386167
38582	2020-07-20 02:27:29	2020-07-20	Lolita Frami	lolita.frami@warmmail.com	New York	New York	3011247757151572	b90cfb23a0f249ebc8b429f86ab54cb5	VISA 16 digit	40.712081484565509	-73.8639301560714756
38583	2020-07-20 02:50:24	2020-07-20	Shyla Schmeler-Fadel	shyla.schmeler.fadel@warmmail.com	Chicago	Illinois	3462550605334894	7a14bfd0ff3d4d85deb4c0022906812d	Maestro	41.8808285091374088	-87.6775273256033643
38584	2020-07-20 02:52:03	2020-07-20	Viridiana Reichel DVM	viridiana.reichel.dvm@geemail.com	Omaha	Nebraska	869969160597823046	a556f032fdde3393c49d8d903ea9d2dd	JCB 16 digit	41.2019230059493324	-96.0886083315707822
38585	2020-07-20 03:35:57	2020-07-20	Mr. Aldo Gislason	mr.aldo.gislason@warmmail.com	Winston–Salem	North Carolina	869901329950417818	1b7483e6a5a4af1e5600bc89473ca5c2	JCB 16 digit	36.0207022773798542	-80.2294243153314994
38586	2020-07-20 03:40:13	2020-07-20	Emil Hintz	emil.hintz@woohoo.com	San Francisco	California	51407160647628453	93798cc38026dd7cb6d4d991f348473f	Voyager	37.778955356415473	-122.385697807359278
38587	2020-07-20 03:45:34	2020-07-20	Sharla Stanton	sharla.stanton@geemail.com	Westminster	Colorado	4420141055698819	8def24aae0b3600e90ee3957c04a3732	JCB 16 digit	39.830197666243464	-105.145637810477623
38588	2020-07-20 03:52:10	2020-07-20	Vance Lynch	vance.lynch@woohoo.com	Mobile	Alabama	4772340493282343	c97da657c63b94ffc20e173143620ed7	VISA 16 digit	30.6192463034871949	-88.1506716411232958
38589	2020-07-20 03:53:30	2020-07-20	Jaron Waters	jaron.waters@woohoo.com	Chicago	Illinois	869979920891353406	bbde3d5a5e352ad3538ed6d73a0a5d7a	JCB 16 digit	41.817866659799968	-87.7705745777610673
38590	2020-07-20 03:57:31	2020-07-20	Alphonsus Nader	alphonsus.nader@geemail.com	San Diego	California	52788463850011071	07062e6a109be045167a5ce13a19d0b2	JCB 16 digit	32.911161084060744	-117.146203436693185
38591	2020-07-20 04:10:58	2020-07-20	Macel Emmerich	macel.emmerich@geemail.com	Los Angeles	California	6011211032124170273	09e4598943ca157b1825e69a4de53c80	Mastercard	34.0603950308036048	-118.499884462588653
38592	2020-07-20 04:15:27	2020-07-20	Enoch Daugherty	enoch.daugherty@geemail.com	Indianapolis	Indiana	676193933947611	814661c15ded1dedd4c35945c7cfb074	American Express	39.7088183504536758	-86.2382906404059355
38593	2020-07-20 04:26:52	2020-07-20	Zachariah Abbott	zachariah.abbott@geemail.com	Chicago	Illinois	55571479098812378	a1eec7f57a7e25270ceb67e268dc9b7e	VISA 16 digit	41.9146509288180624	-87.7404058256216359
38594	2020-07-20 04:27:10	2020-07-20	Ms. Christiana Hane DDS	ms.christiana.hane.dds@geemail.com	New York	New York	3016117571714613	c24fd6d1fbaf00fff85ea2f44c031ffd	Diners Club / Carte Blanche	40.607031907489521	-73.9248363664735137
38595	2020-07-20 04:34:39	2020-07-20	Mickey Ryan-Kulas	mickey.ryan.kulas@warmmail.com	Louisville	Kentucky	3337442610259901611	9f4c195b5688cfc00ec9301f564c278c	VISA 13 digit	38.1352718250729126	-85.594141507342087
38596	2020-07-20 04:43:38	2020-07-20	Dolly Cronin	dolly.cronin@geemail.com	Atlanta	Georgia	3337874224253886765	a7eeb8b2ea62aa15680902658f0af3af	Mastercard	33.8358890590533647	-84.4214238141242532
38597	2020-07-20 04:53:36	2020-07-20	Freddie Runolfsson-Bradtke	freddie.runolfsson.bradtke@warmmail.com	Chula Vista	California	3088416185059955184	0f76f2d5d08718f7953d5288acb5955b	Diners Club / Carte Blanche	32.5519465078365045	-117.064412964437892
38598	2020-07-20 04:54:54	2020-07-20	Atticus Murray	atticus.murray@geemail.com	Milwaukee	Wisconsin	4355642326829074	c17d86d0a8b8624d72990a2e5e433cab	JCB 16 digit	43.1398708242543023	-87.9893676380261809
38599	2020-07-20 04:55:37	2020-07-20	Corbett Turner	corbett.turner@geemail.com	San Angelo	Texas	4996092925633243	88b9038ab1f435fffe874ffdeb8f09cd	JCB 16 digit	31.47316206844188	-100.526909483933821
38600	2020-07-20 05:04:12	2020-07-20	Jordan Fritsch PhD	jordan.fritsch.phd@geemail.com	New York	New York	3029459971690267	887663901ebce85dbce8259e9a3b9016	VISA 13 digit	40.7017109859492621	-73.9080255449645165
38601	2020-07-20 05:29:43	2020-07-20	Abbey Lowe-Satterfield	abbey.lowe.satterfield@warmmail.com	Berkeley	California	4447949496221	097c6b2b9badfdc752f95542cef78d5f	VISA 16 digit	37.8305523851156451	-122.27138886336769
38602	2020-07-20 05:30:33	2020-07-20	Leisa Hamill	leisa.hamill@geemail.com	Oakland	California	4109755371976498	ca3ddd16b4c8259ea3722ac167e25e94	JCB 15 digit	37.795450435527826	-122.285784809979504
38603	2020-07-20 05:52:53	2020-07-20	Mr. Dessie Leuschke DDS	mr.dessie.leuschke.dds@geemail.com	San Antonio	Texas	869990823352776401	b44984f2c24372d211711a6ed417d719	Diners Club / Carte Blanche	29.3895665836591284	-98.4978954084519245
38604	2020-07-20 05:55:23	2020-07-20	Davon Kshlerin-Ledner	davon.kshlerin.ledner@geemail.com	Greensboro	North Carolina	6011900712501468657	c91457cb4f1bb4a224fa318007d59fa3	JCB 16 digit	36.0614584670983263	-79.835071502577506
38605	2020-07-20 06:10:28	2020-07-20	Ephriam Cole V	ephriam.cole.v@woohoo.com	San Diego	California	4288818196780967	f0652356a72990fd4b6b37cdafcbf7fc	JCB 15 digit	32.7939182055249816	-117.051794917080557
38606	2020-07-20 06:13:36	2020-07-20	Elsworth Jacobi	elsworth.jacobi@geemail.com	Clarksville	Tennessee	53387506774693658	a627e4d35422eb1908298c716f6c32d3	Mastercard	36.4680850624233486	-87.3857567624606304
38607	2020-07-20 06:34:03	2020-07-20	Armond McCullough	armond.mccullough@geemail.com	New York	New York	4156031204484015	b3d3a2740961c09c6439d83273056007	American Express	40.7258925076797595	-73.9877325308870439
38608	2020-07-20 06:36:08	2020-07-20	Mandy Armstrong-Koss	mandy.armstrong.koss@geemail.com	Chandler	Arizona	6011518595724665140	6c2adca8f8e9a78c7f59b54838d3373a	Voyager	33.219194408282263	-111.942037296609584
38609	2020-07-20 06:37:22	2020-07-20	Carole Mertz	carole.mertz@woohoo.com	New York	New York	54592576929665613	80cd9cfed457bc0b7557203eb4a287ef	JCB 15 digit	40.6969440454840665	-73.9523279561556848
38610	2020-07-20 06:43:03	2020-07-20	Isa Nikolaus	isa.nikolaus@woohoo.com	San Antonio	Texas	6011536703319208536	8165aad6e46e196703ab5afee169f00e	VISA 13 digit	29.5679100006889541	-98.4889830716721661
38611	2020-07-20 06:59:43	2020-07-20	Dr. Augustina Aufderhar	dr.augustina.aufderhar@geemail.com	Minneapolis	Minnesota	869975966649125426	8c8f7b147a80a90588e7b0ebd2753908	American Express	44.8916964236266907	-93.351820286204287
38612	2020-07-20 07:13:56	2020-07-20	Erykah Pacocha	erykah.pacocha@geemail.com	Berkeley	California	4452652738201202	9baa7ef5d56e033906abdb874dc42ff0	VISA 13 digit	37.8788514455587162	-122.288183561882803
38613	2020-07-20 07:14:06	2020-07-20	Mr. Buddy Cummerata	mr.buddy.cummerata@woohoo.com	Columbus	Ohio	210050995905770244	02b74c9bb2450dd2db46795ab2976261	American Express	39.9408350534781817	-82.9055383710891078
38614	2020-07-20 07:25:28	2020-07-20	Ricci Dickens	ricci.dickens@warmmail.com	Madison	Wisconsin	3013699307494183	26287a1ff12d8f69c18ffb204521c1a0	JCB 15 digit	43.0437520878363387	-89.4648722832907026
38615	2020-07-20 07:27:13	2020-07-20	Orlando Reynolds	orlando.reynolds@geemail.com	Dallas	Texas	51321119417551553	b48eedadaa3cd9c4cb8ca642019882f0	Discover	32.8901099512625521	-96.7881352241113717
38616	2020-07-20 07:28:04	2020-07-20	Marisol Rowe	marisol.rowe@geemail.com	Huntsville	Alabama	3088532721622520763	6a430dab762793fdeba121f079b8f0d5	VISA 13 digit	34.6319315584152889	-86.6391992615554472
38617	2020-07-20 07:49:21	2020-07-20	Mr. Aryan Waelchi	mr.aryan.waelchi@warmmail.com	Thousand Oaks	California	3027014440983025	1c4884a526af9a3906901e352d592530	JCB 16 digit	34.1046773304503432	-118.817028490119426
38618	2020-07-20 08:36:55	2020-07-20	Dr. Duane Douglas IV	dr.duane.douglas.iv@geemail.com	Washington	District of Columbia	3112944364200288479	f6d1a9490058adb1c3953e8e019b95af	VISA 13 digit	38.9798481049280596	-76.9784138738390027
38619	2020-07-20 08:54:03	2020-07-20	Oris Durgan PhD	oris.durgan.phd@warmmail.com	Riverside	California	6011282666312842914	496c546286979539b6dd0bbcb7c5cef9	VISA 13 digit	33.9082141136698425	-117.425011254518097
38620	2020-07-20 08:54:07	2020-07-20	Destry Hagenes	destry.hagenes@warmmail.com	Oakland	California	4315554964052902	10d2a47c4b9acf19e86fc27838fa1f88	VISA 13 digit	37.8195015156109662	-122.304714184196285
38621	2020-07-20 09:05:59	2020-07-20	Jayson Runolfsson	jayson.runolfsson@geemail.com	Chicago	Illinois	4159869450568529	e3525ec4c2510599c8c93425812555fe	Maestro	41.8063558661680688	-87.6559515316534714
38622	2020-07-20 09:08:35	2020-07-20	Miss Amaya Schroeder	miss.amaya.schroeder@warmmail.com	Moreno Valley	California	4176922352533940	c5b787996946907fa374e83101cf9952	Diners Club / Carte Blanche	33.889499543140829	-117.224495487005257
38623	2020-07-20 09:11:39	2020-07-20	Mr. Donaciano Boehm I	mr.donaciano.boehm.i@geemail.com	League City	Texas	6011733436663864312	29a9869e14a51c1e183d95cf795a671b	Maestro	29.398367423603684	-95.1717705003436691
38624	2020-07-20 09:13:35	2020-07-20	Calvin Kuhn	calvin.kuhn@warmmail.com	San Francisco	California	4561680044139	279c9e7ffed1116aec001fef0378027f	JCB 16 digit	37.7848871876928385	-122.419195060928971
38625	2020-07-20 09:23:58	2020-07-20	Alline Jacobson	alline.jacobson@warmmail.com	San Francisco	California	3733735534939899	610ccdaa23de8615fe1f790d7c7df775	American Express	37.7744858628809084	-122.434154630907841
38626	2020-07-20 09:28:32	2020-07-20	Bette Kling MD	bette.kling.md@geemail.com	New York	New York	3786834150489911	7af0a862c89d1fcb666f7df42e1cbd83	Mastercard	40.6808493802081799	-74.0236908884614735
38627	2020-07-20 09:44:32	2020-07-20	Diallo Paucek	diallo.paucek@warmmail.com	Richmond	Virginia	4669859015879	ebef0fcca9ef8843512a1f195811dfdb	American Express	37.4361222158405909	-77.506798382731148
38628	2020-07-20 09:45:42	2020-07-20	Aiyanna Emmerich	aiyanna.emmerich@geemail.com	New York	New York	589353826720137	ac30a246ed13354ae2fca7c8d7a933a0	Mastercard	40.6879463269133126	-73.8433369204763324
38629	2020-07-20 09:47:04	2020-07-20	Dian Huel	dian.huel@geemail.com	Aurora	Colorado	3158215953545410665	fc20e55dad1ebca3f062c4801ab2b627	JCB 16 digit	39.71672045650147	-104.660033489309996
38630	2020-07-20 10:00:26	2020-07-20	Mr. Lazaro Stroman V	mr.lazaro.stroman.v@warmmail.com	Tulsa	Oklahoma	3426515484010340	03b9f9e1ff218b4572aaed1d5b149ffa	JCB 16 digit	36.2119964878443596	-95.9441407889082996
38631	2020-07-20 10:06:52	2020-07-20	Fitzhugh Paucek	fitzhugh.paucek@geemail.com	New York	New York	561203601381746	31900161064f3e9d118b9dd0258b222c	JCB 16 digit	40.6035341643951853	-73.9664681321371376
38632	2020-07-20 10:15:34	2020-07-20	Dr. Leo Jones	dr.leo.jones@geemail.com	Seattle	Washington	3046310121484676	c0bc861cf3a85146e8d8d90ec9348b09	VISA 16 digit	47.695295916117729	-122.421608862133326
38633	2020-07-20 10:16:56	2020-07-20	Pairlee Skiles	pairlee.skiles@geemail.com	Wichita	Kansas	4155652257301235	e9098c9ee61839e1f1d1c036c7ab13aa	VISA 13 digit	37.7264257272582526	-97.3774693715587318
38634	2020-07-20 10:23:43	2020-07-20	Fleeta Kassulke	fleeta.kassulke@warmmail.com	Oakland	California	6011089217208246110	cf2cf697f0fae915e4471cdf274e2cbb	JCB 15 digit	37.8184206108629937	-122.291139413838309
38635	2020-07-20 10:25:41	2020-07-20	Michelle Kilback	michelle.kilback@geemail.com	Sioux Falls	South Dakota	3528931823389141341	4d5b23fc4a85e1aea30d8d43273a70a6	Discover	43.5202083151407564	-96.7200356229841702
38636	2020-07-20 10:28:18	2020-07-20	Lisette Beahan	lisette.beahan@warmmail.com	Palm Bay	Florida	6011991635880368166	10fbb8b28d15576216ed4df5f8a0c345	VISA 16 digit	27.8991624901857236	-80.5946732811465836
38637	2020-07-20 10:39:13	2020-07-20	Daniela Rau MD	daniela.rau.md@woohoo.com	Nashville	Tennessee	676386787790376	316963d12a1a6a39a73d1c5357c49134	Maestro	36.1980215120252211	-86.7887569732870929
38638	2020-07-20 10:41:35	2020-07-20	Dr. Kody Bartoletti II	dr.kody.bartoletti.ii@geemail.com	New York	New York	3040691952559900	8be1a10990f8f053514ef85efb17e968	American Express	40.6230473845023639	-73.8685839980270629
38639	2020-07-20 10:47:26	2020-07-20	Neveah Kuhlman DVM	neveah.kuhlman.dvm@warmmail.com	Beaumont	Texas	3088907248472647170	95965eb04252ba5fd522546b02e0c03c	JCB 15 digit	30.0390406674310562	-94.1270229070700708
38640	2020-07-20 11:04:07	2020-07-20	Tammie Schimmel	tammie.schimmel@geemail.com	San Jose	California	4742180704627986	a645d84edd1c442184481b485e85f3a1	VISA 13 digit	37.2272464277043937	-121.87364920724518
38641	2020-07-20 11:09:58	2020-07-20	Elliott Jaskolski Sr.	elliott.jaskolski.sr.@geemail.com	Oakland	California	869992530043283360	ecf909dc4d83fa26d6f7b808fe0c3764	Maestro	37.8015575640946437	-122.2574617687917
38642	2020-07-20 11:13:08	2020-07-20	Demarcus Feeney-Schaden	demarcus.feeney.schaden@geemail.com	San Francisco	California	3112907014130697704	7eaf47aacc367f65509b152331ac51f6	Diners Club / Carte Blanche	37.7895935355209787	-122.420882328031723
38643	2020-07-20 11:14:28	2020-07-20	Makena Koelpin-Kozey	makena.koelpin.kozey@geemail.com	Austin	Texas	4976671037514	f665d763e2313f389d274ae9e8b092fb	VISA 16 digit	30.3723523791074754	-97.8100145097129143
38644	2020-07-20 11:15:13	2020-07-20	Miss Cheryll Turner	miss.cheryll.turner@geemail.com	Seattle	Washington	4703923486497863	719a4e816d94a41e51fa579788f40172	Maestro	47.7007873290143891	-122.403583786954727
38645	2020-07-20 11:25:49	2020-07-20	Dian Lehner	dian.lehner@geemail.com	Kansas City	Missouri	3096383580349094886	904ab90a06bc3f1d2c8a75794750bbed	American Express	39.0435312551282365	-94.6155937430672367
38646	2020-07-20 11:37:00	2020-07-20	Brenden Hand	brenden.hand@geemail.com	Santa Ana	California	3158088138350642594	13aeba4e2c2b3e1d33503165a9d0017d	JCB 16 digit	33.7771838982693851	-117.826332466576247
38647	2020-07-20 11:37:48	2020-07-20	Raymon Hudson	raymon.hudson@geemail.com	Nashville	Tennessee	3020494133699020	688b708cc0c6ca2cb2cf32299fe2e6c3	Diners Club / Carte Blanche	36.0903013291891668	-86.8174600577354454
38648	2020-07-20 11:42:43	2020-07-20	Amina Kuhic	amina.kuhic@geemail.com	New York	New York	55610877870032714	eb66f09c69da02ef20634c5285f66fee	JCB 15 digit	40.7266764922756721	-73.8447994790866886
38649	2020-07-20 11:42:58	2020-07-20	Alonso Schroeder	alonso.schroeder@geemail.com	Dallas	Texas	6011440144643543949	2488821ad29778ccccfbce52c49fdbc2	VISA 16 digit	32.8785435897104463	-96.8439465817026672
38650	2020-07-20 11:59:35	2020-07-20	Adrianna Block	adrianna.block@geemail.com	Joliet	Illinois	3096542463211570721	7fe6940900dec36e32155170774c0d9c	Maestro	41.5530352811187456	-88.1846554130420088
38651	2020-07-20 12:16:24	2020-07-20	Zakary Huels V	zakary.huels.v@geemail.com	Oakland	California	3088207067647129741	203848e6e9c7886ffb698886ac72cbe1	JCB 16 digit	37.7770998358668777	-122.259140690492558
38653	2020-07-20 12:19:18	2020-07-20	Beatrice Halvorson	beatrice.halvorson@geemail.com	Denver	Colorado	676380239938105	590c07cd9b2c71db857f308e511a3fed	Voyager	39.8243737096950383	-104.8206513416268
38654	2020-07-20 12:33:03	2020-07-20	Mrs. Dagny Hermiston MD	mrs.dagny.hermiston.md@geemail.com	Naperville	Illinois	060412139449495	90930f6f0cc5ab4d284eab7623156b06	JCB 16 digit	41.6943941095292558	-88.1284430753793657
38655	2020-07-20 12:53:54	2020-07-20	Rowan Bruen	rowan.bruen@geemail.com	New York	New York	6011240418785340393	20b4e90c8949ce95179978d000839ea1	American Express	40.6418282871358088	-73.8933958317514481
38656	2020-07-20 12:54:41	2020-07-20	Besse Mayer	besse.mayer@geemail.com	Renton	Washington	3742979001696280	579d3921a97b3aff244301a136c7a6f9	Maestro	47.4950759994391376	-122.174101648626845
38657	2020-07-20 12:59:51	2020-07-20	Leslie Ferry	leslie.ferry@woohoo.com	Oakland	California	51602892417141357	7015ac2c347be9b6491cced2451b1e48	JCB 16 digit	37.7888353420728933	-122.225434439428398
38658	2020-07-20 13:07:06	2020-07-20	Jailene Emmerich-Rosenbaum	jailene.emmerich.rosenbaum@geemail.com	San Francisco	California	4860393608204242	1a6b4db5311f2b8127ee019a6451c3b3	JCB 15 digit	37.7578700403219685	-122.45674087512424
38659	2020-07-20 13:07:45	2020-07-20	Vashon Sipes	vashon.sipes@geemail.com	Hollywood	Florida	4893030134893624	79bcf2ebed7bb1f1909f17f55a4d1870	VISA 16 digit	25.9815783526692528	-80.0759953898660797
38660	2020-07-20 13:11:06	2020-07-20	Dominik Reichert	dominik.reichert@geemail.com	Berkeley	California	4824408603697	82f1c3fa22bb7450b9ceb9f0f9f3cff4	Voyager	37.8503173268040456	-122.238653206147134
38661	2020-07-20 13:24:43	2020-07-20	Dr. Johnny Wolff DDS	dr.johnny.wolff.dds@geemail.com	High Point	North Carolina	3158326110672286949	2bf6dcefb4ba25260a6a04dd8ee7b3ff	Maestro	35.9629724891483775	-79.9425862037781627
38662	2020-07-20 13:25:58	2020-07-20	Miss Exie Pollich	miss.exie.pollich@geemail.com	New York	New York	51910451246454924	439ee5a1993a3ce124a798be7a6b61d6	Discover	40.6698049259595535	-73.9739029514964699
38663	2020-07-20 13:35:27	2020-07-20	Celestia Trantow	celestia.trantow@geemail.com	Chicago	Illinois	3001651003670311	3786492ba43099a1aacf43c7ecda42e3	Maestro	41.9050859468825152	-87.7701847052231443
38664	2020-07-20 13:59:39	2020-07-20	Alta Kerluke	alta.kerluke@geemail.com	Columbia	South Carolina	3408583226991567	733bce127dccf3ee503e581d89fc682e	VISA 13 digit	34.0411309483259927	-80.8613257383480573
38665	2020-07-20 14:03:41	2020-07-20	Victoriano Wilderman	victoriano.wilderman@geemail.com	Clovis	California	210069799001195994	692b6db60b9644d4ff354845ebcc0d78	American Express	36.8221839320257303	-119.783182142216333
38666	2020-07-20 14:24:24	2020-07-20	Dena Berge	dena.berge@geemail.com	Houston	Texas	4683706117713418	d010eb90f34297e2415c7db2f0241d6b	JCB 16 digit	29.7561888386107967	-95.4025733400151097
38667	2020-07-20 14:27:26	2020-07-20	Mercer Jacobson Sr.	mercer.jacobson.sr.@geemail.com	San Francisco	California	3337328775731097525	4ab73b0092a08b00d3757b8d9ea700fc	Diners Club / Carte Blanche	37.7700307305766785	-122.41445353482807
38668	2020-07-20 14:39:49	2020-07-20	Acey Johnston	acey.johnston@geemail.com	Houston	Texas	3020386329220506	679b26bf9bc6429f7f34459d5d7f0ae8	JCB 15 digit	29.8543175148855902	-95.4431633592132442
38669	2020-07-20 14:46:57	2020-07-20	Willis Marks	willis.marks@geemail.com	Woodbridge	New Jersey	3484549150668783	f402c39cb2a58ea4e99c37618e83f218	American Express	40.5975635782040598	-74.3576700629524794
38670	2020-07-20 14:52:08	2020-07-20	Dr. Mekhi Schmeler II	dr.mekhi.schmeler.ii@warmmail.com	Hialeah	Florida	4691334545872514	973ec38acfab7232b12060917fa054c1	VISA 16 digit	25.8061349613569675	-80.3706515297196802
38671	2020-07-20 14:53:26	2020-07-20	Nicolas Tillman	nicolas.tillman@geemail.com	Lincoln	Nebraska	3030942801693832	1d2106de07421a2956beca305ba45cd7	VISA 13 digit	40.726957261564209	-96.6908997846927463
38672	2020-07-20 14:58:58	2020-07-20	Dr. Yoshio Hermann	dr.yoshio.hermann@warmmail.com	Las Cruces	New Mexico	180026729612064323	ebd7e50bab0cbac0dee5d96ec4289acf	Maestro	32.2329339047927377	-106.784884617023906
38673	2020-07-20 15:09:20	2020-07-20	Nakisha Stroman	nakisha.stroman@geemail.com	Los Angeles	California	210040807865750442	f46a7e880cc8acb865948702519899ec	VISA 16 digit	34.0540053916495253	-118.453124466351412
38674	2020-07-20 15:11:05	2020-07-20	Whitley Hoppe	whitley.hoppe@geemail.com	Columbus	Ohio	4671448596323104	feeddd39ae3a82fa34413eaa57e9d614	Diners Club / Carte Blanche	39.8869438182607254	-83.0651910591173959
38675	2020-07-20 15:32:36	2020-07-20	Tracey McClure	tracey.mcclure@geemail.com	Charleston	South Carolina	6011828521898398032	1dda9e2be1c9884d62f19e251bc3f3d0	Mastercard	32.8759632955301555	-79.985645654439935
38676	2020-07-20 15:51:54	2020-07-20	Beatrice Roob DVM	beatrice.roob.dvm@woohoo.com	San Francisco	California	6011030200456276393	4238395b9fc56fcbc1581cf2ea79238f	Diners Club / Carte Blanche	37.7589352151991093	-122.430700348347742
38677	2020-07-20 15:56:01	2020-07-20	Gust Christiansen PhD	gust.christiansen.phd@geemail.com	Phoenix	Arizona	3088214325292775239	12c000a27cb7057cedaaceae91858b34	Maestro	33.4767617723837532	-112.106986279592292
38678	2020-07-20 15:57:03	2020-07-20	Cielo Runolfsdottir	cielo.runolfsdottir@geemail.com	Anchorage	Alaska	6011363218086825899	4752962ec14b0c9b6bc79f639a99eee9	JCB 16 digit	61.1786914268724615	-149.278578138177465
38679	2020-07-20 15:59:37	2020-07-20	Mr. Jayvon Wuckert	mr.jayvon.wuckert@geemail.com	New York	New York	561246208918832	29ea7db35e917014eccf26b80844ac0f	VISA 13 digit	40.5936071366295224	-73.9389142225857796
38680	2020-07-20 16:00:16	2020-07-20	Elba Hermiston	elba.hermiston@geemail.com	Boston	Massachusetts	3088406699823598973	b7e34ddb321c97a050aa3b8f24569183	Discover	42.3946639901194757	-70.9452895219389319
38681	2020-07-20 16:03:37	2020-07-20	Conner Ruecker-Reichel	conner.ruecker.reichel@geemail.com	Jacksonville	Florida	6011840865704577444	ce9415074b8b1df0ca2abdc0b452135a	VISA 16 digit	30.3075773586571202	-81.7344592819534341
38682	2020-07-20 16:09:28	2020-07-20	Lucetta Thiel	lucetta.thiel@woohoo.com	Ontario	California	869975883423540896	5f8ecd6f2746c64b28dd3eb4fffa399f	VISA 16 digit	33.9982007040321861	-117.555954503138366
38683	2020-07-20 16:15:56	2020-07-20	Kaylin Koss	kaylin.koss@woohoo.com	New York	New York	6011679691689768840	73163da6038c8ddcd14efdd0f470d6d1	American Express	40.7034689961224814	-74.0152296409837902
38684	2020-07-20 16:20:05	2020-07-20	Dr. Verl Kozey	dr.verl.kozey@warmmail.com	San Francisco	California	3798536829599139	c35120da40aa0ae67b4c68557375fc92	JCB 16 digit	37.7787619050068599	-122.380802628076893
38685	2020-07-20 16:22:44	2020-07-20	Ozzie Batz	ozzie.batz@warmmail.com	Berkeley	California	676140047491796	d46b5e49cb32b527f267a61d7bdc3d1f	Maestro	37.8510681998400784	-122.270498368220188
38686	2020-07-20 16:24:52	2020-07-20	Kyle Bashirian	kyle.bashirian@geemail.com	Oakland	California	3096691629718749849	9e97226727117ab6bfcf665d9ea79187	Mastercard	37.8219635053724943	-122.254512084366979
38687	2020-07-20 16:25:47	2020-07-20	Brittany Willms-Batz	brittany.willms.batz@geemail.com	Las Vegas	Nevada	639035524440530	65ad167b8aabd65796601d15895f476d	VISA 16 digit	36.2532311715751874	-115.168432111407071
38688	2020-07-20 16:28:54	2020-07-20	Ernestina McCullough	ernestina.mccullough@warmmail.com	Reno	Nevada	180078012029164532	983629f201c5a8cde396d4ce5bbdd1c9	VISA 13 digit	39.6314814080562456	-119.857608432804795
38689	2020-07-20 16:31:41	2020-07-20	Camila Marquardt-Gorczany	camila.marquardt.gorczany@geemail.com	Chicago	Illinois	3472839565555509	1d1b743cd7c82755687d3c6a2f93fe85	VISA 16 digit	41.8879562301397357	-87.6740977736685352
38690	2020-07-20 16:32:10	2020-07-20	Beverlee Glover	beverlee.glover@woohoo.com	Sunnyvale	California	3747660569508530	c423ac565fd4b699706085b1e2060604	JCB 15 digit	37.3995401910964418	-121.981834231057391
38691	2020-07-20 16:34:02	2020-07-20	Dr. Lawerence Weimann III	dr.lawerence.weimann.iii@woohoo.com	New York	New York	3721503670219664	8de08ed539859ef822c165a1f0d07f58	VISA 13 digit	40.6547931343540512	-74.0284113224957139
38692	2020-07-20 16:41:11	2020-07-20	Verlie Pollich	verlie.pollich@geemail.com	Tampa	Florida	3039088178696635	216d5693e5fcbd220ae7b5f6dd73a163	Diners Club / Carte Blanche	28.0601946429464952	-82.5034680915277363
38693	2020-07-20 16:58:22	2020-07-20	Elfreda Borer	elfreda.borer@geemail.com	Buffalo	New York	4894922288267	c509d63352f81d724d711dda886042eb	Maestro	42.9126054139994082	-78.9292252101868428
38694	2020-07-20 17:06:53	2020-07-20	Lenny Hermann	lenny.hermann@geemail.com	Houston	Texas	3096180011037364485	92a15b6f9bc04c7286acc6baeeb3fe04	Maestro	29.8662902870759375	-95.2987078134916743
38695	2020-07-20 17:07:28	2020-07-20	Racheal Crona	racheal.crona@geemail.com	Anaheim	California	4221406149022925	6e44fbd26e9b1b6d5274c4f105f413cb	Discover	33.9427551479842506	-117.788315430676931
38696	2020-07-20 17:09:10	2020-07-20	Elsie Moore MD	elsie.moore.md@woohoo.com	Nashville	Tennessee	3158460803416758167	6fd2e1447a355e448e638b3d889edd6f	JCB 16 digit	36.2503231775138488	-86.749079999458047
38697	2020-07-20 17:20:46	2020-07-20	Deondre Stoltenberg	deondre.stoltenberg@warmmail.com	Baltimore	Maryland	3412193225153500	907b6f8238e0ff2a64f109246dd2131f	Discover	39.2155452523846151	-76.5390674656275678
38698	2020-07-20 17:45:53	2020-07-20	Mcarthur Schumm	mcarthur.schumm@geemail.com	Fullerton	California	6011472927041764948	72a7bd4e042211a17cc405976d303ef7	JCB 16 digit	33.8210969249408677	-117.953759032275528
38699	2020-07-20 17:50:24	2020-07-20	Peyton Bechtelar	peyton.bechtelar@geemail.com	San Francisco	California	3757531157418746	f450c52e44d79f3d527649de991e3861	VISA 16 digit	37.7587502260812187	-122.437743715964928
38700	2020-07-20 17:52:44	2020-07-20	Justin Gutmann	justin.gutmann@woohoo.com	Sunnyvale	California	4348676204096075	baeae0283816606223295621b4f34cf5	VISA 16 digit	37.481880059371889	-122.119707005211339
38701	2020-07-20 17:58:30	2020-07-20	Astrid Oberbrunner-O'Kon	astrid.oberbrunner.o'kon@geemail.com	Aurora	Illinois	53190070036754086	5cc4be5e7927c47ba43742db65946247	JCB 16 digit	41.7308972054384668	-88.260751664119212
38702	2020-07-20 18:03:57	2020-07-20	Dr. Jerrica Runolfsson	dr.jerrica.runolfsson@geemail.com	Chicago	Illinois	869914281890885015	65233bcbbc0b9842404574924131cce4	JCB 16 digit	41.7608759926933786	-87.7427988641925083
38703	2020-07-20 18:04:40	2020-07-20	Ms. Madelene Bernhard MD	ms.madelene.bernhard.md@woohoo.com	Plano	Texas	3783452788871526	dba15b0d7f4b9f3befee4aae8ad4a56e	Diners Club / Carte Blanche	33.1474330594848894	-96.7700060246694846
38704	2020-07-20 18:12:00	2020-07-20	Ruffin Hettinger	ruffin.hettinger@geemail.com	Clearwater	Florida	3088296350766572798	b5c0746244d949bd4750c91da4fe08b7	JCB 15 digit	27.9249765646304944	-82.7498554643042326
38705	2020-07-20 18:13:39	2020-07-20	Tremaine Bosco	tremaine.bosco@geemail.com	New York	New York	3490507960836299	c4ca081fe49b3339a9b1026cc7fd6880	JCB 15 digit	40.5822882127705924	-73.9567803253315361
38706	2020-07-20 18:18:01	2020-07-20	Clabe Weimann	clabe.weimann@geemail.com	Irvine	California	676395832245005	a0396b66c009d698e12813b6f1dee98d	Mastercard	33.7522283217884649	-117.797611309682196
38707	2020-07-20 18:28:12	2020-07-20	Ashleigh Champlin	ashleigh.champlin@warmmail.com	Chicago	Illinois	3112152490381325280	18b90009d86b5be2f12d8e048f4c73bd	JCB 15 digit	41.7408944424077859	-87.7019865131966725
38708	2020-07-20 18:29:42	2020-07-20	Jesica Effertz	jesica.effertz@geemail.com	Worcester	Massachusetts	54678619310516222	bfcc9bef55feba21e43461535af770b5	Discover	42.2942008959762745	-71.7392561850391388
38709	2020-07-20 18:45:57	2020-07-20	Isadore Kovacek	isadore.kovacek@woohoo.com	San Francisco	California	3782886438721063	79950078dd6481398b7fbc23cb0b5e59	JCB 15 digit	37.7714969184887011	-122.440705813121497
38710	2020-07-20 18:52:59	2020-07-20	Mykel Dooley	mykel.dooley@geemail.com	San Francisco	California	869940008654181465	1e99943e447684ae5026940fa40ddf4e	VISA 16 digit	37.7586573971698343	-122.424849378054191
38711	2020-07-20 19:01:21	2020-07-20	Ah Hermiston-Dooley	ah.hermiston.dooley@geemail.com	Santa Clarita	California	4720138650060343	397d30984abc604fd991cd7a79803589	VISA 16 digit	34.4235160434357823	-118.454152533701432
38712	2020-07-20 19:01:36	2020-07-20	Braylon Wiza DVM	braylon.wiza.dvm@geemail.com	New York	New York	210073337756297162	e4b0f9d3e0220c1ad1b0bedc53f94c6e	VISA 16 digit	40.7389137416835894	-73.8528774344723615
38713	2020-07-20 19:02:05	2020-07-20	Cory Hammes-Tremblay	cory.hammes.tremblay@warmmail.com	Fort Wayne	Indiana	3158885205723346560	31be2003ede324dcdc4f7660d809bde7	Diners Club / Carte Blanche	41.1829773043531944	-85.1343831567779148
38714	2020-07-20 19:04:49	2020-07-20	Virdie Keebler	virdie.keebler@geemail.com	Fort Wayne	Indiana	6011202485853627247	70d4afb4ce15004225786bda11b748cb	American Express	40.9935693118039524	-85.1889777870602956
38715	2020-07-20 19:05:13	2020-07-20	Dr. Starr Lockman PhD	dr.starr.lockman.phd@geemail.com	Phoenix	Arizona	52513576826111972	ff96c7d547d188ebf8e84e85b601d2f6	JCB 16 digit	33.5829029648497723	-112.117786882764108
38716	2020-07-20 19:06:35	2020-07-20	Devan Bogisich	devan.bogisich@woohoo.com	Miami Gardens	Florida	53208014236174455	51b8e6af722aeb4788612bf1b75dbfed	VISA 16 digit	25.8929118700265875	-80.1730347347226058
38717	2020-07-20 19:19:15	2020-07-20	Dr. Shirley Homenick	dr.shirley.homenick@geemail.com	Carlsbad	California	3158925479441165253	0dc7cdd36539256051a005bcb4b7dc92	Diners Club / Carte Blanche	33.1261456641308953	-117.356943944028757
38718	2020-07-20 19:50:04	2020-07-20	Noe Schulist	noe.schulist@warmmail.com	Irvine	California	6011256766131415892	ea703dcab26254fa146b0c03aa6a2026	VISA 13 digit	33.760326303217191	-117.829849592364582
38719	2020-07-20 19:51:30	2020-07-20	Joeseph Krajcik	joeseph.krajcik@geemail.com	Jacksonville	Florida	502090677124886	9caa105af00417b9f41f4f0bc0fd5150	Mastercard	30.3360776807699359	-81.7552680546496191
38720	2020-07-20 19:59:55	2020-07-20	Gale Lindgren	gale.lindgren@geemail.com	San Francisco	California	3337105706715192346	ed696bd4f70bc69ed4e78c73e1a3962b	Discover	37.7809347030166975	-122.392687261532814
38721	2020-07-20 20:22:32	2020-07-20	Minta Wiegand	minta.wiegand@woohoo.com	San Francisco	California	6011899037002466783	76d8de903f7d85305c5e6e3ba926313e	VISA 16 digit	37.7739805300790437	-122.463047374383791
38722	2020-07-20 20:39:47	2020-07-20	Rosco Walker	rosco.walker@warmmail.com	San Francisco	California	675918754863381	56f593e820c6d66906b300ed50ffc5de	American Express	37.7787140494099276	-122.438686586410483
38723	2020-07-20 20:45:43	2020-07-20	Mickey Trantow-Connelly	mickey.trantow.connelly@geemail.com	Colorado Springs	Colorado	3158586099698786161	b1aca2ca44d7fdb3c1b3b6dc02643306	VISA 16 digit	38.7722385633319604	-104.712075472731883
38724	2020-07-20 20:58:15	2020-07-20	Milissa Wolff	milissa.wolff@warmmail.com	San Francisco	California	3042728863852723	71b51524716cef1bea2e8f6d04247063	VISA 13 digit	37.7777415729231976	-122.419850608702049
38725	2020-07-20 21:17:34	2020-07-20	Mason Morissette-Kunze	mason.morissette.kunze@geemail.com	Indianapolis	Indiana	3112696464237509580	2e980167d8da3a24aeb88f7fcca7b8ff	Voyager	39.8166188363458957	-86.1720962153483185
38726	2020-07-20 21:22:09	2020-07-20	Izabella Sanford MD	izabella.sanford.md@woohoo.com	Ventura	California	869998683560205268	24c88acf6c233c9aaffd7df8a2b38794	JCB 16 digit	34.3026135796375584	-119.166953552990037
38727	2020-07-20 21:22:55	2020-07-20	Ms. Gladys Greenfelder	ms.gladys.greenfelder@geemail.com	Lewisville	Texas	869935821112127822	af33ed72e28719b4976da92b0b698d87	VISA 13 digit	33.0358458384390872	-97.0557161581266712
38728	2020-07-20 21:33:09	2020-07-20	Dr. Tamika Lind	dr.tamika.lind@warmmail.com	Houston	Texas	4624566924087	1844e33fed30ff3cdba8dbfb1b5784bc	Discover	29.8688918730322257	-95.440176721756913
38729	2020-07-20 21:53:34	2020-07-20	Abel Nienow	abel.nienow@geemail.com	Vacaville	California	210098426225681220	51eafc73417d693426cf654ace590a76	Voyager	38.4401530569545926	-121.937211833509807
38730	2020-07-20 21:58:28	2020-07-20	Doctor Olson	doctor.olson@woohoo.com	Orange	California	4986783974348	e4431a2d9fe88ead7e3b28191b997f5b	VISA 13 digit	33.7603480501454314	-117.938902206682783
38731	2020-07-20 22:07:32	2020-07-20	Dr. Kristian Rath	dr.kristian.rath@geemail.com	Washington	District of Columbia	869968893531427919	86d54c4bf3695accf7b1c8a6616a1449	JCB 16 digit	38.8369834823798357	-76.9184453414034124
38732	2020-07-20 22:24:36	2020-07-20	Edd Sporer	edd.sporer@geemail.com	Port St. Lucie	Florida	869904840974115003	9c831a220b260b4bc850d85fd57b64da	Voyager	27.2045388649351878	-80.3112044883046252
38733	2020-07-20 22:29:10	2020-07-20	Paige Okuneva	paige.okuneva@geemail.com	Rochester	New York	4678173605919	7063b6a32cd0bed39a3e56e04f18b9d2	VISA 16 digit	43.0951565644681409	-77.6800857748143443
38734	2020-07-20 22:32:33	2020-07-20	Roena Larkin DDS	roena.larkin.dds@geemail.com	Corpus Christi	Texas	210092784812204152	bb17d1dbd5d6e77c3589f36bbfebf5d2	Discover	27.7742959538411363	-97.1174281473565912
38735	2020-07-20 22:35:49	2020-07-20	Ethan Lind Jr.	ethan.lind.jr.@geemail.com	Salt Lake City	Utah	4913005579780128	b41328d6ee5a43994fdc051d15d86a21	JCB 16 digit	40.7421481540106214	-111.998803617939345
38736	2020-07-20 22:41:44	2020-07-20	Joye Cormier DVM	joye.cormier.dvm@warmmail.com	Stamford	Connecticut	180033624146959075	18fcc34c180a198b10d0714521a30ce0	Maestro	41.174351269228012	-73.5433783012014004
38737	2020-07-20 22:44:44	2020-07-20	Elia Koss MD	elia.koss.md@geemail.com	Santa Clarita	California	4732301234893706	aa3861ebdd494dfc66cc40c6d260d5fb	Discover	34.4337605162728551	-118.444149710667133
38738	2020-07-20 22:50:15	2020-07-20	Loula Rowe	loula.rowe@geemail.com	Chicago	Illinois	4805119422300504	2cca0a78d377954b78210495eda4bc90	Discover	41.9308391044683759	-87.662876280632986
38739	2020-07-20 22:58:38	2020-07-20	Kyla Tillman DDS	kyla.tillman.dds@geemail.com	Salinas	California	210095239823570361	a9e607c8f00f8d6ad97a6894c5d4c03e	Discover	36.6366775424450637	-121.549611344625063
38740	2020-07-20 23:13:32	2020-07-20	Miss Anabelle Heaney DVM	miss.anabelle.heaney.dvm@geemail.com	Fontana	California	676364837286299	cc90012e6c6d4dfec6f3b561cbb93bd8	Maestro	34.0640358037929971	-117.520713302287831
38741	2020-07-20 23:19:01	2020-07-20	Denis Beatty-Parker	denis.beatty.parker@geemail.com	San Francisco	California	4772571062294257	ce7111d57865e3fc619fe352531992cb	American Express	37.7538437753951612	-122.423676979357538
38742	2020-07-20 23:20:50	2020-07-20	Mrs. Mina Hansen	mrs.mina.hansen@geemail.com	Torrance	California	3748828062675184	d731c8f3628816b01aea56b6fe2d4cf1	VISA 13 digit	33.8690253918897355	-118.434072496009605
38743	2020-07-20 23:23:10	2020-07-20	Tayla Hayes	tayla.hayes@woohoo.com	Chicago	Illinois	4251563184036120	fa39d8852d0c13620a85fac184e9d51e	JCB 16 digit	41.8901623733643476	-87.5986522116728139
38744	2020-07-20 23:29:59	2020-07-20	Rosario Toy	rosario.toy@geemail.com	Green Bay	Wisconsin	3096648160147888663	1f87c66b6d2f30368906a2956d5a774b	JCB 15 digit	44.5083814432907801	-88.0839089598793521
38745	2020-07-20 23:32:23	2020-07-20	Edie Huel	edie.huel@geemail.com	Austin	Texas	3015027081779249	882d5548197ec1335423449f21cde6c4	JCB 16 digit	30.3939632616598132	-97.6773556552134465
38746	2020-07-20 23:36:30	2020-07-20	Dr. Lary Hand PhD	dr.lary.hand.phd@geemail.com	Salem	Oregon	55345134042394750	8173d3ef1f790deeab1c1648425f3ed1	Maestro	44.9759842762060416	-123.104811749529844
38747	2020-07-20 23:50:57	2020-07-20	Enos Gaylord	enos.gaylord@geemail.com	Kansas City	Missouri	4563212764168118	540dadda8431d23610f0dd3f26279dd3	VISA 13 digit	39.0415783612825038	-94.5099305331930566
38748	2020-07-20 23:55:34	2020-07-20	Mira Pouros	mira.pouros@woohoo.com	Miami	Florida	54529771920744610	62977318b06d481133cf5395e9d3fa51	Maestro	25.7826423794634643	-80.2154713735789073
38749	2020-07-20 23:59:25	2020-07-20	Lacy Swift-Fahey	lacy.swift.fahey@woohoo.com	Lincoln	Nebraska	3424005499820034	c75a1ef2e7e67a5bf89671b58b760472	VISA 16 digit	40.7734125733859827	-96.7231259391337659
38750	2020-07-20 23:59:33	2020-07-20	Jeraldine Breitenberg	jeraldine.breitenberg@woohoo.com	San Francisco	California	210072053874270764	2395d7e2fbf762469925d3bddd524a2c	JCB 15 digit	37.7566365396889481	-122.448107687993669
38751	2020-07-21 00:03:00	2020-07-21	Derik Marquardt	derik.marquardt@geemail.com	Albuquerque	New Mexico	51970810894513736	ecd52b0587ec48c264c8c10522175fe7	VISA 13 digit	35.1611707772262392	-106.732753737650441
38752	2020-07-21 00:13:33	2020-07-21	Destiny Walker	destiny.walker@geemail.com	Chicago	Illinois	3004246230152642	17d5cfba68040238fce554095dca361c	Discover	41.7610980897512292	-87.6062090521708114
38753	2020-07-21 00:19:36	2020-07-21	Ellamae Emmerich	ellamae.emmerich@warmmail.com	Durham	North Carolina	4144655452197716	884dbb6bc6d90f3f7b51bb0efa8bd010	JCB 16 digit	36.0439503232728669	-78.9881668685372915
38754	2020-07-21 00:20:24	2020-07-21	Deonte Lynch DVM	deonte.lynch.dvm@geemail.com	Fort Worth	Texas	55610325725635877	e061b9b48d5599b10b3ab51715f2fbf3	VISA 13 digit	32.7423535975217845	-97.3831116558805121
38755	2020-07-21 00:29:24	2020-07-21	Bernita McKenzie	bernita.mckenzie@geemail.com	Mesa	Arizona	589303555749039	d2c25e00d4737622447ef2c40f1247ad	Maestro	33.4326104102335862	-111.741625415755067
38756	2020-07-21 00:45:08	2020-07-21	Semaj Steuber	semaj.steuber@warmmail.com	Pearland	Texas	4805286673966331	ba57749840a5eff119b0061cbe84718b	American Express	29.510989164215701	-95.2364009421639111
38757	2020-07-21 00:47:31	2020-07-21	Miss Elyssa Graham DVM	miss.elyssa.graham.dvm@warmmail.com	Baton Rouge	Louisiana	4767251520092992	9e23c0b04485d4583b4bfa9a8f6cc788	Voyager	30.4490828364368511	-91.0807149173799928
38758	2020-07-21 01:02:24	2020-07-21	Mr. Hope Wunsch IV	mr.hope.wunsch.iv@geemail.com	Orange	California	4204967082106	a2e2ecab762a6de30313bf9d661a20dd	Maestro	33.7525025955755282	-117.904401848615336
38759	2020-07-21 01:03:19	2020-07-21	Jaleel Stamm	jaleel.stamm@warmmail.com	Birmingham	Alabama	4033241556519602	f72614598eba372cefcc66c155491d9f	VISA 16 digit	33.6038019716996672	-86.7797053837925318
38760	2020-07-21 01:09:00	2020-07-21	Petra Vandervort	petra.vandervort@geemail.com	New York	New York	4779642524615166	7d8c5bb465dde1eb5c0ab579b3ca9f65	American Express	40.7525989781357367	-73.9983985168289422
38761	2020-07-21 01:21:52	2020-07-21	Mintie Lind	mintie.lind@geemail.com	New York	New York	869918543260686356	2e3712fb9a48a343c7f5b2509b05e0a0	JCB 16 digit	40.7356199658699296	-74.0294257640268683
38762	2020-07-21 01:30:51	2020-07-21	Love Miller	love.miller@geemail.com	Wichita	Kansas	3003162110817108	5c6879decf1ffe0136a945a1f0ac8181	VISA 16 digit	37.7782595903955425	-97.3715339405663372
38763	2020-07-21 01:31:53	2020-07-21	Dr. Alexis Bartell MD	dr.alexis.bartell.md@woohoo.com	Denver	Colorado	54259310494432868	ea8805c2f81788f49de3ab46f17bafc5	American Express	39.7050864750571506	-104.937469441235436
38764	2020-07-21 01:40:18	2020-07-21	Katelyn Conroy	katelyn.conroy@geemail.com	Virginia Beach	Virginia	3088925491529523816	e030dbb9ddf746c184a01902309a3d2e	JCB 16 digit	36.7825114513933684	-76.0698252973750186
38765	2020-07-21 01:46:55	2020-07-21	Miss Maegan Hagenes	miss.maegan.hagenes@geemail.com	Tucson	Arizona	180027075508260586	f6e859233085cc12c9956617a7b74eea	JCB 16 digit	32.2511061930604299	-110.772567511139812
38766	2020-07-21 01:53:56	2020-07-21	Mrs. Rae Pagac DVM	mrs.rae.pagac.dvm@warmmail.com	Dayton	Ohio	3468889387552065	f7db1cf0c180043e598f7df08fbbeec6	VISA 16 digit	39.7398566618353115	-84.1161054839104452
38767	2020-07-21 01:54:04	2020-07-21	Marc McGlynn	marc.mcglynn@geemail.com	Los Angeles	California	6011711841754328281	4c478fba423157414d536de07300315e	VISA 16 digit	34.0616782385721777	-118.386716015868998
38768	2020-07-21 01:56:10	2020-07-21	Shelly Hudson	shelly.hudson@warmmail.com	Kansas City	Missouri	676247925085756	cac13cff4b3d60847c88901fda7f8e20	JCB 15 digit	39.1833233991939593	-94.5794430667292403
38769	2020-07-21 02:14:28	2020-07-21	Evelena Hessel	evelena.hessel@geemail.com	Milwaukee	Wisconsin	4049211707064586	70b23df30a76c3cbaf3e378c647dbc49	JCB 16 digit	43.0893938784107533	-88.0216654619768235
38770	2020-07-21 02:15:57	2020-07-21	Beverlee Greenfelder	beverlee.greenfelder@geemail.com	Vista	California	869900254966095534	cba19c4fbba2df37f988d2d13e1edfb8	VISA 13 digit	33.2431999575328092	-117.227805286791551
38771	2020-07-21 02:18:33	2020-07-21	Luann Pagac	luann.pagac@geemail.com	San Francisco	California	676309597664888	a66544f16f36ef9450093cc699b4cc37	Maestro	37.7565797337905522	-122.433187459357171
38772	2020-07-21 02:39:16	2020-07-21	Agnes Zieme DDS	agnes.zieme.dds@warmmail.com	Fort Collins	Colorado	4361454309011270	13e24f172bcad81b579cb92112a9862f	Mastercard	40.5048995748784435	-105.008100722446301
38773	2020-07-21 02:56:39	2020-07-21	Rutherford Collier-Monahan	rutherford.collier.monahan@warmmail.com	San Francisco	California	4146974627606974	7732f1a8deef0c094ac41488bf3fabd8	Mastercard	37.7813877544161656	-122.412195581640049
38774	2020-07-21 03:00:13	2020-07-21	Gene Collins	gene.collins@woohoo.com	Pueblo	Colorado	4567735226670277	4135f436f8f1828554aeeeb126f41960	JCB 16 digit	38.2880752488017109	-104.540258210511141
38775	2020-07-21 03:02:08	2020-07-21	Enrico Howell	enrico.howell@geemail.com	Portland	Oregon	3049125105235200	e8ea639546307462fe5f22f699f79eb6	VISA 13 digit	45.4978309218659973	-122.671380296861756
38776	2020-07-21 03:07:50	2020-07-21	Devonte Kertzmann	devonte.kertzmann@geemail.com	Richmond	Virginia	52242158838463259	36f6845683c977ba4516c7a51828fde1	American Express	37.4383647952448584	-77.5173014964666152
38777	2020-07-21 03:15:52	2020-07-21	Miss Lindsay Balistreri	miss.lindsay.balistreri@geemail.com	San Antonio	Texas	51242231513813435	ca48409ab9ab7aad6980e003c8a4da79	American Express	29.3995457990631479	-98.4254957035485631
38778	2020-07-21 03:16:29	2020-07-21	Dr. Pedro Hoppe Sr.	dr.pedro.hoppe.sr.@geemail.com	Spokane	Washington	3112891202983683834	ad20ceae5fc41bf65370ba0adcc2301e	Maestro	47.6284971323102724	-117.439184146923196
38779	2020-07-21 03:19:55	2020-07-21	Uriel Baumbach	uriel.baumbach@woohoo.com	Fort Worth	Texas	4160859975140273	b8a9edb6e47d1a2836fcf53c7f7ce788	Maestro	32.706883816566318	-97.4120436060063497
38780	2020-07-21 03:45:25	2020-07-21	Dr. Jeramiah Jacobs	dr.jeramiah.jacobs@geemail.com	Santa Rosa	California	3004257080162706	6112ff257655cf9a5d1f2fcf5b1c391b	Discover	38.4985779933754415	-122.637426660234482
38781	2020-07-21 03:46:55	2020-07-21	Miss Claudette Gulgowski	miss.claudette.gulgowski@geemail.com	Boston	Massachusetts	4779955332253875	37bc45594f681d8e3d4de9c9b236a4e1	Discover	42.4077441394496688	-71.1172975478645384
38782	2020-07-21 03:48:47	2020-07-21	Alta Hauck PhD	alta.hauck.phd@geemail.com	Detroit	Michigan	3158573587202239326	a153ec35b5eaada76f3651449433c1cb	JCB 15 digit	42.3321773621179176	-83.0311066769182702
38783	2020-07-21 04:24:14	2020-07-21	Mrs. Kathern Bode MD	mrs.kathern.bode.md@geemail.com	San Francisco	California	4065173182370624	612c20c340d5e9ad63cb264a6da1fe95	Discover	37.7778789042413194	-122.443963473699242
38784	2020-07-21 04:26:46	2020-07-21	Rayburn Reichert-Stoltenberg	rayburn.reichert.stoltenberg@geemail.com	Plano	Texas	4928739854547249	e4a06e8bf22bf4ec614751968f6a9f64	VISA 16 digit	33.0967894622676084	-96.8050333107072873
38785	2020-07-21 04:26:55	2020-07-21	Alzina Runte	alzina.runte@geemail.com	Atlanta	Georgia	52832122576297341	a65fed5c3c9ba668cb9639633afcfa9c	VISA 16 digit	33.6787610702026683	-84.3488748502962409
38786	2020-07-21 04:28:20	2020-07-21	Attie Crist	attie.crist@geemail.com	Chicago	Illinois	6011023218463670860	ffd81bc462a4350c8933c748d5f10407	Maestro	41.8556602697655578	-87.6783778058860435
38787	2020-07-21 04:44:31	2020-07-21	Augustina Thompson	augustina.thompson@geemail.com	Santa Rosa	California	4834047317930	358ece459f22a10dae76b2d6cf20dd30	VISA 16 digit	38.5221692352212983	-122.660626320332668
38788	2020-07-21 04:47:46	2020-07-21	Laverne Reichert	laverne.reichert@geemail.com	Portland	Oregon	4364421382380242	52c4916cabee09eaede2e44bb1b1436a	Maestro	45.4476406345497779	-122.553231029910975
38789	2020-07-21 04:48:02	2020-07-21	Jaden Maggio-Torp	jaden.maggio.torp@warmmail.com	Memphis	Tennessee	180074125741689257	9bcbeacc13f1ae9fcaa5de606e3a862d	Voyager	35.0766839874044081	-90.031295293548709
38790	2020-07-21 05:01:11	2020-07-21	Skip Durgan	skip.durgan@geemail.com	Arlington	Texas	3023854967117950	0637b7fc30c69e69ab81dfbf1840bd3e	Voyager	32.6087028694122978	-97.0354958720531329
38791	2020-07-21 05:09:28	2020-07-21	Braxton D'Amore	braxton.d'amore@geemail.com	Santa Clarita	California	4203044869935067	ca03c59f99eb42c64c8c942a023513c5	JCB 15 digit	34.4287447977084682	-118.588589057848594
38792	2020-07-21 05:23:16	2020-07-21	Ms. Lyndsay Collier	ms.lyndsay.collier@geemail.com	Huntington Beach	California	54164709479734087	bdf439418ac22feed1ca30d4b82ea1ef	Voyager	33.5973483366932726	-118.044347608893361
38793	2020-07-21 05:23:21	2020-07-21	Susanna Spencer	susanna.spencer@geemail.com	New York	New York	4354937515723232	27cf05af0e4c25de3a3f1299036e3832	Discover	40.6642018846925311	-73.9962847390107754
38794	2020-07-21 05:24:38	2020-07-21	Esequiel Blick I	esequiel.blick.i@geemail.com	New York	New York	3112987990334458584	31105b0d07d04708df6e00fba70ecc2a	VISA 16 digit	40.7210000865384956	-74.0210290539439768
38795	2020-07-21 05:33:42	2020-07-21	Miss Khadijah Hudson MD	miss.khadijah.hudson.md@woohoo.com	San Francisco	California	3450567484295644	a7ee4fea4ae0141a695cbf27f844d130	Maestro	37.789773311343609	-122.419943441300902
38796	2020-07-21 05:34:38	2020-07-21	Josephine Nolan	josephine.nolan@geemail.com	Allentown	Pennsylvania	589303641381292	e6d6991f9c5a131e05e6d6d43d2f0438	JCB 15 digit	40.6614711769636727	-75.3992623211365185
38797	2020-07-21 05:38:46	2020-07-21	Juwan Gorczany	juwan.gorczany@geemail.com	Salt Lake City	Utah	4262156103527241	abf242a1061e169c39a3d19bcef4b859	JCB 16 digit	40.8135467471234463	-111.980159062188122
38798	2020-07-21 05:49:40	2020-07-21	Mr. Tracey Ziemann	mr.tracey.ziemann@geemail.com	San Francisco	California	3096633299159088510	67ccac7723735847120f4a70d8d23e91	JCB 16 digit	37.7861596916265654	-122.424114245067102
38799	2020-07-21 05:54:50	2020-07-21	Jamila McGlynn	jamila.mcglynn@geemail.com	Clovis	California	3710120434664102	8744739269fad2f30835ab3026931235	VISA 16 digit	36.7340890806976716	-119.590964656423409
38800	2020-07-21 05:55:59	2020-07-21	Dereck Brakus	dereck.brakus@geemail.com	San Francisco	California	4385897040197	29ead52755a86f9bcca6d0e742abd802	JCB 16 digit	37.7706267109047289	-122.419919588376885
38801	2020-07-21 06:26:48	2020-07-21	Bethel Gislason III	bethel.gislason.iii@woohoo.com	Columbus	Georgia	54943513652245384	588516d30f98b528cd6b711758cc502e	Mastercard	32.6000046680260454	-84.9423011915922075
38802	2020-07-21 06:34:31	2020-07-21	Kirt Gulgowski-Gleason	kirt.gulgowski.gleason@geemail.com	New York	New York	4392509304772888	4d792dbd96a577a99b6af730280a4e89	VISA 13 digit	40.6506585608459972	-74.0379133953142912
38803	2020-07-21 06:38:43	2020-07-21	Denisha Towne-Doyle	denisha.towne.doyle@geemail.com	Seattle	Washington	4318563465479040	6bf83f0b8295486ccde7be643c1d434e	VISA 16 digit	47.5590557364206745	-122.341095893077181
38804	2020-07-21 06:40:08	2020-07-21	Dr. Elia Gerhold	dr.elia.gerhold@woohoo.com	High Point	North Carolina	4122110993638808	83fbb54b4e6891960d1fa29776f6565e	Voyager	36.0206121702305992	-79.960586324773729
38805	2020-07-21 06:42:41	2020-07-21	Mrs. Olevia Wiza	mrs.olevia.wiza@geemail.com	Sacramento	California	3528087700656419539	8660c4c42b30b95d7024b3d6f636f0a0	VISA 16 digit	38.609051002541932	-121.469733200945328
38806	2020-07-21 06:43:15	2020-07-21	Bennie Swift DDS	bennie.swift.dds@warmmail.com	New York	New York	52559665966468311	d6ec75303e43b76073dea4f691a96898	Discover	40.5876563372779628	-74.0315888367023263
38807	2020-07-21 06:52:54	2020-07-21	Miss Elmira Bode	miss.elmira.bode@woohoo.com	Jacksonville	Florida	54606582988638586	a4234f9f4635538e6c353349ff4bbaef	VISA 16 digit	30.3917672412987798	-81.6328069994770118
38808	2020-07-21 06:58:52	2020-07-21	Alton Kohler	alton.kohler@geemail.com	Bakersfield	California	55265161854807740	aad5b12919a510faabbab5e73b83d26b	Diners Club / Carte Blanche	35.3698102502327387	-119.082235247110205
38809	2020-07-21 07:00:41	2020-07-21	Del Abernathy DVM	del.abernathy.dvm@geemail.com	San Francisco	California	676232149986179	a156ef91bf0832a6b5f20dc3adb75fb3	JCB 16 digit	37.7945801427736896	-122.4755816520222
38810	2020-07-21 07:01:35	2020-07-21	Kyla Stanton MD	kyla.stanton.md@woohoo.com	San Antonio	Texas	869935149054351386	2df8af73b72391528ce97fa68fcfa62c	VISA 16 digit	29.4918084702990946	-98.6206984014086316
38811	2020-07-21 07:01:57	2020-07-21	Dessie Barton	dessie.barton@geemail.com	Virginia Beach	Virginia	4763253373461450	b98cf3f7413ef966368e530975b08fd8	American Express	36.8380651411321054	-76.0982908395256885
38812	2020-07-21 07:08:10	2020-07-21	Emilio Ankunding	emilio.ankunding@woohoo.com	San Francisco	California	869903542526938608	3f8a84e4f896fecfef32350054f573b3	JCB 16 digit	37.7655597711839519	-122.426728258100937
38813	2020-07-21 07:13:00	2020-07-21	Georgia Miller-Hegmann	georgia.miller.hegmann@warmmail.com	Santa Ana	California	4921566450083	fa052f06d3c8f11e1708caf7295e3e31	American Express	33.6527669275749446	-117.89903547683916
38814	2020-07-21 07:17:59	2020-07-21	Dr. Webster Rowe	dr.webster.rowe@geemail.com	New York	New York	4740427527826127	081d79003a5bddb5d59ef7e6a8fa4911	VISA 13 digit	40.7022654095888115	-73.9815508337121486
38815	2020-07-21 07:20:37	2020-07-21	Lexi Powlowski	lexi.powlowski@geemail.com	San Francisco	California	3088381987564317037	841c6c329199bbcc1a61ad8ad5674c8d	American Express	37.8092623389112106	-122.454644475800052
38816	2020-07-21 07:26:36	2020-07-21	Kirby Huels	kirby.huels@warmmail.com	San Antonio	Texas	869939316908262756	3e78c83344bb4bced5fba649f30dda88	Discover	29.395067655209079	-98.4432867084465926
38817	2020-07-21 07:29:04	2020-07-21	Anjanette Hills DDS	anjanette.hills.dds@geemail.com	Cambridge	Massachusetts	6011666918737347623	008ec9397ea3764bdd15ae5cd869b58e	JCB 15 digit	42.2857202277742275	-71.0336663906078769
38818	2020-07-21 07:35:51	2020-07-21	Vincent Kessler-Zemlak	vincent.kessler.zemlak@geemail.com	Memphis	Tennessee	210034226448562992	c3b0588927c7198da9650b44cbed5b51	Voyager	35.0136434255234903	-89.9550766730006757
38819	2020-07-21 07:49:27	2020-07-21	Trumaine Hyatt	trumaine.hyatt@warmmail.com	Miami	Florida	4741807248360093	1bda540a4b3d904f3d16a1c60895ea62	American Express	25.8466197937399151	-80.1545993058815611
38820	2020-07-21 07:53:14	2020-07-21	Dr. Collie Baumbach MD	dr.collie.baumbach.md@woohoo.com	Pembroke Pines	Florida	3088035367650663430	b78664a60d6531e33e6614454dee7123	JCB 16 digit	25.9261625791471459	-80.263464100602647
38821	2020-07-21 07:53:36	2020-07-21	Mrs. Carisa Steuber PhD	mrs.carisa.steuber.phd@woohoo.com	Pomona	California	180015569183647228	0f998951feb580575556bf7282e40dfa	Mastercard	33.9682776019480102	-117.727887396371358
38822	2020-07-21 07:56:15	2020-07-21	Miss Virdie Ebert MD	miss.virdie.ebert.md@geemail.com	Davie	Florida	3088110620862841402	f68cf600610ea04d908c847daee9f981	American Express	26.0373723718602221	-80.2252075961232123
38823	2020-07-21 08:03:45	2020-07-21	Bernardo Crona	bernardo.crona@geemail.com	New York	New York	6011356589083031593	3de62168aeeecf3a0b3871995dcc0347	JCB 16 digit	40.7146003467254332	-73.8620020193874751
38824	2020-07-21 08:09:01	2020-07-21	Lenord Moore	lenord.moore@geemail.com	Houston	Texas	4370113794249	a54ae512ffd00aa9388f7abe6e7ba1fb	Voyager	29.7358647489532828	-95.4731885026689611
38825	2020-07-21 08:13:39	2020-07-21	Mrs. Dafne Bogan PhD	mrs.dafne.bogan.phd@warmmail.com	New York	New York	3005265759866555	cfc820f63eccaa2406b14eb3a764e58f	Maestro	40.5928773553334139	-73.9242848354287361
38826	2020-07-21 08:22:41	2020-07-21	Gabrielle Smitham DVM	gabrielle.smitham.dvm@woohoo.com	San Diego	California	869917522803048630	6db832939fe1877d995264496e0602c5	JCB 16 digit	32.7194707694530464	-117.120317414905884
38827	2020-07-21 08:24:22	2020-07-21	Ms. Sarah Will	ms.sarah.will@geemail.com	Los Angeles	California	4147345335458	bae3932eacaa921b102b82dff438cdfc	JCB 16 digit	33.9865225645579372	-118.347770047140486
38828	2020-07-21 08:25:41	2020-07-21	Paxton Tillman	paxton.tillman@geemail.com	San Jose	California	3031355374836135	9424ded1187a159e9dc6e03de6a176e0	JCB 15 digit	37.2747489289201823	-121.8537350060638
38829	2020-07-21 08:29:36	2020-07-21	Ossie Strosin	ossie.strosin@geemail.com	Hillsboro	Oregon	180027972135123205	8eb6219a2f6b2661c313d021fc14f8b8	VISA 16 digit	45.547646236766127	-122.948116762439525
38830	2020-07-21 08:30:02	2020-07-21	Yolanda Bradtke	yolanda.bradtke@geemail.com	Los Angeles	California	503849991836849	a4dc70d2638bd06f9b19200e7c3a35cd	JCB 16 digit	33.9819120869372	-118.357709008594227
38831	2020-07-21 08:34:12	2020-07-21	Tatum Walter-Jacobson	tatum.walter.jacobson@geemail.com	Peoria	Arizona	060493267486335	cc5f156d10a11b17d8dabc846e1404a7	JCB 16 digit	33.8758686742082276	-112.368043402854354
38832	2020-07-21 08:36:29	2020-07-21	Mr. Babe O'Hara V	mr.babe.o'hara.v@warmmail.com	Glendale	California	3728432356058837	6188e88cfb8cdc2d0a3fc54d10f77af9	Mastercard	34.1285406261902295	-118.158523439186808
38833	2020-07-21 08:40:08	2020-07-21	Melodee Bauch	melodee.bauch@warmmail.com	Warren	Michigan	210085179593167588	39accb73b801d975e9f0c9f999a0b431	JCB 16 digit	42.5107314397111509	-83.0598648210056183
38834	2020-07-21 08:41:13	2020-07-21	Robyn Marks	robyn.marks@geemail.com	Denver	Colorado	3096040581056927099	9bae3b80d90cb0e7570f962cbb9593c7	VISA 16 digit	39.759967080322653	-104.876740748180453
38835	2020-07-21 08:45:42	2020-07-21	Mr. Redden Walsh	mr.redden.walsh@geemail.com	Vancouver	Washington	210037989314129488	422972dd27d3efcac2fd191bd77099f8	VISA 16 digit	45.6713316490944479	-122.610315584257989
38836	2020-07-21 08:48:17	2020-07-21	Daxton Kozey	daxton.kozey@geemail.com	New York	New York	4711075874271770	421a558991640e7e339d107e3b9827c1	Discover	40.6328328083958468	-73.9957901322644176
38837	2020-07-21 08:54:42	2020-07-21	Aniya Gibson	aniya.gibson@geemail.com	Berkeley	California	3732691907054769	05b19dab14eef8c2e5b0a382368ced96	JCB 16 digit	37.9182800254351235	-122.258267389832383
38838	2020-07-21 08:55:42	2020-07-21	Layton Nicolas	layton.nicolas@geemail.com	Oakland	California	4449097171993517	b796020a17e2fd3e34d808e3e6ad8d07	VISA 16 digit	37.8299566324270913	-122.257806065202701
38839	2020-07-21 09:04:10	2020-07-21	Regena Adams	regena.adams@warmmail.com	New York	New York	4105776144416681	fda2f29d334f67d3e6ba072a11203424	VISA 13 digit	40.6332596611455088	-73.9058057394239967
38840	2020-07-21 09:04:24	2020-07-21	Dr. Mekhi Bergnaum MD	dr.mekhi.bergnaum.md@geemail.com	Lakewood	Colorado	4854978314007216	cf3817eeee1951e0134fda77b9295ffb	American Express	39.6609599063113336	-105.156439499000456
38841	2020-07-21 09:09:06	2020-07-21	Bonita Halvorson DVM	bonita.halvorson.dvm@geemail.com	Los Angeles	California	3337727641302553196	48527418d825c7fca81c9aacf2f3c0f0	JCB 15 digit	33.9987899686541368	-118.324712886427704
38842	2020-07-21 09:10:45	2020-07-21	Rusty Bradtke	rusty.bradtke@geemail.com	New York	New York	3112808613223115944	4e7a317927fdf128e5fa6bcffeab527a	JCB 16 digit	40.6349191488921662	-73.9494981616631151
38843	2020-07-21 09:17:30	2020-07-21	Cortez Trantow	cortez.trantow@woohoo.com	Everett	Washington	180093700377065902	a81210159869c1a835c2af0e598ef50b	JCB 15 digit	47.9681143159870089	-122.156963835948702
38844	2020-07-21 09:19:33	2020-07-21	Harris Schumm Jr.	harris.schumm.jr.@geemail.com	Oakland	California	53574461489823278	aa97147e715b5b08f43ffaa6c217fc68	American Express	37.7869433079042878	-122.27196514027905
38845	2020-07-21 09:31:46	2020-07-21	Miss Lucetta Hammes MD	miss.lucetta.hammes.md@geemail.com	Columbus	Ohio	180060656321265460	7f840c55a75ba9481550969dc96410c9	JCB 16 digit	39.9130538538143043	-82.9524755655557016
38846	2020-07-21 09:32:48	2020-07-21	Mr. Lora Marquardt Jr.	mr.lora.marquardt.jr.@geemail.com	Bakersfield	California	3528702515749018592	e6a9b2c3b7e609c1dcb95d12140b1cfe	Maestro	35.3485291180375967	-118.955369483846425
38847	2020-07-21 09:39:26	2020-07-21	Ginny Beer	ginny.beer@warmmail.com	Chicago	Illinois	55769498813251482	c46b8989e734856bc9a665a225ddfd74	VISA 13 digit	41.8456692422110592	-87.69134219242558
38848	2020-07-21 09:54:24	2020-07-21	Mr. Cain Harvey III	mr.cain.harvey.iii@woohoo.com	Los Angeles	California	6011084443405719874	3a190c5ba7b964aea1e01ee6ad54f9e3	JCB 15 digit	33.9546353212889258	-118.334056045766175
38849	2020-07-21 10:03:54	2020-07-21	Luverne Prosacco	luverne.prosacco@geemail.com	Berkeley	California	3528494020568358015	483428bddc645681acb2e3b49051ec80	Discover	37.8737049616073165	-122.290175768905272
38850	2020-07-21 10:13:05	2020-07-21	Kermit Frami	kermit.frami@geemail.com	New York	New York	3112323902738652343	212f96e6679421941922598e03edf02f	VISA 16 digit	40.7488315028361967	-73.8923854158155535
38851	2020-07-21 10:21:58	2020-07-21	Bobbi Nader	bobbi.nader@geemail.com	San Francisco	California	55516971794000199	cadb88023ebabc8a4bf86f63582a1f10	JCB 16 digit	37.7966868131105471	-122.412935764855163
38852	2020-07-21 10:45:06	2020-07-21	Adina Hudson	adina.hudson@geemail.com	New York	New York	3337297516142297255	2a9ec90e5052f0a7f8f14605e554896c	Diners Club / Carte Blanche	40.6577483077291362	-73.9003361255291793
38853	2020-07-21 10:55:33	2020-07-21	Rahul Thompson I	rahul.thompson.i@warmmail.com	St. Louis	Missouri	3055658914248208	2216f1228b8150f01c3d7ab5ee5882ee	JCB 16 digit	38.5539790864258975	-90.1754487641625104
38854	2020-07-21 10:55:46	2020-07-21	Mrs. Marybeth Rutherford PhD	mrs.marybeth.rutherford.phd@geemail.com	Brownsville	Texas	6011870227463015566	70b4a4b5ebe960c6f973b264de80da01	JCB 16 digit	26.002259868298097	-97.4092620155029039
38855	2020-07-21 10:58:44	2020-07-21	Arlyn Muller-Hane	arlyn.muller.hane@geemail.com	Clarksville	Tennessee	210024770847022100	b1d855b44b7883258c201ffb5ee057a9	Voyager	36.570211153676361	-87.3738468277219766
38856	2020-07-21 11:01:48	2020-07-21	Dr. Adelbert Botsford IV	dr.adelbert.botsford.iv@warmmail.com	Amarillo	Texas	3112311738560354671	f242be10e06d0cf0fbc729645f31f2a0	JCB 16 digit	35.2258226627647844	-101.837373431944101
38857	2020-07-21 11:04:04	2020-07-21	Mrs. Kattie Cormier MD	mrs.kattie.cormier.md@woohoo.com	San Francisco	California	6011260597122239692	2601b34e43478f2f09fbbc10ae6a77dd	Maestro	37.7752179750960764	-122.438644612782525
38858	2020-07-21 11:08:12	2020-07-21	Collins Stokes-Konopelski	collins.stokes.konopelski@woohoo.com	Los Angeles	California	6011278755704914591	c82b4b91050ae3b9c1fb5fb31f97bf5c	VISA 13 digit	33.9194032572075699	-118.405146050498999
38859	2020-07-21 11:30:59	2020-07-21	Hernan Gorczany	hernan.gorczany@geemail.com	New York	New York	4888456452932230	892eecfcae120a664b560b4c8abdff4a	VISA 16 digit	40.7628749101646264	-73.852295558982334
38860	2020-07-21 11:35:46	2020-07-21	Braulio Deckow	braulio.deckow@woohoo.com	Detroit	Michigan	3055512888072575	aca9bd70e5779b1a1bc0873cc8a561f1	Maestro	42.4321208437364561	-83.0658476928833807
38861	2020-07-21 11:42:41	2020-07-21	Nelle Abshire	nelle.abshire@woohoo.com	Chicago	Illinois	589387233893269	7a1107eb029c570d7d9f8da1d0da63c7	Discover	41.9254562905825665	-87.6247140997119232
38862	2020-07-21 11:48:22	2020-07-21	Gerry Klocko	gerry.klocko@geemail.com	Hartford	Connecticut	3417535619686385	de3e3cc338e519acbfce89eee1086c32	Voyager	41.7642271315693847	-72.7809820125702771
38863	2020-07-21 11:52:14	2020-07-21	Minoru Kshlerin-Ritchie	minoru.kshlerin.ritchie@geemail.com	Scottsdale	Arizona	4200192497619182	72b1fa8b279a199fb5b4b9e1d5ba3155	JCB 15 digit	33.6091019614722555	-111.960394232483949
38864	2020-07-21 11:56:23	2020-07-21	Ivette Gottlieb	ivette.gottlieb@geemail.com	Arvada	Colorado	4485586104445657	5c48e3a9a5718b450b6ce14fa0ffcd97	JCB 16 digit	39.789494558115301	-105.133939417123045
38865	2020-07-21 12:12:51	2020-07-21	Keshawn VonRueden	keshawn.vonrueden@geemail.com	Los Angeles	California	6011224266387479857	728a1f48d430b854a8ae7f6aeeca7dce	VISA 16 digit	33.963070991435643	-118.417595651605353
38866	2020-07-21 12:18:50	2020-07-21	Shayne Bartell	shayne.bartell@warmmail.com	Minneapolis	Minnesota	3021247942090412	19f132400b8e578553844bd59bdf7550	Mastercard	45.0506804230242963	-93.1761080633189493
38867	2020-07-21 12:22:19	2020-07-21	Flora Kilback	flora.kilback@geemail.com	Dallas	Texas	53383627768251602	6fa4170ff29a646b3921c21557527f90	JCB 16 digit	32.7330089407313665	-96.7256827248223061
38868	2020-07-21 12:29:46	2020-07-21	Mattie Trantow	mattie.trantow@geemail.com	Jacksonville	Florida	4224960621334460	5c0d531f1cb58abba315234d5ea851a0	Diners Club / Carte Blanche	30.4367055017087615	-81.5679634310383364
38869	2020-07-21 12:36:47	2020-07-21	Alvaro Schuppe-Lindgren	alvaro.schuppe.lindgren@woohoo.com	Cincinnati	Ohio	3038957150474396	82c9972e6aaf3d7d27d41d1248c08723	American Express	39.0511640466515004	-84.4355884182538716
38870	2020-07-21 12:40:10	2020-07-21	Tori Heaney	tori.heaney@woohoo.com	Tyler	Texas	3158312397220794583	bcbfa52b023d7d06f46d69ad4caa657a	Maestro	32.2255404823508158	-95.2286643853984742
38871	2020-07-21 12:49:48	2020-07-21	Nakia Crist	nakia.crist@geemail.com	West Valley City	Utah	3158502991101409558	c3c9507f8d86944308c85abd1ccf8fe8	American Express	40.6607094764467334	-111.942525293839338
38872	2020-07-21 12:52:12	2020-07-21	Roselyn Denesik-Wolf	roselyn.denesik.wolf@woohoo.com	Houston	Texas	869941084338010544	4c30d927556923a3cc2fd81201ff9dbc	Diners Club / Carte Blanche	29.8381843031927936	-95.3705072895638608
38873	2020-07-21 12:52:58	2020-07-21	Paisley Emard	paisley.emard@geemail.com	Austin	Texas	675903530158736	b09cad1cd240d3674694471d007d4b61	Voyager	30.3722551903348403	-97.7178339055046479
38874	2020-07-21 13:04:22	2020-07-21	Pearly McKenzie	pearly.mckenzie@geemail.com	Berkeley	California	4081770431174861	5d51c40ffbc3bcbe499fb51e6a7209df	VISA 16 digit	37.8554467040089833	-122.270600372652524
38875	2020-07-21 13:11:00	2020-07-21	Mr. Williard Hane I	mr.williard.hane.i@geemail.com	College Station	Texas	3038919513027139	200ace93de04a37eb776e4bad406390c	JCB 16 digit	30.5473562091633681	-96.391881538865718
38876	2020-07-21 13:11:51	2020-07-21	Howell VonRueden-Purdy	howell.vonrueden.purdy@warmmail.com	New York	New York	180059224608787368	9d45f224c7a55b132459145a2dc28ec7	JCB 16 digit	40.6897153256684518	-73.9421867922775391
38877	2020-07-21 13:24:05	2020-07-21	Jereme Flatley-Murphy	jereme.flatley.murphy@geemail.com	Arlington	Texas	6011234949252455544	75caacded07f93cf94757e092a23024e	Discover	32.7711587397165545	-97.1610010757137132
38878	2020-07-21 13:25:17	2020-07-21	Jody Abshire DVM	jody.abshire.dvm@geemail.com	Oakland	California	3528883578801847903	07d9ca880181cdf49ec0a393390f278f	American Express	37.8231233119688852	-122.275732009331804
38879	2020-07-21 13:27:11	2020-07-21	Vickey Labadie	vickey.labadie@geemail.com	San Francisco	California	4049448107423117	de52243077f50512a21823257f4e3283	VISA 16 digit	37.8182493942997411	-122.487982488219501
38880	2020-07-21 13:44:11	2020-07-21	Kieran Keeling Jr.	kieran.keeling.jr.@geemail.com	Ann Arbor	Michigan	676137611495682	eb0b934ad8e6ee5d93edefdade4e5c66	Diners Club / Carte Blanche	42.2350115017093728	-83.8021156181223716
38881	2020-07-21 13:45:17	2020-07-21	Rilla Shields	rilla.shields@geemail.com	San Francisco	California	4735578244672736	8af46719462c8156f9dd89e1b2dc69bc	VISA 16 digit	37.7865548061552516	-122.427819557408057
38882	2020-07-21 13:45:30	2020-07-21	Dr. Sigmund Dare DVM	dr.sigmund.dare.dvm@geemail.com	San Antonio	Texas	3528094621166851063	b1feb98232074f592493adf99d64add5	VISA 16 digit	29.5061184010539215	-98.5539665622938372
38883	2020-07-21 13:55:18	2020-07-21	Mr. Leslie Jacobs	mr.leslie.jacobs@woohoo.com	San Jose	California	3723774328532265	cd12934253e8e353dc58c3dab58f69d0	Voyager	37.27306331887916	-121.881282173771041
38884	2020-07-21 13:56:57	2020-07-21	Stephen Davis	stephen.davis@geemail.com	Berkeley	California	3055028966243434	1250fa30ea7080ef6577e0b5cd12fbe0	Mastercard	37.8325833865645933	-122.273849895136024
38885	2020-07-21 13:57:31	2020-07-21	Cordella Littel-Bogan	cordella.littel.bogan@geemail.com	Abilene	Texas	3158156803176628484	70b517504a2972f0eba26c863fd92c5c	JCB 16 digit	32.4807550562154503	-99.6487362340040477
38886	2020-07-21 14:01:30	2020-07-21	Nicki Crona	nicki.crona@warmmail.com	Kent	Washington	4494324651111	5957af1670a632ed9f29fc970f19cf04	Mastercard	47.4233925656061572	-122.257279302798949
38887	2020-07-21 14:10:11	2020-07-21	Hart Orn	hart.orn@geemail.com	Chicago	Illinois	180006097127958833	43c956c886d32effa3204cde15d93a81	VISA 16 digit	41.8511040621273267	-87.6026961551543337
38888	2020-07-21 14:13:48	2020-07-21	Frieda Feil	frieda.feil@geemail.com	Kansas City	Missouri	55407598105905170	efc6a98b40ffa844bb4dd0fd3b74ce82	VISA 16 digit	39.1170801865704405	-94.5745026869457206
38889	2020-07-21 14:17:57	2020-07-21	Miss Martine Von	miss.martine.von@geemail.com	Oakland	California	54696488392683963	e3e8b1a4b201dd9a4c824483884bd9d8	VISA 13 digit	37.7731894503765631	-122.284864191956046
38890	2020-07-21 14:27:51	2020-07-21	Pleasant Nikolaus-Pfeffer	pleasant.nikolaus.pfeffer@woohoo.com	Sacramento	California	4507379463320	713ee510c6a259d4c11977eb0e760cdc	Voyager	38.5535108583312507	-121.484170914279659
38891	2020-07-21 14:28:10	2020-07-21	Mrs. Bertina Skiles	mrs.bertina.skiles@geemail.com	Hialeah	Florida	502098250518671	22e4a33ce8bd36d74baf206b072b9adf	Diners Club / Carte Blanche	25.8374939555745584	-80.3870357592027602
38892	2020-07-21 14:32:27	2020-07-21	Yuridia Cartwright	yuridia.cartwright@woohoo.com	Oakland	California	4488016609171	751f9a5cb6048a984c57c021cb0a3b10	VISA 13 digit	37.8157046520731512	-122.276821682689345
38893	2020-07-21 14:41:51	2020-07-21	Mr. Marlin Lesch DDS	mr.marlin.lesch.dds@woohoo.com	Los Angeles	California	3112431530394900182	7f760b00e1a4fd287d4564614170ecaa	VISA 16 digit	34.0513622764363859	-118.479706026799221
38894	2020-07-21 14:51:21	2020-07-21	Darwin Douglas V	darwin.douglas.v@geemail.com	Baltimore	Maryland	6011016323318114467	091cd0881216213ce40860d70df5061a	JCB 16 digit	39.2551460761576863	-76.5549245611317417
38895	2020-07-21 14:52:44	2020-07-21	Denny Lubowitz	denny.lubowitz@geemail.com	Richardson	Texas	3011911741050816	39a2ec21f11ecc6a272fd61741033385	JCB 15 digit	33.0431885876927467	-96.7337846126634702
38896	2020-07-21 15:21:36	2020-07-21	Adah Rau-Sporer	adah.rau.sporer@warmmail.com	Surprise	Arizona	6011080580347899621	410c13754f61795a8d0a5e62f089b3b7	Maestro	33.6178262214869292	-112.433054992672794
38897	2020-07-21 15:30:04	2020-07-21	Tiesha Larkin DVM	tiesha.larkin.dvm@woohoo.com	San Francisco	California	53773181127355678	233c9173cb6152f8a1fd9e1f1d265e41	American Express	37.748924098145892	-122.437545380912567
38898	2020-07-21 15:36:23	2020-07-21	Emanuel Volkman-Jakubowski	emanuel.volkman.jakubowski@woohoo.com	Las Vegas	Nevada	6011761632273183367	4560ec63d01022d80a38e6418e8e64bb	JCB 15 digit	36.1633742226388293	-115.251490293370921
38899	2020-07-21 15:38:14	2020-07-21	Dr. Daisy Hayes	dr.daisy.hayes@geemail.com	Augusta	Georgia	53677214842480351	409e849ad366515cb99ef621a376691b	Mastercard	33.2940743972286555	-82.0968261011704925
38900	2020-07-21 15:46:58	2020-07-21	Demarcus Marquardt	demarcus.marquardt@warmmail.com	Tampa	Florida	6011390739795613869	319cafc485e35c881cfca1683d10bee3	VISA 13 digit	28.0154532947227359	-82.5742517453364968
38901	2020-07-21 15:47:22	2020-07-21	Adriel Wyman	adriel.wyman@geemail.com	Waco	Texas	589307337684158	613a24804d3e72cb58771291875989e5	VISA 16 digit	31.5918118520382762	-97.2737772842533985
38902	2020-07-21 15:48:31	2020-07-21	Bryson Sawayn DVM	bryson.sawayn.dvm@geemail.com	Naperville	Illinois	3029254025393459	4dfe13c5c9b776e470922b6bdbccbeb9	American Express	41.7623051223259409	-88.2318547728359732
38903	2020-07-21 15:49:31	2020-07-21	Mr. Bynum Littel III	mr.bynum.littel.iii@warmmail.com	Garland	Texas	52023705758369661	b787bd5014f2c73d5ad2cb36ca221866	VISA 16 digit	33.0006148889429838	-96.7150732683178092
38904	2020-07-21 15:56:19	2020-07-21	Rodger Ruecker	rodger.ruecker@warmmail.com	Tulsa	Oklahoma	3096014067705871849	f72ef7c12f204f2d24ddd15453eb92a1	VISA 16 digit	36.1555835071388572	-95.8592343704264636
38905	2020-07-21 16:09:08	2020-07-21	Ms. Alysha Hackett MD	ms.alysha.hackett.md@geemail.com	Aurora	Illinois	869967758292425942	2a8aea4deb872e7ed8f19b1352491d79	VISA 16 digit	41.78801179525815	-88.3521655096135987
38906	2020-07-21 16:10:31	2020-07-21	Shirley Rowe III	shirley.rowe.iii@woohoo.com	Visalia	California	869939295411888978	a09280f116f926aebc15912db8a4eab0	JCB 15 digit	36.3311244761992285	-119.275882625452809
38907	2020-07-21 16:15:53	2020-07-21	Mrs. Rhonda Stark DDS	mrs.rhonda.stark.dds@geemail.com	Omaha	Nebraska	3158288112464290150	5dec724651eff224d3a79f2400fe9faa	JCB 15 digit	41.319261384956171	-96.0141840114839482
38908	2020-07-21 16:20:54	2020-07-21	Mr. Casper Christiansen	mr.casper.christiansen@warmmail.com	Austin	Texas	4000339857751574	65c1cf769f8799b0860e40c6af255ea8	Discover	30.2575942055914524	-97.7787051307741564
38909	2020-07-21 16:23:55	2020-07-21	Latonya Crist DDS	latonya.crist.dds@geemail.com	Amarillo	Texas	3446387229400103	18a903cae9c5b10ec07666e9510d0536	VISA 16 digit	35.1765279148403565	-101.793331389534103
38910	2020-07-21 16:29:17	2020-07-21	Lula Predovic-Hilll	lula.predovic.hilll@woohoo.com	Washington	District of Columbia	676143232994384	c0d78e6f0373def45eb689643bae55fb	VISA 16 digit	38.9440490060284716	-77.0030244243543649
38911	2020-07-21 16:36:32	2020-07-21	Arvin O'Connell V	arvin.o'connell.v@warmmail.com	Phoenix	Arizona	676224818363103	3a9023f0472ccd65468f4f03548d43e1	Discover	33.581649790138755	-112.149450667055703
38912	2020-07-21 16:40:25	2020-07-21	Osie Parker	osie.parker@geemail.com	San Francisco	California	676123401659810	b52d2a0bc4dbddf704d0c4377b7d7ef0	Diners Club / Carte Blanche	37.7975163323087315	-122.418889886198897
38913	2020-07-21 16:44:05	2020-07-21	Stacey Farrell	stacey.farrell@geemail.com	Woodbridge	New Jersey	3033772621495531	7d502aa7e4a5c76480b17f7492ff8fb1	JCB 15 digit	40.5695265643455087	-74.30758533434458
38914	2020-07-21 16:47:22	2020-07-21	Kaylee Wilkinson	kaylee.wilkinson@geemail.com	New York	New York	3763058592521183	bf1c28d14eb7e359c08f98539e4c6817	VISA 16 digit	40.6724679400902218	-73.9371657518565684
38915	2020-07-21 16:59:19	2020-07-21	Amelie Hermann DVM	amelie.hermann.dvm@geemail.com	Tampa	Florida	3158584691299713800	d289dae6feea9a29029081a4a65d41db	VISA 16 digit	28.060403091052919	-82.4051807997960566
38916	2020-07-21 17:07:03	2020-07-21	Dr. Cedrick Boyer II	dr.cedrick.boyer.ii@woohoo.com	Houston	Texas	675934950616127	6825a82952c63d4efe6f080b4f5bc1d9	JCB 16 digit	29.7493501267008469	-95.3592210432995131
38917	2020-07-21 17:17:22	2020-07-21	Katarina Feest	katarina.feest@geemail.com	Berkeley	California	3096203877769241171	9ceb71b71c3b2afbcffff1048845c0d9	JCB 16 digit	37.8691599319996968	-122.281573199129525
38918	2020-07-21 17:20:54	2020-07-21	Lura Walker	lura.walker@woohoo.com	Brownsville	Texas	3054201761950617	f273f687cd5c8db89f89c317b3595f07	VISA 13 digit	25.950040395658835	-97.4003446724917694
38919	2020-07-21 17:26:26	2020-07-21	Christina Boyle	christina.boyle@geemail.com	Pembroke Pines	Florida	4404147017744138	b21b2c5181f18a077e04a146cad8a5ef	VISA 13 digit	25.9931513277385378	-80.4157481912892393
38920	2020-07-21 17:30:27	2020-07-21	Adeline Fahey PhD	adeline.fahey.phd@geemail.com	North Las Vegas	Nevada	3009889745101763	4deb791792f61a25e7708d3c2f6518fe	JCB 15 digit	36.323292366756867	-115.068956615145879
38921	2020-07-21 17:35:12	2020-07-21	Dr. Aidyn Gislason	dr.aidyn.gislason@geemail.com	Lexington	Kentucky	3760934580435383	f1a9a5475a636550f6bd42a4d23aee89	VISA 16 digit	38.1309397361118343	-84.4100802040558307
38922	2020-07-21 17:37:04	2020-07-21	Camille Greenholt-Fay	camille.greenholt.fay@geemail.com	Philadelphia	Pennsylvania	4805955657492098	110f0ecd6d50f070c3dc7cda4bf4bc6c	VISA 16 digit	39.9941642301581766	-75.0855689784877001
38923	2020-07-21 17:45:46	2020-07-21	Lonzo Runolfsson	lonzo.runolfsson@geemail.com	Lexington	Kentucky	3112998367637257160	126f31faff75ca7b1df3994a54c6ab97	JCB 16 digit	38.0626777185469862	-84.469712411928171
38924	2020-07-21 17:47:44	2020-07-21	Stephan Collins	stephan.collins@geemail.com	Las Vegas	Nevada	4087506046207	8f173f391313f96f17c3c9c424d20ee0	Mastercard	36.3103855158768596	-115.296411844736326
38925	2020-07-21 18:03:36	2020-07-21	Harman Zieme-Senger	harman.zieme.senger@geemail.com	San Francisco	California	6011654565720047811	b498ea3ecea3e9bb891cefe0d3fa3482	American Express	37.7855334743787026	-122.457480920546487
38926	2020-07-21 18:10:07	2020-07-21	Brice Effertz	brice.effertz@geemail.com	Los Angeles	California	6011083457729554016	d18a88b761f7ee23f5153eda7de2177c	Voyager	34.0981605849560339	-118.417899320460108
38927	2020-07-21 18:24:36	2020-07-21	Claire Spinka MD	claire.spinka.md@warmmail.com	New Haven	Connecticut	3337596946694371836	e4ecf0b6e8a07d0942248aae1ff7edde	Voyager	41.3345498994451006	-72.9704072124790315
38928	2020-07-21 18:24:41	2020-07-21	Fronia Jerde	fronia.jerde@geemail.com	San Antonio	Texas	210097245592704261	94de8a99b2e623ca25c2c1bba0ca4d9e	JCB 16 digit	29.5244561207085852	-98.6102356135681219
38929	2020-07-21 18:31:25	2020-07-21	Addie Hilpert	addie.hilpert@woohoo.com	Houston	Texas	4641050211003	b01fbeb4d5ddc77400fe07ee8dd3a694	Mastercard	29.7160568929355584	-95.3248412400499063
38930	2020-07-21 18:32:59	2020-07-21	Gaston Carter-Osinski	gaston.carter.osinski@warmmail.com	Phoenix	Arizona	4647909251316692	3c3a3d34a53ab570563a267f7dea12c4	VISA 16 digit	33.6429636507693672	-111.998226023923991
38931	2020-07-21 18:37:33	2020-07-21	Mrs. Lara Pfeffer	mrs.lara.pfeffer@geemail.com	Columbus	Georgia	4344571650169	63a8d7ad02418169da11b20db908589e	VISA 13 digit	32.4524246329020656	-84.7817171058315751
38932	2020-07-21 18:38:52	2020-07-21	Mckenzie Wehner	mckenzie.wehner@warmmail.com	Nashville	Tennessee	3337191404803156952	646826e41322673f8051a9703dd2d88a	Voyager	36.2548614767502997	-86.7329734128340988
38933	2020-07-21 18:41:29	2020-07-21	Mr. Yaakov Gerhold	mr.yaakov.gerhold@geemail.com	Tulsa	Oklahoma	3528333382712664432	dc8c13f71c6a4a2c21027bab624932c3	Diners Club / Carte Blanche	36.1805724853552846	-95.8256819562941757
38934	2020-07-21 18:47:02	2020-07-21	Allyn Marvin DDS	allyn.marvin.dds@woohoo.com	New York	New York	3088063065809803809	8ff304e3c72e5eece0f4f5ede4029c6c	American Express	40.6883406432569004	-73.9158291236858815
38935	2020-07-21 18:49:46	2020-07-21	Mr. Kendal Monahan	mr.kendal.monahan@warmmail.com	San Antonio	Texas	4806905049848191	88b6cd3e07207932da6944a342749119	American Express	29.5533352730866525	-98.446232817072783
38936	2020-07-21 19:04:04	2020-07-21	Talen Mills	talen.mills@woohoo.com	Corpus Christi	Texas	4521222552056	ff1ea1163319c0491fa4caff84c60e19	Discover	27.8060982056364416	-97.1843900954179531
38937	2020-07-21 19:05:18	2020-07-21	Mitchel Ankunding	mitchel.ankunding@woohoo.com	Los Angeles	California	3432356874733932	1116c5eb6574a20971210c7508a4d783	VISA 13 digit	33.9701071843836431	-118.509156846859668
38938	2020-07-21 19:09:38	2020-07-21	Dr. Tuan Leuschke	dr.tuan.leuschke@geemail.com	Arlington	Texas	3096638912964594432	140c88af23f75d0376ee87d56cd0de67	Voyager	32.7086057002440072	-97.2246580842442825
38939	2020-07-21 19:17:06	2020-07-21	Gaston Hickle	gaston.hickle@geemail.com	Los Angeles	California	3096260242540054957	3961b14760484de776c512a74b65dfd6	American Express	34.0935379944607604	-118.418153752711788
38940	2020-07-21 19:21:21	2020-07-21	Delores Williamson DVM	delores.williamson.dvm@geemail.com	Denver	Colorado	3010800643721999	62d5ddbe45b8606dba117239c588f7bd	Maestro	39.7023348024632767	-104.92637114443481
38941	2020-07-21 19:23:34	2020-07-21	Juli Hegmann	juli.hegmann@geemail.com	Anaheim	California	180093326577442921	86db2b88918b34f1f75ce3907825eb95	VISA 16 digit	33.9120270720049746	-117.696788094632694
38942	2020-07-21 19:28:36	2020-07-21	Laurence Hammes Sr.	laurence.hammes.sr.@woohoo.com	New York	New York	3337750620474240212	8f385f00ae3699312da2dc56b22dc0e8	Discover	40.6506817238628884	-74.0198275826301426
38943	2020-07-21 19:30:40	2020-07-21	Lenwood Schoen	lenwood.schoen@warmmail.com	Dallas	Texas	54921201210016945	9e0434b7a4ccaf436106d4a8300c156f	VISA 16 digit	32.8406827525973313	-96.6806752724535698
38944	2020-07-21 19:31:26	2020-07-21	Neil Stoltenberg-Tremblay	neil.stoltenberg.tremblay@woohoo.com	Baltimore	Maryland	4038411300650	09819bb3d0dc1fbb733dd1ddd72c6a13	VISA 16 digit	39.2534202747978256	-76.6114794550016569
38945	2020-07-21 19:35:11	2020-07-21	Manley Stanton	manley.stanton@geemail.com	Miami	Florida	3011547455087691	828afe6383cf28a53aea305206ccb282	Mastercard	25.6924245918773124	-80.2464323714248877
38946	2020-07-21 19:51:52	2020-07-21	Dr. Anastacio Anderson	dr.anastacio.anderson@geemail.com	Los Angeles	California	51318029890555929	a9c18ac9e2644e5a989f199f0f083267	JCB 15 digit	34.0386328336182942	-118.470978002342576
38947	2020-07-21 20:00:35	2020-07-21	Rhianna Rippin DDS	rhianna.rippin.dds@geemail.com	Colorado Springs	Colorado	3088101554148636974	9f214d85cf2b46ac6e88c073183e0f37	American Express	38.8770556166350829	-104.712901355434951
38948	2020-07-21 20:02:40	2020-07-21	Miss Eliza Barrows DDS	miss.eliza.barrows.dds@warmmail.com	Berkeley	California	3088424503619732804	e300f6d6a3807fd8bc0e4b7e2f1b72bf	Discover	37.8365577136218931	-122.264744018172991
38949	2020-07-21 20:07:12	2020-07-21	Tre Jaskolski	tre.jaskolski@geemail.com	San Diego	California	6011811623745517944	f8a73a259ef2447be688428062a2f393	Mastercard	32.8288273702908313	-117.196039383662864
38950	2020-07-21 20:10:43	2020-07-21	Queenie Mayer	queenie.mayer@geemail.com	El Paso	Texas	3758151139389391	76ded6f483ea727798645b019250aa57	Diners Club / Carte Blanche	31.8507208599071951	-106.327212764553735
38951	2020-07-21 20:12:13	2020-07-21	Darrion Pollich	darrion.pollich@woohoo.com	Columbia	South Carolina	4167985675694765	6bdcfdc0a36bf5303fb9d67d4addff1d	Discover	33.9629416659738865	-80.9954492283537917
38952	2020-07-21 20:20:05	2020-07-21	Alessandro Hahn III	alessandro.hahn.iii@geemail.com	Long Beach	California	54300015816021534	ed5bb584b13c266fdae550c1e738b98d	JCB 16 digit	33.8932958558488622	-118.203066165761271
38953	2020-07-21 20:27:42	2020-07-21	Sharla Mitchell	sharla.mitchell@geemail.com	San Jose	California	3056332610534332	c1716e7e0d1384abe391f7af0ba9c04e	American Express	37.3724464413531123	-121.856458102607732
38954	2020-07-21 20:29:00	2020-07-21	Orin Sporer	orin.sporer@geemail.com	San Diego	California	3096622242488632825	5b913cce0bb8d19acfe130d4b9dba28a	VISA 16 digit	32.7220683282308258	-117.056762041933837
38955	2020-07-21 20:32:46	2020-07-21	Jacqulyn Luettgen	jacqulyn.luettgen@geemail.com	Miramar	Florida	3753805161518517	ef7ba9356ae1dafb68915150dffa1e16	JCB 16 digit	26.0609443848468381	-80.2889040282454403
38956	2020-07-21 20:40:43	2020-07-21	Levon Dooley-Stokes	levon.dooley.stokes@geemail.com	Meridian	Idaho	869920861451198270	09ec59451e95e8e114139c051e6252b1	Discover	43.7075087872341257	-116.417912167444456
38957	2020-07-21 20:50:29	2020-07-21	Less Roob	less.roob@geemail.com	Houston	Texas	3158676759455311799	7dbdf6874d3b14ad2d8da0b4367b275e	JCB 16 digit	29.7754180491048857	-95.4075039798408824
38958	2020-07-21 20:56:39	2020-07-21	Karson Schinner-Romaguera	karson.schinner.romaguera@warmmail.com	New York	New York	4498411486495409	ebc2fc8a96f1d5ed65bf7dd4f75364e8	JCB 16 digit	40.7424774789009234	-74.0095256644662385
38959	2020-07-21 20:56:40	2020-07-21	Dr. Lyric Grady	dr.lyric.grady@warmmail.com	Lincoln	Nebraska	51252152401894740	cefaef25ccaed6a2e5f48cb590dd6423	Voyager	40.8370989649575193	-96.6133370883922993
38960	2020-07-21 20:58:21	2020-07-21	Marcello Ebert	marcello.ebert@geemail.com	San Francisco	California	210055591113370003	f09bc7184067d9267f333cd69c97bc72	Voyager	37.7548006998181336	-122.433210547091576
38961	2020-07-21 21:04:00	2020-07-21	Lahoma Reichel	lahoma.reichel@warmmail.com	New York	New York	4431089304882	b3d0c74d13342ed15861237723acde55	VISA 16 digit	40.7233403368145233	-73.8639967410255167
38962	2020-07-21 21:05:47	2020-07-21	Brandy Ledner	brandy.ledner@geemail.com	San Francisco	California	501887205285007	1d6d45ec42bf80a152906d2b1365a99c	JCB 15 digit	37.7807352068604558	-122.426987931468233
38963	2020-07-21 21:11:13	2020-07-21	Ms. Arlie Considine	ms.arlie.considine@woohoo.com	Seattle	Washington	55763966046309992	273b57976ac7fab677f890f4bbd407cb	VISA 16 digit	47.6587977861911085	-122.320213090341156
38964	2020-07-21 21:12:35	2020-07-21	Miss Syreeta D'Amore MD	miss.syreeta.d'amore.md@geemail.com	San Antonio	Texas	3712085043319323	7bd304a1aa979d84ee4614df8abf3e33	American Express	29.5053404264688481	-98.4861648916568555
38965	2020-07-21 21:19:19	2020-07-21	Jarred Mueller	jarred.mueller@geemail.com	Fresno	California	3096417217498021994	61cbc679e5c19a4b12311e4e82fd5ca5	Mastercard	36.6914721857629686	-119.715453814353424
38966	2020-07-21 21:31:40	2020-07-21	Mrs. Thursa Carroll DDS	mrs.thursa.carroll.dds@woohoo.com	New York	New York	4265621633859908	0d2dedc018c0e5b2ce8b26b296b184d7	Diners Club / Carte Blanche	40.7039138618614516	-73.9896141591377585
38967	2020-07-21 21:37:01	2020-07-21	Charley Roob-Braun	charley.roob.braun@warmmail.com	Pembroke Pines	Florida	55480418695468283	c4431fd7e8378d7b61a09d91f394db33	Diners Club / Carte Blanche	25.9441902502477184	-80.4008929375927863
38968	2020-07-21 21:47:16	2020-07-21	Ms. Sharday Wyman	ms.sharday.wyman@geemail.com	New York	New York	6011527937464122768	a48e5bf5f2a9a2a878c16d30db183c14	Maestro	40.684911941666158	-74.0141435110837165
38969	2020-07-21 21:51:18	2020-07-21	Ninnie Sanford	ninnie.sanford@geemail.com	Westminster	Colorado	6011988671376128264	82f32264df32b2908868ef1065b6e915	Discover	39.7975227488510299	-105.047003833265606
38970	2020-07-21 21:52:42	2020-07-21	Tabetha Dach-Mante	tabetha.dach.mante@warmmail.com	New York	New York	4848609485737	014f0a9cdfb53da8288306654054ba05	Mastercard	40.7581603033225974	-73.9164587051503332
38971	2020-07-21 21:53:23	2020-07-21	Mr. Karim Treutel	mr.karim.treutel@geemail.com	Clearwater	Florida	3096325825282088606	a210954f974b50d1b8d33fb8a724513e	VISA 13 digit	27.9106951287142913	-82.7721441679898646
38972	2020-07-21 21:58:36	2020-07-21	Miss Migdalia Kris DDS	miss.migdalia.kris.dds@warmmail.com	Las Cruces	New Mexico	6011817469121359103	05a9f30ac9f0b9cd161d1f98b8fb036e	JCB 15 digit	32.4166662643697094	-106.856473813776674
38973	2020-07-21 22:04:42	2020-07-21	Dr. Dariana Zulauf PhD	dr.dariana.zulauf.phd@geemail.com	Odessa	Texas	4224120537785087	701fa3d0b05737802cf89ae75e04f040	Mastercard	31.8767157772567131	-102.310358634094143
38974	2020-07-21 22:06:13	2020-07-21	Dr. Ether Fahey DDS	dr.ether.fahey.dds@geemail.com	Baltimore	Maryland	3797762543972458	cfc223fcdbc528e03f2f3a3f9b14baa5	Diners Club / Carte Blanche	39.3980339154135422	-76.5330901673547999
38975	2020-07-21 22:10:56	2020-07-21	Seneca Mitchell	seneca.mitchell@geemail.com	New York	New York	3774955668871243	fbee44c4b02db713f6a354ecc0c65c6f	JCB 16 digit	40.5835193450786136	-74.0375741673529149
38976	2020-07-21 22:14:09	2020-07-21	Hayley Walter	hayley.walter@geemail.com	Grand Prairie	Texas	3021968449120721	225c5cc47e012249f0cd6d34e7a3bd84	VISA 16 digit	32.6287602248188122	-97.1147175717972289
38977	2020-07-21 22:19:58	2020-07-21	Mr. Harvey Aufderhar DDS	mr.harvey.aufderhar.dds@warmmail.com	Mesa	Arizona	869908889533049928	be935b13ab5d4c2f5c0b487e2e80e182	American Express	33.3855597467772611	-111.61823360369317
38978	2020-07-21 22:20:50	2020-07-21	Mr. Luca Eichmann	mr.luca.eichmann@geemail.com	Glendale	Arizona	4396094832740	4f7015dcf73cd759105546fb8e1bc4a5	American Express	33.5625614891521593	-112.261646274037275
38979	2020-07-21 22:23:06	2020-07-21	Mahalia Hansen	mahalia.hansen@warmmail.com	Indianapolis	Indiana	180006056944764725	ed14036624cbdc24742a4472421e6d7a	VISA 13 digit	39.8444485739812251	-86.0885406750455502
38980	2020-07-21 22:29:43	2020-07-21	Amalia Wisoky	amalia.wisoky@warmmail.com	Tyler	Texas	52553024211822912	3bee801ec8ee9c6742962e13a34b91c4	Discover	32.2479057786103382	-95.389283170235899
38981	2020-07-21 22:30:34	2020-07-21	Perley Treutel	perley.treutel@woohoo.com	Sunnyvale	California	3528649051011798477	db38364f74087cac0ff2f03ea4836a3d	JCB 15 digit	37.3393319450311409	-122.002347713309533
38982	2020-07-21 22:43:50	2020-07-21	Kali Maggio	kali.maggio@warmmail.com	Jersey City	New Jersey	3402869790758029	c1df8e45eaf083ee8a142e283eef061c	JCB 15 digit	40.6202781355880163	-73.9721102946858906
38983	2020-07-21 22:47:02	2020-07-21	Cristofer Bauch	cristofer.bauch@geemail.com	San Francisco	California	4316500950944	2aa2911dd1f1be7d70fcdcdd86de4a10	Maestro	37.7569931004533217	-122.419005161521028
38984	2020-07-21 22:50:18	2020-07-21	Aurelia Purdy	aurelia.purdy@geemail.com	Los Angeles	California	3441999591090679	017f0f3dae52ff4a6070c2613067bb71	JCB 16 digit	33.9904790930781502	-118.467276274318991
38985	2020-07-21 22:53:38	2020-07-21	Fallon Orn	fallon.orn@geemail.com	Fontana	California	3024053971619601	e9687fed69926ffe047e6edad08ac653	VISA 13 digit	34.1335739619713294	-117.561812299377848
38986	2020-07-21 22:56:31	2020-07-21	Lovie Dickinson IV	lovie.dickinson.iv@warmmail.com	Colorado Springs	Colorado	6011448185901059690	718dc9b552afc86734f8496c381acf86	American Express	38.8738684009809035	-104.780763742669293
38987	2020-07-21 22:59:58	2020-07-21	Chris Wyman	chris.wyman@woohoo.com	Henderson	Nevada	4575240929316	f289e76a8eb57f8879d5a799744cb246	American Express	36.0389079959064773	-115.124710778488591
38988	2020-07-21 23:03:26	2020-07-21	Daisey Bashirian	daisey.bashirian@geemail.com	New York	New York	4409236648823	7d767cc84619f0b9e385b4a5b65fa7ae	Maestro	40.645662287831307	-73.8835198582977029
38989	2020-07-21 23:07:32	2020-07-21	Dr. Sariah Moen DDS	dr.sariah.moen.dds@geemail.com	Boston	Massachusetts	4996194266739	f1c47ba7821772ee0ce2598655a6f63f	VISA 16 digit	42.2819331702012562	-71.0878645173691268
38990	2020-07-21 23:08:41	2020-07-21	Nereida Donnelly DDS	nereida.donnelly.dds@geemail.com	Columbus	Ohio	6011773976190459202	135e21b31714f13c57eeadf86eccab43	Maestro	39.9094016579955806	-82.9535339963391465
38991	2020-07-21 23:09:04	2020-07-21	Santos Greenholt	santos.greenholt@geemail.com	Worcester	Massachusetts	6011671368676837387	d07c9df1d4e1d8cd847e05e2be5a036e	VISA 13 digit	42.1809557206630714	-71.8599664633415642
38992	2020-07-21 23:20:00	2020-07-21	Marge Marquardt-Zulauf	marge.marquardt.zulauf@geemail.com	Visalia	California	3158731482627343029	9e7af95f2827cd06c0c992d96ee92669	JCB 15 digit	36.3777044775851053	-119.250999991794686
38993	2020-07-21 23:24:32	2020-07-21	Winthrop Herzog	winthrop.herzog@geemail.com	Arlington	Texas	180093362577891700	7738aa88d5f6d2233c9dfb688e33c36a	VISA 16 digit	32.6439729644235186	-97.0605457181602702
38994	2020-07-21 23:27:42	2020-07-21	Katy Morissette MD	katy.morissette.md@geemail.com	San Francisco	California	676334190122696	a2d662fd1f1880c587235dab907c2d37	VISA 13 digit	37.7948112958532008	-122.437590033107568
38995	2020-07-21 23:38:13	2020-07-21	Toney Douglas DDS	toney.douglas.dds@geemail.com	New York	New York	3088444057515372781	20918e2148f778132371fc339ac1e62e	Mastercard	40.6687913682069606	-73.9746465064946506
38996	2020-07-21 23:46:37	2020-07-21	Dr. Lanny Moore	dr.lanny.moore@geemail.com	Chicago	Illinois	3750604775610023	31b68dc148a73ffedb49d55f75bd1431	JCB 16 digit	41.921232563892751	-87.6398059302039343
38997	2020-07-21 23:50:31	2020-07-21	Natasha Skiles	natasha.skiles@geemail.com	Berkeley	California	589381143889723	01293d07a0e0a02ceb1dcde9fba1bea4	American Express	37.865007127289573	-122.266025953005595
38998	2020-07-21 23:53:28	2020-07-21	Mariam Wunsch	mariam.wunsch@woohoo.com	New York	New York	3158802527899803870	81afb6f8b5d87f5011e20c552b460aff	JCB 15 digit	40.7139381042905129	-73.8627545529872123
38999	2020-07-21 23:53:37	2020-07-21	Mr. Dijon Stroman DVM	mr.dijon.stroman.dvm@geemail.com	El Paso	Texas	4277433413626	efed9a255b3572a1eb87ad7bf3d34de2	Voyager	31.8866636740338087	-106.395718926049781
39000	2020-07-22 00:02:37	2020-07-22	Adan Bashirian	adan.bashirian@woohoo.com	Anchorage	Alaska	4336607475504244	00dcd6abcb5172e5a504768f492e1527	American Express	61.2498635390989534	-149.198151974578565
39001	2020-07-22 00:15:28	2020-07-22	Burke McClure	burke.mcclure@geemail.com	Los Angeles	California	3088825795577764200	4667195e22c5ead16363f7e9b1d1e811	Maestro	33.927371136923874	-118.352299480558557
39002	2020-07-22 00:20:36	2020-07-22	Tyler Sipes MD	tyler.sipes.md@geemail.com	Warren	Michigan	4958422991082	7f275e47a5a3b640e287800fc3067141	JCB 16 digit	42.5321662790603909	-82.9496201392728949
39003	2020-07-22 00:21:24	2020-07-22	Demarco Wyman-Walker	demarco.wyman.walker@geemail.com	San Francisco	California	3158809771797824173	adf2745902248238fbd586574342b3c6	VISA 16 digit	37.7717845577417819	-122.445541494458979
39004	2020-07-22 00:22:21	2020-07-22	Morgan Spencer	morgan.spencer@geemail.com	Chicago	Illinois	869964196192700549	dc16f0099ddc897fb14d7ced6c089793	Voyager	41.7771629068370913	-87.7766571685701535
39005	2020-07-22 00:30:33	2020-07-22	Miss Gwyneth Walsh	miss.gwyneth.walsh@geemail.com	Houston	Texas	3034936194245198	2313c92bc857a9b63112c3ff756f360f	American Express	29.7667411901600651	-95.4289603869445671
39006	2020-07-22 00:46:57	2020-07-22	Milagros Hickle	milagros.hickle@geemail.com	Houston	Texas	4049655621867	48056fbd88c5f8b1760cbd307dfa16f0	Maestro	29.8762021923981607	-95.3269397904179954
39007	2020-07-22 00:48:00	2020-07-22	Brittnie Kulas	brittnie.kulas@geemail.com	Los Angeles	California	4406866170813	ece7a150d5e62f2b7a7283bf4587c622	JCB 16 digit	34.0173921534657424	-118.343778703919796
39008	2020-07-22 00:54:20	2020-07-22	Trisha Volkman	trisha.volkman@woohoo.com	Norwalk	California	3019990489950439	a8fe8e0817db8796b23d7fc19174e8aa	Diners Club / Carte Blanche	33.9235864066634321	-118.043617135522894
39009	2020-07-22 00:58:16	2020-07-22	Silver Gutmann	silver.gutmann@geemail.com	Buffalo	New York	6011907113501983592	ea1b49d62e0cdc8a914454c1cf1cdc21	Discover	42.7990059993416025	-78.9403142349261771
39010	2020-07-22 01:05:57	2020-07-22	Sally Simonis-Cummings	sally.simonis.cummings@geemail.com	Fort Collins	Colorado	3337034711670738964	eb710bfd41e35fdffee10fe88f7be3e4	Maestro	40.5231958147760523	-105.115147235053783
39011	2020-07-22 01:16:47	2020-07-22	Quintin Gibson-Cummerata	quintin.gibson.cummerata@geemail.com	McKinney	Texas	4731883146139915	55943ec14e59d6027875b471b5957356	JCB 16 digit	33.1925150592010496	-96.6996109608858916
39012	2020-07-22 01:22:30	2020-07-22	Harrie Bergnaum IV	harrie.bergnaum.iv@geemail.com	Minneapolis	Minnesota	3484550140778708	9e3f0b8f8f38039c8bea0c6a630742de	VISA 16 digit	45.0459655576471221	-93.3617355615638189
39013	2020-07-22 01:27:41	2020-07-22	Prudie Crooks	prudie.crooks@geemail.com	New York	New York	54362618448923350	e985377cc826738aa40b92ca5278acad	Diners Club / Carte Blanche	40.5865962602887294	-73.9369121781445955
39014	2020-07-22 01:28:18	2020-07-22	Mr. Larkin Nitzsche IV	mr.larkin.nitzsche.iv@woohoo.com	New York	New York	3003703456241054	abbd49bef2f7aca0aa58900691df008d	VISA 13 digit	40.7210603390112524	-73.8967834139604065
39015	2020-07-22 01:38:44	2020-07-22	Tawanna Bailey DVM	tawanna.bailey.dvm@warmmail.com	Columbus	Ohio	3096722164659111117	0896e61e7b0ca05e9a63a63e509c219f	VISA 13 digit	40.064587715645132	-82.9060276730220806
39016	2020-07-22 01:48:43	2020-07-22	Buck Wisoky	buck.wisoky@geemail.com	Visalia	California	4617057239429	4ea6913edeedcc9c2d18b6466890bc55	Mastercard	36.285598736764122	-119.266401539150252
39017	2020-07-22 01:54:04	2020-07-22	Elwyn Fay	elwyn.fay@geemail.com	Chicago	Illinois	869935259807056552	b91245aba1636c001323402e3b571783	Voyager	41.7982972673442248	-87.595462754511459
39018	2020-07-22 01:59:07	2020-07-22	Kamryn Turner DDS	kamryn.turner.dds@geemail.com	Winston–Salem	North Carolina	4818576650915169	1c9305e402ab48f9c13a184190c3f879	Voyager	36.2013823114566478	-80.2193624693564971
39019	2020-07-22 02:12:28	2020-07-22	Oland Gutmann MD	oland.gutmann.md@geemail.com	San Francisco	California	53642411802458755	f1269d256e47059951bdb5faf8699825	Mastercard	37.778445278934548	-122.468925333008173
39020	2020-07-22 02:16:26	2020-07-22	Dr. Adelaide Quitzon	dr.adelaide.quitzon@geemail.com	Colorado Springs	Colorado	4955494676302	65c5010e30cf3459c856408be13febfc	Voyager	38.8670428106609762	-104.701431058456009
39021	2020-07-22 02:21:15	2020-07-22	Guy Kunze	guy.kunze@warmmail.com	Dallas	Texas	3025457269138456	81e6b1eaa2bd9765128d21b9c1d0301f	JCB 16 digit	32.7600639266699574	-96.7414590520746884
39022	2020-07-22 02:29:47	2020-07-22	Simona Dach	simona.dach@geemail.com	Santa Ana	California	4199706782852282	e901d20f5d2c2f7e89c4329bfc8ada2b	VISA 16 digit	33.7409512365806847	-117.91227261921577
39023	2020-07-22 02:33:18	2020-07-22	Kendrick Rempel	kendrick.rempel@geemail.com	New York	New York	3038407832333057	965ee1f964139e7b9533344fbca062ea	JCB 16 digit	40.6466017038784884	-73.9787923861190677
39024	2020-07-22 02:33:22	2020-07-22	Khari Kuhic	khari.kuhic@woohoo.com	Rancho Cucamonga	California	3437949974096757	08c370ce646891ec6a90a4be3e3e2e15	VISA 13 digit	34.2044319756321613	-117.642059875373548
39025	2020-07-22 02:42:05	2020-07-22	Lilianna Schumm	lilianna.schumm@warmmail.com	San Francisco	California	3426003799862580	0a661e85841e3d5545d3796da3d9c05f	Mastercard	37.8176635464905644	-122.456179716187179
39026	2020-07-22 02:49:51	2020-07-22	Dr. Gilman Wolff	dr.gilman.wolff@geemail.com	Glendale	Arizona	675973458280556	a3b21598b54041d8ad0017eec9d9454c	JCB 16 digit	33.4412228116061527	-112.159853802460802
39027	2020-07-22 02:56:34	2020-07-22	Carra Cummerata-Herzog	carra.cummerata.herzog@woohoo.com	Kansas City	Missouri	55624820619408005	a3aff48f3186402dd6fad11eabd19a81	VISA 13 digit	39.1585044593852061	-94.6174267912972766
39028	2020-07-22 03:01:51	2020-07-22	Mrs. Christin Little DDS	mrs.christin.little.dds@geemail.com	Baltimore	Maryland	4182875690584	85446ae233a3f852d99f6ace8bedf995	VISA 16 digit	39.2290767776779816	-76.6250275971852233
39029	2020-07-22 03:02:37	2020-07-22	Harvy Klocko-Flatley	harvy.klocko.flatley@geemail.com	Columbus	Ohio	676169744339420	c6366beaf4f20ded3f17d12cbf15fe84	JCB 16 digit	40.0753571965310726	-82.9343129341725387
39030	2020-07-22 03:04:20	2020-07-22	Rian Padberg	rian.padberg@geemail.com	Bridgeport	Connecticut	676369537114311	f0bf2a346be2828ebd6c98b9e58dbb23	Diners Club / Carte Blanche	41.2201640615403591	-73.1020631638720744
39031	2020-07-22 03:13:08	2020-07-22	Cristine Strosin	cristine.strosin@geemail.com	Los Angeles	California	55870872052692109	3419ec78a905eecfe40b820eaa0ba44d	Mastercard	34.1099648457817679	-118.338324277707557
39032	2020-07-22 03:19:08	2020-07-22	Yahaira Hintz	yahaira.hintz@geemail.com	Temecula	California	4505895438942495	d7eb74a33cd981fd49b0e2727d449319	Discover	33.4167339755356281	-117.158195345681904
39033	2020-07-22 03:22:27	2020-07-22	Alois McGlynn	alois.mcglynn@geemail.com	Kansas City	Kansas	3024932212764757	6411a83abe9bb4316382360d23e61d6b	JCB 15 digit	39.0483481653407267	-94.8302430952370088
39034	2020-07-22 03:25:53	2020-07-22	Korbin O'Hara	korbin.o'hara@warmmail.com	Oakland	California	52158907342874985	5bfe5498adb57faf0aeccb726f2558c0	Mastercard	37.7928962061640803	-122.271243959461884
39035	2020-07-22 03:34:50	2020-07-22	Dr. Judah Carter	dr.judah.carter@geemail.com	Lakewood	Colorado	3759854045051083	aadc69d49a83c2fb01afdfbb683dbe6a	Discover	39.6452212385773706	-105.199309049874913
39036	2020-07-22 03:42:10	2020-07-22	Kory Reilly Sr.	kory.reilly.sr.@geemail.com	Toledo	Ohio	3402575538710764	d0360be5bff47feda29a735c201161dc	JCB 16 digit	41.6866098793394855	-83.5145858923304871
39037	2020-07-22 03:42:55	2020-07-22	Zeno Kuphal	zeno.kuphal@geemail.com	Las Vegas	Nevada	3051601755249756	1268a0fbcbd5df5bbacf031015c413f0	Mastercard	36.2099735879439848	-115.314119943065933
39038	2020-07-22 03:47:23	2020-07-22	Jaheem Johnston	jaheem.johnston@geemail.com	Buffalo	New York	4290501849338989	2a36d9ff49ac27e844f670be6223b302	Maestro	42.9729162845481198	-78.8426405481927191
39039	2020-07-22 03:50:11	2020-07-22	Okey Wisoky	okey.wisoky@geemail.com	Lincoln	Nebraska	180003853328744783	54dd1799d7a010de86cf2533aad42b92	Discover	40.8138237869385634	-96.6626463139124183
39040	2020-07-22 03:52:28	2020-07-22	Giancarlo Prosacco	giancarlo.prosacco@geemail.com	Portland	Oregon	3088817508899584010	a0c3716cb2282434469c52824f95261d	Voyager	45.4532174221593905	-122.74345250078477
39041	2020-07-22 03:54:02	2020-07-22	Ms. Sharday Erdman	ms.sharday.erdman@woohoo.com	San Angelo	Texas	869913998440207850	2aafcc9f8f68441d5ed281e823acebbc	VISA 16 digit	31.4329981641530978	-100.398043195681652
39042	2020-07-22 04:00:18	2020-07-22	Mr. Jamar Quitzon	mr.jamar.quitzon@warmmail.com	Boston	Massachusetts	53826005185064830	0626145df13e206d70f2b3a1d0effee9	Discover	42.3096322158984819	-71.0324731640469338
39043	2020-07-22 04:02:36	2020-07-22	Shelley Yost	shelley.yost@woohoo.com	Memphis	Tennessee	4028293668509051	4786fca0dae059db0fa89272d0195e8a	JCB 16 digit	35.0996934698030358	-89.9607603964187206
39044	2020-07-22 04:06:42	2020-07-22	Loreen Miller MD	loreen.miller.md@geemail.com	Columbia	Missouri	210025509131709389	6b569a0ed257c61f7ca4b087497e43ff	JCB 15 digit	38.8925095477488441	-92.3732809104544259
39045	2020-07-22 04:06:42	2020-07-22	Dr. Gaynell Spencer	dr.gaynell.spencer@geemail.com	New York	New York	180087174671311206	60bbff6712ceee071e83be1095288c98	Maestro	40.6302618260718873	-73.8626963534753713
39046	2020-07-22 04:09:22	2020-07-22	Litha Donnelly	litha.donnelly@geemail.com	Las Vegas	Nevada	561272530316412	40a03c81d13f9708c4118ce6d4734a51	VISA 16 digit	36.266107348688692	-115.296019517837465
39047	2020-07-22 04:15:23	2020-07-22	Mima Franecki	mima.franecki@geemail.com	San Francisco	California	52929057783097817	5b4b262436157ee9cd856bb5fe264d24	VISA 16 digit	37.7501890605593786	-122.424399091887693
39048	2020-07-22 04:41:39	2020-07-22	Irma Halvorson-Erdman	irma.halvorson.erdman@warmmail.com	Greensboro	North Carolina	4035119267781760	3b998ae05d7489839707cd9c869e2658	JCB 16 digit	36.1509207490481472	-79.8173096615802535
39049	2020-07-22 04:43:25	2020-07-22	Miss Joan Daugherty MD	miss.joan.daugherty.md@warmmail.com	McAllen	Texas	3088604580412934136	a1eaba2b8cd5d33597113b4f128e2105	JCB 16 digit	26.3049989249397065	-98.3277386667519693
39050	2020-07-22 04:46:12	2020-07-22	Ethie Macejkovic	ethie.macejkovic@geemail.com	Philadelphia	Pennsylvania	4939445864907426	cbd173a505fc5ee9bb216a000cb6f6fd	VISA 16 digit	39.9501126919366385	-75.1367138874616529
39051	2020-07-22 04:46:34	2020-07-22	Louis Stehr-Von	louis.stehr.von@geemail.com	Phoenix	Arizona	6011398297525783207	aa382faa08d5f733c8b24690f6f84f2a	VISA 16 digit	33.5632182564519397	-112.008108551700047
39052	2020-07-22 04:47:15	2020-07-22	Francina Wintheiser	francina.wintheiser@geemail.com	Fremont	California	3009227529077042	ef88944bbe29418490229b3d7b0720a4	VISA 16 digit	37.4225819460749634	-121.964518772157646
39053	2020-07-22 04:49:40	2020-07-22	Jules Zboncak	jules.zboncak@warmmail.com	Fresno	California	51243229657990349	0e6dc745ba93f6ce96669ad7081232f8	VISA 13 digit	36.7494214240334927	-119.823711571527284
39054	2020-07-22 04:58:37	2020-07-22	Devante Dicki	devante.dicki@geemail.com	Greeley	Colorado	3470432621219310	67db4acfe9fa135f9d595ead3fbd51d5	Maestro	40.3347397604558608	-104.71017748348676
39055	2020-07-22 04:59:46	2020-07-22	Dr. Jabez Jast	dr.jabez.jast@geemail.com	Fresno	California	869915313076079110	7d498229f903164901c59de4a1e7d6a3	Mastercard	36.7501298144798696	-119.863997027894115
39056	2020-07-22 05:05:17	2020-07-22	Marcy Hane	marcy.hane@geemail.com	Oakland	California	4462405357296	f600b6d853169f14f4c7f9c3137e4e53	VISA 16 digit	37.8088587773943985	-122.24753093204113
39057	2020-07-22 05:07:44	2020-07-22	Dr. Quinten Pfannerstill DVM	dr.quinten.pfannerstill.dvm@woohoo.com	Philadelphia	Pennsylvania	589354020044050	712be1a467f4a373310153d75391693a	JCB 16 digit	40.0469591555144646	-75.1257660718999887
39058	2020-07-22 05:17:03	2020-07-22	Ofelia Hermiston	ofelia.hermiston@geemail.com	Murrieta	California	3158813281557747402	070fb862cbcdf320b8037f23cf9b46a3	JCB 16 digit	33.4788192347720255	-117.096178389098114
39059	2020-07-22 05:18:46	2020-07-22	Mozell Feest-Hoppe	mozell.feest.hoppe@geemail.com	New York	New York	4311123690728336	12cfbbcca0b2e64e73ee2de2d53cdb0b	Voyager	40.7469062958601853	-73.8553330262087258
39060	2020-07-22 05:20:06	2020-07-22	Adelynn Hettinger DVM	adelynn.hettinger.dvm@geemail.com	Fullerton	California	6011719946500538745	bcd955b0320f510f904199b05b46cae7	VISA 13 digit	33.8111810525104417	-117.830054705098263
39061	2020-07-22 05:35:22	2020-07-22	Angela McDermott	angela.mcdermott@geemail.com	Oakland	California	6011409418073160187	807e99abb42180683b0c1c0e3e7e7fa4	Voyager	37.7935100236750401	-122.294144177694477
39062	2020-07-22 05:50:06	2020-07-22	Ronin Ledner-Nicolas	ronin.ledner.nicolas@geemail.com	Houston	Texas	639009391485480	d27280dc3311a12bacd167b3f7b449fe	Mastercard	29.7002789666488773	-95.4446902418058443
39063	2020-07-22 06:00:04	2020-07-22	Jamarcus O'Keefe	jamarcus.o'keefe@geemail.com	Orlando	Florida	3528211171598204174	8e95adcfd204ea770cd50d967b6cf436	Diners Club / Carte Blanche	28.5061907318685179	-81.1913664441987919
39064	2020-07-22 06:01:02	2020-07-22	Jan Johnston	jan.johnston@geemail.com	San Francisco	California	3766586989064802	7d3605b5ed8c36496a4cda0044eff316	VISA 16 digit	37.7590980370715741	-122.418733334602678
39065	2020-07-22 06:02:07	2020-07-22	Brad Schmidt	brad.schmidt@geemail.com	San Diego	California	55211182656265031	393bb465f6a6e80f9e114a0e89a2ad24	American Express	32.8573790071133516	-117.226619148291647
39066	2020-07-22 06:02:46	2020-07-22	Hayden Dare	hayden.dare@geemail.com	St. Petersburg	Florida	3716924879802349	fcb0b87bc227143a56410e61fdd619ba	JCB 16 digit	27.7119095410574232	-82.6092079631876146
39067	2020-07-22 06:03:22	2020-07-22	Camden Bernier	camden.bernier@geemail.com	Tucson	Arizona	3001703473145116	823454a423c31c9aa529dd23fd80c7af	JCB 16 digit	32.0771304436534663	-110.855339844733848
39068	2020-07-22 06:24:12	2020-07-22	Eartha Jacobs	eartha.jacobs@warmmail.com	Philadelphia	Pennsylvania	3112094454994387732	da530eeaf1e06cbb29dbb51c9f667314	JCB 15 digit	40.0790060893125855	-75.182201316057899
39069	2020-07-22 06:30:34	2020-07-22	Kaycee Mertz	kaycee.mertz@woohoo.com	New York	New York	3019959968514206	34213e6bba9d5230fc94df0335d312a5	VISA 16 digit	40.6441821772363028	-74.0046392393194168
39070	2020-07-22 06:33:21	2020-07-22	Michelina Heller	michelina.heller@geemail.com	Los Angeles	California	180043778203572722	0cd84a66cc7a28a2ac6fe2fc6ec7e3a2	Maestro	34.102801569025587	-118.343439843970529
39071	2020-07-22 06:48:20	2020-07-22	Jazlynn Schoen-Turner	jazlynn.schoen.turner@geemail.com	Athens	Georgia	060470940944831	0443cea947ac36fcceef741bf8e7f930	JCB 15 digit	34.0160981868118029	-83.3491406072977838
39072	2020-07-22 06:50:19	2020-07-22	Buck Toy	buck.toy@geemail.com	Escondido	California	3528529001248859142	581f262409b58821681ad847e0c80cc5	American Express	33.2146000389236917	-117.038816462621085
39073	2020-07-22 07:01:11	2020-07-22	Kacey Barton DVM	kacey.barton.dvm@geemail.com	San Diego	California	675907588985536	4d9f6ee416cbfbbff45600b90080d269	VISA 13 digit	32.8636070454094593	-117.215597207089886
39074	2020-07-22 07:02:41	2020-07-22	Tamya Schamberger	tamya.schamberger@geemail.com	Greensboro	North Carolina	3042794020001802	0a5ae70ab9d96a3570ac46c7e7075623	Mastercard	36.0531534984357691	-79.834207101257519
39075	2020-07-22 07:07:01	2020-07-22	Troy Conroy	troy.conroy@geemail.com	Philadelphia	Pennsylvania	4719178761677141	46d37e4f61c419a1e479e364e17dc129	VISA 13 digit	40.0313525759573992	-75.2071611351698692
39076	2020-07-22 07:11:54	2020-07-22	Alyvia Nitzsche	alyvia.nitzsche@warmmail.com	Corpus Christi	Texas	3088208948393661715	1318a670bddfd6c06fc7052465edada4	VISA 16 digit	27.7423573860369643	-97.2191924001384535
39077	2020-07-22 07:17:28	2020-07-22	Ms. Kenley Marks	ms.kenley.marks@geemail.com	Kansas City	Missouri	4523318202000	1906e223ee355956fe005eb258af25c7	Maestro	39.1623445592656765	-94.6104661837443786
39078	2020-07-22 07:18:09	2020-07-22	Haley Rodriguez	haley.rodriguez@geemail.com	Garden Grove	California	3337127524815241226	d698cff73f3e54b534785099deca965a	VISA 16 digit	33.7717145900532572	-117.932383939206602
39079	2020-07-22 07:22:45	2020-07-22	Dr. Jeanie Hand	dr.jeanie.hand@geemail.com	San Francisco	California	53797134055577609	34642a25ac95aca0c50b68541165bcb4	VISA 16 digit	37.758028185900173	-122.415859189918834
39080	2020-07-22 07:28:43	2020-07-22	Alexa Okuneva	alexa.okuneva@geemail.com	Long Beach	California	180014249681198203	4739c72ff4637365363e5485bc80f555	Maestro	33.8989401289083006	-118.166544494048878
39081	2020-07-22 07:32:42	2020-07-22	Lawanda Kshlerin	lawanda.kshlerin@geemail.com	New York	New York	4276108871696	506dbadb4c5ca11f7a3d59c44eef851d	VISA 13 digit	40.6033069819435468	-73.847041665891922
39082	2020-07-22 07:53:05	2020-07-22	Miss Ottilie Olson MD	miss.ottilie.olson.md@geemail.com	Louisville	Kentucky	53474926756035880	93aa5c79ccc0338e8ce194081f34f8d6	VISA 13 digit	38.0717729321584102	-85.7012924364373134
39083	2020-07-22 08:01:42	2020-07-22	Iesha Harber	iesha.harber@warmmail.com	New York	New York	869949839193449570	95766c9ef3e7f2282095cc027b813dd6	VISA 13 digit	40.5785393963791421	-74.0169832204829845
39084	2020-07-22 08:04:52	2020-07-22	Giovanni Halvorson-Hayes	giovanni.halvorson.hayes@geemail.com	Nashville	Tennessee	4095870629227	f56d1da5bbbc4c26f08eadd99ffc17bc	Maestro	36.1134727025993172	-86.7783661509305233
39085	2020-07-22 08:06:11	2020-07-22	Ms. Bessie Schaefer DDS	ms.bessie.schaefer.dds@woohoo.com	Denton	Texas	4572466849265674	51ce79e4c48c087feba32b90aeb91b6e	JCB 15 digit	33.120465918144582	-97.2054815832652253
39086	2020-07-22 08:11:44	2020-07-22	Rollo Steuber	rollo.steuber@geemail.com	Salt Lake City	Utah	6011886582136186422	51417c2a6829ca9db50bcb6e122ab74a	VISA 16 digit	40.7194867684185482	-111.845090233342717
39087	2020-07-22 08:27:15	2020-07-22	Evertt Tremblay	evertt.tremblay@warmmail.com	Detroit	Michigan	4105154637149641	766fc304ba6e618b8d5fdcd1c26f5b85	American Express	42.3006421006675808	-83.1498084128022157
39088	2020-07-22 08:32:02	2020-07-22	Willa Huels	willa.huels@warmmail.com	Toledo	Ohio	210050178498014607	1ff892aece82065bbf39abf2104bb8e9	JCB 16 digit	41.7059556651566155	-83.5468125474039454
39089	2020-07-22 08:35:05	2020-07-22	Francesca Kertzmann	francesca.kertzmann@geemail.com	Louisville	Kentucky	4951894108988	a637b2959f0d3666f0e7e5572a75adfa	American Express	38.1391936384975878	-85.7242695044796932
39090	2020-07-22 08:35:41	2020-07-22	Lulu Cummings	lulu.cummings@geemail.com	Hillsboro	Oregon	210047416977313348	c494ef570b93676eac02a206b0c4db10	VISA 16 digit	45.4727328122798369	-122.909987924822417
39091	2020-07-22 08:40:29	2020-07-22	Lorenza Zieme	lorenza.zieme@geemail.com	Port St. Lucie	Florida	869948973270875539	7f2a19f08a0c3970f5cdf5caa4ef32e9	Mastercard	27.3036758515186619	-80.4852421545043626
39092	2020-07-22 08:40:38	2020-07-22	Britt Beatty	britt.beatty@woohoo.com	Frisco	Texas	4183796613481	f283c0c75caddcf085b47eae3ec563b3	Maestro	33.0856185863256442	-96.8909118572924228
39093	2020-07-22 08:43:28	2020-07-22	Paola Strosin	paola.strosin@warmmail.com	Milwaukee	Wisconsin	4276754308279776	fec9b0e8855bf0ab0b18a8eedc35d840	Mastercard	43.0456798281140607	-87.9014570499871013
39094	2020-07-22 08:49:58	2020-07-22	Kelcie VonRueden	kelcie.vonrueden@geemail.com	Chicago	Illinois	675924622862076	2f85fb678c75ee19cfe07c78dde405e8	JCB 15 digit	41.7553838941104729	-87.6398482384189919
39095	2020-07-22 09:13:27	2020-07-22	Elon Friesen	elon.friesen@geemail.com	San Diego	California	4265457811263682	a82e6596221387ef605351ce49862345	JCB 16 digit	32.8126612813279053	-117.215014828033745
39096	2020-07-22 09:16:15	2020-07-22	Rosey Beatty	rosey.beatty@geemail.com	Reno	Nevada	4834535066036853	73df8ba4fd2ab3636c377dcfa56cbcf8	Discover	39.5638329665254815	-119.87668466145881
39097	2020-07-22 09:16:52	2020-07-22	Miss Karsyn Abbott	miss.karsyn.abbott@geemail.com	New York	New York	501834982655259	6f77937509ba6468315da05a2b074e85	JCB 16 digit	40.5754208854157454	-74.0319860200759052
39098	2020-07-22 09:27:33	2020-07-22	Killian Nienow	killian.nienow@geemail.com	Orlando	Florida	3418957190760422	25d5a8d15c1ce262caec028a0a74166e	Discover	28.3855532017335292	-81.2309371586855491
39099	2020-07-22 09:29:50	2020-07-22	Sina Fahey	sina.fahey@woohoo.com	Clinton	Michigan	4396978235234	b2ee04b86dd04b1eafa48922f5e7b16d	Diners Club / Carte Blanche	42.6727014701414831	-82.9148878448717284
39100	2020-07-22 09:33:13	2020-07-22	Cleda Hickle	cleda.hickle@geemail.com	Denver	Colorado	4346126338644061	6584904e42f5d6df651bd2f3b364adad	Diners Club / Carte Blanche	39.6941447759099262	-104.923520815024531
39101	2020-07-22 09:33:26	2020-07-22	Meghan Braun	meghan.braun@warmmail.com	San Diego	California	54118316480716371	a78d63f6a966bb1ff9b5315c1a330129	Diners Club / Carte Blanche	32.7256471962269373	-117.231413156343635
39102	2020-07-22 09:51:06	2020-07-22	Dr. Deegan Kessler MD	dr.deegan.kessler.md@geemail.com	Indianapolis	Indiana	55020720136246195	a9fe97662cc3c68bf2ea52b3b7004629	Discover	39.8673583731062706	-86.135397381635002
39103	2020-07-22 09:54:35	2020-07-22	Lula Langosh II	lula.langosh.ii@geemail.com	San Francisco	California	4277689147441121	368d1b2ddef1a467f157b3e84240a3f6	VISA 16 digit	37.7721041878854678	-122.421581907067278
39104	2020-07-22 09:54:39	2020-07-22	Leoma Tromp	leoma.tromp@geemail.com	Visalia	California	4018914673701746	bf7f4f239e2fa08e00ee7b0981f915b9	VISA 16 digit	36.3309687839310627	-119.27283453132361
39105	2020-07-22 09:56:55	2020-07-22	Narcissus Purdy	narcissus.purdy@geemail.com	San Francisco	California	3742079194789099	a5bd9d05232360874def666831583727	VISA 16 digit	37.7649731049855291	-122.412015726582268
39106	2020-07-22 10:02:57	2020-07-22	Miss Octavia Leuschke	miss.octavia.leuschke@geemail.com	Mesa	Arizona	4227341705449	4aa31b0c75f9b730b14904579a591115	JCB 16 digit	33.3227685579709672	-111.761626286606855
39107	2020-07-22 10:09:08	2020-07-22	Buddy Veum IV	buddy.veum.iv@woohoo.com	San Jose	California	3018999267470966	d7841a58a5cea1e09fcf3f920308d3f0	Voyager	37.2038761557832345	-121.839726576743274
39108	2020-07-22 10:13:28	2020-07-22	Gaylen Kuvalis-Smith	gaylen.kuvalis.smith@geemail.com	Denver	Colorado	4816910274124	73492cbe1b22d95448105a7ffedf551d	American Express	39.6793524962902069	-104.950954964176191
39109	2020-07-22 10:21:25	2020-07-22	Mr. Benjman Cummerata	mr.benjman.cummerata@warmmail.com	Columbus	Ohio	6011345026322157552	7fa0c37623152fdb28d7be2a453af4f1	VISA 16 digit	39.9395746632989486	-82.9568799036324123
39110	2020-07-22 10:23:18	2020-07-22	Anika West-Block	anika.west.block@geemail.com	Los Angeles	California	630467518211163	13df862ac8c67584283177f3940a139f	American Express	33.932039729212967	-118.367651997505874
39111	2020-07-22 10:26:55	2020-07-22	Mr. Bryan Bogan PhD	mr.bryan.bogan.phd@geemail.com	Port St. Lucie	Florida	3051690205281733	461e020c5bd498d1e59aab2a69570afc	American Express	27.3572902510076759	-80.4207743957258714
39112	2020-07-22 10:40:59	2020-07-22	Elza Nader MD	elza.nader.md@geemail.com	San Francisco	California	4677680402216	2c435cac4e506bfb351df575547e8af7	Maestro	37.7674628415793521	-122.430489901068739
39113	2020-07-22 10:41:56	2020-07-22	Germaine Schultz	germaine.schultz@geemail.com	Virginia Beach	Virginia	3459852654808470	6d85f725c91a20382c7e69a54cd514bf	Voyager	36.8378795898240057	-76.0732950818397029
39114	2020-07-22 10:50:12	2020-07-22	Karissa Pollich-Murphy	karissa.pollich.murphy@geemail.com	Durham	North Carolina	589301661325173	3052cb55a30d7d10110801c7e8cb570d	Mastercard	35.9847911963950793	-78.9162288574405011
39115	2020-07-22 10:52:24	2020-07-22	Francesca Hoeger	francesca.hoeger@woohoo.com	Scottsdale	Arizona	4155966980023	19009486d95028cdca880098e9f86a77	JCB 16 digit	33.6411786927964513	-111.789338037554543
39116	2020-07-22 10:53:51	2020-07-22	Miss Maya Hermiston DVM	miss.maya.hermiston.dvm@warmmail.com	Philadelphia	Pennsylvania	3032905870069901	81dcf1fb138518ddc36d326d83ac7be9	VISA 13 digit	39.9214113078970456	-75.2177901951029924
39117	2020-07-22 10:56:18	2020-07-22	Britt Bruen I	britt.bruen.i@warmmail.com	New York	New York	869938071166596541	5d3e3338c7120abd3970a29b0c3b731c	VISA 13 digit	40.7607662757150848	-73.9246228665474803
39118	2020-07-22 10:56:34	2020-07-22	Arlin Botsford V	arlin.botsford.v@warmmail.com	Phoenix	Arizona	51171825847641001	759ba52f3e46672cb070b09016160c5f	VISA 16 digit	33.5982577209759512	-112.167580786200617
39119	2020-07-22 11:09:11	2020-07-22	Kadin Upton Sr.	kadin.upton.sr.@geemail.com	San Francisco	California	3528704460474830242	b9f07c55e343e4d2d4a3589c8a6bb2c8	Discover	37.7608573054069439	-122.459294337907451
39120	2020-07-22 11:10:39	2020-07-22	Asher McLaughlin	asher.mclaughlin@woohoo.com	New York	New York	210092131925354666	4670201b01369e8e2e87059d580ce661	VISA 16 digit	40.720768970133733	-74.0060611195292353
39121	2020-07-22 11:12:43	2020-07-22	Kaaren Rempel	kaaren.rempel@warmmail.com	Fullerton	California	869924438109031496	0ed51bcf9b97e965e3ece6761b19ab39	VISA 13 digit	33.8918931125819682	-117.910154317665842
39122	2020-07-22 11:15:56	2020-07-22	Jamila Spinka	jamila.spinka@warmmail.com	Dallas	Texas	869949782821908320	35287e2d0e848c076400d7ec0a78b844	American Express	32.8522802430011325	-96.864958760045468
39123	2020-07-22 11:26:22	2020-07-22	Willodean Donnelly MD	willodean.donnelly.md@geemail.com	Chula Vista	California	675974624160557	57414867fea6905a62ae7d30164ba1d8	VISA 16 digit	32.7050131098132582	-116.945936745381715
39124	2020-07-22 11:31:30	2020-07-22	Chiquita Sporer	chiquita.sporer@geemail.com	North Charleston	South Carolina	6011794826830031173	3088c749e599779bd5f8f8a9a217a21b	JCB 16 digit	32.8367760929904904	-80.1380069762095815
39125	2020-07-22 11:31:35	2020-07-22	Harlie Zulauf	harlie.zulauf@woohoo.com	Mesa	Arizona	4319163400272193	f5d9ec99f4daf9601c3af2cbc930c439	VISA 16 digit	33.4223910014756029	-111.777020171599091
39126	2020-07-22 11:47:53	2020-07-22	Mrs. Clytie Schroeder MD	mrs.clytie.schroeder.md@woohoo.com	Ventura	California	4611205928039516	fedcfd0a15e14170b66e9afceea50840	VISA 16 digit	34.1944962503548737	-119.215339196017752
39127	2020-07-22 11:55:30	2020-07-22	Zoey Little	zoey.little@geemail.com	Memphis	Tennessee	4483184564072674	8a8d1b4ae1765da452b6b82a274ba893	Voyager	35.1982204992391203	-89.9946646168619395
39128	2020-07-22 12:10:18	2020-07-22	Von Spencer	von.spencer@geemail.com	Milwaukee	Wisconsin	3039892419056057	51a0ed877c95f01c6fb9d530b3f6a4b0	American Express	42.981292032738402	-88.0564882351186213
39129	2020-07-22 12:12:29	2020-07-22	Dr. Vicente Zemlak	dr.vicente.zemlak@geemail.com	Abilene	Texas	4445315730870487	3e9163aeb66ace9ddfb7e5ad1a331fcb	JCB 16 digit	32.5105679943300814	-99.6727881610341342
39130	2020-07-22 12:23:06	2020-07-22	Manda Kohler	manda.kohler@geemail.com	San Francisco	California	52128053926760956	3f8476a43c614c1e704b49e4b96e0836	VISA 16 digit	37.7495224697940515	-122.419909516813647
39131	2020-07-22 12:24:31	2020-07-22	Dr. Pinkney O'Keefe III	dr.pinkney.o'keefe.iii@geemail.com	Chicago	Illinois	180031932976093051	7aa9501198a30105727c508c0605e787	Discover	41.814857176488637	-87.59049083548895
39132	2020-07-22 12:31:27	2020-07-22	Eloise Mertz	eloise.mertz@geemail.com	Arvada	Colorado	180028271704001291	830f15afad3ac713e0441a45728a744e	VISA 16 digit	39.7348225415859346	-105.180163814963024
39133	2020-07-22 12:40:36	2020-07-22	Ciera Veum	ciera.veum@geemail.com	San Francisco	California	675934235450367	fdef5b04d3d811acf922493874f03a7f	Diners Club / Carte Blanche	37.7574926156112269	-122.467018736263299
39134	2020-07-22 12:48:57	2020-07-22	Isaak Haley	isaak.haley@geemail.com	San Francisco	California	3402786444942264	7007891e0bb7c24537230f8f9cf27d19	JCB 15 digit	37.7793529332094096	-122.472035189971194
39135	2020-07-22 12:49:37	2020-07-22	Amari Botsford	amari.botsford@geemail.com	Corpus Christi	Texas	3746600875429683	62bf367973b76958df9f80eb3fc9193a	VISA 16 digit	27.6559500462777912	-97.2121264830526002
39136	2020-07-22 12:51:04	2020-07-22	Monnie McClure	monnie.mcclure@geemail.com	Clarksville	Tennessee	3337784263907029033	01e085acc07af5b83b4e325dfe2f7730	VISA 13 digit	36.4959311397407191	-87.3936519303776436
39137	2020-07-22 12:51:05	2020-07-22	Ms. Florida Orn MD	ms.florida.orn.md@geemail.com	Norfolk	Virginia	4928292975002	bfcbc3eed840d11dcd5293b0afafe7a7	American Express	36.922567818129437	-76.1654029462490314
39138	2020-07-22 12:52:36	2020-07-22	Mr. Julius Streich	mr.julius.streich@geemail.com	Oakland	California	869988832150192079	2b6c39384d1b09f1d703659e80841193	Voyager	37.81860041416315	-122.295531642731532
39139	2020-07-22 12:54:43	2020-07-22	Eli Skiles	eli.skiles@warmmail.com	New York	New York	3096783564726939828	6ab623fa346a2d74ebf97b96ebbff16b	Maestro	40.7564404230322666	-73.9941370917845518
39140	2020-07-22 12:58:21	2020-07-22	Tavian Treutel	tavian.treutel@geemail.com	Salem	Oregon	3026344084459458	968b3d6f5e5725d38b2867f7bafefd36	VISA 16 digit	44.8464190905716222	-122.931713077721
39141	2020-07-22 12:59:16	2020-07-22	Adolfo Bogan DVM	adolfo.bogan.dvm@geemail.com	Little Rock	Arkansas	4398835219260	bfd8e3d16e50d31ef7ac8f7d4dc66995	VISA 13 digit	34.7301244219109435	-92.2722277863290117
39142	2020-07-22 13:02:59	2020-07-22	Guilford McDermott	guilford.mcdermott@geemail.com	Savannah	Georgia	869997400690100488	0a8267aa2cd52996f51faaf5523458bf	Mastercard	31.9252054345887117	-81.1949885291665794
39143	2020-07-22 13:08:44	2020-07-22	Asa Watsica	asa.watsica@geemail.com	San Francisco	California	4498369471783330	790d4c62f2727d8e31dd3d4c35c24f5c	Discover	37.7498822414892814	-122.453746045828126
39144	2020-07-22 13:15:36	2020-07-22	Eugenio Kihn	eugenio.kihn@geemail.com	Los Angeles	California	4646374871350848	bb8a570983253961432d9a0d4a031852	JCB 16 digit	34.0015604993660006	-118.475377035047103
39145	2020-07-22 13:15:50	2020-07-22	Purl Wyman Jr.	purl.wyman.jr.@woohoo.com	San Antonio	Texas	3528123817630721750	ab49bd4155a039aa24af02b0dfeaa6f9	JCB 15 digit	29.3742280017189685	-98.6230854509700094
39146	2020-07-22 13:17:44	2020-07-22	Marlena Champlin	marlena.champlin@geemail.com	Lincoln	Nebraska	561257594372781	ef06392f5c6874dae3eb25bc2fe328e7	VISA 16 digit	40.8430368228368437	-96.7199884879097311
39147	2020-07-22 13:20:06	2020-07-22	Shelby Pagac	shelby.pagac@woohoo.com	Virginia Beach	Virginia	4660671328467385	74f558b2120ff0e744eba8ae8c17f0b6	JCB 16 digit	36.7095038008596788	-76.0058742243468686
39148	2020-07-22 13:52:27	2020-07-22	Cannon Balistreri	cannon.balistreri@geemail.com	Topeka	Kansas	4979666017798	94d6468d7985ca29ada8d11ddab508a4	JCB 15 digit	39.0428770337186748	-95.7773345936730607
39149	2020-07-22 13:56:53	2020-07-22	Madisen Kuhn	madisen.kuhn@geemail.com	Austin	Texas	3096086989212246103	391c473b10ee0b6fdb0461f17e7ae7a1	Maestro	30.3233403371307979	-97.722512981226302
39150	2020-07-22 14:22:56	2020-07-22	Geoffrey Koepp	geoffrey.koepp@woohoo.com	Pembroke Pines	Florida	180043762798780908	c085803457fe1756cf58864a04d803cc	Maestro	26.0740746233183884	-80.3879433360319666
39151	2020-07-22 14:24:30	2020-07-22	Mrs. Emma Jenkins	mrs.emma.jenkins@warmmail.com	North Las Vegas	Nevada	3337908222936798209	736b0011d3622c79a26027fda62f31c9	JCB 15 digit	36.1984032176125794	-115.129869206783923
39152	2020-07-22 14:35:21	2020-07-22	Ardath Harris	ardath.harris@geemail.com	San Diego	California	6011911645390467934	27063f9ff09124335b283119101e05cf	VISA 13 digit	32.7309008046586101	-117.180032375073068
39153	2020-07-22 14:35:57	2020-07-22	Brandy Kshlerin	brandy.kshlerin@geemail.com	Henderson	Nevada	3790956533767624	1cdec87db86f32615fd997756a636d24	JCB 16 digit	36.0186217861183025	-115.010317252033204
39154	2020-07-22 14:40:31	2020-07-22	Dorthey Nader	dorthey.nader@geemail.com	New York	New York	4807848504823	d41c7881f56e670d32b825200ac10ae8	JCB 15 digit	40.5909009544867985	-74.0317073324590922
39155	2020-07-22 14:44:39	2020-07-22	Florrie Dickinson PhD	florrie.dickinson.phd@geemail.com	El Paso	Texas	4756690838892507	c6abbc5d6fa488d1677ce383a1a9e6d4	VISA 13 digit	31.833736242662745	-106.406225400183359
39156	2020-07-22 14:44:45	2020-07-22	Wendel O'Reilly	wendel.o'reilly@geemail.com	Houston	Texas	51740619747168120	9c170dcc28efa11628b9d146e302b678	JCB 16 digit	29.8832012225020662	-95.414099929110705
39157	2020-07-22 14:47:00	2020-07-22	Dr. Coleton Dicki	dr.coleton.dicki@geemail.com	Corona	California	210029600212119824	b3b1afed4c82a146391f13a2955379d2	Voyager	33.7856145094502764	-117.540304568197584
39158	2020-07-22 14:50:19	2020-07-22	Dr. Tawny Ullrich	dr.tawny.ullrich@geemail.com	San Francisco	California	4973972276684571	00bf670c4a3cdb15b90e4effc33eba90	VISA 16 digit	37.7934632604086929	-122.447473673086208
39159	2020-07-22 14:51:15	2020-07-22	America Hilll	america.hilll@geemail.com	Pembroke Pines	Florida	4157870347976	2f45f03cb6e21cd0e19bdaf23eceb169	VISA 13 digit	26.083816449115055	-80.3505204389240646
39160	2020-07-22 14:54:04	2020-07-22	Starr Howell	starr.howell@geemail.com	Santa Maria	California	6011291056586883274	0451f308ef5496f33a95d9689b73ac3c	Diners Club / Carte Blanche	35.0223172918491059	-120.510828233269223
39161	2020-07-22 14:54:47	2020-07-22	Ms. Lulie Kihn PhD	ms.lulie.kihn.phd@geemail.com	Elgin	Illinois	589354672207179	fd1f8831cec26a035032f50a279264f3	Voyager	41.9794919483181062	-88.2651227959718625
39162	2020-07-22 15:15:27	2020-07-22	Charlotta Bins	charlotta.bins@geemail.com	New York	New York	502004931557054	157984b41d5da7846ab93b7e1eefe25d	VISA 13 digit	40.6593749974612138	-73.8638579477917432
39163	2020-07-22 15:27:02	2020-07-22	Shawnda Roberts	shawnda.roberts@geemail.com	San Antonio	Texas	869927569195843464	4aa18ac50567053174a3e6586699aa9f	Discover	29.42026201012321	-98.5342424243990251
39164	2020-07-22 15:27:33	2020-07-22	Thorwald Kozey-Reilly	thorwald.kozey.reilly@geemail.com	Modesto	California	561240228739310	e50801877d09cd851f3681aa5df387fd	VISA 16 digit	37.684142480976881	-120.943836225822565
39165	2020-07-22 15:27:48	2020-07-22	Dr. Leopold Hoeger Sr.	dr.leopold.hoeger.sr.@geemail.com	Milwaukee	Wisconsin	4952157601984459	5c3823fd4cfe995ad66e85110ad99d93	VISA 16 digit	43.0538250609386708	-87.9607419426653507
39166	2020-07-22 15:28:21	2020-07-22	Jaxon Torphy	jaxon.torphy@woohoo.com	Phoenix	Arizona	3748349907899012	c68f7ee99657384cfd987833a352204c	Mastercard	33.5211681279286751	-112.136444309765849
39167	2020-07-22 15:34:22	2020-07-22	Anastacia Morar	anastacia.morar@geemail.com	Philadelphia	Pennsylvania	4876840080863525	bfee7dc413191caf0a78485ec74350d1	Maestro	39.9766470930498059	-75.0551998251482928
39168	2020-07-22 15:34:26	2020-07-22	Mr. Elmore Friesen I	mr.elmore.friesen.i@geemail.com	Charlotte	North Carolina	869914122195740689	8dbb3f3b5d871742812dd35e21742372	JCB 15 digit	35.2127830615986142	-80.8998339475076733
39169	2020-07-22 15:53:21	2020-07-22	Idell Medhurst	idell.medhurst@warmmail.com	Clinton	Michigan	3039418964315647	450de77ef8444b71d3cc7ed1c753a5ae	Mastercard	42.6759880345381788	-82.894768879430373
39170	2020-07-22 16:00:15	2020-07-22	Wilfred Lubowitz	wilfred.lubowitz@geemail.com	Concord	California	3158562267902212732	595bb5258b95c7779f77b7323a7476c3	American Express	37.9832487361438567	-122.009829080634191
39171	2020-07-22 16:01:47	2020-07-22	Olen Conn	olen.conn@geemail.com	Los Angeles	California	54187206985399599	1fb503cf120a428767d4aee6bc04c43e	JCB 16 digit	34.1181867723684746	-118.363628964125354
39172	2020-07-22 16:10:02	2020-07-22	Ms. Gaye Rau	ms.gaye.rau@geemail.com	San Francisco	California	4908107624694408	81303e29c1fafacb9194fd412c46b33b	American Express	37.7792878048514282	-122.460466298030553
39173	2020-07-22 16:15:48	2020-07-22	Pascal Gibson	pascal.gibson@geemail.com	San Francisco	California	869991887269150322	26ee24810ac3f697cd1ec299abf2bfc8	VISA 13 digit	37.7604953238535899	-122.443209800395877
39174	2020-07-22 16:23:42	2020-07-22	Geovanni Smith	geovanni.smith@geemail.com	Laredo	Texas	3421632611937389	f960ea1c8d6fd5e5dbd279136fb25337	Discover	27.5095114794276654	-99.5253071057151999
39175	2020-07-22 16:27:12	2020-07-22	Dagny Bechtelar MD	dagny.bechtelar.md@geemail.com	Oakland	California	6011103932280580614	a930c784ca1e303b382e36394f336eb8	Maestro	37.7812657024283425	-122.286728052218791
39176	2020-07-22 16:29:18	2020-07-22	Mr. Reid Robel	mr.reid.robel@geemail.com	Plano	Texas	3337009239433618530	83cd16727e0a628c5ca1fb5240a666a2	American Express	33.1193584477614635	-96.8451750646527927
39177	2020-07-22 16:31:41	2020-07-22	Uriel Leffler	uriel.leffler@geemail.com	Oakland	California	3045414226289971	aa62d62afb483ffbd4827b40dbaf9667	Diners Club / Carte Blanche	37.808601062643227	-122.26698661621991
39178	2020-07-22 16:34:32	2020-07-22	Willam Conroy	willam.conroy@geemail.com	New York	New York	6011522112091127490	b815748fa0e8f275604e9762f2f2a79a	JCB 16 digit	40.7321391731724134	-73.8997636353027048
39179	2020-07-22 16:34:34	2020-07-22	Vernelle Krajcik-Miller	vernelle.krajcik.miller@geemail.com	Omaha	Nebraska	869995638714379347	251d1085211946c7434631570821adbb	American Express	41.3149626424681387	-96.1310437213279414
39180	2020-07-22 16:36:25	2020-07-22	Miss Camisha Hartmann PhD	miss.camisha.hartmann.phd@geemail.com	Corpus Christi	Texas	3000386127651092	4eb7bd758f272b1993f2f8a8d41ece99	Discover	27.7506062184862792	-97.1332558994010071
39181	2020-07-22 16:37:30	2020-07-22	Miss Raina Satterfield MD	miss.raina.satterfield.md@geemail.com	Houston	Texas	4335014529549	d9a0ad4a0b0facdf2bcbbe2555a2fb75	JCB 16 digit	29.7232759200114742	-95.4183223719723514
39182	2020-07-22 16:45:46	2020-07-22	Ms. Keshia Monahan PhD	ms.keshia.monahan.phd@warmmail.com	Pearland	Texas	869907328837172491	3d6aea4bd9427bef635b465f0ee0ad84	JCB 16 digit	29.5413485771317035	-95.2938269565202205
39183	2020-07-22 16:48:02	2020-07-22	Jude Heathcote	jude.heathcote@geemail.com	Oakland	California	4066999907491579	6b14b415b437fe62f7b3213bf4c6f9fe	VISA 16 digit	37.8203591357136162	-122.270375567842478
39184	2020-07-22 16:54:32	2020-07-22	Milo Morar-Medhurst	milo.morar.medhurst@geemail.com	Rancho Cucamonga	California	53997901493901395	e0124d77d45341371bb0e29be7562d3d	JCB 16 digit	34.1958139402318722	-117.642109923018893
39185	2020-07-22 17:13:52	2020-07-22	Erland Turcotte	erland.turcotte@warmmail.com	San Mateo	California	3487526279841407	58f5beb07be08becdbbdbbead1b17459	Maestro	37.5861607755880769	-122.303460522214323
39186	2020-07-22 17:17:45	2020-07-22	Leana Champlin	leana.champlin@geemail.com	San Francisco	California	210038523047068611	b0b339e8b29c548aec3250f6ee35bf2a	American Express	37.7527489695200771	-122.447309967554347
39187	2020-07-22 17:27:18	2020-07-22	Atha Dietrich	atha.dietrich@woohoo.com	Fort Worth	Texas	3337334926458659649	1b5fe14d0d591f43bc6de5d255a99625	Voyager	32.6835484348293406	-97.3235480215221571
39188	2020-07-22 17:28:43	2020-07-22	Mohamed Hermiston-Wolff	mohamed.hermiston.wolff@warmmail.com	New York	New York	4376791430904334	5910422ee7ad019292fc74f777d1df90	JCB 16 digit	40.5897465762905796	-73.8661133253842621
39189	2020-07-22 17:33:14	2020-07-22	Jerrad Hand	jerrad.hand@geemail.com	Wichita Falls	Texas	869916592222011429	9652425f17c74335bfc09226ad83ddee	Mastercard	34.0038519969403765	-98.5648651492237917
39190	2020-07-22 17:42:13	2020-07-22	Stuart Beer-Sawayn	stuart.beer.sawayn@geemail.com	Chattanooga	Tennessee	501874387011872	41052efcd62c0f4b50b3f8ad484ea996	Diners Club / Carte Blanche	35.1057575888782765	-85.2808496348854135
39191	2020-07-22 17:52:31	2020-07-22	Mellissa Leuschke	mellissa.leuschke@geemail.com	Lubbock	Texas	502052020961489	6b77f0d884972b5d46e3b1f7cc017bfb	JCB 16 digit	33.5982391223818126	-101.837852123790242
39192	2020-07-22 17:53:22	2020-07-22	Mr. Rolf Rath Jr.	mr.rolf.rath.jr.@geemail.com	Tempe	Arizona	6011305475413954351	84445f47a3e739855d363dbfbf4d8750	JCB 16 digit	33.4511528070006463	-111.92089404259174
39193	2020-07-22 17:54:18	2020-07-22	Belle Littel	belle.littel@woohoo.com	New York	New York	3730036101864211	521a6ed704652568f7df25bbc68010f6	VISA 16 digit	40.7345638881661003	-73.8952190133638709
39194	2020-07-22 17:57:17	2020-07-22	Kelly Nader	kelly.nader@woohoo.com	Laredo	Texas	3030493558656853	7d0a3aab946a8d47161b41553f167948	VISA 13 digit	27.4658584087803987	-99.5774018815725981
39195	2020-07-22 17:57:51	2020-07-22	Madelene Torp	madelene.torp@warmmail.com	New York	New York	4698328154775425	9691892ef27d8660a735600e60d1d7d3	American Express	40.733123115239664	-73.8937303789321334
39196	2020-07-22 18:18:09	2020-07-22	Natalia Windler	natalia.windler@geemail.com	Gainesville	Florida	869919614906683716	b8e831f8c391576607b549ce4310a3f9	JCB 16 digit	29.6943585425440197	-82.359598489186169
39197	2020-07-22 18:18:36	2020-07-22	Nyasia Weimann	nyasia.weimann@geemail.com	Indianapolis	Indiana	676282770447058	3fd78af2b64cc0d0271a8c55c09a7c7e	Discover	39.6784530952580283	-86.2288952867235992
39198	2020-07-22 18:29:05	2020-07-22	Jamey Kuvalis PhD	jamey.kuvalis.phd@geemail.com	Austin	Texas	180006956114286849	4aff7d5a8ec7aa8db1811dc51ea1a48c	JCB 16 digit	30.3522989004045698	-97.8282670132588663
39199	2020-07-22 18:45:07	2020-07-22	Frank Rempel	frank.rempel@woohoo.com	San Francisco	California	3044812887986259	acb68ef850e1bb5b05fffdf3dfca19c9	JCB 15 digit	37.7896409399638031	-122.426927113852386
39200	2020-07-22 18:47:54	2020-07-22	Concepcion Bins	concepcion.bins@geemail.com	Rochester	New York	502059777942174	318956a07e4867698ea68f18bac23eb3	JCB 16 digit	43.1714985683072356	-77.5978866243973329
39201	2020-07-22 19:07:03	2020-07-22	Mr. Truman Wolff DDS	mr.truman.wolff.dds@geemail.com	Corona	California	3474436380782125	c062d9f77717e5392d0e16949da72032	JCB 16 digit	33.9498559099510331	-117.526688958818099
39202	2020-07-22 19:15:39	2020-07-22	Javen Koepp	javen.koepp@geemail.com	Sandy Springs	Georgia	51703035257100509	0e958d185646fc82f5365457a43351f2	Diners Club / Carte Blanche	33.8465287508964536	-84.4086677893146913
39203	2020-07-22 19:25:27	2020-07-22	Tennessee Harber	tennessee.harber@geemail.com	Tulsa	Oklahoma	3439818195920384	b60957e411457e0ab33352d3357eb085	JCB 16 digit	36.0650333281975222	-95.8984310929618715
39204	2020-07-22 19:28:05	2020-07-22	Webb Kreiger-Kris	webb.kreiger.kris@warmmail.com	Saint Paul	Minnesota	869904077388223947	ae9a493d90ea320ebeb40a19fad4ce53	Mastercard	44.9907141479138275	-93.1172371179129925
39205	2020-07-22 19:44:51	2020-07-22	Bria Larson	bria.larson@warmmail.com	San Francisco	California	3057350750816243	d697db821a5eb3b99f41452caee5388c	Maestro	37.775856641651238	-122.43300622845652
39206	2020-07-22 20:07:41	2020-07-22	Jennings Terry	jennings.terry@geemail.com	New York	New York	6011373134503321008	73e8f97da399ce6d78a8d905f23996aa	JCB 16 digit	40.66356026094779	-73.9398401507072123
39207	2020-07-22 20:11:48	2020-07-22	Mozella Beatty	mozella.beatty@geemail.com	Amarillo	Texas	869937938090389329	df6b8b652bdad541064bb4cc01c214c5	Mastercard	35.2967025095760789	-101.798797328383486
39208	2020-07-22 20:14:08	2020-07-22	Dallin Gulgowski	dallin.gulgowski@warmmail.com	Columbia	South Carolina	675946410367059	3aecacabb8b96b23129b24126ba4e83f	Maestro	34.0745389280173896	-80.8103262818437003
39209	2020-07-22 20:27:40	2020-07-22	Aurthur Hagenes	aurthur.hagenes@geemail.com	Oakland	California	060461173795776	5d4d51c2c1b120e70f0f868e49f8a6ed	JCB 16 digit	37.7794545732366558	-122.304947966191691
39210	2020-07-22 20:27:53	2020-07-22	Ms. Felicity Cartwright	ms.felicity.cartwright@geemail.com	Indianapolis	Indiana	561287363729176	5a847c705819f702dae605ca20e23b15	JCB 16 digit	39.6885848322425048	-86.2413420039895868
39211	2020-07-22 20:30:48	2020-07-22	Dr. Erling Hilpert II	dr.erling.hilpert.ii@geemail.com	Chicago	Illinois	6011310031044821940	67e6c01df51efb03829933b3d5e8ab2f	Voyager	41.7914601976353666	-87.7513413687731969
39212	2020-07-22 20:35:38	2020-07-22	Bartley Heidenreich	bartley.heidenreich@geemail.com	Chicago	Illinois	4422981023404354	9e02ea71e4fecff268a811a20c9d5e46	Maestro	41.8469338185921345	-87.5977545571077627
39213	2020-07-22 20:45:28	2020-07-22	Barrett Carroll-Ullrich	barrett.carroll.ullrich@warmmail.com	Austin	Texas	180035685458163398	ccc6a01a6b76f2f2a95f36d22fdc1ce8	VISA 16 digit	30.3510321563236403	-97.8316566934581857
39214	2020-07-22 20:55:28	2020-07-22	Dr. Ora Schultz II	dr.ora.schultz.ii@warmmail.com	Cincinnati	Ohio	180019746781112443	168e11272e3a06e236c546f9ad46f75e	Voyager	39.1163528889648617	-84.5668019651707255
39215	2020-07-22 20:59:16	2020-07-22	Cristy Adams	cristy.adams@warmmail.com	San Francisco	California	3795249753480812	dde95e367d8cd5f1a44238f04903c1ff	Mastercard	37.7653311511395628	-122.417107586499981
39216	2020-07-22 21:00:32	2020-07-22	Caitlin Block	caitlin.block@geemail.com	South Bend	Indiana	4569367759683747	12b097da926729828624caac1c65e443	JCB 16 digit	41.5805626049317425	-86.2035970925875006
39217	2020-07-22 21:20:47	2020-07-22	Lena Champlin	lena.champlin@woohoo.com	Pasadena	California	3422893920375716	aa097069d7f22b9479415da3eb107cfc	VISA 16 digit	34.0834228546679014	-118.117475095047055
39218	2020-07-22 21:24:55	2020-07-22	Randall Bayer	randall.bayer@geemail.com	Naperville	Illinois	3014320148190398	307569dc8cc144e1d585137db735eaa5	VISA 16 digit	41.7568940038241436	-88.1094401880987022
39219	2020-07-22 21:34:52	2020-07-22	Luisa Wilkinson	luisa.wilkinson@woohoo.com	Santa Ana	California	3112178196119522094	22d7bb271f1c5733e82b850bf208798f	Voyager	33.8009025406196741	-117.962742780420925
39220	2020-07-22 21:35:42	2020-07-22	Colby McCullough	colby.mccullough@geemail.com	Henderson	Nevada	3414629342680121	1a5dc5767a7ebc9d7e2102566754cf58	JCB 16 digit	36.017448754136268	-115.121378692301747
39221	2020-07-22 21:42:59	2020-07-22	Lilian Willms DVM	lilian.willms.dvm@geemail.com	Broken Arrow	Oklahoma	4298769654801886	cfaea6767633f4a02f0196397b85950f	VISA 16 digit	36.1204142402168316	-95.775129946082842
39222	2020-07-22 21:43:01	2020-07-22	Dr. Lesta Ebert PhD	dr.lesta.ebert.phd@geemail.com	Fort Collins	Colorado	52456742973387620	93ccb026b457b82ddf4aebbc44ac0191	Mastercard	40.5496643282629563	-105.122069539218401
39223	2020-07-22 21:44:41	2020-07-22	Allean Weber	allean.weber@geemail.com	New York	New York	4490448674087174	b7453f76daa449f31ea36e19b9c83f2b	American Express	40.7156688558626882	-73.86052084964588
39224	2020-07-22 21:50:39	2020-07-22	Buren Wolf	buren.wolf@geemail.com	Chicago	Illinois	4423972274225605	f4e8031ed499b5431896960e4e94f350	VISA 13 digit	41.8569447254132498	-87.7424232667341784
39225	2020-07-22 21:52:20	2020-07-22	Lavina Franecki-Kuhlman	lavina.franecki.kuhlman@warmmail.com	Stockton	California	3024182102303882	630073eb2bcf86e5ce40e41680113696	JCB 16 digit	37.8804482746135491	-121.268538664615903
39226	2020-07-22 21:59:07	2020-07-22	Mr. Saverio Mueller DVM	mr.saverio.mueller.dvm@geemail.com	Huntsville	Alabama	869902151789732673	061173ff28294ef652ed551799b7c2d9	VISA 16 digit	34.746608446422961	-86.6310475416965744
39227	2020-07-22 21:59:19	2020-07-22	Eben Maggio	eben.maggio@geemail.com	Corona	California	3774914685499793	c7bc93720e317429ea8376180f745a96	American Express	33.8958845710735801	-117.564793828476226
39228	2020-07-22 22:09:38	2020-07-22	Ms. Sonja Strosin PhD	ms.sonja.strosin.phd@geemail.com	Detroit	Michigan	3096317520472923395	a573bf240a05a931ee527e34113c49e7	JCB 15 digit	42.470154777208343	-83.1235475689291974
39229	2020-07-22 22:20:39	2020-07-22	Trever Schowalter	trever.schowalter@geemail.com	Colorado Springs	Colorado	3732844535108610	77651062638191ddcd4014d56afe9cec	Discover	38.9397662842228982	-104.663525164934626
39230	2020-07-22 22:24:42	2020-07-22	Carmella Nikolaus MD	carmella.nikolaus.md@warmmail.com	Frisco	Texas	4182277340374	591692262d4d6ad9aabbb89cbe7bc928	VISA 16 digit	33.0929624656677248	-96.893847101714826
39231	2020-07-22 22:25:18	2020-07-22	Tavian Will	tavian.will@geemail.com	Newport News	Virginia	4150766219765439	91f27482c3da3687d29768b2ef37c8ba	Diners Club / Carte Blanche	37.0864149407379315	-76.5742974031977468
39232	2020-07-22 22:31:32	2020-07-22	Drake Kuhn	drake.kuhn@geemail.com	Nashville	Tennessee	4061462178819593	49ad3c625b432e0364ea79660026a66f	Maestro	36.1588804507751007	-86.8303883742913598
39233	2020-07-22 22:37:36	2020-07-22	Deontae Parisian Jr.	deontae.parisian.jr.@woohoo.com	Norfolk	Virginia	4542587798332	90a81bf187637cab51a646f17ddbe922	JCB 16 digit	36.956482678234579	-76.2633674565240796
39234	2020-07-22 22:38:06	2020-07-22	Dr. Issac Wilkinson I	dr.issac.wilkinson.i@geemail.com	New York	New York	869980241873699501	07b83a3fdca369157d189ae9224e6930	VISA 16 digit	40.6152414933070531	-73.9675359237369179
39235	2020-07-22 22:49:54	2020-07-22	Wilda McGlynn	wilda.mcglynn@geemail.com	Philadelphia	Pennsylvania	4566415087644981	c2eac5bcfe9bfe1e8b16441a5ebe8935	Diners Club / Carte Blanche	40.0027277095667984	-75.2143082875657853
39236	2020-07-22 22:52:53	2020-07-22	Ms. Noemie Buckridge	ms.noemie.buckridge@warmmail.com	Chesapeake	Virginia	4601568228956	e61d449e6e0c2317764b2bfe6352f653	Maestro	36.7291502224985535	-76.3486054913915666
39237	2020-07-22 22:53:22	2020-07-22	Victor Ratke DDS	victor.ratke.dds@warmmail.com	Portland	Oregon	869942277873085934	48c4349f85898de514664a1d257aad22	American Express	45.5599622868821044	-122.603994112834343
39238	2020-07-22 22:55:16	2020-07-22	Jabez Quitzon PhD	jabez.quitzon.phd@geemail.com	Oakland	California	3096575446923561401	9cd9f7e42a72ec971adf1854a1fdef1d	Diners Club / Carte Blanche	37.8240509295495571	-122.243592142284854
39239	2020-07-22 22:58:58	2020-07-22	Ms. Bea Kautzer	ms.bea.kautzer@warmmail.com	Phoenix	Arizona	4100810103848793	0975586d9bec3edbb589bc885e657434	Voyager	33.4756002498257956	-112.02865004594662
39240	2020-07-22 23:00:43	2020-07-22	Ms. Johnnie Trantow	ms.johnnie.trantow@geemail.com	Indianapolis	Indiana	4645792379274825	149f1329f37489de9e2413db9c43391d	JCB 16 digit	39.8705550197519329	-86.1737252883348646
39241	2020-07-22 23:00:54	2020-07-22	Margeret Rodriguez	margeret.rodriguez@geemail.com	San Francisco	California	3096501855604631755	c02834efcd1e67a19ffef2a11671fbb6	VISA 16 digit	37.8234025846687132	-122.426451189406052
39242	2020-07-22 23:14:07	2020-07-22	Stephania Mitchell	stephania.mitchell@geemail.com	Hollywood	Florida	4172304453717272	5bf4421f19ce1bcddf4085e176eaf580	JCB 15 digit	26.107325401663779	-80.0741295282546304
39243	2020-07-22 23:14:38	2020-07-22	Gil Kshlerin-Moore	gil.kshlerin.moore@geemail.com	New York	New York	4333779472730289	cc418aa15b615b19794851781ec3c82e	Voyager	40.6440339165497591	-74.0305654646724491
39244	2020-07-22 23:21:08	2020-07-22	Stewart Hyatt	stewart.hyatt@geemail.com	Madison	Wisconsin	4537435489896811	68d32713609b50dd04e66a9b06ea7023	American Express	43.0259524141412228	-89.4948873253423756
39245	2020-07-22 23:22:25	2020-07-22	Cody Herzog	cody.herzog@woohoo.com	Denver	Colorado	3051232611911924	4c1a701126b626d44ace1176f12f61cd	Diners Club / Carte Blanche	39.6956136405985802	-104.874998610537872
39246	2020-07-22 23:26:42	2020-07-22	Broderick Johnston PhD	broderick.johnston.phd@geemail.com	New York	New York	869983365487059559	77d7bd9cf645a9f32feab782b7bcef6e	Diners Club / Carte Blanche	40.6241238391250334	-73.9470319711964521
39247	2020-07-22 23:36:59	2020-07-22	Josiah Olson	josiah.olson@geemail.com	Omaha	Nebraska	4718523702639653	d215dd421b41e15abc84af99274550bc	Diners Club / Carte Blanche	41.2698551271256093	-96.0220198085181522
39248	2020-07-22 23:56:52	2020-07-22	Oliver Bins-Cole	oliver.bins.cole@geemail.com	Milwaukee	Wisconsin	869905174754511721	154f497688dc748650718ea8a2cd6f65	JCB 16 digit	43.0854862080972651	-87.8771956349823711
39249	2020-07-23 00:06:02	2020-07-23	Lorrie Kassulke	lorrie.kassulke@geemail.com	Oklahoma City	Oklahoma	3717416410831159	adb7869808bb703230357a04d29f2dca	JCB 16 digit	35.4991953036658501	-97.4233366584301024
39250	2020-07-23 00:07:02	2020-07-23	Keanu Barton	keanu.barton@warmmail.com	Philadelphia	Pennsylvania	4095934932670207	f876019d60345428fe628aeeae170465	VISA 16 digit	40.0635500542778544	-75.1889747932452792
39251	2020-07-23 00:09:16	2020-07-23	Dr. Sigurd Hagenes MD	dr.sigurd.hagenes.md@geemail.com	Miramar	Florida	3007206379127067	873e524b642660ceaf94ef0af0e4cec8	Discover	25.9184227415341901	-80.351035566627246
39252	2020-07-23 00:12:35	2020-07-23	Miss Ozella Anderson MD	miss.ozella.anderson.md@geemail.com	Oakland	California	210045811637849990	f90ca38a38f9fb0336d10d41fa7021e2	VISA 13 digit	37.8226143482716495	-122.273916783025228
39253	2020-07-23 00:15:47	2020-07-23	Lara Carroll	lara.carroll@geemail.com	Concord	California	3748431844377177	17ab130e5828299ac2c5b8e4b421ab28	JCB 15 digit	37.9045114262893819	-122.090663515607261
39254	2020-07-23 00:28:58	2020-07-23	Cap Rippin	cap.rippin@geemail.com	San Francisco	California	6011982964237860696	f9fe9849a4114c2db5d09e4d23561d26	JCB 15 digit	37.7723985628293732	-122.451946912350593
39255	2020-07-23 00:32:10	2020-07-23	Parker Beahan	parker.beahan@geemail.com	Berkeley	California	4974543444836	bc3f6ab1b487b59ed17bbbed5805e506	American Express	37.896337122476055	-122.272533731102158
39256	2020-07-23 00:33:30	2020-07-23	Roll Hackett	roll.hackett@geemail.com	New York	New York	3757240696320237	7ca41b182283d981acf25e4b2b834a33	VISA 16 digit	40.5759412764795115	-73.9569711227331226
39257	2020-07-23 00:40:13	2020-07-23	Cheri Ortiz	cheri.ortiz@geemail.com	Columbia	Missouri	180081995724952760	9b3579a27da0ac8a76758c6f70c86826	VISA 13 digit	38.9276720079009095	-92.3137514579628657
39258	2020-07-23 00:43:54	2020-07-23	Brigitte Langosh	brigitte.langosh@geemail.com	New Haven	Connecticut	4144776824232047	2ee453658284c6bc5973ffd3a6072e4f	Diners Club / Carte Blanche	41.2285528232801681	-72.9477653944864812
39259	2020-07-23 00:46:37	2020-07-23	Dr. Lida Runolfsdottir	dr.lida.runolfsdottir@geemail.com	New York	New York	210072337053856059	3a275477654e2eed201890cf9798d66c	VISA 16 digit	40.5905019046496562	-73.9347770083591342
39260	2020-07-23 00:48:05	2020-07-23	Kathrine Ratke	kathrine.ratke@geemail.com	Washington	District of Columbia	3528843364407686469	f80f53bfd0f5e68892f50cc186f2e095	VISA 16 digit	38.8054629507739079	-77.0705605421893267
39261	2020-07-23 01:13:05	2020-07-23	Merle Leuschke	merle.leuschke@geemail.com	Vallejo	California	4301301406718	b5ec216e1e3c9a14072e3f029df94464	Voyager	38.102939283810187	-122.211718663746481
39262	2020-07-23 01:13:25	2020-07-23	Robbie Brown	robbie.brown@woohoo.com	Murfreesboro	Tennessee	3051677389902028	f6dff9a454c8b09509d62ccea446c7ab	VISA 16 digit	35.7712574506297756	-86.3189246862046389
39263	2020-07-23 01:24:38	2020-07-23	Emeline Sawayn	emeline.sawayn@warmmail.com	Rancho Cucamonga	California	52138251454047352	670e363c9156bf5dbb150e7477a0d86a	JCB 16 digit	34.0325039147391948	-117.638075815933576
39264	2020-07-23 01:28:08	2020-07-23	Delmas Nolan V	delmas.nolan.v@geemail.com	Lakewood	Colorado	6011926160361280038	413bd784553d2396d9ef2714d87ab867	VISA 16 digit	39.7733916133116949	-105.048567958131798
39265	2020-07-23 02:06:10	2020-07-23	Lex Halvorson I	lex.halvorson.i@woohoo.com	Philadelphia	Pennsylvania	3720852093995181	d840a9910d1ae2d2d30d8eacda28de9a	JCB 16 digit	40.0715074452996234	-75.115718464031076
39266	2020-07-23 02:21:13	2020-07-23	Deryl Stehr-Gulgowski	deryl.stehr.gulgowski@geemail.com	Fort Worth	Texas	869993872258777390	9d4392dd9863a9556dbbf2eb9a1c4dea	VISA 16 digit	32.8533941736035047	-97.4124505381386712
39267	2020-07-23 02:30:53	2020-07-23	Blanche Satterfield	blanche.satterfield@geemail.com	Los Angeles	California	180002633760833307	088c79e9aa3769a0979a59bce009d289	Maestro	33.9382503631856238	-118.438519058608634
39268	2020-07-23 02:33:18	2020-07-23	Menachem Herzog	menachem.herzog@geemail.com	Brownsville	Texas	180080182421651570	ac403ce2f77eb79316908a81cea2fbd1	JCB 16 digit	25.9212491992007941	-97.5185403337422798
39269	2020-07-23 02:36:59	2020-07-23	Mr. Nicholaus Harris	mr.nicholaus.harris@geemail.com	New York	New York	6011100610419944090	2eb14f9435b15018712ddb21ae29a3b1	Discover	40.6026214822884626	-73.9098377542931502
39270	2020-07-23 02:43:58	2020-07-23	Lilian Cruickshank	lilian.cruickshank@woohoo.com	Chicago	Illinois	4171861027281	1b01de076823d07942ab16ac56833386	Voyager	41.9020636224489706	-87.7735955536395238
39271	2020-07-23 03:24:55	2020-07-23	Mrs. Corinna Morar PhD	mrs.corinna.morar.phd@geemail.com	Victorville	California	3044446406271727	8a0beca33e8d541bbfdf31fd7d78d2b9	JCB 16 digit	34.6273463299728945	-117.43340985580943
39272	2020-07-23 03:34:58	2020-07-23	Dr. Areli Windler	dr.areli.windler@woohoo.com	Newark	New Jersey	060466290485367	098678655959be15afefadfafa8516c4	VISA 13 digit	40.7250222229778771	-74.2496919437054572
39273	2020-07-23 03:43:59	2020-07-23	Pablo Hickle DVM	pablo.hickle.dvm@geemail.com	Greeley	Colorado	3003678406385716	b9f717af8d34b348a8c53789ef7c3b70	Diners Club / Carte Blanche	40.3710762195821857	-104.699808929984272
39274	2020-07-23 03:44:06	2020-07-23	Berenice Cole	berenice.cole@geemail.com	New York	New York	639087530908851	e285aaca23c5f3e4890e6ac3067f31cf	JCB 16 digit	40.6217766259089075	-73.9591283232335002
39275	2020-07-23 03:45:09	2020-07-23	Leia Sipes	leia.sipes@geemail.com	Salem	Oregon	4365786515138033	18f92c46b5f4e32dbc7a944e2823eedc	American Express	44.8728587259806631	-122.965926710857829
39276	2020-07-23 03:47:13	2020-07-23	Orie Kris	orie.kris@geemail.com	Los Angeles	California	210038364312359454	1fb137419de47d5ee51b9a4672364189	Maestro	34.0212685764167446	-118.392330084740365
39277	2020-07-23 03:59:26	2020-07-23	Phil McClure	phil.mcclure@geemail.com	Long Beach	California	4287048548162893	45deede4df0aec564bfd300cb5fc8160	Voyager	33.7968786090899229	-118.192489651327207
39278	2020-07-23 04:00:13	2020-07-23	General Dicki	general.dicki@geemail.com	Fort Wayne	Indiana	4872568026376526	962737d256f9b73793d0ba0fa3e04635	Discover	41.1255237665276994	-85.0558380721356713
39279	2020-07-23 04:00:51	2020-07-23	Rowena Will	rowena.will@geemail.com	Houston	Texas	3792091948053689	54a709fcdb0a53478d2dc95dcc6ed13e	Discover	29.7620063346423223	-95.4487728532418629
39280	2020-07-23 04:01:47	2020-07-23	Grayson Turcotte	grayson.turcotte@geemail.com	New York	New York	869981981005850287	28248d934f45e58a80ce7030e0eb045f	JCB 16 digit	40.5775885534696243	-74.0382021533221035
39281	2020-07-23 04:12:46	2020-07-23	Earlie Blick	earlie.blick@warmmail.com	Charlotte	North Carolina	3767078448313870	b386e17f5e8a8199a0dba1ad82c7acb0	Voyager	35.2199278567705321	-80.7402082911636683
39282	2020-07-23 04:20:37	2020-07-23	Lexi Hintz	lexi.hintz@geemail.com	Philadelphia	Pennsylvania	4238238632394375	3e94b994420b6fe4fb6b5ae20027280b	Maestro	40.0344564532354497	-75.064578871046379
39283	2020-07-23 04:22:30	2020-07-23	Natalie Aufderhar-Hills	natalie.aufderhar.hills@warmmail.com	San Francisco	California	6011043535378844264	2aae8e9de091dab6f9009d338c677ddd	JCB 16 digit	37.7755744593325318	-122.443432777356222
39284	2020-07-23 04:32:26	2020-07-23	Dr. Cade Predovic MD	dr.cade.predovic.md@geemail.com	Oakland	California	210004335170815324	5aea00b28fb11c31a3461ac4d066f8a5	Mastercard	37.8188482236323011	-122.255787703585852
39285	2020-07-23 04:35:15	2020-07-23	Melvyn Carroll	melvyn.carroll@geemail.com	Hampton	Virginia	3112767423357230108	152f58bb6b6cd2207811322a7c8c8072	Diners Club / Carte Blanche	37.1281102013327171	-76.388145982856301
39286	2020-07-23 04:51:05	2020-07-23	Venice D'Amore	venice.d'amore@geemail.com	Austin	Texas	3473054508551115	53bdeb3c19db15f73a113f9c6cf89598	Maestro	30.3632276752624648	-97.6549478331819216
39287	2020-07-23 04:54:40	2020-07-23	Cortney Feil	cortney.feil@warmmail.com	Chicago	Illinois	3711066424887816	4630f5e0978e88b59a8ad29c63401a45	Mastercard	41.8602187537889918	-87.7427035206027313
39288	2020-07-23 05:01:39	2020-07-23	Matilde Connelly	matilde.connelly@warmmail.com	San Jose	California	3025568488127961	05ddfbc771fb87dd5bbb7ec48ffee9fc	Maestro	37.2237594256464419	-121.745467291188987
39289	2020-07-23 05:10:23	2020-07-23	Humphrey Feil	humphrey.feil@geemail.com	Phoenix	Arizona	869996553468010536	2dbf3aeb6dd3db14ddcbf815ea156d79	American Express	33.54776718424894	-112.121279608032111
39290	2020-07-23 05:23:12	2020-07-23	Janyce Gorczany DDS	janyce.gorczany.dds@woohoo.com	Jersey City	New Jersey	4646039604435360	0216efa058c7273b77d258f3d74f1e6a	Mastercard	40.6998072809945768	-73.980313185178872
39291	2020-07-23 05:25:27	2020-07-23	Dewey Effertz	dewey.effertz@geemail.com	San Francisco	California	3528468902692109236	c48631c163e251e76e7cdf175aaa52d5	Diners Club / Carte Blanche	37.7626973266490182	-122.432784689060114
39292	2020-07-23 05:31:46	2020-07-23	Gilbert Kling DVM	gilbert.kling.dvm@geemail.com	New York	New York	3096787804928677800	da52ae74b30f323300c5744d87e40b75	Mastercard	40.6055795959886154	-73.9739109105326236
39293	2020-07-23 05:35:09	2020-07-23	Broderick Walker-Barrows	broderick.walker.barrows@geemail.com	San Antonio	Texas	210036971977209287	e047cff6a5aa8c2515f14d68ca681c1b	Mastercard	29.4519854866039026	-98.5964626218493976
39294	2020-07-23 05:47:03	2020-07-23	Amirah Grady	amirah.grady@warmmail.com	Los Angeles	California	6011523172460070597	29a8d4390ef7ad0c3c7ed274b065f2bb	VISA 16 digit	33.9309439169108842	-118.333122986368082
39295	2020-07-23 06:06:50	2020-07-23	Krystal Kilback	krystal.kilback@geemail.com	Garland	Texas	869999038851954166	df6e788de28ed97164dc06392fecc2d8	Diners Club / Carte Blanche	32.8982640656411647	-96.5540913209479328
39296	2020-07-23 06:12:15	2020-07-23	Octave Krajcik	octave.krajcik@warmmail.com	Grand Prairie	Texas	869943005296989021	bd4c8f69ab0cb999f849bc6e7f333e76	VISA 16 digit	32.7626437541149542	-96.937448203690721
39297	2020-07-23 06:23:56	2020-07-23	Henderson Osinski	henderson.osinski@geemail.com	Phoenix	Arizona	210005896580667778	8b38af1ed418be21ce30b77e95cee8d0	Mastercard	33.6087102992858746	-112.00896610169896
39298	2020-07-23 06:24:07	2020-07-23	Alvaro Weissnat	alvaro.weissnat@geemail.com	San Francisco	California	630434516424032	dcff9d7c49b26d8a5b990628f5a0f861	JCB 16 digit	37.7254753804454737	-122.417898422310117
39299	2020-07-23 06:35:05	2020-07-23	Candice Rath	candice.rath@geemail.com	Detroit	Michigan	6011175417828821616	90c25f85f47eec8387cd3e29d54b97e3	Mastercard	42.4762514713145833	-83.0463813895478751
39300	2020-07-23 06:49:27	2020-07-23	Adele Dietrich-Farrell	adele.dietrich.farrell@geemail.com	Berkeley	California	210037764384376214	e8f1bd3ab108447dc77b4a0805e845f3	Mastercard	37.8683232436873425	-122.286720417895921
39301	2020-07-23 06:49:34	2020-07-23	Ariella Powlowski	ariella.powlowski@geemail.com	Fort Collins	Colorado	3112328183894177608	248dc60d9dfba2b8f3ae53493aa50377	Maestro	40.4971688564557581	-105.018753912341978
39302	2020-07-23 06:59:29	2020-07-23	Minor Olson	minor.olson@geemail.com	San Antonio	Texas	55304507168615885	3c77c074db169a4d0544cc2d1e95904b	JCB 15 digit	29.4725340650487695	-98.5061426298528886
39303	2020-07-23 07:00:53	2020-07-23	Rosy Gerlach	rosy.gerlach@warmmail.com	High Point	North Carolina	501870941468327	bffe7c1f37087fb0da0797829515621b	JCB 16 digit	35.9608126346115071	-80.074121880644924
39304	2020-07-23 07:05:15	2020-07-23	Mr. Michael Bergnaum II	mr.michael.bergnaum.ii@geemail.com	Riverside	California	210086727467299579	b4bdcac2c55f7bdfae51d8a3582d098a	Discover	33.8671245062671602	-117.355123340475174
39305	2020-07-23 07:07:33	2020-07-23	Ms. Clora Pouros	ms.clora.pouros@woohoo.com	San Francisco	California	54553588728200416	35895377d23d8b18a65ec67ef876b486	Maestro	37.7644633755283223	-122.440742334876916
39306	2020-07-23 07:07:37	2020-07-23	Ms. Eleonore Gottlieb DDS	ms.eleonore.gottlieb.dds@warmmail.com	Lancaster	California	4511196416974	fcad435da98e6aa60c32273b1dd94300	JCB 15 digit	34.7095708252176678	-118.273951961982249
39307	2020-07-23 07:12:58	2020-07-23	Shawanda Kunze	shawanda.kunze@geemail.com	San Francisco	California	6011245149099942963	db851d733741f15b721b443bb59c775b	JCB 16 digit	37.7751525700173687	-122.413713282104595
39308	2020-07-23 07:13:34	2020-07-23	Eldon Leuschke	eldon.leuschke@geemail.com	Abilene	Texas	869990120364777596	7efb36699a93284807ad02b87a74fa6c	Discover	32.4680902462527214	-99.6794986094296007
39309	2020-07-23 07:15:52	2020-07-23	Jaquan Doyle	jaquan.doyle@geemail.com	Oakland	California	3479805228879233	42af85ea3636ad53019078c6c16d9795	Discover	37.822264127416652	-122.276247796589757
39310	2020-07-23 07:24:28	2020-07-23	Karsyn Smith	karsyn.smith@warmmail.com	Indianapolis	Indiana	3428274269637525	d813ec4a6f91bcafd4e1c2f11c88af40	Maestro	39.809988012072445	-86.1511734355442229
39311	2020-07-23 07:29:02	2020-07-23	Dwayne Lakin	dwayne.lakin@warmmail.com	Boston	Massachusetts	3025292139884520	1e7d307a36ebbae74d8e9985b8892a11	JCB 16 digit	42.2635528396982707	-71.0695735167197853
39312	2020-07-23 07:31:31	2020-07-23	Miss Ruthie Huels DVM	miss.ruthie.huels.dvm@geemail.com	Everett	Washington	4489510283107066	de5ff27a7d0861176f8bc080ba2b393c	JCB 16 digit	47.888079041138667	-122.127718247625609
39313	2020-07-23 07:32:00	2020-07-23	Margarita Ankunding	margarita.ankunding@woohoo.com	Miramar	Florida	4305948190972416	59d335bffaff57edce75d0e6a7fb3022	American Express	26.0157338799890141	-80.3752625172950417
39314	2020-07-23 07:33:17	2020-07-23	Ms. Marge Schmeler	ms.marge.schmeler@geemail.com	San Francisco	California	180058319857105527	73f88f5cebe092aa9e80e8531fc4feec	JCB 16 digit	37.7843826869031005	-122.443447923660102
39315	2020-07-23 07:36:42	2020-07-23	Theodore Emmerich	theodore.emmerich@warmmail.com	Tampa	Florida	6011807718997546199	8965057348a008b79ca28bb4a895c041	JCB 15 digit	27.8926373931694762	-82.550016071389237
39316	2020-07-23 07:38:18	2020-07-23	Shea Rutherford	shea.rutherford@geemail.com	Tempe	Arizona	869986576692805225	a5e05270d49246993ba4796b78943705	VISA 16 digit	33.4511850753720807	-111.860312874059375
39317	2020-07-23 07:46:28	2020-07-23	Mr. Derald Bosco	mr.derald.bosco@geemail.com	San Francisco	California	4918220028735608	3961600c0689e016e5d0cbcc4cfb17b0	American Express	37.761414088273817	-122.399069080073971
39318	2020-07-23 07:56:44	2020-07-23	Blas Stoltenberg	blas.stoltenberg@geemail.com	Austin	Texas	3776478521863867	eae2d4b4445e00c7dcd7f454b76f2f21	Voyager	30.2700209203302855	-97.8403908040147314
39319	2020-07-23 08:09:35	2020-07-23	Angus Fay	angus.fay@geemail.com	Phoenix	Arizona	6011358079884788243	18c5165d0d0f02650f5b3f365f8643f4	American Express	33.531949298263342	-112.181057880252979
39320	2020-07-23 08:15:47	2020-07-23	Nohely Skiles DDS	nohely.skiles.dds@woohoo.com	New York	New York	4477961768684398	00fd50e4d6a1254651394831c8f80a84	American Express	40.7478097280710898	-74.0028768205445289
39321	2020-07-23 08:28:05	2020-07-23	Humberto Bernier	humberto.bernier@geemail.com	Austin	Texas	3158979864044682629	8d4e8f3de0068d2c3acaf7c72c7255af	VISA 16 digit	30.287332273799553	-97.7481717362307023
39322	2020-07-23 08:36:55	2020-07-23	Dr. Roe Schulist PhD	dr.roe.schulist.phd@woohoo.com	Fort Worth	Texas	4666849259823	c964b3cb2e8b97852e1768990d2da29f	Mastercard	32.7341134002022471	-97.2760035386130255
39323	2020-07-23 09:04:21	2020-07-23	Dr. Ewin Doyle III	dr.ewin.doyle.iii@geemail.com	Houston	Texas	869947932986091469	c6853c23bd747c2413daffa8087a356b	American Express	29.809967835581304	-95.3363619739204609
39324	2020-07-23 09:11:12	2020-07-23	Ms. Cadence McClure DVM	ms.cadence.mcclure.dvm@geemail.com	Peoria	Arizona	3112250015577278067	4c8d5ce1ff635eb4e29691ae9ddb7c14	VISA 16 digit	33.812000299551336	-112.286935507033022
39325	2020-07-23 09:17:07	2020-07-23	Cher Cronin PhD	cher.cronin.phd@geemail.com	San Francisco	California	3710486283906823	d1f100a81c8b60a77a2e2e583a04506d	Diners Club / Carte Blanche	37.7935813957927564	-122.480574443985219
39326	2020-07-23 09:20:16	2020-07-23	Tavion Tromp-Sanford	tavion.tromp.sanford@geemail.com	San Francisco	California	6011392451349063090	c9481e96ebbeaab914ea41cb1936613b	JCB 15 digit	37.7310613931577876	-122.426598255326041
39327	2020-07-23 09:21:08	2020-07-23	Levi Renner	levi.renner@warmmail.com	Los Angeles	California	4163961214901	f4e646a75ebe1bd529e9ddc34e1508ba	VISA 13 digit	33.9848938349965906	-118.389356726640088
39328	2020-07-23 09:36:29	2020-07-23	Ms. Caryl Balistreri DVM	ms.caryl.balistreri.dvm@geemail.com	San Antonio	Texas	3015421097887031	67c04036cf91e122e1a280852f9d9885	Mastercard	29.4408540269896406	-98.5161498480312474
39329	2020-07-23 09:39:28	2020-07-23	Ms. Kimberly Schumm MD	ms.kimberly.schumm.md@geemail.com	New York	New York	53250211418207759	344f678a1de0a22effa69935ecaf2f2d	JCB 15 digit	40.7457135658469056	-73.926448666899276
39330	2020-07-23 09:42:57	2020-07-23	Thomas Pouros	thomas.pouros@geemail.com	San Diego	California	676355736988852	168a3dac772a5dbe5020af2d4d0794eb	VISA 13 digit	32.8847752242416149	-117.136436265092343
39331	2020-07-23 09:43:34	2020-07-23	Jerrad Berge	jerrad.berge@geemail.com	Houston	Texas	3096971086403679024	001115964e4fcc64aed5c07758d007ad	VISA 16 digit	29.8041507535226629	-95.4782501549940577
39332	2020-07-23 09:46:29	2020-07-23	Waverly Turcotte Jr.	waverly.turcotte.jr.@geemail.com	Portland	Oregon	3528058578082501509	5588b85e6ae3143f4797deba67ee903b	Diners Club / Carte Blanche	45.4873348066937169	-122.674306615535173
39333	2020-07-23 09:55:22	2020-07-23	Jabbar Kiehn-Hansen	jabbar.kiehn.hansen@geemail.com	Rockford	Illinois	869963147300128306	16e8b504dcda1cbeb91ae5a40a90ef89	Maestro	42.3276726570922861	-89.0104977610338466
39334	2020-07-23 09:56:22	2020-07-23	Emmer Schneider	emmer.schneider@geemail.com	Santa Ana	California	4382682681442	7202f7f1b340ba43d9b2110369e419c5	Diners Club / Carte Blanche	33.6904752123739542	-117.962079301236187
39335	2020-07-23 10:07:15	2020-07-23	Tabitha Lesch-Graham	tabitha.lesch.graham@geemail.com	Palm Bay	Florida	210017848003916361	ff1295d94d4e4f64c23334afa0a2658a	Voyager	27.9608411390189104	-80.7179235911764152
39336	2020-07-23 10:15:30	2020-07-23	Redden Schimmel	redden.schimmel@geemail.com	Los Angeles	California	6011353392444129153	07f1dbb46c21d1192063318d6b5db66c	Mastercard	34.089276292347904	-118.467645596618951
39337	2020-07-23 10:16:06	2020-07-23	Leanne Luettgen	leanne.luettgen@woohoo.com	Oceanside	California	180077317737583217	0c794081ce637fd4a5444386d36d665c	American Express	33.2758616659212834	-117.342556410710145
39338	2020-07-23 10:36:18	2020-07-23	Clair Cormier-Mayer	clair.cormier.mayer@geemail.com	Wichita	Kansas	3483078447598166	f7da15a1c6e7fd41e95eefc1609f317f	Diners Club / Carte Blanche	37.6343468133237238	-97.2662101690392973
39339	2020-07-23 10:40:33	2020-07-23	Mrs. Clair Volkman	mrs.clair.volkman@woohoo.com	Rochester	New York	3337426515742901641	c9305aef36511c9b8aaa1f296a0bebf3	JCB 15 digit	43.1247472202848598	-77.626694505219902
39340	2020-07-23 11:10:35	2020-07-23	Syed Dietrich	syed.dietrich@geemail.com	San Francisco	California	3158147417035794080	c4a45c17ef7e3a65262879b5290fdf9f	Mastercard	37.7789701785106899	-122.410352712415261
39341	2020-07-23 11:20:02	2020-07-23	Dr. Clark Gleason PhD	dr.clark.gleason.phd@geemail.com	Los Angeles	California	4045575828848	1c26e89192d68e0101d4346aa2b712d0	VISA 16 digit	34.0380410076916178	-118.46711336439401
39342	2020-07-23 11:25:31	2020-07-23	Kurt Barrows	kurt.barrows@geemail.com	New York	New York	210014553195454030	045f35fc83564a866cdfa614de037d54	JCB 15 digit	40.6269905655402681	-73.8577233142580809
39343	2020-07-23 11:25:56	2020-07-23	Tina Schuster DVM	tina.schuster.dvm@geemail.com	Dallas	Texas	4077849049783622	9756aab7eccb961b187c3fd96f105178	VISA 13 digit	32.7710958739548914	-96.7443450615703995
39344	2020-07-23 11:27:02	2020-07-23	Kael Murazik-Rowe	kael.murazik.rowe@geemail.com	Detroit	Michigan	51425202242533627	3ce1121be3e5f1e72bfd1c3b59215548	VISA 16 digit	42.4716050267610754	-83.1619725880332226
39345	2020-07-23 11:53:13	2020-07-23	Gunda Carter	gunda.carter@geemail.com	New York	New York	51388490958639762	aa51d4065922050a3c6f5df41a3e5a4a	VISA 13 digit	40.7250669493097774	-73.8713744041405533
39346	2020-07-23 11:54:17	2020-07-23	Dr. Gaige D'Amore	dr.gaige.d'amore@geemail.com	New York	New York	55612967905795498	ef86d89f6cbc840ec9888110344204f2	VISA 16 digit	40.5712340990770599	-73.8542978769529554
39347	2020-07-23 12:24:56	2020-07-23	Eric Berge	eric.berge@warmmail.com	Los Angeles	California	3528278609532082198	38e266504099bec04baa5af97f2ec66d	Maestro	34.0976428462058294	-118.36619461774751
39348	2020-07-23 12:26:41	2020-07-23	Coleen Kuhn	coleen.kuhn@geemail.com	Chesapeake	Virginia	3088229852339201690	15ffc72e4eee97c219ab688b34e29694	Discover	36.6466068849671629	-76.3308803290903626
39349	2020-07-23 12:28:48	2020-07-23	Sheyla Bogisich	sheyla.bogisich@geemail.com	Fremont	California	4484386228277818	4f7663a467d59cc7cd251235c6de0c07	VISA 13 digit	37.434382976887747	-121.922713954745603
39350	2020-07-23 12:30:35	2020-07-23	Keandre Stamm	keandre.stamm@geemail.com	San Bernardino	California	3158004519914962175	1d5642fc99197830420aed0e8945cbb1	VISA 16 digit	34.1789971337918175	-117.233301586589221
39351	2020-07-23 12:33:34	2020-07-23	Dr. Ronaldo Ankunding III	dr.ronaldo.ankunding.iii@woohoo.com	Detroit	Michigan	4760163415176	15a106b40d50d091e22117ec10d217ea	VISA 16 digit	42.3041687535513233	-83.0608206878069808
39352	2020-07-23 12:34:43	2020-07-23	Eliana Casper	eliana.casper@geemail.com	Oakland	California	869932613965767504	4b556eb9a5ecde8992d6dd645cdaeaf8	JCB 16 digit	37.7858165869917926	-122.253161012025473
39353	2020-07-23 12:41:11	2020-07-23	Latasha Stamm	latasha.stamm@woohoo.com	College Station	Texas	869943505122303925	0aaab9eb5c21571c04f07c41310ca1a6	Maestro	30.5083892807409178	-96.3919389109905893
39354	2020-07-23 12:45:02	2020-07-23	Grace Luettgen	grace.luettgen@geemail.com	Rockford	Illinois	3453980480366250	2ccb045d67ef1f77a6d24496f4b9ff3e	Maestro	42.2886383644782029	-89.0547671339757727
39355	2020-07-23 12:48:14	2020-07-23	Mr. Orie Little	mr.orie.little@geemail.com	Anchorage	Alaska	869915494423406303	05bf1b7e24cf8dfbc4bc1ab48d3e6f09	Voyager	61.1386958598841019	-149.278952863033112
39356	2020-07-23 12:53:53	2020-07-23	Elsworth Larson	elsworth.larson@geemail.com	San Francisco	California	676116164003895	56c39c309766bfb474a64eb392f5d67b	Discover	37.8272894095206738	-122.494257253205504
39357	2020-07-23 13:00:04	2020-07-23	Mrs. Laraine Jast	mrs.laraine.jast@geemail.com	Clearwater	Florida	6011547664274161184	e2f80de7e80a875d46b1ffef572be4a0	JCB 16 digit	28.0031557021323572	-82.7704705867715091
39358	2020-07-23 13:04:29	2020-07-23	Jerald Keeling MD	jerald.keeling.md@geemail.com	Renton	Washington	4339368458009332	713479282ec94fb7739b30180fdd815b	Diners Club / Carte Blanche	47.3901302598476448	-122.275691928721955
39359	2020-07-23 13:13:09	2020-07-23	Willia Strosin-Graham	willia.strosin.graham@geemail.com	Fresno	California	6011809808836821552	22f0af0f469bf81199018bfa07244b11	VISA 16 digit	36.8134872992396325	-119.889202875142544
39360	2020-07-23 13:15:04	2020-07-23	Loren Larkin DVM	loren.larkin.dvm@warmmail.com	Houston	Texas	3011662255023281	b9604cc7a6813f49558add7e42064865	Maestro	29.8022700827181346	-95.3466975899428206
39361	2020-07-23 13:22:17	2020-07-23	Burl Pagac	burl.pagac@geemail.com	Salem	Oregon	6011632218801625553	0f452d6911f6e40f02ca392819dfa9a4	JCB 15 digit	44.9943364324781996	-123.103577915455034
39362	2020-07-23 13:30:03	2020-07-23	Male Cormier	male.cormier@warmmail.com	Philadelphia	Pennsylvania	55522842082325246	10568193e06092b34fb00b8633064d83	JCB 16 digit	39.983923044982923	-75.0602819582812515
39363	2020-07-23 13:52:54	2020-07-23	Mrs. Gwendolyn Kemmer	mrs.gwendolyn.kemmer@warmmail.com	Berkeley	California	869918214218776794	f815e5da8651db97ccb85e5285a7e72f	Maestro	37.8791001696981553	-122.295780920596073
39364	2020-07-23 13:56:10	2020-07-23	Arvil Gusikowski	arvil.gusikowski@geemail.com	Irvine	California	4382441397764956	3d76f49eb9ec3670787e268c94d401a5	JCB 15 digit	33.6139291573330823	-117.834510274977603
39365	2020-07-23 14:00:08	2020-07-23	Bula Breitenberg	bula.breitenberg@geemail.com	Phoenix	Arizona	4235837650657986	ffae1ebfda0f0562f45e478f98421363	VISA 16 digit	33.5593359706390686	-112.067630816569931
39366	2020-07-23 14:05:37	2020-07-23	Theodora Jast	theodora.jast@geemail.com	Santa Ana	California	180006606127862587	2b2271101abd9c8f9a63a3f4e28221c6	VISA 13 digit	33.6870961377967149	-117.879004223404451
39367	2020-07-23 14:10:17	2020-07-23	Arvid Torphy-Walter	arvid.torphy.walter@geemail.com	San Francisco	California	4403314842205377	333f107d5152771a582d96f31ae97a10	Maestro	37.7567930025933691	-122.448425162147501
39368	2020-07-23 14:27:49	2020-07-23	Misti Fahey	misti.fahey@geemail.com	New York	New York	52906694579977344	ae289b057f96b826619ed9fa1f4fd31c	Discover	40.7050200942661604	-73.9640301821649047
39369	2020-07-23 14:28:33	2020-07-23	Mr. Jamey Auer IV	mr.jamey.auer.iv@geemail.com	Chula Vista	California	54814447567131833	a45aea36f3f721fc088670c2665a6667	American Express	32.6742121794491993	-116.957602401566504
39370	2020-07-23 14:32:24	2020-07-23	Wes Gulgowski	wes.gulgowski@warmmail.com	Jacksonville	Florida	4653331421403014	a2ebb32cb652c658db7ee7fb014f9bcd	JCB 16 digit	30.2751395611144609	-81.5988050754725975
39371	2020-07-23 14:33:56	2020-07-23	Mr. Vernon Bauch III	mr.vernon.bauch.iii@geemail.com	Spokane	Washington	676186970892427	7f6e591e15b31625b935fd722fff062b	American Express	47.6842535073175995	-117.48474894663245
39372	2020-07-23 14:42:46	2020-07-23	Karel Shanahan	karel.shanahan@geemail.com	New York	New York	4750398069639276	e09f189f2965a01f54f866605c4366ca	Discover	40.5666569617800405	-73.8912386698078336
39373	2020-07-23 14:54:00	2020-07-23	Lindbergh Fahey	lindbergh.fahey@geemail.com	New York	New York	4618559451631740	34840599a2c255ab11661b5f59122528	Diners Club / Carte Blanche	40.6470381888318784	-73.8893806097924681
39374	2020-07-23 14:57:56	2020-07-23	Mr. Kennedy Wuckert	mr.kennedy.wuckert@geemail.com	Winston–Salem	North Carolina	3337393862719227520	766d1321fa77ac5b148404d05e344736	VISA 16 digit	36.0805567276895047	-80.3525887922048554
39375	2020-07-23 14:58:15	2020-07-23	Vertie Dare	vertie.dare@geemail.com	Sugar Land	Texas	3528151351403100237	a3253f1fb69af0a34abf55de4eb689b3	JCB 15 digit	29.6168548335839041	-95.6479082176003601
39376	2020-07-23 15:02:07	2020-07-23	Lloyd Torp	lloyd.torp@geemail.com	Tuscaloosa	Alabama	3786326407947643	955f9dbb8309666a260fb6d2b49e0121	American Express	33.1608274841271324	-87.5826760039761609
39377	2020-07-23 15:04:43	2020-07-23	Hartwell Stanton	hartwell.stanton@geemail.com	Montgomery	Alabama	210084915074293067	e1682cf012161fab9fd9aafa9dac6e73	Diners Club / Carte Blanche	32.3154237437926213	-86.2178081415280673
39378	2020-07-23 15:06:35	2020-07-23	Dr. Armani Torphy	dr.armani.torphy@woohoo.com	Boston	Massachusetts	3088287597752152677	996b77559f5e6027ea93443d9967f67b	VISA 16 digit	42.2841478241309545	-71.0799790993750094
39379	2020-07-23 15:10:28	2020-07-23	Alvan Sauer II	alvan.sauer.ii@geemail.com	San Diego	California	3018459548930239	55054a16adb20367e2ae28b906d1b8ce	Discover	32.8619959237586698	-117.065814907699831
39380	2020-07-23 15:12:08	2020-07-23	Jenilee Hirthe	jenilee.hirthe@geemail.com	Los Angeles	California	3096851947979614205	ef732d2a0f2e5f8c28533307e0c43529	Voyager	33.9815407651808101	-118.454739983751622
39381	2020-07-23 15:14:26	2020-07-23	Alma Spinka PhD	alma.spinka.phd@woohoo.com	Grand Prairie	Texas	4408311361856171	08e2a4946111c62456195f2d1da6650a	Diners Club / Carte Blanche	32.7418755039159208	-97.015127065113191
39382	2020-07-23 15:23:18	2020-07-23	Eathel Donnelly	eathel.donnelly@geemail.com	Chicago	Illinois	3112563400296858906	06e518aca689335817f887e1a3fc10e0	JCB 16 digit	41.8699239477351313	-87.7396388388734323
39383	2020-07-23 15:28:05	2020-07-23	Doss Huel V	doss.huel.v@geemail.com	Saint Paul	Minnesota	52274786064971990	20fc5df4e74d45167478b9050ac61060	Maestro	44.8735515946462797	-93.1207483748704163
39384	2020-07-23 15:34:23	2020-07-23	Magan Reichert	magan.reichert@geemail.com	Nashville	Tennessee	4330914819492433	3ae03a653f2d33fe1dc889bf7078bc5f	VISA 16 digit	36.1442281688220746	-86.6875755331385847
39385	2020-07-23 15:57:33	2020-07-23	Makenzie Walker	makenzie.walker@woohoo.com	Albuquerque	New Mexico	3017085201099169	b01af99ceecd76a353a0ddf867fc206b	VISA 16 digit	35.1241880567878511	-106.591632774386184
39386	2020-07-23 16:04:35	2020-07-23	Ms. Nohely Dickens MD	ms.nohely.dickens.md@geemail.com	New York	New York	4535139863714341	5d42e52744559517df5abd37d5e1114e	JCB 16 digit	40.5658960945196441	-73.8653564053483223
39387	2020-07-23 16:08:13	2020-07-23	Georgene Zulauf	georgene.zulauf@geemail.com	San Jose	California	3096879610116384649	96ae07761da96ba9c51333aba5a650f6	American Express	37.3947076148640392	-121.766912303980064
39388	2020-07-23 16:14:13	2020-07-23	Kathern Wehner	kathern.wehner@geemail.com	Naperville	Illinois	55476906357148264	90910dc3f510497332b382c3822075d5	JCB 16 digit	41.8121831086378535	-88.1203842870779397
39389	2020-07-23 16:46:23	2020-07-23	Tad Frami-Skiles	tad.frami.skiles@geemail.com	Houston	Texas	3337297342225549136	674b2a1996ceab853868c53935883e00	Voyager	29.7543359574008726	-95.385906044302132
39390	2020-07-23 16:54:57	2020-07-23	Waino Rempel-Jast	waino.rempel.jast@warmmail.com	New York	New York	180072053088427606	1a36e2476a5a74f4e3f792ad0ceed821	Diners Club / Carte Blanche	40.7577301457282175	-73.9881517080485764
39391	2020-07-23 17:06:51	2020-07-23	Devyn Schmidt	devyn.schmidt@geemail.com	San Francisco	California	53265804136636243	3dd74056288d4a1c57f4a86a1b219a81	Discover	37.7634069754570803	-122.439539582351472
39392	2020-07-23 17:18:16	2020-07-23	Cecile Donnelly	cecile.donnelly@geemail.com	San Francisco	California	675959825164359	84242bd7074355a4889ac413904a6d99	Discover	37.7812328993425481	-122.456212479102604
39393	2020-07-23 17:43:10	2020-07-23	Chanda Pacocha	chanda.pacocha@geemail.com	Berkeley	California	51142354564489045	fd241b283a5c0c9216981a2580d24d84	Voyager	37.8824149161543602	-122.279610081983591
39394	2020-07-23 17:55:23	2020-07-23	Arley Tremblay	arley.tremblay@geemail.com	Allen	Texas	6011511853880689017	d8c5d4d71fc86d7af64da8732f34652a	Diners Club / Carte Blanche	33.0607394868534072	-96.657729432866347
39395	2020-07-23 17:55:47	2020-07-23	Buell Bins	buell.bins@geemail.com	Santa Maria	California	210037829485947351	87574f104de736b8dd40560dbc4cceb9	VISA 16 digit	34.9780649534024306	-120.540495817960419
39396	2020-07-23 17:59:13	2020-07-23	Coral Bosco PhD	coral.bosco.phd@geemail.com	Pasadena	Texas	561288530058283	0993a853bb44b29ae271368c8b8a3ae4	JCB 16 digit	29.6244818516414625	-95.2385477428738056
39397	2020-07-23 18:00:18	2020-07-23	Ema Hermann	ema.hermann@woohoo.com	San Francisco	California	3096629099900020549	04f1124ba99367de30bc1e16137f5ad1	JCB 15 digit	37.767654786151482	-122.411311499317918
39398	2020-07-23 18:03:23	2020-07-23	Calvin McDermott DVM	calvin.mcdermott.dvm@geemail.com	Fresno	California	3498672720362507	d67fe2e35a02d2c4e5d1ec6110ee4522	Maestro	36.881139937868717	-119.801942738994583
39399	2020-07-23 18:14:19	2020-07-23	Ariana Quitzon	ariana.quitzon@geemail.com	Boston	Massachusetts	3528895896304702011	983c5bffe2cf16e83d1af8e34a2df653	Discover	42.3790807550940656	-71.1011397382196009
39400	2020-07-23 18:16:40	2020-07-23	Salomon Dickens	salomon.dickens@geemail.com	Philadelphia	Pennsylvania	3766255703786534	7da7031e1e761f77090b288ed852e08c	VISA 16 digit	39.9266529835253934	-75.1701573060724968
39401	2020-07-23 18:17:22	2020-07-23	Metro Abbott-Baumbach	metro.abbott.baumbach@geemail.com	San Francisco	California	4726239175590196	96b455eadfe841092fb1f71c8006dbb8	Mastercard	37.7700476570519825	-122.440653428686389
39402	2020-07-23 18:20:28	2020-07-23	Milton Klein	milton.klein@geemail.com	New York	New York	4411059750688250	46bf6b17051b4132ae0b0d4896be4f7e	VISA 16 digit	40.6516870434619477	-74.0141406784661058
39403	2020-07-23 18:20:42	2020-07-23	Mrs. Zelma Jacobi PhD	mrs.zelma.jacobi.phd@geemail.com	Richmond	California	3528999786992580016	3fd85597a06e41548fcfa7c103c40be4	JCB 15 digit	37.8681388402313033	-122.377511983909088
39404	2020-07-23 18:22:20	2020-07-23	Denver Powlowski	denver.powlowski@geemail.com	Sunnyvale	California	3158317972669680033	ed204ad6adc90ee56cc0ba3a5667bced	Discover	37.3293703013092326	-122.002429061356196
39405	2020-07-23 18:27:45	2020-07-23	Mr. Knute Rogahn	mr.knute.rogahn@woohoo.com	Houston	Texas	675981079245189	88ca24c687410aba8b7cf921dccc090e	Maestro	29.830396912766993	-95.3059111249182394
39406	2020-07-23 18:28:44	2020-07-23	Mr. Skip Schoen	mr.skip.schoen@geemail.com	Chicago	Illinois	51115654527698258	c6af60c31d44764b06b8c9343cc5bbd5	Discover	41.8266336314681908	-87.6312300051592246
39407	2020-07-23 18:28:45	2020-07-23	Mr. Arnoldo Rosenbaum Sr.	mr.arnoldo.rosenbaum.sr.@geemail.com	San Jose	California	869997504279716562	f021ad79eec99b115b4235bd41eb4323	Discover	37.3782811973065137	-121.768868748679381
39408	2020-07-23 18:32:20	2020-07-23	Dr. Dorr Dicki	dr.dorr.dicki@geemail.com	Detroit	Michigan	3158382041063876603	01510d82ea4ba1a027852728cb24d147	VISA 16 digit	42.2977197837475742	-83.1700630193695361
39409	2020-07-23 18:39:17	2020-07-23	Shane Miller	shane.miller@geemail.com	Oakland	California	3406156755943150	fcd0bafb9f4d8349e8cc42b4c023b776	Discover	37.8281194602199591	-122.264357566504643
39410	2020-07-23 18:39:25	2020-07-23	Marchello Cummerata II	marchello.cummerata.ii@warmmail.com	San Francisco	California	4085875909845763	f91b851fa4d73e3b1d8378b83de8331d	Diners Club / Carte Blanche	37.786249972818716	-122.439036559583485
39411	2020-07-23 18:49:11	2020-07-23	Alijah Heathcote Jr.	alijah.heathcote.jr.@geemail.com	Yonkers	New York	869916560736040234	e966d1215cf94dc31aadf1e4d3cb0fb0	Voyager	40.8871407653871941	-73.9339451469831204
39412	2020-07-23 19:01:07	2020-07-23	Arabella Dicki	arabella.dicki@geemail.com	Coral Springs	Florida	676365088000446	a7afcbd957f2594ba07f8546c097ec8d	American Express	26.32145848903507	-80.3163998530834817
39413	2020-07-23 19:02:09	2020-07-23	Coty Feil	coty.feil@geemail.com	Plano	Texas	3030027507530262	531669815ebabbcb004aae7db202044e	Voyager	33.1452620207417752	-96.6656729132119636
39414	2020-07-23 19:02:50	2020-07-23	Worth Dickens V	worth.dickens.v@geemail.com	Reno	Nevada	6011993740298833120	bf0c87781500e5887cc049a4631b1559	Maestro	39.4532782006155713	-119.877208266889312
39415	2020-07-23 19:09:24	2020-07-23	Inell Rohan DDS	inell.rohan.dds@geemail.com	Sacramento	California	6011884734496890224	4aca1ca0fee86eb666d5ff14024a11d0	VISA 16 digit	38.5681113771893109	-121.498516291218252
39416	2020-07-23 19:20:12	2020-07-23	Dr. Evia Luettgen	dr.evia.luettgen@geemail.com	San Antonio	Texas	3788180667721018	1891057114ce7345f57fb55015297603	Mastercard	29.519369121741132	-98.4793890377342649
39417	2020-07-23 19:21:25	2020-07-23	Ms. Anjanette Lynch	ms.anjanette.lynch@geemail.com	Milwaukee	Wisconsin	51509284077777338	f2eadf5303dff940f4e37f6973fa486f	Diners Club / Carte Blanche	43.1541153715543402	-88.0049771798875184
39418	2020-07-23 19:30:18	2020-07-23	Autry Fritsch	autry.fritsch@woohoo.com	Gainesville	Florida	54875199233731548	950d7f49337445af02d79a527e44dc41	VISA 16 digit	29.6321696256112297	-82.3659934718035203
39419	2020-07-23 19:32:46	2020-07-23	Unknown Hintz	unknown.hintz@warmmail.com	Omaha	Nebraska	3112684327182713917	e30315ebc432a01dbed3ba408a583320	Voyager	41.1754031606163835	-96.0271617323741395
39420	2020-07-23 19:33:54	2020-07-23	Stephenie Lockman	stephenie.lockman@geemail.com	Fayetteville	North Carolina	3112939014028807557	def159c2e2f27d81aab7f516b74b411b	Diners Club / Carte Blanche	35.1559242109090064	-78.9341818473897945
39421	2020-07-23 19:39:29	2020-07-23	Erna Quigley	erna.quigley@geemail.com	New York	New York	3096191722427634330	0a9dc8d623ddff722a83cd9cbed0ba66	Mastercard	40.7418620805945224	-74.0082334355812463
39422	2020-07-23 19:40:33	2020-07-23	Ah Wiegand-Daugherty	ah.wiegand.daugherty@geemail.com	New York	New York	3337612359148917461	0bfbf6b6fdad824c96054753a542545b	American Express	40.6672938844878189	-73.8828275757271768
39423	2020-07-23 19:50:41	2020-07-23	Anahi Lubowitz	anahi.lubowitz@geemail.com	San Francisco	California	210021857202557300	031616c84c3f6225bf459ea66f0be5fa	Mastercard	37.7813405069465915	-122.458372592056477
39424	2020-07-23 19:58:34	2020-07-23	Mr. Kameron Stoltenberg MD	mr.kameron.stoltenberg.md@geemail.com	San Jose	California	52294480683418171	c56ba7a586d08db80066cbcc294d3945	VISA 16 digit	37.3680962167967152	-121.898539706062152
39425	2020-07-23 20:13:55	2020-07-23	Gaven Trantow-Kshlerin	gaven.trantow.kshlerin@warmmail.com	Rockford	Illinois	52507105482182768	fdfb43e9e01c0cf7cdd9d79f1ddb56db	VISA 13 digit	42.2548269200149917	-89.0204615682180957
39426	2020-07-23 20:20:44	2020-07-23	Ms. Larissa Turcotte MD	ms.larissa.turcotte.md@geemail.com	Fresno	California	53156966427819143	d7e4f11633e1244fe09788a3d7ac9d7f	Mastercard	36.6906198440924314	-119.778589496958631
39427	2020-07-23 20:27:20	2020-07-23	Miss Manuela Watsica	miss.manuela.watsica@woohoo.com	Akron	Ohio	3711340573582472	3bb44212063c7e2df4a997a2e1b89c21	Maestro	41.1002423182893537	-81.5959847296901017
39428	2020-07-23 20:36:16	2020-07-23	Clare Connelly	clare.connelly@geemail.com	Austin	Texas	3096577524731564839	7c1245f14472c9895b6351985dde1950	JCB 16 digit	30.3186132981102894	-97.7740041693445363
39429	2020-07-23 20:52:03	2020-07-23	Jair Trantow	jair.trantow@warmmail.com	Orange	California	3029430163690001	86853cccdcd302229398f094b1a3b792	Voyager	33.7117127749025798	-117.809962224132562
39430	2020-07-23 21:06:00	2020-07-23	Dr. Wilmer Keebler Jr.	dr.wilmer.keebler.jr.@geemail.com	Philadelphia	Pennsylvania	4271672494812090	d0dfb7124010f41252a0bc4ed3e35ecf	VISA 16 digit	40.0191472396679231	-75.1014355316192024
39431	2020-07-23 21:06:57	2020-07-23	Dagmar Emard	dagmar.emard@geemail.com	New York	New York	3337597160183074385	b382e7e54670d3375e0eb3aa4904c152	Mastercard	40.6771673559434674	-74.009049659956986
39432	2020-07-23 21:15:14	2020-07-23	Simona Sawayn-Bergstrom	simona.sawayn.bergstrom@geemail.com	St. Petersburg	Florida	3088161061064048983	56afb853e6921deba39e0987794a1079	Mastercard	27.7634575497712959	-82.6617550206262592
39433	2020-07-23 21:23:39	2020-07-23	Dr. Ransom Wisozk I	dr.ransom.wisozk.i@geemail.com	San Francisco	California	869914391344782203	671838d71529048e757541a2cdd50108	American Express	37.752988847013647	-122.474630413985437
39434	2020-07-23 21:27:05	2020-07-23	Trula Sporer MD	trula.sporer.md@woohoo.com	San Francisco	California	3112853229736227920	82e12c9baf1193eab15f1ab77ab2bb4d	American Express	37.7805939717720491	-122.44540386034042
39435	2020-07-23 21:29:01	2020-07-23	Mr. Kazuo Witting	mr.kazuo.witting@geemail.com	Fontana	California	210031395485460973	1b839f131dd0a553f53992f425393af4	JCB 16 digit	34.0298061429671961	-117.383529873406147
39436	2020-07-23 21:31:49	2020-07-23	Romello Hoppe	romello.hoppe@warmmail.com	New York	New York	3059436958127638	78b698fcc5b7135901040d26bd5f8c50	Mastercard	40.6251834337823112	-73.947079781292743
39437	2020-07-23 21:47:23	2020-07-23	Anahi Gutkowski	anahi.gutkowski@warmmail.com	Killeen	Texas	3752579626003990	0732f0ca60f730171aada37200a4c34e	Discover	31.0062193655639895	-97.8088275870475883
39438	2020-07-23 21:49:54	2020-07-23	Kit Wuckert	kit.wuckert@geemail.com	San Francisco	California	6011955081946541351	e84da7944e219502f3d8f81be11e7396	JCB 16 digit	37.8065736048028214	-122.403660978252091
39439	2020-07-23 21:57:48	2020-07-23	Jaxson Cartwright	jaxson.cartwright@geemail.com	Los Angeles	California	4334425026351	16fc62e3bff9a06ebc836b20be62fbf8	VISA 16 digit	33.9334700778923875	-118.47936182878837
39440	2020-07-23 22:00:22	2020-07-23	Dr. Elmo Upton DVM	dr.elmo.upton.dvm@geemail.com	Omaha	Nebraska	3528440180337009375	d0d95aa7f2757aca3d50c52672afa43e	Diners Club / Carte Blanche	41.2320587218418737	-96.0498613536473442
39441	2020-07-23 22:05:02	2020-07-23	Rosalyn Parker	rosalyn.parker@geemail.com	San Francisco	California	4294074012234894	aab0aae38640e021d70a6ed1b7fda488	American Express	37.741731298555429	-122.452623805138217
39442	2020-07-23 22:10:58	2020-07-23	Woodie McGlynn-Keebler	woodie.mcglynn.keebler@woohoo.com	San Francisco	California	869931373471365225	7d668c2a925b08d3e6db2a948b2d9d28	Mastercard	37.7563546444892069	-122.442759095029416
39443	2020-07-23 22:15:32	2020-07-23	Miss Louann Kub DVM	miss.louann.kub.dvm@geemail.com	New York	New York	3528636494217740981	6056e058b47eed00303796b7c43a7def	Voyager	40.6815382779333703	-73.8941556435905369
39444	2020-07-23 22:25:35	2020-07-23	Callum Predovic-Emmerich	callum.predovic.emmerich@geemail.com	Norman	Oklahoma	4454787383145698	e8d0b5abdf1be9ff1bdfb71ed8a3352b	Maestro	35.1588706291321671	-97.3955797703258668
39445	2020-07-23 22:57:51	2020-07-23	Miss Izora Grimes	miss.izora.grimes@geemail.com	Fort Lauderdale	Florida	3765903178807290	42aa3ea0374b430dec39922a66cf92ac	Diners Club / Carte Blanche	26.2251542475529043	-80.1110980479333534
39446	2020-07-23 23:10:04	2020-07-23	Katy Dietrich	katy.dietrich@woohoo.com	Des Moines	Iowa	54700786233595310	e4ed25ef3de2d3fb61b1e106af986dcf	JCB 16 digit	41.5066855461545288	-93.674114197403938
39447	2020-07-23 23:13:59	2020-07-23	Dr. Jerad Hackett	dr.jerad.hackett@geemail.com	Oklahoma City	Oklahoma	53305805865484905	60ea5a5b4b5f3ab38d0320c7db99dd40	Voyager	35.5380105014801018	-97.6009867272701115
39448	2020-07-23 23:13:59	2020-07-23	Dr. Yaritza Hand MD	dr.yaritza.hand.md@geemail.com	Los Angeles	California	3446166079323841	5c8590cbbcee0cf34c6e482cda0c1d01	VISA 13 digit	34.0914880261622315	-118.321368301705633
39449	2020-07-23 23:16:17	2020-07-23	Dr. Mitchell Marquardt	dr.mitchell.marquardt@geemail.com	Waterbury	Connecticut	3057331594337935	1927d043d89c7740e82d8fda7c4087c2	JCB 16 digit	41.636608662273737	-73.0905191525265536
39450	2020-07-23 23:18:12	2020-07-23	Duard Feil	duard.feil@warmmail.com	Madison	Wisconsin	3038890866355122	a16b603eadb43100ba352b997e041453	Maestro	43.1873200652163476	-89.4557700979873545
39451	2020-07-23 23:33:17	2020-07-23	Astrid Pouros DVM	astrid.pouros.dvm@geemail.com	Fort Worth	Texas	210032960668168898	430bb0d13e62838e0e59a24d00e6df3d	Diners Club / Carte Blanche	32.8319992661997659	-97.4334702766787188
39452	2020-07-23 23:35:49	2020-07-23	Khiry Von	khiry.von@geemail.com	Corona	California	4878287946554518	38888d1e24ec37ee1a2236ccccf5e000	VISA 16 digit	33.8201570390611934	-117.522988349964848
39453	2020-07-23 23:49:05	2020-07-23	Marlys Carter	marlys.carter@geemail.com	Seattle	Washington	4978151932171399	3731c1d909da04bf294e7eb6ff1dd5cf	VISA 16 digit	47.6402655486408619	-122.37102395146303
39454	2020-07-23 23:56:40	2020-07-23	Rahn O'Conner	rahn.o'conner@woohoo.com	Omaha	Nebraska	3042336860029756	e8ae9826765e0bf19af34c29e8c8f17e	Mastercard	41.2704283757746211	-96.0058235001400107
39455	2020-07-24 00:11:04	2020-07-24	Sanjuana Zieme-Stanton	sanjuana.zieme.stanton@warmmail.com	Los Angeles	California	6011570201898657410	94fddd49ca4bf20e3377dd2a19267bd1	Discover	34.0888672472774985	-118.365226204366607
39456	2020-07-24 00:14:34	2020-07-24	Mr. Gaige Lehner DDS	mr.gaige.lehner.dds@warmmail.com	New York	New York	3418538135531662	85aeeff8d3245101adf65929c90730a3	Mastercard	40.7306488435473284	-73.8653633291263105
39457	2020-07-24 00:15:51	2020-07-24	Desirae Shields	desirae.shields@warmmail.com	Portland	Oregon	4030409182607967	10f0bffeebab2db5db5883b382c9b308	JCB 16 digit	45.5666279194764812	-122.734325340762737
39458	2020-07-24 00:22:11	2020-07-24	Miss Lola Schinner PhD	miss.lola.schinner.phd@geemail.com	Grand Rapids	Michigan	55056708703285537	65be0ac42c0a698bf7c8b5097bb334dc	Mastercard	42.8631852397963371	-85.5770998150710085
39459	2020-07-24 00:22:20	2020-07-24	Emery Stanton	emery.stanton@woohoo.com	New York	New York	4725037291754204	2c91d637a1241360f0d112d8850bb0de	JCB 15 digit	40.7331575288660801	-73.9129272657807945
39460	2020-07-24 00:27:38	2020-07-24	Clarke Wyman	clarke.wyman@woohoo.com	Sandy Springs	Georgia	210096902331841058	bbc89efed80da7e1712a63d73651b1c3	VISA 13 digit	34.0110100102201116	-84.4406368696212866
39461	2020-07-24 00:38:59	2020-07-24	Damien Hintz	damien.hintz@geemail.com	Westminster	Colorado	4378247984016	59f1ee50a96b588e27a57096ac84aeeb	VISA 16 digit	39.8152046390183258	-104.966542490958801
39462	2020-07-24 00:43:34	2020-07-24	Verda Jones	verda.jones@geemail.com	Chicago	Illinois	4767189113115	52d8af388e5e4d6a6cc4d1e705b3b20f	Maestro	41.8728014574222271	-87.64893516986929
39463	2020-07-24 00:45:44	2020-07-24	Miss Alison Schamberger DVM	miss.alison.schamberger.dvm@woohoo.com	San Antonio	Texas	4177745828562	76d454c3cf56acba0897018c6bdaecaf	Diners Club / Carte Blanche	29.4638669139310707	-98.4575879112653354
39464	2020-07-24 00:53:03	2020-07-24	Sasha Cormier	sasha.cormier@geemail.com	San Diego	California	3400375893227831	22f07b4e689bacc55bf9dc0e0919bbc3	Diners Club / Carte Blanche	32.7626481366876519	-117.086742286700755
39465	2020-07-24 01:03:20	2020-07-24	Dr. Glen Wiegand PhD	dr.glen.wiegand.phd@geemail.com	San Francisco	California	4927441261813840	eee324f534055663c74babb583e77e31	Maestro	37.7982827296072941	-122.426245443948616
39466	2020-07-24 01:03:57	2020-07-24	Jana Lueilwitz	jana.lueilwitz@geemail.com	Cambridge	Massachusetts	180004706250965819	600fd4cbc87cf1cde629a2fdef249b7b	JCB 16 digit	42.3693997495565569	-71.1293727493926866
39467	2020-07-24 01:15:07	2020-07-24	Lempi Cronin	lempi.cronin@geemail.com	Minneapolis	Minnesota	3755346056313639	cfc003829a9e4c517eb3209c36f3e0a2	VISA 16 digit	44.951363083123411	-93.2488270368233287
39468	2020-07-24 01:22:34	2020-07-24	Jaquelin Hudson	jaquelin.hudson@geemail.com	San Francisco	California	180014725112461260	ee110d7394b969fe4841c1b31fb9e041	JCB 15 digit	37.7689151625006474	-122.400963985695867
39469	2020-07-24 01:26:11	2020-07-24	Jerrilyn Denesik MD	jerrilyn.denesik.md@woohoo.com	Philadelphia	Pennsylvania	3012456228616621	5ef51c9aa50dae5aee092d8a6779ad7f	VISA 13 digit	39.9579010934062282	-75.0626116228655036
39470	2020-07-24 01:26:21	2020-07-24	Miss Arta Swift	miss.arta.swift@woohoo.com	San Diego	California	4344638627499	dd27905f4f559ae7d054b591f4acca3c	American Express	32.7383884383898263	-117.198221465190883
39471	2020-07-24 01:30:45	2020-07-24	Brenden Hoeger	brenden.hoeger@woohoo.com	San Francisco	California	4959611725753094	7ba6bd9e1db22d1686b41d70cab080dd	VISA 16 digit	37.8227645067900369	-122.429368744368176
39472	2020-07-24 01:31:22	2020-07-24	Mr. Orlo Torp IV	mr.orlo.torp.iv@warmmail.com	Oakland	California	501842392949584	47ff8179706ff1b24c07f96b35ce87df	VISA 16 digit	37.8187994175603706	-122.267869955565203
39473	2020-07-24 01:50:28	2020-07-24	Burnice Leffler	burnice.leffler@geemail.com	Clinton	Michigan	53794227327961032	87eddfccffa583f4de63aa48a951d073	JCB 15 digit	42.5342847301691762	-82.9886001026798112
39474	2020-07-24 01:50:31	2020-07-24	Miss Hester Mraz DDS	miss.hester.mraz.dds@woohoo.com	Augusta	Georgia	6011860165256988387	6a6085c4f4bdec603c17d0f50bb6db71	Discover	33.3269414046984167	-82.0157315172549346
39475	2020-07-24 01:55:10	2020-07-24	Albert Breitenberg	albert.breitenberg@geemail.com	Fort Worth	Texas	4769315333682	8b36633cc0f620eeba8cdbed3702b349	American Express	32.8382107698880148	-97.4376700002055571
39476	2020-07-24 01:55:23	2020-07-24	Ms. Regenia Leuschke	ms.regenia.leuschke@geemail.com	San Antonio	Texas	3088221091986351809	88a28db7cae41d68ad3eefee6f103b4d	JCB 15 digit	29.4946082103136931	-98.4843990234494129
39477	2020-07-24 01:58:17	2020-07-24	Jamarion Russel Sr.	jamarion.russel.sr.@geemail.com	Scottsdale	Arizona	675923215625684	ea60aa8b5e3fbf91f32b0478efee7723	Voyager	33.6353836679022749	-111.918051669976109
39478	2020-07-24 02:00:03	2020-07-24	Lew Sawayn	lew.sawayn@woohoo.com	San Mateo	California	6011074477356352691	3c29383d15fa65486de6fa01a6d638de	JCB 16 digit	37.6187647110663335	-122.273431282522523
39479	2020-07-24 02:03:18	2020-07-24	Dr. Mitchell Dooley V	dr.mitchell.dooley.v@geemail.com	Richardson	Texas	869926458443900485	d5909f02e8b818930590a3a76c0265a2	VISA 13 digit	32.8842590714573859	-96.698602717345949
39480	2020-07-24 02:07:10	2020-07-24	Coleton Conn	coleton.conn@warmmail.com	Austin	Texas	53843220188862713	372404a6aa9294639d27257059b02c0f	JCB 16 digit	30.2376858799844968	-97.8181423883657999
39481	2020-07-24 02:08:49	2020-07-24	Maryann Macejkovic	maryann.macejkovic@geemail.com	Evansville	Indiana	869983501843337715	98a27ac8a701ce865204e6a219f50df6	JCB 16 digit	37.9027079836137588	-87.5510550811354022
39482	2020-07-24 02:09:22	2020-07-24	Flo Jerde	flo.jerde@warmmail.com	Houston	Texas	3004208046004003	5ef37cb0c2f585081ea1947766e458d5	JCB 15 digit	29.8421144096259034	-95.4140194533873398
39483	2020-07-24 02:30:38	2020-07-24	Ty Hackett	ty.hackett@geemail.com	Rochester	New York	54289198985115181	9f3bdae557abc699e6b06ed555a54f64	JCB 16 digit	43.1553320176877051	-77.6424225387867608
39484	2020-07-24 02:36:40	2020-07-24	Durrell Smitham-Fisher	durrell.smitham.fisher@geemail.com	Bellevue	Washington	4928174675004693	415849381938a792af3be4ef94cd40ec	Maestro	47.5989756844654721	-122.113044900825244
39485	2020-07-24 02:37:20	2020-07-24	Sherilyn Olson	sherilyn.olson@warmmail.com	Lansing	Michigan	3088530341944717286	2a5009e4781ed2c56bcb832a5a8adb7e	JCB 16 digit	42.6686040168471621	-84.5393996866542778
39486	2020-07-24 02:45:43	2020-07-24	Alisha Graham	alisha.graham@geemail.com	Berkeley	California	3042465636375720	cb1f393f9f56e5986dc87528a90a0fdd	Mastercard	37.8428950631417536	-122.304302647374897
39487	2020-07-24 02:45:45	2020-07-24	Sudie Stoltenberg	sudie.stoltenberg@geemail.com	San Francisco	California	210076607461974371	11609ce9aa5ccbff5a60a1e6251e2109	VISA 13 digit	37.7766610296617671	-122.435900531382359
39488	2020-07-24 02:46:53	2020-07-24	Memphis Nolan	memphis.nolan@geemail.com	Berkeley	California	52470726899226295	f4f151ff55b14710738db66d7cafafe6	JCB 15 digit	37.8811956364662379	-122.271288150246946
39489	2020-07-24 02:56:59	2020-07-24	Burns Hoeger-Eichmann	burns.hoeger.eichmann@geemail.com	El Paso	Texas	6011280942980099901	f574510a0b23c8a80e9ed1fb5fa84b5f	Maestro	31.7635836307253712	-106.463701590707529
39490	2020-07-24 02:57:10	2020-07-24	Alysha Aufderhar	alysha.aufderhar@geemail.com	Columbus	Ohio	210019771838036205	ff7a8334def92f5db12a37d68880a4f7	VISA 16 digit	40.0468961081512234	-82.9504873722560774
39491	2020-07-24 03:00:55	2020-07-24	Fed Herman	fed.herman@geemail.com	Chicago	Illinois	3779924689060496	707aedb4c63c16deba4eceb3056e292b	Mastercard	41.8649970089852843	-87.6068851678661957
39492	2020-07-24 03:03:39	2020-07-24	Alexis Reilly	alexis.reilly@geemail.com	Lewisville	Texas	4084880329382	b830c4938088e6efd2f86f330f2dcdc9	Voyager	33.1104135176617618	-97.0788523013267763
39493	2020-07-24 03:04:10	2020-07-24	Danny Boyle	danny.boyle@woohoo.com	Louisville	Kentucky	54809046723543654	d8afbb0fcb8f8ae8b0b04c0eb7559763	American Express	38.150400250115986	-85.6833476328361883
39494	2020-07-24 03:10:10	2020-07-24	Ignacio Emard	ignacio.emard@geemail.com	Pembroke Pines	Florida	869991285004616329	c1eff6485ecf04ca663abaacf90f73cf	Discover	26.0388391737397775	-80.3937156949095453
39495	2020-07-24 03:17:14	2020-07-24	Campbell Mohr-Stark	campbell.mohr.stark@woohoo.com	Hollywood	Florida	3088228980752736222	a2944b37cb4318e8ae57bc06c4075bf0	VISA 16 digit	26.077320220874622	-80.1203515512220434
39496	2020-07-24 03:22:53	2020-07-24	Miss Farrah Reilly	miss.farrah.reilly@geemail.com	Manchester	New Hampshire	3337088918489999555	04d708ef811ac86b293563157105ba6c	Mastercard	43.0553080680385278	-71.442018304847565
39497	2020-07-24 03:23:53	2020-07-24	Leva Lemke PhD	leva.lemke.phd@warmmail.com	Savannah	Georgia	6011022187218504263	75c9b2bc79ff7edb5efea633dece3efd	Discover	31.9424125547148279	-81.1893289253734025
39498	2020-07-24 03:30:15	2020-07-24	Rae Romaguera	rae.romaguera@geemail.com	New York	New York	3096014876985246328	eb437496b8c340c2e66f8b81a9cfb4d2	Discover	40.7072124907970405	-73.9035281852249
39499	2020-07-24 03:31:52	2020-07-24	Dr. Lynn Pfannerstill Jr.	dr.lynn.pfannerstill.jr.@geemail.com	Wichita	Kansas	4072012827258	da4b9de0451bb40d7d9ec0e75a9a026c	Discover	37.6505853503353904	-97.3560703977212256
39500	2020-07-24 03:31:58	2020-07-24	Ms. Gretchen Witting	ms.gretchen.witting@warmmail.com	New York	New York	3112235066785314418	0f350faca2ea6085683a8b658d30b542	JCB 16 digit	40.6525836235135785	-73.8861778522737325
39501	2020-07-24 03:47:11	2020-07-24	Maximillian Yundt	maximillian.yundt@geemail.com	Washington	District of Columbia	55241759864002985	f1450ef8762d7cc3e05457a60b3763ee	JCB 15 digit	38.8644639698121708	-77.0414368048988365
39502	2020-07-24 03:47:52	2020-07-24	Tre McKenzie	tre.mckenzie@geemail.com	Joliet	Illinois	3528608480686029828	c7d7e0eaef4d72620b7667cb09dfef0f	VISA 13 digit	41.5792707894787199	-88.1823162416100388
39503	2020-07-24 03:49:25	2020-07-24	Mrs. Jackie Harvey	mrs.jackie.harvey@geemail.com	Berkeley	California	3337585928629588703	1757f5af57de7626c5c0a78abac1670d	VISA 16 digit	37.8719475618059178	-122.261940058480675
39504	2020-07-24 03:51:18	2020-07-24	Cathy Brown	cathy.brown@geemail.com	Hayward	California	4841566237249720	e88781c67157cb754c169c67e839691c	JCB 16 digit	37.5682446204580387	-122.113993975592408
39505	2020-07-24 03:55:30	2020-07-24	Jeremiah Ledner	jeremiah.ledner@geemail.com	Portland	Oregon	869906110574634987	7bbf1ac9bbec4f0fe4d3e69a7d24fdf3	JCB 15 digit	45.4704903431124947	-122.711987454257908
39506	2020-07-24 03:57:31	2020-07-24	Kipp Spinka	kipp.spinka@geemail.com	Chandler	Arizona	3088558269962314370	7f8eb53f37f9677fd2062fd71eb0a51a	Mastercard	33.200292636323347	-111.854692717071245
39507	2020-07-24 03:59:24	2020-07-24	Dandre Dickinson DVM	dandre.dickinson.dvm@woohoo.com	Santa Rosa	California	3022906631852106	dbe0b99e6480cb138246b08a95ad664e	JCB 16 digit	38.4818042977370354	-122.697793766415131
39508	2020-07-24 04:02:35	2020-07-24	Veva Mann-Bosco	veva.mann.bosco@woohoo.com	Ontario	California	869979273451779663	8adf41f7a3aaacd155bed88dcd6a532d	Mastercard	34.1361164946254334	-117.617271622792643
39509	2020-07-24 04:10:06	2020-07-24	Ari Daugherty	ari.daugherty@geemail.com	Berkeley	California	4964851179161757	8831872f63c209dc2f79957bc890a557	JCB 16 digit	37.8272435698372576	-122.253468775846827
39510	2020-07-24 04:12:03	2020-07-24	Mr. Clide Weber III	mr.clide.weber.iii@geemail.com	San Antonio	Texas	3735302137109616	52382609055bc62bcd20486d6cf3b7f8	Diners Club / Carte Blanche	29.4888153970312317	-98.6119455225601769
39511	2020-07-24 04:13:45	2020-07-24	Jameel Murphy	jameel.murphy@geemail.com	Surprise	Arizona	4003412825789229	c266eb324c430126a26d1ebf09327a69	VISA 13 digit	33.5911500860232834	-112.401293810154115
39512	2020-07-24 04:26:01	2020-07-24	Yoshio Jakubowski	yoshio.jakubowski@geemail.com	Jacksonville	Florida	180060510931444165	b84116d4f6487208e9ae8c6268824503	Diners Club / Carte Blanche	30.4135883156728006	-81.6932380905918905
39513	2020-07-24 04:30:26	2020-07-24	Dr. Steve D'Amore II	dr.steve.d'amore.ii@woohoo.com	New York	New York	4996614772772731	9373af5bebdda86bf7444efc717818a5	Discover	40.7160435068178899	-73.869379038120428
39514	2020-07-24 04:34:05	2020-07-24	Loran Bradtke-Pollich	loran.bradtke.pollich@geemail.com	Jacksonville	Florida	54975561479150833	425d4ee5758677403f77a14616a2d0f8	JCB 16 digit	30.3074529473721981	-81.7311163433905818
39515	2020-07-24 04:35:48	2020-07-24	Lue Ullrich	lue.ullrich@warmmail.com	Oklahoma City	Oklahoma	676324693109480	4814bce125f2a0eaf6a217e651f01da6	JCB 15 digit	35.3808743053957855	-97.5391169828258455
39516	2020-07-24 04:48:09	2020-07-24	Bonita Pagac	bonita.pagac@geemail.com	Jersey City	New Jersey	3025645758336264	3b10878b1978c6d00752ae914d6f31e0	JCB 16 digit	40.639094179257377	-74.0491516480177694
39517	2020-07-24 04:51:17	2020-07-24	Luis Carroll	luis.carroll@warmmail.com	Sacramento	California	180095634306235344	8154aa8402dfd86cc1873f48056f93b0	Maestro	38.5055693339355329	-121.408326107055316
39518	2020-07-24 04:56:20	2020-07-24	Ivah Johnson	ivah.johnson@geemail.com	Ventura	California	3018148640187729	5863ceb930b723afa28be90912196855	JCB 16 digit	34.2476142849933396	-119.26105399607755
39519	2020-07-24 05:03:07	2020-07-24	Thyra Predovic	thyra.predovic@geemail.com	Chicago	Illinois	3088474870789789297	0ef39b22d36fee91fcf656c00160e946	JCB 15 digit	41.8287628421861726	-87.7311251607287659
39520	2020-07-24 05:11:18	2020-07-24	Mr. Anthoney Kiehn II	mr.anthoney.kiehn.ii@woohoo.com	Rochester	New York	52520713994140142	5698d30b6dd2cb1efbd2c12e44d0b005	Discover	43.2461183555401831	-77.5643412021692882
39521	2020-07-24 05:15:20	2020-07-24	Buddie Satterfield MD	buddie.satterfield.md@geemail.com	Fontana	California	4840079874938	75aa309b9e37fe2b446b8a0e017c68a6	American Express	34.0284304522592578	-117.366436951448776
39522	2020-07-24 05:17:30	2020-07-24	Emilio Torp	emilio.torp@geemail.com	League City	Texas	3088179319515498839	f96c0897d225867cc10bb087db5e0b91	Maestro	29.5161456855408879	-95.1965602828640414
39523	2020-07-24 05:28:12	2020-07-24	Mariel Hills	mariel.hills@geemail.com	St. Petersburg	Florida	3337126392771235777	9797ebe2377ff58debea8d788a3917e1	Voyager	27.6918478144686659	-82.5571646944977289
39524	2020-07-24 05:30:52	2020-07-24	Rutha Gorczany	rutha.gorczany@geemail.com	Kansas City	Missouri	3711426829050941	4778d6a7ccf108cbc8bc94c78196f41e	Discover	39.1767116100363495	-94.6254221554137729
39525	2020-07-24 05:31:36	2020-07-24	Evelyne Bins	evelyne.bins@woohoo.com	Moreno Valley	California	4902062212713175	cae09258a74c36454e7ce5be7d053bf8	Diners Club / Carte Blanche	33.9407973316956273	-117.218248273755236
39526	2020-07-24 05:38:29	2020-07-24	Ted Roob	ted.roob@warmmail.com	New York	New York	3112022557352248184	ec0583b4d248a4873472f6152e3be4c9	VISA 13 digit	40.6886992398872991	-74.0196331798925939
39527	2020-07-24 05:45:21	2020-07-24	Ms. Flor Rolfson	ms.flor.rolfson@geemail.com	Tucson	Arizona	6011709776203911614	9b0b3a14bd11f95d648872a5173648ab	Discover	32.2156725252088165	-110.889744876161586
39528	2020-07-24 05:53:29	2020-07-24	Palmer Leuschke	palmer.leuschke@geemail.com	Milwaukee	Wisconsin	3337545763392640962	7a80e78ebba54b23585b6d1d99a08a06	VISA 13 digit	43.047072932132707	-88.0459116384953262
39529	2020-07-24 06:07:14	2020-07-24	Jaquan Hickle	jaquan.hickle@geemail.com	Murrieta	California	4682146347784882	288ee752b2374c7d43f5358ab3757313	Mastercard	33.6249712200932223	-117.150798565698409
39530	2020-07-24 06:12:42	2020-07-24	Dustin Schinner	dustin.schinner@geemail.com	San Francisco	California	561257785502592	c8d0b5844277ab0f2f4dddd3b8d92b1b	JCB 16 digit	37.7786931216673452	-122.425713476715529
39531	2020-07-24 06:22:43	2020-07-24	Lanny Bradtke	lanny.bradtke@geemail.com	New Orleans	Louisiana	676314845310011	54a3509f9b1d074d0797ab7e362b5096	VISA 13 digit	29.987469495974107	-89.875189458372077
39532	2020-07-24 06:24:16	2020-07-24	Keagan Torp-Steuber	keagan.torp.steuber@woohoo.com	Aurora	Colorado	210069349603419093	4d060620abb925341ab0a930c75c30cd	JCB 15 digit	39.7545749043226238	-104.780495900160446
39533	2020-07-24 06:26:16	2020-07-24	Dr. Eli Ernser	dr.eli.ernser@geemail.com	Cincinnati	Ohio	52990391608295643	44cf9be991e4e21426a048a3bb1b4048	JCB 16 digit	39.0579525564562502	-84.5835001500595354
39534	2020-07-24 06:28:50	2020-07-24	Simona Cruickshank	simona.cruickshank@geemail.com	Tucson	Arizona	3052194616261961	8708d2deae5fac5b8e256199cb57c243	Discover	32.1075564360752708	-110.833180612581216
39535	2020-07-24 06:29:06	2020-07-24	Billy Block-Kilback	billy.block.kilback@geemail.com	Columbus	Georgia	869993099881758866	df189e7171367fda0311296d5fc10b4f	JCB 15 digit	32.4455733781725115	-84.8341898934148162
39536	2020-07-24 06:36:09	2020-07-24	Carie Crooks-Turcotte	carie.crooks.turcotte@warmmail.com	Oakland	California	54199647604732106	6d73dd390396fe33dab20acadca09e5a	Diners Club / Carte Blanche	37.8032338066863574	-122.251591704271064
39537	2020-07-24 06:38:53	2020-07-24	Dr. James Nicolas III	dr.james.nicolas.iii@geemail.com	Sioux Falls	South Dakota	589391703937283	66b6d061d25cb2d5b1bd7825d6932f3b	JCB 16 digit	43.5388722465459281	-96.8274603309277495
39538	2020-07-24 06:41:34	2020-07-24	Sing Goldner	sing.goldner@woohoo.com	New York	New York	55539142860758176	31c22cc1c5382689e8f863f0d64c7e5e	Mastercard	40.6584081458151303	-74.0233894967835369
39539	2020-07-24 06:50:49	2020-07-24	Dr. Ocie Schaefer MD	dr.ocie.schaefer.md@warmmail.com	Detroit	Michigan	869926612471145922	bafc3dcf973902f653a5b65b9508f9ef	Mastercard	42.4458138161730076	-83.0715258695770018
39540	2020-07-24 06:57:16	2020-07-24	Zavion Jacobson-McLaughlin	zavion.jacobson.mclaughlin@geemail.com	San Francisco	California	3759304440090260	abb6015b474d6b878e86265f44a9c21a	JCB 15 digit	37.7434433209457723	-122.421205354185616
39541	2020-07-24 07:11:01	2020-07-24	Gayla Heidenreich MD	gayla.heidenreich.md@geemail.com	Portland	Oregon	869937413686078470	a552453bbaf07a2abe00f90567ba4b52	JCB 16 digit	45.5512634341493268	-122.668778996961194
39542	2020-07-24 07:13:33	2020-07-24	Margretta Kerluke	margretta.kerluke@geemail.com	Huntington Beach	California	3008143603038001	0617a591ed6016117c2ba8be41869ce6	American Express	33.7818764276377905	-117.995513947413485
39543	2020-07-24 07:20:54	2020-07-24	Bronson Bode	bronson.bode@geemail.com	Dayton	Ohio	6011423991726458242	582fba86b32690eae6f53952bbce2807	VISA 16 digit	39.8322874388914556	-84.124020552747325
39544	2020-07-24 07:22:58	2020-07-24	Dr. Catrina Nienow MD	dr.catrina.nienow.md@geemail.com	New York	New York	060406838681028	e1264b335b5d9ae3d8ae791f25ff9871	JCB 15 digit	40.6923359223864978	-73.9088817560009659
39545	2020-07-24 07:26:28	2020-07-24	Taryn Kshlerin PhD	taryn.kshlerin.phd@warmmail.com	High Point	North Carolina	3015019555982607	4ae1474bc1d97a9e0ec1f6dd5de69494	Voyager	36.0825683816894909	-80.0290311241727323
39546	2020-07-24 07:43:35	2020-07-24	Odell Bosco-Bode	odell.bosco.bode@geemail.com	Phoenix	Arizona	4777501575961394	0fadb4866bbc0d1b6344f92c87545969	Voyager	33.508367543660853	-112.153966701629017
39547	2020-07-24 07:48:02	2020-07-24	Dosha Bogisich-Blanda	dosha.bogisich.blanda@geemail.com	Chicago	Illinois	6011083737364163813	0649c45d77e8cc37d6dd522a38e9ccc8	Mastercard	41.7888558896560269	-87.7779241730954425
39548	2020-07-24 07:50:48	2020-07-24	Dr. Eula Hodkiewicz DDS	dr.eula.hodkiewicz.dds@woohoo.com	Downey	California	4470181080834	6325648d20f075d9fe6ef01e1b65a801	JCB 15 digit	33.8526787810277199	-118.07899765191749
39549	2020-07-24 08:00:21	2020-07-24	Alyvia Bauch	alyvia.bauch@geemail.com	Minneapolis	Minnesota	3013509758038399	6fc39ae997ece85767064c9e46be2ae0	JCB 16 digit	44.8696895047176625	-93.2037255087673628
39550	2020-07-24 08:03:09	2020-07-24	Lucky Bayer	lucky.bayer@geemail.com	Downey	California	6011132324970886722	106dd09a4445e8697700def176f13043	JCB 16 digit	33.9574133912816691	-118.064749070454013
39551	2020-07-24 08:05:04	2020-07-24	Ryley Hoppe	ryley.hoppe@geemail.com	Chicago	Illinois	869959743164503190	df647de596eba769e0f0c78c8c9bad7d	JCB 16 digit	41.7920634034391512	-87.6460723605968042
39552	2020-07-24 08:05:30	2020-07-24	Baylee Zieme	baylee.zieme@woohoo.com	San Francisco	California	3096555181795432415	6561f9ede6be442ff05c13ba0a98c0a3	VISA 16 digit	37.7879001313681755	-122.465243437666146
39553	2020-07-24 08:06:49	2020-07-24	Eric Gottlieb-Cormier	eric.gottlieb.cormier@geemail.com	Honolulu	Hawaii	3001048197713116	438e9adfbc95f665bb4fa5d5fe390dd3	VISA 16 digit	21.2670465678192677	-157.855250190265849
39554	2020-07-24 08:24:09	2020-07-24	Mr. Demetrius Hamill V	mr.demetrius.hamill.v@geemail.com	Norman	Oklahoma	3011838638551350	9af0fe8cc32007010d6867bff1940c42	Maestro	35.3005341910798123	-97.2520418822552983
39555	2020-07-24 08:24:15	2020-07-24	Oley Brown	oley.brown@geemail.com	Sparks	Nevada	561283635275395	8c1097e3e9afb9f7beab70db241ee40c	Maestro	39.5993710648506863	-119.760188907510042
39556	2020-07-24 08:29:35	2020-07-24	Murray Bartell	murray.bartell@woohoo.com	Chicago	Illinois	54270376244470248	5cd4a741fac03d355d66a4898e9555e1	VISA 16 digit	41.7634160134311756	-87.7565545025311309
39557	2020-07-24 08:32:39	2020-07-24	Jeraldine Koepp-Bosco	jeraldine.koepp.bosco@woohoo.com	New York	New York	4153708873584463	45bf14df76e1447dc4ee6eceb15454af	Voyager	40.6850575910173333	-73.8982249810721754
39558	2020-07-24 08:39:50	2020-07-24	Shana Barton	shana.barton@warmmail.com	Corona	California	4966751788300	14c503baddb12a83a8d72f77523245a0	Mastercard	33.9420849584862623	-117.49538058603369
39559	2020-07-24 08:48:23	2020-07-24	Duncan Simonis	duncan.simonis@geemail.com	Billings	Montana	3442405435017877	adfe147ea04dc62bdde708524e17d496	Maestro	45.8671024450790128	-108.462064273532107
39560	2020-07-24 09:04:05	2020-07-24	Amie Mante	amie.mante@woohoo.com	Rochester	Minnesota	4501422402801997	5b6c6c20a8581a6428cc4f0678c599e8	Voyager	43.9400905302628857	-92.5677613182112538
39561	2020-07-24 09:10:12	2020-07-24	Tinnie Koch	tinnie.koch@geemail.com	Fort Worth	Texas	210045789594649639	c795ea0ebf9376dde716002481617dca	JCB 16 digit	32.719595882534982	-97.2899999168988359
39562	2020-07-24 09:10:17	2020-07-24	Campbell Becker PhD	campbell.becker.phd@geemail.com	New York	New York	869985614004558553	d347bb81bc427819a3935e7e0df6355b	VISA 13 digit	40.6819759738855069	-73.887004168973121
39563	2020-07-24 09:11:23	2020-07-24	Cindi Rogahn	cindi.rogahn@woohoo.com	Corpus Christi	Texas	3038192435579369	bc18e5acd10527abb91c84911ce41b30	VISA 16 digit	27.6657123734179891	-97.1451715334147252
39564	2020-07-24 09:13:29	2020-07-24	Adrianne Lesch	adrianne.lesch@woohoo.com	Boston	Massachusetts	54067342556009120	dcc7c22bdde4d5bf1b90a8cf86ebc4e6	VISA 16 digit	42.3494901244230562	-70.9553960640400732
39565	2020-07-24 09:15:26	2020-07-24	Karl Carter	karl.carter@warmmail.com	San Francisco	California	3725378520584401	230efd9d6746cb04e41dbd28c5f8976a	VISA 16 digit	37.7690247560588332	-122.432844082813148
39566	2020-07-24 09:17:45	2020-07-24	Mr. Benjaman Yundt DVM	mr.benjaman.yundt.dvm@geemail.com	Wilmington	North Carolina	869909007825953926	4997d4c316a2f63357059f15e057af35	VISA 13 digit	34.2595742070868639	-77.8992419649839434
39567	2020-07-24 09:22:18	2020-07-24	Kimber Smitham PhD	kimber.smitham.phd@geemail.com	Philadelphia	Pennsylvania	4898281064672	90c77bf148f40f2752580326c0bbc963	JCB 16 digit	39.9502587041776636	-75.0700128489539082
39568	2020-07-24 09:31:11	2020-07-24	Mrs. Makena Fadel PhD	mrs.makena.fadel.phd@geemail.com	San Francisco	California	3528587893574396239	5f204dc893d78d1431ef002d3e47c337	Mastercard	37.7891066863210483	-122.423050697965579
39569	2020-07-24 09:33:27	2020-07-24	Ruffin Kilback	ruffin.kilback@geemail.com	Las Vegas	Nevada	210087576213375061	8d0f9b53ff735701ccc450a657efa744	Diners Club / Carte Blanche	36.2180812089804576	-115.319223661462217
39570	2020-07-24 09:43:24	2020-07-24	Germaine Zemlak	germaine.zemlak@woohoo.com	Macon	Georgia	3158706453107762351	f1a321527d8a3629b6dba83b4b290abb	VISA 13 digit	32.9075545668147456	-83.7718375028770339
39571	2020-07-24 09:45:00	2020-07-24	Lyle Treutel	lyle.treutel@geemail.com	Portland	Oregon	675920588071793	059fa505bbbd9ffc0223f8d5bf7e573a	Mastercard	45.4692118921205406	-122.618521849066028
39572	2020-07-24 09:47:21	2020-07-24	Ms. Celesta Maggio DDS	ms.celesta.maggio.dds@geemail.com	Philadelphia	Pennsylvania	4775386688768254	d7945747f33f5bb2f0c00572940f72ce	Maestro	40.1005621202249074	-75.1406764957487638
39573	2020-07-24 09:54:43	2020-07-24	Renata Beahan	renata.beahan@geemail.com	Dallas	Texas	55768335948436557	2e0a99239010ae285447caa9582bb4d6	Mastercard	32.7230304677311352	-96.7332482000309852
39574	2020-07-24 10:08:43	2020-07-24	Mikeal Koepp	mikeal.koepp@warmmail.com	Fort Collins	Colorado	3038083391815311	4c259d6394b7dcc84324dd70a674b57c	JCB 16 digit	40.4880050716146869	-105.086684576277818
39575	2020-07-24 10:17:09	2020-07-24	Daryl Hamill	daryl.hamill@geemail.com	San Francisco	California	210045071421656057	1006e0d79decdfc5dfb702037ef42dd0	Diners Club / Carte Blanche	37.774039777870847	-122.433906704865876
39576	2020-07-24 10:18:36	2020-07-24	Eola Dibbert	eola.dibbert@woohoo.com	Baltimore	Maryland	4483048538332	048217b952f5b2629c479d0e756414bd	VISA 13 digit	39.3267722133547011	-76.5428044600896555
39577	2020-07-24 10:23:19	2020-07-24	Maximus Ullrich	maximus.ullrich@geemail.com	Chesapeake	Virginia	6011198075029871815	2ba7130e9b5f1714ddce12d67af677a5	Discover	36.6770552200038011	-76.2169899894699512
39578	2020-07-24 10:26:46	2020-07-24	Miss Alesia Harvey PhD	miss.alesia.harvey.phd@geemail.com	Rochester	Minnesota	55516543952314686	bad197ec725c83d3064a557af27b52d1	Maestro	43.9919518681146187	-92.5195595101106818
39579	2020-07-24 10:27:50	2020-07-24	Marlo Schiller	marlo.schiller@woohoo.com	Berkeley	California	4569004546432	6f5935e82b8fdfdbe7830e8bf3159a7d	Discover	37.87853457147569	-122.237202924118478
39580	2020-07-24 10:30:37	2020-07-24	Mr. Keandre Waelchi	mr.keandre.waelchi@geemail.com	Portland	Oregon	3528123352580502380	88e608cf17ca7e29ab3088783927cc6e	Diners Club / Carte Blanche	45.4854089356847098	-122.573282440705228
39581	2020-07-24 10:32:23	2020-07-24	Sunshine Murphy	sunshine.murphy@geemail.com	Lubbock	Texas	52553673040178928	76b081d54dada8dad176fcf484569a96	Maestro	33.6057179991196904	-101.803339039292936
39582	2020-07-24 10:39:01	2020-07-24	Ell Renner	ell.renner@geemail.com	New York	New York	869944428245122560	6f07a904cf1ae42ddbd96714fe628b8c	Voyager	40.5815765232536947	-73.9310352961894068
39583	2020-07-24 10:41:56	2020-07-24	Mr. Gerhard Cartwright	mr.gerhard.cartwright@geemail.com	Oklahoma City	Oklahoma	3403278124887315	5c85a783b5d1cc9075a86d544ac4625e	American Express	35.4413265633773094	-97.4438202921196819
39584	2020-07-24 10:43:59	2020-07-24	Cole Mosciski DVM	cole.mosciski.dvm@warmmail.com	Seattle	Washington	3015249602431783	48df48205953ebb4c5cd09b01f08d6e7	VISA 13 digit	47.5233787706512985	-122.264049963133033
39585	2020-07-24 10:56:11	2020-07-24	Shawanda Cummings	shawanda.cummings@geemail.com	Mobile	Alabama	6011368120395166400	54aa3de414ea70b526fdd8ab9b386253	JCB 16 digit	30.6792574044425024	-88.1325939856141787
39586	2020-07-24 11:17:26	2020-07-24	Ms. Guadalupe Nienow	ms.guadalupe.nienow@warmmail.com	Greeley	Colorado	52395653701419714	1a519aaba65c3f5fd61c89574b0e85d3	VISA 13 digit	40.4994541823465397	-104.858507244971392
39587	2020-07-24 11:22:10	2020-07-24	Brandy Schaefer-Morissette	brandy.schaefer.morissette@geemail.com	San Francisco	California	4168444965984840	1a97295469b07250d01682aead260485	VISA 16 digit	37.8296979384173184	-122.441132105129057
39588	2020-07-24 11:25:26	2020-07-24	Iola Moore	iola.moore@warmmail.com	Baltimore	Maryland	51361477015003562	cbef5eeaa49aa56596165e3b71ea7474	Mastercard	39.2827972685918212	-76.64909760132619
39589	2020-07-24 11:26:30	2020-07-24	Mr. Melville Willms V	mr.melville.willms.v@woohoo.com	Los Angeles	California	3496898891417695	cbf3bc6652791995385e901fa574a945	Maestro	34.1103447973594029	-118.427395975914962
39590	2020-07-24 11:26:51	2020-07-24	Sade Witting	sade.witting@woohoo.com	San Jose	California	3337935879202074073	e6320c6122eec05b4e29e4d5f7f258e2	VISA 16 digit	37.3847532047245679	-121.780242169437557
39591	2020-07-24 11:31:08	2020-07-24	Ms. Victory Sauer PhD	ms.victory.sauer.phd@warmmail.com	Salem	Oregon	6011994485284879005	c8e82cb38d335c66018adabe25f092bd	JCB 16 digit	44.8551193693455303	-123.108393321853882
39592	2020-07-24 11:38:46	2020-07-24	Juanita Ankunding	juanita.ankunding@warmmail.com	Oakland	California	3430314777339275	cbfb8e2043c234c70308676005128f1e	Voyager	37.7759624093249542	-122.249836632503133
39593	2020-07-24 11:39:38	2020-07-24	Ms. Gretta Ryan DVM	ms.gretta.ryan.dvm@geemail.com	New York	New York	55602179527239077	f7912e308aad011e17d4bf0f858ff570	VISA 16 digit	40.6235831173360324	-73.955348670937866
39594	2020-07-24 11:44:41	2020-07-24	Callie Leannon	callie.leannon@warmmail.com	San Francisco	California	3528452622887076838	f8434fe85c72153f9da74ee2c8da4212	Voyager	37.7340241805669621	-122.438110884461011
39595	2020-07-24 11:57:47	2020-07-24	Nanna Parker PhD	nanna.parker.phd@geemail.com	Fayetteville	North Carolina	4236979856360681	c29da3bfa25d2e5ede8a29ba375e0624	JCB 15 digit	35.0276154165409466	-78.9484257823918085
39596	2020-07-24 12:03:37	2020-07-24	Willaim Bergnaum	willaim.bergnaum@geemail.com	San Antonio	Texas	4297362365906375	30baabd01acf927a12a72d5afcfd38dc	Voyager	29.4259886523313838	-98.4471991555601278
39597	2020-07-24 12:03:51	2020-07-24	Elissa Rau	elissa.rau@geemail.com	Clarksville	Tennessee	4307664953422865	4e23b02bcf5265e56fb40fa177647266	JCB 16 digit	36.6632210651539268	-87.3462968885384612
39598	2020-07-24 12:04:34	2020-07-24	Mina Howell	mina.howell@warmmail.com	Los Angeles	California	180024649917774743	37cf9ec7c433bc6815b0bd4bfd79c292	Discover	34.0902724303636688	-118.33247467409744
39599	2020-07-24 12:37:49	2020-07-24	Azalee Miller MD	azalee.miller.md@geemail.com	Boise	Idaho	6011388610715687958	62c89d9092f5dac0b36a6fea0a7efefe	VISA 16 digit	43.6058927795056235	-116.197199747218562
39600	2020-07-24 12:39:22	2020-07-24	Samira Rippin	samira.rippin@geemail.com	Berkeley	California	869945186566256149	2766ee49d2c3c579f8816e05b7c156c0	Mastercard	37.8799196305357029	-122.276749809990974
39601	2020-07-24 12:39:53	2020-07-24	Trenton Stroman	trenton.stroman@geemail.com	Los Angeles	California	6011767838987412034	3039b8c3ca1c7fb50477adf42e335d24	VISA 16 digit	34.0563048155844186	-118.458203190983454
39602	2020-07-24 12:49:08	2020-07-24	Abigale Maggio	abigale.maggio@geemail.com	Lansing	Michigan	4299310167893	7f8a7cde8af4dfe79092808b0f760627	VISA 13 digit	42.7160407842911809	-84.6131577496539791
39603	2020-07-24 12:51:07	2020-07-24	Lenore Hessel	lenore.hessel@geemail.com	Frisco	Texas	4097234140859	907c66403c9bbc342077f0593baf0a10	VISA 16 digit	33.2271036537360374	-96.7416027438104038
39604	2020-07-24 12:51:12	2020-07-24	Sarah Wyman	sarah.wyman@warmmail.com	New York	New York	3002642312860908	e0fb3836d6aea952a7ef4774351bf205	Diners Club / Carte Blanche	40.6326235692240303	-73.8817921718943893
39605	2020-07-24 12:53:09	2020-07-24	Alethea Bergnaum	alethea.bergnaum@geemail.com	Tempe	Arizona	4609891127557384	8bb47f98888408be3f9015e6b5c39799	JCB 15 digit	33.3814939830839634	-111.99433872909583
39606	2020-07-24 13:05:37	2020-07-24	Ignatius Hand-Hoppe	ignatius.hand.hoppe@woohoo.com	Tallahassee	Florida	3112224972326556875	80fb454b56ab5f6ecfc7576b49f80dfa	JCB 16 digit	30.4223490303404631	-84.2708780064728131
39607	2020-07-24 13:11:45	2020-07-24	Handy Bernier	handy.bernier@geemail.com	Abilene	Texas	869948402875947741	64d01d750a2e14b716db83edbeb3630f	Diners Club / Carte Blanche	32.4594125314690203	-99.642192251602566
39608	2020-07-24 13:25:11	2020-07-24	Helaine Hackett	helaine.hackett@geemail.com	Nashville	Tennessee	6011555441921732462	72bca3269ee2bd0ec6ce369a5201f24b	JCB 16 digit	36.2131261148147274	-86.8420386726874796
39609	2020-07-24 13:26:11	2020-07-24	Dr. Hardy Bernier	dr.hardy.bernier@geemail.com	Fairfield	California	3096577725183768147	75c0845c5431ff1019b842c9bf2f0f38	VISA 16 digit	38.3222464098718021	-122.075447967742008
39610	2020-07-24 13:29:42	2020-07-24	Ansley Heathcote	ansley.heathcote@geemail.com	Phoenix	Arizona	3096236955823161709	8026ddbb62deb5f36c0795b91f9af7b1	VISA 16 digit	33.5416249018561103	-112.105394950548572
39611	2020-07-24 13:37:08	2020-07-24	Elex Kemmer III	elex.kemmer.iii@geemail.com	Los Angeles	California	676218485131041	3ca2cef4bf39010e6d8e9f1d519eee8b	VISA 13 digit	34.0398109239391928	-118.480884062684325
39612	2020-07-24 13:47:07	2020-07-24	Kayson Luettgen	kayson.luettgen@geemail.com	Austin	Texas	3528154026767520793	c2e6f87e3286a24ce8ee684731c9fc5f	VISA 16 digit	30.2654167889744024	-97.6955013260018177
39613	2020-07-24 13:53:39	2020-07-24	Ms. Leann Cassin	ms.leann.cassin@geemail.com	Los Angeles	California	4923516819151	ed080d481816ad726adaf5af672f880d	Diners Club / Carte Blanche	33.9565597818564626	-118.464819162291661
39614	2020-07-24 14:02:32	2020-07-24	Mr. Aldo Miller MD	mr.aldo.miller.md@woohoo.com	Fort Worth	Texas	869954941566335725	de65c17083594028bcab2c25273aa339	Discover	32.7385286096073713	-97.3838129100676611
39615	2020-07-24 14:03:39	2020-07-24	Mrs. Antonetta Marks PhD	mrs.antonetta.marks.phd@woohoo.com	Gilbert	Arizona	3088836987102605076	2a8d8564b869f335324ead954e220128	Maestro	33.3848684314984823	-111.678386960564552
39616	2020-07-24 14:13:43	2020-07-24	Betsy Bogisich-Parisian	betsy.bogisich.parisian@geemail.com	Louisville	Kentucky	3088968097575936089	c06b3aad16c797900f58edb1877dc5ad	Mastercard	38.1429948244612618	-85.5951695418521865
39617	2020-07-24 14:15:27	2020-07-24	Mrs. Angelita Okuneva MD	mrs.angelita.okuneva.md@geemail.com	Salt Lake City	Utah	3096913736827545844	4baa66895b0e870783a2c37f4baa8656	Discover	40.6907761031907	-111.889683271845797
39618	2020-07-24 14:15:37	2020-07-24	Clinton D'Amore-Davis	clinton.d'amore.davis@geemail.com	Stamford	Connecticut	4938449639435	554ddddd72e733b208d87b62d32fa265	JCB 15 digit	41.1130468875054262	-73.4739765260405875
39619	2020-07-24 14:20:04	2020-07-24	Hiroshi Connelly	hiroshi.connelly@woohoo.com	Los Angeles	California	501839729905339	5500bba3919bf9791c5236ae33dce3b9	Voyager	34.0916086954396178	-118.482737131788582
39620	2020-07-24 14:21:48	2020-07-24	Juan Waelchi	juan.waelchi@warmmail.com	San Francisco	California	869928344903855708	65e3f9089cd2ac4948f8e6f06456f8d4	Maestro	37.7664559273975655	-122.426852614580937
39621	2020-07-24 14:27:37	2020-07-24	Carmelo Harvey	carmelo.harvey@geemail.com	San Francisco	California	4097630439285337	e537ec94f211bd400ab8411bec36e5fc	Diners Club / Carte Blanche	37.8040106130760307	-122.428444817079068
39622	2020-07-24 14:32:41	2020-07-24	Elzada Morissette	elzada.morissette@woohoo.com	Akron	Ohio	3052749843999459	3a9bb286980168c0f581e37923f1dffc	VISA 16 digit	41.1663620554674452	-81.599186898147309
39623	2020-07-24 14:33:54	2020-07-24	Dr. Aloys Pfeffer	dr.aloys.pfeffer@geemail.com	Clarksville	Tennessee	180017410652601461	02604ebfd9992bd014710f9ce33cef7b	American Express	36.5507612666241855	-87.3753244223956074
39624	2020-07-24 14:44:56	2020-07-24	Tollie Douglas	tollie.douglas@geemail.com	St. Louis	Missouri	3419273316908617	6798d256553ba7fec7c075579ab4db49	JCB 16 digit	38.5813134647596598	-90.288359493762627
39625	2020-07-24 14:49:21	2020-07-24	Vallie Quigley	vallie.quigley@geemail.com	Tucson	Arizona	676192675940685	a4503536986305d2a99be1d797c64c59	VISA 16 digit	32.0692188775673515	-110.927502054417872
39626	2020-07-24 15:00:58	2020-07-24	Ms. Ernestina Legros	ms.ernestina.legros@warmmail.com	Bakersfield	California	3088927685767693623	d420b6088fd9c684132c03d69413a7ec	Maestro	35.401139779220145	-118.952196924601864
39627	2020-07-24 15:05:02	2020-07-24	Samara Champlin MD	samara.champlin.md@warmmail.com	Hialeah	Florida	4003528269743826	c1955304b5f245179b826f35a3867388	VISA 16 digit	25.7831155624683959	-80.3244325712691989
39628	2020-07-24 15:07:20	2020-07-24	Roma Kessler	roma.kessler@geemail.com	Miami	Florida	4104056469444670	0f92990cd9deaca75c66a815675dd2f8	Mastercard	25.7569592751700434	-80.1843507909555058
39629	2020-07-24 15:07:53	2020-07-24	Amey Kshlerin	amey.kshlerin@geemail.com	Indianapolis	Indiana	6011035830616770474	a7ae8bf0209b03b8d9e06f9a4064bf99	Maestro	39.7383568976547537	-86.1540533628981535
39630	2020-07-24 15:09:44	2020-07-24	Eller Bauch MD	eller.bauch.md@woohoo.com	Laredo	Texas	4162285916969	906e154ce5de776d160db4a3ba926a24	Voyager	27.5870103148460402	-99.4298939957756573
39631	2020-07-24 15:09:47	2020-07-24	Lesia O'Conner	lesia.o'conner@warmmail.com	Montgomery	Alabama	3096796276127218166	33c513570f6656e4fa57a8b78149bffa	JCB 16 digit	32.3976328055772953	-86.2309870899807578
39632	2020-07-24 15:13:44	2020-07-24	Tyrel Murray-Little	tyrel.murray.little@geemail.com	San Francisco	California	3049685882698482	be66a0810de5534184f66aef1b64cafd	VISA 13 digit	37.7690605407801385	-122.424614291782959
39633	2020-07-24 15:17:42	2020-07-24	Lavonia Mertz	lavonia.mertz@warmmail.com	New York	New York	3417238395661298	dafa57c8316bb23018b8bab1107bc79b	JCB 16 digit	40.7125320298355078	-73.9742612754356088
39634	2020-07-24 15:20:08	2020-07-24	Clemon Kiehn DVM	clemon.kiehn.dvm@geemail.com	Tampa	Florida	4003416217739	b1c581f32975de552f853ed0b1eca92a	American Express	27.8754993587847792	-82.4099586720325021
39635	2020-07-24 15:25:32	2020-07-24	Quiana Wolf	quiana.wolf@geemail.com	San Francisco	California	676313803062903	8223f24fb5b88f17058426c3214b8b5e	Maestro	37.7628034187294972	-122.440671807669659
39636	2020-07-24 15:26:47	2020-07-24	Tai Walker	tai.walker@geemail.com	El Paso	Texas	3088434243362079339	102e4ec13050a291d5c6a6938cc9a573	JCB 16 digit	31.9042553045615556	-106.470785743042839
39637	2020-07-24 15:39:09	2020-07-24	Mr. Vance Franecki I	mr.vance.franecki.i@geemail.com	San Francisco	California	3018066666979680	c63f2cfcf2803a8a77dfed24999f904f	Voyager	37.8045076712501569	-122.391196956030385
39638	2020-07-24 15:45:40	2020-07-24	Crysta Rice	crysta.rice@geemail.com	New York	New York	3528175665696523777	fb6693cb8c8efc94ca79002e141ae022	Voyager	40.6783710436187675	-74.0089110543847113
39639	2020-07-24 16:08:35	2020-07-24	Ms. Felicia Wiegand DDS	ms.felicia.wiegand.dds@geemail.com	Denver	Colorado	4099953319953	4c34a48490188192e5a03da1a18e9d51	JCB 15 digit	39.7905685570143106	-104.837626591209698
39640	2020-07-24 16:12:06	2020-07-24	Syble Bartell DDS	syble.bartell.dds@geemail.com	Huntsville	Alabama	503859915755058	9c895a2e5800c6a42aaf1c05949b505f	VISA 13 digit	34.6669328300990145	-86.669275036269795
39641	2020-07-24 16:13:55	2020-07-24	Mrs. Aline Mills DVM	mrs.aline.mills.dvm@geemail.com	Fayetteville	North Carolina	630436585672342	03ddc36a4cb470448d642671c5370ca2	American Express	35.0639592371668627	-78.939283194731928
39642	2020-07-24 16:16:11	2020-07-24	Auther Huels IV	auther.huels.iv@woohoo.com	New York	New York	3088224660209914010	37466b84c40a024aa0173103a1568fa9	VISA 13 digit	40.6984510283675007	-73.8892756534635993
39643	2020-07-24 16:17:12	2020-07-24	Jensen Hettinger	jensen.hettinger@geemail.com	Hayward	California	869955156974330528	d07212d7ebd8701c3b77b486586a453a	JCB 15 digit	37.5547169517714536	-122.109123327189693
39644	2020-07-24 16:23:12	2020-07-24	Evita Trantow	evita.trantow@geemail.com	Henderson	Nevada	6011505517469554128	d274d00316b6b77d40f973e28c9853c7	JCB 16 digit	36.0198182646118141	-115.011930540033433
39645	2020-07-24 16:25:21	2020-07-24	Ewing Kuhic	ewing.kuhic@geemail.com	San Diego	California	869966185642133110	49b501e3c8f558b3924f8b3356469542	VISA 13 digit	32.8882370881803325	-117.233771258629858
39646	2020-07-24 16:38:00	2020-07-24	Jena Trantow	jena.trantow@geemail.com	Jackson	Mississippi	630479711726376	678cd8fb9650c4f2fc8a4c12ceeb5834	Voyager	32.2710252584602699	-90.2986053369913293
39647	2020-07-24 16:42:11	2020-07-24	Erick Botsford-Torp	erick.botsford.torp@geemail.com	Cary	North Carolina	3337985402843248144	4aab8b9ab46ccc31add0687a046c08f1	JCB 16 digit	35.6898330838993232	-78.8532219722952732
39648	2020-07-24 16:45:34	2020-07-24	Eliana Huels	eliana.huels@woohoo.com	San Diego	California	210095523409385819	9ffcd1f9564c9f4b429afd8189d214bc	JCB 15 digit	32.8160723359391113	-117.224690156234431
39649	2020-07-24 16:45:51	2020-07-24	Kate Johnston	kate.johnston@woohoo.com	Naperville	Illinois	4849533393264143	413f85a55c5e96eab29a5cde473f19e7	Diners Club / Carte Blanche	41.7290914665356283	-88.205102005077535
39650	2020-07-24 16:49:19	2020-07-24	Philo Hoppe	philo.hoppe@woohoo.com	Las Vegas	Nevada	3048835788783034	643433b0d6965b6717160c6186c779fc	Diners Club / Carte Blanche	36.2070780557680862	-115.238537325917179
39651	2020-07-24 16:49:29	2020-07-24	Merritt Kihn-Jacobs	merritt.kihn.jacobs@geemail.com	Los Angeles	California	210018294884682922	6fa5d1d3ae24ab1cc6a42f6b30621640	Mastercard	34.0376014509104152	-118.325212124222134
39652	2020-07-24 16:54:00	2020-07-24	Ashby Douglas	ashby.douglas@warmmail.com	Nashville	Tennessee	869943481912208577	9fbe5f33d9a7e4000ee6ad320456e242	VISA 16 digit	36.0794242499984747	-86.868206664212039
39653	2020-07-24 17:03:24	2020-07-24	Iesha Johns	iesha.johns@woohoo.com	San Antonio	Texas	6011628897560150725	84d87827df21713ee61908ecbb50ab9f	Voyager	29.4232986997883756	-98.6172066667418932
39654	2020-07-24 17:04:16	2020-07-24	Lassie Hackett	lassie.hackett@geemail.com	Buffalo	New York	4170755830081256	309aabcc2a7ceef7201d0ccd2c897489	Diners Club / Carte Blanche	42.9145108957961199	-78.7753808361411103
39655	2020-07-24 17:04:52	2020-07-24	Dr. Dario Farrell III	dr.dario.farrell.iii@geemail.com	Overland Park	Kansas	4828602241314767	2b31a730c002b90e601903f23a094a69	JCB 16 digit	38.8814328725785074	-94.7102038157679118
39656	2020-07-24 17:13:17	2020-07-24	Drake West	drake.west@warmmail.com	Wichita	Kansas	6011550659403701359	f22dbe36257ff791f5c32bb84b20c805	Mastercard	37.651905762019382	-97.4010261012442413
39657	2020-07-24 17:14:44	2020-07-24	Elvis Gerlach	elvis.gerlach@geemail.com	Virginia Beach	Virginia	53490811083000858	5c24716c085b7fc1eb2c147726df78d6	JCB 15 digit	36.8103031587973248	-76.1039375602871218
39658	2020-07-24 17:16:44	2020-07-24	Tresa Moore	tresa.moore@warmmail.com	Charleston	South Carolina	4300328803568	cb13740fd6b2677a13f623f7043ca8d7	Voyager	32.8187601410314471	-79.8758299638200526
39659	2020-07-24 17:18:17	2020-07-24	Astrid Gottlieb	astrid.gottlieb@geemail.com	Murrieta	California	210059020028915310	c3ec1760f64cb41afa5a010496f17ff5	Maestro	33.4788304216325301	-117.282467388677972
39660	2020-07-24 17:19:56	2020-07-24	Frederick Rice	frederick.rice@warmmail.com	Indianapolis	Indiana	3096080096224354812	199ba8d431c38274aaed58b9f6eb5db6	American Express	39.7605208703324209	-86.1464836682394122
39661	2020-07-24 17:29:59	2020-07-24	Frazier Torphy-D'Amore	frazier.torphy.d'amore@geemail.com	Stockton	California	180075099985631375	3fdd49a17dfceca077fa31ae77bba377	Mastercard	37.9295170429360127	-121.351109132598339
39662	2020-07-24 17:31:06	2020-07-24	Dr. Eugene Quitzon	dr.eugene.quitzon@warmmail.com	San Francisco	California	3337671884670729909	1c3620b1aea246b980a59474c4ed4514	JCB 16 digit	37.776226490733265	-122.448107753280823
39663	2020-07-24 17:31:25	2020-07-24	Exa Volkman	exa.volkman@geemail.com	Lakewood	Colorado	3056871266696028	7f963af7431de9eb49c7f82bc91c96ff	VISA 13 digit	39.7888292964488315	-105.132934900375446
39664	2020-07-24 17:37:17	2020-07-24	Gerhardt Murray	gerhardt.murray@woohoo.com	Saint Paul	Minnesota	3009756926344654	85ab2687b7cd5f966ba96387ba2f7e0c	American Express	45.0100970864702035	-93.185105495879796
39665	2020-07-24 17:44:51	2020-07-24	Kyleigh Stanton	kyleigh.stanton@geemail.com	Thornton	Colorado	3112261639929104395	3247568f87030b149ec84739c83d4cb5	American Express	39.9748666743148178	-104.933658760615813
39666	2020-07-24 17:59:43	2020-07-24	Ruben Dach	ruben.dach@geemail.com	Anaheim	California	6011173390057243319	26047bc72d2e12956d55b594dc6771a0	American Express	33.8281921857800327	-117.739452102661502
39667	2020-07-24 18:03:25	2020-07-24	Wes Toy	wes.toy@geemail.com	Honolulu	Hawaii	869964054002842888	ae6852b742cacb0c3c65b4d04590f9b5	JCB 15 digit	21.3861376819882558	-157.890283268710959
39668	2020-07-24 18:05:41	2020-07-24	Dr. Terry Kassulke PhD	dr.terry.kassulke.phd@geemail.com	Los Angeles	California	4400839944757522	2032f93ba0aa1f1843f3d3f1cd6b0b3b	VISA 13 digit	33.9303110536053723	-118.495288856652749
39669	2020-07-24 18:12:46	2020-07-24	Orrie Tillman-Wiegand	orrie.tillman.wiegand@warmmail.com	Greensboro	North Carolina	180019286114803525	25975486861beeff0e7841d890c5a6af	VISA 16 digit	36.0468340919934249	-79.7866573106944514
39670	2020-07-24 18:14:23	2020-07-24	Emmalee Ritchie	emmalee.ritchie@geemail.com	Green Bay	Wisconsin	676291146057509	6fb632b11808bd278afc7c96bc665f79	Voyager	44.5330806476592969	-87.9848643713451963
39671	2020-07-24 18:23:00	2020-07-24	Lillian Schmidt MD	lillian.schmidt.md@geemail.com	New York	New York	210083168208426622	06cb30eb7c23fb5fbef81b3cde84321d	JCB 16 digit	40.5886077540684482	-73.8782779519807491
39672	2020-07-24 18:23:50	2020-07-24	Levie Langworth-Tromp	levie.langworth.tromp@woohoo.com	Berkeley	California	501875008187330	8011b328574cbd38ee3b286cd69cc04b	JCB 15 digit	37.9020655752580637	-122.277943088280253
39673	2020-07-24 18:32:34	2020-07-24	Barbie Predovic	barbie.predovic@warmmail.com	San Francisco	California	53863402068790702	d69b049e1d4432812180308ff719a47a	JCB 16 digit	37.7643617018342539	-122.418713186013392
39674	2020-07-24 18:33:21	2020-07-24	Alton Adams	alton.adams@warmmail.com	Sacramento	California	3088190996057092131	fd33175e2dbebef6ec2106bbd96c59f2	JCB 15 digit	38.4891368125829842	-121.439668179933349
39675	2020-07-24 18:46:21	2020-07-24	Mr. Tayler Bartoletti Sr.	mr.tayler.bartoletti.sr.@geemail.com	Houston	Texas	210080363480515647	8295f339c2cbcb92e40179eea4b49705	American Express	29.7085424678012728	-95.3806763476241457
39676	2020-07-24 18:49:23	2020-07-24	Mr. Emmet O'Connell	mr.emmet.o'connell@geemail.com	Springfield	Illinois	4050811581631	ccff9cf07be80aaf352e0e18314e9826	JCB 16 digit	39.820399116181207	-89.596449101670089
39677	2020-07-24 18:53:33	2020-07-24	Almer Rippin	almer.rippin@woohoo.com	Modesto	California	4044727651529725	3ed2b035145967e26be7b039fdef5155	American Express	37.6732820087578162	-120.919761167813093
39678	2020-07-24 18:54:11	2020-07-24	Ms. Hassie Herzog DVM	ms.hassie.herzog.dvm@warmmail.com	Peoria	Illinois	4088075923514829	6eaaa8a2eebd78cc1346ab99a8b4ff07	Diners Club / Carte Blanche	40.6891647081691801	-89.5841247438803379
39679	2020-07-24 19:08:36	2020-07-24	Miss Gina Smith DDS	miss.gina.smith.dds@geemail.com	Los Angeles	California	3470964068013913	68edd98ba7e1f78c9da52c454435700b	VISA 13 digit	34.0538217670615708	-118.429613382042561
39680	2020-07-24 19:12:11	2020-07-24	Roman Goldner-Collins	roman.goldner.collins@warmmail.com	San Francisco	California	4229159550693	f8dabe68c9ecca91f5247c99ce5d534a	JCB 16 digit	37.7719241682416254	-122.434138647235798
39681	2020-07-24 19:13:01	2020-07-24	Carlota Kutch	carlota.kutch@geemail.com	Long Beach	California	54257726393797758	132659c7bad12d448240200ea07d6f0b	Discover	33.8275029227890016	-118.181739437456429
39682	2020-07-24 19:15:06	2020-07-24	Mortimer Dietrich	mortimer.dietrich@geemail.com	St. Petersburg	Florida	53925970746344965	14c51b25792eb37dc74cafaa39e793a2	VISA 16 digit	27.6707410926353177	-82.6158385481111708
39683	2020-07-24 19:15:46	2020-07-24	Kelsi Ortiz	kelsi.ortiz@woohoo.com	New Orleans	Louisiana	4862426148193901	34c881eb246202750b0c3a8b50f5336e	VISA 16 digit	30.0230255388669676	-89.9565779941882937
39684	2020-07-24 19:33:54	2020-07-24	Billie Bartoletti MD	billie.bartoletti.md@warmmail.com	New York	New York	561240296053776	668ad1c5a489237d02afd16edd04e4aa	Diners Club / Carte Blanche	40.6707585416957755	-74.0073931370757521
39685	2020-07-24 19:43:06	2020-07-24	Barnett Leannon-Herzog	barnett.leannon.herzog@woohoo.com	Oakland	California	676332974005186	8b7451a9a3d565a1407b72f274a8298a	VISA 13 digit	37.7916365659312063	-122.291938492453454
39686	2020-07-24 19:46:16	2020-07-24	Less Denesik	less.denesik@woohoo.com	Los Angeles	California	4710900354915	09168f0f50167d34be949c72d1649453	VISA 16 digit	34.0138052720442374	-118.387266793427244
39687	2020-07-24 20:12:42	2020-07-24	Lucero Wilkinson	lucero.wilkinson@woohoo.com	Lubbock	Texas	3158504445663845319	f70e438463c5465eec14fe7d97a67b3b	Discover	33.6115276425652212	-101.824899666561564
39688	2020-07-24 20:14:24	2020-07-24	Corie Schinner	corie.schinner@geemail.com	Yonkers	New York	4687020003442	386e5af34de54c65cfc140ed326d9f0c	American Express	40.8517961425907927	-73.9573780063889927
39689	2020-07-24 20:18:19	2020-07-24	Omer Haag	omer.haag@geemail.com	Dallas	Texas	3337970029415153654	25e586fcd74a12fadf21065a70ed64a3	American Express	32.8625857612855725	-96.6693995742555643
39690	2020-07-24 20:20:56	2020-07-24	Brianne Baumbach	brianne.baumbach@geemail.com	San Francisco	California	4004278032000133	fbbcc0eac4ebcd3b583959b2a593e836	JCB 16 digit	37.7927042095986252	-122.429326896523932
39691	2020-07-24 20:26:38	2020-07-24	Casimiro Johns	casimiro.johns@geemail.com	Portland	Oregon	3776411085237558	ccbd21513746c54f850466fdbfe3cd16	JCB 16 digit	45.5934498021733035	-122.745649559050804
39692	2020-07-24 20:33:45	2020-07-24	Cruz Bartell	cruz.bartell@warmmail.com	Philadelphia	Pennsylvania	3337626697958556158	efadb0ee7762b0b0204926213971a5f1	American Express	39.9449194755829851	-75.1138728964973268
39693	2020-07-24 20:34:48	2020-07-24	Dr. Kenley Swift	dr.kenley.swift@woohoo.com	Philadelphia	Pennsylvania	869900996624534086	cbf49ce53390c25d48fe530f9d603872	JCB 15 digit	40.075820996468515	-75.0602476956687923
39694	2020-07-24 20:48:42	2020-07-24	Evelina Sawayn	evelina.sawayn@geemail.com	San Francisco	California	4801279421306904	63efe61df95dd66bb7dc28ec2ef25572	JCB 15 digit	37.7656973215368552	-122.409624068094303
39695	2020-07-24 20:54:49	2020-07-24	Kellee Haag-Mante	kellee.haag.mante@warmmail.com	San Francisco	California	4473276067311690	b0f4315acd0073bc1d86c56d1d0704f0	VISA 16 digit	37.7732773491595282	-122.434823725522804
39696	2020-07-24 20:56:10	2020-07-24	Mr. Kelby Anderson V	mr.kelby.anderson.v@geemail.com	Jackson	Mississippi	4082836180180	c7d423678af444596986c6be51411cae	VISA 13 digit	32.3860040860895069	-90.1989131968442308
39697	2020-07-24 21:06:37	2020-07-24	Audrianna Nienow	audrianna.nienow@woohoo.com	San Diego	California	6011504688211780021	e091ea2427e3a75cd16db50816fafade	American Express	32.8012981285408145	-117.210907382462182
39698	2020-07-24 21:09:59	2020-07-24	Zelpha Huels	zelpha.huels@geemail.com	San Francisco	California	55765452852822038	b7378e8b39388106f10fa56ab45032a4	Mastercard	37.7736134644063881	-122.439877126670638
39699	2020-07-24 21:17:40	2020-07-24	Corrina Kunze	corrina.kunze@geemail.com	Garden Grove	California	4702655438191	b6c264cec7e3880f52f3bd3e7bf2faa8	VISA 16 digit	33.8602165742136521	-118.033749347321688
39700	2020-07-24 21:23:14	2020-07-24	Dr. Jorden Lowe	dr.jorden.lowe@woohoo.com	Clarksville	Tennessee	502008853411984	6e6b2a1cf1fcc6a66cfc1bdc5c1d8aad	Voyager	36.5477440639991329	-87.3119492046952246
39701	2020-07-24 21:26:38	2020-07-24	Tinnie Dibbert DVM	tinnie.dibbert.dvm@geemail.com	Joliet	Illinois	51373470820201030	ad15b700ea2dee7a6113603211d47890	Mastercard	41.610901341480016	-88.1275819785065835
39702	2020-07-24 21:28:09	2020-07-24	Ms. Tamie Schmeler	ms.tamie.schmeler@geemail.com	Hillsboro	Oregon	3027184534114553	0bd4c94d86c748b130c3d4686708ea03	American Express	45.6058243098873604	-122.854907947887483
39703	2020-07-24 21:34:03	2020-07-24	Dr. Arlin Flatley Sr.	dr.arlin.flatley.sr.@geemail.com	Miami	Florida	4618307019868010	8daedb36aecdacce183257daeb58d842	VISA 16 digit	25.827251238249989	-80.3008926033847104
39704	2020-07-24 21:37:15	2020-07-24	Dr. Lott Feest	dr.lott.feest@woohoo.com	Hampton	Virginia	6011424839562099381	b38f9b574b7f8b7774fdc788ad0bb33c	JCB 16 digit	36.9497023417633059	-76.3379789392095063
39705	2020-07-24 21:48:06	2020-07-24	Knox Nitzsche	knox.nitzsche@geemail.com	San Francisco	California	6011361401602748298	2f8a21c9e07cd1bf6c4760eb4cd442df	Voyager	37.7437924000821425	-122.440105802303265
39706	2020-07-24 21:53:05	2020-07-24	Mireya Maggio	mireya.maggio@geemail.com	Houston	Texas	4390115990173	e390cfec0e62e0bd701eb68255e6feb5	VISA 16 digit	29.8580872532058521	-95.4504731322187894
39707	2020-07-24 21:54:32	2020-07-24	Leanna White MD	leanna.white.md@geemail.com	New York	New York	3455563497548389	ea81f1fcc5b1d5f9aa35eb5c7b21d6ab	American Express	40.7344791219327576	-73.850459745748708
39708	2020-07-24 21:57:18	2020-07-24	Sharde Hermiston	sharde.hermiston@geemail.com	Downey	California	4273285190484631	7f8d6b9ca703ed7f627fcd8960cff757	American Express	33.9990108898624825	-118.203480274846399
39709	2020-07-24 22:16:47	2020-07-24	Baron Klein-Nienow	baron.klein.nienow@geemail.com	Oakland	California	561265005072718	8be5cc75702b227e3e904c0c77ab6719	American Express	37.8159904349039593	-122.278322383872521
39710	2020-07-24 22:19:18	2020-07-24	Mrs. Waneta Effertz MD	mrs.waneta.effertz.md@woohoo.com	Olathe	Kansas	3473957890779922	b2888da0f9f5646251f9e9d8f858baa3	Discover	38.9626317790832388	-94.9050344544164943
39711	2020-07-24 22:28:03	2020-07-24	Corrine Kuphal	corrine.kuphal@geemail.com	St. Petersburg	Florida	501875985566399	167e2b21e5b88944f02aee7f2c7609c4	JCB 15 digit	27.6899572605155413	-82.637108286412797
39712	2020-07-24 22:28:42	2020-07-24	Ernie Rolfson	ernie.rolfson@woohoo.com	Port St. Lucie	Florida	4464385685175	6af2c655f473d4480961bc69380fda1f	Maestro	27.1967823448259374	-80.4686931751288483
39713	2020-07-24 22:33:17	2020-07-24	Ray Grimes	ray.grimes@geemail.com	Philadelphia	Pennsylvania	4805991620340379	344f9bc2ebdac514299a668d7fc83b2f	JCB 16 digit	40.0308976733084734	-75.0352126685802006
39714	2020-07-24 22:35:01	2020-07-24	Stephany Batz	stephany.batz@geemail.com	Los Angeles	California	3425551857975562	f395ec31304d3ed52e69414150e705b1	Diners Club / Carte Blanche	33.9719900157168482	-118.490938019239522
39715	2020-07-24 22:41:41	2020-07-24	Miss Consuelo Stanton	miss.consuelo.stanton@geemail.com	Pasadena	Texas	3480752227689170	8e00d6729c0a99327199983d5badd7ca	Discover	29.5597300913989542	-95.1448844452336431
39716	2020-07-24 22:46:09	2020-07-24	Annis Mann	annis.mann@geemail.com	Stockton	California	3112898470257969972	54f4013efbaecc55676be1d7d9f9f95b	Mastercard	37.9066393881767993	-121.410864083524046
39717	2020-07-24 22:48:19	2020-07-24	Unnamed Stamm DDS	unnamed.stamm.dds@geemail.com	Tucson	Arizona	3528800953264406481	d3f5aeb8b589211134eca249662ec4f3	VISA 16 digit	32.0985570153728119	-110.960407238662611
39718	2020-07-24 22:50:07	2020-07-24	Menachem Wunsch	menachem.wunsch@geemail.com	Jersey City	New Jersey	6011980180552415881	663fee93e4ce4379d9045cf7ed9dc8e8	Diners Club / Carte Blanche	40.728655118116734	-73.9999864220108918
39719	2020-07-24 22:51:26	2020-07-24	Myrtice Schultz	myrtice.schultz@geemail.com	Berkeley	California	3751735340630242	1b195adc274de36ff79399fffc78d997	Mastercard	37.8929974574836592	-122.277257449072152
39720	2020-07-24 22:59:11	2020-07-24	Walter Hane IV	walter.hane.iv@warmmail.com	Honolulu	Hawaii	4588858515500669	34325e4ecfa0520dd4361dd4e4873f05	JCB 16 digit	21.3627464352857324	-157.866094809884572
39721	2020-07-24 23:01:20	2020-07-24	Miss Alabama Hermiston DDS	miss.alabama.hermiston.dds@geemail.com	New York	New York	4147774922828516	ee6b340465a5cea5dc7a27cb239f7043	JCB 15 digit	40.6710115664396454	-73.8805426432646755
39722	2020-07-24 23:08:00	2020-07-24	Gena Gislason DVM	gena.gislason.dvm@geemail.com	Los Angeles	California	180014523147291244	f079a1824a40748b4d4a0e50b4a5be87	Discover	34.1013757043849637	-118.428396993129695
39723	2020-07-24 23:10:07	2020-07-24	Dollie Fay	dollie.fay@geemail.com	Gresham	Oregon	53411364762706045	3c3219aa4ec1cc387c281a20d6655e26	VISA 16 digit	45.4875293507661667	-122.522240706187105
39724	2020-07-24 23:10:45	2020-07-24	Dink Hyatt	dink.hyatt@geemail.com	Macon	Georgia	3158927457376391183	cd678bf1aaaab7efb1837bac12c64fdd	Voyager	32.8777528957940604	-83.6145958617988896
39725	2020-07-24 23:11:55	2020-07-24	Dijon Cruickshank	dijon.cruickshank@geemail.com	Toledo	Ohio	4686780228110944	be50438b589bdb5a941298146e28da38	Voyager	41.6602576565168761	-83.5687159214034665
39726	2020-07-24 23:13:11	2020-07-24	Halley Thompson	halley.thompson@geemail.com	Baltimore	Maryland	869938499123777518	76f9051558525bccfd6d406c4a9ba408	VISA 16 digit	39.2108138804323971	-76.692681380456321
39727	2020-07-24 23:15:49	2020-07-24	Debi Hilpert	debi.hilpert@geemail.com	Phoenix	Arizona	4020561135250790	ea78f9856d779d4b67aeb74536105b27	Voyager	33.5385517619483196	-112.111626631759492
39728	2020-07-24 23:26:58	2020-07-24	Susanna Wiegand	susanna.wiegand@woohoo.com	Tulsa	Oklahoma	6011365357890293890	ac9b4a3932fe939e8cf35666b9d8feb0	Maestro	36.1471773428745564	-95.9674429120916841
39729	2020-07-24 23:32:20	2020-07-24	Elwin Ledner	elwin.ledner@geemail.com	San Francisco	California	6011054085667099200	beeb3e9a1d818cd3077c3b72eed91431	JCB 16 digit	37.7945012612294491	-122.409047329842963
39730	2020-07-24 23:41:51	2020-07-24	Dr. Ashley Schamberger DDS	dr.ashley.schamberger.dds@warmmail.com	Nashville	Tennessee	4707955598800	9c48bd6e8ddfaab559e916d9a4449f23	VISA 16 digit	36.1734318662557754	-86.7493600008916133
39731	2020-07-24 23:43:13	2020-07-24	Glendon Donnelly	glendon.donnelly@geemail.com	Stockton	California	3096924695841591043	453572827b136ded5feab99110114aa9	JCB 15 digit	37.9742771398939212	-121.289216255312041
39732	2020-07-24 23:48:18	2020-07-24	Ms. Eppie Shields MD	ms.eppie.shields.md@warmmail.com	New York	New York	4369281984293	c159df4c05e88df206b23eb25aac1b09	VISA 13 digit	40.6476229694895466	-73.9044749075442553
39733	2020-07-24 23:55:39	2020-07-24	Ms. Tonya Schmidt	ms.tonya.schmidt@geemail.com	Escondido	California	3715298514458507	ce4bf9d00d4e585901dea4a1c860288d	VISA 13 digit	33.2255740114714939	-117.034318976594136
39734	2020-07-25 00:20:18	2020-07-25	Press Emmerich	press.emmerich@geemail.com	Houston	Texas	3021489798209445	7e4fb52de41a529660cb5e8cfb69b0ba	JCB 16 digit	29.7300077860787511	-95.3356381267324053
39735	2020-07-25 00:33:36	2020-07-25	Louanna Zulauf	louanna.zulauf@woohoo.com	Mesa	Arizona	4199172207461839	505fa4546b88fd4ca08da60cc4d0d554	VISA 16 digit	33.4730364804767078	-111.635232746542982
39736	2020-07-25 00:56:52	2020-07-25	Janet Kessler	janet.kessler@warmmail.com	San Francisco	California	55519674576385153	f0019c2da54662f6ecfac1e01fb3d832	JCB 16 digit	37.7984511726287238	-122.424196837735693
39737	2020-07-25 00:57:28	2020-07-25	Leticia Fritsch	leticia.fritsch@woohoo.com	Garland	Texas	3088110538658513722	2ab6e5f3d26bcde97a4d5ba893a4d1d1	JCB 16 digit	32.9699393106393472	-96.5834222891993903
39738	2020-07-25 01:19:36	2020-07-25	Pearle Goyette-Trantow	pearle.goyette.trantow@geemail.com	Riverside	California	3088004632264242997	83c22288d9ca86c94b7b272a299922ed	JCB 15 digit	33.9547517503559604	-117.355233697217699
39739	2020-07-25 01:28:47	2020-07-25	Isa Huel	isa.huel@geemail.com	Cape Coral	Florida	180036164604163461	ac79d48f774f8be72c4958f65171fd87	JCB 15 digit	26.5741575764462361	-82.0740637396998665
39740	2020-07-25 01:30:35	2020-07-25	Garnet Cremin	garnet.cremin@geemail.com	San Francisco	California	4517949633108117	f785aa653d67d678f6d9dfc043db07ee	American Express	37.7382311083671311	-122.43144779249188
39741	2020-07-25 02:01:49	2020-07-25	Katharine Hilpert	katharine.hilpert@geemail.com	Oakland	California	6011688338540156687	827946618e4d54a126c6ed3c364505fe	American Express	37.8064610116553226	-122.260924236920289
39742	2020-07-25 02:05:58	2020-07-25	Dr. Rubi Torphy	dr.rubi.torphy@woohoo.com	Philadelphia	Pennsylvania	3057092328681507	c4c8a2ce39dd6318eea9e9e40cce58ef	JCB 16 digit	40.0836729821242415	-75.0358962454732534
39743	2020-07-25 02:06:51	2020-07-25	Roxy Considine	roxy.considine@geemail.com	Sterling Heights	Michigan	51468632926927505	fd7b391c9813a513a4dbc419d7bf7a95	JCB 16 digit	42.5728458864696364	-83.0778858206395086
39744	2020-07-25 02:13:56	2020-07-25	Dr. Olaf Ward I	dr.olaf.ward.i@warmmail.com	Denver	Colorado	869981140083715132	532507380bf13e4fb73582c8456ba58a	VISA 13 digit	39.7715960150636718	-104.879364158936227
39745	2020-07-25 02:19:46	2020-07-25	Dr. Kierra D'Amore	dr.kierra.d'amore@woohoo.com	Milwaukee	Wisconsin	6011344953003454571	43c21c283c384f235365cae9212d91bc	VISA 16 digit	43.1260624469343554	-87.9745111027367415
39746	2020-07-25 02:29:41	2020-07-25	Kelvin Doyle	kelvin.doyle@geemail.com	San Francisco	California	4516256742029205	1770876ea594d7927a98f77ddefc31da	VISA 13 digit	37.7946792749512781	-122.45294280839029
39747	2020-07-25 02:30:06	2020-07-25	Jaleel Johnston	jaleel.johnston@woohoo.com	Anaheim	California	6011941805908806684	251ca38f297ee7ad4ca127c0bb38e7a9	VISA 13 digit	33.8752076082695268	-117.685507532695681
39748	2020-07-25 02:34:49	2020-07-25	Deegan Maggio	deegan.maggio@geemail.com	Phoenix	Arizona	3088587303384795141	98b7fb75631338435ac8a258f6d6db9b	VISA 16 digit	33.6279857564650513	-112.014816477794582
39749	2020-07-25 02:35:54	2020-07-25	Harmon Wolff	harmon.wolff@geemail.com	Newport News	Virginia	4033331929993	8a4010d693dc74e415fc42fe71d2dc74	Voyager	37.0751827459678083	-76.5601727686151889
39750	2020-07-25 02:36:31	2020-07-25	Dwyane Abbott	dwyane.abbott@geemail.com	Vancouver	Washington	180084786033026108	506418b4ab2e4a96f96f7139d7f231c0	VISA 16 digit	45.6498786460679042	-122.581219581660619
39751	2020-07-25 02:37:40	2020-07-25	Acey Thompson II	acey.thompson.ii@geemail.com	Anchorage	Alaska	4247665017804165	e0fcaefed3c0a7815609ead666dfcbf1	VISA 16 digit	61.196631171249976	-149.270448823704584
39752	2020-07-25 02:38:49	2020-07-25	Simone Lakin	simone.lakin@geemail.com	Knoxville	Tennessee	210077126536348528	282231165f57c6ec79fddaf835fb1f78	VISA 13 digit	35.8771752876292922	-83.9069411708258031
39753	2020-07-25 02:41:14	2020-07-25	Cayla Romaguera	cayla.romaguera@warmmail.com	San Francisco	California	210036793604797272	187ab00e218956f638acaa5e4f1f6e65	American Express	37.7788795651954459	-122.477889714428215
39754	2020-07-25 03:00:01	2020-07-25	Zaida Corwin DDS	zaida.corwin.dds@woohoo.com	Atlanta	Georgia	4264612271355	53e5afd0c3bcbbe033246e80860114e3	VISA 13 digit	33.6981623145096023	-84.4565603952434003
39755	2020-07-25 03:06:56	2020-07-25	Jaydon Cassin	jaydon.cassin@woohoo.com	New York	New York	210013005531064974	d862175d48cfdaea52cba271265ac346	Discover	40.6622865401897542	-73.9290275454882533
39756	2020-07-25 03:23:07	2020-07-25	Fidencio Donnelly	fidencio.donnelly@geemail.com	Davenport	Iowa	53048830961606807	d3b3ededee28c5d85f93caf116fcaa5d	JCB 15 digit	41.6267237455848615	-90.5242957709319853
39757	2020-07-25 03:40:45	2020-07-25	Alver Block	alver.block@geemail.com	New York	New York	4078290060348	e4fc54af31674ef471d0761863f50217	Voyager	40.6744812026843405	-73.8552127262007474
39758	2020-07-25 03:41:25	2020-07-25	Aubree Huel	aubree.huel@warmmail.com	Pasadena	California	3493136217477140	5066fe823dbeec9e126d6a679acc4b0e	VISA 16 digit	34.1741219817981161	-118.186620435379822
39759	2020-07-25 03:42:16	2020-07-25	Mr. Almer Keebler	mr.almer.keebler@warmmail.com	Topeka	Kansas	869992187973559655	4ceda4008846916bae5c7cd0f36b11d7	VISA 16 digit	39.0548977076474557	-95.7741217149596764
39760	2020-07-25 03:43:17	2020-07-25	Bret Rutherford	bret.rutherford@woohoo.com	San Francisco	California	4886850522712840	ba030be4f01fbe5ff36e9ccebf4ec4cb	Voyager	37.7342074428868131	-122.435603217939743
39761	2020-07-25 03:46:19	2020-07-25	Mrs. Monica Goyette	mrs.monica.goyette@warmmail.com	Pasadena	Texas	869993583309068305	2e0b6a27f73e1f5f268ac22d6ee25506	Voyager	29.7305031768385319	-95.2374410384748131
39762	2020-07-25 03:47:47	2020-07-25	Dr. Thedore O'Connell	dr.thedore.o'connell@geemail.com	New York	New York	869908450959646968	2a1cb5fc972a8733e804a927f685efeb	VISA 16 digit	40.7446795971821984	-73.8973356396321179
39763	2020-07-25 04:14:55	2020-07-25	Ms. Stacie McDermott	ms.stacie.mcdermott@woohoo.com	Omaha	Nebraska	561223287683942	c646632994b0c7b7a83dc16f16f4d2ac	Diners Club / Carte Blanche	41.3167407938890179	-95.9523670071851456
39764	2020-07-25 04:24:42	2020-07-25	Orah Hagenes	orah.hagenes@geemail.com	Albuquerque	New Mexico	869914018441783285	7d4d3c0863f78c3c86b50d3d160e06aa	JCB 16 digit	35.1123421660292934	-106.716039110401283
39765	2020-07-25 04:25:30	2020-07-25	Stacy Thiel	stacy.thiel@geemail.com	New York	New York	869931132064477924	86d5f56602b09c9a0b94fd9c0d6e3592	Maestro	40.6249208956714725	-73.9914748515829359
39766	2020-07-25 04:29:34	2020-07-25	Brandon Flatley	brandon.flatley@geemail.com	Houston	Texas	3013669048410491	bd9917194e2d000ca7bb417f7383f8a0	VISA 16 digit	29.8019265802189715	-95.320182830283045
39767	2020-07-25 04:41:36	2020-07-25	Jahiem Bartoletti IV	jahiem.bartoletti.iv@geemail.com	Newark	New Jersey	3429174470930124	afa35fcba80ec4c9c30242c82864318b	American Express	40.6600891334850374	-74.2112432954575922
39768	2020-07-25 04:44:46	2020-07-25	Eliezer Torphy	eliezer.torphy@geemail.com	Oakland	California	4937215696503822	2584bbddad66e3154cecc8dacc18d117	VISA 16 digit	37.7779809473736492	-122.282479271095141
39769	2020-07-25 04:52:23	2020-07-25	Dr. Justina Bergstrom PhD	dr.justina.bergstrom.phd@warmmail.com	Cedar Rapids	Iowa	3337749582786340987	40de20758f4cd75b4d7033ce7527f262	JCB 16 digit	42.0649094648268047	-91.6118207446366597
39770	2020-07-25 05:02:41	2020-07-25	Matilde Koelpin-Olson	matilde.koelpin.olson@geemail.com	New York	New York	501811519907056	b1e704964021d4e26a63f28ebdfae61c	Diners Club / Carte Blanche	40.6056848068013778	-73.9832655529387324
39771	2020-07-25 05:28:06	2020-07-25	Jolene Roob-Mueller	jolene.roob.mueller@geemail.com	Phoenix	Arizona	3000068119049168	f28d81262efc4d65644c3dd511554de6	VISA 13 digit	33.639472731289267	-111.999435364354781
39772	2020-07-25 05:34:07	2020-07-25	Dr. Diallo Brekke Sr.	dr.diallo.brekke.sr.@woohoo.com	Worcester	Massachusetts	4535777467513757	41a73de1575f42b1cc896cbbdd119603	JCB 16 digit	42.2613874739669271	-71.8571176863528791
39773	2020-07-25 05:42:30	2020-07-25	Berry Becker-Armstrong	berry.becker.armstrong@geemail.com	Vallejo	California	4120589817166660	4cd5fda3646b3644b9e5521b6e096b90	Maestro	38.0327820841312416	-122.260545883268108
39774	2020-07-25 05:52:13	2020-07-25	Dezzie Oberbrunner	dezzie.oberbrunner@geemail.com	Hollywood	Florida	52765787987097455	e4f89db2980f3b5fe7c87b90ce6967c3	Maestro	26.0717118657603848	-80.0909083929195873
39775	2020-07-25 05:53:04	2020-07-25	Will Bartoletti-Steuber	will.bartoletti.steuber@geemail.com	New York	New York	869931119087575032	6e96a288db4278fff1f0660c73f1fc6d	Voyager	40.6792744367141239	-73.8513353999134097
39776	2020-07-25 05:54:56	2020-07-25	Angelo Reynolds II	angelo.reynolds.ii@geemail.com	San Diego	California	4242191047075986	a244feec859b96b83c103b1030bc4fa5	Voyager	32.8270419090122019	-117.107784970980148
39777	2020-07-25 05:57:52	2020-07-25	Sabastian Morar	sabastian.morar@geemail.com	San Francisco	California	51462029591535315	d01bff123369d92dfe55a435435714bd	VISA 16 digit	37.7789528580073579	-122.452746962240965
39778	2020-07-25 05:58:36	2020-07-25	Mrs. Rosaria Hickle	mrs.rosaria.hickle@geemail.com	Temecula	California	3337312948968421969	bb6d1195092f9d482d6da3774d5965fa	JCB 16 digit	33.4774831726349902	-117.038143165894596
39779	2020-07-25 05:59:32	2020-07-25	Ms. Adaline Feil	ms.adaline.feil@geemail.com	Columbus	Ohio	51860544403249911	efbd4712980416ec4c9869222d829851	Maestro	39.9526740833695939	-82.9305025917247036
39780	2020-07-25 06:02:20	2020-07-25	Josephus Considine	josephus.considine@geemail.com	San Francisco	California	4942396118427	e613a0250c067c21e3974faef3d3b14a	VISA 13 digit	37.7788629128503217	-122.445207654908529
39781	2020-07-25 06:07:22	2020-07-25	Lexi Murphy MD	lexi.murphy.md@geemail.com	Albuquerque	New Mexico	3337821678865428239	0de38cf54ef51cc90f7d8ca4952587b4	Diners Club / Carte Blanche	35.0952900246385511	-106.611224677420779
39782	2020-07-25 06:11:04	2020-07-25	Mr. Grover Franecki II	mr.grover.franecki.ii@geemail.com	Cincinnati	Ohio	4333959804110257	1b02ae7aa475690c66bf20139a31f33c	VISA 13 digit	39.058757827500628	-84.6038591601226386
39783	2020-07-25 06:11:12	2020-07-25	Seymour Trantow	seymour.trantow@geemail.com	New York	New York	4727546147420	2bcd831dec41edd3d3d075cb8a7696dd	VISA 13 digit	40.6577433641757793	-74.0192474245455116
39784	2020-07-25 06:34:08	2020-07-25	Lanny Heathcote	lanny.heathcote@geemail.com	Sacramento	California	3017656827667207	2af695100b0650980d552a65c7d41c48	VISA 13 digit	38.5187196119021635	-121.382464483172072
39785	2020-07-25 06:37:26	2020-07-25	Julio Rodriguez III	julio.rodriguez.iii@woohoo.com	Indianapolis	Indiana	3337249387300851302	597d9f79d1bc8bcc5109b7a51d3cad45	Mastercard	39.7632824607200916	-86.1661861021738531
39786	2020-07-25 06:41:38	2020-07-25	Corliss Harber	corliss.harber@warmmail.com	Los Angeles	California	4284646544899658	e275c8bdc9abfe47e030237c0bcb9f72	Mastercard	34.0277229146432134	-118.444902465538306
39787	2020-07-25 06:42:46	2020-07-25	Treena Erdman	treena.erdman@warmmail.com	San Diego	California	4839049681138891	a95e6f01d92fb8b3e906542e876c40f8	VISA 16 digit	32.788159647311268	-117.096055008787673
39788	2020-07-25 06:43:41	2020-07-25	Laquita Lesch MD	laquita.lesch.md@geemail.com	Oakland	California	3029154376878217	198acbc3e75048ed66ec94ee3f58fe93	JCB 16 digit	37.7754295125006152	-122.272744804138853
39789	2020-07-25 06:52:32	2020-07-25	Leaner Grady	leaner.grady@geemail.com	St. Petersburg	Florida	4212293628253093	db03a4379664d971bb6a3ae9300617f9	Maestro	27.774592368293554	-82.6470378313571103
39790	2020-07-25 06:53:33	2020-07-25	Porter Schmeler-Strosin	porter.schmeler.strosin@geemail.com	New York	New York	589390421203127	75799a25253d7ad12d8d5f49c593a5a8	Voyager	40.7004769847951806	-73.9774302369810641
39791	2020-07-25 07:02:53	2020-07-25	Arch Kub	arch.kub@geemail.com	Long Beach	California	3767477838705689	6faad29c261fe161b4c4b410133d5b8b	Mastercard	33.8285619354628011	-118.179064205584297
39792	2020-07-25 07:09:07	2020-07-25	Jaelyn Mertz	jaelyn.mertz@geemail.com	Los Angeles	California	4700067701735	85dd5e7d88aa3e3ba64303f6bf01251b	JCB 16 digit	34.0218280324578259	-118.462944505782048
39793	2020-07-25 07:13:41	2020-07-25	Tiny Boyer	tiny.boyer@geemail.com	Greeley	Colorado	869956799389298803	a87ff04eb86758e3f0981827001997b5	American Express	40.4649359384618705	-104.682665886434535
39794	2020-07-25 07:17:48	2020-07-25	Cedric Schuppe	cedric.schuppe@geemail.com	Aurora	Colorado	54616874886193550	c574e640bd1c7162ce256a3b6f9236de	VISA 13 digit	39.7455718983076522	-104.776050309895354
39795	2020-07-25 07:41:33	2020-07-25	Dejah Christiansen-Torphy	dejah.christiansen.torphy@geemail.com	New York	New York	503874737839964	0322ee70bc1c050a4bdc404dd9d81a61	JCB 15 digit	40.6108334183916426	-73.8602607879683291
39796	2020-07-25 08:13:11	2020-07-25	Sibbie Gusikowski	sibbie.gusikowski@geemail.com	Philadelphia	Pennsylvania	52786723328258618	3a61176b1a5d37987270f33af54d1098	Voyager	39.9923812378622614	-75.1977991196226441
39797	2020-07-25 08:25:14	2020-07-25	Texas Rempel	texas.rempel@geemail.com	Phoenix	Arizona	3059135218298938	c06b25f8768119bf4d85148337cd0345	Mastercard	33.5410215086236647	-112.010406584611545
39798	2020-07-25 08:45:50	2020-07-25	Alyson Block	alyson.block@geemail.com	Pasadena	California	4117918688917536	8519e86e24b88440b43e3827ba5aac87	Mastercard	34.2422885820589968	-118.132255061883853
39799	2020-07-25 08:49:09	2020-07-25	Martha Reilly	martha.reilly@geemail.com	Evansville	Indiana	869964219693929480	a8a02bef07b4f39570d69b6ec385275f	VISA 16 digit	37.9864138047348661	-87.5254978785689985
39800	2020-07-25 08:55:31	2020-07-25	Luke Kihn	luke.kihn@warmmail.com	Tucson	Arizona	869938428139483431	fef11a39b4dc87856f3dfe912a27f98e	JCB 16 digit	32.1120173964224804	-110.910074519714712
39801	2020-07-25 08:56:12	2020-07-25	Iyana Auer-Keebler	iyana.auer.keebler@geemail.com	Houston	Texas	4531204037539	c60fadaaaeed5e8a45c903a0d9161236	Voyager	29.7315785592034452	-95.48037672359645
39802	2020-07-25 09:21:50	2020-07-25	Kenley Williamson-Lueilwitz	kenley.williamson.lueilwitz@warmmail.com	Chula Vista	California	4812806790468100	13fa57008b252fb4482be9a3582e1b17	VISA 16 digit	32.5659784847635763	-116.948695221519841
39803	2020-07-25 09:25:41	2020-07-25	Dereck Haley-Morar	dereck.haley.morar@woohoo.com	Oklahoma City	Oklahoma	4262586108892	135c29a45f16fd3fdb9243dd294ee49e	Voyager	35.4159079143688089	-97.4356935686327574
39804	2020-07-25 09:27:11	2020-07-25	Mamie Ernser-Kohler	mamie.ernser.kohler@geemail.com	Berkeley	California	676256483760700	5819079403a88ece515d4a4237b801d1	JCB 16 digit	37.9038743463211745	-122.266275182431556
39805	2020-07-25 09:40:04	2020-07-25	Kalvin Schimmel	kalvin.schimmel@warmmail.com	Philadelphia	Pennsylvania	52597139782048040	1b89e5865ca15aba79609ec9498d265b	Voyager	40.0954767842270456	-75.1376257493060109
39806	2020-07-25 09:40:40	2020-07-25	Mr. Huy Toy V	mr.huy.toy.v@geemail.com	Orlando	Florida	3492306633413075	88add2f5bf3667951de274557f0f5b2a	VISA 13 digit	28.3281744332782921	-81.2473608155701328
39807	2020-07-25 09:45:09	2020-07-25	Vicie Kerluke	vicie.kerluke@geemail.com	Jurupa Valley	California	3096288843608765372	7e9f00cc4fe779bfbc8e3a36603347c0	JCB 16 digit	33.9829930962923896	-117.414976661840825
39808	2020-07-25 09:54:02	2020-07-25	Stuart Mills IV	stuart.mills.iv@warmmail.com	Los Angeles	California	869953009594725241	9af153e1306692802af282c2f6e7d333	JCB 16 digit	33.9973272853862483	-118.386454912972823
39809	2020-07-25 09:57:13	2020-07-25	Ms. Rosina Wilderman DVM	ms.rosina.wilderman.dvm@geemail.com	San Francisco	California	53371985722627927	9d723eddc68815bbac47a94e9587892d	Maestro	37.7682317088502515	-122.412119706836961
39810	2020-07-25 09:58:33	2020-07-25	Cloyd Kirlin	cloyd.kirlin@woohoo.com	Santa Clara	California	3462333042279125	b2388a0dbbc0566de78907f19b34567c	VISA 16 digit	37.4535658020343689	-121.90121168200821
39811	2020-07-25 09:59:31	2020-07-25	Harrold Dickens MD	harrold.dickens.md@woohoo.com	San Francisco	California	6011360145183313086	bc25157b469143d1a5f810bad1b5591c	JCB 15 digit	37.8087838587306777	-122.435304112703562
39812	2020-07-25 10:11:06	2020-07-25	Stefan Stark	stefan.stark@woohoo.com	Jurupa Valley	California	3006290157904377	8e442a78515ca97c6d85b34bb561ee04	Discover	34.0751527875125433	-117.415941647209607
39813	2020-07-25 10:15:00	2020-07-25	Diya Cormier	diya.cormier@warmmail.com	Berkeley	California	3017773408351679	b75e7bed072772a8c2ead89d5110da8a	Maestro	37.8792337074200347	-122.27024206397536
39814	2020-07-25 10:18:36	2020-07-25	Budd Willms	budd.willms@geemail.com	Chicago	Illinois	869966991182521899	ad1358f91670b2df90bdabe29a7ed578	VISA 16 digit	41.7538892590742563	-87.6306495644181922
39815	2020-07-25 10:20:24	2020-07-25	Evelyn Beahan DVM	evelyn.beahan.dvm@geemail.com	Tyler	Texas	869983336413750264	da64c7e13f1859f027ea035a135f5fad	Mastercard	32.3423182752497524	-95.2886272731810777
39816	2020-07-25 10:34:29	2020-07-25	Quiana Crist	quiana.crist@geemail.com	Olathe	Kansas	3038230817828291	f5b4b7a254f74aa01ed6b9a7acf2e6be	JCB 16 digit	38.9417846756178889	-94.8639093318190447
39817	2020-07-25 10:42:36	2020-07-25	Shayna Roberts	shayna.roberts@geemail.com	San Francisco	California	3457910031298658	2d34d2e79bfe938208e43a30777c7276	VISA 13 digit	37.7575763334860639	-122.433784111276395
39818	2020-07-25 10:48:50	2020-07-25	Darl Rohan	darl.rohan@woohoo.com	Bellevue	Washington	4085249865041009	65e88353899b3caea3a2c938299bb57a	JCB 15 digit	47.615716713685174	-122.073268993949512
39819	2020-07-25 10:54:54	2020-07-25	Cherrie Johns	cherrie.johns@woohoo.com	Antioch	California	180075282289691358	2af039f274c82a4b21cdcee850830bb6	Mastercard	38.0321859885271678	-121.743161971279235
39820	2020-07-25 11:04:12	2020-07-25	Moe Schiller	moe.schiller@geemail.com	West Covina	California	3088499041571875899	902f9091f3a35803ac8d548d6252a375	VISA 13 digit	34.0276634981498134	-117.929846001423513
39821	2020-07-25 11:04:13	2020-07-25	Lim Wintheiser	lim.wintheiser@geemail.com	Renton	Washington	060402536077122	a36888717764343150b815c17560320f	American Express	47.4167787686981299	-122.099599238352837
39822	2020-07-25 11:07:05	2020-07-25	Flor Feest	flor.feest@geemail.com	Santa Maria	California	3048325796634726	582381d502b347bd1d3545092c18e69e	Discover	34.9574875497322495	-120.405754451724889
39823	2020-07-25 11:07:34	2020-07-25	Donovan Turner	donovan.turner@geemail.com	Columbus	Ohio	639075502282280	7f93ea9b18839fb69d9dfec3d7b90e48	Discover	39.9533149775162357	-83.0747653987027803
39824	2020-07-25 11:13:40	2020-07-25	Lanie Corwin DDS	lanie.corwin.dds@geemail.com	Oakland	California	180096917090485442	16d1a1e09cd5a1115af383708a435931	Maestro	37.8336461540091307	-122.281604893728215
39825	2020-07-25 11:26:29	2020-07-25	Brook Runte	brook.runte@geemail.com	Chicago	Illinois	4901066084178	085c8a58ebf106472e21be2e289f8fb7	VISA 13 digit	41.8749278903774922	-87.7451569473400639
39826	2020-07-25 11:35:35	2020-07-25	Dr. Melina Reilly DVM	dr.melina.reilly.dvm@warmmail.com	Berkeley	California	3046418535102980	2a976b2e8bdcbbccf6642bc90df99530	Discover	37.8681583940252864	-122.296250574325015
39827	2020-07-25 11:35:54	2020-07-25	Dr. Elois Stanton DDS	dr.elois.stanton.dds@geemail.com	Mobile	Alabama	639080095266443	18c0969e9206b32f1078a714f1f48c3c	American Express	30.6695347452178595	-88.1201823283590358
39828	2020-07-25 11:42:50	2020-07-25	Charlsie Abbott	charlsie.abbott@woohoo.com	Joliet	Illinois	503897879480040	85d11c418898d4b8a4078f709032c655	JCB 16 digit	41.546762327276916	-88.098403829486287
39829	2020-07-25 11:49:05	2020-07-25	Murry Tremblay PhD	murry.tremblay.phd@geemail.com	New York	New York	3498148834814477	a663ed7d968ccc7b9dda992f32525c2c	Diners Club / Carte Blanche	40.7261923892181343	-73.8422799904260785
39830	2020-07-25 11:54:47	2020-07-25	Dr. Josh Borer	dr.josh.borer@geemail.com	San Francisco	California	3528328843693107896	a60fd8ff4729886d197f0c65deed2b22	Mastercard	37.7939381925237967	-122.394033223208623
39831	2020-07-25 12:16:33	2020-07-25	Dariana Anderson	dariana.anderson@geemail.com	Dallas	Texas	639040830335937	3907913d4af3f0e44caf4ad161be84a7	Discover	32.8765827308680869	-96.7864120942968782
39832	2020-07-25 12:16:38	2020-07-25	Patricia Mraz DVM	patricia.mraz.dvm@warmmail.com	San Francisco	California	3410560848493947	df3ab67dd7dab82b0dfaa3571ca0cb80	American Express	37.8099109105720643	-122.428826490307998
39833	2020-07-25 12:28:36	2020-07-25	Delphine Pollich-Fisher	delphine.pollich.fisher@geemail.com	Carlsbad	California	210045176166431689	03da949fdbac3b85a5cf3f4e85e32c35	JCB 15 digit	33.0618924055188899	-117.341196266587076
39834	2020-07-25 12:31:47	2020-07-25	Dr. Oakley Sipes	dr.oakley.sipes@geemail.com	San Francisco	California	3030726142561299	b4cf3557e89e8312767564ca418c1a4b	JCB 15 digit	37.7653784885220674	-122.384813385072931
39835	2020-07-25 12:32:35	2020-07-25	Candido Kshlerin MD	candido.kshlerin.md@geemail.com	Frisco	Texas	869983529094018643	8c3087cac92ef11d6ffe0c028f1ecc63	JCB 16 digit	33.241530819935349	-96.851071348108718
39836	2020-07-25 12:33:34	2020-07-25	Luverne Rosenbaum-Buckridge	luverne.rosenbaum.buckridge@warmmail.com	New York	New York	210004792637927474	f9389becca143ca41d468b2f49a60e98	American Express	40.7605625934656715	-73.933119506844136
39837	2020-07-25 12:34:01	2020-07-25	Amelia Von	amelia.von@woohoo.com	San Jose	California	53879073100566020	41d857429f3ffee5b4c3b307128760a8	VISA 16 digit	37.2172186658538919	-121.784550046290832
39838	2020-07-25 12:42:16	2020-07-25	Ott Swift	ott.swift@warmmail.com	New York	New York	3112659400553436607	86dc437f3386f2336c9c5c3740e6ea35	VISA 13 digit	40.6473985442183903	-73.8630141800630753
39839	2020-07-25 12:44:06	2020-07-25	Jettie Feeney	jettie.feeney@geemail.com	San Francisco	California	3436469664678898	41469c3f91b02531a8b28151af65d9cb	JCB 15 digit	37.7770253673099532	-122.43825961666127
39840	2020-07-25 12:44:40	2020-07-25	Mrs. Kathey Pfannerstill DDS	mrs.kathey.pfannerstill.dds@geemail.com	Reno	Nevada	4702695302861321	b9323214d21d6d67c2640ecb59e2aad4	Discover	39.4495815064370632	-119.900233436625086
39841	2020-07-25 12:47:56	2020-07-25	Mrs. Susanne Windler PhD	mrs.susanne.windler.phd@geemail.com	Austin	Texas	180086031556543330	aba004796c9ca409cdb20d18e009fb15	Discover	30.2104422171726803	-97.6674249071866285
39842	2020-07-25 12:50:30	2020-07-25	Eben Lesch	eben.lesch@geemail.com	Laredo	Texas	4661466131164280	5369384841eada2ea2396c6d23691950	American Express	27.4964661443788572	-99.5157525893308161
39843	2020-07-25 13:01:30	2020-07-25	Chaney Konopelski-Witting	chaney.konopelski.witting@geemail.com	Little Rock	Arkansas	180050410422406843	bacb392acf7e05b62f1f22a0a41b5a3b	VISA 16 digit	34.763501155729962	-92.3047204938590511
39844	2020-07-25 13:04:39	2020-07-25	Tenisha Rau	tenisha.rau@geemail.com	Fort Collins	Colorado	4384508681357545	1aefdba851a48d4e771ca430168f2bef	Maestro	40.4849615390103352	-105.058214547527214
39845	2020-07-25 13:04:50	2020-07-25	Josh Pouros-Hintz	josh.pouros.hintz@geemail.com	Elk Grove	California	4203422620872	cd983d5f90cc3107412ff291df949424	VISA 13 digit	38.419988452252376	-121.410005322089418
39846	2020-07-25 13:14:50	2020-07-25	Polk Hansen	polk.hansen@woohoo.com	Long Beach	California	869909841737368165	bd1358b7839c23769b2bdbf8a8a50192	Voyager	33.7750110463060409	-118.176592156493285
39847	2020-07-25 13:15:09	2020-07-25	Miss Nettie Zulauf DDS	miss.nettie.zulauf.dds@geemail.com	San Diego	California	503814908157358	333aa8024614ff6a1a1b810f0f90179e	JCB 16 digit	32.8785802457548684	-117.216819628179081
39848	2020-07-25 13:17:00	2020-07-25	Tabetha Lueilwitz-Ryan	tabetha.lueilwitz.ryan@warmmail.com	Cincinnati	Ohio	3055818396858862	e2876594689043de1be0f89ea615d78f	VISA 13 digit	39.2190480975665139	-84.5062797090776172
39849	2020-07-25 13:20:25	2020-07-25	Casandra Mertz DVM	casandra.mertz.dvm@geemail.com	Colorado Springs	Colorado	180094169869887208	beb4c72a6ee62329e070a6339494ba7b	Diners Club / Carte Blanche	38.7769356006339194	-104.76959560100623
39850	2020-07-25 13:27:49	2020-07-25	Glennie Kunze	glennie.kunze@geemail.com	Chicago	Illinois	869933786217062749	e9627adf930eac4979660033c7cb37de	Diners Club / Carte Blanche	41.8951411351397667	-87.7743383346155213
39851	2020-07-25 13:30:15	2020-07-25	Alanna Upton	alanna.upton@woohoo.com	Washington	District of Columbia	4555794246390	d895b0e59165585bd4661629009a0538	JCB 16 digit	38.8111524375420061	-76.9814684691120021
39852	2020-07-25 13:33:00	2020-07-25	Carie Hilpert	carie.hilpert@geemail.com	Los Angeles	California	4622185363395523	91c1f967522c93e8855a99a23b392cce	VISA 16 digit	34.0601632548361977	-118.405550016601751
39853	2020-07-25 13:37:38	2020-07-25	Salome Friesen	salome.friesen@geemail.com	Phoenix	Arizona	52220695958539224	146f24e78df930b8ee237aebb6cfcfb4	VISA 13 digit	33.5495310552816832	-112.001874318292749
39854	2020-07-25 13:46:11	2020-07-25	Stafford Carroll	stafford.carroll@geemail.com	San Francisco	California	180075259712588609	566292897a3d4fe17d1accc64ea052a7	VISA 13 digit	37.7429981743351135	-122.455724684611695
39855	2020-07-25 13:47:07	2020-07-25	Elmer Schuster	elmer.schuster@geemail.com	Houston	Texas	6011436708519733671	9dd74227a89ab26fa3cfec180056c870	JCB 15 digit	29.8007748792957514	-95.4080375628095112
39856	2020-07-25 14:59:05	2020-07-25	Loula Smitham DDS	loula.smitham.dds@geemail.com	Chula Vista	California	210032354790977683	c3b65585c7ea98edfdfcc479cfd1e69e	Voyager	32.6452628529395881	-116.922090130322417
39857	2020-07-25 15:05:20	2020-07-25	Mr. Krish Kozey	mr.krish.kozey@geemail.com	Cincinnati	Ohio	3528411523336453869	72b9310ce218822f870cbf70803dfd7a	JCB 16 digit	39.1853093023642884	-84.4216858288079379
39858	2020-07-25 15:37:15	2020-07-25	Ransom Cruickshank	ransom.cruickshank@geemail.com	Philadelphia	Pennsylvania	3461885985186246	907695f43206f39a92f1ec7d13926624	Diners Club / Carte Blanche	40.0098041541367735	-75.1768290049761561
39859	2020-07-25 15:41:16	2020-07-25	Dr. Park Schaefer	dr.park.schaefer@geemail.com	Saint Paul	Minnesota	676346144900795	50bafd16621daf4a13e318b840aa0f7a	VISA 16 digit	44.9599692821443071	-93.1949948850817975
39860	2020-07-25 15:46:08	2020-07-25	Jenni Leuschke	jenni.leuschke@geemail.com	Woodbridge	New Jersey	4912395220369756	6966fb64ce18a7e35d9f9c14bae6cc25	JCB 16 digit	40.5581191260058418	-74.2028492207031718
39861	2020-07-25 15:47:39	2020-07-25	Mr. Enrique Sipes	mr.enrique.sipes@geemail.com	College Station	Texas	6011913210580247287	fbf8378f5a6e5b9749a6cc1d3cba8851	Mastercard	30.5217445125848066	-96.3928789818506715
39862	2020-07-25 15:49:29	2020-07-25	Sherwood Towne	sherwood.towne@geemail.com	Daly City	California	3780239353838045	31c640cb6797efec41a99fbe98e37668	Discover	37.6732595001734794	-122.531241885209454
39863	2020-07-25 16:00:45	2020-07-25	Letha Medhurst	letha.medhurst@geemail.com	Greensboro	North Carolina	3096266047188418800	b079a6a3ea3b1caee30d99224632da47	Maestro	36.0244089059647195	-79.8836077356226752
39864	2020-07-25 16:01:07	2020-07-25	Renaldo Hoppe	renaldo.hoppe@geemail.com	San Francisco	California	3008974472307840	5fecfa5c3da9b8b866aa96bb4195cc80	JCB 16 digit	37.791028369304918	-122.443608084266714
39865	2020-07-25 16:05:08	2020-07-25	Betha O'Reilly	betha.o'reilly@warmmail.com	Kenosha	Wisconsin	4713416674891	156dcd05d445b6a1a2432ef099349a56	VISA 13 digit	42.5800187802713381	-87.7613214390113967
39866	2020-07-25 16:09:39	2020-07-25	Patti Haley	patti.haley@geemail.com	San Diego	California	3049038155000020	b68ce2e3fdd0d63bcbaffd9cff69d84c	VISA 13 digit	32.8762496232587864	-117.10564233808779
39867	2020-07-25 16:13:39	2020-07-25	Arron Schamberger	arron.schamberger@geemail.com	New York	New York	4572390067014400	9bc0e42698135f39f8e463f4169f1e6e	Mastercard	40.7530182254258548	-74.0089279248274892
39868	2020-07-25 16:29:11	2020-07-25	Liana Wunsch	liana.wunsch@geemail.com	San Francisco	California	3005237439240014	15a713d67ef7844c83bb8eb4ac31d651	Discover	37.7511300720095377	-122.423357331558492
39869	2020-07-25 16:40:40	2020-07-25	Sanders Grimes	sanders.grimes@warmmail.com	Jacksonville	Florida	3006128957383584	f87d137e468951d3053a76ea6333f994	Diners Club / Carte Blanche	30.3962213678803295	-81.7506790479723406
39870	2020-07-25 16:50:52	2020-07-25	Miss Cecilia Gislason	miss.cecilia.gislason@geemail.com	Chicago	Illinois	3088859081650298179	c78d8bed4c45c07b714f497f7e6b4ab8	VISA 13 digit	41.9125848228413602	-87.6727113450907183
39871	2020-07-25 16:51:52	2020-07-25	Dr. Aarav Mayer MD	dr.aarav.mayer.md@geemail.com	San Jose	California	6011133384238791386	7762e944c4cd3fc8cc3332503833eaab	VISA 13 digit	37.2633196578182293	-121.746703619718176
39872	2020-07-25 16:54:48	2020-07-25	Randell Zulauf	randell.zulauf@warmmail.com	San Francisco	California	869927525710241303	a4d9311adc3de6eb7c228f4c54ac60f8	JCB 15 digit	37.7258020527042675	-122.426870575842599
39873	2020-07-25 16:55:45	2020-07-25	Lashawn Gislason	lashawn.gislason@geemail.com	Chicago	Illinois	180049547555743940	b2a181080beb061713be0f2f83955ce6	VISA 16 digit	41.7471784280914804	-87.6013074011106028
39874	2020-07-25 17:19:13	2020-07-25	Beda Leannon	beda.leannon@geemail.com	Fort Worth	Texas	3112150340381681293	7570448593a78dc23e96d77630afd3c1	Maestro	32.8228207376375778	-97.4015358720261588
39875	2020-07-25 17:39:16	2020-07-25	Dr. Shenna Crist MD	dr.shenna.crist.md@geemail.com	Tucson	Arizona	53581207223644871	61a8604569305973be55e861a498206c	Diners Club / Carte Blanche	32.1972608486697069	-110.835332509385793
39876	2020-07-25 17:40:53	2020-07-25	Adron Cartwright	adron.cartwright@warmmail.com	Tulsa	Oklahoma	3036546054021742	0a7dac34540ed1b33d7f491dcea7460f	JCB 16 digit	36.1845971411928531	-95.8828730195250358
39877	2020-07-25 17:49:26	2020-07-25	Cornelious Kling	cornelious.kling@geemail.com	Chicago	Illinois	6011753609489490828	c82abda5eb18648f73b5f346b15822ae	VISA 16 digit	41.8262430862359693	-87.6533514331590311
39878	2020-07-25 18:01:40	2020-07-25	Earlie Hackett	earlie.hackett@geemail.com	San Francisco	California	4982899952898	298059f5eb51d7b005590e4a2ee4dbb6	Voyager	37.7523758132591212	-122.394715993045722
39879	2020-07-25 18:04:13	2020-07-25	Alphonso Gislason	alphonso.gislason@woohoo.com	Berkeley	California	3337167392940884976	feb9805a2ce0f72babae51f221573c38	JCB 16 digit	37.8686767810928586	-122.280971410531166
39880	2020-07-25 18:24:09	2020-07-25	Mr. Shon Davis	mr.shon.davis@geemail.com	Oakland	California	3019986883762859	45a7b3e629d279d09839bc327b0ecf2f	American Express	37.7818239379663865	-122.259104968397168
39881	2020-07-25 18:38:24	2020-07-25	Mrs. Jailyn Mraz DVM	mrs.jailyn.mraz.dvm@geemail.com	Dallas	Texas	6011746316752923549	6a23c2388ea71b539f805685161d8942	Mastercard	32.8801410712573698	-96.8086728451736178
39882	2020-07-25 18:40:41	2020-07-25	Chet Beatty	chet.beatty@geemail.com	San Francisco	California	6011755389708289842	eb4217fdbacee7b9f8392ba980b82049	JCB 16 digit	37.7853836003265684	-122.406707133959088
39883	2020-07-25 18:47:40	2020-07-25	Rome White	rome.white@geemail.com	San Francisco	California	3088220948510428521	64e186a55a9a8b2a25d85543d058c244	Voyager	37.7812456365274159	-122.418019745446941
39884	2020-07-25 18:59:02	2020-07-25	Trenten Orn	trenten.orn@warmmail.com	Los Angeles	California	3337504498466551824	0ab4bfcac3e34b88157476c1d15e3876	Diners Club / Carte Blanche	34.1167236848134507	-118.332468155211956
39885	2020-07-25 18:59:15	2020-07-25	Loyal VonRueden-Jacobi	loyal.vonrueden.jacobi@geemail.com	Chicago	Illinois	4180981452371092	8b083cbf668a35c3e4f4a8e68c55ee74	Discover	41.8338830170523366	-87.7380638454604878
39886	2020-07-25 19:03:14	2020-07-25	Emmalee Goldner-Zboncak	emmalee.goldner.zboncak@geemail.com	Albuquerque	New Mexico	3030823118855811	266b7d41543db11cfbcd44a2769f796d	VISA 16 digit	35.0437936128251266	-106.595162117581452
39887	2020-07-25 19:15:36	2020-07-25	Bell West	bell.west@geemail.com	Bakersfield	California	3007232502206701	a5e6aaf5d914589900b5f4bce97e9d67	JCB 16 digit	35.334088108612967	-119.063429074016582
39888	2020-07-25 19:58:17	2020-07-25	Veda Gleason DVM	veda.gleason.dvm@woohoo.com	Los Angeles	California	3412946632429023	f0a8901e0ccec1833884f7ef29d3cc1e	JCB 15 digit	33.9361020597960774	-118.460561456483973
39889	2020-07-25 19:58:55	2020-07-25	Estell Waelchi DVM	estell.waelchi.dvm@geemail.com	Los Angeles	California	3054971159142098	dcfc740e80a71df1d4ba372f61afb9c7	JCB 16 digit	34.0664485544763451	-118.360181360597906
39890	2020-07-25 20:01:15	2020-07-25	Rashaad Walker	rashaad.walker@warmmail.com	San Francisco	California	6011770235599655198	69a4cc60bf4b9cf23b64487933c3cc8a	VISA 13 digit	37.7779797058257856	-122.433116508658856
39891	2020-07-25 20:14:42	2020-07-25	Stuart Hessel	stuart.hessel@geemail.com	Tacoma	Washington	3456073976451914	8b4be435c5a6c23d5014c787150de4fe	American Express	47.2329636081241091	-122.43269043096825
39892	2020-07-25 20:14:55	2020-07-25	Hulda Rempel-Blick	hulda.rempel.blick@geemail.com	Elk Grove	California	3487882292989750	b1f2a86f433c05b15ff5b14e3292e8ce	VISA 16 digit	38.4508281092442559	-121.404275202276196
39893	2020-07-25 20:18:31	2020-07-25	Ms. Bristol Batz	ms.bristol.batz@geemail.com	Kent	Washington	3715909946305898	a01064900c90ce016f59843b1d7b9590	Discover	47.4298123439419967	-122.298153968215729
39894	2020-07-25 20:25:03	2020-07-25	Mylee Jacobi	mylee.jacobi@geemail.com	Visalia	California	4220326589354003	96185e912b211f86ab79ca268647cb16	JCB 16 digit	36.2920245314903553	-119.379762767361115
39895	2020-07-25 20:45:16	2020-07-25	Ethel Lesch	ethel.lesch@geemail.com	San Jose	California	869965679519222635	71d914c99615b9cf4b385a9dcbcccf57	JCB 16 digit	37.2623832884997128	-121.844777270847558
39896	2020-07-25 21:06:38	2020-07-25	Katelin Kutch DVM	katelin.kutch.dvm@warmmail.com	Norman	Oklahoma	676195188262364	8585537c74bbfa2e2b71845cd705f201	VISA 16 digit	35.2463734810281579	-97.3437071427956226
39897	2020-07-25 21:08:06	2020-07-25	Hayleigh Heidenreich	hayleigh.heidenreich@geemail.com	New York	New York	3088318756870387333	114924996fab4c097c4b445b86a2c8d2	VISA 16 digit	40.695682879280298	-73.9683829001512407
39898	2020-07-25 21:18:22	2020-07-25	Mariah Rolfson	mariah.rolfson@geemail.com	San Francisco	California	4495765955695366	955ccd0807d64ccc2ac2c9b74c59ce24	Mastercard	37.7703746538885454	-122.420846703342249
39899	2020-07-25 21:19:45	2020-07-25	Dr. Anthony Ledner DDS	dr.anthony.ledner.dds@warmmail.com	Cincinnati	Ohio	4567521297869	1bd5401bc4ee98b853e1a722bb8ebf55	Mastercard	39.2131369262233349	-84.5345416728213337
39900	2020-07-25 21:42:05	2020-07-25	Merri Hyatt MD	merri.hyatt.md@woohoo.com	Cary	North Carolina	4702493972325995	f1d09a117b9b6a4aed3af9ca9c128267	JCB 15 digit	35.7516435428630572	-78.8353484113320633
39901	2020-07-25 21:46:13	2020-07-25	Miss Blair Friesen	miss.blair.friesen@geemail.com	Raleigh	North Carolina	869928277036211987	320722df7e822a9976aa043f18dde266	JCB 16 digit	35.8425982448872134	-78.7273160336941515
39902	2020-07-25 21:48:09	2020-07-25	Kolton Robel-Balistreri	kolton.robel.balistreri@geemail.com	Berkeley	California	4255931357190717	44efd43a87d060d3a179ede298610ac5	JCB 16 digit	37.8682068064643929	-122.286340039607239
39903	2020-07-25 21:55:35	2020-07-25	Stephanie Anderson	stephanie.anderson@geemail.com	Anaheim	California	4297091396590	047e589042411b81debd0946fbd93f5e	Mastercard	33.8558508610185243	-117.857743912117925
39904	2020-07-25 22:28:01	2020-07-25	Celia Strosin-Hickle	celia.strosin.hickle@woohoo.com	Memphis	Tennessee	869924312433401453	7fac677d15b8fbabc658e0e71f855f97	JCB 15 digit	35.0987894852712756	-90.0631095465064107
39905	2020-07-25 22:35:48	2020-07-25	Collin Farrell	collin.farrell@geemail.com	Columbus	Georgia	3752696316797515	6cb6a576291e42539337ac85cbd586ca	Maestro	32.5930421352896786	-84.9572194224853092
39906	2020-07-25 22:54:09	2020-07-25	Dr. Erland Zieme	dr.erland.zieme@geemail.com	Long Beach	California	4209709730085441	c078bf3404747b96866ebcceb5c1a1d3	Mastercard	33.8462077549479901	-118.168158626572406
39907	2020-07-25 22:57:46	2020-07-25	Estella Turcotte	estella.turcotte@woohoo.com	Wilmington	North Carolina	3018555279594340	47f7ef70bc90c12136f49f0ab4cd2187	Diners Club / Carte Blanche	34.2311457055442077	-77.9688945628229533
39908	2020-07-25 22:58:03	2020-07-25	Irma Gorczany	irma.gorczany@geemail.com	Kenosha	Wisconsin	4703899733697101	4a57304df516f224920278a7e83f28b8	JCB 15 digit	42.5388466053482119	-87.7896149826463414
39909	2020-07-25 23:01:19	2020-07-25	Starla Daugherty	starla.daugherty@geemail.com	Fairfield	California	3096930801281527982	38e4f25e2df6dc6b0894b057b8670c43	VISA 16 digit	38.2112131643231976	-122.023231202084943
39910	2020-07-25 23:12:38	2020-07-25	Dr. Osborne Halvorson V	dr.osborne.halvorson.v@geemail.com	Berkeley	California	3158999548915770896	d53c5d047bbe36d5364993a6327a66e3	American Express	37.8480263414229015	-122.266653607024466
39911	2020-07-25 23:19:32	2020-07-25	Vince Stanton	vince.stanton@geemail.com	Newark	New Jersey	3337044862785671273	70eb642680ae36fc11f111b105354485	Voyager	40.7668303356885957	-74.2237882027611136
39912	2020-07-25 23:29:21	2020-07-25	Elvis Wiegand-Larson	elvis.wiegand.larson@woohoo.com	Washington	District of Columbia	55473216116218660	d67903d22d3e1f232507d7c2c6e84b9d	Mastercard	38.9629272734079493	-77.0880415060304074
39913	2020-07-25 23:34:05	2020-07-25	Prince Bosco	prince.bosco@geemail.com	Louisville	Kentucky	6011557163926194328	5879d12dd195d01150c6380fb0fea01b	Maestro	38.0802761589545753	-85.7199755091756685
39914	2020-07-25 23:51:56	2020-07-25	Maci Goyette	maci.goyette@warmmail.com	West Valley City	Utah	4759696350033831	797bb0a827ae313c1247871d93e35163	JCB 16 digit	40.5958145589791215	-112.055411484812566
39915	2020-07-25 23:55:34	2020-07-25	Mrs. Unique Feest	mrs.unique.feest@geemail.com	Oakland	California	3031231693123432	ce1dcaf0a017281de1e6ecd60c5e382b	VISA 16 digit	37.7927121760550264	-122.266712393301063
39916	2020-07-26 00:03:04	2020-07-26	Olivine Grant	olivine.grant@geemail.com	Tucson	Arizona	3008011156210386	738cb5b34550353b46be000a8d65ceeb	Voyager	32.13849380831644	-110.965625021908807
39917	2020-07-26 00:05:45	2020-07-26	Janet Bosco	janet.bosco@woohoo.com	Mesa	Arizona	3112243530443061596	9e8225e79c5e2b9fe57e915f3a14626a	VISA 16 digit	33.4222858908731482	-111.737588568672166
39918	2020-07-26 00:08:01	2020-07-26	Mr. Victor Carter	mr.victor.carter@geemail.com	Phoenix	Arizona	869984921895990055	642b84369f62e2704e3a9c05f3d82ea6	VISA 13 digit	33.5043085494011663	-112.130475750232492
39919	2020-07-26 00:11:08	2020-07-26	Dr. Abraham Bayer Jr.	dr.abraham.bayer.jr.@geemail.com	Los Angeles	California	630460108040647	992cf36575514076cc567a60f13c249e	American Express	33.936260819794235	-118.458017365866525
39920	2020-07-26 00:15:29	2020-07-26	Mr. Wilfredo Nader PhD	mr.wilfredo.nader.phd@geemail.com	San Francisco	California	4217907568794	bc8b38be2bb2bc79aa3cb9d7c1137751	American Express	37.778370531332726	-122.451281536790873
39921	2020-07-26 00:16:00	2020-07-26	Lenwood Stracke II	lenwood.stracke.ii@woohoo.com	Fort Worth	Texas	4529800415933014	674cd8eff5b05b06901d9c755047619c	JCB 16 digit	32.7977830119021263	-97.3922613486468833
39922	2020-07-26 00:16:31	2020-07-26	Mrs. Ila Abbott PhD	mrs.ila.abbott.phd@woohoo.com	Jackson	Mississippi	4643460650424	ab14a15777d40f27e96acc69589963c2	Voyager	32.3037102285485744	-90.1666648377638325
39923	2020-07-26 00:24:16	2020-07-26	Jacqulyn West	jacqulyn.west@geemail.com	Albuquerque	New Mexico	4943777195780351	d37da872c5eb9e0cc4096ba3c56c6241	VISA 16 digit	35.0492109586618881	-106.616630509689088
39924	2020-07-26 00:24:58	2020-07-26	Nelie Parker DVM	nelie.parker.dvm@geemail.com	San Diego	California	869929568568535366	2088877ec14bbc0681e4a8f72f062d0f	JCB 16 digit	32.7261677968848517	-117.232817123308777
39925	2020-07-26 00:32:03	2020-07-26	Magan Mann	magan.mann@geemail.com	Toledo	Ohio	4340676240891800	0bb774abd9e8762dafd160f0b8b30e7d	JCB 15 digit	41.7140151659198111	-83.6562385088630123
39926	2020-07-26 00:38:10	2020-07-26	Skylar Swift	skylar.swift@warmmail.com	Chicago	Illinois	3793924407736403	f03ae95233d5c020367fd3b7e1e9405b	VISA 16 digit	41.7395200327340561	-87.5976188499044639
39927	2020-07-26 00:56:25	2020-07-26	Chancey Armstrong IV	chancey.armstrong.iv@geemail.com	Los Angeles	California	51597130578962908	91e7a378bc05d4488c5e8e862592745b	JCB 16 digit	34.0216123658098226	-118.495806392234925
39928	2020-07-26 01:01:12	2020-07-26	Dr. Merlyn Lemke III	dr.merlyn.lemke.iii@geemail.com	Los Angeles	California	4027896278903	63e149364b294e0611a9516f81d53bfc	JCB 16 digit	33.9280930054705578	-118.419735503335659
39929	2020-07-26 01:01:32	2020-07-26	Mekhi Predovic	mekhi.predovic@geemail.com	Chesapeake	Virginia	3096277828208076489	52aa2fbb0fbc09a32fc71feab373fb53	Diners Club / Carte Blanche	36.5994936964713062	-76.246230287415159
39930	2020-07-26 01:08:48	2020-07-26	Kaley Dietrich DVM	kaley.dietrich.dvm@woohoo.com	Bellevue	Washington	3494413037017029	c0a9578ac3d87669363eff02bf348e10	VISA 16 digit	47.5970601553279948	-122.207298469549045
39931	2020-07-26 01:26:22	2020-07-26	Miss Mickey Bergstrom	miss.mickey.bergstrom@geemail.com	Berkeley	California	4957252170616569	82b1d370b22159b7098db190c4918232	American Express	37.8757450107847617	-122.245879441061334
39932	2020-07-26 01:30:44	2020-07-26	Adron Leffler-Cole	adron.leffler.cole@woohoo.com	Denver	Colorado	3158134863566968178	08ac7b0f373c6d81d70111828c9e5ad4	Mastercard	39.7536226127348797	-104.913743189467496
39933	2020-07-26 01:37:53	2020-07-26	Virgle Mayert	virgle.mayert@geemail.com	Overland Park	Kansas	869955184095945768	eece0d03df43193f7f246a6a3c93d0cf	VISA 13 digit	38.8977865461129753	-94.7408299914602168
39934	2020-07-26 01:43:06	2020-07-26	Dr. Darin Cassin III	dr.darin.cassin.iii@woohoo.com	Berkeley	California	210023386636045235	ab38abdaaf626cccfba92568cf94f4a2	Diners Club / Carte Blanche	37.8919874313379736	-122.271248103688436
39935	2020-07-26 01:43:43	2020-07-26	Bobbi Bartell	bobbi.bartell@geemail.com	Newark	New Jersey	3158682475762229655	eebce285f9319e24233a427a150ad711	Voyager	40.7853637108493601	-74.0808973284646868
39936	2020-07-26 01:58:38	2020-07-26	Dr. Kiara Mohr PhD	dr.kiara.mohr.phd@geemail.com	Louisville	Kentucky	4646320473028191	0f1f8311b18aeb7aebda2bb38d9bcbd4	VISA 13 digit	38.2250572057344016	-85.6960708995886193
39937	2020-07-26 02:02:03	2020-07-26	Charissa Howell	charissa.howell@geemail.com	Sandy Springs	Georgia	54550078398075390	af0a3073aff9aa9d11e84e4e273d885c	JCB 16 digit	33.9704005215838549	-84.3479615860235015
39938	2020-07-26 02:11:58	2020-07-26	Evelyn Schumm	evelyn.schumm@geemail.com	Overland Park	Kansas	54418442607926839	70c77c0af52e9fc66bae8628a1071bed	Maestro	38.824286660399288	-94.7754588980734383
39939	2020-07-26 02:13:50	2020-07-26	Joselyn Lockman-Lemke	joselyn.lockman.lemke@geemail.com	Albuquerque	New Mexico	4466488172563	4addcbfb7a7516cf04a19688a25ea32b	Maestro	35.0094731739390639	-106.656230546401446
39940	2020-07-26 02:15:08	2020-07-26	Maxie Bernier	maxie.bernier@geemail.com	San Francisco	California	6011836254776880604	fb8c9fc35767f82a198b51742be4e8da	JCB 16 digit	37.7783552989615856	-122.47538736517572
39941	2020-07-26 02:18:27	2020-07-26	Gaston Zieme	gaston.zieme@geemail.com	Chicago	Illinois	3035246858781556	ada42426d3aa795050b58854b1095b59	JCB 16 digit	41.7810269239660386	-87.7785814230360018
39942	2020-07-26 02:24:24	2020-07-26	Mr. Nathaniel Quitzon	mr.nathaniel.quitzon@warmmail.com	Killeen	Texas	501897822572364	fac1409431f9a083494daa027ffd5e5e	JCB 16 digit	31.1067941554587328	-97.7617532276716048
39943	2020-07-26 02:30:56	2020-07-26	Lahoma Hauck-Hyatt	lahoma.hauck.hyatt@geemail.com	Chicago	Illinois	4244794098427317	55afb6687ac328cd3c333f3954fb29bd	American Express	41.9259109998423654	-87.6635025195341484
39944	2020-07-26 02:35:42	2020-07-26	Justice Keeling	justice.keeling@geemail.com	San Diego	California	869965114550201660	5d66c2a7d38cc2bc87f054c83f94154d	Discover	32.7995848572880035	-117.127595111485576
39945	2020-07-26 02:38:55	2020-07-26	Tara Jacobson	tara.jacobson@geemail.com	Gresham	Oregon	51259429606101854	4f61f689dab8d3b6de2c24ddfe46e6d8	American Express	45.5632911740291817	-122.486970376016941
39946	2020-07-26 02:42:33	2020-07-26	Tayla Von	tayla.von@geemail.com	Scottsdale	Arizona	3704379165379458	791b967c1b7e3e379a5496943843e647	Maestro	33.6637888047967095	-111.847769431393957
39947	2020-07-26 02:44:14	2020-07-26	Miss Mickey Boehm	miss.mickey.boehm@geemail.com	Jacksonville	Florida	639040871507345	e3cbf5d69317f51741bf33cea4b1694f	Diners Club / Carte Blanche	30.3963096103217438	-81.6940405674822756
39948	2020-07-26 02:46:46	2020-07-26	Elise Legros	elise.legros@geemail.com	San Francisco	California	3019080375212217	22379366c018ae8ebd7a962826977ee9	Mastercard	37.7598476831136551	-122.404676151292122
39949	2020-07-26 02:47:08	2020-07-26	Alston Ebert	alston.ebert@woohoo.com	Detroit	Michigan	52062492748769936	8b22b41d32921cb19f78bbcdd75addc2	Mastercard	42.3913304699044673	-83.0197902993418211
39950	2020-07-26 02:49:37	2020-07-26	Mrs. Jaida Littel DVM	mrs.jaida.littel.dvm@geemail.com	San Diego	California	3405557492026798	0e8c623900ad3d6e9b72079ea4295d10	Diners Club / Carte Blanche	32.8378223988294593	-117.101941642807802
39951	2020-07-26 02:55:52	2020-07-26	Jarrod Stoltenberg DDS	jarrod.stoltenberg.dds@woohoo.com	San Diego	California	3528240441314371234	a530654d420d07c94fc419680cb4487b	Discover	32.8741259865529827	-117.137658575121321
39952	2020-07-26 02:57:10	2020-07-26	Otelia Greenholt	otelia.greenholt@geemail.com	Tucson	Arizona	4177263724647798	5fcea594a7074396af226ff770fda16a	VISA 16 digit	32.1436429353937498	-110.970258441683271
39953	2020-07-26 03:06:48	2020-07-26	Roxanne Cormier	roxanne.cormier@geemail.com	Oakland	California	675965568353570	a0fdf0096058e633536a9c4b03062eb4	JCB 16 digit	37.812715749884461	-122.295756303938774
39954	2020-07-26 03:10:20	2020-07-26	Aloysius Wisoky	aloysius.wisoky@geemail.com	San Francisco	California	869935334833994066	dd58e8e91487d055d7a8373a40e17234	JCB 15 digit	37.7711619886859893	-122.401799787196779
39955	2020-07-26 03:16:57	2020-07-26	Dr. Eileen Huels	dr.eileen.huels@geemail.com	Houston	Texas	6011042768303269163	f290cff0e9857954f69aab4777332f2c	JCB 16 digit	29.7154894376717493	-95.3424026776585691
39956	2020-07-26 03:18:25	2020-07-26	Carlie Price	carlie.price@geemail.com	Houston	Texas	3158856316236457854	06207397f679a922a14a7903b3ac5d6c	JCB 15 digit	29.7083601305339471	-95.3825701120790086
39957	2020-07-26 03:20:18	2020-07-26	Brenden Williamson-Berge	brenden.williamson.berge@warmmail.com	Augusta	Georgia	3045951878284669	4749c7602464ed1b880ac5be64906570	JCB 16 digit	33.2749275848474326	-82.1235402788795597
39958	2020-07-26 03:23:18	2020-07-26	Kyra Littel-Considine	kyra.littel.considine@geemail.com	Columbus	Ohio	4329636698812265	45030cbf71ad22c3ace22b5f949d5b6e	Discover	40.0751101868271817	-82.8978973505787593
39959	2020-07-26 03:23:40	2020-07-26	Dr. Junius Gutkowski Sr.	dr.junius.gutkowski.sr.@geemail.com	Los Angeles	California	503828503061310	5542e65009c5a39ba4c3b9e162682724	JCB 16 digit	33.9248131433833393	-118.346588768064223
39960	2020-07-26 03:26:42	2020-07-26	Mr. Farrell Ziemann I	mr.farrell.ziemann.i@warmmail.com	Los Angeles	California	3018138537752362	2399beed2a8081bb361e508047443ba3	Voyager	33.9722201953042244	-118.345192312820998
39961	2020-07-26 03:27:54	2020-07-26	Judge Halvorson	judge.halvorson@geemail.com	Charlotte	North Carolina	869964496506385106	1b761f6c5ce5b41dab83ed527a3b46c4	JCB 15 digit	35.1768728545188907	-80.8230713231898932
39962	2020-07-26 03:28:26	2020-07-26	Lonie Pouros	lonie.pouros@geemail.com	Scottsdale	Arizona	3796381364123058	c6b8e923e212638acf3d5d38a4a989a1	JCB 16 digit	33.7154508542392435	-111.813190510679405
39963	2020-07-26 03:31:03	2020-07-26	Miss Oda Hermann	miss.oda.hermann@warmmail.com	Santa Ana	California	210078627652685105	084f2f5239b3b6da9b54524734282e76	Diners Club / Carte Blanche	33.6408171988662303	-117.981415275383739
39964	2020-07-26 03:34:51	2020-07-26	Richelle Simonis-Renner	richelle.simonis.renner@geemail.com	Pomona	California	210064694352164456	2c108d93a44bc76e5fd0863c92c05848	VISA 16 digit	34.0002599119246014	-117.667757900148999
39965	2020-07-26 03:38:14	2020-07-26	Mrs. Josiephine Schimmel DVM	mrs.josiephine.schimmel.dvm@warmmail.com	New York	New York	6011817887168081563	145099e79f0e5aa3e9eee391c48a8e00	JCB 16 digit	40.7373406307063988	-73.9003166628431529
39966	2020-07-26 03:39:14	2020-07-26	Mrs. Dakota Johns	mrs.dakota.johns@geemail.com	New York	New York	060452614672435	e8cb6161697a5e4ef45c7625b9297a50	Diners Club / Carte Blanche	40.6974176064822828	-73.9145290735073388
39967	2020-07-26 03:45:49	2020-07-26	Cheryl Torp	cheryl.torp@geemail.com	Fresno	California	3158519797081794005	3abbd8ef3f34b563255d260a27c7fbb5	American Express	36.7231463544409706	-119.890086859661722
39968	2020-07-26 03:45:59	2020-07-26	Torrance Farrell	torrance.farrell@geemail.com	Denton	Texas	4508476403925828	9f2d297bf0c6e7d38edba47b73e70933	Discover	33.2463073922120032	-97.0495392438151043
39969	2020-07-26 03:46:13	2020-07-26	Felipe Boyer PhD	felipe.boyer.phd@geemail.com	Albuquerque	New Mexico	3096380524354573585	fc2a886bf5658b116cbdbed922eb11c5	VISA 16 digit	35.0974278714176293	-106.579498124315961
39970	2020-07-26 03:50:20	2020-07-26	Miss Martine Predovic DVM	miss.martine.predovic.dvm@geemail.com	Chicago	Illinois	3337689405780077847	b4152d75713475c13b0439dc228ed385	VISA 13 digit	41.8015390087220808	-87.697111771631242
39971	2020-07-26 03:52:54	2020-07-26	Yuliana Nienow	yuliana.nienow@geemail.com	New York	New York	3088627601391755780	0f3b4bc69805ac700703249c42630a39	VISA 16 digit	40.6135773904379462	-74.0176579626172781
39972	2020-07-26 03:57:59	2020-07-26	Arlo White	arlo.white@warmmail.com	Beaumont	Texas	4173475420240363	a6a427c6bc79326c6df058839c14884e	JCB 16 digit	30.125792910165714	-94.1140698587775262
39973	2020-07-26 04:02:07	2020-07-26	Ruthie Monahan	ruthie.monahan@geemail.com	Cedar Rapids	Iowa	4052779536480029	eef1a767a56a447b500e322c56c79a89	JCB 16 digit	41.8946360403280664	-91.715270103893431
39974	2020-07-26 04:17:35	2020-07-26	Celesta McKenzie-Bartoletti	celesta.mckenzie.bartoletti@geemail.com	Philadelphia	Pennsylvania	3457441919095123	d79fc16252195120c4106ea0f7759724	JCB 16 digit	39.923098549335819	-75.1983703189894612
39975	2020-07-26 04:20:21	2020-07-26	Mistie Effertz	mistie.effertz@woohoo.com	Philadelphia	Pennsylvania	210094190242596084	506a19e67a6825bdefd45125dd7eca8c	American Express	40.0829857354011381	-75.1182778568372242
39976	2020-07-26 04:28:30	2020-07-26	Cuba Bergnaum	cuba.bergnaum@geemail.com	San Antonio	Texas	210076658808829844	452992dba8c9cc15d1ea861875b24e74	JCB 15 digit	29.38948957324736	-98.5644409610725916
39977	2020-07-26 04:37:07	2020-07-26	Simona Kris	simona.kris@geemail.com	New York	New York	4484668592898	dda6922630237165d46de8792c729ea5	American Express	40.6845924111772348	-73.9941265169426714
39978	2020-07-26 04:41:10	2020-07-26	Marlon Effertz	marlon.effertz@geemail.com	Phoenix	Arizona	3028748636615755	204abc3f98a7225f052a730c16e81fee	Discover	33.5471844118021423	-112.040741397805888
39979	2020-07-26 04:44:06	2020-07-26	Nadia McClure	nadia.mcclure@geemail.com	Berkeley	California	4737828623006	10d01aafcbbe72ac9a8b9811a04de64b	Diners Club / Carte Blanche	37.8788535715837043	-122.282484863003745
39980	2020-07-26 04:49:14	2020-07-26	Alpha Bogan	alpha.bogan@geemail.com	Atlanta	Georgia	4624590805475163	99abf36fdfb145880ddeef789a2e044e	Maestro	33.8155816707104435	-84.4657459280032725
39981	2020-07-26 05:01:04	2020-07-26	Jess Schamberger	jess.schamberger@woohoo.com	San Angelo	Texas	3033988023198412	dc1ad755f3e38d88854350c206ccf95b	Maestro	31.3992728142220514	-100.409700845006853
39982	2020-07-26 05:08:34	2020-07-26	Dr. Kenton Schaefer I	dr.kenton.schaefer.i@geemail.com	Memphis	Tennessee	676167398667336	b4b12d3580f96fcebcbc571c7c738880	VISA 13 digit	35.1406508263267625	-90.0035823617853197
39983	2020-07-26 05:13:01	2020-07-26	Ty Schaden	ty.schaden@geemail.com	San Francisco	California	4289169703669866	d96ccb44542f2f1716df2712d8d7a249	VISA 13 digit	37.8022366189579344	-122.454173402446429
39984	2020-07-26 05:28:05	2020-07-26	Mrs. Modena Schmeler	mrs.modena.schmeler@warmmail.com	Philadelphia	Pennsylvania	55451247870008712	468b01524d8dd6bb384362ab5cb3ce84	Voyager	39.9309873192064444	-75.1478151379052548
39985	2020-07-26 05:36:47	2020-07-26	Westley Auer	westley.auer@geemail.com	Jacksonville	Florida	3096562415313328247	5adba4b479bcea6b81e81d603f0d54f0	Mastercard	30.3576967663183801	-81.7130736892655563
39986	2020-07-26 05:37:37	2020-07-26	Tobie Boehm	tobie.boehm@geemail.com	Charlotte	North Carolina	4746093804300303	f7f02d6f6fb589a5c083ec073bfa177e	JCB 16 digit	35.3021599527236063	-80.9111524599082799
39987	2020-07-26 05:38:23	2020-07-26	Normand Jacobson	normand.jacobson@woohoo.com	Chicago	Illinois	4414082038383756	4460a54fa3e39b297a4708ca0aa8e8bd	VISA 16 digit	41.8250294710811232	-87.6098153908301072
39988	2020-07-26 05:43:03	2020-07-26	Hurbert Wolf DVM	hurbert.wolf.dvm@woohoo.com	Houston	Texas	869961191729405442	e079dd20adc92c17040e6f16da27b6c4	Voyager	29.7092692504715181	-95.4265878039427093
39989	2020-07-26 06:01:11	2020-07-26	Mariyah Will-Kihn	mariyah.will.kihn@warmmail.com	Oakland	California	3024543459870445	42e6d23a7cb1e2500afc3a82663376a4	Discover	37.8316801583127571	-122.2815590009928
39990	2020-07-26 06:01:26	2020-07-26	Joel Wyman	joel.wyman@geemail.com	Little Rock	Arkansas	503856477347308	a4659ac08f70c989383df1b2547c0b9f	Discover	34.7884074149463345	-92.2804958102632327
39991	2020-07-26 06:03:59	2020-07-26	Sheldon Glover	sheldon.glover@geemail.com	Greensboro	North Carolina	210035401744666875	334d75d0cf0a3b0e4fd3a70a3cbe9b94	JCB 16 digit	36.1665341611135744	-79.8988610884156003
39992	2020-07-26 06:09:05	2020-07-26	Nola Rempel	nola.rempel@geemail.com	Murfreesboro	Tennessee	3024746211164979	9fde7c47c4b9253c466fa47535cdff43	VISA 13 digit	35.9217378730073591	-86.4610709206517782
39993	2020-07-26 06:26:29	2020-07-26	Manley Schmidt	manley.schmidt@woohoo.com	Tulsa	Oklahoma	4250837769935	f24a89e10dbab201b1697204d43d88e1	Diners Club / Carte Blanche	36.1290099673807603	-95.8279999096833137
39994	2020-07-26 06:29:58	2020-07-26	Miss Josefa Littel	miss.josefa.littel@geemail.com	New York	New York	4688525680469546	af2dd440d661c2927bd780b008accb9a	Voyager	40.6369928113408392	-73.9186534549936596
39995	2020-07-26 06:31:48	2020-07-26	Cristopher Armstrong	cristopher.armstrong@geemail.com	Mesa	Arizona	3483886545580187	795a287c6a51dc1984b297b618c2340c	VISA 13 digit	33.332095860192176	-111.787777693418406
39996	2020-07-26 06:35:38	2020-07-26	Clifton Bradtke	clifton.bradtke@warmmail.com	San Francisco	California	4639701617210861	5b5387508203cea85671942eea3f1bef	JCB 16 digit	37.7667410972705895	-122.4097977337305
39997	2020-07-26 06:39:35	2020-07-26	Thompson Rice	thompson.rice@geemail.com	San Antonio	Texas	4303668124670728	976b9d36677e3f6315f53921db971fe6	JCB 16 digit	29.5573644329398881	-98.4880668557085102
39998	2020-07-26 06:42:30	2020-07-26	Novella Fadel-Upton	novella.fadel.upton@geemail.com	Tallahassee	Florida	55376751829613177	19a2835d5de0fcad4408878b9645b5b8	American Express	30.4599505970276923	-84.1691220688648514
39999	2020-07-26 06:43:49	2020-07-26	Moriah McKenzie-Lindgren	moriah.mckenzie.lindgren@geemail.com	Dallas	Texas	54883378894853094	6bfecfd30e723a5880c027c9fd82bc3b	JCB 15 digit	32.8678449048001369	-96.8397293392531537
40000	2020-07-26 06:44:07	2020-07-26	Faron Ullrich	faron.ullrich@geemail.com	Austin	Texas	4285269917586	3fd683aaf6b12252c781517c46be136f	VISA 16 digit	30.2434281722769143	-97.6752141482435263
40001	2020-07-26 06:51:41	2020-07-26	Tessie Harber	tessie.harber@warmmail.com	Denver	Colorado	54307776473533730	b9ddc0b7aeb11e5ed8d5903206873ed9	Mastercard	39.7142696308024199	-104.877425599588463
40002	2020-07-26 06:52:05	2020-07-26	Junie Fisher	junie.fisher@geemail.com	Birmingham	Alabama	4904889848910	44ce3714814e0fded58fe413bfafced4	Maestro	33.5257964629005656	-86.7064974718038002
40003	2020-07-26 06:54:22	2020-07-26	Chadrick Sporer	chadrick.sporer@geemail.com	New York	New York	4452987153312682	ba796e1879b8945e21325e5eb86f4c57	JCB 16 digit	40.5786909509208016	-73.9612674404762629
40004	2020-07-26 06:55:43	2020-07-26	Orlin VonRueden PhD	orlin.vonrueden.phd@geemail.com	New York	New York	502029638785518	7b0688ddad9632fe6a5142b4530567f0	VISA 16 digit	40.6438419276140621	-73.9451405625685965
40005	2020-07-26 07:00:45	2020-07-26	Carroll Walsh	carroll.walsh@geemail.com	Seattle	Washington	180005434552887230	b3ea939974f9e669ddd359b56871ec93	VISA 13 digit	47.6774011081475777	-122.385622243295984
40006	2020-07-26 07:16:03	2020-07-26	Sam Schimmel	sam.schimmel@warmmail.com	Tampa	Florida	6011041865209492377	b19b6aa24743158ab18c6b9c3ba02e69	Maestro	27.9003845988422619	-82.5355111680205908
40131	2020-07-26 17:51:08	2020-07-26	Mignon Flatley	mignon.flatley@geemail.com	Memphis	Tennessee	4228375884053978	4ae04625b2003b82cd9ec328d8522206	JCB 16 digit	35.0434095298007122	-90.0213932913053867
40007	2020-07-26 07:18:08	2020-07-26	Mr. Cassius Muller MD	mr.cassius.muller.md@warmmail.com	Las Vegas	Nevada	3096453822558736418	4f2451083a7bdac4688ad1cb1dae247c	Diners Club / Carte Blanche	36.3174566238753513	-115.224085927402967
40008	2020-07-26 07:49:13	2020-07-26	Zachary Leffler	zachary.leffler@geemail.com	Glendale	Arizona	3337057652566851333	16cd3334be23d0d0ba365d00f5f4e441	Voyager	33.5653337795048898	-112.171394562095031
40009	2020-07-26 07:53:31	2020-07-26	Rian Zemlak	rian.zemlak@geemail.com	Temecula	California	3112940232514692930	7bddb67d06c096155acc69dfc2412a42	Voyager	33.3978850743401807	-117.057980107721676
40010	2020-07-26 07:57:01	2020-07-26	Mrs. Luberta Boyer	mrs.luberta.boyer@geemail.com	Baltimore	Maryland	210037939715146656	c2f30e1004a787d1fe9b4db61ebfa56d	Maestro	39.2176615170668796	-76.6647400029953587
40011	2020-07-26 07:58:06	2020-07-26	Holland Streich	holland.streich@warmmail.com	Los Angeles	California	503845164027786	f56ac73e330712044cd7de6e10b5e492	Mastercard	34.1031188454344871	-118.311543992486961
40012	2020-07-26 08:03:48	2020-07-26	Vern Sporer	vern.sporer@warmmail.com	San Antonio	Texas	52554792815633526	d5c22238ae3b25e51cd6a084e142a32f	JCB 16 digit	29.5686568108923744	-98.4990693650510138
40013	2020-07-26 08:19:08	2020-07-26	Joretta Keeling	joretta.keeling@geemail.com	San Jose	California	6011322675123541922	c305e01faa71bc308cbbbc17668dbe47	Diners Club / Carte Blanche	37.2494899296022979	-121.807614249944308
40014	2020-07-26 08:30:41	2020-07-26	Esteban Nicolas DVM	esteban.nicolas.dvm@geemail.com	St. Petersburg	Florida	180095647818243283	2ca817a74daf8cc6852fadbefcb8f96d	Mastercard	27.805620325438678	-82.5742454233936911
40015	2020-07-26 08:40:11	2020-07-26	Ms. Rikki Donnelly	ms.rikki.donnelly@warmmail.com	San Francisco	California	3112780943358794599	fda2eb41e60c70748e42acbb04d46d79	Mastercard	37.7306526512795131	-122.438721319959555
40016	2020-07-26 08:47:01	2020-07-26	Oda Abbott	oda.abbott@geemail.com	Charlotte	North Carolina	180087977705338205	2c6eed836ed24c4480a80a8a7907ebf5	Voyager	35.2758180757306476	-80.7366907510384948
40017	2020-07-26 08:52:59	2020-07-26	Margene Witting-Kuphal	margene.witting.kuphal@geemail.com	Port St. Lucie	Florida	4356418963985	9e122cffb93ef14b4aa11db7e652043d	Diners Club / Carte Blanche	27.1959571800328774	-80.3903324472338028
40018	2020-07-26 08:54:02	2020-07-26	Ms. Mora Miller DVM	ms.mora.miller.dvm@geemail.com	Austin	Texas	4895223241488770	e7052c0863de965b1a5ab9156047ad35	Maestro	30.3764747347809347	-97.6811587974201956
40019	2020-07-26 08:56:03	2020-07-26	Katy Monahan	katy.monahan@warmmail.com	Fremont	California	4009557158713974	5b8e73cb4015cb9e9d3c8dcb68a9171d	VISA 16 digit	37.5221253732387012	-121.942750097996367
40020	2020-07-26 08:58:28	2020-07-26	Daron Smith	daron.smith@woohoo.com	Kent	Washington	3088007598263903821	b93ea0e5d1508b3c92f7bf19d6b09a92	VISA 16 digit	47.3322778422031547	-122.298982307794319
40021	2020-07-26 09:04:10	2020-07-26	Leonce Davis	leonce.davis@geemail.com	San Francisco	California	53485442062791874	57e6d4a3cb937238bb1c628c09bc3cd0	American Express	37.7710705274118581	-122.448854381294296
40022	2020-07-26 09:23:58	2020-07-26	Miss Jenniffer Reichel DDS	miss.jenniffer.reichel.dds@geemail.com	Jackson	Mississippi	54557189107884809	648e9375520168dfbf53370c44811925	JCB 16 digit	32.4076126374483167	-90.238688761552055
40023	2020-07-26 09:26:20	2020-07-26	Jerrie Klocko	jerrie.klocko@geemail.com	San Bernardino	California	6011974199279229530	fb69c5cf67c5b1f0b8e0fd756df0f9db	Maestro	34.1309277671188056	-117.222766916850958
40024	2020-07-26 09:33:37	2020-07-26	Ellamae Keebler	ellamae.keebler@geemail.com	Durham	North Carolina	4363190037555505	27ad88aaf5de1dd852bcf277d693c2dd	Maestro	36.078970866116137	-78.9441559878081165
40025	2020-07-26 09:35:10	2020-07-26	Shakira Hegmann	shakira.hegmann@geemail.com	Irvine	California	4263355710629	824149a0fe3892076d4b6ccefc32643b	VISA 16 digit	33.5787714000340571	-117.843467558455842
40026	2020-07-26 09:47:07	2020-07-26	Karri DuBuque	karri.dubuque@geemail.com	San Francisco	California	4957492891400931	694f03795b6346b0a487e5d5140ce9d1	Discover	37.7640248957026969	-122.45094204147199
40027	2020-07-26 09:47:55	2020-07-26	Miss Verdell Volkman	miss.verdell.volkman@geemail.com	Lakewood	Colorado	869927591595371268	f017fd241a941533edf02bafd18ccc6d	American Express	39.7082519526068154	-105.173935906358437
40028	2020-07-26 09:48:42	2020-07-26	Kaycee Bosco PhD	kaycee.bosco.phd@woohoo.com	San Francisco	California	3033913300846590	7dc0d5e9a8fed447547f0bbdcb57c91a	VISA 13 digit	37.7463006982420879	-122.451836076294654
40029	2020-07-26 09:55:20	2020-07-26	Stefan Upton	stefan.upton@geemail.com	Allentown	Pennsylvania	676152849273306	a5ad1c47e016c2073ea2c39e0257a164	American Express	40.5332294256672299	-75.5375827556490833
40030	2020-07-26 10:08:58	2020-07-26	Acey Swift	acey.swift@geemail.com	New York	New York	676170593110805	17009bb345cff6adaedc85b95f8a4ede	Mastercard	40.574265015194193	-73.9951724920783107
40031	2020-07-26 10:09:27	2020-07-26	Lenora Witting	lenora.witting@warmmail.com	Mesa	Arizona	675935162090365	4dee74e0a02b89d116c4e6d285473e8f	Diners Club / Carte Blanche	33.321056460277731	-111.648362061369795
40032	2020-07-26 10:12:56	2020-07-26	Norah Moen	norah.moen@geemail.com	Jacksonville	Florida	180073213169608537	7673835ed7266f632648c4253e70426d	JCB 16 digit	30.3982637934438884	-81.5964397676367383
40033	2020-07-26 10:16:04	2020-07-26	Hortense Mraz	hortense.mraz@geemail.com	San Francisco	California	3485269293876214	f69bc13d5f4ad1e9c1bbee88a0f538f7	VISA 16 digit	37.7762322242268951	-122.463637020375074
40034	2020-07-26 10:23:05	2020-07-26	Angeles Braun-Jast	angeles.braun.jast@woohoo.com	Birmingham	Alabama	3158759957809470705	150ef338fc39e017678e6448e838bef0	VISA 16 digit	33.5621775724716471	-86.6993223898355012
40035	2020-07-26 10:24:41	2020-07-26	Deric Stanton	deric.stanton@geemail.com	Dallas	Texas	3022875060529628	41bb4b7fd9ec0a713cf58a303049482d	VISA 13 digit	32.8387989783931573	-96.75612527695111
40036	2020-07-26 10:25:01	2020-07-26	Catherine Hintz	catherine.hintz@geemail.com	San Francisco	California	4753690728486652	7d2ef87fb930edbbb20fe82fde38460f	Diners Club / Carte Blanche	37.7731733371553418	-122.404514122918656
40037	2020-07-26 10:30:05	2020-07-26	Vicie Bailey	vicie.bailey@woohoo.com	Stockton	California	869913378229938993	d91e47483529bce74ff67c649e0acfb8	Maestro	37.9785981131449333	-121.223747110421954
40038	2020-07-26 10:40:02	2020-07-26	Zelia Klein-Baumbach	zelia.klein.baumbach@geemail.com	Omaha	Nebraska	4778642086160	a1cf7813fd933829b13623f175cb8c08	Maestro	41.2219214780401444	-95.9533848052028588
40039	2020-07-26 10:42:50	2020-07-26	Mr. Al Mraz I	mr.al.mraz.i@geemail.com	Fairfield	California	6011610125529660026	12877a2dfc4c14471fa054bc2946cb74	VISA 16 digit	38.2395964141592444	-121.946742286673185
40040	2020-07-26 10:52:55	2020-07-26	Jalon Barton	jalon.barton@geemail.com	San Francisco	California	4477098455093417	4f8c4e3d0f208509237e31f1327342db	Mastercard	37.7516727585363441	-122.434534112410347
40041	2020-07-26 10:54:35	2020-07-26	Ms. Viola Ritchie PhD	ms.viola.ritchie.phd@geemail.com	Salinas	California	4684664707401341	9032d8b1eef4bf929b4860e708e0a380	JCB 16 digit	36.6017690847393098	-121.661138041893764
40042	2020-07-26 10:56:16	2020-07-26	Ms. Amalie Schmidt PhD	ms.amalie.schmidt.phd@geemail.com	New York	New York	060442740418431	088bee955d1c9a924950225abf93b308	Voyager	40.730372282326222	-73.8614998125832471
40043	2020-07-26 11:01:35	2020-07-26	Otho Witting	otho.witting@geemail.com	Paterson	New Jersey	4020008729268705	9271d247ca6db32c1024552fa2b69ef7	JCB 16 digit	40.9908123645886775	-74.0904544110383938
40044	2020-07-26 11:01:59	2020-07-26	Winfield Goodwin	winfield.goodwin@woohoo.com	Oklahoma City	Oklahoma	52956383068093495	f7e0fe51730ad9cebacb2a71c13b7d02	Maestro	35.4031653024632504	-97.4751190555643348
40045	2020-07-26 11:07:32	2020-07-26	Dominic Green	dominic.green@geemail.com	Durham	North Carolina	54165535378995472	4cd21b98f19c94a72292760bbc401444	JCB 15 digit	35.9751568326972375	-79.0007604615200307
40046	2020-07-26 11:24:25	2020-07-26	Madaline Moore MD	madaline.moore.md@geemail.com	Los Angeles	California	501854387677724	bf8dbcea83012df8d09737c8aaf6a674	Discover	34.0472681512922009	-118.351884078093988
40047	2020-07-26 11:24:25	2020-07-26	Bridgette Rolfson	bridgette.rolfson@geemail.com	Los Angeles	California	4262294024451512	f02a9acae453cfb74a78304f19a0293b	VISA 16 digit	34.0506137410975995	-118.370542409503088
40048	2020-07-26 11:38:22	2020-07-26	Damarcus Quigley II	damarcus.quigley.ii@woohoo.com	San Bernardino	California	4308882096392758	3172bebb7a0ac2ae7b0893fe30438613	VISA 16 digit	34.1918444861922382	-117.211095850007979
40049	2020-07-26 11:41:24	2020-07-26	Shania Klocko	shania.klocko@woohoo.com	San Francisco	California	53945913138716321	02fb83f1b37889c9f4470f70044c6825	Diners Club / Carte Blanche	37.7564092936263691	-122.450775476106386
40050	2020-07-26 11:43:19	2020-07-26	Trenten Cummerata	trenten.cummerata@woohoo.com	Woodbridge	New Jersey	3158612897281217678	88c7011329d08eed58b8f2948fbba88e	American Express	40.5541592173434751	-74.2672394879486433
40051	2020-07-26 11:46:51	2020-07-26	Issac Blanda	issac.blanda@geemail.com	Springfield	Illinois	3158749426494276374	d7d78768085b31c526f92097fc97525b	Mastercard	39.6967646377779531	-89.6394504239320753
40052	2020-07-26 11:52:48	2020-07-26	Reginald Reichert	reginald.reichert@geemail.com	Nashville	Tennessee	3742905281860262	4aa19733cd2d5214e4bcfae54da65358	JCB 16 digit	36.1914422669570897	-86.7255035422183482
40053	2020-07-26 11:54:32	2020-07-26	Delpha Runte	delpha.runte@geemail.com	Hillsboro	Oregon	869916993509838916	605be37a13f61f07d0b1322fdff8a355	JCB 16 digit	45.4462356361299769	-122.862229888855296
40054	2020-07-26 11:55:57	2020-07-26	Lonzo Quitzon	lonzo.quitzon@woohoo.com	San Francisco	California	4769057393522	746607a77ecb4cc835ad85df41badfa7	Discover	37.7743568597185373	-122.385141008619115
40055	2020-07-26 12:01:13	2020-07-26	Pamela Bechtelar	pamela.bechtelar@woohoo.com	St. Louis	Missouri	3032169200454370	80d5073e31640100cc2d5a10a3eaf584	JCB 16 digit	38.5718193258315338	-90.3010644806087015
40056	2020-07-26 12:03:13	2020-07-26	Desiree Hamill	desiree.hamill@geemail.com	Austin	Texas	6011470536579635701	d11c97f34cff3b56961bac30f2aaf553	Maestro	30.3767830531705165	-97.8065922217216439
40057	2020-07-26 12:08:35	2020-07-26	Mrs. Leisha Dooley	mrs.leisha.dooley@geemail.com	San Francisco	California	503881769628579	8097b691286a98a8f19961c59c1dadb2	Voyager	37.799587586116111	-122.420962657627342
40058	2020-07-26 12:16:01	2020-07-26	Mr. Arman Gleichner	mr.arman.gleichner@woohoo.com	Wilmington	North Carolina	3796854212417070	9961a406aedbcb2994a15cac67de4d36	VISA 13 digit	34.2757285829454688	-77.9705898525651548
40059	2020-07-26 12:18:17	2020-07-26	Lonnie Walker	lonnie.walker@geemail.com	Cleveland	Ohio	4268246433106297	bd644588f3a68893388c26e62aa9283a	JCB 15 digit	41.4168813687134474	-81.7698868522658984
40060	2020-07-26 12:21:21	2020-07-26	Assunta Gerlach	assunta.gerlach@woohoo.com	Greensboro	North Carolina	4837471003003714	eaa2138d204f4ed2d16b7e7e845dc76c	Voyager	36.0115948075544097	-79.8307327033467544
40061	2020-07-26 12:25:26	2020-07-26	Aurelio Dickens	aurelio.dickens@geemail.com	Fort Worth	Texas	3406522251065782	df5274c007318841817908757a78b599	Diners Club / Carte Blanche	32.7133634672556113	-97.3381385819807576
40062	2020-07-26 12:36:10	2020-07-26	Darby Okuneva	darby.okuneva@woohoo.com	Austin	Texas	52970264826327718	675d438e03a6812ec4aeb840f5def9c4	JCB 16 digit	30.3710156023163336	-97.7491622857522202
40063	2020-07-26 12:42:10	2020-07-26	Ms. Dulcie Mayer	ms.dulcie.mayer@geemail.com	Cleveland	Ohio	3440149000229101	831e8d0bbb451db240497d663d832e15	Diners Club / Carte Blanche	41.410676099345082	-81.6280886311322433
40064	2020-07-26 12:47:26	2020-07-26	Toccara Bruen	toccara.bruen@geemail.com	Seattle	Washington	4622390199295133	c5b8173a8adeda56666b92aa346fb99d	Maestro	47.5747682193219674	-122.282825362953915
40065	2020-07-26 12:48:04	2020-07-26	Dr. Lourdes McKenzie DVM	dr.lourdes.mckenzie.dvm@woohoo.com	Arlington	Texas	4264882761073396	13b00f3a35fe6346f04eab323e7632a7	Maestro	32.6080577951174178	-97.2141078640732985
40066	2020-07-26 12:58:03	2020-07-26	Dr. Tristen Russel	dr.tristen.russel@geemail.com	Riverside	California	51314858738797697	a3d80e243ee2781a26323c34e16293cc	JCB 16 digit	33.877130801923947	-117.492646616321792
40067	2020-07-26 13:03:20	2020-07-26	Lolita Marquardt	lolita.marquardt@geemail.com	Rochester	New York	3112359371123374532	e6509f5c4e87940d367eeb888119b9fc	Voyager	43.1465348293982416	-77.7052637628983689
40068	2020-07-26 13:04:52	2020-07-26	Alejandro Pfannerstill	alejandro.pfannerstill@geemail.com	Overland Park	Kansas	3088596508664584671	a1722429b75cc6d87e3e356718c4c33a	JCB 16 digit	38.9411708806511072	-94.6775524300564086
40069	2020-07-26 13:06:59	2020-07-26	Julious Walker	julious.walker@woohoo.com	Houston	Texas	3528083228563339487	9f493a249110d75202ad3dfd9e6f3533	VISA 16 digit	29.881706784580274	-95.4869980576463036
40070	2020-07-26 13:07:23	2020-07-26	Jasen Kautzer-Armstrong	jasen.kautzer.armstrong@geemail.com	Houston	Texas	3337687859660531160	66abf18b188fc43973527b6dc86887ad	JCB 15 digit	29.8785575209729366	-95.3798845492318321
40071	2020-07-26 13:12:19	2020-07-26	Mr. Thurman Carroll IV	mr.thurman.carroll.iv@geemail.com	Yonkers	New York	4227443122711574	ae398df3606bfe280494f4111c8d7f16	Maestro	40.955073443168402	-73.8479219152942363
40072	2020-07-26 13:22:07	2020-07-26	Johnnie Littel	johnnie.littel@geemail.com	Berkeley	California	3413812774221819	eb6c1f359af74bd6ae814b958a937a8d	Voyager	37.8533918565333352	-122.277821305033754
40073	2020-07-26 13:24:04	2020-07-26	Noah Schmitt	noah.schmitt@warmmail.com	Augusta	Georgia	3792994920294488	4e51d50af12fbfda38c3f4c905d9f850	Maestro	33.4613382925484331	-82.1563814842902218
40074	2020-07-26 13:30:12	2020-07-26	Aretha Hilll	aretha.hilll@geemail.com	Seattle	Washington	6011413789251434378	41a8158494ea796569fcb5e389247a15	Diners Club / Carte Blanche	47.6922515435535459	-122.446509638234602
40075	2020-07-26 13:30:36	2020-07-26	Alonzo O'Conner	alonzo.o'conner@woohoo.com	Portland	Oregon	51130528827423792	ec902fc75dbc7117de7fed100308f40d	Voyager	45.4910828995872265	-122.563056671619421
40076	2020-07-26 13:34:39	2020-07-26	Portia Gorczany PhD	portia.gorczany.phd@geemail.com	Las Vegas	Nevada	3528617747672525012	f21e2bc38800ba4391d02ef55c87b583	Voyager	36.1375672276232365	-115.216568970468259
40077	2020-07-26 13:41:59	2020-07-26	Mrs. Nikki Becker	mrs.nikki.becker@warmmail.com	Manchester	New Hampshire	6011366647781608738	dae92f82e9378cec9f966bf71d6bcdaf	VISA 16 digit	42.8993348667934598	-71.3623992106303575
40078	2020-07-26 13:44:22	2020-07-26	Evalena Greenholt	evalena.greenholt@geemail.com	Odessa	Texas	3028667044981171	52bdd526df2d05a4f6df9524d619a62e	JCB 16 digit	31.9096024272974574	-102.274370507538691
40079	2020-07-26 13:55:40	2020-07-26	Bailey Connelly	bailey.connelly@geemail.com	Knoxville	Tennessee	51865769697216087	a0e46220da485c00fc1da45f168f4bc2	Mastercard	36.019439615641538	-84.0424146934628453
40080	2020-07-26 13:56:41	2020-07-26	Alia Pfannerstill PhD	alia.pfannerstill.phd@woohoo.com	New York	New York	3005338603937771	24c87f5e4f1026cb63b6b8280e3fa7fb	JCB 15 digit	40.7205515529718269	-73.9646184998925804
40081	2020-07-26 14:03:53	2020-07-26	David Torp-Swift	david.torp.swift@geemail.com	Omaha	Nebraska	869965663266170700	2fcc8afce5427615f60fb3b383b5e4b7	American Express	41.3114429360400877	-95.9678953624445938
40082	2020-07-26 14:03:56	2020-07-26	Lim Purdy-Dooley	lim.purdy.dooley@geemail.com	Pomona	California	4970703435968487	5842b3eeef86f31d1f159857e6a67263	VISA 13 digit	34.0201327414289167	-117.843851423725852
40083	2020-07-26 14:04:15	2020-07-26	Hallie Halvorson-Langworth	hallie.halvorson.langworth@woohoo.com	League City	Texas	4575731909717022	d1ff7064df54c2a64f7d5c16d21c94e4	JCB 15 digit	29.5871506821759063	-95.1287465612854817
40084	2020-07-26 14:06:31	2020-07-26	Kadyn Dietrich IV	kadyn.dietrich.iv@geemail.com	San Bernardino	California	3528084798804528774	7df53d9f93a9eaeef54cb53c4fde4b58	American Express	34.0809196768127336	-117.214677748620886
40085	2020-07-26 14:10:33	2020-07-26	Alvin Goodwin Sr.	alvin.goodwin.sr.@geemail.com	San Francisco	California	6011232805750572234	1785fba8e8d2c6141691fa967cfb347a	Maestro	37.730736356179996	-122.405405843337562
40086	2020-07-26 14:23:56	2020-07-26	Pinkney Hane	pinkney.hane@woohoo.com	Portland	Oregon	3088793631800989256	385d79b4c6aa4a3f31077f4bcf90f14f	JCB 15 digit	45.5726276296544839	-122.666854347195482
40087	2020-07-26 14:24:23	2020-07-26	Jorge Hintz	jorge.hintz@geemail.com	Los Angeles	California	6011208712266094200	2bc99b76c08c2bbe6eda959aabf46081	Mastercard	34.0550590652838352	-118.453188678854332
40088	2020-07-26 14:24:50	2020-07-26	Yuliana Stracke	yuliana.stracke@geemail.com	Indianapolis	Indiana	3011017234296872	cd23125d8c7769e7c7c357803682b8a7	VISA 16 digit	39.7395947622608361	-86.0613981355648434
40089	2020-07-26 14:26:16	2020-07-26	Cortney Sanford Jr.	cortney.sanford.jr.@warmmail.com	San Francisco	California	3055793927282611	183bd2463432d0ea7cc91627530b2378	VISA 13 digit	37.7727648248038221	-122.417770194773524
40090	2020-07-26 14:26:49	2020-07-26	Harley Rohan	harley.rohan@warmmail.com	Carrollton	Texas	3337722793041359479	86adb8276b6381e5e8cb7b5e79c9926d	VISA 16 digit	32.9330032072417396	-96.9784658304277798
40091	2020-07-26 14:29:42	2020-07-26	Madelyn Koss	madelyn.koss@geemail.com	Baltimore	Maryland	6011848510200345738	fbfd9786db6312497dbdbe820968eb78	VISA 16 digit	39.2021297945640939	-76.7065354431997974
40092	2020-07-26 14:30:02	2020-07-26	Bobbi Boehm	bobbi.boehm@warmmail.com	San Francisco	California	869940875085151410	978b290175f77c4ad4712aeef2dbbabb	Mastercard	37.7631438667308927	-122.439633437928123
40093	2020-07-26 14:41:28	2020-07-26	Mr. Lew Leffler	mr.lew.leffler@woohoo.com	San Antonio	Texas	4602682080257	ef489c89481ba6d174088f6ec91cb72b	Maestro	29.5379860557686555	-98.5652924296282151
40094	2020-07-26 14:50:23	2020-07-26	Werner Kovacek	werner.kovacek@geemail.com	Tallahassee	Florida	54162936477912835	8a470e412f99916e43a360255bc3b8a2	Maestro	30.4735022682718935	-84.1817968668896697
40095	2020-07-26 14:53:56	2020-07-26	Mrs. Sonji Koepp	mrs.sonji.koepp@geemail.com	Portland	Oregon	6011554174464503609	897131ac05066d06125fe786bbf30879	Mastercard	45.5541108030248409	-122.589345772890383
40096	2020-07-26 14:56:47	2020-07-26	Annice O'Conner	annice.o'conner@warmmail.com	Oakland	California	3009166398541334	f4ca4dd116be0c2d8e95503ac77f79a2	JCB 16 digit	37.8062712684589641	-122.274291986044858
40097	2020-07-26 15:00:08	2020-07-26	Kamya Hoeger	kamya.hoeger@geemail.com	Phoenix	Arizona	3096201516309686972	1a1fcea18b847633650c9e2e3a75816e	VISA 16 digit	33.5150938747383691	-112.071534433441613
40098	2020-07-26 15:01:43	2020-07-26	Dr. Rosaria Blick	dr.rosaria.blick@geemail.com	Santa Clara	California	180083427736455333	e03e1820a9235a71ee99fa8026f36127	Voyager	37.3233858098093449	-122.05223491494506
40099	2020-07-26 15:02:11	2020-07-26	Georgeanna Veum	georgeanna.veum@geemail.com	Cape Coral	Florida	3337661050603049730	1a3bccb0baf1f568bd076bf5faab4be0	Voyager	26.657052145941929	-81.9252105573262952
40100	2020-07-26 15:03:16	2020-07-26	Ms. Ilma Sipes	ms.ilma.sipes@woohoo.com	Portland	Oregon	869922222756692541	d19fc22f53673098feaf95255b3e0c2f	Diners Club / Carte Blanche	45.6261158615238926	-122.668392433179548
40101	2020-07-26 15:10:46	2020-07-26	Emmie Gislason	emmie.gislason@warmmail.com	Philadelphia	Pennsylvania	4707506169390	dd86ed0480715a0124fee525dadc9587	Mastercard	40.0255724246107008	-75.0361120291419326
40102	2020-07-26 15:13:43	2020-07-26	Dr. Nolen Schoen V	dr.nolen.schoen.v@woohoo.com	Berkeley	California	3042758549085091	6b1e3ecd09cfa2c9dcdc308ba633319e	American Express	37.9224974639467973	-122.273340476053292
40103	2020-07-26 15:15:00	2020-07-26	Joi Koelpin	joi.koelpin@geemail.com	Mesa	Arizona	6011776496122565072	e337aa72574caec5b5b7486b49c18f59	JCB 16 digit	33.3877563439454832	-111.630782488070054
40104	2020-07-26 15:18:45	2020-07-26	Fleming Medhurst	fleming.medhurst@geemail.com	Amarillo	Texas	52016368129687656	2716907ccf686b3843670899019d74cf	Discover	35.2075648073270884	-101.871844554166131
40105	2020-07-26 15:19:11	2020-07-26	Karina O'Connell PhD	karina.o'connell.phd@geemail.com	Louisville	Kentucky	4002707060576	a6e9cefbecc0417d2b94b3fdcf96875a	JCB 15 digit	38.1906882891334547	-85.5906580443564877
40106	2020-07-26 15:20:06	2020-07-26	Dr. Kadeem Boehm	dr.kadeem.boehm@woohoo.com	Moreno Valley	California	3001017031517710	9c022ef977effe47d60179377c3be2bd	Maestro	33.8705218162845796	-117.12394061363004
40107	2020-07-26 15:26:43	2020-07-26	Hallie Kuhn	hallie.kuhn@geemail.com	Gilbert	Arizona	4890462921242	e3aa3e052c2aa64b3e68dd7186af7a20	VISA 13 digit	33.329767927375805	-111.694470373554523
40108	2020-07-26 15:32:26	2020-07-26	Ardyce Bechtelar	ardyce.bechtelar@warmmail.com	Olathe	Kansas	4581346468852	e1d17265b7e6f4f6f70ee3941073960b	Voyager	38.7946533203247981	-94.8666087826881608
40109	2020-07-26 15:35:43	2020-07-26	Chelsie Witting	chelsie.witting@geemail.com	San Francisco	California	4125841069655469	7e19a747293992aa96cb1c20ef581e85	Discover	37.7766164576538372	-122.434074049912823
40110	2020-07-26 15:46:10	2020-07-26	Hansford Emard	hansford.emard@geemail.com	Miami	Florida	4573117783878365	5282fe2b737a42ef7e1ba9d434283254	Mastercard	25.7681885640740411	-80.1098837892863997
40111	2020-07-26 16:04:14	2020-07-26	Jeanette Wehner DVM	jeanette.wehner.dvm@geemail.com	New York	New York	6011228918368650098	5d7c2967461a694ab7d09ee0b33c41f7	VISA 13 digit	40.6602737665865561	-73.8664091046329503
40112	2020-07-26 16:06:46	2020-07-26	Mikhail Rath	mikhail.rath@geemail.com	Austin	Texas	503852136844496	6df8c080fbed174f7f9c7b5787b82ac5	Diners Club / Carte Blanche	30.2498193612914505	-97.7609780862234601
40113	2020-07-26 16:07:59	2020-07-26	Harry Wunsch-Moen	harry.wunsch.moen@geemail.com	Louisville	Kentucky	561212150140700	92310e5883e9d7372d12535419500d4e	VISA 16 digit	38.1267738266285505	-85.5809548739880341
40114	2020-07-26 16:14:54	2020-07-26	Joselyn Hudson	joselyn.hudson@warmmail.com	Seattle	Washington	3528972657116869620	bd4f53198d6955e16ecf9a935b44069c	Mastercard	47.5939018782619385	-122.31333573357351
40115	2020-07-26 16:19:49	2020-07-26	Alvera Cummings	alvera.cummings@warmmail.com	Eugene	Oregon	4299240662369	c07f1c181ebb5c62c067a808b9b66a6b	Diners Club / Carte Blanche	43.9832905244275949	-123.198354166558758
40116	2020-07-26 16:21:43	2020-07-26	West Powlowski	west.powlowski@geemail.com	Scottsdale	Arizona	3422022219469499	1dd85787dd28d6f3c19b9b36c728b6ef	JCB 16 digit	33.7581390825688814	-111.90067830336875
40117	2020-07-26 16:25:26	2020-07-26	Warren Littel	warren.littel@woohoo.com	Tempe	Arizona	4877898169839757	699aaf021f2df0bbb0dd85b198fb541c	VISA 16 digit	33.3329816115476163	-111.894564973938458
40118	2020-07-26 16:26:03	2020-07-26	Tressa Kling	tressa.kling@geemail.com	Detroit	Michigan	4414846622288955	7817ae9b89824247acdb84594796bd81	Maestro	42.3125935342088368	-83.1632480768605973
40119	2020-07-26 16:26:10	2020-07-26	Antwon Schmeler-Grimes	antwon.schmeler.grimes@geemail.com	Aurora	Illinois	4350908777393	698dcf4f9b9e33167a0e7a0fab5806e7	Mastercard	41.7824771607983863	-88.259296958281098
40120	2020-07-26 16:28:41	2020-07-26	Gidget Shanahan	gidget.shanahan@geemail.com	Fort Lauderdale	Florida	3088226835464074159	b7e4c3ea592e440caca14c6261ac051b	Diners Club / Carte Blanche	26.1596130595531342	-80.2450293048106147
40121	2020-07-26 16:41:11	2020-07-26	Deana Legros	deana.legros@geemail.com	Greensboro	North Carolina	3096046947002058723	69f1a80de36af9bbbf0fec81cd6ce9d9	VISA 16 digit	36.1816847311448342	-79.8029939889423474
40122	2020-07-26 16:48:58	2020-07-26	Pamela Reynolds	pamela.reynolds@warmmail.com	Grand Rapids	Michigan	060428078261006	dd2531dc93aa50e7024ed41cea764ea3	JCB 16 digit	43.0466007436893889	-85.7276397496130329
40123	2020-07-26 16:50:45	2020-07-26	Brittanie Russel	brittanie.russel@geemail.com	Amarillo	Texas	4374528189990375	f81970869cab4cad67ace5d41b8ce741	JCB 16 digit	35.1165712090838724	-101.887446213825427
40124	2020-07-26 16:54:51	2020-07-26	Miracle Corwin	miracle.corwin@warmmail.com	Phoenix	Arizona	869973353387684660	bde576fe954e10fdbcf9657ebc5954b3	American Express	33.5737996326226735	-112.027955443358422
40125	2020-07-26 16:59:49	2020-07-26	River Gulgowski	river.gulgowski@geemail.com	Philadelphia	Pennsylvania	3528400527652353812	bf163e08e77d19f1e4d7c1be7e7e00ea	Maestro	40.0783697238151007	-75.1276261597771224
40126	2020-07-26 17:05:42	2020-07-26	Mrs. Litzy Paucek	mrs.litzy.paucek@geemail.com	New York	New York	180050931181349908	1f535e151d65f9fdc527b074cc04b3e5	JCB 15 digit	40.7420167509689932	-74.0168752827111547
40127	2020-07-26 17:08:05	2020-07-26	Norene Roob	norene.roob@geemail.com	Olathe	Kansas	3337146524598794778	817b1437068e88a61e8e7aa2bc144294	American Express	38.9578895113553898	-94.8098750848025134
40128	2020-07-26 17:12:07	2020-07-26	Allean Gulgowski	allean.gulgowski@geemail.com	Louisville	Kentucky	4520026875983476	f2c0716fd111890a01830acd7086b753	VISA 13 digit	38.1156500437200023	-85.641510252847894
40129	2020-07-26 17:22:40	2020-07-26	Sade McGlynn	sade.mcglynn@woohoo.com	North Las Vegas	Nevada	4843804641507765	09c12dd402acbcebbc66d76186c9ee41	JCB 16 digit	36.3195195743970558	-115.1144434919335
40130	2020-07-26 17:45:20	2020-07-26	Dr. Dallas Quitzon IV	dr.dallas.quitzon.iv@geemail.com	Centennial	Colorado	4415711894576	16dcb789d30caf23f4e5ba635bf6207c	JCB 15 digit	39.5604518900200759	-104.931980641175443
40132	2020-07-26 17:58:11	2020-07-26	Crystal Koch	crystal.koch@geemail.com	Chicago	Illinois	676339278563273	7c996deba39c97d00364a7f624b3f576	VISA 16 digit	41.73897366503477	-87.740190428591518
40133	2020-07-26 18:00:03	2020-07-26	Mr. Garrett Roob II	mr.garrett.roob.ii@geemail.com	Chicago	Illinois	3337691556388604089	7f8730c940d4d3686f5f0b316e99c9c5	Discover	41.8199651506565502	-87.7017562202673417
40134	2020-07-26 18:03:48	2020-07-26	Ms. Tera Zemlak	ms.tera.zemlak@geemail.com	Boulder	Colorado	4239561399311889	0259c26b9634f6e59c2ed73f91ff03d9	VISA 16 digit	40.0863825546093295	-105.16692718441189
40135	2020-07-26 18:05:30	2020-07-26	Shelba Cassin	shelba.cassin@geemail.com	Orange	California	4959621810433387	93c435787f141faef8fd519ae72d71ae	Maestro	33.8322935852110405	-117.870445852550858
40136	2020-07-26 18:05:37	2020-07-26	Mr. Hardin Stokes Jr.	mr.hardin.stokes.jr.@woohoo.com	Rancho Cucamonga	California	54966242232576447	eb93689fc04b0f7ac3b21245506b9dad	Diners Club / Carte Blanche	34.0332644664209312	-117.596031804197281
40137	2020-07-26 18:11:04	2020-07-26	Webb Conroy	webb.conroy@geemail.com	Jacksonville	Florida	869974740109156804	58a650fea1c25ce74c6d4cb79517ff1e	VISA 16 digit	30.3829761948022998	-81.7584573975376827
40138	2020-07-26 18:15:24	2020-07-26	Aidyn Yundt	aidyn.yundt@geemail.com	Oklahoma City	Oklahoma	6011140875706851827	ef3a1b2c54d9f507099d4affdc95e508	JCB 15 digit	35.4052716760341113	-97.4723413574404987
40139	2020-07-26 18:23:57	2020-07-26	Winthrop Stracke DDS	winthrop.stracke.dds@warmmail.com	Berkeley	California	3048778543213923	0c7623a22572154225b5885391fb665f	American Express	37.8496531312348594	-122.289603314990501
40140	2020-07-26 18:24:47	2020-07-26	Dr. Remy Abbott Sr.	dr.remy.abbott.sr.@geemail.com	Dallas	Texas	180021656066032099	15ec1053e441d4f07e7499def9c05710	American Express	32.8306186329845389	-96.8419959706216957
40141	2020-07-26 18:25:23	2020-07-26	Maida Schultz	maida.schultz@geemail.com	Corona	California	3088457386622861426	348da80b8b8fc001d59f3551e07fbe92	VISA 16 digit	33.9357052903510663	-117.474761954668907
40142	2020-07-26 18:26:30	2020-07-26	Mrs. Lucy Herman DVM	mrs.lucy.herman.dvm@geemail.com	Syracuse	New York	869978364173324051	70066a0f8a26ebeee19df40d544c2b4e	VISA 16 digit	42.9802462262418103	-76.1930314081035647
40143	2020-07-26 18:28:48	2020-07-26	Cleone Oberbrunner	cleone.oberbrunner@woohoo.com	San Bernardino	California	6011178670950232484	cd9eefed2b6450af259c042c97fc7f3a	JCB 16 digit	34.0811552373025535	-117.264689125005532
40144	2020-07-26 18:28:52	2020-07-26	Dr. Arvel Hettinger	dr.arvel.hettinger@geemail.com	San Francisco	California	4054545194090733	a4067ffa0aa6110fd145934dd5c11bbf	Discover	37.7633728269816658	-122.423602296378363
40145	2020-07-26 18:34:13	2020-07-26	Ozell Kutch	ozell.kutch@geemail.com	Rialto	California	6011195412349277550	bf3476f463b125f563797290eec1773f	JCB 15 digit	34.1499313181016646	-117.334629506626356
40146	2020-07-26 18:35:11	2020-07-26	Giovani Johns	giovani.johns@geemail.com	Washington	District of Columbia	3112917009294632453	bc222081a223e91f31199923e58af768	VISA 13 digit	38.8368707428950799	-76.9824453552000278
40147	2020-07-26 18:40:57	2020-07-26	Charlee Fahey	charlee.fahey@woohoo.com	Frisco	Texas	54020195636392486	2fa463523443bb2ca96c7fb1bd09f37e	VISA 16 digit	33.1553085960444065	-96.8964303394988065
40148	2020-07-26 18:43:08	2020-07-26	Woodson Hettinger Jr.	woodson.hettinger.jr.@geemail.com	Las Vegas	Nevada	3430628714341957	4556a9427e870a08fb8141af4a921601	JCB 16 digit	36.1939523442748907	-115.33765968677811
40149	2020-07-26 18:48:46	2020-07-26	Dr. Paul Murray	dr.paul.murray@geemail.com	Chicago	Illinois	4604596266118386	adff14c2433236f781d314ed5f62eb3e	Diners Club / Carte Blanche	41.7817664847545345	-87.6786987914733515
40150	2020-07-26 18:53:46	2020-07-26	Dr. Jaimie Walsh Jr.	dr.jaimie.walsh.jr.@geemail.com	San Diego	California	3053948653118056	1025f8bae5aea516253f4dce766f183b	Mastercard	32.756578931451962	-117.110257579982289
40151	2020-07-26 18:56:04	2020-07-26	Jennifer Homenick	jennifer.homenick@geemail.com	Honolulu	Hawaii	4420266388894460	cd0f4ca19a478ae198aa9fbb2a3b843b	Diners Club / Carte Blanche	21.2489150512713962	-157.812902709722891
40152	2020-07-26 19:02:09	2020-07-26	Merle Weissnat-Windler	merle.weissnat.windler@geemail.com	Savannah	Georgia	4253037890555465	8d472165869053e316ec0a6e3566cc49	JCB 16 digit	32.0050600275956043	-81.0869720656577471
40153	2020-07-26 19:02:57	2020-07-26	Almina Gerhold	almina.gerhold@geemail.com	Gresham	Oregon	4184166988412	cd2b9ddf552989ed19f82a0e1c287fa1	Maestro	45.4277360817838414	-122.351565389547858
40154	2020-07-26 19:25:01	2020-07-26	Wenzel Stracke-Hahn	wenzel.stracke.hahn@warmmail.com	New York	New York	3023886971152565	59e235d4cf3a44da782cc6ec2a7b9902	Discover	40.6502262646090244	-73.8716844697844266
40155	2020-07-26 19:29:11	2020-07-26	Mr. Hence Marquardt Jr.	mr.hence.marquardt.jr.@geemail.com	San Francisco	California	3788689561900981	fbe60ddddf157f57f69fb4f17f1ca84b	JCB 16 digit	37.7726506885212316	-122.430205134852528
40156	2020-07-26 19:42:48	2020-07-26	Kelis Stroman	kelis.stroman@warmmail.com	Port St. Lucie	Florida	53782749834178440	031ba2f55a94188ef356df3700f957c6	JCB 16 digit	27.3451336658693833	-80.4846496707379799
40157	2020-07-26 19:48:01	2020-07-26	Mr. Melville Rempel PhD	mr.melville.rempel.phd@geemail.com	Pasadena	Texas	869908058968064352	b8b60aa31c12ae978f9a4a5bd71ac960	VISA 16 digit	29.7527269853618002	-95.0606050332024637
40158	2020-07-26 19:49:14	2020-07-26	Lloyd Herman	lloyd.herman@geemail.com	New York	New York	3088184514720952652	bc59250b94542e378e48c68727b7ba70	Mastercard	40.7375681319963192	-73.8752589957684194
40159	2020-07-26 19:54:58	2020-07-26	Kim Rowe	kim.rowe@geemail.com	Clarksville	Tennessee	3112561784161988126	d80b5a9b73d99e75a704b59e1faf9c7c	Diners Club / Carte Blanche	36.5330069690603807	-87.4424762329969667
40160	2020-07-26 20:06:33	2020-07-26	Javen Von-Weber	javen.von.weber@geemail.com	Savannah	Georgia	180009335407276188	2b405569ba812ef24f842fbb07e4c693	VISA 16 digit	31.9254833853896685	-81.1342574304122479
40161	2020-07-26 20:08:14	2020-07-26	Tomeka Kirlin	tomeka.kirlin@geemail.com	Louisville	Kentucky	210097680439655963	5d0bb57ded7a583a7625c8255ab1a918	VISA 16 digit	38.2164514160618154	-85.6122064041975932
40162	2020-07-26 20:09:37	2020-07-26	Kennedy Considine PhD	kennedy.considine.phd@warmmail.com	Boston	Massachusetts	3051888257958766	070f1e2d91874f0cd02c5b6b65a1cf4e	Mastercard	42.3820955057330409	-71.0036620845969821
40163	2020-07-26 20:22:57	2020-07-26	Mrs. Carlotta Moen	mrs.carlotta.moen@geemail.com	Columbus	Ohio	53899448336068312	65d9ad2f5d77be3e070756d55edeeb4b	JCB 16 digit	39.9522736912172292	-83.0777571250919351
40164	2020-07-26 20:25:10	2020-07-26	Leonore Witting	leonore.witting@geemail.com	Washington	District of Columbia	4297744326084337	aff99559592b9ce1e864558f58de3ec1	VISA 16 digit	38.9415826679471877	-77.1166672618340669
40165	2020-07-26 20:28:16	2020-07-26	Mr. Lavern Pouros I	mr.lavern.pouros.i@woohoo.com	Houston	Texas	4150217995739388	4c9c37f8126d2d748e1a37dfb7f81c5c	VISA 16 digit	29.8546767083540558	-95.3095698115430849
40166	2020-07-26 20:31:45	2020-07-26	Tania Kris	tania.kris@warmmail.com	Midland	Texas	180052995375485149	3974d527ddc330433749bc14b2a837ca	Discover	32.1174699910175079	-102.136756327910348
40167	2020-07-26 20:32:39	2020-07-26	Elmyra Ortiz PhD	elmyra.ortiz.phd@geemail.com	Victorville	California	3007267491282016	74115ddd8d8f227f40096f6b1c0b363d	VISA 16 digit	34.6153486571971385	-117.398892508602145
40168	2020-07-26 20:32:40	2020-07-26	Kitty Beahan	kitty.beahan@geemail.com	Pittsburgh	Pennsylvania	55476450638525693	640d562b669283129127fa0cec95910b	Maestro	40.3431178084064257	-79.9966783139560391
40169	2020-07-26 20:44:31	2020-07-26	Benito Kassulke	benito.kassulke@geemail.com	Houston	Texas	4829684573654084	73b10686e868d4cf1d485ffdd374a4c9	Voyager	29.7667551835611448	-95.2987857054468321
40170	2020-07-26 20:44:39	2020-07-26	Margaretha Kub	margaretha.kub@geemail.com	Chandler	Arizona	3337072483110409431	e08b19f427bfe9f2371e36dc77493bf1	VISA 16 digit	33.2654013378635014	-111.772991581622136
40171	2020-07-26 21:12:09	2020-07-26	Clemmie O'Conner	clemmie.o'conner@geemail.com	Fremont	California	3088702291416923098	6abecd040a4dabb59666bb0c9fd18aad	American Express	37.4117940321266644	-121.936551303787894
40172	2020-07-26 21:22:02	2020-07-26	Erland Skiles-Reichel	erland.skiles.reichel@geemail.com	San Francisco	California	4642301467501	e1a385617990d8be481dbf14dd6d01e8	VISA 13 digit	37.7879508614405637	-122.382346695896686
40173	2020-07-26 21:23:13	2020-07-26	Cass Reynolds	cass.reynolds@woohoo.com	San Francisco	California	3056311789364614	dc80e67f732a16008be2573216cb2108	Maestro	37.7571171285415872	-122.470013264482219
40174	2020-07-26 21:28:33	2020-07-26	Mrs. Briana Bogan DVM	mrs.briana.bogan.dvm@geemail.com	Phoenix	Arizona	3112537579362534427	eb5b2645a21149a378fe4214c258012a	American Express	33.613841430603344	-112.129320273075635
40175	2020-07-26 21:35:31	2020-07-26	Harrell Fisher	harrell.fisher@geemail.com	Glendale	California	6011886481556861855	584731042cb2c09f1c64fc69b0e48ad8	VISA 16 digit	34.2067697284031595	-118.159392916075149
40176	2020-07-26 21:37:16	2020-07-26	Mrs. Michal Hilll PhD	mrs.michal.hilll.phd@geemail.com	Little Rock	Arkansas	3438694492444605	9f5bb53da88e50c7dd09d4d2119ba445	Discover	34.6285093895900999	-92.2980686231855287
40177	2020-07-26 21:39:20	2020-07-26	Ah Ledner-Rosenbaum	ah.ledner.rosenbaum@geemail.com	New York	New York	060407866346922	2a3b662e39c15195979b210ab7848cc2	Discover	40.6228984924256764	-73.9996046013094428
40178	2020-07-26 21:40:12	2020-07-26	Hosteen Heaney-Blick	hosteen.heaney.blick@warmmail.com	San Antonio	Texas	210058625992965645	985d3fbd17a3c0ca17de38a3e4826316	JCB 16 digit	29.4174857345946137	-98.5909229086082348
40179	2020-07-26 21:46:35	2020-07-26	Oswald Ratke	oswald.ratke@woohoo.com	Ventura	California	4881759657177	f2960e1cc79dd99d2bead016874e251b	JCB 15 digit	34.2305240144647698	-119.295879583536461
40180	2020-07-26 21:47:30	2020-07-26	Ms. Lavern Friesen	ms.lavern.friesen@geemail.com	Los Angeles	California	3444288208615608	689aa3945c4cb35ab2478e11564bb45b	Voyager	33.9374645134765629	-118.414299276796356
40181	2020-07-26 21:50:59	2020-07-26	Ms. Linna Casper DVM	ms.linna.casper.dvm@geemail.com	Vallejo	California	869949248798911838	67f6442257fd319a01b8f7e9f097f6e8	JCB 15 digit	38.2061292430009729	-122.352096689712255
40182	2020-07-26 21:52:58	2020-07-26	Miss Rhona Braun DDS	miss.rhona.braun.dds@geemail.com	Houston	Texas	3014490689054756	cd9c096c84bab31436c03e6a426208d4	Voyager	29.8655649414364248	-95.3834095111597406
40183	2020-07-26 21:57:46	2020-07-26	Isam Hermann Sr.	isam.hermann.sr.@geemail.com	McKinney	Texas	4701186360882	87f37c2266d635e7408fd7a54e3b1e5f	JCB 16 digit	33.1679886899087606	-96.6653320180550253
40184	2020-07-26 21:58:20	2020-07-26	Dianne Paucek	dianne.paucek@geemail.com	San Diego	California	4715814267526572	ce1b75030fb1943b93e7eb958af6a8d7	Voyager	32.7464000613961375	-117.083898678040143
40185	2020-07-26 22:02:00	2020-07-26	Donald Rolfson	donald.rolfson@woohoo.com	Sparks	Nevada	3528482562685228906	f6ad9356099e7604071ac58825072d22	Mastercard	39.5563581792410446	-119.658813474825024
40186	2020-07-26 22:10:38	2020-07-26	Leola Macejkovic	leola.macejkovic@geemail.com	Elk Grove	California	180058500375486321	21c2537cd3be8c9a6f898a4177ba5055	JCB 15 digit	38.4715770040456206	-121.47912002139725
40187	2020-07-26 22:16:47	2020-07-26	Sheila Collins-Ankunding	sheila.collins.ankunding@warmmail.com	Thornton	Colorado	180008362213435635	bb2c33ab25db4baa9f2b185eaa3bdb23	JCB 15 digit	39.9064188502594845	-104.850335997824743
40188	2020-07-26 22:17:33	2020-07-26	Miss Saige Blanda DVM	miss.saige.blanda.dvm@woohoo.com	San Francisco	California	180037627328038952	f67f38ed9a29186c69a9718d0aebb376	Maestro	37.782521029144732	-122.41956374295539
40189	2020-07-26 22:18:20	2020-07-26	Onnie Kuvalis	onnie.kuvalis@woohoo.com	Rialto	California	4203431786333056	9284f32488f460b2a2ce8d464fdec8be	VISA 13 digit	34.0936454801570648	-117.425158270782973
40190	2020-07-26 22:24:07	2020-07-26	Mrs. Lois Zboncak MD	mrs.lois.zboncak.md@geemail.com	Washington	District of Columbia	3528434671748234816	eaa447ae24dcc7a92c754822113c5288	Diners Club / Carte Blanche	38.9380370179455753	-76.9883674526799524
40191	2020-07-26 22:26:18	2020-07-26	Jaylah Macejkovic	jaylah.macejkovic@geemail.com	Irving	Texas	4194371142036	9d785155358ab597fb070e466c51b49d	JCB 16 digit	32.9414125878781121	-97.0554084489401419
40192	2020-07-26 22:26:47	2020-07-26	Jaeden Pacocha	jaeden.pacocha@geemail.com	Albuquerque	New Mexico	6011217918952647453	e6bf17017e20c5b9a6fb32cb7aef6fd4	American Express	35.0711196797102716	-106.594339413016669
40193	2020-07-26 22:27:29	2020-07-26	Guido Lueilwitz	guido.lueilwitz@geemail.com	Lansing	Michigan	4784347682425811	300acdb873a24b106698709e7dbd60a3	VISA 16 digit	42.7464759738959401	-84.5712130058214058
40194	2020-07-26 22:28:22	2020-07-26	Sable Larkin	sable.larkin@geemail.com	Columbus	Ohio	4603127491122984	d4743598d2e24bb0577f81d20eda41d7	Voyager	40.0799014175821071	-82.9468498410426207
40195	2020-07-26 22:29:31	2020-07-26	Nola Paucek MD	nola.paucek.md@geemail.com	Las Vegas	Nevada	6011953659771888583	133f5c586ffeafa9c2be5a3f9c7cefcf	Voyager	36.2677056089144187	-115.324692704223466
40196	2020-07-26 22:33:04	2020-07-26	Harlen Jaskolski	harlen.jaskolski@geemail.com	Waco	Texas	869989485163389254	2becda439d70acbf9057069289bee406	JCB 15 digit	31.6175641346000127	-97.2377764557153057
40197	2020-07-26 22:44:31	2020-07-26	Garnet Kris IV	garnet.kris.iv@geemail.com	Berkeley	California	4654400391888	ea9248f9cfde5847fa08ca797da4637d	JCB 16 digit	37.8680501953903885	-122.316950480682436
40198	2020-07-26 22:47:04	2020-07-26	Sanaa Hoeger	sanaa.hoeger@geemail.com	New York	New York	869914325397342283	0c5efd36b2a4a27a37f4bd83d6075641	JCB 16 digit	40.709833066839721	-74.0086195725843226
40199	2020-07-26 22:50:11	2020-07-26	Mr. Brad Nicolas PhD	mr.brad.nicolas.phd@geemail.com	Louisville	Kentucky	3096988446779771824	6f7773174ad740cf95e99a802931f444	VISA 16 digit	38.1941529482971873	-85.7367643865361799
40200	2020-07-26 22:50:12	2020-07-26	Zackery Fay	zackery.fay@geemail.com	New York	New York	3337301771983065204	aeb6f1ec8f8697e96a3dea9c7d00194f	JCB 16 digit	40.6927727760039275	-74.0107266505144565
40201	2020-07-26 22:50:44	2020-07-26	Evert Gottlieb	evert.gottlieb@geemail.com	Berkeley	California	3528563210501081693	b2611f11f57cbc53c84325f7c19beda3	Mastercard	37.8581464085057675	-122.270000535738831
40202	2020-07-26 22:52:53	2020-07-26	Jeanette Baumbach	jeanette.baumbach@geemail.com	Washington	District of Columbia	503816794462610	3222f47a4d6347115c05ec33884bb6d0	VISA 13 digit	38.8689053751327123	-76.9575334449511104
40203	2020-07-26 22:58:54	2020-07-26	Pauline Stroman-Gottlieb	pauline.stroman.gottlieb@geemail.com	Richmond	Virginia	52271556216814726	f8b09989bb49c96eda077b061e749ac5	VISA 16 digit	37.6089535689201213	-77.401835662521421
40204	2020-07-26 22:59:23	2020-07-26	Jaeden Kling	jaeden.kling@woohoo.com	Columbia	South Carolina	210034162479544411	aba6226ff7bc37b6c46095706a02c143	Maestro	34.1105584805164455	-80.8435360817257305
40205	2020-07-26 23:07:44	2020-07-26	Verena Stroman DDS	verena.stroman.dds@geemail.com	Sacramento	California	3432477802711152	a6c41e4642d29b93232aafb15483223c	JCB 15 digit	38.5963298964578669	-121.384806956421954
40206	2020-07-26 23:18:40	2020-07-26	Nicholaus Grady	nicholaus.grady@geemail.com	San Francisco	California	3049246383369121	55ca9a080051d75b2b600f8fed6abb68	VISA 13 digit	37.7644104768475017	-122.438580455237286
40207	2020-07-26 23:24:19	2020-07-26	Moriah Wolff-Luettgen	moriah.wolff.luettgen@woohoo.com	Albuquerque	New Mexico	869902101875501813	faf98a2269d5202b8f69499e8673a649	Diners Club / Carte Blanche	35.2037670072767881	-106.67075626371205
40208	2020-07-26 23:30:38	2020-07-26	Dylan Yost-Schneider	dylan.yost.schneider@geemail.com	League City	Texas	676313737830896	708dc674a2f083be25fc98b4dfaeabd8	JCB 16 digit	29.5142674849297855	-95.2023523759081911
40209	2020-07-26 23:32:49	2020-07-26	Martin Champlin	martin.champlin@warmmail.com	Nashville	Tennessee	501846018349301	3e8045abf8ff0cd164f01f8695cf0b5f	Mastercard	36.2444322812959498	-86.8575847314111797
40210	2020-07-26 23:40:57	2020-07-26	Shena Hills	shena.hills@geemail.com	Charlotte	North Carolina	210083772248237350	f7fdfc5338b6f7c4235ea4a8065314c9	VISA 16 digit	35.2766459569588307	-80.7857242560889546
40211	2020-07-26 23:45:37	2020-07-26	Ozie Ziemann-Block	ozie.ziemann.block@geemail.com	San Francisco	California	55932603727968947	fa284b4c7439371ac0d62dfda9174454	VISA 16 digit	37.7558192307000198	-122.437021767046772
40212	2020-07-26 23:48:09	2020-07-26	Dellar Wiegand	dellar.wiegand@geemail.com	San Francisco	California	4381111193421918	603c46ac16fe03f69249e195749e474b	JCB 15 digit	37.7732019719157321	-122.441079086561402
40213	2020-07-27 00:00:35	2020-07-27	Kadijah Reichert	kadijah.reichert@geemail.com	San Francisco	California	6011076026085166951	bac2336ec3617de4720b1ac2ddb1e5e7	Diners Club / Carte Blanche	37.7503732028208745	-122.439455574145185
40214	2020-07-27 00:00:40	2020-07-27	Chad Bechtelar	chad.bechtelar@geemail.com	Las Vegas	Nevada	4982041114603	bd1b95c6c349790b9c555a5a95aaf8cb	VISA 16 digit	36.1378649898439619	-115.166785415469107
40215	2020-07-27 00:02:26	2020-07-27	Sunshine Block	sunshine.block@geemail.com	Fremont	California	501885777776874	d4211e30bc47b7f53c37757a34b62eeb	VISA 13 digit	37.5874690367542215	-121.967379009582842
40216	2020-07-27 00:02:39	2020-07-27	Beverly Ryan	beverly.ryan@warmmail.com	Houston	Texas	180003107134113935	ebb41af815d1aea45b6b6057e169591c	Mastercard	29.7030060250390306	-95.3853062819238744
40217	2020-07-27 00:07:20	2020-07-27	Keri Muller-Rodriguez	keri.muller.rodriguez@geemail.com	Memphis	Tennessee	4988000860920	67dbcf7ff5024c1e8b88e3ac4b16cb99	JCB 15 digit	35.0927781565181931	-89.901574508359289
40218	2020-07-27 00:18:20	2020-07-27	Bennie Gusikowski	bennie.gusikowski@geemail.com	Tucson	Arizona	210017179729696230	894ef181cfc91521fe9f43d06e5223f9	JCB 16 digit	32.1319279087282723	-110.814671000441905
40219	2020-07-27 00:29:50	2020-07-27	Shayna Farrell DDS	shayna.farrell.dds@warmmail.com	West Jordan	Utah	869914197768044859	dd17c696c649b1de562e953fa7cbd4df	American Express	40.6359063870064929	-112.085519620225952
40220	2020-07-27 00:37:38	2020-07-27	Harlie Lesch	harlie.lesch@geemail.com	Phoenix	Arizona	675909716028452	0dae8087393db59ce6242bcf30aa0fba	VISA 16 digit	33.5581232007525898	-112.122358183462552
40221	2020-07-27 00:40:45	2020-07-27	Lew Carroll	lew.carroll@geemail.com	Oakland	California	3708003326680366	efd54783d9bbedc829c6f3779a99c2c1	JCB 16 digit	37.7877788388778768	-122.266636998225181
40222	2020-07-27 00:50:01	2020-07-27	Kaycee Carroll	kaycee.carroll@geemail.com	Mesa	Arizona	4015021667138407	45649049ebff7230a9be137ceff78c26	American Express	33.4555610871553384	-111.771686647541443
40223	2020-07-27 01:00:07	2020-07-27	Kit McClure	kit.mcclure@geemail.com	Kansas City	Kansas	210091336336936438	bb25ed94007a48ba83af866d9275233d	VISA 13 digit	39.0538550213351883	-94.7389449153497765
40224	2020-07-27 01:02:07	2020-07-27	Mrs. Amara Graham DDS	mrs.amara.graham.dds@woohoo.com	Raleigh	North Carolina	869987811570287074	b4f2b54b948c7c601a88efe1b17136c3	Discover	35.8810813409410372	-78.5503701560601684
40225	2020-07-27 01:09:07	2020-07-27	Dori Mayert	dori.mayert@woohoo.com	Miami	Florida	3736474692931715	a50f00f4e52ad08800ddbdabd4b0743e	JCB 15 digit	25.7387031785815985	-80.1634318564891828
40226	2020-07-27 01:13:21	2020-07-27	Dr. Tevin Blanda	dr.tevin.blanda@warmmail.com	Garland	Texas	869903455440352105	46871b444d8cd5578f156f5dd506afc6	Maestro	32.9234443529278025	-96.6316550444971796
40227	2020-07-27 01:16:25	2020-07-27	Parrish Rutherford	parrish.rutherford@woohoo.com	New York	New York	869909596036852455	00f0ac688d08da07f0a1b09b4c21fe93	VISA 16 digit	40.7510231636222429	-73.9583605335920993
40228	2020-07-27 01:22:49	2020-07-27	Felicitas Effertz	felicitas.effertz@geemail.com	Los Angeles	California	3158505132144548147	8605bbbd1a91a2ac0d93047640821259	Maestro	34.0946302153967267	-118.478428655023862
40229	2020-07-27 01:38:57	2020-07-27	Arline Mayert	arline.mayert@geemail.com	Durham	North Carolina	676206821860753	480af59319ca663de3cae69b42448cf0	VISA 16 digit	36.0806445231907063	-78.8903053900595808
40230	2020-07-27 01:42:39	2020-07-27	Kendall Beatty	kendall.beatty@geemail.com	San Francisco	California	869984155877474610	bbcce1e995877c401822e97d03e94d7b	Diners Club / Carte Blanche	37.7664580130150824	-122.421048152904959
40231	2020-07-27 01:48:46	2020-07-27	Jep Mante II	jep.mante.ii@geemail.com	Memphis	Tennessee	52956930750558100	4e7b7a38e7648b08650e0a1f8b6541f0	Mastercard	35.1589422618106013	-89.9587283546362073
40232	2020-07-27 01:51:01	2020-07-27	Josiah Dibbert	josiah.dibbert@geemail.com	Oakland	California	3337936161777594978	bfeca69492428aa4b113b64144b346f7	JCB 16 digit	37.8113793491608092	-122.275986509380644
40233	2020-07-27 01:52:13	2020-07-27	Miss Marva Walsh	miss.marva.walsh@geemail.com	Phoenix	Arizona	869950331730846738	edab5c2034e8df3d450a1df08f206211	American Express	33.4735372428715223	-112.144874561896927
40234	2020-07-27 02:06:33	2020-07-27	Miss Aylin Hammes	miss.aylin.hammes@geemail.com	Seattle	Washington	4441322018347182	603fd1b9b0da79905ae17fd5db320659	JCB 16 digit	47.6151522164158507	-122.28461290247887
40235	2020-07-27 02:08:40	2020-07-27	Salvatore Klocko	salvatore.klocko@geemail.com	San Francisco	California	3112904147062609389	f77d02323d7c236eb3851ade7f5ed4e1	VISA 16 digit	37.7567687142636927	-122.452131564441785
40236	2020-07-27 02:17:06	2020-07-27	Toma Connelly-Mitchell	toma.connelly.mitchell@geemail.com	Newark	New Jersey	3528550278631025976	e587e92f4acd1e5015f33ac756f7530c	JCB 16 digit	40.736508715516706	-74.146877253542101
40237	2020-07-27 02:18:15	2020-07-27	Maryanne Boehm DVM	maryanne.boehm.dvm@geemail.com	San Francisco	California	3337494630897453079	ec7015d1057e830454c8564416f9d9ac	Mastercard	37.7412307248366616	-122.419334017517812
40238	2020-07-27 02:20:33	2020-07-27	Gray Ruecker	gray.ruecker@geemail.com	Pomona	California	6011738467844027284	7a1f16249b31c9b44d15abc945b66fa8	American Express	34.072764029311017	-117.731685262915121
40239	2020-07-27 02:31:21	2020-07-27	Tyler Hane DVM	tyler.hane.dvm@geemail.com	Grand Rapids	Michigan	51050649617786291	27d915e9e4287ea3c0c0a4eb3799122a	Diners Club / Carte Blanche	43.010685734524202	-85.7186174707621404
40240	2020-07-27 02:33:56	2020-07-27	Shayne Hodkiewicz	shayne.hodkiewicz@geemail.com	New York	New York	3030175959784828	cea23af8e150b54f89abca867fd1ac90	Mastercard	40.7124435572642795	-73.8630979142047437
40241	2020-07-27 02:45:57	2020-07-27	Jame Schroeder	jame.schroeder@geemail.com	Anchorage	Alaska	869933862381484082	6471fa85997c37f481e97fbe7e1116b2	American Express	61.1513544945728071	-149.287068853958687
40242	2020-07-27 02:55:46	2020-07-27	Erastus Swaniawski	erastus.swaniawski@geemail.com	Indianapolis	Indiana	3414700439842401	ec10e08e913a655396fe97bd7c7cf1a2	VISA 13 digit	39.7961182686507655	-86.2289977567005934
40243	2020-07-27 03:07:13	2020-07-27	Keyshawn Daniel Jr.	keyshawn.daniel.jr.@geemail.com	Kansas City	Missouri	210055444501098689	b2ecf79c3d8ed63239f1a9d5fe14d05c	Maestro	39.2232332811061326	-94.6399527318067868
40244	2020-07-27 03:08:14	2020-07-27	Tayler Greenfelder	tayler.greenfelder@woohoo.com	Chicago	Illinois	180052294951774039	1df2082838a2c5f2b165a33a375a83dd	Maestro	41.7970727948308038	-87.740073871475829
40245	2020-07-27 03:08:17	2020-07-27	Nigel Feest	nigel.feest@geemail.com	Orlando	Florida	4998541844259	b587ded90542356f0cc49e5d4b21e333	VISA 16 digit	28.4343696666214605	-81.2283873569186738
40246	2020-07-27 03:14:03	2020-07-27	Lizeth Murphy	lizeth.murphy@geemail.com	Costa Mesa	California	630453414292713	cdc64a1987ed53b23f326bae44ea55fa	Discover	33.6363679900314665	-118.003828539359574
40247	2020-07-27 03:16:37	2020-07-27	Isabella Ledner	isabella.ledner@geemail.com	Indianapolis	Indiana	180006815355969721	7de17b67297dea8d65827f8a85325875	VISA 16 digit	39.6964104318067399	-86.0732302898742176
40248	2020-07-27 03:19:20	2020-07-27	Dr. Amy Kiehn DDS	dr.amy.kiehn.dds@geemail.com	Woodbridge	New Jersey	869996701638337533	25a09b5671ebb4678caf43f6b2353c70	Maestro	40.6185638297971323	-74.2446440069794562
40249	2020-07-27 03:24:20	2020-07-27	Yamilex Hand	yamilex.hand@geemail.com	New York	New York	3430673349407997	25600789755c0fb95eb82b88b636b7e9	American Express	40.6887726581878937	-73.9013341553404928
40250	2020-07-27 03:24:48	2020-07-27	Sinda Parisian	sinda.parisian@geemail.com	Arlington	Texas	869909118565507135	67594679b0225c89ff8a0fc250d5c9df	JCB 16 digit	32.7488596656143613	-97.0830374392706972
40251	2020-07-27 03:29:44	2020-07-27	Corwin Crooks	corwin.crooks@warmmail.com	Pompano Beach	Florida	869971904701920040	73e724ab1e288303153864249d1689fe	JCB 16 digit	26.2216759454257762	-80.1651850281596126
40252	2020-07-27 03:51:07	2020-07-27	Francis Kohler	francis.kohler@geemail.com	Oxnard	California	4516594719111949	feb34feafae55123d15b439a0cf65063	JCB 16 digit	34.11959291379452	-119.261709943684195
40253	2020-07-27 03:56:44	2020-07-27	Mr. Unnamed Moen	mr.unnamed.moen@geemail.com	Lubbock	Texas	4625158237094553	087894a81098cfff979dbd45998c0bcd	Diners Club / Carte Blanche	33.6159086694050586	-101.883678726936509
40254	2020-07-27 03:59:02	2020-07-27	Hana Krajcik	hana.krajcik@geemail.com	San Francisco	California	180083940953520357	c3ec98ba410760a00f9f353639772465	JCB 16 digit	37.7720226996924424	-122.402573396465328
40255	2020-07-27 04:08:41	2020-07-27	Rudolf Parker	rudolf.parker@woohoo.com	Garden Grove	California	639044911784591	c1f31152476930167b91ad255c3333c8	VISA 16 digit	33.7351298479188202	-118.034075929692008
40256	2020-07-27 04:14:50	2020-07-27	Orland Jaskolski-Lemke	orland.jaskolski.lemke@woohoo.com	Portland	Oregon	3112013841950326910	7c39fcfe47dfcb03fb223c7aecb3c302	VISA 16 digit	45.5270486569851656	-122.61672700494529
40257	2020-07-27 04:15:02	2020-07-27	Dr. Maryellen Berge	dr.maryellen.berge@geemail.com	Everett	Washington	51523773708921481	37c7118836e27de320a691c1d7d32e2f	American Express	47.9588756974678532	-122.131144030637671
40258	2020-07-27 04:17:54	2020-07-27	Cleve Becker	cleve.becker@geemail.com	Corpus Christi	Texas	630420847457148	5bc16be9414ba1cd27074d61cf51638b	JCB 15 digit	27.7305725684326134	-97.2023763157721561
40259	2020-07-27 04:19:02	2020-07-27	Dr. Gertrude Streich	dr.gertrude.streich@warmmail.com	Salinas	California	52067686071425868	0fb278a02b04223bd3c37c30b484b3cc	JCB 16 digit	36.6316526728913132	-121.623074449430035
40260	2020-07-27 04:21:40	2020-07-27	Noel Kirlin-Rutherford	noel.kirlin.rutherford@geemail.com	Columbus	Ohio	6011645403951900916	1f133d77715978f2f55ceae582502ede	Diners Club / Carte Blanche	39.8991217087067653	-83.0670373581118895
40261	2020-07-27 04:33:11	2020-07-27	Danial Wilkinson-Kuhlman	danial.wilkinson.kuhlman@warmmail.com	San Francisco	California	3112308709247660017	b977b4e2d12fcfdc6bab71d9202ff530	Voyager	37.7673885748456755	-122.390710114867233
40262	2020-07-27 04:45:17	2020-07-27	Mrs. Alexandria Cole	mrs.alexandria.cole@geemail.com	Clarksville	Tennessee	4785031751304	25dc2ebf5602d3844fe9d285d41c0ab1	JCB 15 digit	36.6109613408926862	-87.2726573880247827
40263	2020-07-27 04:55:33	2020-07-27	Eston Wisozk	eston.wisozk@warmmail.com	College Station	Texas	4763350293057473	420dc1871f1f4e2296d8c9626e6dd47b	JCB 16 digit	30.5003247820816945	-96.3003319583214932
40264	2020-07-27 05:03:02	2020-07-27	Jaylee Hilll	jaylee.hilll@geemail.com	Tuscaloosa	Alabama	4973898765252200	ef54b43894d3afff2145c4c7de8bd1f8	VISA 13 digit	33.2716153880171461	-87.4354738139644212
40265	2020-07-27 05:10:10	2020-07-27	Mr. Kellan Lemke III	mr.kellan.lemke.iii@warmmail.com	New York	New York	3088445350132106594	69515d27ce9dfb6b04b997e3c4270207	American Express	40.7351990049462742	-73.9971246636833939
40266	2020-07-27 05:13:46	2020-07-27	Kamren Kutch IV	kamren.kutch.iv@geemail.com	Oakland	California	4886371527526	ca89630ebad8eff4616792fdd05af6b8	VISA 16 digit	37.8097035279773763	-122.310836786234276
40267	2020-07-27 05:15:46	2020-07-27	Ah D'Amore-Stokes	ah.d'amore.stokes@geemail.com	San Diego	California	4664399799138154	376984ed13a1e494f931c331ec274842	VISA 16 digit	32.9066062633480882	-117.125688144834712
40268	2020-07-27 05:20:34	2020-07-27	Viola Stracke	viola.stracke@geemail.com	Albuquerque	New Mexico	4491501215439	348273d98cb25620af6154a91f6c54fb	Discover	35.1200363950937984	-106.738325591625284
40269	2020-07-27 05:25:46	2020-07-27	Lyndsay Gleason	lyndsay.gleason@geemail.com	Joliet	Illinois	501842463640567	2e02dcb1e4a01d8103aa3faa1884a06f	Voyager	41.4865751608598927	-88.2261317356128245
40270	2020-07-27 05:29:11	2020-07-27	Mrs. Venice Ondricka PhD	mrs.venice.ondricka.phd@woohoo.com	Chula Vista	California	3158178072299275920	8e0158458c108ef6965a0ad42b19d494	VISA 16 digit	32.5742220673475416	-116.938758783624309
40271	2020-07-27 05:50:44	2020-07-27	Jaycie Schimmel MD	jaycie.schimmel.md@geemail.com	Berkeley	California	180019599045007150	4c55b9023635c1b1d5fade75ca9b2483	Mastercard	37.9220637859865946	-122.275174476510429
40272	2020-07-27 06:02:25	2020-07-27	Rayford Mante	rayford.mante@geemail.com	San Francisco	California	6011234474851510045	31f53d4ec8b12a6be95fa03aade3b71f	Maestro	37.7617110493178387	-122.421319870698994
40273	2020-07-27 06:03:38	2020-07-27	Moody Klein	moody.klein@warmmail.com	Davie	Florida	4614870654507064	3e7f8dfb99dff0a70ee5c0aea96f5c27	JCB 15 digit	26.1139002197686594	-80.2832368264347309
40274	2020-07-27 06:10:29	2020-07-27	Jean Grady	jean.grady@geemail.com	New York	New York	3042593689825463	5b0a14d55a00cb2ded607fe1425c2729	VISA 16 digit	40.6365672340374431	-73.8925609126116996
40275	2020-07-27 06:10:57	2020-07-27	Isaac McKenzie	isaac.mckenzie@geemail.com	Fresno	California	4832621483691801	c5eb14558743a0a3830d24d9cdba10c7	VISA 16 digit	36.7377284946724743	-119.848100843105101
40276	2020-07-27 06:11:29	2020-07-27	Gustie Luettgen	gustie.luettgen@geemail.com	North Charleston	South Carolina	3736884884204376	06afa9038fe4bae0bc25991feb0225ae	American Express	33.000133893096077	-79.9984788956679438
40277	2020-07-27 06:27:36	2020-07-27	Stephen Kassulke	stephen.kassulke@woohoo.com	McAllen	Texas	6011023007399112521	fd51039b05dc2b345dca27e0ddd22724	VISA 16 digit	26.1569700429055843	-98.2551913058232458
40278	2020-07-27 06:47:23	2020-07-27	Honora Will	honora.will@geemail.com	Buffalo	New York	4861699337444787	fd66fd804624bec837de55e11f654df1	VISA 16 digit	42.9572448768839195	-78.8344293833177545
40279	2020-07-27 06:49:40	2020-07-27	Devaughn Shanahan-Hane	devaughn.shanahan.hane@geemail.com	Tulsa	Oklahoma	52543729348310531	2152cffb16795553f3fbeb0509a8a519	Mastercard	36.0700719910576879	-95.853540401668468
40280	2020-07-27 06:51:56	2020-07-27	Susanne Windler	susanne.windler@geemail.com	Tampa	Florida	4855078463589798	0ca06af72ee4eca437c1abc0d25e9454	Mastercard	28.0530250376205892	-82.3906251492656736
40281	2020-07-27 06:53:26	2020-07-27	Braylen Russel-Spinka	braylen.russel.spinka@woohoo.com	Huntington Beach	California	4747121265223802	9331ef7b8d4293b41a80db21eaf19545	VISA 13 digit	33.7323765744030482	-117.951191330061476
40282	2020-07-27 07:28:32	2020-07-27	Collier Ebert	collier.ebert@geemail.com	San Bernardino	California	869968725896738912	98762b3ee79024384b2790d4546a27e0	VISA 16 digit	34.2113617966216026	-117.322730464792244
40283	2020-07-27 07:35:26	2020-07-27	Justyn Bogan	justyn.bogan@warmmail.com	Lafayette	Louisiana	3484642448645901	3dfd3143bd57e83b2dd1910ef7eb0608	VISA 16 digit	30.1891492891568696	-91.9996891556624234
40284	2020-07-27 07:38:12	2020-07-27	Mrs. Izola Farrell	mrs.izola.farrell@geemail.com	Scottsdale	Arizona	3088936889652884508	0cab4838abb95dc3fc9cc0960314e12c	JCB 16 digit	33.7718644317362475	-111.812985087462138
40285	2020-07-27 07:41:56	2020-07-27	Ciji Bosco	ciji.bosco@warmmail.com	San Antonio	Texas	869985365990847712	417eb10eb0e6dbe6cb1a774206236e9e	Discover	29.5383340040758249	-98.5626398058444266
40286	2020-07-27 07:51:02	2020-07-27	Maliyah Sporer	maliyah.sporer@warmmail.com	Memphis	Tennessee	4704820378252	a7f876abd84b5de008a9f47b2d72dc76	Voyager	35.1807282317962517	-89.9654302305333289
40287	2020-07-27 07:52:22	2020-07-27	Mrs. Kyra Buckridge MD	mrs.kyra.buckridge.md@woohoo.com	Little Rock	Arkansas	51261027834965631	4e5791baf74ca9d0b30941c3aacff6f7	Maestro	34.6751311428189268	-92.3172199149489359
40288	2020-07-27 07:53:40	2020-07-27	Miss Breonna Kunze MD	miss.breonna.kunze.md@warmmail.com	Akron	Ohio	52818491584700887	b87ae6b9166649ada3b7994a55a6838b	Maestro	41.1565239573661259	-81.6139043127965209
40289	2020-07-27 08:04:01	2020-07-27	Rudy Swaniawski	rudy.swaniawski@geemail.com	San Francisco	California	3112705186739991326	4820dc8d159a41a195f6509000af8f03	Maestro	37.8062194935904614	-122.432032298476301
40290	2020-07-27 08:09:43	2020-07-27	Debi Glover	debi.glover@geemail.com	Kansas City	Missouri	210082701614628828	9b437dead42db0085bf78a66fff7743e	VISA 16 digit	39.0359617129270049	-94.6374599738735753
40291	2020-07-27 08:10:40	2020-07-27	Skip Windler DVM	skip.windler.dvm@geemail.com	Hayward	California	6011236687914754973	1fc58d136d95d199ab51d9d1ed9ea15f	VISA 16 digit	37.6415797017503522	-122.14561291805245
40292	2020-07-27 08:17:20	2020-07-27	Immanuel Lynch-O'Kon	immanuel.lynch.o'kon@geemail.com	Colorado Springs	Colorado	4424146282867125	81bcec84a07d697e5f351a2e17585dcf	VISA 16 digit	38.8701097847476618	-104.746933234964317
40293	2020-07-27 08:19:39	2020-07-27	Halley Medhurst	halley.medhurst@geemail.com	Los Angeles	California	4527318783722531	c313c9f2e03e6dc45476d9d8bc0da0a7	Diners Club / Carte Blanche	33.9260192177589985	-118.42310784137733
40294	2020-07-27 08:22:44	2020-07-27	Marina Gleichner-Hackett	marina.gleichner.hackett@geemail.com	Phoenix	Arizona	4205083920670899	aa10444d9b2e1e117edeea9d739be6b5	Mastercard	33.5266366311747603	-112.017891835973046
40295	2020-07-27 08:28:05	2020-07-27	Jerod Greenfelder	jerod.greenfelder@geemail.com	Anaheim	California	55693085428306586	ca2b3e08ca2040711165391a16153004	Maestro	33.9277434533294269	-117.745148868833098
40296	2020-07-27 08:35:58	2020-07-27	Deena Mills MD	deena.mills.md@geemail.com	New York	New York	3158262274999904836	0fce35fb3f3e87a463403cbe614342b8	JCB 16 digit	40.6813990182466796	-73.9526612128026812
40297	2020-07-27 08:36:07	2020-07-27	Takisha Feest	takisha.feest@geemail.com	Lansing	Michigan	3158311441068547132	276b1c7c34ebc30d9b40ab1dc89c0b77	VISA 13 digit	42.69679219572172	-84.6050833604421371
40298	2020-07-27 08:37:07	2020-07-27	Attilio Smitham Jr.	attilio.smitham.jr.@geemail.com	New York	New York	3088261165907752229	6640e1fd1458264815d3067a76b499b5	JCB 16 digit	40.6436128723658641	-73.941403019091851
40299	2020-07-27 08:37:53	2020-07-27	Estefania Becker	estefania.becker@geemail.com	Philadelphia	Pennsylvania	676316074586062	cb67e85497caa9c486bf45bd8f26652c	JCB 15 digit	39.9230236272286589	-75.1205084995731767
40300	2020-07-27 08:43:09	2020-07-27	Chandra Brekke	chandra.brekke@woohoo.com	Naperville	Illinois	3158433628902940787	24eee6043bbefaf8e3efb9bf64127e45	JCB 15 digit	41.7353141965258914	-88.1341950564533505
40301	2020-07-27 08:45:51	2020-07-27	Dr. Summer Ortiz MD	dr.summer.ortiz.md@geemail.com	Los Angeles	California	3035691137625688	070d95ebf312f261a6bfafa78089b446	JCB 15 digit	34.0429562801826719	-118.474948402120916
40302	2020-07-27 08:48:20	2020-07-27	Elsa Jakubowski	elsa.jakubowski@geemail.com	Topeka	Kansas	3337614989070111069	884d6eeeb56b51eba65048d271fc3c8d	VISA 16 digit	39.0402410105269411	-95.7193605518143613
40303	2020-07-27 08:48:58	2020-07-27	Miss Moira Medhurst	miss.moira.medhurst@warmmail.com	Los Angeles	California	52634963303691292	d9758e7bf5d7b12dbae8d808dec71ebe	Discover	34.040543383020534	-118.502307571563122
40304	2020-07-27 08:49:20	2020-07-27	Natalia Torp	natalia.torp@woohoo.com	San Francisco	California	869949334067738738	36ea5709fc27db55748c3198b221808a	American Express	37.7471818503621535	-122.434786206630207
40305	2020-07-27 08:49:28	2020-07-27	Dr. Valencia Daniel	dr.valencia.daniel@woohoo.com	Port St. Lucie	Florida	869983682467550229	534333d57a8c9170843c69b9b3d141da	VISA 16 digit	27.3158821479551506	-80.3525782747745581
40306	2020-07-27 08:52:54	2020-07-27	Carly Hessel	carly.hessel@geemail.com	San Francisco	California	6011216300082671433	5f94e001658cbaf2feb4e3ad70036ed5	American Express	37.7651447072197328	-122.404640445892568
40307	2020-07-27 09:02:00	2020-07-27	Maximus Bernhard	maximus.bernhard@woohoo.com	Detroit	Michigan	54137789266275787	6a059d12b68eaeacb004a6a6a3f1dee0	Mastercard	42.4596652511898469	-83.0210391759060258
40308	2020-07-27 09:03:09	2020-07-27	Fay Ward	fay.ward@warmmail.com	El Paso	Texas	3088277062316107032	3cffb1669e4fa45a486c3f1194611515	Discover	31.8582607092164487	-106.435284721756361
40309	2020-07-27 09:03:52	2020-07-27	Nikolai Rath III	nikolai.rath.iii@geemail.com	McKinney	Texas	4419089734638	054132cea21798f297ff77bb2cc1e721	Diners Club / Carte Blanche	33.2508934893310126	-96.6319852895867086
40310	2020-07-27 09:09:08	2020-07-27	Mrs. Stormy Mann	mrs.stormy.mann@geemail.com	Denver	Colorado	6011511184202658930	e8cbd8475c62d91e96176f1146d128e7	American Express	39.6883941235538558	-104.781693270594261
40311	2020-07-27 09:10:18	2020-07-27	Jaliyah Wilkinson	jaliyah.wilkinson@geemail.com	Chandler	Arizona	4576245609707802	067c67190b5353c5a9be83ebf3b709ac	Diners Club / Carte Blanche	33.3532572219237693	-111.928078782360629
40312	2020-07-27 09:10:57	2020-07-27	Zakary Quitzon	zakary.quitzon@geemail.com	Omaha	Nebraska	55558396612020816	2c0ba7b4376a451e18c294e664ce79c1	American Express	41.2889086844544906	-96.0856290654860459
40313	2020-07-27 09:25:07	2020-07-27	Ms. Shae Towne	ms.shae.towne@woohoo.com	Kansas City	Kansas	210049660993749955	65643718c8afa319701f3a2e3b37a998	JCB 15 digit	39.1265568639524304	-94.7580354615516995
40314	2020-07-27 09:29:40	2020-07-27	Najee Gusikowski-Bauch	najee.gusikowski.bauch@geemail.com	Saint Paul	Minnesota	180049099633006403	e73c8ced2104fe835aaa685f46543765	Discover	44.8935479202248189	-93.1854878894783525
40315	2020-07-27 09:31:25	2020-07-27	Laken Barton	laken.barton@geemail.com	New York	New York	676223537549240	c1bef5650a329589da180e7339c46709	Mastercard	40.7393544567506751	-73.8626045780152083
40316	2020-07-27 09:41:10	2020-07-27	Abril Huel	abril.huel@warmmail.com	Denver	Colorado	4551925509533	2d9b821ef1bef1a1a2505c0ec5c3a3a7	VISA 16 digit	39.801630589883402	-104.863864363847682
40317	2020-07-27 09:47:01	2020-07-27	Emanuel Trantow	emanuel.trantow@geemail.com	San Antonio	Texas	4003867758145204	b0e9ed7c407dde55a18b5816af6076eb	JCB 16 digit	29.5253295891057697	-98.4351352970417537
40318	2020-07-27 09:47:50	2020-07-27	Maebell Gerhold	maebell.gerhold@geemail.com	New York	New York	4226141039959	f9b4cff875417dd850f4f413d289444e	JCB 16 digit	40.7011198800280667	-73.9420912811893913
40319	2020-07-27 09:56:43	2020-07-27	Nicole Cartwright	nicole.cartwright@geemail.com	Detroit	Michigan	53958628608060612	fb41fefb8e4c4a7218791d1dfca6ba3d	American Express	42.4292903663516086	-83.1788856658738069
40320	2020-07-27 10:09:23	2020-07-27	Birt Becker-Mosciski	birt.becker.mosciski@woohoo.com	Newark	New Jersey	869956958242394759	e3400cffa6dbc5fd0c2c4bf17862eadb	Diners Club / Carte Blanche	40.6676793186374042	-74.1137441115196793
40321	2020-07-27 10:10:58	2020-07-27	Magnolia Anderson	magnolia.anderson@geemail.com	San Francisco	California	3112786925653852267	cc751f1712dc067889887a1001f5fc76	VISA 16 digit	37.7360319381896829	-122.412715895924208
40322	2020-07-27 10:15:31	2020-07-27	Mr. Earley Schaefer DVM	mr.earley.schaefer.dvm@geemail.com	San Francisco	California	3050205394296177	d81ad360c111d4adc5d4d1ee41b8d4c3	Discover	37.8071584840401016	-122.442205037934414
40323	2020-07-27 10:15:46	2020-07-27	Cena Huels-McCullough	cena.huels.mccullough@geemail.com	Scottsdale	Arizona	4823594210274129	92bff38d128eaebd0c83c8b5719b3caa	JCB 15 digit	33.6664548383217337	-111.771233895976465
40324	2020-07-27 10:28:57	2020-07-27	Ms. Makenzie Murazik	ms.makenzie.murazik@geemail.com	Denver	Colorado	4045955760728	3cf22fac0d3831aca62550464920095a	Voyager	39.8314202439092071	-104.880238744687659
40325	2020-07-27 10:29:24	2020-07-27	Dr. Angelina Gottlieb DVM	dr.angelina.gottlieb.dvm@geemail.com	Santa Clara	California	869973681803808046	52a57fdda26dded4ace21f5b318437ae	JCB 16 digit	37.4158270745821326	-121.894320675357804
40326	2020-07-27 10:29:49	2020-07-27	Coraima Grimes	coraima.grimes@geemail.com	Bridgeport	Connecticut	3096609317116512529	8c2464d814b283d1b986047f1da90017	VISA 16 digit	41.2772035161662814	-73.1343860559530583
40327	2020-07-27 10:44:29	2020-07-27	Ericka Sipes	ericka.sipes@geemail.com	Detroit	Michigan	210038071648622212	2fead0f1f3d165fb70f15eae4ebd3ffe	VISA 13 digit	42.4022717287689446	-83.1505120185788655
40328	2020-07-27 10:55:08	2020-07-27	Mr. Everett Zemlak	mr.everett.zemlak@geemail.com	Irving	Texas	4368722649168	bb78b1f3a4740e974ae2edf218f0f46c	Mastercard	32.7762426753480014	-96.9155855485051916
40329	2020-07-27 11:02:18	2020-07-27	Jules Monahan	jules.monahan@geemail.com	Bakersfield	California	3088347779820745728	e0ea4b04d439ef846cdc45fa974c53c3	Discover	35.2388021805033063	-118.957219678889217
40330	2020-07-27 11:13:39	2020-07-27	Dr. Tabitha Barrows	dr.tabitha.barrows@geemail.com	Boston	Massachusetts	6011514320890678445	483d7b536ae1b7a72a816be308bcf6ba	VISA 16 digit	42.3903506080322003	-70.9942043699741419
40331	2020-07-27 11:15:16	2020-07-27	Mr. Captain Rempel	mr.captain.rempel@woohoo.com	San Francisco	California	180078092451078152	f45a41c89975e0fd5ad2c2675db42f7c	JCB 16 digit	37.7766878285051462	-122.475564355096722
40332	2020-07-27 11:15:27	2020-07-27	Destinee Luettgen-Conroy	destinee.luettgen.conroy@geemail.com	Carlsbad	California	869973108123320585	bf47071fbc8dccd10cf68f52cf05e85c	American Express	33.1200510829161843	-117.210861404498289
40333	2020-07-27 11:19:37	2020-07-27	Rubye Marvin	rubye.marvin@geemail.com	New York	New York	3732681247182123	a3cdbff274d9c812e9f6462e31a022c5	American Express	40.6017986039854577	-73.857653091232109
40334	2020-07-27 11:28:07	2020-07-27	Hilma Gutkowski	hilma.gutkowski@warmmail.com	Milwaukee	Wisconsin	869999542128648998	76410155e69686231e7bab90192e190c	Maestro	43.021579037242752	-87.993328237729898
40335	2020-07-27 11:40:57	2020-07-27	Marquez Pouros Sr.	marquez.pouros.sr.@geemail.com	San Francisco	California	4037338182068	a95494fadd018728f33ad8247469811b	JCB 16 digit	37.7776014121693819	-122.380855478289476
40336	2020-07-27 11:41:52	2020-07-27	Maryjane King	maryjane.king@geemail.com	Temecula	California	180054876384817928	581cd823848f49ba5b37f48bc5c49869	Diners Club / Carte Blanche	33.4775092221464945	-117.145608383762465
40337	2020-07-27 11:43:02	2020-07-27	Tamisha Wiza	tamisha.wiza@geemail.com	Athens	Georgia	3734580227762698	6ea8d1f9ab4660b774f3d34878f22381	Maestro	33.9664375353328865	-83.4226762151460974
40338	2020-07-27 11:55:02	2020-07-27	Anastacio D'Amore	anastacio.d'amore@warmmail.com	New York	New York	503838714224185	74d22138834a2ca75dcdf5f2cea164dc	Mastercard	40.6350573998633777	-73.9094842064555735
40339	2020-07-27 11:59:31	2020-07-27	Malorie Schaden	malorie.schaden@woohoo.com	New York	New York	6011687961540348250	4974037b66ca8c8db438d4f13dc66418	Voyager	40.6847257981300316	-73.8469350962329685
40340	2020-07-27 12:14:09	2020-07-27	Dr. Infant Torp III	dr.infant.torp.iii@geemail.com	Mesa	Arizona	55783496067186695	d7264a1a3a598f83f4579cc5b93d3749	VISA 16 digit	33.4595392800547131	-111.697230234404657
40341	2020-07-27 12:15:02	2020-07-27	Roosevelt Koss	roosevelt.koss@geemail.com	Centennial	Colorado	3003577410893444	4cae38d0c811ed94c8ceb6617f48a760	Discover	39.5615641218185417	-104.858361617697781
40342	2020-07-27 12:25:39	2020-07-27	Khiry Bashirian	khiry.bashirian@geemail.com	Detroit	Michigan	3000776558400706	49cafcd39b9dbe4b492357ec563aa6ee	Maestro	42.3187911664061289	-83.1742933690201482
40343	2020-07-27 12:34:19	2020-07-27	Baylie Gleichner	baylie.gleichner@geemail.com	Tampa	Florida	210094344563942332	ebfb3283dfde3b90b6c81bd349f200c1	VISA 16 digit	28.0232903784722076	-82.4302713384598462
40344	2020-07-27 12:35:07	2020-07-27	Reginal Hyatt	reginal.hyatt@geemail.com	Fairfield	California	4221841686062415	d93d35eea91a5c3897ba34a1ffaa1926	VISA 16 digit	38.222029888223112	-122.087585342815515
40345	2020-07-27 12:42:23	2020-07-27	Ulysses Ortiz	ulysses.ortiz@woohoo.com	Long Beach	California	4734401944288607	9cf74bf8f59fdb1b07adc9e997492238	American Express	33.7333068072617053	-118.235396333101392
40346	2020-07-27 12:48:44	2020-07-27	Versie Langosh	versie.langosh@geemail.com	Grand Rapids	Michigan	3096816870497595751	897acd3acc311183da858622264a83bd	JCB 16 digit	43.0354241136729669	-85.6492323297210163
40347	2020-07-27 12:50:36	2020-07-27	Dr. Antonette Wilderman MD	dr.antonette.wilderman.md@geemail.com	Los Angeles	California	6011191735249320748	d2a32be27159129ec3c55f083d7b8c17	Discover	33.9663694682862598	-118.319305872823293
40348	2020-07-27 12:55:59	2020-07-27	Alaya Sporer	alaya.sporer@geemail.com	Miramar	Florida	6011471199749516456	0ffc8c69a71ae973e2b1d46342402d98	Maestro	26.0039629627931852	-80.3828292560290549
40349	2020-07-27 12:56:17	2020-07-27	Emeline Schinner	emeline.schinner@woohoo.com	Fort Wayne	Indiana	869938982699539628	fe12972874ec0674e296d5d791245acc	JCB 15 digit	40.995572690085325	-85.1267495348338059
40350	2020-07-27 13:01:26	2020-07-27	Dr. Vella Rohan	dr.vella.rohan@warmmail.com	San Francisco	California	4137340349507711	849a3e25fea51599daf7cd905f62edb8	Discover	37.7937924044837104	-122.43756316369381
40351	2020-07-27 13:07:44	2020-07-27	Izora Hammes	izora.hammes@warmmail.com	Fort Collins	Colorado	210071361361317118	9b777059561bad61cb304ea3258986fe	JCB 16 digit	40.4656441435374319	-105.023509084382283
40352	2020-07-27 13:10:02	2020-07-27	Nina Hammes	nina.hammes@warmmail.com	Boston	Massachusetts	4329277252613227	017bbb01133839658b0c2471e27e366b	Diners Club / Carte Blanche	42.265147428231316	-71.0453304508652508
40353	2020-07-27 13:14:51	2020-07-27	Jamarion O'Conner MD	jamarion.o'conner.md@geemail.com	San Francisco	California	4395770781338	91afb55f5890d925c843f7b4752d9888	Voyager	37.8091366970766103	-122.414639444330291
40354	2020-07-27 13:17:05	2020-07-27	Donnie Wyman-Funk	donnie.wyman.funk@geemail.com	Ontario	California	3021363273662735	4e3b660be15af8be507c55a7fee9404e	American Express	33.9901174137979751	-117.664734182051205
40355	2020-07-27 13:17:50	2020-07-27	Darian Tremblay	darian.tremblay@warmmail.com	Oakland	California	3769320923199962	085a3fb0ec8561012c157f39bc1d9dc8	VISA 16 digit	37.7600967833086614	-122.287221111024891
40356	2020-07-27 13:23:36	2020-07-27	Shay Swift DDS	shay.swift.dds@woohoo.com	Cary	North Carolina	3112079709210349892	04b153d943144b08e35fd29e6a6cea85	Diners Club / Carte Blanche	35.685662925906108	-78.8329262314450006
40357	2020-07-27 13:39:55	2020-07-27	Fronia Walter	fronia.walter@geemail.com	Knoxville	Tennessee	3337012281774131611	6afbce109ef1a450aa6aea20811e2e2c	American Express	36.017412195035071	-83.8704683151312054
40358	2020-07-27 13:42:22	2020-07-27	Emma Will	emma.will@woohoo.com	Los Angeles	California	3033993786134182	f705fbe359e27e45317366b55eb6f605	Maestro	33.9364628055464479	-118.449830045410607
40359	2020-07-27 13:43:13	2020-07-27	Judd Lynch	judd.lynch@geemail.com	Buffalo	New York	4431628052053821	4854d23ecc37fb97d2e153a29386e9a0	Diners Club / Carte Blanche	42.9623380439542188	-78.932343214976413
40360	2020-07-27 13:47:20	2020-07-27	Vashon Emmerich	vashon.emmerich@geemail.com	Irvine	California	3026322258521360	7f21f5044e44ae332c9305c1a163cb60	VISA 13 digit	33.6438299363028293	-117.814346366423365
40361	2020-07-27 13:49:21	2020-07-27	Kaiya Brekke-Bahringer	kaiya.brekke.bahringer@geemail.com	San Francisco	California	6011154817894248567	36372712da1cd067ad6e00bd66c48209	Diners Club / Carte Blanche	37.7710293000538755	-122.428983412561223
40362	2020-07-27 13:51:42	2020-07-27	Dr. Dusty Cartwright DDS	dr.dusty.cartwright.dds@warmmail.com	Kansas City	Missouri	3431122380669320	99f7f1c42e1b7bb04d7aabb98ad2bd0d	American Express	39.2009491011336451	-94.5143600536268167
40363	2020-07-27 14:08:05	2020-07-27	Alby Kuhlman	alby.kuhlman@geemail.com	Durham	North Carolina	4555563364356572	58bddd03685cb9c6a2080096afc92a90	JCB 16 digit	35.9599193846121423	-78.8987077298011599
40364	2020-07-27 14:12:26	2020-07-27	Mr. Johnpaul Gerlach I	mr.johnpaul.gerlach.i@geemail.com	Oakland	California	676386476634844	e9d6c2fb3db739c495f2483e1514cd86	JCB 16 digit	37.7861080583872777	-122.316159852773495
40365	2020-07-27 14:21:06	2020-07-27	Osvaldo Schowalter	osvaldo.schowalter@warmmail.com	Houston	Texas	52420887211183829	e5c0b2ade0358fb537a626395f4cfc2b	Voyager	29.7263201654966913	-95.4314072249006529
40366	2020-07-27 14:26:34	2020-07-27	Washington Ruecker	washington.ruecker@geemail.com	San Bernardino	California	4796951465740654	12a613a6b613a1dc195c69003d9cebc6	Diners Club / Carte Blanche	34.1698012283802015	-117.282030660078306
40367	2020-07-27 14:28:40	2020-07-27	Jacky Mueller	jacky.mueller@woohoo.com	Santa Clarita	California	630487853563648	6120e138b398629f8236c2e2fb574726	VISA 16 digit	34.309761045614259	-118.494175702017543
40368	2020-07-27 14:40:34	2020-07-27	Kaitlynn Morissette	kaitlynn.morissette@geemail.com	New York	New York	4004748648985471	99e3b17b29e7658cdbce9c53adb78a18	Maestro	40.7049570393972076	-73.9391428682383065
40369	2020-07-27 14:47:55	2020-07-27	Audley Dietrich-Mueller	audley.dietrich.mueller@geemail.com	Ventura	California	210014634292766474	2c843125319d421e3baf9244a1d51175	VISA 16 digit	34.1978067521631743	-119.267180504659933
40370	2020-07-27 14:49:06	2020-07-27	Selena Langosh	selena.langosh@geemail.com	Thousand Oaks	California	3158139481547690772	aa607457338695c1ec0bcff4f1b9d546	VISA 16 digit	34.1991028365019716	-118.896832349794735
40371	2020-07-27 14:51:31	2020-07-27	Hansel Lueilwitz	hansel.lueilwitz@geemail.com	Denton	Texas	3032437902099797	40c07ebe3181005540a8075afb654f4e	JCB 16 digit	33.2315670828599465	-97.0904467671770703
40372	2020-07-27 14:52:56	2020-07-27	Beverley Schmidt	beverley.schmidt@geemail.com	Columbus	Georgia	4309425672589345	e3ebbd9e5b4bf7468329c8d868ba8b09	VISA 16 digit	32.4697748578198215	-84.7749725737772906
40373	2020-07-27 14:53:33	2020-07-27	Lashawn Fadel-McLaughlin	lashawn.fadel.mclaughlin@geemail.com	Torrance	California	3799352230208933	04ba044dd080a9a8f4e4ebe9f04e01f8	VISA 16 digit	33.7492216877546198	-118.341715129943182
40374	2020-07-27 14:58:06	2020-07-27	Cody Marquardt-Purdy	cody.marquardt.purdy@geemail.com	San Francisco	California	4566799763381855	a1d6de044e5654659715a4d1e9082c10	Maestro	37.7790825564114172	-122.435696613616045
40375	2020-07-27 15:06:01	2020-07-27	Clair Thiel	clair.thiel@geemail.com	Philadelphia	Pennsylvania	4927182281992	87ad61a4eea96e5bf662f04b9bc3880d	JCB 15 digit	39.9328938342124218	-75.0818435244161719
40376	2020-07-27 15:14:52	2020-07-27	Ira Howell	ira.howell@geemail.com	Louisville	Kentucky	4161238656338051	9613c3b2c1a0b55f04073e13b6143d9e	VISA 13 digit	38.0961076360564661	-85.6643528699945733
40377	2020-07-27 15:23:33	2020-07-27	Jep Labadie Jr.	jep.labadie.jr.@warmmail.com	Pueblo	Colorado	6011329047345198712	bfb4f6e0d94fe8133838c24110f31ffd	American Express	38.3676865665685369	-104.639141014204554
40378	2020-07-27 15:23:43	2020-07-27	Benjaman Altenwerth-Hamill	benjaman.altenwerth.hamill@geemail.com	Berkeley	California	869922212797561722	319f379898d4d7b9145b0a238765b97b	Discover	37.8691007959086647	-122.26406174877792
40379	2020-07-27 15:26:19	2020-07-27	Hakeem Jenkins	hakeem.jenkins@geemail.com	Birmingham	Alabama	503865018733959	8bbc931296194c4b2417412aff00f8bd	JCB 16 digit	33.5009385962761925	-86.7809906963035473
40380	2020-07-27 15:28:23	2020-07-27	Miss Jocelyn Gusikowski	miss.jocelyn.gusikowski@geemail.com	Denver	Colorado	3096031280199955916	b6fea3bb5d6891ecd6cb888362317cb8	Maestro	39.8481315562087985	-104.976972191153465
40381	2020-07-27 15:30:39	2020-07-27	Gay Stark-Zulauf	gay.stark.zulauf@geemail.com	New York	New York	3088467164648506855	70eb0cd5602ad3c8b5afaf947248a2dc	JCB 16 digit	40.6113335945866964	-74.0253417973767966
40382	2020-07-27 15:40:22	2020-07-27	Sunshine Reichert	sunshine.reichert@geemail.com	Stamford	Connecticut	4576808781180	1a64a2addd22ffccdb559e0bcc785328	JCB 15 digit	41.0873931005016004	-73.5474138902071957
40383	2020-07-27 15:41:56	2020-07-27	Dabney Little	dabney.little@geemail.com	New York	New York	3088581034118285911	84e8ff01af1bdb955bcd3d109ff9ad25	American Express	40.5728780720606466	-73.8632600162073913
40384	2020-07-27 15:44:08	2020-07-27	Roby Kuphal	roby.kuphal@geemail.com	Grand Prairie	Texas	3088568140067334894	6d2d3d3a90d0ec6f6f4cdc1ecf0cf09d	JCB 16 digit	32.710413488750909	-96.9704770848494064
40385	2020-07-27 15:57:46	2020-07-27	Brittny Moore-Champlin	brittny.moore.champlin@geemail.com	Baltimore	Maryland	4022893635306295	91978f0393fb2712bdfdae0a7ba58371	Voyager	39.2394034501165123	-76.591121403688561
40386	2020-07-27 16:02:11	2020-07-27	Ms. Melina Nader PhD	ms.melina.nader.phd@woohoo.com	New York	New York	3337430990626130985	73008ac46f3b689dff54d0014fe1166a	VISA 16 digit	40.6991428228784358	-74.022363906855503
40387	2020-07-27 16:06:12	2020-07-27	Dayana Nienow	dayana.nienow@geemail.com	Memphis	Tennessee	3020905587281627	e5f41cd1991939e7db0dfaff9c8996d1	Voyager	35.120422081981971	-90.0731535932771834
40388	2020-07-27 16:14:34	2020-07-27	Hanna Murray	hanna.murray@geemail.com	Anchorage	Alaska	3528840823919125178	64601d3fbbc054e8491989601989a03e	Mastercard	61.169523693782466	-149.287734049431236
40389	2020-07-27 16:19:17	2020-07-27	Magan Deckow DDS	magan.deckow.dds@geemail.com	Arvada	Colorado	4649775650140	13c54fd1cee6946dc9df3ceea17f1abc	Diners Club / Carte Blanche	39.8751367248304192	-105.138627096635474
40390	2020-07-27 16:22:15	2020-07-27	Enos Stamm	enos.stamm@geemail.com	El Cajon	California	55368498435057981	d84b617d0fd0be25671da8455b62866d	JCB 15 digit	32.8361793938100277	-116.875428684260328
40391	2020-07-27 16:29:26	2020-07-27	Zoey Senger	zoey.senger@geemail.com	San Francisco	California	51622295893738447	9aa5b6e677a13fc01ab491365d1c9fc8	JCB 15 digit	37.7796965308205657	-122.438502778963112
40392	2020-07-27 16:35:22	2020-07-27	Evelyne Sauer	evelyne.sauer@geemail.com	San Francisco	California	3088824216332675780	9eda41fb6639eda404f64fefd9cccfda	Voyager	37.7653086633291579	-122.415203812594058
40393	2020-07-27 16:43:42	2020-07-27	Harrell Hand	harrell.hand@geemail.com	Berkeley	California	3096203479684348338	6530443cffe856a7e79723b16d5e9e39	VISA 13 digit	37.8921205878375744	-122.285567592072269
40394	2020-07-27 16:49:52	2020-07-27	Mr. Sylvester Koelpin I	mr.sylvester.koelpin.i@geemail.com	Montgomery	Alabama	3088595364262759765	4af777b322e14f6f0dee160d8262afd7	American Express	32.267541839687901	-86.1907864598710063
40395	2020-07-27 16:56:09	2020-07-27	Alta Donnelly	alta.donnelly@woohoo.com	Washington	District of Columbia	869974438230393541	402baccc59685f5c8c932bbdf2f4bca8	Maestro	38.9798105503231298	-77.1157760925337641
40396	2020-07-27 16:58:21	2020-07-27	Ara Stoltenberg	ara.stoltenberg@geemail.com	Lexington	Kentucky	6011929120277262832	8f7cf7f1a66a9c4d5a1c1d58ec7f7115	VISA 16 digit	38.1195270855322477	-84.4145549328897147
40397	2020-07-27 17:00:47	2020-07-27	Carter Rath	carter.rath@woohoo.com	Anaheim	California	3423076580467911	c803a9e4c9e76d67029d97a0a4cbe00e	Voyager	33.8407140195667751	-117.716731231913343
40398	2020-07-27 17:01:51	2020-07-27	Clarabelle Bauch MD	clarabelle.bauch.md@geemail.com	Tempe	Arizona	4738185592750	575e45850f79c3a8edc331d77f741574	VISA 16 digit	33.4155835702005746	-111.921053567438562
40399	2020-07-27 17:18:43	2020-07-27	Amiyah Bechtelar-Koch	amiyah.bechtelar.koch@geemail.com	San Antonio	Texas	3003167462638614	bf06ec87bd1f3617eb445047c591578d	Maestro	29.5559561779327709	-98.5006073597188987
40400	2020-07-27 17:34:07	2020-07-27	Yosef Dicki	yosef.dicki@geemail.com	Oklahoma City	Oklahoma	3729458727170075	d586f99580608d272be3b372b89173c6	American Express	35.457939427709583	-97.4167403188895378
40401	2020-07-27 17:37:52	2020-07-27	Venus Greenfelder MD	venus.greenfelder.md@warmmail.com	New York	New York	869959300324107923	cdbfdd4251e9d1432d3fde282441ef72	Voyager	40.7293827072009407	-74.0041000027570846
40402	2020-07-27 17:38:13	2020-07-27	Mercy Bergstrom	mercy.bergstrom@geemail.com	Virginia Beach	Virginia	4302265783391612	cc865f5cdfd2552912296225c4c9c848	Maestro	36.7047889951337112	-75.9590649779558191
40403	2020-07-27 17:41:08	2020-07-27	Greene Koss	greene.koss@geemail.com	Portland	Oregon	4128941507047	83c21597e2be46967f024d89ef36ac31	VISA 13 digit	45.4631224400252094	-122.640335873095324
40404	2020-07-27 17:43:23	2020-07-27	Lesli Waters DDS	lesli.waters.dds@geemail.com	Fort Worth	Texas	3041923207889587	a53d8c4de19d97ebc6145ad7a737eb93	American Express	32.8071361732259419	-97.3981311019796863
40405	2020-07-27 17:45:45	2020-07-27	Sherree Mills	sherree.mills@woohoo.com	Modesto	California	180017463544497192	7a9e01784b274caa5a0187cbfb89b613	Discover	37.6253445279784557	-120.915467074999583
40406	2020-07-27 17:56:26	2020-07-27	Kendall Boyle	kendall.boyle@geemail.com	Omaha	Nebraska	3030692231980362	7963a998fb5f97b7ff17be89417fe7b7	JCB 16 digit	41.2508301412366336	-96.1425114820361131
40407	2020-07-27 18:00:17	2020-07-27	Alger Zulauf-Vandervort	alger.zulauf.vandervort@woohoo.com	Portland	Oregon	3088499681196250695	60b85de1d648f3316b73baa5fb4234eb	VISA 16 digit	45.4627604983169604	-122.714738969970497
40408	2020-07-27 18:11:34	2020-07-27	Myrtice Bode	myrtice.bode@geemail.com	North Charleston	South Carolina	3096605716977854629	64b25a3ccec7358b75e2a07cf317d5ec	Voyager	32.9668870639216181	-80.0655077286157706
40409	2020-07-27 18:15:09	2020-07-27	Mrs. Retta Bahringer MD	mrs.retta.bahringer.md@woohoo.com	West Palm Beach	Florida	4562348211874998	ff344aed673aa3b0a2f1b01742444d24	JCB 16 digit	26.6945171177700189	-80.1988426619511188
40410	2020-07-27 18:27:12	2020-07-27	Kerry Hartmann	kerry.hartmann@geemail.com	Sandy Springs	Georgia	3158525324896280625	6efbd354694e787fe83fc05abfd5a90a	Maestro	33.9106726178489595	-84.4456952938892016
40411	2020-07-27 18:27:40	2020-07-27	Isom Auer V	isom.auer.v@geemail.com	Corona	California	52981339210267238	7e084719b76f780a9ccf2847b5a4cd6f	VISA 16 digit	33.813085059856995	-117.565542553059757
40412	2020-07-27 18:35:08	2020-07-27	Aloys Rodriguez	aloys.rodriguez@geemail.com	Reno	Nevada	4375730621005031	8eb01b43938c4fd664ddab7ac1200ae7	Diners Club / Carte Blanche	39.5085085858669132	-119.926889937294277
40413	2020-07-27 18:36:48	2020-07-27	Collins Auer	collins.auer@woohoo.com	Fresno	California	869969073325183403	1e7f730a6ab1228bfc2594f3605f149c	VISA 16 digit	36.7127663312353221	-119.713010910676431
40414	2020-07-27 18:37:33	2020-07-27	Ms. Euna Kohler	ms.euna.kohler@geemail.com	Wichita	Kansas	3112796226190638873	d20c8185c437d37bce07d3727173a11c	JCB 15 digit	37.6324631658259747	-97.3767813765179397
40415	2020-07-27 18:43:47	2020-07-27	Raven Wunsch	raven.wunsch@woohoo.com	Salem	Oregon	3337465147859365329	9304850f148af46d9ba87d734948c5c9	JCB 16 digit	44.9264806101832477	-122.928516875549036
40416	2020-07-27 18:55:13	2020-07-27	Metro Erdman-Crist	metro.erdman.crist@warmmail.com	San Francisco	California	3096691310053217938	d6d40fd76204f5d5972d96013e382c6f	American Express	37.8120199569023399	-122.438341005190026
40417	2020-07-27 18:56:17	2020-07-27	Mrs. Eboni Carroll	mrs.eboni.carroll@geemail.com	San Diego	California	4273629501111054	d87cff7ce8a344edb3aadbe5f2b69bcc	VISA 16 digit	32.8597717626087373	-117.185932490406557
40418	2020-07-27 18:59:06	2020-07-27	Bethann Hegmann-Schiller	bethann.hegmann.schiller@geemail.com	Daly City	California	4665633666172808	85248c1da9cffa6ce1f276f90636a67e	JCB 15 digit	37.7602540461268248	-122.51052256288007
40419	2020-07-27 19:10:48	2020-07-27	Almond Bogan	almond.bogan@geemail.com	Louisville	Kentucky	4670217056677312	99c0f55c480e88847ffc37429813c44d	Maestro	38.0921084009479713	-85.737363165437813
40420	2020-07-27 19:19:26	2020-07-27	Miss Talia Reichert MD	miss.talia.reichert.md@geemail.com	Little Rock	Arkansas	4448363310518	7af44f282dac306b6f8a001042065279	Maestro	34.7174649956911807	-92.4208418310027469
40421	2020-07-27 19:22:42	2020-07-27	Dr. Winter Ledner	dr.winter.ledner@warmmail.com	Jacksonville	Florida	3016535920712014	8b6dd625e0240510be66a0614129ff3c	Maestro	30.3650068209558732	-81.5799811188209816
40422	2020-07-27 19:22:57	2020-07-27	Loretto Turner-Murazik	loretto.turner.murazik@warmmail.com	Dallas	Texas	4312352022403	f4edab77ddc9dd1057797be4c9defa39	VISA 16 digit	32.8710969105169184	-96.8047073966786229
40423	2020-07-27 19:29:37	2020-07-27	Debra Howe	debra.howe@geemail.com	Glendale	California	6011080531132482073	2d3ddb3aac49c1f55189b481a5b7c732	Maestro	34.1801399137113222	-118.146901270969963
40424	2020-07-27 19:43:24	2020-07-27	Lee Halvorson	lee.halvorson@geemail.com	Kent	Washington	869939604603636287	9a0e74a8f76638aa95f5a442d30daf03	Discover	47.4866887677106959	-122.223491704850275
40425	2020-07-27 19:43:48	2020-07-27	Adonis Mante Jr.	adonis.mante.jr.@geemail.com	Orange	California	210017680842207672	da59dc10c7ee10a9ddf3a3b6cfff7621	JCB 16 digit	33.851916357491163	-117.821313250540939
40426	2020-07-27 19:44:00	2020-07-27	Maegan Rath	maegan.rath@geemail.com	Anchorage	Alaska	3096962513362861815	96b504b6aaad01b4c4e38e3f2ceb718a	American Express	61.2638384619943821	-149.338592129864907
40427	2020-07-27 19:48:52	2020-07-27	Carlyn Greenfelder	carlyn.greenfelder@geemail.com	Charlotte	North Carolina	4880908112829	b38b116f12c8c51be25ef4f57d0d730f	JCB 16 digit	35.2598487797446509	-80.893155637564135
40428	2020-07-27 19:49:17	2020-07-27	Miss Patty Runolfsson PhD	miss.patty.runolfsson.phd@woohoo.com	Independence	Missouri	4192282008387	e0ca28eb53e61019e810f0ebf478f821	Diners Club / Carte Blanche	39.0896269921232076	-94.4030307503700215
40429	2020-07-27 19:54:00	2020-07-27	Jens Kohler	jens.kohler@geemail.com	San Antonio	Texas	6011589837156243424	dc138694004e0303abf8433461b9ff62	American Express	29.5545530199144046	-98.6207442889291741
40430	2020-07-27 19:54:14	2020-07-27	Staci Jenkins-Sanford	staci.jenkins.sanford@geemail.com	Chicago	Illinois	6011626218076563388	016c7f2932aa942c366ee5d989805cf8	Mastercard	41.7684932628016909	-87.7309959804203316
40431	2020-07-27 20:04:08	2020-07-27	Waverly Brakus	waverly.brakus@geemail.com	Des Moines	Iowa	869933532682407849	a36442e36937799235313208ae662830	JCB 16 digit	41.6157408106349394	-93.677222646032277
40432	2020-07-27 20:14:03	2020-07-27	Robin Quitzon	robin.quitzon@geemail.com	Aurora	Colorado	3713528544255438	a9f81523c8fb99cca10954945acedb2d	Maestro	39.6339892078768514	-104.720741193753483
40433	2020-07-27 20:19:57	2020-07-27	Zelda Bernhard DDS	zelda.bernhard.dds@geemail.com	Washington	District of Columbia	3096988455167893579	d0820e232bc43b01e1a58b135e509e4e	Maestro	38.8431296316239951	-77.0911344584289964
40434	2020-07-27 20:31:00	2020-07-27	Ollie Prohaska-Schowalter	ollie.prohaska.schowalter@geemail.com	Los Angeles	California	3410960564873472	afdf7d23fd2bd3f3b8b9c862fce52155	Mastercard	33.9403795918315652	-118.476662966002891
40435	2020-07-27 20:33:40	2020-07-27	Giovanny Beer	giovanny.beer@woohoo.com	San Francisco	California	3796959751646771	03967f9e915ef5b95bc9d4156552ac83	American Express	37.7726477719636122	-122.407845309812174
40436	2020-07-27 20:39:29	2020-07-27	Lyla Padberg	lyla.padberg@geemail.com	San Diego	California	501896973339912	cc69024edc405cd8c65243e44dc00bbd	Mastercard	32.8526525464441619	-117.20704394149594
40437	2020-07-27 20:48:45	2020-07-27	Aric Pacocha	aric.pacocha@warmmail.com	Clarksville	Tennessee	4478879022222996	f390fc938adee1fa4b94ddfa0998a808	Maestro	36.6290941129565226	-87.4249007590532301
40438	2020-07-27 20:55:37	2020-07-27	Ms. Ilda Ebert DDS	ms.ilda.ebert.dds@geemail.com	San Antonio	Texas	869945065286401591	4b273d1569ff4e649ad3536b4920396d	Discover	29.5507137402031574	-98.5193259845789413
40439	2020-07-27 20:58:54	2020-07-27	Wilmer Yost	wilmer.yost@geemail.com	St. Louis	Missouri	869962669420437367	a43ff4f2dbfe78bc07e625297cb818af	JCB 16 digit	38.732775856011358	-90.2945801880214418
40440	2020-07-27 21:05:04	2020-07-27	Mrs. Jana Fay DDS	mrs.jana.fay.dds@woohoo.com	Houston	Texas	180088963572190050	cf4f9593dca6a0ff164a04806ff71f8d	VISA 13 digit	29.8072257782876484	-95.3651865851614673
40441	2020-07-27 21:06:40	2020-07-27	Talmage Olson-Fisher	talmage.olson.fisher@geemail.com	Bakersfield	California	4154361383461	a06d18737b6414513ebcfd862ef4f15c	Maestro	35.3329422384675595	-119.007653911951181
40442	2020-07-27 21:06:42	2020-07-27	Berkley Windler	berkley.windler@woohoo.com	Portland	Oregon	3096535539068444901	f9a9faa204f94d0dcc654e489728a10f	Discover	45.5167830913215852	-122.740985749941331
40443	2020-07-27 21:13:20	2020-07-27	Mr. Loyal Bailey	mr.loyal.bailey@geemail.com	Virginia Beach	Virginia	3096069896354939224	655418121ffe8aca24e4a9dd94af23d8	American Express	36.7458314235042778	-76.1198035276167104
40444	2020-07-27 21:16:04	2020-07-27	Dr. Del Connelly	dr.del.connelly@geemail.com	Chicago	Illinois	869906172936664037	b1ebb96b27fd68de52376ffe3307a242	VISA 13 digit	41.8602064613088984	-87.6605108573131275
40445	2020-07-27 21:18:28	2020-07-27	Almer Krajcik	almer.krajcik@geemail.com	Rockford	Illinois	4853018269533428	b3846f837f56729b42aac94da49fe0d2	JCB 16 digit	42.2487808002635816	-89.1505075882937774
40446	2020-07-27 21:31:12	2020-07-27	Deborah Goodwin	deborah.goodwin@geemail.com	New York	New York	3158239520153136445	31ce8e2304a91063eb9c1d10ffb06d39	VISA 16 digit	40.7476119717340879	-73.9120964251819998
40447	2020-07-27 21:35:01	2020-07-27	Philo Hartmann III	philo.hartmann.iii@geemail.com	Omaha	Nebraska	4999075989643	446723bfd501c817e4bfc91e1bc0bdf8	Diners Club / Carte Blanche	41.3118465466570157	-96.0307400304008354
40448	2020-07-27 21:35:30	2020-07-27	Hazen Mueller	hazen.mueller@geemail.com	Atlanta	Georgia	676150036303332	a990bee569ebe834aea638ebfd043471	Maestro	33.7751192934621116	-84.5172994877722203
40449	2020-07-27 21:54:24	2020-07-27	Kelton Zboncak	kelton.zboncak@geemail.com	Boston	Massachusetts	3736043775296211	7a604493c210f448a84e8b8e9429a432	VISA 16 digit	42.3825754220299444	-71.0500733838368177
40450	2020-07-27 21:55:16	2020-07-27	Rochelle Stamm	rochelle.stamm@woohoo.com	San Francisco	California	4304049507268	f08c0d7589cc2ee785c3ef21b3ad9dfd	Mastercard	37.7625284960128411	-122.4178754313089
40451	2020-07-27 22:09:08	2020-07-27	Jill Weissnat	jill.weissnat@warmmail.com	Lakeland	Florida	3728447421174542	5f0fa030a263438cea297ea67d615d93	Diners Club / Carte Blanche	28.0396893795877666	-82.0308244604501766
40452	2020-07-27 22:09:58	2020-07-27	Mr. Scottie Will II	mr.scottie.will.ii@woohoo.com	Wilmington	North Carolina	6011003971962911565	7671fb7b48eca94933b7b55387a4bb60	VISA 16 digit	34.2802564982146052	-77.7948302955824857
40453	2020-07-27 22:14:03	2020-07-27	Omar Kohler	omar.kohler@geemail.com	San Francisco	California	4765295140028664	c36ae65744b6580aa4b24be3b10c9a87	Voyager	37.7721625835235599	-122.398583556394129
40454	2020-07-27 22:19:00	2020-07-27	Mr. Bertrand Kuhn MD	mr.bertrand.kuhn.md@woohoo.com	San Antonio	Texas	869922399148037831	560afa55e7565ddb650ee282e5437847	JCB 16 digit	29.5427914629761119	-98.560728087446094
40455	2020-07-27 22:21:15	2020-07-27	Jodie Emmerich MD	jodie.emmerich.md@geemail.com	Laredo	Texas	210093793848450431	58ef9d6d205091a9400e4cfbc22a2ad1	JCB 15 digit	27.5967444044720409	-99.4484860233504264
40456	2020-07-27 22:21:56	2020-07-27	Dr. Alfonso Jacobson I	dr.alfonso.jacobson.i@woohoo.com	El Paso	Texas	869912351483535517	f166b43d82810fa102d2c94e3acc0a13	Voyager	31.9128118735101083	-106.431368383716801
40457	2020-07-27 22:23:03	2020-07-27	Beecher Abshire III	beecher.abshire.iii@geemail.com	Colorado Springs	Colorado	3764218999870828	6ac70da9a81fa7d02014aa8efa163304	JCB 15 digit	38.7758635389201345	-104.746282686401898
40458	2020-07-27 22:23:55	2020-07-27	Emely O'Conner	emely.o'conner@warmmail.com	St. Louis	Missouri	4071110546296469	a5e3762079a3f5bf98a32f08ee472902	Maestro	38.6817124246776132	-90.1507712986324066
40459	2020-07-27 22:31:35	2020-07-27	Orange Herzog	orange.herzog@geemail.com	San Francisco	California	210043565448231812	0a419e8a52594678eb82716c36c14304	American Express	37.7742700427762088	-122.453979649639138
40460	2020-07-27 22:34:27	2020-07-27	Sanders Gislason	sanders.gislason@geemail.com	Columbus	Ohio	4281101824676	6675bf0feb31d95f53c9953f4158216d	JCB 16 digit	39.9471779316242745	-82.9566129382934463
40461	2020-07-27 22:46:45	2020-07-27	Dr. Suzette Russel	dr.suzette.russel@woohoo.com	Huntington Beach	California	4696551315008772	a4c49085161eea2d91ca7add5d83b201	Discover	33.6176047971978846	-117.96777010873258
40462	2020-07-27 23:13:55	2020-07-27	Jacqulyn Larkin-Schumm	jacqulyn.larkin.schumm@geemail.com	Palmdale	California	869984736069378618	5459ca82492f06d92c64ae5a96ba7a7f	American Express	34.6539659947939214	-118.101156840752438
40463	2020-07-27 23:15:36	2020-07-27	Mariana Kirlin	mariana.kirlin@geemail.com	Baton Rouge	Louisiana	6011203058624779909	ccf3ca441639c3727d55f536220f47c2	VISA 16 digit	30.412477442922814	-91.1711743687853158
40464	2020-07-27 23:18:34	2020-07-27	Elva Kassulke DVM	elva.kassulke.dvm@geemail.com	Columbus	Ohio	4645325283090324	d475c0cc652fc15100ac0ebb89cd70c8	JCB 16 digit	40.0769611940763895	-83.0347543271027604
40465	2020-07-27 23:40:49	2020-07-27	Theadore Shields	theadore.shields@warmmail.com	Phoenix	Arizona	3792323430312657	a78d9c8afee34a9792e6e4ac7a43eb93	JCB 16 digit	33.5601207947757132	-112.158637134770316
40466	2020-07-27 23:44:57	2020-07-27	Wilfred Hackett-Olson	wilfred.hackett.olson@warmmail.com	New York	New York	180027643288725373	1e4d39451fadbd45c4cf79978e2dcdf3	JCB 16 digit	40.7128145392276366	-73.8458194883435937
40467	2020-07-27 23:58:50	2020-07-27	Leslie Koelpin	leslie.koelpin@geemail.com	Pompano Beach	Florida	3787242241385313	efe1fa6a0ffee09f9c68ad64ad794f4a	Discover	26.1706855793282358	-80.1124592467524081
40468	2020-07-28 00:00:52	2020-07-28	Darcie Lakin	darcie.lakin@geemail.com	Berkeley	California	3158631323804339094	c6b57e8fbc44aa4f5a7cd2d9b74e3ed8	Voyager	37.8732825019671253	-122.290634343100976
40469	2020-07-28 00:06:07	2020-07-28	Dr. Bernie Gerhold	dr.bernie.gerhold@geemail.com	Dallas	Texas	4446156460411517	dc2ad98a5d83d230e23c0ec3ced98f81	Voyager	32.753435926771914	-96.7496548126414382
40470	2020-07-28 00:11:15	2020-07-28	Dr. Casie Wintheiser DVM	dr.casie.wintheiser.dvm@geemail.com	Phoenix	Arizona	52918164670197032	509290bbd5dca11849418ada29030915	VISA 16 digit	33.5235400051742829	-112.15310828657114
40471	2020-07-28 00:11:55	2020-07-28	Parlee Casper	parlee.casper@geemail.com	Indianapolis	Indiana	3446676650763728	240f36ff2363b0b1d18ded406571b135	Voyager	39.8484135258484642	-86.1746473921198373
40472	2020-07-28 00:22:24	2020-07-28	Virginia Kiehn-Franecki	virginia.kiehn.franecki@warmmail.com	Garland	Texas	3022442586466551	0efabff4f94e8494d69ba662d5641621	Maestro	32.9127930505901531	-96.6479153821405106
40473	2020-07-28 00:24:04	2020-07-28	Ruthann Lehner	ruthann.lehner@geemail.com	Sunnyvale	California	6011657090742758490	59b9db63710e9cd9339171da266927c4	VISA 16 digit	37.356332247144735	-121.956832960034916
40474	2020-07-28 00:24:17	2020-07-28	Alexys Mosciski	alexys.mosciski@geemail.com	Berkeley	California	4465416215833	b72a876f52dc0df691e5779351c3d217	VISA 16 digit	37.829144179570946	-122.321708403177595
40475	2020-07-28 00:32:19	2020-07-28	Zeta Lueilwitz-Murray	zeta.lueilwitz.murray@warmmail.com	St. Louis	Missouri	3158349352465457252	c000928340d113110e6aa0363ac54ae7	Voyager	38.7138090948265017	-90.285135445977005
40476	2020-07-28 00:39:10	2020-07-28	Dr. Roel Jerde Jr.	dr.roel.jerde.jr.@geemail.com	Houston	Texas	639049473447495	ff8298da145ecd7fa8dfa8c2619d0fba	VISA 16 digit	29.8279887592498199	-95.4361018921263593
40477	2020-07-28 00:40:26	2020-07-28	Dr. Izaiah Kessler DDS	dr.izaiah.kessler.dds@geemail.com	Bellevue	Washington	210031599135186165	a810f1a3534dff610e0fdec3ec3752bd	JCB 16 digit	47.6282018427453977	-122.066366847423836
40478	2020-07-28 00:57:47	2020-07-28	Glinda Kertzmann	glinda.kertzmann@geemail.com	Milwaukee	Wisconsin	4028198446958	3dadd2e52ff62a5571a6a77e266675ca	JCB 16 digit	43.0408649814866493	-88.0126758711513162
40479	2020-07-28 01:10:32	2020-07-28	Mariana Ullrich	mariana.ullrich@woohoo.com	Memphis	Tennessee	55159003098256699	be4a161870fe635080b86ba38b2b7fbb	JCB 16 digit	35.1385665904797619	-90.037090422564745
40480	2020-07-28 01:12:15	2020-07-28	Davion Conroy	davion.conroy@geemail.com	Berkeley	California	4143969990311379	4d720b813c7a63a9937865c5d234be48	JCB 16 digit	37.882359646047945	-122.262662664872636
40481	2020-07-28 01:26:06	2020-07-28	Mrs. Bridget Goyette	mrs.bridget.goyette@geemail.com	Winston–Salem	North Carolina	4333631101901932	bb5f520c1f84255336fd64ccdc96975e	Maestro	36.0147027431286872	-80.200421086804937
40482	2020-07-28 01:33:53	2020-07-28	Miss Anissa Kuhn DDS	miss.anissa.kuhn.dds@geemail.com	Boston	Massachusetts	3037074282305695	4afb5203f38bd09ee9281421d92df9bc	American Express	42.2773497462905965	-70.9581064938519148
40483	2020-07-28 01:48:53	2020-07-28	Debbra Stokes	debbra.stokes@woohoo.com	Fort Wayne	Indiana	4101501751064325	a0a73ee45a8325814207130e9c7b9d29	JCB 15 digit	41.0555534721136084	-85.0980386138647873
40484	2020-07-28 01:58:42	2020-07-28	Renada Toy	renada.toy@geemail.com	Charleston	South Carolina	869963370013327656	5cdcc813c319e2772f52a7c09a7bd7dc	VISA 13 digit	32.8367648366369309	-79.9079750336390049
40485	2020-07-28 02:05:43	2020-07-28	Jakob Little	jakob.little@geemail.com	Dallas	Texas	589376591127089	2dc8ba40aa8eff23c814e854ab612ee7	Discover	32.717385931852462	-96.8419142988473141
40486	2020-07-28 02:07:29	2020-07-28	Dr. Soren Bogan	dr.soren.bogan@geemail.com	Boston	Massachusetts	3050148003793517	2f5e381709d7b562554d423072d54e2e	Voyager	42.4281033772677176	-70.9458974915508236
40487	2020-07-28 02:13:57	2020-07-28	Jazmine Bergstrom	jazmine.bergstrom@geemail.com	San Francisco	California	3037788325044397	77e7dbaabb315368aa2183c7e1ca140a	VISA 13 digit	37.7775492536444162	-122.461867984178369
40488	2020-07-28 02:20:20	2020-07-28	Issac Altenwerth	issac.altenwerth@geemail.com	Warren	Michigan	3112344743329048037	af795d1d569d4c8ba21b11ae82e56b5d	Discover	42.4024192568376677	-82.9589086210355191
40489	2020-07-28 02:25:10	2020-07-28	Eleanore Larson PhD	eleanore.larson.phd@warmmail.com	Indianapolis	Indiana	4198212673635135	86abfba3f9d4b5ab2f716928d3f1f0b3	Discover	39.8615258797544953	-86.2406103886399364
40490	2020-07-28 02:39:03	2020-07-28	Willia Goyette-Beatty	willia.goyette.beatty@geemail.com	Los Angeles	California	6011343814801759028	513035b3bb049394c967f2ae2a0b1f65	Voyager	33.9590999027579983	-118.414462320924912
40491	2020-07-28 02:43:15	2020-07-28	Ms. Clem Hayes DDS	ms.clem.hayes.dds@woohoo.com	El Monte	California	55768652037577335	2357e5e9eedbb67509e1233c59312de6	JCB 16 digit	34.1200645389690962	-118.031673944069439
40492	2020-07-28 02:46:43	2020-07-28	Sena Homenick	sena.homenick@geemail.com	Sacramento	California	3528161086584821247	e78575c3e140b9f09167510d3d63afdc	VISA 13 digit	38.6406639114752437	-121.432374483883748
40493	2020-07-28 03:03:23	2020-07-28	Lorene Brakus	lorene.brakus@geemail.com	Oakland	California	503829140102889	57ccf078a532b1a8f128728823c97cde	Voyager	37.7727265971103776	-122.295359982102809
40494	2020-07-28 03:06:42	2020-07-28	Miss Rella Boyer MD	miss.rella.boyer.md@warmmail.com	Naperville	Illinois	3088549756520925665	6c9c2c7e3bbfc059888c19ef2a5914a1	Mastercard	41.7696966737888786	-88.1027223260030183
40495	2020-07-28 03:11:13	2020-07-28	Jessi Watsica	jessi.watsica@geemail.com	Daly City	California	869908191649027512	cd39499b25d8ad77afa59d2f64b75c28	JCB 16 digit	37.783265103578195	-122.46284215763211
40496	2020-07-28 03:15:11	2020-07-28	Dr. Reese Bashirian	dr.reese.bashirian@geemail.com	Chicago	Illinois	3096101728296649902	45cc32e463e6f43775ce1daed38ec1d8	VISA 16 digit	41.8135753176942515	-87.5985620574124084
40497	2020-07-28 03:16:31	2020-07-28	Tavaris Jacobi	tavaris.jacobi@geemail.com	Durham	North Carolina	869900856827597779	87df77a7004315f227b94f082106e111	Voyager	36.0487936723757514	-78.8829442396197464
40498	2020-07-28 03:26:13	2020-07-28	Yuridia Konopelski-Fay	yuridia.konopelski.fay@woohoo.com	Houston	Texas	180007740618842896	7b89b1b273429f64cf26863a950b7627	VISA 16 digit	29.7817607457362108	-95.304514426041024
40499	2020-07-28 03:29:54	2020-07-28	Dr. Akeelah Bartell	dr.akeelah.bartell@geemail.com	Oakland	California	3337762939300179253	8041967b248cf912c724e4d4b13b644a	American Express	37.8019466786251499	-122.286068353225559
40500	2020-07-28 03:35:52	2020-07-28	Curtiss Rath III	curtiss.rath.iii@warmmail.com	Phoenix	Arizona	4112579756082390	ad236c8ba032d1b4a53c9452bda115e3	Maestro	33.5724421726938331	-112.080036884958304
40501	2020-07-28 03:39:29	2020-07-28	Mr. Donta Kshlerin Jr.	mr.donta.kshlerin.jr.@woohoo.com	Greensboro	North Carolina	51404505068030154	ed587a81e894e7363994ba81e86d12c9	American Express	36.0101282785762109	-79.8131991388723208
40502	2020-07-28 03:45:44	2020-07-28	Skyler Hartmann	skyler.hartmann@geemail.com	Wichita	Kansas	4987647011807083	0b7571ab0f70d74e9e872b26c345271b	JCB 16 digit	37.6218298018787038	-97.310229392369834
40503	2020-07-28 04:00:39	2020-07-28	Evon Lynch	evon.lynch@geemail.com	Indianapolis	Indiana	3058985929805541	33432fc8c57e2b848a073cd480d54f4e	Voyager	39.8272889918189463	-86.1415373554188761
40504	2020-07-28 04:03:10	2020-07-28	Norval Parisian	norval.parisian@geemail.com	Miami	Florida	3029259934215917	91a5a8493c04551989bfbc49e3e93360	Voyager	25.698055051374066	-80.2605118376541924
40505	2020-07-28 04:03:49	2020-07-28	Mrs. Debi Considine	mrs.debi.considine@geemail.com	West Jordan	Utah	6011896738185712447	e37131e264966191790dadc9e83c1655	VISA 13 digit	40.6512467289134918	-111.947970560434456
40506	2020-07-28 04:05:26	2020-07-28	Demarco Johnson-Metz	demarco.johnson.metz@warmmail.com	Raleigh	North Carolina	3022773056287279	1f3605e01546e59a0c9533ee49911393	JCB 16 digit	35.8615713366441398	-78.6753163613315678
40507	2020-07-28 04:33:27	2020-07-28	Dr. Boston Flatley II	dr.boston.flatley.ii@geemail.com	Phoenix	Arizona	180081064746768124	8d5fabac42c1c6e4f26bda9900cb2097	Maestro	33.6091117540307351	-112.134129114628223
40508	2020-07-28 04:37:55	2020-07-28	Lilly Bartell-Torp	lilly.bartell.torp@warmmail.com	Kent	Washington	4425575919735223	ef54355818685fc2f01db677c52a0245	JCB 15 digit	47.3775058150403154	-122.12258945472054
40509	2020-07-28 04:54:27	2020-07-28	Windell Lueilwitz-Beatty	windell.lueilwitz.beatty@warmmail.com	Sioux Falls	South Dakota	869930486562900428	6522cd7ffa2b0a2fdd18e743d81eb9d5	American Express	43.4584463003642867	-96.687426330119365
40510	2020-07-28 04:54:39	2020-07-28	Nakia Deckow DDS	nakia.deckow.dds@geemail.com	Baltimore	Maryland	4886787376988177	16909e9cb97e19b3f6d45547c7d9f12f	Discover	39.2469130080658886	-76.5730228350982145
40511	2020-07-28 04:57:52	2020-07-28	Risa Kulas	risa.kulas@geemail.com	Aurora	Colorado	3528244007386642889	4ecdbf925f91cf03a11b68f378474fa5	American Express	39.7635153396632575	-104.773564910295235
40512	2020-07-28 05:19:59	2020-07-28	Olivine Paucek-Weissnat	olivine.paucek.weissnat@geemail.com	Houston	Texas	869990584420308607	785059ba11f48829839cc30298a3aba7	JCB 16 digit	29.8353966085784137	-95.3414209088325464
40513	2020-07-28 05:28:20	2020-07-28	Desi Oberbrunner IV	desi.oberbrunner.iv@geemail.com	San Diego	California	4064313019975861	b69a13f136df23bfece2ba14e9ea9ac2	Mastercard	32.7537525047615148	-117.143179076807584
40514	2020-07-28 05:30:39	2020-07-28	Shelley Olson-Witting	shelley.olson.witting@geemail.com	Denver	Colorado	3004220195418447	ee8bc1fd64c156da7f3f5e19c033336a	Discover	39.8172865449968683	-104.936791867042331
40515	2020-07-28 05:34:09	2020-07-28	January Smitham	january.smitham@warmmail.com	Fort Lauderdale	Florida	55462372791523255	58deae165055758225db2b71f9706d71	JCB 16 digit	26.0476814570825574	-80.2362561428740548
40516	2020-07-28 05:34:41	2020-07-28	Seamus Skiles DVM	seamus.skiles.dvm@woohoo.com	Miami	Florida	4673941278562427	66abc53a94d6f5956df7d6c703e20deb	JCB 16 digit	25.8605562223259362	-80.280424397798626
40517	2020-07-28 05:36:49	2020-07-28	Willow Wintheiser	willow.wintheiser@geemail.com	Los Angeles	California	6011909832824094567	3eb0e9988054ea1651f2cbc75f5f948d	Diners Club / Carte Blanche	34.0658293329045136	-118.489695553760228
40518	2020-07-28 05:43:18	2020-07-28	Lum Frami	lum.frami@geemail.com	Oakland	California	210050462896144418	3acf0e99808219207bdddf8fbb8ed468	JCB 15 digit	37.8459732287530457	-122.263401952334362
40519	2020-07-28 05:45:42	2020-07-28	Cherrelle Koss	cherrelle.koss@warmmail.com	Seattle	Washington	3768466674400561	428191d2e70bfda07ccc5098db86c847	Maestro	47.5276223511360598	-122.319184684186794
40520	2020-07-28 05:53:03	2020-07-28	Dr. Christiana Pollich	dr.christiana.pollich@geemail.com	Los Angeles	California	4000951344307750	62c7ea0ef3db3734bbcc8bade065c61e	Mastercard	34.0171127749007169	-118.329074449743331
40521	2020-07-28 05:53:44	2020-07-28	Loula Yost	loula.yost@geemail.com	Rialto	California	3337910485339407480	34c4ef5b5dab3b88ff64abc391f4b701	JCB 16 digit	34.0723644603259856	-117.362090352977816
40522	2020-07-28 05:54:13	2020-07-28	Miss Kellee Buckridge DDS	miss.kellee.buckridge.dds@geemail.com	Clearwater	Florida	3465879628104092	817a760baa94e60b5dc27fc0f3c0f0a0	Mastercard	27.9634658286474647	-82.8237309562772452
40523	2020-07-28 05:58:36	2020-07-28	Keaton Hessel	keaton.hessel@warmmail.com	New York	New York	4245144442749199	896b5eb0656e618b1db3b96e6a06fac0	VISA 16 digit	40.6901364703420541	-73.880103813706711
40524	2020-07-28 06:07:08	2020-07-28	Wilhelmine Robel	wilhelmine.robel@geemail.com	Dallas	Texas	4458672784626	5e7d40459fec684e4f34dcb24c6fa0de	VISA 16 digit	32.7909051648147454	-96.8310533910486839
40525	2020-07-28 06:12:18	2020-07-28	Miss Larae Lakin PhD	miss.larae.lakin.phd@geemail.com	San Francisco	California	6011548941531531964	f6bb140ca539e8e9aae8b1b726c50437	VISA 16 digit	37.7773414704137025	-122.43359120239208
40526	2020-07-28 06:18:36	2020-07-28	Grayce Sanford	grayce.sanford@geemail.com	Milwaukee	Wisconsin	4148795390276903	2c8baba6c2a456dbfc8acd18981e9c60	VISA 13 digit	43.0875162305861679	-87.9030430511206475
40527	2020-07-28 06:22:26	2020-07-28	Wally Balistreri I	wally.balistreri.i@geemail.com	Berkeley	California	3158824545307590198	003ec045a286584a388fb16853db773a	VISA 16 digit	37.8242151009038921	-122.273837416125446
40528	2020-07-28 06:42:31	2020-07-28	Nan Murphy DVM	nan.murphy.dvm@woohoo.com	Montgomery	Alabama	3528948022910728749	51c224c2f386292b91fc6723267c32f9	VISA 16 digit	32.2668888457983769	-86.2400211911335504
40529	2020-07-28 06:44:18	2020-07-28	Mr. Andre McLaughlin	mr.andre.mclaughlin@geemail.com	Aurora	Colorado	53541145282482651	3e2c75d61ecdb5f1e872c241a310374b	Voyager	39.6355481689907663	-104.615994976286586
40530	2020-07-28 06:49:31	2020-07-28	Kiley Heidenreich	kiley.heidenreich@woohoo.com	Dallas	Texas	869995835237769810	76c1756042ea81206bc72637d7def07c	American Express	32.8849337651200599	-96.7645627123732055
40531	2020-07-28 06:51:05	2020-07-28	Mr. Elzie Runte IV	mr.elzie.runte.iv@warmmail.com	Little Rock	Arkansas	3754237443290682	7cbfa5ed3bdc60318f75bb30a854fceb	Maestro	34.6998652975816313	-92.3104578837625667
40532	2020-07-28 06:51:35	2020-07-28	Yolanda Bosco PhD	yolanda.bosco.phd@warmmail.com	Las Vegas	Nevada	3112601354261845162	59016a754c1f307d1bad1af005d4be6f	JCB 16 digit	36.3275178974129247	-115.196440839462355
40533	2020-07-28 06:54:17	2020-07-28	Zaniyah Larson	zaniyah.larson@geemail.com	Philadelphia	Pennsylvania	639032912797134	5137b77c630dafc67c7f238229d267ef	JCB 15 digit	40.0540565254125767	-75.1186011442348445
40534	2020-07-28 06:56:07	2020-07-28	Mrs. Dionne Runolfsson PhD	mrs.dionne.runolfsson.phd@geemail.com	Jersey City	New Jersey	3112392997321893508	522780952ee394fa79f51a5856b279fc	Diners Club / Carte Blanche	40.8042208866622289	-74.1296017468396684
40535	2020-07-28 07:02:21	2020-07-28	Bev Kilback	bev.kilback@warmmail.com	Minneapolis	Minnesota	3158505783415187922	f5690308735de63e259345da114f2336	American Express	45.0252884619954941	-93.2979344092581329
40536	2020-07-28 07:03:36	2020-07-28	Zariah Borer	zariah.borer@geemail.com	New York	New York	6011288810694008124	121fad33a4ff428fc3d06d6e04af62d2	American Express	40.6566020169518865	-73.9127743179339944
40537	2020-07-28 07:34:46	2020-07-28	Nathan Fisher	nathan.fisher@geemail.com	Tempe	Arizona	869939404815408397	7d5387c13fc51ba91968d360fa41a458	Maestro	33.2962026839531902	-111.850451604000469
40538	2020-07-28 07:37:52	2020-07-28	Ulysses Heathcote-Pollich	ulysses.heathcote.pollich@geemail.com	Scottsdale	Arizona	4176451016961032	8634e5d2fed47721f1a70d2712cbdfba	VISA 16 digit	33.6217819083604965	-111.910881550513579
40539	2020-07-28 07:38:16	2020-07-28	Haylee Langosh	haylee.langosh@geemail.com	Oakland	California	55022009761308779	f48da4dd0289eb4bb1025179034681b7	JCB 16 digit	37.800103583596659	-122.299628814634602
40540	2020-07-28 07:39:16	2020-07-28	Anjali Reichel	anjali.reichel@woohoo.com	San Francisco	California	676231083705066	06f2e8cdbce7fdcf11d82847d0a3bbbb	JCB 16 digit	37.7770628550213274	-122.422658116804115
40541	2020-07-28 07:41:43	2020-07-28	Burdette Koch	burdette.koch@geemail.com	Escondido	California	3740791834634384	cc6e55a5274ceabb58dc33f1a244c2b0	Voyager	33.0529593003209641	-117.021774622822178
40542	2020-07-28 07:47:25	2020-07-28	Jovani Schmeler	jovani.schmeler@warmmail.com	Saint Paul	Minnesota	869960163280117048	524ac6a54c0d3d5b8904a55f8ad090c8	Maestro	44.9226615938764056	-93.0149688202686633
40543	2020-07-28 07:49:56	2020-07-28	Suzanne Becker DDS	suzanne.becker.dds@geemail.com	Bakersfield	California	3434805364372385	da5872cffabe4415cd30fdf4541eec6e	Diners Club / Carte Blanche	35.2603075432300557	-119.091589580084374
40544	2020-07-28 07:52:11	2020-07-28	Dr. Hyman Bartell	dr.hyman.bartell@geemail.com	Lubbock	Texas	675900655647493	d01716d284552c9d7c894c5658141001	JCB 15 digit	33.4898347366642213	-101.851097630281757
40545	2020-07-28 07:56:53	2020-07-28	Shanae Raynor DVM	shanae.raynor.dvm@geemail.com	Columbus	Ohio	869908542970700335	c1783de5234ab4700d84c149749d80f0	VISA 13 digit	40.0756837419744585	-83.0338910929162068
40546	2020-07-28 07:58:13	2020-07-28	Darlyne Nader	darlyne.nader@geemail.com	Los Angeles	California	3401803101115455	ebef4f6a7c942afbb98cbdbd2a091aa7	VISA 16 digit	34.0647307100571695	-118.42170671340935
40547	2020-07-28 08:01:53	2020-07-28	Louisiana Rutherford	louisiana.rutherford@warmmail.com	Los Angeles	California	869920637707109786	b4d084600d20b527881a8676f0cd2c83	VISA 16 digit	33.9747681180346746	-118.337786706256864
40548	2020-07-28 08:07:40	2020-07-28	Omari Dickens	omari.dickens@warmmail.com	Thornton	Colorado	3528705270580723713	a9e7f220ca555c3baa9831b46494fd90	JCB 16 digit	39.8986368453927369	-105.030005188907694
40549	2020-07-28 08:16:20	2020-07-28	Mills Reynolds-McLaughlin	mills.reynolds.mclaughlin@geemail.com	Dallas	Texas	4763360658150	3585c5fd96da3da70fdaa99cecc46e8e	Maestro	32.801912044062469	-96.8545153461825095
40550	2020-07-28 08:22:31	2020-07-28	Jaquan Renner	jaquan.renner@geemail.com	Los Angeles	California	501893707781659	1b798c6abb111f911dff51173699033c	VISA 13 digit	34.0131976284883919	-118.355136547423143
40551	2020-07-28 08:23:10	2020-07-28	Doretha Corkery	doretha.corkery@warmmail.com	San Antonio	Texas	3425274670694464	694808827243602b23cf42325d551082	VISA 16 digit	29.5448709649104622	-98.4547274698804955
40552	2020-07-28 08:27:58	2020-07-28	Dr. Shirlee Stroman	dr.shirlee.stroman@warmmail.com	Tulsa	Oklahoma	503829539775998	7b682db67ec42f05d4870e7ebdb8d9cc	JCB 15 digit	36.0862334126509694	-95.9009931485123843
40553	2020-07-28 08:29:51	2020-07-28	Dr. Evelyn Fadel	dr.evelyn.fadel@geemail.com	Buffalo	New York	4394083180710428	3b4602473a7d873143c8e72dde7e61ca	American Express	42.9036729199532374	-78.9149634713240005
40554	2020-07-28 08:35:53	2020-07-28	Mrs. Linna Morissette DDS	mrs.linna.morissette.dds@woohoo.com	Long Beach	California	4601246443396439	80edae53e6a9656d19145477f3a666d2	VISA 16 digit	33.8537165512152001	-118.223294042299685
40555	2020-07-28 09:03:49	2020-07-28	Joan Wolff MD	joan.wolff.md@warmmail.com	San Francisco	California	51737427270593580	701c65a1f9c2a589b14a3714b7cbf968	VISA 16 digit	37.8080485393489951	-122.452741813414136
40556	2020-07-28 09:06:00	2020-07-28	Mr. Javen Lehner	mr.javen.lehner@geemail.com	Indianapolis	Indiana	6011903754590641106	45f5ee8737775dc2d64649bf3444ed64	Discover	39.8183410042438624	-86.1939723185930404
40557	2020-07-28 09:07:38	2020-07-28	Mr. Mcarthur Keebler	mr.mcarthur.keebler@geemail.com	Jacksonville	Florida	180089903594342718	16acab8f0a31897c47e12d18ffbc708a	Mastercard	30.3006367167975768	-81.7563048739064584
40558	2020-07-28 09:11:25	2020-07-28	Bryce Ruecker	bryce.ruecker@geemail.com	Santa Rosa	California	3401557832654279	db9355d0efccdaf81eec1ece667a7be6	VISA 16 digit	38.5414244333405094	-122.680487512682006
40559	2020-07-28 09:21:01	2020-07-28	Dr. Machelle Maggio DDS	dr.machelle.maggio.dds@geemail.com	Baton Rouge	Louisiana	4161230203526767	8f197ef44db64d4e0d0fb9b9dcd2eed6	Diners Club / Carte Blanche	30.3876274791758512	-91.0610384128164441
40560	2020-07-28 09:24:21	2020-07-28	Jakobe Dickens	jakobe.dickens@geemail.com	Salem	Oregon	869925281681641459	7442f49b063c57e04b5ca585ab78a1f4	VISA 13 digit	44.9827824703220216	-123.010966872579232
40561	2020-07-28 09:25:00	2020-07-28	Miss Lorelei Kiehn	miss.lorelei.kiehn@warmmail.com	Plano	Texas	4701583462780120	9b3f4f4bdd5efa28f12a2b32301af3c2	VISA 13 digit	33.0653523848477775	-96.837501119607694
40562	2020-07-28 09:28:42	2020-07-28	Belle Kessler-Kling	belle.kessler.kling@woohoo.com	Fresno	California	869996418336126817	4f5620cb8b51260607a187bab12c535f	Voyager	36.8798844518013311	-119.75369081055895
40563	2020-07-28 09:46:38	2020-07-28	Delbert Gerlach	delbert.gerlach@warmmail.com	Gilbert	Arizona	6011412239614544928	dc941f7ea35ffd02e160e302cebe25c8	Mastercard	33.2347294329080682	-111.738001228416707
40564	2020-07-28 09:52:43	2020-07-28	Mr. Aleck Zulauf V	mr.aleck.zulauf.v@geemail.com	San Francisco	California	3088272191215352327	c699d182de32040cdfb553d66625d1cb	VISA 16 digit	37.7869113965927426	-122.430604737065337
40565	2020-07-28 09:52:52	2020-07-28	Barnie Goldner	barnie.goldner@woohoo.com	Chicago	Illinois	3088002652489856134	b5948a07c705e2232b599ce8097442e6	JCB 16 digit	41.8202751084066975	-87.7641777006473376
40566	2020-07-28 09:53:34	2020-07-28	Kayden Maggio	kayden.maggio@geemail.com	Portland	Oregon	210035421651337708	950cb228d72db128501c57b89a21e971	American Express	45.5396426432654238	-122.673870017658928
40567	2020-07-28 09:55:09	2020-07-28	Dorothea Hintz-Kuhn	dorothea.hintz.kuhn@woohoo.com	Lowell	Massachusetts	3528690417766038179	47a607403ac1edf9c4c1619f1b296034	VISA 16 digit	42.6976348845623477	-71.3577474491544024
40568	2020-07-28 09:58:35	2020-07-28	Dr. Micayla Walker	dr.micayla.walker@geemail.com	El Paso	Texas	060479432677312	1bff3dc4ceee321f68c7bb16829f3c45	JCB 15 digit	31.8921668365426392	-106.438152154393507
40569	2020-07-28 09:59:59	2020-07-28	Jeannie Schmitt	jeannie.schmitt@geemail.com	Phoenix	Arizona	4833188243249428	1cc32798be418ee411bd7a382e7fa6ec	JCB 16 digit	33.472709314890956	-112.116750166464982
40570	2020-07-28 10:06:44	2020-07-28	Foch Schulist II	foch.schulist.ii@geemail.com	Bridgeport	Connecticut	869906858053929266	452b8aa38ec4be8ea411ec5b49b478f1	VISA 13 digit	41.1495829862706302	-73.0962952401388435
40571	2020-07-28 10:14:22	2020-07-28	Enoch Wisoky	enoch.wisoky@geemail.com	Winston–Salem	North Carolina	51098109160222545	fe49c36c6dfb8f642375bb014028d050	VISA 16 digit	36.1786241923689857	-80.2843735539950387
40572	2020-07-28 10:18:48	2020-07-28	Ruie Volkman PhD	ruie.volkman.phd@geemail.com	Jacksonville	Florida	4597316466596748	f4cd9cfb4d3c0b01508a360f4d324d14	Diners Club / Carte Blanche	30.3962377807177617	-81.6517129183825148
40573	2020-07-28 10:23:22	2020-07-28	Kerry Harvey	kerry.harvey@geemail.com	El Paso	Texas	869936544862076747	0d9824b5e348aad2a3ef9cf19a61ab2e	VISA 16 digit	31.8194803182330013	-106.382468550510708
40574	2020-07-28 10:26:21	2020-07-28	Sondra Kiehn	sondra.kiehn@geemail.com	Carrollton	Texas	6011632776440390764	1eeef56d1a55b19b8f2ad00e01e0a0b8	VISA 13 digit	32.9678880887027788	-96.9859528536304794
40575	2020-07-28 10:35:23	2020-07-28	Lindsay Kutch	lindsay.kutch@geemail.com	New York	New York	53359647087742743	bef2e07c96f78c4d33c258c02d219f49	Voyager	40.6399852545224149	-73.9188850493065956
40576	2020-07-28 10:49:25	2020-07-28	Nery Abshire	nery.abshire@warmmail.com	Grand Rapids	Michigan	630402762978951	8c1dc8bdf2e02713d5d8a45e6f098713	Discover	42.9587171437487001	-85.5658834671270228
40577	2020-07-28 10:54:03	2020-07-28	Khiry Mosciski MD	khiry.mosciski.md@woohoo.com	Nashville	Tennessee	4295072862836320	07761cdceae509b2bb1610843b1b36d6	Voyager	36.1558839963406271	-86.8554599103424607
40578	2020-07-28 10:56:08	2020-07-28	Ossie Zemlak DVM	ossie.zemlak.dvm@geemail.com	Plano	Texas	3337674229616683546	febd2772bb612b614b17ac1564b23c92	Discover	33.0132935994856069	-96.8427758027050629
40579	2020-07-28 10:56:28	2020-07-28	Cleo Kuhn-Bergnaum	cleo.kuhn.bergnaum@geemail.com	Los Angeles	California	869919888817169912	bbd0b3a83026281d71a90d4e0d102ca8	VISA 13 digit	34.0223377937782558	-118.343376871197663
40580	2020-07-28 10:57:23	2020-07-28	Miss Gladyce Schoen	miss.gladyce.schoen@geemail.com	Albuquerque	New Mexico	3088794205850392957	f118d9c2e105bd22b92dd927bfca9d5d	JCB 15 digit	35.0401213142689372	-106.616941279273107
40581	2020-07-28 10:59:27	2020-07-28	Ginger Jacobson-Beatty	ginger.jacobson.beatty@geemail.com	Chicago	Illinois	4211587433746683	42129e9814b7c6258614eff941236161	Voyager	41.8655601870570351	-87.5925988173607664
40582	2020-07-28 10:59:56	2020-07-28	Marsha Schimmel	marsha.schimmel@geemail.com	Huntsville	Alabama	3047977017209042	c63e92dd8252a232dfd96523d3ff078d	Diners Club / Carte Blanche	34.7143913373127546	-86.6599866017252225
40583	2020-07-28 11:06:28	2020-07-28	Ms. Loretta Lowe DDS	ms.loretta.lowe.dds@geemail.com	New York	New York	4099104837039967	a05ca9b3689687aafb908df5af42f54c	JCB 16 digit	40.6474847348630419	-73.9445618091046839
40584	2020-07-28 11:10:37	2020-07-28	Dr. Clemence Wilkinson III	dr.clemence.wilkinson.iii@geemail.com	Los Angeles	California	4605232052684	54afb9a3e9d0a96dbbb28c1f90da7948	American Express	34.1022428843989971	-118.425937097286052
40585	2020-07-28 11:20:09	2020-07-28	Greta Windler	greta.windler@warmmail.com	Indianapolis	Indiana	630441834637203	4b76961de13b7bda9796e962088df3f8	Voyager	39.7435771735392507	-86.0791173689268447
40586	2020-07-28 11:31:46	2020-07-28	Hilda Block	hilda.block@geemail.com	Sacramento	California	3096635887330266274	5f7431630d32605e4e62b8e723bfa51c	Maestro	38.5277205207649658	-121.490244488302991
40587	2020-07-28 11:42:15	2020-07-28	Delaney Hagenes	delaney.hagenes@geemail.com	Hialeah	Florida	4037787424970399	e82871420e8a952e9ed7f11553658e9d	JCB 16 digit	25.7907023339044308	-80.2602187496513011
40588	2020-07-28 11:44:50	2020-07-28	Miss Monna Lehner	miss.monna.lehner@geemail.com	Louisville	Kentucky	3528736797808070165	1147bf7ed79296318a4414ab24ed7ec5	JCB 16 digit	38.0825032221056503	-85.6047198784142722
40589	2020-07-28 11:47:22	2020-07-28	Arlene Marvin DVM	arlene.marvin.dvm@woohoo.com	Charlotte	North Carolina	6011848207916656454	de8151419398c3580d359e1dcf221be7	VISA 13 digit	35.2585196858525265	-80.7552495424114198
40590	2020-07-28 11:47:31	2020-07-28	Guy Rosenbaum II	guy.rosenbaum.ii@geemail.com	El Paso	Texas	3088721547457588810	dc758e9ec91c5326070a9c35b17de578	Diners Club / Carte Blanche	31.888818592421341	-106.477125236995519
40591	2020-07-28 11:59:57	2020-07-28	Edmund Hyatt-Wolff	edmund.hyatt.wolff@geemail.com	San Francisco	California	3421210565451465	edc19771eadb8f376928601c2a15c998	VISA 16 digit	37.8300542030345639	-122.436578911804617
40592	2020-07-28 12:01:21	2020-07-28	Willy Hettinger	willy.hettinger@warmmail.com	Jacksonville	Florida	502090734188445	ec8751cbeaefe4675a21cf8f932529ae	Voyager	30.2831740052025751	-81.6627095222085728
40593	2020-07-28 12:04:56	2020-07-28	Starla Daugherty	starla.daugherty@geemail.com	Rancho Cucamonga	California	869934373849553764	5b0a8145a2d776c20512d3b8a0eb737d	American Express	34.1529452676877412	-117.635524338996788
40594	2020-07-28 12:14:41	2020-07-28	Sylas Kris	sylas.kris@geemail.com	Tucson	Arizona	3112670976252407614	91bfc4cd6f5ff4f727f7e4eec1ca61ed	Discover	32.0557630016975139	-110.835217326622825
40595	2020-07-28 12:15:30	2020-07-28	Prince Wolf Jr.	prince.wolf.jr.@geemail.com	San Francisco	California	3096121524177501775	f89f99b643f8682b256138805e566d0c	Mastercard	37.7705860999642056	-122.436947110669678
40596	2020-07-28 12:23:54	2020-07-28	Davian Eichmann I	davian.eichmann.i@warmmail.com	Baltimore	Maryland	3463843589004339	588de4b24f829211fd25d4247bbafd8a	American Express	39.2260410304646925	-76.6920546044614184
40597	2020-07-28 12:32:42	2020-07-28	Dr. Nira Powlowski	dr.nira.powlowski@warmmail.com	Louisville	Kentucky	4410153355103780	18d5ecbbd0253bb1184c3e890e8f9b98	VISA 16 digit	38.2271581665050206	-85.6962082313444569
40598	2020-07-28 12:34:30	2020-07-28	Dr. Anner Mills	dr.anner.mills@woohoo.com	Beaumont	Texas	869988287402688244	b51c9f829d77a25d895ea74306351063	VISA 13 digit	30.1079713916476841	-94.2180735485881655
40599	2020-07-28 12:38:40	2020-07-28	Ebony Haley-Gleichner	ebony.haley.gleichner@geemail.com	Orlando	Florida	4889105155234	dbaa73e4481e3890bec0801a0f776d25	Mastercard	28.4883306483071301	-81.2140139955062494
40600	2020-07-28 12:51:08	2020-07-28	Junior Wisoky-Swift	junior.wisoky.swift@woohoo.com	Jacksonville	Florida	210007865509099403	d4dbfcb4e33e5c3baa2147cb0619159a	JCB 16 digit	30.3348890855494879	-81.6576150525905291
40601	2020-07-28 13:03:40	2020-07-28	Aime Ullrich	aime.ullrich@woohoo.com	Chula Vista	California	501826915227693	2a76f3a5b2af2cc51269f62ee2d6328a	Mastercard	32.670583978877211	-116.984708474599557
40602	2020-07-28 13:06:41	2020-07-28	Delma Dibbert MD	delma.dibbert.md@geemail.com	Oklahoma City	Oklahoma	6011924662519823553	4e5335d22ab64798c21b6f2f912f296d	JCB 16 digit	35.456953825001051	-97.4430868302367656
40603	2020-07-28 13:12:50	2020-07-28	Hayes Cummerata Jr.	hayes.cummerata.jr.@geemail.com	Frisco	Texas	6011715435497574784	28c68b9124f705b293f06fde561e8582	Mastercard	33.2127228499386433	-96.7449785291425854
40604	2020-07-28 13:22:04	2020-07-28	Shirleen Spencer	shirleen.spencer@woohoo.com	New York	New York	4044876213496285	b31628962b458e43ea772ec18beec74b	JCB 16 digit	40.7514076724406351	-74.0129863720282941
40605	2020-07-28 13:22:49	2020-07-28	Lisette Olson	lisette.olson@geemail.com	Oakland	California	3158731645873556169	a544fbef4300230012a45711fee49f0d	Maestro	37.8461383550085202	-122.266736990227784
40606	2020-07-28 13:23:28	2020-07-28	Perla Hilpert	perla.hilpert@geemail.com	Newark	New Jersey	180078854041425668	de792bb52971032aa55e42c9495a5abf	Maestro	40.7073723995041163	-74.1848073047328711
40607	2020-07-28 13:25:41	2020-07-28	Caitlyn Hand	caitlyn.hand@geemail.com	Phoenix	Arizona	869900315884373566	fd753ee1a06446886434f3326cf96a9d	VISA 16 digit	33.6415457189481728	-112.067710685583208
40608	2020-07-28 13:34:46	2020-07-28	Cecil Abshire-Wyman	cecil.abshire.wyman@woohoo.com	Portland	Oregon	4957880264107	8e2b2bcc25114ba41f9521aa3a8f7aa4	VISA 16 digit	45.6187257124464978	-122.553949237614873
40609	2020-07-28 13:40:35	2020-07-28	Aretha Kemmer	aretha.kemmer@warmmail.com	Oakland	California	3112445288294808666	fa48f31be5740dcba9f81d5493ccb31a	Maestro	37.7970043370113586	-122.276963053108091
40610	2020-07-28 13:44:40	2020-07-28	Gaylene Reichert	gaylene.reichert@geemail.com	Little Rock	Arkansas	869944835333235064	f270e8a52b02a3a7938426e7cfcbdcd2	VISA 16 digit	34.7596569954227661	-92.375360048177086
40611	2020-07-28 13:45:46	2020-07-28	Dr. Merna Douglas	dr.merna.douglas@geemail.com	Oakland	California	3158636045650647255	db787e4a1ef9b6870c61d8349a3ccf2e	Diners Club / Carte Blanche	37.811907968895774	-122.2673325647757
40612	2020-07-28 13:56:27	2020-07-28	Levy Schultz	levy.schultz@woohoo.com	Chattanooga	Tennessee	630412909998424	15d9d8c95f706b8c2b4deeb727de9cf3	VISA 16 digit	35.018509360946716	-85.2207411040846239
40613	2020-07-28 14:07:11	2020-07-28	Mr. Augustin Kreiger	mr.augustin.kreiger@geemail.com	Chicago	Illinois	3112200572371884491	a96414d7947ff436fbd419265bcd4f46	JCB 16 digit	41.7984834004960959	-87.6164870825160307
40614	2020-07-28 14:14:05	2020-07-28	Mrs. Karri Hauck	mrs.karri.hauck@geemail.com	New York	New York	180029735242442596	4b4c6e5a182d1475a01188b9de302cbf	JCB 16 digit	40.7360938759744187	-74.0209727535851272
40615	2020-07-28 14:18:20	2020-07-28	Reanna Upton MD	reanna.upton.md@woohoo.com	San Francisco	California	210009269687019218	b6ec4b739e5df92fd02eb10ca0588ab1	Discover	37.7676697691929419	-122.409064209270753
40616	2020-07-28 14:24:30	2020-07-28	Mr. Cas Reilly	mr.cas.reilly@woohoo.com	Chula Vista	California	54617179615484851	7ac242a0caf8f34b28937029a5577797	Discover	32.5867052852407042	-116.968536972882958
40617	2020-07-28 14:32:30	2020-07-28	Daisy Witting-Wunsch	daisy.witting.wunsch@geemail.com	Akron	Ohio	3400997527746488	1e349332e211a7035b0e5b21fd27a7de	JCB 16 digit	41.0679455644749112	-81.5480146560665276
40618	2020-07-28 14:41:50	2020-07-28	Tricia Howe	tricia.howe@geemail.com	Waterbury	Connecticut	4940536844670	e6b36ad6b4b3ad85a24a49bcc61cf298	Discover	41.5778594201467939	-72.9557072409342879
40619	2020-07-28 14:50:59	2020-07-28	Audry Schultz	audry.schultz@geemail.com	Phoenix	Arizona	3096871190624673989	ee2e725f8227aab016b0efecbf6d49f4	Discover	33.6538868538036979	-112.021304326543969
40620	2020-07-28 14:51:55	2020-07-28	Nola Nolan	nola.nolan@geemail.com	San Francisco	California	180020866408056729	125113390c71f944393bda81208ddae8	JCB 16 digit	37.7772873795035053	-122.445426437529733
40621	2020-07-28 14:54:54	2020-07-28	Oren Nolan	oren.nolan@geemail.com	Sacramento	California	3438625195288873	2d3e7a9339259cf50db221d9c5b85bff	Diners Club / Carte Blanche	38.5280511306397599	-121.421813627589856
40622	2020-07-28 14:55:28	2020-07-28	Marylin Powlowski	marylin.powlowski@woohoo.com	West Palm Beach	Florida	4888516954798387	602cdfde2b7254c69b53f7e899f2c715	Maestro	26.837935135032609	-80.1040188826456756
40623	2020-07-28 15:02:41	2020-07-28	Durrell Frami	durrell.frami@geemail.com	San Francisco	California	4040853308733058	113294fa19a6900ed8d58f5d7df037b2	Mastercard	37.7724350869255332	-122.442162619844993
40624	2020-07-28 15:07:55	2020-07-28	Zula Wilkinson	zula.wilkinson@geemail.com	Costa Mesa	California	6011332538016420505	9e9549632437cfd682edce8ed1ddea69	VISA 13 digit	33.58737567924112	-117.878990652119001
40625	2020-07-28 15:38:49	2020-07-28	Geo McKenzie-Raynor	geo.mckenzie.raynor@geemail.com	Huntington Beach	California	4514908342066	129a03f6e57ab5e65077307737d3d98e	JCB 15 digit	33.6972689078696135	-117.956471745356168
40626	2020-07-28 15:45:10	2020-07-28	Hughie Rau	hughie.rau@geemail.com	St. Louis	Missouri	869948868964343101	4cbee5733003a68c269d21e4c086f39d	Discover	38.6595999533466994	-90.2778746595144383
40627	2020-07-28 15:45:30	2020-07-28	Izetta McCullough	izetta.mccullough@geemail.com	Las Vegas	Nevada	4490887754005608	f73460b0c71f96e894349e8c6c67b2ba	Mastercard	36.1852962134040865	-115.255734721079833
40628	2020-07-28 15:53:44	2020-07-28	Dr. Philo Champlin Sr.	dr.philo.champlin.sr.@geemail.com	Lincoln	Nebraska	180083307102472676	cbb9e7a2aa4aaaeed945b6109f680643	Maestro	40.888298896748573	-96.586424717369681
40629	2020-07-28 16:02:33	2020-07-28	Emilee Goldner DVM	emilee.goldner.dvm@geemail.com	Berkeley	California	4797829288585002	cfa2bb61f462ed65ad76b5bf868b585d	American Express	37.8931664912621784	-122.274413567836305
40630	2020-07-28 16:07:04	2020-07-28	Miss Liane Metz PhD	miss.liane.metz.phd@geemail.com	Los Angeles	California	3734511977141460	d334562e15e93cb9a36b14191a69523d	Discover	33.9833073730446387	-118.396644242200253
40631	2020-07-28 16:12:52	2020-07-28	Kameron Beier II	kameron.beier.ii@woohoo.com	San Francisco	California	3055184211832198	717711f1fb989bd10fa21bd91cb2e6e4	American Express	37.763893997865182	-122.420769417792826
40632	2020-07-28 16:18:27	2020-07-28	Makenzie Jast	makenzie.jast@woohoo.com	Portland	Oregon	3088116568465707294	62a242f85e78669aeff3262b67007b9a	VISA 16 digit	45.6100758321005841	-122.695572388870644
40633	2020-07-28 16:21:22	2020-07-28	Louie Stracke	louie.stracke@woohoo.com	Oklahoma City	Oklahoma	4768793789318971	fd186d60528ecf672869fe5a536f8cc8	Discover	35.390099155335129	-97.5753566601675004
40634	2020-07-28 16:21:41	2020-07-28	Macey Schoen	macey.schoen@geemail.com	San Francisco	California	180044638347029683	776cf6b3c0536a3fea2877418a9161a5	Diners Club / Carte Blanche	37.7866401389134126	-122.426331891463548
40635	2020-07-28 16:36:32	2020-07-28	Melody Swaniawski-Cummerata	melody.swaniawski.cummerata@geemail.com	Honolulu	Hawaii	3725827775797944	66885424b2caa9ba828d48cbf9b6c075	JCB 16 digit	21.2547850497748705	-157.826402156541491
40636	2020-07-28 16:36:40	2020-07-28	Levi Koepp	levi.koepp@geemail.com	Birmingham	Alabama	53001137933013145	290693c9ec68f81f992c12d5cee6e790	Diners Club / Carte Blanche	33.5126867168374361	-86.8564498179834459
40637	2020-07-28 16:38:06	2020-07-28	Sabrina Dietrich	sabrina.dietrich@woohoo.com	Honolulu	Hawaii	503867453685801	8f8ec9979f3de0060dc626ad5690b8fa	JCB 16 digit	21.2311513952195661	-157.811019291237358
40638	2020-07-28 16:39:33	2020-07-28	Selmer Harris	selmer.harris@woohoo.com	Los Angeles	California	3088762173519502887	db6461fa227c4a454ebce81b21e87b16	Voyager	34.0017951813857948	-118.453614018810157
40639	2020-07-28 16:46:04	2020-07-28	Miss Ivey Crona MD	miss.ivey.crona.md@woohoo.com	Los Angeles	California	869941842137995987	1ab4bb12723fab1361e2720a67ecf5c1	American Express	34.0156809440679808	-118.359647033828495
40640	2020-07-28 16:53:42	2020-07-28	Mignon Simonis	mignon.simonis@geemail.com	Mesa	Arizona	3790836685440966	8e195cf9867e51bccdcb9af2487718fb	VISA 16 digit	33.3551312039751551	-111.800721147086094
40641	2020-07-28 16:55:28	2020-07-28	Destinee Conroy	destinee.conroy@geemail.com	Oakland	California	3337722582092312341	17b1327c5a3ebbd482d20d37fb2dcfc6	Discover	37.8034971200468561	-122.245269840881107
40642	2020-07-28 16:59:31	2020-07-28	Dr. Phebe Tillman	dr.phebe.tillman@warmmail.com	Frisco	Texas	3023436840792298	91d3f9efe202b99f2750ad4382893f8b	JCB 16 digit	33.1917033536821577	-96.8913201826833159
40643	2020-07-28 17:09:35	2020-07-28	Samir Trantow-Trantow	samir.trantow.trantow@geemail.com	Durham	North Carolina	4183370536854207	d36ed731f1e5987f65109d9c5edddc02	JCB 15 digit	35.987059484353658	-78.871168236564472
40644	2020-07-28 17:10:09	2020-07-28	Journey Bernier	journey.bernier@woohoo.com	San Diego	California	53666292095577936	491f3c9407b11c9082e96574e8412dd3	Mastercard	32.7985762025296665	-117.209256048770627
40645	2020-07-28 17:11:23	2020-07-28	Dona Hodkiewicz	dona.hodkiewicz@woohoo.com	Philadelphia	Pennsylvania	3040578398603972	5c414d64ea403cc04a0584838ca74d6d	JCB 16 digit	40.0689167310442755	-75.117179818022251
40646	2020-07-28 17:12:17	2020-07-28	Stephon Johnston	stephon.johnston@geemail.com	Pittsburgh	Pennsylvania	6011406899240392733	568f87edda7d2204545421276996bad2	VISA 13 digit	40.3937496987592439	-79.8901265007149419
40647	2020-07-28 17:17:09	2020-07-28	Kolten Conroy	kolten.conroy@geemail.com	St. Louis	Missouri	3337020372480072304	da8013ab05e5cebc4ff73005cae67f1d	VISA 16 digit	38.7139581824809298	-90.202159135090568
40648	2020-07-28 17:17:17	2020-07-28	Yareli Miller	yareli.miller@woohoo.com	Los Angeles	California	3158997018969324398	684562bdebd9ea925408dcc519e09711	JCB 16 digit	33.9382176092226047	-118.400344130675492
40649	2020-07-28 17:22:37	2020-07-28	Jep Johns	jep.johns@geemail.com	Columbus	Ohio	869976763047616844	f0e28b2cae10fcb77c8289bb7c7c0b82	VISA 13 digit	39.9864289069127281	-82.9360715434189899
40650	2020-07-28 17:23:53	2020-07-28	Jeryl Schoen-Bartoletti	jeryl.schoen.bartoletti@woohoo.com	Chula Vista	California	180081335848576429	f6e3e1ab7a0b28e6a43c838c395a6423	JCB 16 digit	32.6457531376507077	-117.017464280663802
40651	2020-07-28 17:29:59	2020-07-28	Vilma Altenwerth	vilma.altenwerth@warmmail.com	Laredo	Texas	210055542245525741	5506abc44b67089f8b2e77df010a2f33	JCB 16 digit	27.5053152549263089	-99.4640675633221889
40652	2020-07-28 17:32:06	2020-07-28	Brennon Pouros-Jacobi	brennon.pouros.jacobi@geemail.com	Raleigh	North Carolina	6011219931940417200	751a47558d175b5a790a33eda743ba26	American Express	35.7714441070467188	-78.7248996315460658
40653	2020-07-28 17:33:50	2020-07-28	Trent Champlin	trent.champlin@geemail.com	Berkeley	California	180084327747822795	c1d2f41de32cf8cb437beea1f7e062b5	JCB 16 digit	37.8827408390783091	-122.317474141510104
40654	2020-07-28 17:38:59	2020-07-28	Mr. Levi Fahey Jr.	mr.levi.fahey.jr.@geemail.com	Jacksonville	Florida	4102491686663970	c2a03bdba1e9fe1be84c72855e32f360	JCB 15 digit	30.4236071173619465	-81.6422799804791879
40655	2020-07-28 17:41:40	2020-07-28	Kahlil Haag	kahlil.haag@geemail.com	San Jose	California	4736453023003	c22e4aaa2b3a7768e91daf1da4fe1b1d	Diners Club / Carte Blanche	37.3091642763752489	-121.884380242343624
40656	2020-07-28 17:51:09	2020-07-28	Wm Jast	wm.jast@warmmail.com	Rancho Cucamonga	California	676326150844582	21438de4b912e27847d8826f33f0d398	Voyager	34.2217831270761792	-117.510927621648463
40657	2020-07-28 17:51:44	2020-07-28	Ellison Dooley	ellison.dooley@geemail.com	Temecula	California	3041821507988952	a087b3e7e50b293cf39cb9034b7e8b96	Mastercard	33.4313578882854401	-117.04130063361562
40658	2020-07-28 17:55:38	2020-07-28	Dr. Jim Schneider I	dr.jim.schneider.i@geemail.com	San Francisco	California	3499868135716571	e7a82986fba96fe510ea00b659090228	American Express	37.7660867129873949	-122.460397655601497
40659	2020-07-28 18:19:02	2020-07-28	Shayne Dicki V	shayne.dicki.v@geemail.com	San Antonio	Texas	3014803782260676	376043694f7888162cfbef1cab11c208	VISA 13 digit	29.477869817947596	-98.5482139154639043
40660	2020-07-28 18:27:44	2020-07-28	Ms. Shannon Schroeder MD	ms.shannon.schroeder.md@geemail.com	Lansing	Michigan	676146656026153	7526a484a194fb4d3029fe0df7925939	VISA 16 digit	42.7564110514085769	-84.6163791893172998
40661	2020-07-28 18:31:08	2020-07-28	Damien Bartoletti	damien.bartoletti@geemail.com	Fargo	North Dakota	4891795034802071	a59b44ab087c861e1c6e5867c00783d9	Discover	46.9607053659621627	-96.8746932272761967
40662	2020-07-28 18:35:50	2020-07-28	Hardin Kunde	hardin.kunde@warmmail.com	Chicago	Illinois	4357019958203563	b06c6abd4770c0eca7d8690464cb4038	Maestro	41.771012977727132	-87.7283622951276527
40663	2020-07-28 18:41:09	2020-07-28	Miss Ella Doyle	miss.ella.doyle@warmmail.com	Athens	Georgia	4210915549120	f34255d3bfca0c45b2961ceaa671c07e	JCB 16 digit	33.9046933808553916	-83.3671058347098466
40664	2020-07-28 18:42:40	2020-07-28	Trudy Bednar DDS	trudy.bednar.dds@geemail.com	Columbus	Georgia	639094304748562	ce6ec105f776d4326a4a0e75ce3090a9	Mastercard	32.4125272820748336	-84.9230770477257693
40665	2020-07-28 18:48:26	2020-07-28	Amy Gibson MD	amy.gibson.md@geemail.com	New York	New York	6011632479251920882	eb4224c9e3ad380b331df073c9c46cbc	VISA 13 digit	40.6736410721428712	-73.8574512106262091
40666	2020-07-28 18:54:39	2020-07-28	Garvin Bernhard-Schiller	garvin.bernhard.schiller@geemail.com	Thousand Oaks	California	3039100447386920	8bee667b47d4512ac0e99f1e8f4dee6d	VISA 13 digit	34.1086577120043373	-118.924027965116125
40667	2020-07-28 19:07:45	2020-07-28	Pepper Hammes	pepper.hammes@geemail.com	Hillsboro	Oregon	3743984310215417	f2b412f6adf64bf88c12bc2066859cb2	JCB 16 digit	45.566284501153973	-122.950503085476157
40668	2020-07-28 19:11:17	2020-07-28	Frazier Fay	frazier.fay@warmmail.com	Tucson	Arizona	4227628436424795	670a2a7e5b3d20872165f5bd23b65c66	VISA 13 digit	32.1681915293954361	-110.942752119036754
40669	2020-07-28 19:13:41	2020-07-28	Lauri Herman	lauri.herman@geemail.com	Houston	Texas	4090778887126	1f9fb1bd42742ee621b41f78710e21e6	American Express	29.8151399493761353	-95.3582762277234366
40670	2020-07-28 19:14:56	2020-07-28	Dwan Smith	dwan.smith@geemail.com	New York	New York	6011305466116866844	983330adbf8b3ae8a6b9cb15478667b8	Diners Club / Carte Blanche	40.5764983594641109	-74.0263287931576315
40671	2020-07-28 19:24:55	2020-07-28	Alice Smith-Sipes	alice.smith.sipes@geemail.com	Los Angeles	California	6011684264608735705	52979797b323dfa838f91c0c4cc695ed	American Express	34.0608799011312371	-118.348407602728528
40672	2020-07-28 19:30:03	2020-07-28	Pranav Vandervort MD	pranav.vandervort.md@warmmail.com	San Francisco	California	3440286947327968	34b2b3263399f23a5b56bc662d360835	JCB 16 digit	37.7698133850734692	-122.448583985959729
40673	2020-07-28 19:33:08	2020-07-28	Richmond Sauer	richmond.sauer@geemail.com	Austin	Texas	3096450459597598492	7823450670773917d47c938de5ceb923	Mastercard	30.2233363540038447	-97.7576905881293214
40674	2020-07-28 19:44:59	2020-07-28	Dee Connelly	dee.connelly@geemail.com	Jacksonville	Florida	3096926186585382169	8e3f5082a268eff8fda97e74f6c65ba3	JCB 16 digit	30.2770865643449127	-81.6696698120407802
40675	2020-07-28 19:47:42	2020-07-28	Jordin Cronin	jordin.cronin@geemail.com	Omaha	Nebraska	4910882288746837	c9dadb94a4ed652d483a1ee76938dcb4	VISA 16 digit	41.290492541078109	-96.0688437655218053
40676	2020-07-28 19:56:39	2020-07-28	Shari Wuckert MD	shari.wuckert.md@warmmail.com	Oklahoma City	Oklahoma	869936409364437864	c287d731fa474300143de75ca3b1921a	Discover	35.4765570497516549	-97.4846922429639875
40677	2020-07-28 20:02:50	2020-07-28	Dr. Dolores VonRueden MD	dr.dolores.vonrueden.md@geemail.com	Aurora	Colorado	6011758516611076190	de6ff5ff8e333954091bd304197c2351	VISA 13 digit	39.5932910513244565	-104.765619440714644
40678	2020-07-28 20:04:42	2020-07-28	Leamon Gislason	leamon.gislason@warmmail.com	Knoxville	Tennessee	4490522831505	6567e4bbdf8410521297be2fb8ba0173	VISA 13 digit	36.0122265402756625	-83.9551690534438819
40679	2020-07-28 20:08:35	2020-07-28	Celestia Crist-Abernathy	celestia.crist.abernathy@geemail.com	Berkeley	California	55678820007349097	11c78aef263d8ccad85173f205594646	Diners Club / Carte Blanche	37.8656830973513507	-122.26247364165647
40680	2020-07-28 20:12:15	2020-07-28	Jensen Metz	jensen.metz@geemail.com	Burbank	California	3002281829886450	81c25253b12dcc48daf535fe880243e7	Voyager	34.1684322829287481	-118.33865607711823
40681	2020-07-28 20:16:54	2020-07-28	Dellie Greenholt PhD	dellie.greenholt.phd@woohoo.com	Lubbock	Texas	4248919604468457	d8fd169f3defe33faca3a71d57cec70c	VISA 16 digit	33.548961349813645	-101.827518905271589
40682	2020-07-28 20:27:51	2020-07-28	Orrie Dooley	orrie.dooley@geemail.com	Gilbert	Arizona	3486202848806054	98129d61c5f220069fb8a4f1b115ca15	Maestro	33.3109563289556618	-111.647982554011421
40683	2020-07-28 20:29:55	2020-07-28	Mr. Perley Russel PhD	mr.perley.russel.phd@geemail.com	Boston	Massachusetts	4517644780390804	2036dec18f464fe07e818add79ce8266	Diners Club / Carte Blanche	42.358993982587009	-71.0970196582328526
40684	2020-07-28 20:37:04	2020-07-28	Tiesha Carter MD	tiesha.carter.md@geemail.com	Portland	Oregon	3053942297918971	f95d0cf79d0c853f2411ddcde4e7d959	VISA 13 digit	45.530245223164556	-122.72339319395833
40685	2020-07-28 20:52:03	2020-07-28	Mirtie Wyman	mirtie.wyman@warmmail.com	San Francisco	California	3050857082649925	6604a9c900de6c97918b90ae715ffc2d	Voyager	37.776172454686666	-122.42708096847322
40686	2020-07-28 20:54:56	2020-07-28	Leighton Osinski	leighton.osinski@warmmail.com	El Paso	Texas	3053346721339814	09d3aa7faa150785d6b08153ad036496	Voyager	31.944408031675593	-106.482862852232543
40687	2020-07-28 21:02:28	2020-07-28	Millie Murazik	millie.murazik@geemail.com	Garland	Texas	3048179291459364	e241369f034a3f5a200660633e929209	Diners Club / Carte Blanche	32.9384890990566461	-96.6323038554910596
40688	2020-07-28 21:06:21	2020-07-28	Carmen Emard V	carmen.emard.v@geemail.com	Lincoln	Nebraska	869921139501379284	80c8c9e6cda5c8551aaed26707e9e7f9	Voyager	40.7365159184224908	-96.7372661337882249
40689	2020-07-28 21:08:48	2020-07-28	Brianda Baumbach DDS	brianda.baumbach.dds@geemail.com	Dallas	Texas	4905520250044	a643f840e3cfc5eb0ce167180c0968b9	Maestro	32.7516637460134916	-96.7540651450827625
40690	2020-07-28 21:10:01	2020-07-28	Louie Funk MD	louie.funk.md@woohoo.com	Cleveland	Ohio	3528351228342510213	e5f29a6c70206b115811604626fb3474	Diners Club / Carte Blanche	41.5328551701121	-81.6350605952326163
40691	2020-07-28 21:10:10	2020-07-28	Ebony Senger	ebony.senger@geemail.com	El Paso	Texas	630423370339774	3fc26033fad2293a43b45cfca72c7853	VISA 13 digit	31.8069536556318404	-106.372844279835007
40692	2020-07-28 21:12:49	2020-07-28	Chip Boyle	chip.boyle@geemail.com	Columbus	Ohio	53666906438667134	e25ff1fd8d4d1bd622ca2549679cb681	JCB 15 digit	39.9712493697691684	-82.9471344792518863
40693	2020-07-28 21:15:08	2020-07-28	Mr. Chance Senger	mr.chance.senger@geemail.com	Phoenix	Arizona	6011074140848782392	f986beedb9ee58d02eb08ded1172ce39	VISA 13 digit	33.6392553892850898	-112.129641006786755
40694	2020-07-28 21:17:10	2020-07-28	Theodore Morissette	theodore.morissette@geemail.com	Miramar	Florida	6011684160328357657	6b9e0ac4c2108945c9f25b545593d129	JCB 16 digit	26.0363620283063497	-80.2891829943742721
40695	2020-07-28 21:18:21	2020-07-28	Ason Zemlak PhD	ason.zemlak.phd@woohoo.com	Tampa	Florida	51149905661071466	cd61110081ef9946bbc2fa7660ff9236	JCB 16 digit	28.0629620828315609	-82.5663769646294412
40696	2020-07-28 21:18:56	2020-07-28	Conrad Ritchie	conrad.ritchie@warmmail.com	Houston	Texas	51325741231575611	17f811893d48fd4bff0458a9f9c16373	Diners Club / Carte Blanche	29.8634955239560469	-95.4126397176660674
40697	2020-07-28 21:27:33	2020-07-28	Jacqulyn Ledner	jacqulyn.ledner@warmmail.com	Oakland	California	4607100725982321	4af8018c25eb8be56c3e993c19f43c77	VISA 13 digit	37.8000705387615028	-122.308635011892704
40698	2020-07-28 21:31:15	2020-07-28	Dr. Phil Reilly III	dr.phil.reilly.iii@geemail.com	San Diego	California	3337127427453006762	16136f04d19cde49b0b3e1675b1dd3d6	VISA 16 digit	32.7672277176354072	-117.207206414584078
40699	2020-07-28 21:43:22	2020-07-28	Mandy Cruickshank DVM	mandy.cruickshank.dvm@warmmail.com	Hialeah	Florida	3404246446310612	a1c4b0d894aa3318249a5c8ab01ff8ed	JCB 15 digit	25.8857660453278591	-80.3572741432018489
40700	2020-07-28 21:52:51	2020-07-28	Julia Breitenberg	julia.breitenberg@geemail.com	Memphis	Tennessee	4066287647135684	d59c21d697035a4c0d06692362843efa	VISA 13 digit	35.058675661130998	-90.0265993042174699
40701	2020-07-28 21:58:46	2020-07-28	Byron Lindgren	byron.lindgren@geemail.com	Tulsa	Oklahoma	3007050677781096	533339df5fd1c990699af92bad8bbb53	American Express	36.0698125075452012	-95.9322661809112844
40702	2020-07-28 22:03:08	2020-07-28	Shanelle Dietrich	shanelle.dietrich@geemail.com	Raleigh	North Carolina	3757964027676138	4353beee3a540f9a130bd66acedeb0e4	Mastercard	35.7845550264365926	-78.6123145927146112
40703	2020-07-28 22:04:18	2020-07-28	Buell Nienow	buell.nienow@geemail.com	Centennial	Colorado	4349774525628210	ec3c910218148fafaf9bdd6b26f8865d	VISA 13 digit	39.5500068652950247	-104.815113665897769
40704	2020-07-28 22:05:56	2020-07-28	Loney Steuber III	loney.steuber.iii@woohoo.com	Honolulu	Hawaii	6011753554715648486	980aa3cad62d9e698b58f058714bd470	Voyager	21.2475559628318997	-157.7951638765376
40705	2020-07-28 22:07:21	2020-07-28	Adelaide Berge DVM	adelaide.berge.dvm@geemail.com	El Paso	Texas	3467144530339247	ca2ae121629f54719fb7e11ca1729a76	Mastercard	31.8825160422191054	-106.522898174541083
40706	2020-07-28 22:08:16	2020-07-28	Tamica Connelly	tamica.connelly@geemail.com	Garden Grove	California	869994761304206562	e0837817ab1b4d053b3188c8c5bfae4a	VISA 13 digit	33.7889738247089042	-118.049867844536891
40707	2020-07-28 22:15:52	2020-07-28	Chelsey Lueilwitz	chelsey.lueilwitz@warmmail.com	Chicago	Illinois	4526589555017554	a2b97e74367222bd15b069e8473ca428	Maestro	41.8915731665980076	-87.7749433399207817
40708	2020-07-28 22:17:05	2020-07-28	Kristoffer Kuhic	kristoffer.kuhic@geemail.com	Hartford	Connecticut	54713563162951235	7a75afbd25f0e6151a605e4f709925dc	Voyager	41.8517300485648249	-72.6757799262072979
40709	2020-07-28 22:37:31	2020-07-28	Leif Okuneva	leif.okuneva@geemail.com	Independence	Missouri	3096674206590491427	a9d67695ea0df981159700cdbcd5a399	VISA 16 digit	39.1640693560726945	-94.3673042699977742
40710	2020-07-28 22:37:51	2020-07-28	Kellie Boehm-Terry	kellie.boehm.terry@warmmail.com	El Paso	Texas	4385656755429846	f5e3bd8587f61057945482d19583194e	Mastercard	31.839731754671412	-106.355527691261855
40711	2020-07-28 22:42:27	2020-07-28	Miss Justice Robel	miss.justice.robel@woohoo.com	Vallejo	California	869926208588013044	02b1d458e46c2fe6a843dc5ecd1d130c	Maestro	38.0903647128582037	-122.257625217070796
40712	2020-07-28 22:48:01	2020-07-28	Darrick Balistreri	darrick.balistreri@geemail.com	Gresham	Oregon	51384635241663888	517f347b825286604a5db06fa3932c12	Maestro	45.5518921253226665	-122.344681520693371
40713	2020-07-28 22:54:26	2020-07-28	Ms. Annamae Moen	ms.annamae.moen@geemail.com	Winston–Salem	North Carolina	3088988361116085988	2414e67acaf0866a96bf4d2dcc2b0a27	JCB 16 digit	36.0306912951402367	-80.1692859072368549
40714	2020-07-28 22:58:11	2020-07-28	Blaze McCullough	blaze.mccullough@geemail.com	San Antonio	Texas	4474748388953	3a64b3a21de41b8d4d911d711b858570	JCB 16 digit	29.5336361438106749	-98.5864930711988308
40715	2020-07-28 22:58:15	2020-07-28	Clyda Mraz	clyda.mraz@geemail.com	Columbia	Missouri	3014439502827625	e8fe2c3ac12047de0903a34d37f86fed	Diners Club / Carte Blanche	38.9070466009315652	-92.2585773267836373
40716	2020-07-28 22:59:08	2020-07-28	Mr. Elroy Lind Sr.	mr.elroy.lind.sr.@warmmail.com	Fresno	California	4310948267386774	a2021e4639582565bb5015466f144d36	Discover	36.8765881371092021	-119.74574553203918
40717	2020-07-28 23:01:04	2020-07-28	Ermina Dare	ermina.dare@geemail.com	Los Angeles	California	4042775762275300	c7c38f5abfc2a32b03c03362f196fce4	American Express	34.036206753212582	-118.394649619422097
40718	2020-07-28 23:04:34	2020-07-28	Brande Bogisich	brande.bogisich@warmmail.com	Omaha	Nebraska	6011798276056562871	396f8f855937c380f936bd7feefc95be	Diners Club / Carte Blanche	41.2892984821606461	-96.0382997705251
40719	2020-07-28 23:09:05	2020-07-28	Cruz Balistreri PhD	cruz.balistreri.phd@geemail.com	Los Angeles	California	3528029539388933859	8eeb08ee0c0fa5d64f734247084a6bb5	Voyager	34.1171925148326878	-118.474189935391024
40720	2020-07-28 23:23:45	2020-07-28	Dane Maggio	dane.maggio@geemail.com	Denver	Colorado	4984488839378079	3a2b9c84c393a75232f986bc0936dfef	VISA 16 digit	39.8241469554655225	-104.798457453517614
40721	2020-07-28 23:29:02	2020-07-28	Alyse Bashirian	alyse.bashirian@warmmail.com	New York	New York	54455964269418445	39c729e9b1a228449a1c96fc9c6ab07b	American Express	40.5854832976348661	-73.9256648460764438
40722	2020-07-28 23:31:32	2020-07-28	Demian Wunsch-Gislason	demian.wunsch.gislason@geemail.com	Edison	New Jersey	6011812423946759745	4525f58e91cb959a4fbe19c25571228f	JCB 15 digit	40.463347752714526	-74.2521361021377118
40723	2020-07-28 23:32:53	2020-07-28	Concha Wolf	concha.wolf@warmmail.com	Dallas	Texas	4291271536935	42ffd14aa3b061857ad869d872e74c4a	Diners Club / Carte Blanche	32.8911927549440435	-96.7654766215439821
40724	2020-07-28 23:35:53	2020-07-28	Marleigh Toy	marleigh.toy@warmmail.com	Irvine	California	3337338025873006456	3bb3cdd5b1365276152a3dc35e0d8124	VISA 16 digit	33.7048174940995935	-117.682409794722872
40725	2020-07-28 23:42:08	2020-07-28	Mr. Horatio Parker DDS	mr.horatio.parker.dds@warmmail.com	Murrieta	California	4562651701543837	3c9d770d302b5d323e000126caa826d7	JCB 16 digit	33.6299918032813778	-117.227394849005705
40726	2020-07-28 23:49:31	2020-07-28	Romona Weimann-Bins	romona.weimann.bins@warmmail.com	Stockton	California	6011045035408767849	4d82bbd36d3bf8e7bde6883d8bc007d6	JCB 16 digit	37.9989788610219961	-121.313115658526499
40727	2020-07-29 00:04:17	2020-07-29	Menachem Oberbrunner	menachem.oberbrunner@geemail.com	Portland	Oregon	4017073276820	48082ff2c1c78411f9e6edfb1c0479fe	JCB 16 digit	45.5685435521770259	-122.608532933890828
40728	2020-07-29 00:11:03	2020-07-29	Aloysius Boyer	aloysius.boyer@woohoo.com	Portland	Oregon	3702731085568242	79dbb03cb891afdd0f49cddcc1d08577	American Express	45.5292174657694986	-122.726370010571557
40729	2020-07-29 00:11:53	2020-07-29	Dr. Oral Lind Jr.	dr.oral.lind.jr.@geemail.com	Lewisville	Texas	3158069201861606400	4340c9d93404b20b1180180da40303d0	VISA 16 digit	33.0454342965953032	-96.8967967720732162
40730	2020-07-29 00:12:11	2020-07-29	Sampson Veum	sampson.veum@geemail.com	Peoria	Illinois	4335530912658111	6301e3baa071a2ee73ebac8595dfc235	VISA 13 digit	40.7197248125784128	-89.717146100371707
40731	2020-07-29 00:26:09	2020-07-29	Dr. Case White	dr.case.white@geemail.com	New York	New York	060481275814119	9c98eaee8366ea3e5cb733a0be46bd87	Diners Club / Carte Blanche	40.7077456406541174	-73.9006855455122889
40732	2020-07-29 00:33:47	2020-07-29	Nicola Abbott-Boyer	nicola.abbott.boyer@geemail.com	Jersey City	New Jersey	869993228736708962	3b3732e753a94753e9ed2b32a454687b	JCB 16 digit	40.6902575235288566	-73.9894175465639705
40733	2020-07-29 00:35:44	2020-07-29	Chaya Green-Bauch	chaya.green.bauch@geemail.com	Oakland	California	502085337234265	f21f6ebb9b956dff67aa491cbe6a933f	JCB 16 digit	37.7947472563784075	-122.277018682817911
40734	2020-07-29 00:43:12	2020-07-29	Annabel Ferry	annabel.ferry@warmmail.com	Philadelphia	Pennsylvania	3088440978046653890	00cab87485406cdc5ff0e4d1ac2d64e6	Maestro	40.0370077860966305	-75.0530977010160711
40735	2020-07-29 00:43:13	2020-07-29	Ms. Eileen Labadie MD	ms.eileen.labadie.md@geemail.com	Cedar Rapids	Iowa	3479828009264557	293316d2fbe318b3e4d43c7c938bc85e	Diners Club / Carte Blanche	42.0578850141335252	-91.619074171788256
40736	2020-07-29 00:52:57	2020-07-29	Caden Crona-Walter	caden.crona.walter@geemail.com	New York	New York	3740196015760729	55ca5f9874232976c2d51f10a52c6a06	Discover	40.7164372031334807	-73.9136168930109534
40737	2020-07-29 01:08:56	2020-07-29	Monnie Beatty PhD	monnie.beatty.phd@warmmail.com	Oklahoma City	Oklahoma	3769640437026447	341d6664cb9c0e7d6b90825c384a8694	JCB 15 digit	35.4429756746538018	-97.4304918769642683
40738	2020-07-29 01:21:06	2020-07-29	Miss Gillian Marvin MD	miss.gillian.marvin.md@geemail.com	New York	New York	6011932819693069482	e416d77ee8888dc3ed5a7f531f296f8f	VISA 16 digit	40.6196276616528635	-73.874751825433961
40739	2020-07-29 01:21:40	2020-07-29	Unknown Olson	unknown.olson@geemail.com	Philadelphia	Pennsylvania	4874421308720581	b2d6131cc5983b6b7fcc70e873ddfcfe	JCB 15 digit	39.9740170900668943	-75.1131085357062602
40740	2020-07-29 01:22:42	2020-07-29	Brian Lemke	brian.lemke@geemail.com	Irvine	California	6011413689376241692	0217114bce0ce78139327892e67e0a63	JCB 16 digit	33.6431349893581171	-117.722676829715439
40741	2020-07-29 01:25:56	2020-07-29	Brigitte Cormier MD	brigitte.cormier.md@geemail.com	New York	New York	3337627108318933987	01d5ba06ddd673ba71198557cf25b4f5	JCB 15 digit	40.7037176414616368	-73.9386141999985966
40742	2020-07-29 01:29:30	2020-07-29	Miss Ednah Gulgowski	miss.ednah.gulgowski@geemail.com	Ontario	California	3337975139850419174	b00d96a7e126a02775591d7ea50c0f79	VISA 13 digit	33.9949649796500779	-117.692764556231722
40743	2020-07-29 01:30:41	2020-07-29	Roland Weimann-Herman	roland.weimann.herman@geemail.com	Corpus Christi	Texas	4527497403101019	6e00dce25a54dd06cd6dfeea41b31d05	VISA 16 digit	27.6548467196460805	-97.2420918055173047
40744	2020-07-29 01:36:38	2020-07-29	Paris Blick	paris.blick@geemail.com	San Diego	California	3024170477351263	3689a9577da13d4a00156426300c7e30	Voyager	32.9061280995208776	-117.105281002391138
40745	2020-07-29 01:37:48	2020-07-29	Noelle Johnston	noelle.johnston@woohoo.com	New York	New York	589325397617231	d1183f42d4d8eb0a7ae9adbe5cb3a28b	Maestro	40.7588504820354274	-73.8814575340960147
40746	2020-07-29 01:42:19	2020-07-29	Ms. Dortha Stracke	ms.dortha.stracke@geemail.com	Boston	Massachusetts	3528165054471787836	97817f22665206f07646d386cc68b339	VISA 16 digit	42.314489659450949	-71.0123417219098627
40747	2020-07-29 01:42:30	2020-07-29	Ruie Mayert PhD	ruie.mayert.phd@warmmail.com	San Diego	California	3158983232343419263	073c47abe27a9a859ff5d5aba2a88b4d	Diners Club / Carte Blanche	32.8364923876311607	-117.05940159595572
40748	2020-07-29 01:44:13	2020-07-29	Lucy Ruecker	lucy.ruecker@geemail.com	Memphis	Tennessee	6011234458675633505	17d074758ac3c59cc6946961dc083411	JCB 15 digit	35.0674989193745006	-89.9800384109165492
40749	2020-07-29 01:46:14	2020-07-29	Dr. Margaretta Jacobson DVM	dr.margaretta.jacobson.dvm@warmmail.com	Aurora	Illinois	210038132177717201	d817aa72a4c4da71384e061bd5592e2f	Voyager	41.6978791157472912	-88.2596598816033406
40750	2020-07-29 01:46:35	2020-07-29	Jeana Lemke	jeana.lemke@geemail.com	Kansas City	Kansas	6011878434365597483	9ded974d20f2c0632abb48812d6d1903	VISA 16 digit	39.1256186450272807	-94.7136931476585602
40751	2020-07-29 01:59:45	2020-07-29	Shepherd Gulgowski	shepherd.gulgowski@geemail.com	Indianapolis	Indiana	3000352962694308	357793c0506c57ca8a9bbfdb59bad2ef	VISA 16 digit	39.6859501620296342	-86.0776541247233666
40752	2020-07-29 02:00:46	2020-07-29	Aleena Harvey	aleena.harvey@geemail.com	San Francisco	California	4811215410482577	066e8acec3f61458f440e12429d1010a	JCB 15 digit	37.788078205887885	-122.436263921912868
40753	2020-07-29 02:09:12	2020-07-29	Mr. Kyree Pouros	mr.kyree.pouros@warmmail.com	New York	New York	6011502637460791272	77045947cf9b8b7ff17dbc8c719ab35f	JCB 16 digit	40.7587209652867131	-73.9433563640236855
40754	2020-07-29 02:12:21	2020-07-29	Colvin Hermiston	colvin.hermiston@geemail.com	Seattle	Washington	4517135488696352	458a9fc2cbbfc28adea51f0d917777ae	VISA 16 digit	47.5839430225938571	-122.30075464494675
40755	2020-07-29 02:15:51	2020-07-29	Dr. Jerrel Halvorson	dr.jerrel.halvorson@warmmail.com	Phoenix	Arizona	3528410737040029317	91bf2d671219d27534f7c757acd1f00a	VISA 16 digit	33.5076767483659097	-112.018361830145494
40756	2020-07-29 02:15:58	2020-07-29	Darwin O'Kon	darwin.o'kon@woohoo.com	Greensboro	North Carolina	869949818003435508	ccff574b88f1f2450b77ce109522e006	Discover	36.1036072791669511	-79.8420647673755894
40757	2020-07-29 02:24:54	2020-07-29	Anice Kling DVM	anice.kling.dvm@geemail.com	Nashville	Tennessee	3528747966522241157	66de07bee5f48d65b06e6e0d9f4d64dd	VISA 16 digit	36.2706318243529608	-86.7679518159385736
40758	2020-07-29 02:28:21	2020-07-29	Dominick Krajcik DDS	dominick.krajcik.dds@woohoo.com	New York	New York	210073148004159553	662ba5d7c87cfabca565f07ab297d055	Discover	40.5968383589982977	-73.8540264629654502
40759	2020-07-29 02:30:50	2020-07-29	Lorri Gulgowski	lorri.gulgowski@geemail.com	Mesa	Arizona	3050993289731420	6b12e0fc3a1d1358b6cc3d2a53c2c72a	Mastercard	33.438693579533691	-111.777516002475835
40760	2020-07-29 02:41:17	2020-07-29	Kiersten Hilpert	kiersten.hilpert@geemail.com	Jersey City	New Jersey	3096828645264987845	68b406f132ab09f7f9528e75785cabef	JCB 15 digit	40.6820236444413652	-74.0143340255089157
40761	2020-07-29 02:43:07	2020-07-29	Derik Lind	derik.lind@woohoo.com	North Las Vegas	Nevada	3005711080818690	eb864c4673d9928d1f2e847fe7f25050	Discover	36.3434274233102812	-115.109744325069343
40762	2020-07-29 02:45:49	2020-07-29	Lyn Fadel-Pollich	lyn.fadel.pollich@geemail.com	Virginia Beach	Virginia	4130384690371	3fa61d61ae0d490adbbf2fa685b7aec4	VISA 16 digit	36.7584821161534663	-76.0844699153348785
40763	2020-07-29 02:46:07	2020-07-29	Griffin Hills	griffin.hills@geemail.com	San Antonio	Texas	869950111019602410	ffb1278387f905ee7dbd71ad14d6737b	VISA 16 digit	29.5035870385427046	-98.5391546286944191
40764	2020-07-29 02:49:56	2020-07-29	Leola Gulgowski	leola.gulgowski@woohoo.com	Dallas	Texas	4819182050768	a18900a5a4afabc6421d7e969d23a290	JCB 15 digit	32.7693717075783795	-96.7858965293001319
40765	2020-07-29 02:53:34	2020-07-29	Ewald Walter	ewald.walter@geemail.com	New York	New York	210013250612162434	b5bd1dfaf245510fd76d4c70258d0709	JCB 15 digit	40.7601749574989043	-73.929849439197028
40766	2020-07-29 03:02:19	2020-07-29	Mrs. Carlotta Hyatt	mrs.carlotta.hyatt@geemail.com	Berkeley	California	3096341757213089223	00ede3e363d0be1ba9f6257d293c5516	Mastercard	37.8947589025845915	-122.283592362227253
40767	2020-07-29 03:11:21	2020-07-29	Mr. Birt Nienow III	mr.birt.nienow.iii@geemail.com	Arlington	Texas	4515897744903797	b31d4972c8f80d3133a82e496f0cc6b7	American Express	32.7355923113197065	-97.2202487274099241
40768	2020-07-29 03:16:13	2020-07-29	Yajaira Fay	yajaira.fay@geemail.com	Knoxville	Tennessee	210030979992774561	408cd0a612e9722bd8dea63cad599d12	JCB 16 digit	35.9051047663733343	-83.9741961621895427
40769	2020-07-29 03:17:42	2020-07-29	Caleb Boehm	caleb.boehm@woohoo.com	Los Angeles	California	3754272688648385	c6efdc96a0b85061df73a8d03eaf4579	VISA 16 digit	34.0239734463725227	-118.343651481763644
40770	2020-07-29 03:22:37	2020-07-29	Joye Runolfsson	joye.runolfsson@geemail.com	Charlotte	North Carolina	869940222112108685	8a6bedb433dea567488f24a252a235e6	JCB 16 digit	35.1578566650182012	-80.8026522515751395
40771	2020-07-29 03:30:36	2020-07-29	Arah Pagac	arah.pagac@woohoo.com	Fremont	California	4019020602564574	b47c3e2ece1cb06621d2947308dc07a9	Voyager	37.4542126501612387	-122.017885355231158
40772	2020-07-29 03:41:56	2020-07-29	Media Schimmel	media.schimmel@woohoo.com	Oakland	California	55801702648473538	1ef3cd4588ab31a498601ce18b7c41a3	VISA 16 digit	37.7786901013005547	-122.274260971978421
40773	2020-07-29 03:54:33	2020-07-29	Dr. Stafford Doyle	dr.stafford.doyle@geemail.com	Cincinnati	Ohio	180001681101240832	977efb0df8cbc36a7536dad786898add	Maestro	39.2336061171486961	-84.4249532911732672
40774	2020-07-29 03:56:41	2020-07-29	Mr. Memphis O'Kon V	mr.memphis.o'kon.v@geemail.com	Colorado Springs	Colorado	4629406076513753	2dae77a6995ec551a289ba8be7c22ae2	VISA 13 digit	38.7858805427841844	-104.722194372691959
40775	2020-07-29 04:01:45	2020-07-29	Alycia Gusikowski	alycia.gusikowski@geemail.com	San Francisco	California	4795862953424472	70c94769c4a667818bcd95c9213538e8	Maestro	37.7456190176811006	-122.422507190460379
40776	2020-07-29 04:03:52	2020-07-29	Dr. Nolen Wolf	dr.nolen.wolf@woohoo.com	Saint Paul	Minnesota	3011765376963051	6bd215c792fec87c3b6932c45718d368	Mastercard	44.9423626018628468	-93.0440795893114085
40777	2020-07-29 04:17:05	2020-07-29	Mr. Ayden Corkery	mr.ayden.corkery@geemail.com	Chicago	Illinois	869926016084185277	3f0b2a69fcba32c1bdbbad5ef1ce3436	JCB 15 digit	41.7510509684517999	-87.6580049939483388
40778	2020-07-29 04:18:10	2020-07-29	Jaidyn Gislason	jaidyn.gislason@woohoo.com	Glendale	Arizona	3727622185545381	eae5dec7a03b0c3af0c707aa5286a228	VISA 16 digit	33.5915221147466454	-112.266167067249853
40779	2020-07-29 04:21:18	2020-07-29	Matilda Anderson	matilda.anderson@geemail.com	San Diego	California	3036533808844082	891fdea857101fec19f451570c11ce59	JCB 15 digit	32.882935915987197	-117.063637480456393
40780	2020-07-29 04:21:41	2020-07-29	Bertie Schulist	bertie.schulist@woohoo.com	Houston	Texas	4859479713645	1c0d942e1f8dcebb864ba3d8e564287f	VISA 13 digit	29.8089410355858497	-95.4282067636974176
40781	2020-07-29 04:22:20	2020-07-29	Blas Reichert	blas.reichert@warmmail.com	Provo	Utah	3528734426873349120	d11ff095dea6234a315a44f6f59e73ac	Voyager	40.3150752304375146	-111.713030785103513
40782	2020-07-29 04:27:36	2020-07-29	Lawanda Adams	lawanda.adams@woohoo.com	Pomona	California	3740426643847782	522932a0990774de4930d55d30d67aa3	Mastercard	34.1403580317776658	-117.842973200740659
40783	2020-07-29 04:30:27	2020-07-29	Anjali Renner	anjali.renner@geemail.com	Glendale	Arizona	3034708006023448	5dd3c59b815d9509b6c6db917bf24380	JCB 16 digit	33.5086767558701339	-112.221498093220958
40784	2020-07-29 04:30:35	2020-07-29	Seamus Stanton	seamus.stanton@geemail.com	Coral Springs	Florida	501830714892160	0968ac49ae11600208291d8129efae37	Mastercard	26.2479884720936418	-80.2634977925225996
40785	2020-07-29 04:36:35	2020-07-29	Freda Maggio	freda.maggio@geemail.com	Columbus	Ohio	4242124671718	61a3da6ec26cee6871fad4394cf1765a	VISA 13 digit	39.9809736371085052	-83.0352086934495759
40786	2020-07-29 04:40:34	2020-07-29	Toy Schaefer-Collier	toy.schaefer.collier@geemail.com	Columbus	Ohio	4472562845264	0be20721f63ca6decfdcad43511e2e0a	VISA 13 digit	40.0296977403152709	-82.9267694948475906
40787	2020-07-29 04:42:18	2020-07-29	Shayna Osinski PhD	shayna.osinski.phd@geemail.com	Arvada	Colorado	4871018746464260	943b6d1d904de5acfdd5ed912d74b9d8	VISA 16 digit	39.8028084534395461	-105.140107401923458
40788	2020-07-29 04:43:16	2020-07-29	Elige Carter	elige.carter@geemail.com	Oakland	California	676161966419121	3e0de0293edb359fb59fb07383d4a845	Maestro	37.7743332540616947	-122.259291446592101
40789	2020-07-29 04:45:37	2020-07-29	Elwyn Lockman	elwyn.lockman@warmmail.com	Boise	Idaho	210087706363376557	229561252e27afeea2ec9740a7c1cd24	Discover	43.5654806189376842	-116.187800258091471
40790	2020-07-29 04:53:42	2020-07-29	Shelly Gerlach DVM	shelly.gerlach.dvm@geemail.com	Oakland	California	869922837636572231	ea17cff58e46f6d06a24b064828f8130	Discover	37.806336923240849	-122.240950029047625
40791	2020-07-29 05:03:49	2020-07-29	Mr. Hezzie Lind DVM	mr.hezzie.lind.dvm@warmmail.com	Baltimore	Maryland	4316342983409397	74f8e41cc37a58eb8cae8e5354270b21	VISA 16 digit	39.3689547164831311	-76.6734415371920903
40792	2020-07-29 05:11:24	2020-07-29	Orelia Turcotte-Daniel	orelia.turcotte.daniel@geemail.com	Everett	Washington	3725956044618894	7d0a83dacfd9148111a7edf0bf0041f0	JCB 15 digit	47.8898361432258071	-122.205577915966145
40793	2020-07-29 05:12:13	2020-07-29	Ebert Nitzsche	ebert.nitzsche@geemail.com	Rockford	Illinois	3096105527922507872	6f8e3bd00836dc1d9df892e8462f90cd	VISA 16 digit	42.3434440142020563	-89.1511605391096253
40794	2020-07-29 05:12:57	2020-07-29	Hettie Stark	hettie.stark@geemail.com	San Francisco	California	4377868044749146	b105ac1428ce3fa89bcd545015a0d0ba	VISA 13 digit	37.7482500379597496	-122.411537117701585
40795	2020-07-29 05:31:22	2020-07-29	Zadie Beatty-Koepp	zadie.beatty.koepp@geemail.com	San Francisco	California	4657993844136814	8914fbf3d50be7a9a00181e7c3ba8dfe	Discover	37.7778196773599362	-122.433843180579686
40796	2020-07-29 05:35:02	2020-07-29	Janel Brown	janel.brown@geemail.com	Berkeley	California	180013486069602288	35b32b30d471f006f7d0ae5932eea343	JCB 15 digit	37.8474857850689688	-122.275485008399087
40797	2020-07-29 05:48:26	2020-07-29	Aden Monahan	aden.monahan@geemail.com	Boise	Idaho	3112177838360875827	d9ed3e87dfe531bc25a6bde805e88e3c	Mastercard	43.5397324183627958	-116.250425382070986
40798	2020-07-29 05:50:46	2020-07-29	Meggan Keeling	meggan.keeling@woohoo.com	Modesto	California	180016119475148417	f67ebc8b10cf17f01ca5e604e76eceb9	VISA 13 digit	37.6755661731120242	-120.962527760976926
40799	2020-07-29 05:52:26	2020-07-29	Miss Bree Zboncak	miss.bree.zboncak@warmmail.com	Kansas City	Missouri	869949414923976381	ad4dd65aa84f1b80e2a139fea24cd3da	American Express	39.0290303203113425	-94.6406115683019209
40800	2020-07-29 05:57:39	2020-07-29	Lindsey Olson	lindsey.olson@geemail.com	Los Angeles	California	210033788732325486	62c2891c241551d723c101195360a838	JCB 16 digit	34.0855486587487135	-118.474286260315395
40801	2020-07-29 05:58:29	2020-07-29	Dr. Ean Larkin	dr.ean.larkin@geemail.com	Hayward	California	4975869564784	cf31a493acf6161ca528d728b0b66284	Maestro	37.636402046912167	-122.113001910203693
40802	2020-07-29 06:04:23	2020-07-29	Hymen Kiehn-Grady	hymen.kiehn.grady@geemail.com	Cleveland	Ohio	4889269540984991	49954b359c2edcb16b72516a35728ef0	American Express	41.524547234348951	-81.7477859753422393
40803	2020-07-29 06:11:37	2020-07-29	Torrey Pouros	torrey.pouros@geemail.com	New York	New York	3017787626690973	3856ed0f29fa567d52cafa9c3a0c1368	JCB 15 digit	40.6029693914335184	-73.9949271920498433
40804	2020-07-29 06:19:41	2020-07-29	Esteban Goyette IV	esteban.goyette.iv@geemail.com	New York	New York	180074653788801329	bf011d40b34361afdeb9307f8e713ed6	VISA 16 digit	40.6343484083414097	-73.9642159946158557
40805	2020-07-29 06:20:30	2020-07-29	Gearld Nikolaus	gearld.nikolaus@woohoo.com	Houston	Texas	3042575668833097	a027c76a1cf71bc04046666b0cfa2281	Diners Club / Carte Blanche	29.841139289092645	-95.4842181384578339
40806	2020-07-29 06:39:36	2020-07-29	Doyle Zboncak DVM	doyle.zboncak.dvm@geemail.com	Hialeah	Florida	4984033212826169	dc863f3ae54a137cb9bcabac517970a6	JCB 16 digit	25.8551369671687503	-80.2325259079128443
40807	2020-07-29 06:57:56	2020-07-29	Dezzie Abshire DVM	dezzie.abshire.dvm@geemail.com	San Diego	California	3053672163413647	f0827685dcfa9fe83c107d271bba1ce2	JCB 16 digit	32.8412280623868114	-117.226439077397814
40808	2020-07-29 07:13:06	2020-07-29	Dakotah Rippin Jr.	dakotah.rippin.jr.@geemail.com	New York	New York	4214423912313737	36951a4cb168fe8fb2693b8caaf808c2	American Express	40.6250841079503289	-73.889495403448862
40809	2020-07-29 07:21:34	2020-07-29	Weldon Greenholt	weldon.greenholt@geemail.com	Orange	California	3337781576377392901	0eb50fcceef202356b56ae74a744bb1b	JCB 16 digit	33.8694856583494683	-117.856327277898046
40810	2020-07-29 07:23:14	2020-07-29	Imelda Quigley DDS	imelda.quigley.dds@geemail.com	Boise	Idaho	4811503884627029	86748f38a7841598ce0625c9384e42c1	JCB 16 digit	43.6314622056342643	-116.321814217391236
40811	2020-07-29 07:25:18	2020-07-29	Haruko Stark	haruko.stark@geemail.com	Anaheim	California	6011174977229345789	2512b6c73a6ed2936f307c46d767331e	VISA 16 digit	33.8641533149704301	-117.743914229024568
40812	2020-07-29 07:26:23	2020-07-29	Dr. Dozier Bosco	dr.dozier.bosco@warmmail.com	Corpus Christi	Texas	3059488446877605	7635c8479d3f379ad89a9444358a556d	VISA 13 digit	27.7535934347130357	-97.1664927224922934
40813	2020-07-29 07:47:56	2020-07-29	Harvy Cummerata	harvy.cummerata@warmmail.com	Lubbock	Texas	3013185542956681	d493d273389ad13626e76e3d27e5ed22	Mastercard	33.5135050123598432	-101.819643919533874
40814	2020-07-29 07:54:43	2020-07-29	Erwin O'Hara	erwin.o'hara@geemail.com	Rochester	Minnesota	4759635423149	1f67c19a1bf6683882937ab62a0564d4	Voyager	43.971357335093991	-92.4704268653996309
40815	2020-07-29 08:00:19	2020-07-29	Dema Gusikowski	dema.gusikowski@geemail.com	Berkeley	California	3112542296676733248	fcec8165766023cc52853eeafb5fc3fa	JCB 15 digit	37.8916536621489968	-122.271436447976882
40816	2020-07-29 08:05:39	2020-07-29	Dr. Waymon Upton	dr.waymon.upton@geemail.com	Dayton	Ohio	52887043966626606	b1b605445a0dcc3e27f9d20ec063eaa7	Discover	39.7293437483977527	-84.2084849942199867
40817	2020-07-29 08:10:34	2020-07-29	Dr. Geo Schulist Jr.	dr.geo.schulist.jr.@geemail.com	Boston	Massachusetts	4094087904314071	06fd3635541cfb6a2ee6e86478106fac	Diners Club / Carte Blanche	42.3920841592531659	-71.0058713032349971
40818	2020-07-29 08:21:34	2020-07-29	Tavaris Dooley	tavaris.dooley@geemail.com	Berkeley	California	4009485326703521	63718615b98f537e00732e1874ff05b3	JCB 15 digit	37.8382568110569295	-122.280143058762093
40819	2020-07-29 08:22:08	2020-07-29	Ms. Vesta Quigley DVM	ms.vesta.quigley.dvm@geemail.com	Syracuse	New York	210015204932801088	a22ff8161363b013591aaa7322f92a38	VISA 16 digit	43.0079660647399677	-76.1588392365504063
40820	2020-07-29 08:22:12	2020-07-29	Raul Brown	raul.brown@geemail.com	Santa Clarita	California	4951352259465817	4c0115b126065477993e0941fc2d2610	Diners Club / Carte Blanche	34.3815853028763101	-118.538281504354245
40821	2020-07-29 08:25:25	2020-07-29	Franklyn Anderson	franklyn.anderson@geemail.com	Lexington	Kentucky	3019597947388373	223b4810259b94368af49e4620024814	Maestro	38.1089400837540637	-84.4360485811617139
40822	2020-07-29 08:30:32	2020-07-29	Redmond Hagenes DDS	redmond.hagenes.dds@geemail.com	Houston	Texas	3440838283722754	6eb2ffa91f204f072e35c828672aecf1	VISA 16 digit	29.7958742301523678	-95.388016843145337
40823	2020-07-29 08:32:31	2020-07-29	Shanae Schroeder	shanae.schroeder@geemail.com	Corpus Christi	Texas	3096721075885343897	275be2b6c20b3ad050669868e2c9076a	American Express	27.7563048222504563	-97.2117041012566574
40824	2020-07-29 08:33:04	2020-07-29	Harriett Sporer	harriett.sporer@woohoo.com	Louisville	Kentucky	4437966635261261	2e555f0d9bfcdc01f4a2792f86c1eecd	JCB 16 digit	38.2080682541146857	-85.6845986381243989
40825	2020-07-29 08:35:01	2020-07-29	Mrs. Crystal Mann	mrs.crystal.mann@geemail.com	Philadelphia	Pennsylvania	4561361965750	b7e016237c772119c40262b8b8bc093e	JCB 16 digit	40.0970421982422494	-75.1508434556789808
40826	2020-07-29 08:37:02	2020-07-29	Mamie Keeling	mamie.keeling@warmmail.com	Los Angeles	California	502052587842924	d7efa65faa9ec91892687760735f332b	VISA 16 digit	34.0794853697862479	-118.422852061734716
40827	2020-07-29 08:38:38	2020-07-29	Vanesa Osinski	vanesa.osinski@geemail.com	Sunnyvale	California	3031637786516615	d21dbfecf4c3403ba13a7d0ddbe661b1	JCB 15 digit	37.4811722652047905	-121.942483595079935
40828	2020-07-29 08:44:54	2020-07-29	Suzette Dare-Renner	suzette.dare.renner@geemail.com	Virginia Beach	Virginia	4941491747690892	5dd16d3f5f7b6cfff136592f3f449df8	JCB 16 digit	36.7178804311621931	-76.0869816173937181
40829	2020-07-29 08:59:29	2020-07-29	Clifford Auer	clifford.auer@geemail.com	New York	New York	676245897606401	d501c0c5659e46b4b9eb7ee09a2ce430	American Express	40.7283239337373502	-73.9244578432653014
40830	2020-07-29 09:01:35	2020-07-29	Mr. Carroll Hayes	mr.carroll.hayes@geemail.com	Cincinnati	Ohio	54231197068868319	44d516b05ed40b3eb9ffc136d74a06f8	VISA 16 digit	39.1216103879965829	-84.4229776822302398
40831	2020-07-29 09:04:11	2020-07-29	Honora Kemmer	honora.kemmer@geemail.com	San Francisco	California	4845116542299	ac38a8d6144719157c1498f5a72e4105	Voyager	37.7770560348973206	-122.43637252212838
40832	2020-07-29 09:04:56	2020-07-29	Miss Yadira Quitzon PhD	miss.yadira.quitzon.phd@geemail.com	Garland	Texas	53720720678013634	dc31f18376e945ba8cd8a435b1f320a3	Voyager	32.8867728963263275	-96.6831017291333552
40833	2020-07-29 09:06:10	2020-07-29	Margaretha Rath	margaretha.rath@warmmail.com	Thornton	Colorado	4158805960639518	a579954d6235b069056234aceb0a0815	VISA 13 digit	39.8633889899455056	-104.949709060804182
40834	2020-07-29 09:07:46	2020-07-29	Corean Leuschke DVM	corean.leuschke.dvm@warmmail.com	Pittsburgh	Pennsylvania	4678239688914626	10fb2e8860b0f80db55f3771969c297b	Discover	40.4553214725062205	-79.9000204448759632
40835	2020-07-29 09:09:36	2020-07-29	Ivey Haag	ivey.haag@geemail.com	Boston	Massachusetts	3337266970896494120	d4e56cacf64be544c92b233ce91450bb	VISA 16 digit	42.2440853908359983	-71.0555776307310936
40836	2020-07-29 09:17:47	2020-07-29	Henrietta Morar	henrietta.morar@geemail.com	New York	New York	55447642006654503	186c9091914763589eec63fb35d243c1	JCB 15 digit	40.7079275350775589	-73.8922796692129253
40837	2020-07-29 09:22:31	2020-07-29	Odalis Fay	odalis.fay@warmmail.com	Omaha	Nebraska	869976852089091501	fd98007d363dd4a9b8bb9fd587249bb2	VISA 13 digit	41.3530749690864283	-96.0733253982499349
40838	2020-07-29 09:22:41	2020-07-29	Phyllis Collins	phyllis.collins@geemail.com	Centennial	Colorado	869953452335407010	3daa7940ce8c40ef31a8cd2563872774	Discover	39.6479293510824462	-104.787312661193681
40839	2020-07-29 09:22:54	2020-07-29	Codie Kling	codie.kling@warmmail.com	Denver	Colorado	3041347161077361	f94d82f40f6bee05bec31cf8f4c16251	VISA 16 digit	39.6812892727140323	-104.91935404853561
40840	2020-07-29 09:23:07	2020-07-29	Gasper Ward	gasper.ward@geemail.com	Charlotte	North Carolina	3030401207868993	893d85c537823375af16b05ff4edde9c	JCB 16 digit	35.252810135229673	-80.7422015020568011
40841	2020-07-29 09:25:08	2020-07-29	Lannie Pfannerstill-Haley	lannie.pfannerstill.haley@geemail.com	Seattle	Washington	630454511489004	9ee24b0ef0da26c4a487a773ca4ea33b	Voyager	47.5940319196712238	-122.383184675724806
40842	2020-07-29 09:33:37	2020-07-29	Jacqulyn Leuschke MD	jacqulyn.leuschke.md@warmmail.com	Oklahoma City	Oklahoma	4626356112956354	09db8a310c6e6f08d1f55ff6740bc7bc	VISA 16 digit	35.4700236840549863	-97.5287784885045141
40843	2020-07-29 09:43:10	2020-07-29	Korey Sauer	korey.sauer@geemail.com	Raleigh	North Carolina	4402169187992	44be38194ddf0bc0e3154a253359a981	VISA 16 digit	35.9181706916209293	-78.5898519623961391
40844	2020-07-29 09:44:46	2020-07-29	Nery Goodwin MD	nery.goodwin.md@warmmail.com	Carrollton	Texas	3010975019876666	8a75778261f0028daf694608ae4714e4	JCB 16 digit	33.0141368421182051	-96.954737046719714
40845	2020-07-29 09:51:36	2020-07-29	Daija Kozey	daija.kozey@geemail.com	Sacramento	California	6011350139260943297	b1b1d613bd1a1594124cc39ddb4df15f	Mastercard	38.4967357941701991	-121.55379914667121
40846	2020-07-29 09:52:28	2020-07-29	Jasmin Bergnaum	jasmin.bergnaum@geemail.com	Broken Arrow	Oklahoma	4796602248447212	a48f426484a9bd15a08cabb3113acc34	Diners Club / Carte Blanche	36.0801808256432395	-95.8191075893528819
40847	2020-07-29 09:55:47	2020-07-29	Karma Ondricka-Rowe	karma.ondricka.rowe@geemail.com	Kansas City	Missouri	3487754038398887	4cee67c5ed12bd9038eb67a9b569e029	American Express	39.1194902669008826	-94.4711857771258821
40848	2020-07-29 09:58:17	2020-07-29	Mena Stamm MD	mena.stamm.md@warmmail.com	Oakland	California	180050056514341677	9ed49025879d6f8a2c64644efdc29b9b	Discover	37.8237321582772807	-122.26083094283166
40849	2020-07-29 10:00:03	2020-07-29	Mrs. Adda Barton PhD	mrs.adda.barton.phd@geemail.com	Denver	Colorado	6011476943786658944	074ed54a63db2c74337e12d99d0ab360	JCB 16 digit	39.7983452159497872	-104.792521833233906
40850	2020-07-29 10:00:15	2020-07-29	Evita Bergnaum	evita.bergnaum@woohoo.com	Santa Ana	California	52649791703930462	b27955aa838165b8af8529d7598eb937	JCB 16 digit	33.8219344019994139	-117.785583542698987
40851	2020-07-29 10:03:52	2020-07-29	Andrae Kling	andrae.kling@woohoo.com	Cape Coral	Florida	4032891147153732	22d6cd502890947935cf206674d5517b	JCB 16 digit	26.6051643198791901	-82.0891682088445833
40852	2020-07-29 10:13:21	2020-07-29	Carolann Morissette	carolann.morissette@warmmail.com	Midland	Texas	869956301882629582	189c6ffc4709a1800cceedd27fc32a66	JCB 16 digit	31.9861595700219254	-102.019979168171062
40853	2020-07-29 10:15:48	2020-07-29	Emit Leuschke IV	emit.leuschke.iv@geemail.com	Berkeley	California	869994551462536326	1526b11f97abde5aeb2f043e145feee3	Diners Club / Carte Blanche	37.8708964283603535	-122.256638287640726
40854	2020-07-29 10:17:44	2020-07-29	Dr. Valentin Ernser	dr.valentin.ernser@warmmail.com	Los Angeles	California	51162743756149125	50c99745e0e6a1e0e54be152f8676534	VISA 16 digit	34.0966993426769918	-118.423721402743084
40855	2020-07-29 10:19:37	2020-07-29	Mr. Malcom Wehner IV	mr.malcom.wehner.iv@warmmail.com	Lakeland	Florida	3410970828269243	26a70a2d136db34b9bf074346a36dbdc	Maestro	28.1165012635122977	-81.8778596645105523
40856	2020-07-29 10:27:22	2020-07-29	Mitchell Bashirian	mitchell.bashirian@geemail.com	Salt Lake City	Utah	52753696914005370	2a537c500216f5eb83a1f408f35f500e	American Express	40.7171461779769501	-111.93352427700907
40857	2020-07-29 10:33:36	2020-07-29	Phoebe Maggio MD	phoebe.maggio.md@warmmail.com	Tuscaloosa	Alabama	3158485226060364499	3c0e78b3f362df2d7d1c6f98ff5ce236	VISA 16 digit	33.2096186809297649	-87.5534198485877369
40858	2020-07-29 10:36:28	2020-07-29	Buena White DDS	buena.white.dds@geemail.com	Lexington	Kentucky	52753016276203986	0cda57e174769fdf6c97e8414cf3d0af	JCB 15 digit	38.0721996672328586	-84.3990399474643169
40859	2020-07-29 11:02:47	2020-07-29	Ms. Consuelo Kling	ms.consuelo.kling@warmmail.com	Memphis	Tennessee	869938400864209190	3615fba7c658342badc5d7c3f18d6207	Diners Club / Carte Blanche	35.0934390919815797	-90.0190034186258998
40860	2020-07-29 11:20:43	2020-07-29	Kelan Brown	kelan.brown@geemail.com	New York	New York	3039263901412986	a43966b4ae1204f47914d9cc1e3a03cf	VISA 16 digit	40.7162211794629698	-74.0095656331524197
40861	2020-07-29 11:35:12	2020-07-29	Zoey Skiles	zoey.skiles@woohoo.com	Chicago	Illinois	4880519865430247	ddfdffeacf0804d0a8b49f75269ecc88	Voyager	41.8585566135425111	-87.5854332685500339
40862	2020-07-29 11:35:43	2020-07-29	Auguste Kiehn	auguste.kiehn@woohoo.com	Los Angeles	California	180065840447243685	af9e6acb5044147a2c3f7a5dd97f7758	American Express	34.028925188012046	-118.460955509961764
40863	2020-07-29 11:36:00	2020-07-29	Jeromy Moen I	jeromy.moen.i@geemail.com	San Diego	California	4201143109746	0e4598a6d0114ce6fda2574b715accfa	Voyager	32.8960539043948046	-117.234775800993674
40864	2020-07-29 11:37:28	2020-07-29	Emma Gaylord	emma.gaylord@geemail.com	Newport News	Virginia	4251023737876	4131a3ddbcaaf4aeb32b5e0b9675e60a	JCB 15 digit	37.1073515115667121	-76.582869677504533
40865	2020-07-29 11:41:20	2020-07-29	Alan Zieme MD	alan.zieme.md@geemail.com	Glendale	California	51332842914318138	c8eb56f9c222cf3ea68bffd61395bf0f	JCB 15 digit	34.1644560581758583	-118.258148966207358
40866	2020-07-29 11:49:33	2020-07-29	Firman Glover	firman.glover@geemail.com	Everett	Washington	4276079675245394	a81b75c8fa90bb5245a37c8e0c897677	JCB 15 digit	48.0055489770494432	-122.2256654499691
40867	2020-07-29 11:51:03	2020-07-29	Dr. Eola Ratke	dr.eola.ratke@geemail.com	Montgomery	Alabama	3337790833039405095	23800397aa0d95757715a528f18d0691	JCB 15 digit	32.2893757770702265	-86.3166894660949708
40868	2020-07-29 11:55:10	2020-07-29	Renaldo Stroman	renaldo.stroman@geemail.com	Chicago	Illinois	52874865807258875	e78b1152f841f1051841bfcb1ac9236d	Voyager	41.7859228101860722	-87.7336684700131428
40869	2020-07-29 12:00:48	2020-07-29	Geary Rodriguez-Botsford	geary.rodriguez.botsford@geemail.com	San Jose	California	3088095328672054336	4733a5340c442260f5a9d26a31fbf4b9	American Express	37.2679940541096073	-121.86049545837902
40870	2020-07-29 12:01:43	2020-07-29	Dr. Jax Haag DDS	dr.jax.haag.dds@geemail.com	Yonkers	New York	869959558729728193	b7155157c283bf9d9ae375975d860cd2	JCB 16 digit	41.0125936752852098	-73.7726169480826712
40871	2020-07-29 12:12:13	2020-07-29	Luciano Kris	luciano.kris@warmmail.com	Stamford	Connecticut	4101941424417742	121f0ddde620d091e170c9c879bb452c	VISA 16 digit	41.1747509393725579	-73.5683248225636817
40872	2020-07-29 12:17:32	2020-07-29	Kirt Breitenberg	kirt.breitenberg@geemail.com	Grand Rapids	Michigan	4963040586945009	a0601677f2f55a5b44a26d50f36105b9	Diners Club / Carte Blanche	43.0325077430613305	-85.659655530997
40873	2020-07-29 12:29:19	2020-07-29	Eathel Kilback	eathel.kilback@woohoo.com	Orlando	Florida	54420399525836613	9296b9ab60b50f5f531a09e68f323ea0	JCB 16 digit	28.4665730466399332	-81.2172456623487165
40874	2020-07-29 12:30:26	2020-07-29	Alberta Osinski	alberta.osinski@woohoo.com	New York	New York	503894466714147	0e0bf5905d8f131e57499dc376c038d3	Maestro	40.571712938206268	-74.0284406068630432
40875	2020-07-29 12:33:09	2020-07-29	Del Cormier	del.cormier@geemail.com	Knoxville	Tennessee	3787334217234508	7c17ce12c041e99ad41a8debb0f77183	American Express	35.8865790585119271	-83.879879448584461
40876	2020-07-29 12:37:06	2020-07-29	Mia Waters	mia.waters@geemail.com	Houston	Texas	869941195065860370	86d1552d79bcbeec389b1a05111d4f32	JCB 15 digit	29.8297565190665424	-95.3516877549249671
40877	2020-07-29 12:41:52	2020-07-29	Mr. Franklyn Senger V	mr.franklyn.senger.v@geemail.com	Pittsburgh	Pennsylvania	3420827200895383	b5a410a48431301825459d181d5d2af2	Mastercard	40.4366139502219823	-80.0386236849412427
40878	2020-07-29 12:42:32	2020-07-29	Pamela Kshlerin	pamela.kshlerin@woohoo.com	Waco	Texas	3703077382991946	d3f588c27ef73e1faf4a33c1500b42cd	JCB 16 digit	31.6135861019346862	-97.2407416221350474
40879	2020-07-29 12:45:28	2020-07-29	Dr. Joellen Considine DDS	dr.joellen.considine.dds@woohoo.com	Portland	Oregon	6011279747543605588	f9810ea013287bc20213c5e6d568f101	Discover	45.5310081452950826	-122.591422672476625
40880	2020-07-29 13:02:01	2020-07-29	Permelia Brown	permelia.brown@geemail.com	Santa Clarita	California	53314155174637416	fae6b62852eb58778342e64f1a9b11a4	JCB 16 digit	34.3270853427443612	-118.517457652753961
40881	2020-07-29 13:03:44	2020-07-29	Jerilynn Jenkins-Satterfield	jerilynn.jenkins.satterfield@geemail.com	New York	New York	3337023696257360287	b4317d19bf781d4ee7ae55d2c0a7d8e7	JCB 16 digit	40.5729021507073213	-73.9999394431140303
40882	2020-07-29 13:03:47	2020-07-29	Lenard Wilkinson	lenard.wilkinson@geemail.com	Las Vegas	Nevada	3528076035105012160	bbdef88d854f0e586091f28f62954b15	VISA 13 digit	36.1328080541554826	-115.261485833695531
40883	2020-07-29 13:08:02	2020-07-29	Cathleen Tillman	cathleen.tillman@geemail.com	Macon	Georgia	54513876530409351	cda9c11268713e2acf5a3c347a311174	Maestro	32.8080774063255589	-83.6921682375211162
40884	2020-07-29 13:09:48	2020-07-29	Daulton Towne-Sawayn	daulton.towne.sawayn@geemail.com	Dayton	Ohio	4314972491790953	fb773ad7e8b696ca11c99baf71fff17a	JCB 16 digit	39.6823519250169383	-84.2739988327216452
40885	2020-07-29 13:33:16	2020-07-29	Jairo Quitzon	jairo.quitzon@geemail.com	North Las Vegas	Nevada	4721982748523401	12b49d78936dc5c507a3df1a89ec31bb	American Express	36.3573350539587423	-115.038366862315314
40886	2020-07-29 13:38:25	2020-07-29	Arthur Kub	arthur.kub@geemail.com	Mesa	Arizona	676305310489975	a5899c367dcb32a0c3f2567aac3fd7b2	JCB 15 digit	33.3350394973210982	-111.657761616201697
40887	2020-07-29 14:02:11	2020-07-29	Braylen Kessler	braylen.kessler@geemail.com	Warren	Michigan	4213826034711	2d592826883b8e607ee6795b0e199e86	Mastercard	42.5483356711450966	-82.9494804165326087
40888	2020-07-29 14:05:19	2020-07-29	Kavon Bode-Robel	kavon.bode.robel@geemail.com	Green Bay	Wisconsin	869911350758478834	f9c9b98c6382c51256071000562c1631	VISA 16 digit	44.5990799029886702	-87.9939152054775491
40889	2020-07-29 14:11:25	2020-07-29	Estefany Ritchie	estefany.ritchie@woohoo.com	San Francisco	California	4438508786216949	410a13733b4e702517f1c4beac1b7a7b	Mastercard	37.72468808179174	-122.431920989119646
40890	2020-07-29 14:13:50	2020-07-29	Ocie Roob-Ullrich	ocie.roob.ullrich@geemail.com	Dallas	Texas	52248214187463384	348261e173911b5209114bc315c71b61	VISA 16 digit	32.7696102394063047	-96.6807908788751718
40891	2020-07-29 14:16:03	2020-07-29	Harve Dooley	harve.dooley@geemail.com	Chicago	Illinois	4623080589680478	7ceaaf4203f171a1e8ee3299d968b2e7	American Express	41.832125689911102	-87.7722973917175011
40892	2020-07-29 14:16:11	2020-07-29	Karren Hickle	karren.hickle@geemail.com	Orlando	Florida	6011440312462113223	b261beda2426d9efd4c19abce15cb68d	VISA 16 digit	28.3410561378844079	-81.309916206585612
40893	2020-07-29 14:19:41	2020-07-29	Dr. Captain Yost DDS	dr.captain.yost.dds@geemail.com	New York	New York	675989843639967	b325e748b1f090dfabc481ad0cbefe96	VISA 16 digit	40.6687819911856181	-73.8950454652670743
40894	2020-07-29 14:35:47	2020-07-29	Mr. Casey Steuber I	mr.casey.steuber.i@geemail.com	Glendale	California	502030060565360	ac1026c7f08f562ca52e9743237529ce	JCB 15 digit	34.1148687820635672	-118.331359100378307
40895	2020-07-29 14:43:17	2020-07-29	Marita McClure	marita.mcclure@warmmail.com	League City	Texas	4498651762484177	113ef032111f562e09ab41276d0d7652	Discover	29.4399498299159141	-95.0463415950521835
40896	2020-07-29 14:45:32	2020-07-29	Ms. Alpha Russel DDS	ms.alpha.russel.dds@geemail.com	Rochester	New York	3014017055531545	533a06bdc883d8e66118e142e0019541	Mastercard	43.1933792386181636	-77.6752321426995138
40897	2020-07-29 14:47:25	2020-07-29	Filomena Feest	filomena.feest@geemail.com	Washington	District of Columbia	4575056092868741	6afa6c50ba83f58a5d571cf847c37574	Diners Club / Carte Blanche	38.9831501549374337	-76.9932588259436272
40898	2020-07-29 14:47:31	2020-07-29	Retha Rodriguez	retha.rodriguez@geemail.com	Corpus Christi	Texas	4335201029388980	e925b18c741e23af30a8d16df4a72627	American Express	27.8206534853607437	-97.1416641961611873
40899	2020-07-29 14:50:41	2020-07-29	Beckett Rau-Fay	beckett.rau.fay@geemail.com	San Francisco	California	3528384817061812312	1d6a3662154d2099655063e2ce671d7b	Diners Club / Carte Blanche	37.799044395875093	-122.437024050602247
40900	2020-07-29 14:51:43	2020-07-29	Harley Rempel	harley.rempel@geemail.com	Houston	Texas	4242398045617772	7d65b33ea5807b679ac9ade51151bdc9	JCB 16 digit	29.8573212738227092	-95.3519293272417059
40901	2020-07-29 15:03:27	2020-07-29	Theodosia Gorczany	theodosia.gorczany@geemail.com	San Francisco	California	210078133366944664	db70987416d89d19d94cbd994ad95ac9	JCB 15 digit	37.7668585042898499	-122.433828747678575
40902	2020-07-29 15:09:40	2020-07-29	Abraham Green	abraham.green@geemail.com	Anaheim	California	502025470041739	4f87deb72ad6dafce75c03deffc8c42e	American Express	33.7819115238096543	-117.833415986106161
40903	2020-07-29 15:10:06	2020-07-29	Tavian Bernhard Jr.	tavian.bernhard.jr.@woohoo.com	Philadelphia	Pennsylvania	3034143934583935	177a6b41d2095202279dad5d921c1891	Maestro	39.9506832657340922	-75.1827956330862008
40904	2020-07-29 15:14:05	2020-07-29	Elaine Wiza	elaine.wiza@warmmail.com	Fontana	California	53374896716222640	4167945874dc7b21c99d7054f812f5ca	Mastercard	34.1120970398336638	-117.429076880616705
40905	2020-07-29 15:19:44	2020-07-29	Dr. Korbin Corkery IV	dr.korbin.corkery.iv@woohoo.com	Little Rock	Arkansas	4387683940647015	29e7d906ab1948903684acc07760e53a	American Express	34.8178179311376041	-92.3274644330017225
40906	2020-07-29 15:23:55	2020-07-29	Mr. Mauricio Sauer Jr.	mr.mauricio.sauer.jr.@geemail.com	Los Angeles	California	4983019146023	a68b54d1970199446b4c5fbeb7222799	Diners Club / Carte Blanche	34.1135394700203065	-118.470028273434565
40907	2020-07-29 15:33:28	2020-07-29	Lennon Graham	lennon.graham@geemail.com	Oakland	California	676294582045087	a8d4de97670b0003bb4a4576923af2d8	VISA 16 digit	37.8340456176149402	-122.250870745291024
40908	2020-07-29 15:37:30	2020-07-29	Dr. Nancy Mayer	dr.nancy.mayer@geemail.com	Albuquerque	New Mexico	4983903943782041	40c6bff1ea51f0a0802370e53ea18821	American Express	35.1205568541906814	-106.731734767283882
40909	2020-07-29 15:41:03	2020-07-29	Simmie Donnelly	simmie.donnelly@geemail.com	Albuquerque	New Mexico	3045792038181316	c80c68135bfd218b9f980a36c009752b	JCB 15 digit	35.0940677463211159	-106.562271218428023
40910	2020-07-29 15:45:08	2020-07-29	Lemuel Lakin-Kub	lemuel.lakin.kub@warmmail.com	Jacksonville	Florida	3096242650444251722	e0292afeaa3c570a1f6cf0183fbf6f50	VISA 16 digit	30.2671559163421406	-81.6438117654141138
40911	2020-07-29 15:58:10	2020-07-29	Miss Brynlee Haley	miss.brynlee.haley@geemail.com	New Orleans	Louisiana	3112984745109885764	3822e02feb97c22248c3346106b9b20e	JCB 16 digit	30.1457619219101964	-90.0069804047495126
40912	2020-07-29 16:01:30	2020-07-29	Jovany Greenholt	jovany.greenholt@geemail.com	Philadelphia	Pennsylvania	55243719287741732	973d30c96f4c54c8009e8e54d9ecc85a	Voyager	40.0065200139727466	-75.0524432573832598
40913	2020-07-29 16:02:35	2020-07-29	Jena Schultz-Legros	jena.schultz.legros@woohoo.com	Lafayette	Louisiana	869905534227360677	9fc66d0f1b23e007ae462105466f3a72	VISA 16 digit	30.3053228914715334	-92.0051945118084546
40914	2020-07-29 16:05:06	2020-07-29	Candyce Borer DDS	candyce.borer.dds@geemail.com	New York	New York	4691871377180011	d4848540bdf6f6aec532ce657f619b59	JCB 15 digit	40.5710504062231649	-73.8825147026579856
40915	2020-07-29 16:05:15	2020-07-29	Mr. Kamden Huel PhD	mr.kamden.huel.phd@geemail.com	Montgomery	Alabama	6011892719562001145	789f85dcf0f137fe0d88fcf6d27043da	Discover	32.2762319302119352	-86.2043896434049941
40916	2020-07-29 16:05:53	2020-07-29	Dante Mayert	dante.mayert@geemail.com	Salem	Oregon	4039203744022	6f57771ba4addb7a8590b5acb36ad786	JCB 16 digit	44.884599014817546	-122.989435772985971
40917	2020-07-29 16:06:27	2020-07-29	Roland Jacobson III	roland.jacobson.iii@geemail.com	Berkeley	California	3449394056968605	93a077959982e73a72ece672bda88198	Mastercard	37.8719989126737673	-122.239616583728321
40918	2020-07-29 16:30:40	2020-07-29	Nataly Reynolds	nataly.reynolds@geemail.com	Los Angeles	California	3528363671286337315	204c4084f6b53f6d9d39c73a7118983a	JCB 15 digit	34.1121797552663821	-118.485538887185228
40919	2020-07-29 16:31:59	2020-07-29	Dr. Victorine Treutel MD	dr.victorine.treutel.md@geemail.com	Austin	Texas	3011203719972720	1d77083ea74aecf596af3b60dbaa1a29	Voyager	30.3821375616487117	-97.7915800723951349
40920	2020-07-29 16:33:26	2020-07-29	Elon Paucek	elon.paucek@woohoo.com	Lakewood	New Jersey	52947303463715353	3fad2334806b8ae89242241a8be8605e	VISA 13 digit	40.1310576853625491	-74.17260704159699
40921	2020-07-29 16:40:06	2020-07-29	Farrah Casper-Schmidt	farrah.casper.schmidt@geemail.com	San Antonio	Texas	3158271035507623385	ef2b624a74cca51cfac40c1c8bcae8d9	VISA 16 digit	29.558117106843369	-98.5135900792036097
40922	2020-07-29 16:40:58	2020-07-29	Fount Hane	fount.hane@warmmail.com	Charlotte	North Carolina	210070771574553724	657aaabec5c952c6cd1dc0022930cc4d	Maestro	35.2777523776769613	-80.8266580606289295
40923	2020-07-29 16:42:18	2020-07-29	Shelbi Stoltenberg	shelbi.stoltenberg@geemail.com	Amarillo	Texas	54288423778803947	7bf644d4ffc7196df3b00587d21a33ed	Mastercard	35.1598488923326116	-101.920975985782974
40924	2020-07-29 16:49:58	2020-07-29	Rexford Jast	rexford.jast@woohoo.com	Tulsa	Oklahoma	52611441177969315	32521b331be1afaf818076b9b4f069ef	JCB 16 digit	36.0392168348092525	-95.947207013606274
40925	2020-07-29 16:50:52	2020-07-29	Sharon Cole-Bogisich	sharon.cole.bogisich@geemail.com	Chicago	Illinois	3714560731367733	ec8844459d8904fae71526a318360c5c	Maestro	41.883232741693412	-87.7376463042601955
40926	2020-07-29 16:51:35	2020-07-29	Mr. Peyton Padberg DDS	mr.peyton.padberg.dds@geemail.com	Carrollton	Texas	53182815305944366	61561a5d1d9054a77d61eabded7d25dc	JCB 16 digit	32.9846273923680187	-96.8677583533666962
40927	2020-07-29 16:51:58	2020-07-29	Hughes Streich	hughes.streich@geemail.com	Scottsdale	Arizona	3158954649797175023	f0e82896558ad964c1c8f9b2efab1224	Mastercard	33.6711492851499443	-111.826554533090814
40928	2020-07-29 16:53:32	2020-07-29	Mrs. Delinda Mertz	mrs.delinda.mertz@geemail.com	Anaheim	California	3058077404058679	954e426c2b73d0bed25157160d6093d6	JCB 16 digit	33.8591940391641089	-117.806555408958715
40929	2020-07-29 17:10:22	2020-07-29	Adron Vandervort	adron.vandervort@geemail.com	San Francisco	California	6011857723166392515	c4ac039b51b3da657eb4d966e78c322a	Voyager	37.7745344900329698	-122.435990455338882
40930	2020-07-29 17:11:41	2020-07-29	Matteo Gerlach	matteo.gerlach@warmmail.com	Little Rock	Arkansas	4284201456414326	9e088fec5f2291b1a2c9d8a6f9a7a950	Maestro	34.811216443385554	-92.2862666975580055
40931	2020-07-29 17:19:04	2020-07-29	Dr. Olaf Mohr	dr.olaf.mohr@geemail.com	Stockton	California	180001312834436014	e09d6c80b0be902749565a18e2dbf925	Voyager	37.9833247880183151	-121.224106230455632
40932	2020-07-29 17:21:24	2020-07-29	Edward Sporer	edward.sporer@woohoo.com	Hartford	Connecticut	51232288650892582	f0d8579e63e7b9a9c23baecc86ff0ed1	JCB 16 digit	41.7877994412105522	-72.6178791602034153
40933	2020-07-29 17:22:46	2020-07-29	Elisa Koss	elisa.koss@geemail.com	Killeen	Texas	6011583805858870246	da7909e54cbd428904b9dfb78560bc09	JCB 16 digit	31.0022756473857903	-97.7785230383910289
40934	2020-07-29 17:24:12	2020-07-29	Levi Rau	levi.rau@geemail.com	Manchester	New Hampshire	503822727924734	6108b88aad5f727b993d8c8e4ef5791a	Mastercard	42.9122553462233398	-71.4536699377357962
40935	2020-07-29 17:48:23	2020-07-29	Mr. Codi Bailey Jr.	mr.codi.bailey.jr.@geemail.com	Denver	Colorado	4635750877733	d958896b0ae20230157db9bb813240ac	JCB 16 digit	39.7116998636681586	-104.912429234037546
40936	2020-07-29 18:04:23	2020-07-29	Kennedy Johnson PhD	kennedy.johnson.phd@geemail.com	Springfield	Illinois	210072754402021781	4914428d01a0537e90b4239b1ca31be8	Diners Club / Carte Blanche	39.7101167944878313	-89.5477962331850108
40937	2020-07-29 18:04:29	2020-07-29	Beverley Marks	beverley.marks@geemail.com	Boise	Idaho	630490051468420	b4519049afd6f4bf914cb05efc07fae5	JCB 16 digit	43.6360884721063087	-116.190169227608294
40938	2020-07-29 18:05:32	2020-07-29	Mozella Rohan-Sporer	mozella.rohan.sporer@geemail.com	St. Petersburg	Florida	3036201001395811	9f128d7d6a56865c7f99a507616801e7	Discover	27.7417843281645347	-82.7391147924479071
40939	2020-07-29 18:08:50	2020-07-29	Dijon Cole	dijon.cole@geemail.com	Colorado Springs	Colorado	180038647500440288	0036c10aec21b905adb1721b6766ddc9	Voyager	38.7953474135652172	-104.75013199110218
40940	2020-07-29 18:13:56	2020-07-29	Sophronia Grady	sophronia.grady@geemail.com	Fremont	California	180001635076319609	eb8da26f106decbeae46974a28a72880	American Express	37.4670077449344134	-121.881312885972477
40941	2020-07-29 18:18:52	2020-07-29	Audry Blanda	audry.blanda@geemail.com	New York	New York	502051157313829	59fb34a9872049de1cb6b71f3f9d993f	VISA 16 digit	40.7094083324298239	-73.9586731887318223
40942	2020-07-29 18:25:33	2020-07-29	Genie Hudson	genie.hudson@geemail.com	Ontario	California	3112544500449304551	bed212d0f0ee27c5d23c4a4b10147aaf	Maestro	34.0949364090483655	-117.518429760318995
40943	2020-07-29 18:25:47	2020-07-29	Marcia Schoen	marcia.schoen@geemail.com	Jersey City	New Jersey	4194391268537239	3c2e969a26a6fe5f702c99f4b5032eab	VISA 16 digit	40.7474955512151098	-74.0339555779427343
40944	2020-07-29 18:28:28	2020-07-29	Hiram Abshire	hiram.abshire@geemail.com	Charlotte	North Carolina	3010947820527440	e508f30da893b0a4ee8915458280b53d	VISA 16 digit	35.1357551770072405	-80.7976884820908339
40945	2020-07-29 18:31:58	2020-07-29	Dusty Abshire-Zulauf	dusty.abshire.zulauf@geemail.com	San Francisco	California	4072770646981192	6c74c48a2cf83856c37f7053f4d2c23b	VISA 16 digit	37.7688038742702616	-122.485887120353624
40946	2020-07-29 18:34:16	2020-07-29	Merna Hayes	merna.hayes@woohoo.com	San Francisco	California	6011052056451858079	a2ae850d704c14a5ce16568ba17e71ef	American Express	37.7777029160166578	-122.425394001781527
40947	2020-07-29 18:37:53	2020-07-29	Alia McDermott	alia.mcdermott@warmmail.com	Grand Prairie	Texas	3158794345789371605	b1d33150e03e61b475b76811887c2e0b	Discover	32.5940479656733615	-97.1081719270315062
40948	2020-07-29 18:49:32	2020-07-29	Ciara Batz-Miller	ciara.batz.miller@geemail.com	Los Angeles	California	561258878711751	d546a857477b6810ff03875a1f789169	VISA 16 digit	33.964704416585711	-118.431787928425891
40949	2020-07-29 18:54:23	2020-07-29	Ms. Vilma Becker MD	ms.vilma.becker.md@geemail.com	Jersey City	New Jersey	53020065442513106	e67a49191780721dc2815e966e93fc83	VISA 16 digit	40.7703811352547234	-74.1581282185811546
40950	2020-07-29 19:01:17	2020-07-29	Fredericka Lowe-Connelly	fredericka.lowe.connelly@geemail.com	Boise	Idaho	869965057953396928	fb0c532593e67588665443d2389ca9c1	VISA 13 digit	43.6884324807811524	-116.316875337363044
40951	2020-07-29 19:02:45	2020-07-29	Jaden Price	jaden.price@geemail.com	Austin	Texas	4954885585632839	6de7c52c579504bc8b469c260e5bd289	Maestro	30.2698808785654592	-97.7462417041190008
40952	2020-07-29 19:03:40	2020-07-29	Lonnie Heller	lonnie.heller@woohoo.com	Omaha	Nebraska	180003501940264926	4534309fcd57f1657a53923fd6eb1d6d	VISA 16 digit	41.2456159129884128	-96.1182021330691896
40953	2020-07-29 19:19:03	2020-07-29	Otha Gleason	otha.gleason@geemail.com	Buffalo	New York	52009368345040911	22c324d59451d0ed0fa8d45ce7fe835a	Voyager	42.7942663575243216	-78.8051608502797762
40954	2020-07-29 19:20:01	2020-07-29	Eulalia Beahan	eulalia.beahan@geemail.com	Fort Lauderdale	Florida	4211654602864	1f07d2d55ee9baa4d0a63e7f1c55ca9c	VISA 13 digit	26.2257801370218395	-80.1146651470854891
40955	2020-07-29 19:21:32	2020-07-29	Tyesha Kerluke	tyesha.kerluke@warmmail.com	Tulsa	Oklahoma	3088980602848745227	2f81de44a6aa6b55ea07f6289dc2de1d	American Express	36.0869264777187198	-95.9660051836121823
40956	2020-07-29 19:25:33	2020-07-29	Rochelle Green-Lehner	rochelle.green.lehner@geemail.com	Los Angeles	California	3041990106095434	91ccca5f9e36fdea3a0693349378ea6a	Diners Club / Carte Blanche	34.1190364779770334	-118.357153621594605
40957	2020-07-29 19:38:48	2020-07-29	Rueben Murphy-Shanahan	rueben.murphy.shanahan@warmmail.com	New York	New York	3337175138117982758	0c3b61fd8fcbc212397c00bcb1efe925	VISA 16 digit	40.7379512378703765	-73.9648298691388248
40958	2020-07-29 19:41:07	2020-07-29	Dorotha Mertz	dorotha.mertz@woohoo.com	Los Angeles	California	3158245938198483592	d9aea2c116b143944a5dba7fa8c4839c	American Express	34.016705396199221	-118.349052570992328
40959	2020-07-29 19:45:12	2020-07-29	Soloman Zieme II	soloman.zieme.ii@geemail.com	Albuquerque	New Mexico	3096795079729170723	1f0a6995d43b7dee1c25e9a4288b073a	Diners Club / Carte Blanche	35.145123315336555	-106.554741569988067
40960	2020-07-29 19:45:48	2020-07-29	Gianni Mayert	gianni.mayert@geemail.com	Philadelphia	Pennsylvania	6011728781651072239	080283f5036dbb39c46ce259da4aabf4	VISA 13 digit	39.9207541133701795	-75.1187446521494593
40961	2020-07-29 19:49:57	2020-07-29	Mr. Firman Daniel	mr.firman.daniel@warmmail.com	Pittsburgh	Pennsylvania	4602695519838	2e368f8489bb4c5bac460bff64b0c41f	Discover	40.5013954518783805	-79.9541806753896225
40962	2020-07-29 19:54:14	2020-07-29	Hartley Stracke	hartley.stracke@geemail.com	New York	New York	3059881946201856	096915f67fcf80aca06f52aa212430ae	JCB 15 digit	40.6329252008106536	-73.9315090982604772
40963	2020-07-29 19:55:26	2020-07-29	Jamey Strosin-Eichmann	jamey.strosin.eichmann@geemail.com	San Francisco	California	869984980445449079	91e259c23b464f4e7d044dd48972e8f1	VISA 16 digit	37.7515822013161184	-122.454931667445365
40964	2020-07-29 19:58:33	2020-07-29	Theodora Schimmel-Barton	theodora.schimmel.barton@geemail.com	Montgomery	Alabama	3413359063744010	21311dea839652e975f550401dfdd331	Voyager	32.4462146879572444	-86.1725684045035365
40965	2020-07-29 20:00:09	2020-07-29	Dereon McKenzie	dereon.mckenzie@warmmail.com	New York	New York	51824251605198152	3ecfc1554033b151a11af6e58f710ea1	JCB 16 digit	40.636898702032866	-73.9052587189607237
40966	2020-07-29 20:00:47	2020-07-29	Emil Steuber	emil.steuber@woohoo.com	Lakeland	Florida	869996945481258425	71e8d7f9010aa1500c3285e513a63c33	VISA 16 digit	28.0241913360841544	-81.9654663634371019
40967	2020-07-29 20:08:55	2020-07-29	Woodrow Morissette	woodrow.morissette@geemail.com	San Francisco	California	53720146946578655	9a37277f2759545edbef9bf438c5a50f	VISA 16 digit	37.7772054914305997	-122.454155526817374
40968	2020-07-29 20:10:11	2020-07-29	Manilla Rath	manilla.rath@geemail.com	Boston	Massachusetts	4691970446100933	e83a5f7cbe5daac0ca051e9a91a53568	VISA 16 digit	42.335049376094716	-70.9529903294470188
40969	2020-07-29 20:11:57	2020-07-29	Carlyn Marks	carlyn.marks@geemail.com	McAllen	Texas	180020040208231722	16d1d878307440ed2df1d9433b70e1eb	JCB 16 digit	26.2455029103744764	-98.2531784309852867
40970	2020-07-29 20:20:37	2020-07-29	Antonia Gutkowski	antonia.gutkowski@geemail.com	Miami	Florida	3158015711025844577	1bd93477a5e24923b14c618f72ccdb59	Voyager	25.774230747637155	-80.2827356183774867
40971	2020-07-29 20:23:35	2020-07-29	Mr. Chauncey Hansen PhD	mr.chauncey.hansen.phd@warmmail.com	Fort Worth	Texas	4272216322431464	dfd9e0b47d055b4105372baf07421f00	Discover	32.7986458862256285	-97.2513838063281071
40972	2020-07-29 20:33:20	2020-07-29	Evangeline Rosenbaum	evangeline.rosenbaum@geemail.com	Chicago	Illinois	4418542497465242	7f51b0482ec931a283f2d635105772ef	Mastercard	41.7469078819569219	-87.7023529305618155
40973	2020-07-29 20:35:27	2020-07-29	Velia Donnelly	velia.donnelly@geemail.com	Sparks	Nevada	3482651205819510	b7d893deda316434558c717e1048f1fe	VISA 16 digit	39.5632927359320234	-119.749282234846063
40974	2020-07-29 20:37:48	2020-07-29	Adamaris Cruickshank	adamaris.cruickshank@warmmail.com	Westminster	Colorado	53838571593990946	f64fd289b7701e40b4df388392a36794	Mastercard	39.9603374666374123	-105.02246061862968
40975	2020-07-29 20:39:27	2020-07-29	Whitney Carter	whitney.carter@geemail.com	Lincoln	Nebraska	3014882941299809	8955031ff1cc32d4f4c82444e39da885	Diners Club / Carte Blanche	40.7386653022859235	-96.6353881327129898
40976	2020-07-29 20:45:54	2020-07-29	Mannie Spinka	mannie.spinka@woohoo.com	Ventura	California	4295292885185923	81e63006439ffaf62625c26ca1c7da4e	JCB 16 digit	34.3545554921656873	-119.250312413005901
40977	2020-07-29 20:58:35	2020-07-29	Markus Hudson	markus.hudson@geemail.com	Philadelphia	Pennsylvania	55652854283120369	9ddeb8f7c0735332d0cafb916e4f05fa	Discover	40.0940691282931709	-75.0696324285484877
40978	2020-07-29 21:06:18	2020-07-29	Chandler Zieme	chandler.zieme@geemail.com	San Francisco	California	3787923221843245	c593c4b490bcccf0b767e5298e6d8f43	Diners Club / Carte Blanche	37.774200545304069	-122.462926372847519
40979	2020-07-29 21:10:25	2020-07-29	Theodore Von	theodore.von@geemail.com	Tallahassee	Florida	210015393227402700	623c3acd046006b1219cdf7668cebbbc	VISA 16 digit	30.4967110129095644	-84.3004564409159087
40980	2020-07-29 21:14:08	2020-07-29	Miss Joell Kub	miss.joell.kub@woohoo.com	Columbus	Ohio	3088107239953187693	12352aaed05ec584b14c8add107c28cf	Mastercard	39.9392107948705544	-82.907008562074239
40981	2020-07-29 21:17:54	2020-07-29	Lashawn Jones	lashawn.jones@geemail.com	Los Angeles	California	4693092716945	3578a19e39255f2099e039d53e648800	Maestro	34.0716330503445093	-118.419868784071127
40982	2020-07-29 21:19:08	2020-07-29	Doc Kilback	doc.kilback@geemail.com	Oakland	California	639012610628773	a91a75c4b4a49d476e3abf2ae39210bb	Discover	37.838945727796343	-122.285937092833663
40983	2020-07-29 21:29:30	2020-07-29	Ramiro Rohan	ramiro.rohan@woohoo.com	Los Angeles	California	4602185660128290	02ca6e265b07073387cf070e2a6de991	Voyager	33.9400473622005379	-118.475128232547263
40984	2020-07-29 21:31:03	2020-07-29	Forest Nader	forest.nader@geemail.com	Louisville	Kentucky	3088863832852092149	0bfe7a7f9a14882fdd3848208001bdca	JCB 16 digit	38.2358314008355151	-85.5857542185649294
40985	2020-07-29 21:38:19	2020-07-29	Hasan Toy	hasan.toy@geemail.com	Birmingham	Alabama	3018335344905023	6bfae07c6ab8e341d96b288bb1850d34	Voyager	33.4684380709450693	-86.8641960652787333
40986	2020-07-29 21:38:36	2020-07-29	Kendal Luettgen	kendal.luettgen@geemail.com	Mesa	Arizona	4972012084570	598c80718ad12b7ac7b9dce0fc59553b	Mastercard	33.3205102159786932	-111.762007913447547
40987	2020-07-29 21:49:24	2020-07-29	Arlan Halvorson	arlan.halvorson@geemail.com	Salt Lake City	Utah	54179520539887515	dd79b820d0ff704c75094886340c1f34	JCB 16 digit	40.831658879356084	-111.909594245063133
40988	2020-07-29 21:49:26	2020-07-29	Abraham Oberbrunner-Gaylord	abraham.oberbrunner.gaylord@geemail.com	St. Louis	Missouri	639025068286035	368ce4c67c6fa774f3dcc3b5bea243f6	JCB 16 digit	38.7094612580414861	-90.2443382069006645
40989	2020-07-29 21:51:19	2020-07-29	Venus Barton	venus.barton@geemail.com	Fontana	California	3096793098539958384	184fed4e99c88975e51d6a5287fb16c0	Voyager	34.0479204404782507	-117.539635669514169
40990	2020-07-29 21:54:42	2020-07-29	Maggie Runolfsson-Johnson	maggie.runolfsson.johnson@geemail.com	Allen	Texas	3158459835105488543	60e1823935e11952f49ec1ad84d7417f	VISA 16 digit	33.0113748990956708	-96.7193009812798294
40991	2020-07-29 22:05:00	2020-07-29	Ms. Kaelynn Runte	ms.kaelynn.runte@woohoo.com	Tulsa	Oklahoma	3013507831663639	852587c1fac189255f278c323c4911d6	Diners Club / Carte Blanche	36.1535735604722035	-95.8126826521430104
40992	2020-07-29 22:09:56	2020-07-29	Elinore Rempel	elinore.rempel@geemail.com	Rancho Cucamonga	California	060494946426999	033541159e4daf8c4381197d56adaf41	JCB 16 digit	34.1102592519011338	-117.618638749980178
40993	2020-07-29 22:11:37	2020-07-29	Averi Schaefer	averi.schaefer@geemail.com	Oakland	California	3337356325286697124	8f470f84458c66bdd0c97b85a7f632e0	Maestro	37.8183906808445087	-122.266048883380407
40994	2020-07-29 22:14:15	2020-07-29	Vern Gleason	vern.gleason@woohoo.com	Kansas City	Kansas	3158381965318119966	2d098bd91443d7394866cf32d51e75ed	VISA 16 digit	39.0611762343347095	-94.6424649449001976
40995	2020-07-29 22:14:23	2020-07-29	Ms. Annemarie Littel	ms.annemarie.littel@geemail.com	Omaha	Nebraska	6011164780784872763	2cb8279b2ea77d8b4300e9ead1b85a82	JCB 16 digit	41.2121815846912583	-96.1032526098772877
40996	2020-07-29 22:33:42	2020-07-29	Dock Erdman	dock.erdman@geemail.com	Wichita Falls	Texas	3337690970576586639	ed9c61619f08578dbc58b77dff07f56a	VISA 16 digit	33.8747287380237125	-98.4531131025325408
40997	2020-07-29 22:34:06	2020-07-29	Keshawn Wyman-Price	keshawn.wyman.price@woohoo.com	New York	New York	3158829815963283171	a0b2e1c63ad28354335c4f2dc588decb	VISA 16 digit	40.567718094702812	-73.9330406940437825
40998	2020-07-29 22:46:17	2020-07-29	Bruce Batz	bruce.batz@geemail.com	Salt Lake City	Utah	3337314277590668799	54d7178b46e7008092b95f53e4fdd969	JCB 15 digit	40.7279443700011825	-111.902835678629572
40999	2020-07-29 22:47:47	2020-07-29	Ednah Altenwerth-Kautzer	ednah.altenwerth.kautzer@warmmail.com	Meridian	Idaho	3096090424886208613	505bd7a7e611623d296b2d2fa18c6d62	Maestro	43.6703385945416969	-116.370042587158821
41000	2020-07-29 22:50:15	2020-07-29	Mr. Lum Runolfsson	mr.lum.runolfsson@geemail.com	Mesa	Arizona	6011692753496945699	a16dcba7f14e41d73646ff6958f43bce	Voyager	33.3649878912284947	-111.675324378011368
41001	2020-07-29 22:51:22	2020-07-29	Izora Breitenberg	izora.breitenberg@warmmail.com	Arvada	Colorado	869911086717999284	d76251c85e0fd00d7a4bbca19a3c3d3b	American Express	39.9334921450529237	-105.084584339612348
41002	2020-07-29 23:01:16	2020-07-29	Mr. Najee Collins	mr.najee.collins@woohoo.com	Warren	Michigan	3793100298851581	bdcc6393c0d13bafc6a27742496c51e5	VISA 16 digit	42.4956224378660323	-82.9790547410491968
41003	2020-07-29 23:03:27	2020-07-29	Marcelino Hodkiewicz	marcelino.hodkiewicz@geemail.com	Los Angeles	California	210099468417528891	9ae3faf41611a6df6f3c5932f83422a3	VISA 16 digit	34.0754994060710032	-118.354224004269753
41004	2020-07-29 23:07:01	2020-07-29	Zillah Barton	zillah.barton@warmmail.com	San Francisco	California	3112943829654642794	917ae188c9fea5ea303690b16daf3b40	American Express	37.8058182811666654	-122.454968769249191
41005	2020-07-29 23:09:00	2020-07-29	Mr. Dell Kassulke	mr.dell.kassulke@warmmail.com	Los Angeles	California	3112071747472505247	6047368b56f166254956a43260681465	Maestro	34.0464992106292357	-118.409116214652727
41006	2020-07-29 23:09:30	2020-07-29	Keira Gibson DDS	keira.gibson.dds@geemail.com	Fort Worth	Texas	4006608002504	e0df81418ca49e5e675c5811393cfd57	Voyager	32.7692097249496754	-97.4249684166915699
41007	2020-07-29 23:11:59	2020-07-29	Dennie Gibson V	dennie.gibson.v@geemail.com	San Jose	California	51924604495910582	a2117f577dd4bd3fd71a96aa991417af	VISA 16 digit	37.2953368205863995	-121.868392025282233
41008	2020-07-29 23:14:40	2020-07-29	Domenica Simonis-Walter	domenica.simonis.walter@geemail.com	Henderson	Nevada	6011614374428308420	1df38634a942095aeb6073cb84e50e96	Voyager	35.935731121611596	-115.046179778237644
41009	2020-07-29 23:23:40	2020-07-29	Erie Wyman	erie.wyman@warmmail.com	Detroit	Michigan	3012197179284486	0acda615cca8be27f4d3a8c37b0070ff	JCB 16 digit	42.3688568419702349	-83.0118192682627551
41010	2020-07-29 23:30:09	2020-07-29	Rodger Hoeger	rodger.hoeger@geemail.com	Mesa	Arizona	3112955189126901194	297e2da8f810f6430b512f87389d0018	VISA 16 digit	33.4512591711856402	-111.73034108498841
41011	2020-07-29 23:41:02	2020-07-29	Minervia Cronin	minervia.cronin@geemail.com	Lakewood	Colorado	54048597574956594	7439339716b7db529109055caa951f5f	VISA 13 digit	39.7333169397838404	-105.031547402453043
41012	2020-07-29 23:44:55	2020-07-29	Dr. Shakira Wisoky	dr.shakira.wisoky@geemail.com	San Francisco	California	3158370640315150131	05abd95db072cf87b2b3dda932925553	JCB 16 digit	37.7709218705847505	-122.436668764260133
41013	2020-07-29 23:56:52	2020-07-29	Luetta Witting	luetta.witting@geemail.com	San Francisco	California	210067673508579269	b6e58b2e36dc66a8be9a87889f64f5b5	American Express	37.7607929495563823	-122.437288974744376
41014	2020-07-30 00:09:28	2020-07-30	Janessa Bashirian	janessa.bashirian@geemail.com	Tallahassee	Florida	3016645203521667	f9870277397d757ddbca31d46bf4cff9	VISA 16 digit	30.380335412968325	-84.2404287198107653
41015	2020-07-30 00:10:28	2020-07-30	Dakoda Stamm	dakoda.stamm@geemail.com	Dallas	Texas	676331157286985	4f7b03c72501af35c6d0cd0cdf3b0e58	Discover	32.7781913472611492	-96.7744976353794328
41016	2020-07-30 00:11:17	2020-07-30	Akeelah McKenzie	akeelah.mckenzie@geemail.com	Wichita	Kansas	589352984402108	24b7406723e38d74833aa9e20e7f783c	American Express	37.6099910374607873	-97.3740655929516947
41017	2020-07-30 00:20:37	2020-07-30	Madden Schaefer-Huels	madden.schaefer.huels@woohoo.com	Atlanta	Georgia	4213607972865	b793115e4c4689dc33cccc8cec492373	Maestro	33.7948367913529282	-84.4851620009679465
41018	2020-07-30 00:27:45	2020-07-30	Chrissy Nicolas	chrissy.nicolas@geemail.com	Berkeley	California	3337636967708974805	9591da2dd188709d3474c03adfa9c703	Mastercard	37.871164464974278	-122.251970456899144
41019	2020-07-30 00:37:40	2020-07-30	Philo Brekke	philo.brekke@geemail.com	Jacksonville	Florida	639046871265115	7fb9a662f5b29b5b693d42dd7781fb82	VISA 13 digit	30.3914834410004318	-81.7276274736117614
41020	2020-07-30 00:42:10	2020-07-30	Wilda Tillman	wilda.tillman@woohoo.com	San Jose	California	3028526948401159	531032df67d0b5221d09813cae483974	Discover	37.2954168537918491	-121.834627985557162
41021	2020-07-30 00:43:06	2020-07-30	Primus McDermott	primus.mcdermott@geemail.com	Baton Rouge	Louisiana	676218464196270	ba3b8528fa1ec441654a8b3eee028869	JCB 16 digit	30.4969915647737686	-91.1160642470806863
41022	2020-07-30 00:46:47	2020-07-30	Dr. Kirby Skiles MD	dr.kirby.skiles.md@geemail.com	Los Angeles	California	210059121382399297	cdfd5d2d780ac26e381ba48f7cdc6512	JCB 16 digit	33.9840655925083865	-118.441976611594853
41023	2020-07-30 00:48:35	2020-07-30	Dessa Frami	dessa.frami@geemail.com	San Francisco	California	210020312821238842	054fececacbb02df87fecfdb0bab4de7	Maestro	37.7574787818833073	-122.426067031956293
41024	2020-07-30 00:48:43	2020-07-30	Miss Alex O'Hara DVM	miss.alex.o'hara.dvm@geemail.com	Louisville	Kentucky	4929480728153	dfda476d801565ad0522037a63d25a99	JCB 16 digit	38.2279235161744069	-85.647295449355255
41025	2020-07-30 00:48:49	2020-07-30	Micayla VonRueden	micayla.vonrueden@geemail.com	Philadelphia	Pennsylvania	4174205769972	2a8423eec4fd9cc208afe61525bbb6a3	VISA 16 digit	40.0032207083847382	-75.1759830477546984
41026	2020-07-30 00:49:04	2020-07-30	Vincent Roob	vincent.roob@geemail.com	Frisco	Texas	4889417522624917	787d30478609773402aea042c5ed6fa1	Voyager	33.2373692641031013	-96.7586927698667978
41027	2020-07-30 00:49:41	2020-07-30	Pearline Mante-Treutel	pearline.mante.treutel@geemail.com	Berkeley	California	4085748741235503	b5a176bfe9b124105756d9c48e0b8146	JCB 16 digit	37.8592787870491208	-122.2590055945263
41028	2020-07-30 00:54:22	2020-07-30	Shedrick Klocko	shedrick.klocko@geemail.com	Irvine	California	180052054265374052	b22b3e6210690871100ce3c3e9e8713b	American Express	33.7254352041069438	-117.764202365699404
41029	2020-07-30 00:55:33	2020-07-30	Jalen Nienow	jalen.nienow@geemail.com	Lexington	Kentucky	869923507822833395	e6e6aecacf9404d662eb7616cc9fce88	Maestro	37.94524363375902	-84.4151766599986644
41030	2020-07-30 00:57:38	2020-07-30	Alphonse O'Hara	alphonse.o'hara@geemail.com	Burbank	California	3703900407555406	b265817ba71642ef7e0a6741c29803f7	VISA 16 digit	34.2402884811092179	-118.25191632607357
41031	2020-07-30 01:03:01	2020-07-30	Tana Lynch	tana.lynch@geemail.com	Raleigh	North Carolina	869912655232044153	ad9628ad2c01e1fb32d2daa24b7effc6	VISA 13 digit	35.7770153302833407	-78.5568705346371985
41032	2020-07-30 01:12:51	2020-07-30	Camryn Langworth	camryn.langworth@geemail.com	San Francisco	California	3027175917903554	7210adf5f6f45ac3550e490763305082	American Express	37.7755694629883934	-122.452677242397769
41033	2020-07-30 01:15:05	2020-07-30	Anie Kessler	anie.kessler@geemail.com	Philadelphia	Pennsylvania	51992903125025648	ac4ffae30ed4db09a2ad7404ff35746b	Maestro	40.0667839297983761	-75.2255423379030077
41034	2020-07-30 01:22:14	2020-07-30	Jada Yundt	jada.yundt@geemail.com	Louisville	Kentucky	6011010533498221496	e4b1214a7d020f34bb4d5323930e75b8	American Express	38.2632033491875987	-85.6138910774212434
41035	2020-07-30 01:23:44	2020-07-30	Miriah Pfeffer-Haley	miriah.pfeffer.haley@woohoo.com	Baltimore	Maryland	3337692431396447567	926891d1c7ff08e94e7d38edff67eb8e	JCB 16 digit	39.2205524913966599	-76.6628809571284791
41036	2020-07-30 01:25:24	2020-07-30	Worley Rolfson	worley.rolfson@warmmail.com	Houston	Texas	4545279511619811	b723536a702005eba06d77a641643f49	Discover	29.8831573732275508	-95.3451855289299033
41037	2020-07-30 01:29:19	2020-07-30	Stoney Williamson-Kling	stoney.williamson.kling@geemail.com	Chicago	Illinois	869910500787111688	4642f434cd01280d6d56c7d88d12d6c1	Maestro	41.790259028442577	-87.7262075210485506
41038	2020-07-30 01:30:27	2020-07-30	Montana Beier	montana.beier@geemail.com	Henderson	Nevada	4592631896889	959a86ad6c87c1112a8bc493f10d3746	Voyager	35.953327088610088	-115.101451501498744
41039	2020-07-30 01:37:25	2020-07-30	Ura Bergnaum	ura.bergnaum@woohoo.com	Richmond	California	4367268378735815	50678379e3bd2bf5a94889b4ed43c13f	VISA 16 digit	37.898745187181234	-122.299499614615371
41040	2020-07-30 01:37:34	2020-07-30	Mr. Madden Powlowski	mr.madden.powlowski@woohoo.com	New York	New York	3112403135243021836	1e24f554ddca0f56c73bd266f9af108c	Maestro	40.7284064434692255	-73.9741177634697351
41041	2020-07-30 01:45:17	2020-07-30	Nickolas Marvin MD	nickolas.marvin.md@geemail.com	Chicago	Illinois	6011509000591164500	acbc96fea5710585f58486c1d4cc9665	VISA 16 digit	41.9162055638920563	-87.6601542683813619
41042	2020-07-30 01:56:50	2020-07-30	Mrs. Jayde Beer MD	mrs.jayde.beer.md@warmmail.com	Fort Worth	Texas	3337492473682755602	180f96c5d730fbef2cf29fe047fb724b	Mastercard	32.7544629932437132	-97.4189339879255698
41043	2020-07-30 01:57:49	2020-07-30	Garnet Kutch DDS	garnet.kutch.dds@geemail.com	Houston	Texas	53637119612917046	7a305810cb04527f3c9b3bdc7fee91a8	Voyager	29.8061195560809225	-95.2982428907431682
41044	2020-07-30 02:07:31	2020-07-30	Mrs. Lesley Schmidt	mrs.lesley.schmidt@woohoo.com	Philadelphia	Pennsylvania	4945750460746090	e5c91241e8281d6b6715eb6f19cb3a2a	JCB 16 digit	40.0068811336491237	-75.0624104937903667
41045	2020-07-30 02:14:37	2020-07-30	Mr. Milton Baumbach	mr.milton.baumbach@geemail.com	Tulsa	Oklahoma	3049442150790421	0587dbe2a606a95b50c4109a46a376a4	Mastercard	36.0739289770271583	-95.9599551070902521
41046	2020-07-30 02:20:14	2020-07-30	Mrs. Felicia Ortiz	mrs.felicia.ortiz@geemail.com	Atlanta	Georgia	4123952317980500	23ee89f7f1e20f661f6443e12e2699be	VISA 13 digit	33.7854957544986192	-84.5187923528764458
41047	2020-07-30 02:25:39	2020-07-30	Donavan Gutkowski Sr.	donavan.gutkowski.sr.@geemail.com	St. Louis	Missouri	3001417035283386	b9858bb9ef2d9f904d7c89c127965a84	VISA 13 digit	38.6542274444054783	-90.2061614352282248
41048	2020-07-30 02:30:56	2020-07-30	Khalil Romaguera	khalil.romaguera@warmmail.com	Indianapolis	Indiana	4487100279404768	9b749760552ecf684fb9794981329af0	Maestro	39.8020759013488856	-86.155862506033472
41049	2020-07-30 02:32:47	2020-07-30	Dr. Zackary Hane IV	dr.zackary.hane.iv@woohoo.com	Cincinnati	Ohio	4033660365783440	dd3dc5228a78a56c8b4581506f1ae0ef	JCB 16 digit	39.1722592523086846	-84.591166996703663
41050	2020-07-30 02:33:42	2020-07-30	Makenna O'Conner	makenna.o'conner@warmmail.com	Kansas City	Missouri	52290971889541356	45ebd81423dc8fd8e0df8d65a73228a5	VISA 16 digit	39.0500695632141088	-94.5816229351088396
41051	2020-07-30 02:49:44	2020-07-30	Emmanuel Johnson	emmanuel.johnson@geemail.com	Chicago	Illinois	3337906272167300078	c5ca2f493d98db9d0851978204b58ce7	Maestro	41.7577261307578524	-87.6561674187920943
41052	2020-07-30 02:51:14	2020-07-30	Tilla Kuphal	tilla.kuphal@geemail.com	Denton	Texas	6011381711665488186	35c168095054fbaf233931a98f370644	JCB 16 digit	33.1232068239975703	-97.2240454352121901
41053	2020-07-30 03:01:42	2020-07-30	Ollie Stehr	ollie.stehr@warmmail.com	Rialto	California	54712617615844156	a1f6bf16db522393cfb1353d3fc31c28	VISA 16 digit	34.0404987190600536	-117.300233803092695
41054	2020-07-30 03:01:54	2020-07-30	Ivory Miller	ivory.miller@geemail.com	Berkeley	California	4207772161940	b28b977984c909693254198150029ec1	Mastercard	37.8764277606941349	-122.287340424018197
41055	2020-07-30 03:03:15	2020-07-30	Johnnie Schmeler	johnnie.schmeler@geemail.com	Louisville	Kentucky	52528345986931113	4ea6f86c0605af86b3f1535907515744	VISA 16 digit	38.2332359722252946	-85.6333175619203644
41056	2020-07-30 03:03:50	2020-07-30	Maymie Huel	maymie.huel@woohoo.com	Chicago	Illinois	3771438180741791	eee3acc11d679e7b127866adaa25293c	Discover	41.9270925142172715	-87.7772909288324428
41057	2020-07-30 03:04:07	2020-07-30	Mrs. Kanisha Berge	mrs.kanisha.berge@geemail.com	Los Angeles	California	869918213089412828	ba7368c39665a997e6ca460113cfbbf7	Voyager	33.9496289813756889	-118.350595434102416
41058	2020-07-30 03:07:44	2020-07-30	Iyana Armstrong	iyana.armstrong@woohoo.com	Fort Worth	Texas	52907830548191752	8464720b521b9549671daa1ca81bb80d	VISA 16 digit	32.7806332939360274	-97.3823022860389216
41059	2020-07-30 03:10:25	2020-07-30	Liller Kohler	liller.kohler@geemail.com	Las Vegas	Nevada	3158299259360457057	14922b2657c2396c10d7c6b12951170d	JCB 16 digit	36.2375384076133358	-115.199592424484337
41060	2020-07-30 03:15:32	2020-07-30	Dr. Kamari Jacobi I	dr.kamari.jacobi.i@geemail.com	Houston	Texas	6011996050232463134	43afc6c8390508613780b2a730bcdc51	JCB 15 digit	29.7506945275314152	-95.3704046140439772
41061	2020-07-30 03:17:33	2020-07-30	Linton Goyette	linton.goyette@geemail.com	Ventura	California	869983878156166901	cdb65e4f6057318aceedaf75fd277dae	VISA 16 digit	34.3629202096417572	-119.302105095154417
41062	2020-07-30 03:24:52	2020-07-30	Gunnar Mosciski	gunnar.mosciski@geemail.com	Los Angeles	California	3158445164827920510	473a658ce7c44f11f57d378cdc4a1b0c	JCB 15 digit	33.9211918963916546	-118.432154715339834
41063	2020-07-30 03:31:54	2020-07-30	Mrs. Ottilia Romaguera DDS	mrs.ottilia.romaguera.dds@geemail.com	Philadelphia	Pennsylvania	4317973584642843	396420dcc26d5c566595abf6339d4626	Maestro	39.965575408838319	-75.0681479619715475
41064	2020-07-30 03:41:32	2020-07-30	Matthias Bergnaum	matthias.bergnaum@warmmail.com	El Cajon	California	3528579101617645939	7be2b78c32f67807c37deb887b09b597	Maestro	32.8179707742303606	-116.908512090537329
41065	2020-07-30 03:45:15	2020-07-30	Jeanna Donnelly PhD	jeanna.donnelly.phd@geemail.com	Providence	Rhode Island	3112594748763719479	cb49b65233892a2364e563fabe491707	Voyager	41.7500089303445066	-71.4120947176974283
41066	2020-07-30 03:48:02	2020-07-30	Dallas O'Hara	dallas.o'hara@geemail.com	Fort Worth	Texas	869980591734415020	f88902a1588c3627c7a0db21a25a8a25	VISA 16 digit	32.8620982460267825	-97.3885539285194142
41067	2020-07-30 03:50:56	2020-07-30	Simpson Bartoletti MD	simpson.bartoletti.md@geemail.com	Las Cruces	New Mexico	869936690596761904	456f7471a2a00f816ed5d3051c07f145	VISA 13 digit	32.2743893838055413	-106.867189421563225
41068	2020-07-30 04:03:17	2020-07-30	Annabelle Emard DVM	annabelle.emard.dvm@geemail.com	Killeen	Texas	3472494368599179	ec894402f4a6024e066f663c61f429f6	JCB 15 digit	31.157597721996531	-97.7176872061267545
41069	2020-07-30 04:18:06	2020-07-30	Darrius O'Hara	darrius.o'hara@geemail.com	Colorado Springs	Colorado	4133300078617366	e9cc76e5fe5e525e426253166a5a757f	Voyager	38.8254576628144861	-104.847494539913541
41070	2020-07-30 04:22:32	2020-07-30	Coletta McDermott	coletta.mcdermott@woohoo.com	New York	New York	3112555794840191271	43dc96fab9908f4b99b2fb54338f7c59	JCB 16 digit	40.6537730952017	-73.9509278478462164
41071	2020-07-30 04:31:48	2020-07-30	Dr. Rush Stoltenberg	dr.rush.stoltenberg@geemail.com	Berkeley	California	54706838279114409	e082a92cec0930cdf848d3d70c336892	American Express	37.8638227510306109	-122.245741279076654
41072	2020-07-30 04:32:18	2020-07-30	Dr. Jorge Toy	dr.jorge.toy@geemail.com	Colorado Springs	Colorado	4167300783691713	a3736060afd52f7180b6a6bda86b399a	Mastercard	38.8969786350198063	-104.683376664451131
41073	2020-07-30 04:42:19	2020-07-30	Ace Ankunding	ace.ankunding@geemail.com	Durham	North Carolina	639071581431286	5842e4115288fb033298ba38bcc9395e	JCB 16 digit	35.9809536204919169	-78.8080647480577312
41074	2020-07-30 04:44:24	2020-07-30	Toy Buckridge	toy.buckridge@geemail.com	Phoenix	Arizona	53277961627504201	fd64056c8ad9c064dedd2ee0d185a455	JCB 16 digit	33.6069417309414646	-112.029150042536116
41075	2020-07-30 04:50:55	2020-07-30	Dr. Wynona Ruecker DVM	dr.wynona.ruecker.dvm@geemail.com	San Francisco	California	869975603136174282	4ecb8f622471d8e5a865387da923cc08	Voyager	37.7738468446551678	-122.45595520234609
41076	2020-07-30 05:03:12	2020-07-30	Maymie Rolfson	maymie.rolfson@geemail.com	Orlando	Florida	4245356011451714	b92f1b01d3fbcb15778cd2cc371e020e	JCB 15 digit	28.3415646281357851	-81.3364405028488449
41077	2020-07-30 05:05:16	2020-07-30	Mr. Quinton Abshire DDS	mr.quinton.abshire.dds@geemail.com	Concord	California	869974701690847086	b51c22cba1592b8566e26026565103ff	VISA 16 digit	37.9153712744291909	-121.994419804744794
41078	2020-07-30 05:18:45	2020-07-30	Izabelle Johnston	izabelle.johnston@geemail.com	Reno	Nevada	180071907810258723	920109c2efedfe970861970af78733fc	VISA 16 digit	39.4709912967015057	-119.858066848495611
41079	2020-07-30 05:26:59	2020-07-30	Catharine Ferry	catharine.ferry@geemail.com	Killeen	Texas	4259279850149913	2fbd0d39eff276658c63d1c9efd8bb06	Voyager	31.1252356078706676	-97.8291601018216426
41080	2020-07-30 05:34:13	2020-07-30	Conner Auer	conner.auer@woohoo.com	Houston	Texas	6011791328015880097	b1a797146d0499109713b668625f30c3	JCB 16 digit	29.7774447236288324	-95.4690466822605543
41081	2020-07-30 05:39:04	2020-07-30	Deeann Stiedemann	deeann.stiedemann@geemail.com	Oklahoma City	Oklahoma	3096335796589513984	49c1d6e06d91309d6ddd65fd704c14a7	VISA 16 digit	35.5216304473955233	-97.4652430050902012
41082	2020-07-30 05:39:12	2020-07-30	Pernell Effertz	pernell.effertz@woohoo.com	Cary	North Carolina	4682895765050	0778a4f24f77c67e27793caedb9fc38b	VISA 13 digit	35.7266474328111912	-78.8644384285986462
41083	2020-07-30 05:41:01	2020-07-30	Mr. Dilan Schuppe I	mr.dilan.schuppe.i@geemail.com	Toledo	Ohio	6011983697189869997	2e33af6b7b4ca52bf987c262d3381b6c	Diners Club / Carte Blanche	41.6440219833221263	-83.5573243251402005
41084	2020-07-30 05:46:52	2020-07-30	Angelic Zieme	angelic.zieme@woohoo.com	San Francisco	California	3088271644005859175	01b6d9a67161e084eeecc5d0df3f86f6	JCB 16 digit	37.7764679169516242	-122.463168277940142
41085	2020-07-30 05:47:09	2020-07-30	Mr. Hampton Harber V	mr.hampton.harber.v@geemail.com	San Diego	California	6011082211195120906	1af4e59c7f97505bc77512dd835686d2	JCB 15 digit	32.8383789628811158	-117.035949646160006
41086	2020-07-30 05:57:03	2020-07-30	Treyton Mante	treyton.mante@geemail.com	Glendale	Arizona	3054695669308135	b664ca8ce3f13b3005bb6507c175a62e	Maestro	33.5864248623367345	-112.2584839807149
41087	2020-07-30 06:00:00	2020-07-30	Demarco Schroeder	demarco.schroeder@geemail.com	Columbus	Ohio	55983137807932752	14a2ba4e7882225ba2e5b00d0d960767	VISA 16 digit	40.045932995206492	-82.891869664215676
41088	2020-07-30 06:06:40	2020-07-30	Mrs. Christena Aufderhar	mrs.christena.aufderhar@geemail.com	Phoenix	Arizona	3755456091745461	4bf2ff2349d2d556d2e456da8a67f069	Mastercard	33.6055786699455226	-112.11584498723262
41089	2020-07-30 06:09:47	2020-07-30	Dr. Carmella Frami DDS	dr.carmella.frami.dds@geemail.com	Dallas	Texas	589357868929035	d610cdfae8dcca311785809cf6547718	JCB 16 digit	32.7829429263986682	-96.8040255254097275
41090	2020-07-30 06:18:41	2020-07-30	Ismael Jacobi	ismael.jacobi@warmmail.com	Fontana	California	3032510737708061	f20ef588277e7c5a69503ce0b0fd2b42	VISA 16 digit	34.175315195662904	-117.375445510474592
41091	2020-07-30 06:19:13	2020-07-30	Bradly Marvin	bradly.marvin@geemail.com	Roseville	California	4894845477371279	ee0fe1fe43c2d40a0ff3761567f3e240	Maestro	38.7693133169375344	-121.395735187990212
41092	2020-07-30 06:20:04	2020-07-30	Zavier Hartmann	zavier.hartmann@geemail.com	New York	New York	4092972348937441	0037fb1c0e639e3e69e130ff6f0ac31f	JCB 16 digit	40.7030957814063896	-74.0371638439956996
41093	2020-07-30 06:20:05	2020-07-30	Maximiliano Harvey	maximiliano.harvey@geemail.com	Fort Collins	Colorado	675930247689208	00ca0c9adadcd58d3df2909879b9ecfd	VISA 13 digit	40.6470849895074977	-105.097274102126434
41094	2020-07-30 06:21:06	2020-07-30	Willene Wolf	willene.wolf@geemail.com	Los Angeles	California	180077254328665998	5283ddd445b82884e61a7695c2903661	VISA 16 digit	34.1021174628153432	-118.433196438382566
41095	2020-07-30 06:34:46	2020-07-30	Inell Muller	inell.muller@geemail.com	Philadelphia	Pennsylvania	4237077566166578	153282d5460d906ad0070cfa5fb628e9	VISA 13 digit	40.079772414914892	-75.0356045811802232
41096	2020-07-30 06:35:04	2020-07-30	Dr. Moe Halvorson	dr.moe.halvorson@geemail.com	Chesapeake	Virginia	4950280095522007	d9049f497005898a22ff89d80da8c0d2	VISA 16 digit	36.7048754217341582	-76.2155818564660876
41097	2020-07-30 06:38:13	2020-07-30	Asia Beahan	asia.beahan@geemail.com	Raleigh	North Carolina	4106339552702354	37c08a70ad603d68b0ecaa8ad00ddb38	VISA 16 digit	35.8942751943733498	-78.6980020004261291
41098	2020-07-30 06:45:11	2020-07-30	Ms. Almina Tremblay	ms.almina.tremblay@woohoo.com	San Francisco	California	4772546988995906	1d88b620ef4138c328cdafb1a1bb7443	Discover	37.7516965410558498	-122.447132868753769
41099	2020-07-30 06:53:07	2020-07-30	Derrick Mann	derrick.mann@geemail.com	Chicago	Illinois	3096254850282938043	4a6a67925f90a4a4ffe59053fbd73e63	Discover	41.746144856868689	-87.5868545666832432
41100	2020-07-30 06:58:05	2020-07-30	Jerimiah McKenzie	jerimiah.mckenzie@geemail.com	West Covina	California	676306731118581	12d5fa1eb21cdcbe476303703da4d437	American Express	33.9581423893213312	-118.003464383033659
41101	2020-07-30 07:03:16	2020-07-30	Manly Upton V	manly.upton.v@geemail.com	Worcester	Massachusetts	210008192672990014	f7f5e9bdfef46502af1babc12e8a907c	VISA 16 digit	42.3126996856816149	-71.8917132464490862
41102	2020-07-30 07:12:01	2020-07-30	Butch O'Hara	butch.o'hara@geemail.com	San Francisco	California	4427833442630	20a21fe829fcb9d9dfb6ba24743d92a7	JCB 16 digit	37.7828626435564772	-122.407143521958048
41103	2020-07-30 07:19:15	2020-07-30	Pam Bosco-Mayer	pam.bosco.mayer@woohoo.com	Carrollton	Texas	630433731092350	4179483c3d0b2166ebdfea58171ccb84	Voyager	32.9887165207337603	-96.9944880525443693
41104	2020-07-30 07:33:51	2020-07-30	Demond Morissette DDS	demond.morissette.dds@geemail.com	Virginia Beach	Virginia	52947863070531568	18c0621b15883c3a86f20f7f1eeb9854	JCB 15 digit	36.7439269562903803	-75.9674445394098683
41105	2020-07-30 07:41:59	2020-07-30	Averi Lubowitz	averi.lubowitz@geemail.com	Phoenix	Arizona	3403512379648216	6d903c6542a7f2b218487a71cd0edca3	American Express	33.5054445176783986	-112.127972123438866
41106	2020-07-30 07:50:08	2020-07-30	Mrs. Davina Herzog DVM	mrs.davina.herzog.dvm@warmmail.com	Anaheim	California	4607447106159965	f0f9ddc0dd963ea739e3d0ae878e51e7	VISA 13 digit	33.9290949478577843	-117.739059290636703
41107	2020-07-30 07:54:19	2020-07-30	Mr. Verlin Veum III	mr.verlin.veum.iii@geemail.com	Springfield	Massachusetts	6011901908181258298	cc70c1e356bcf3583462c27751d06206	Mastercard	42.0394071445073934	-72.4804942867346114
41108	2020-07-30 07:55:36	2020-07-30	Mrs. Caprice Bosco PhD	mrs.caprice.bosco.phd@geemail.com	Houston	Texas	6011426576310117804	300e37e3172af073c9c1b2770051b3e2	VISA 16 digit	29.8104687553908683	-95.4254067117363292
41109	2020-07-30 07:56:31	2020-07-30	Karli Fay	karli.fay@geemail.com	Santa Ana	California	55093276725912129	c93aa27d03202515268edb29be920a47	Maestro	33.668606035235527	-117.944533511197193
41110	2020-07-30 07:57:57	2020-07-30	Jacquelin Ondricka	jacquelin.ondricka@geemail.com	Denver	Colorado	3528816235671255004	6be641b74e345ce6a56dcc5a334ab13d	VISA 13 digit	39.7768396121036218	-104.886432337180153
41111	2020-07-30 07:58:10	2020-07-30	Johny Carter	johny.carter@warmmail.com	Peoria	Arizona	54545343938483621	30d2d63541c7ff5655998cbb8be09d76	Voyager	33.793828481695428	-112.36349576096238
41112	2020-07-30 08:03:40	2020-07-30	Schley Greenfelder	schley.greenfelder@geemail.com	Orange	California	52169683237874649	b25dca57f6fdffd0eeb69ba7d55ba17d	JCB 16 digit	33.7672675805520228	-117.937123879986999
41113	2020-07-30 08:07:38	2020-07-30	Mac Jast	mac.jast@geemail.com	Lincoln	Nebraska	3734448641249546	d0351c15d80b8618454f9176489b5ccf	JCB 16 digit	40.8337927831355429	-96.7436817042224106
41114	2020-07-30 08:19:45	2020-07-30	Alfreda Schimmel	alfreda.schimmel@geemail.com	Berkeley	California	4478862414120192	e810ba0cf1a5c749113a593075468aba	JCB 15 digit	37.8821175913085142	-122.285271931429449
41115	2020-07-30 08:23:58	2020-07-30	Elyse Block	elyse.block@warmmail.com	San Francisco	California	210070023841217232	a5632475f6fa65ac3e8e11c8eed2eed4	Maestro	37.7511731941833233	-122.437295673784249
41116	2020-07-30 08:36:53	2020-07-30	Melvina Funk	melvina.funk@geemail.com	Honolulu	Hawaii	3717505497396126	09becb6d31569b9263312e797ddceaaf	Diners Club / Carte Blanche	21.3890544513922194	-157.769237215605017
41117	2020-07-30 08:41:26	2020-07-30	Dara Stroman	dara.stroman@geemail.com	Houston	Texas	4768166102915890	b3c8a33f30bb356ff5e55c40cf8db0c6	VISA 16 digit	29.8851071043949581	-95.3066845754642031
41118	2020-07-30 08:54:57	2020-07-30	Lilyana Osinski	lilyana.osinski@geemail.com	Arlington	Texas	54972914371842804	1c8df4d3862ccf1ca46088da2323f9df	Mastercard	32.7346637656696089	-97.1570934696614756
41119	2020-07-30 09:13:48	2020-07-30	Daquan Hermann Jr.	daquan.hermann.jr.@geemail.com	Houston	Texas	3337793014708898004	615401b8fc405ac685795cc0b533225d	VISA 16 digit	29.8196184864345923	-95.3813886382632035
41120	2020-07-30 09:26:02	2020-07-30	Peyton Torp DVM	peyton.torp.dvm@geemail.com	Green Bay	Wisconsin	502038776582975	5e6d74663a3095e7ccbe2ae9adb11d2f	Maestro	44.4820459262996906	-87.9931020251762135
41121	2020-07-30 09:26:40	2020-07-30	Marquez Conroy	marquez.conroy@geemail.com	Laredo	Texas	4173522795948300	dcab1bb7d00453fb92380e62b291caf2	JCB 16 digit	27.4758010143596678	-99.4893799229998166
41122	2020-07-30 09:33:42	2020-07-30	Eboni Olson DDS	eboni.olson.dds@warmmail.com	Austin	Texas	502051713079047	9899ecd7500538ce8626e2286bc3aec5	Maestro	30.3716055875770721	-97.8494910481624345
41123	2020-07-30 09:44:20	2020-07-30	Mrs. Suzie Koss MD	mrs.suzie.koss.md@woohoo.com	Los Angeles	California	3112537148367040721	62665380665d081f077c07f7152be5a4	JCB 16 digit	33.9506497449107414	-118.452477732300011
41124	2020-07-30 09:47:56	2020-07-30	Mrs. Orlena Brakus	mrs.orlena.brakus@geemail.com	Kansas City	Missouri	3715678652416633	efd63ca2a3e099ff29cc4f72ca900169	JCB 15 digit	39.1174449312336776	-94.4594001217503063
41125	2020-07-30 09:52:27	2020-07-30	Shellie Leannon	shellie.leannon@geemail.com	San Francisco	California	3792165900559345	4f2c4ed52a29314268bd8a9ec2fb610f	Discover	37.8099230789580716	-122.456979858232231
41126	2020-07-30 09:52:45	2020-07-30	Dr. Reva Sipes	dr.reva.sipes@geemail.com	Irving	Texas	3731508597093132	da72d41889530fb00b22f5f82e936155	Mastercard	32.926234625042234	-97.0243760057073104
41127	2020-07-30 09:56:52	2020-07-30	Mrs. Alwina Dietrich	mrs.alwina.dietrich@woohoo.com	Mobile	Alabama	3088685335136198928	ee763a8186121062c52f217fd4b4850b	Voyager	30.5813894090350686	-88.0532336532741766
41128	2020-07-30 10:05:49	2020-07-30	Dr. Tod Hirthe III	dr.tod.hirthe.iii@geemail.com	Washington	District of Columbia	3337916291126003852	42941f630e0c9f43f3101968d2c1d6f3	VISA 16 digit	38.9929477624393996	-76.9315658698536424
41129	2020-07-30 10:15:47	2020-07-30	Brendan Wunsch	brendan.wunsch@woohoo.com	Baltimore	Maryland	3088995249918787078	4a90415850c9a9a32f9d0a7ff00bc183	JCB 16 digit	39.3564010737463832	-76.5771267972439489
41130	2020-07-30 10:19:33	2020-07-30	Burnice Mann	burnice.mann@warmmail.com	Las Vegas	Nevada	3088574609448636146	b5c606cf042d3599b338f8bf75a81c4a	VISA 16 digit	36.1829419376429158	-115.261578471234429
41131	2020-07-30 10:21:49	2020-07-30	Douglass Terry	douglass.terry@geemail.com	Davie	Florida	3704450396106034	53ad151082f93970969c8f0af833c581	American Express	26.1562300491411257	-80.3552317783609027
41132	2020-07-30 10:22:07	2020-07-30	Dr. Fed Kiehn PhD	dr.fed.kiehn.phd@warmmail.com	Cambridge	Massachusetts	3528539115882190560	2af584d203b9f52b37ffccf6eaa6b190	Discover	42.3823466839957987	-71.0267718217883299
41133	2020-07-30 10:24:15	2020-07-30	Jolie Bruen	jolie.bruen@geemail.com	Madison	Wisconsin	210091954575819782	722970ca77f2384882d3ad1acc7e5c26	VISA 16 digit	42.9997747088290794	-89.4086448221352015
41134	2020-07-30 10:24:41	2020-07-30	Miss Latrice Lesch	miss.latrice.lesch@geemail.com	Hampton	Virginia	3158463623119395084	680c0a4b57365c6dc557f48ddcfa2c8f	American Express	37.0089949235338764	-76.2560832594618176
41135	2020-07-30 10:27:11	2020-07-30	Keli Farrell	keli.farrell@geemail.com	Denver	Colorado	6011092745689975133	b2bf855517b8e00eefb1e0aa45ad069d	JCB 15 digit	39.7170959408912765	-104.852086144011849
41136	2020-07-30 10:41:53	2020-07-30	Gardner Ryan	gardner.ryan@warmmail.com	San Francisco	California	4188701638503919	9f5a829377f71e0a239fdd1920a6554f	Diners Club / Carte Blanche	37.7750802737565792	-122.395019998228136
41137	2020-07-30 10:45:16	2020-07-30	Loring Marks	loring.marks@woohoo.com	Miami Gardens	Florida	3412332456170326	204dfe3acaee9869cc215014a4423d5e	American Express	25.948936053545772	-80.1613286716643785
41138	2020-07-30 10:48:35	2020-07-30	Dr. Annis Volkman	dr.annis.volkman@geemail.com	Memphis	Tennessee	3040723795411989	77819ddae7893271088daefde46a90de	VISA 16 digit	35.1847910707883571	-90.0326210044115811
41139	2020-07-30 11:08:07	2020-07-30	Kristian Medhurst	kristian.medhurst@geemail.com	San Antonio	Texas	3088020815045629471	f0da40f9f51747db632137662efbad7d	JCB 16 digit	29.4562292044121783	-98.5105060139507032
41140	2020-07-30 11:13:37	2020-07-30	Mrs. Caleigh Wilkinson	mrs.caleigh.wilkinson@geemail.com	Philadelphia	Pennsylvania	3096247754465379282	48c63da561ee77303e5b87ae567d3b42	VISA 13 digit	40.0480294951196782	-75.1981290193174061
41141	2020-07-30 11:16:14	2020-07-30	Devyn Gaylord MD	devyn.gaylord.md@geemail.com	New York	New York	3096588750633716147	c6704aed7e3a3463687a46bcea5a0d27	VISA 16 digit	40.7469557570982701	-74.0172209554247473
41142	2020-07-30 11:17:53	2020-07-30	Eva Barrows DVM	eva.barrows.dvm@geemail.com	Fort Collins	Colorado	3528673379941304457	411f05f8384dfe0ec09cd0ba8802a50d	VISA 16 digit	40.6397524207055554	-104.97880513499976
41143	2020-07-30 11:23:45	2020-07-30	Jaleesa Schmitt-Skiles	jaleesa.schmitt.skiles@woohoo.com	Los Angeles	California	869909845574443155	91ed610ea87ba8c0ca53cba6dfb22874	JCB 15 digit	34.006938037169725	-118.482734277797107
41144	2020-07-30 11:32:25	2020-07-30	Benny Reichert	benny.reichert@geemail.com	New York	New York	6011849494606787653	e3ce8477cff5dd9abbd0603406a46714	JCB 16 digit	40.7187196318749329	-74.0345869909401983
41145	2020-07-30 11:33:55	2020-07-30	Mr. Gaylord Fay DVM	mr.gaylord.fay.dvm@geemail.com	Ontario	California	4450014670635347	479843b771d2efbb2dcdec332f00d6d0	VISA 13 digit	34.1036051137518115	-117.586095277276641
41146	2020-07-30 11:34:41	2020-07-30	Mr. Walter Gleichner	mr.walter.gleichner@warmmail.com	San Francisco	California	6011241561794485698	06494a69a73ee4c087b193145319adc1	Diners Club / Carte Blanche	37.7981163440771937	-122.40829535092962
41147	2020-07-30 11:40:20	2020-07-30	Mr. Bernhard Kutch	mr.bernhard.kutch@geemail.com	Wichita	Kansas	3056235076456967	368dd04b7234acef39b7d20017185611	VISA 16 digit	37.6271455156959576	-97.2655236254647377
41148	2020-07-30 11:43:45	2020-07-30	Destin Friesen	destin.friesen@geemail.com	Atlanta	Georgia	3767251449155257	305534f4f10ff251beecc790cf136cdc	American Express	33.7392760246336465	-84.4387154131706836
41149	2020-07-30 11:47:19	2020-07-30	Mckenna Gulgowski	mckenna.gulgowski@geemail.com	Austin	Texas	3001620157810189	8a9a9425f4ea03743f538de5da108bb6	VISA 16 digit	30.2964673156976687	-97.7402207240235157
41150	2020-07-30 11:54:18	2020-07-30	Hilary Schmitt	hilary.schmitt@geemail.com	Raleigh	North Carolina	3433730898987931	b3cca25903ce4f24aaca38dc79cceede	JCB 16 digit	35.8712605255790038	-78.5982882046077407
41151	2020-07-30 11:59:38	2020-07-30	Rocio Lakin	rocio.lakin@woohoo.com	Cincinnati	Ohio	3050926007155001	a0f1b687c28cc1d738407272afabc25d	JCB 15 digit	39.19641739728376	-84.418662513400605
41152	2020-07-30 12:02:10	2020-07-30	Nikia Goyette	nikia.goyette@warmmail.com	Houston	Texas	6011473686242823833	c4924444d50b8fc9e7c59e28cfdbae0c	Maestro	29.8594056508116417	-95.31649003015049
41153	2020-07-30 12:14:10	2020-07-30	Dominque Wilkinson	dominque.wilkinson@geemail.com	Charlotte	North Carolina	52706347602702906	1d5806be4d42a5d1f732c4e7937b60d1	JCB 15 digit	35.2977049579631554	-80.903181014483792
41154	2020-07-30 12:20:32	2020-07-30	Dr. Dudley Lemke	dr.dudley.lemke@geemail.com	Denver	Colorado	3776904734053509	dd301f7e500504fa09a66ed3ffecf2db	JCB 15 digit	39.6846404806762934	-104.958463903820515
41155	2020-07-30 12:30:25	2020-07-30	Mrs. Martha Hand PhD	mrs.martha.hand.phd@geemail.com	Mesa	Arizona	3016698767051126	ebcfd8491567fc83b205e9a786cfb681	VISA 16 digit	33.3882326170947366	-111.707749383838475
41156	2020-07-30 12:30:47	2020-07-30	Lizette Ankunding	lizette.ankunding@woohoo.com	San Francisco	California	3479093756553104	6d76bf4932f57e4ec6e866ae2b4b47be	JCB 15 digit	37.7719459265156701	-122.45413093181412
41157	2020-07-30 12:32:36	2020-07-30	Ira Schuster MD	ira.schuster.md@geemail.com	San Francisco	California	4261865058214156	ea32a707428deaedc87f93bdce88a8c9	VISA 13 digit	37.7651599309590935	-122.449628009943595
41158	2020-07-30 12:45:07	2020-07-30	Percy Veum	percy.veum@geemail.com	Honolulu	Hawaii	4696415261089899	e61be559f742c76614b35fcd5560b241	VISA 16 digit	21.3466478392232233	-157.79491728113257
41159	2020-07-30 12:49:27	2020-07-30	Modena Muller	modena.muller@geemail.com	Fresno	California	4564183823732831	fa315591519e82b24e292924b23ecc7b	Voyager	36.7223875903397783	-119.805853468237075
41160	2020-07-30 12:51:11	2020-07-30	Wende Lowe	wende.lowe@warmmail.com	Oakland	California	180089500167108151	7bf4dad4f248db30fe54d4bd38c0c55c	JCB 16 digit	37.8047748523017901	-122.274094096754766
41161	2020-07-30 12:51:12	2020-07-30	Precious Tromp	precious.tromp@geemail.com	Little Rock	Arkansas	4898104256901	ff70b11402cb8e331d82eb392e5e2921	Maestro	34.8146725042533163	-92.3026460884477871
41162	2020-07-30 13:06:08	2020-07-30	Lacy Lindgren	lacy.lindgren@geemail.com	Carlsbad	California	3528147655268030306	994af19e4339f6549d0a7291918eb606	American Express	33.1545431539356699	-117.301538043308256
41163	2020-07-30 13:10:08	2020-07-30	Jarret Boehm	jarret.boehm@geemail.com	Charlotte	North Carolina	4373381539936768	6a93b972d2f4d69c9ac7df1977d20c12	VISA 16 digit	35.1727126030504706	-80.7366306056212721
41164	2020-07-30 13:11:26	2020-07-30	Evalena Schmeler-Runte	evalena.schmeler.runte@geemail.com	Phoenix	Arizona	180064900843352554	5210144cdc3840341749515e6b1a26f5	Mastercard	33.4843100066229695	-112.18941292897091
41165	2020-07-30 13:13:10	2020-07-30	Cherrie Lind	cherrie.lind@warmmail.com	Indianapolis	Indiana	4770539072148	73d33da6caec04c25dd0fd92f4d0c708	JCB 15 digit	39.6919655901852977	-86.1244495100077216
41166	2020-07-30 13:27:13	2020-07-30	Mrs. Ethyl Larson PhD	mrs.ethyl.larson.phd@geemail.com	Plano	Texas	4400066310637944	16dae48c4e0db44801601fb380bc28f6	JCB 15 digit	33.0307264133907879	-96.6838628586564255
41167	2020-07-30 13:41:51	2020-07-30	Dr. Sheridan Rosenbaum	dr.sheridan.rosenbaum@woohoo.com	High Point	North Carolina	54276634116141659	6d02750144af150baa06476a5ad564e9	Mastercard	35.957103558778762	-79.9516108259297908
41168	2020-07-30 13:53:49	2020-07-30	Brandi Bayer MD	brandi.bayer.md@warmmail.com	San Antonio	Texas	3096354172334406385	3abceb8bdd608ece69e97963e131af6d	Discover	29.5200194413378831	-98.4917927864775038
41169	2020-07-30 14:01:45	2020-07-30	Florance Jerde	florance.jerde@geemail.com	Rochester	New York	3001012606946204	c1c3947031fd832be5690c16d60f8161	VISA 16 digit	43.1298447593092931	-77.5583580723270813
41170	2020-07-30 14:07:02	2020-07-30	Hattie Jast-Kshlerin	hattie.jast.kshlerin@woohoo.com	Worcester	Massachusetts	3112487663682781627	03bca9fc13c50a6ae549e6dcf80d529c	Voyager	42.3336583501361332	-71.9052624108057472
41171	2020-07-30 14:08:28	2020-07-30	Besse Tillman	besse.tillman@geemail.com	Mesa	Arizona	180067651821950045	9b46306cad3a2967052a6e48d3d4dd66	VISA 16 digit	33.3054134546924345	-111.655451834050567
41172	2020-07-30 14:09:05	2020-07-30	Daijah Gusikowski	daijah.gusikowski@geemail.com	Colorado Springs	Colorado	3046612010376735	b2a38c9d640cc3033b456a81db1252f7	Diners Club / Carte Blanche	38.7709060999613229	-104.667711384190994
41173	2020-07-30 14:14:11	2020-07-30	Mr. Arjun VonRueden	mr.arjun.vonrueden@geemail.com	Saint Paul	Minnesota	4726175908706	f1704324f8d9ea418f794150ca742de7	American Express	44.9934799886714671	-93.1798058396469884
41174	2020-07-30 14:17:18	2020-07-30	Lea O'Kon	lea.o'kon@geemail.com	Oakland	California	869958807692307910	3f9d7f525dfcaf39f0563cadcc096447	VISA 16 digit	37.7898124669758886	-122.282483912661107
41175	2020-07-30 14:22:00	2020-07-30	Quinn Sporer DDS	quinn.sporer.dds@geemail.com	Anaheim	California	4878217120426	82b1f9356efb6e50ed916c94a4dda53d	JCB 16 digit	33.8455339859072097	-117.818653510578343
41176	2020-07-30 14:38:34	2020-07-30	Donavan Bartoletti	donavan.bartoletti@geemail.com	San Francisco	California	3096025938203783255	09b7ad6ae67a5cea314c189bc598dfb8	Discover	37.814970916847642	-122.442985344430696
41177	2020-07-30 14:41:14	2020-07-30	Stacey Ritchie	stacey.ritchie@woohoo.com	Raleigh	North Carolina	4917807729059402	0a171f1f99cb8c51f5640386d9f9b35a	American Express	35.7777848316490648	-78.5584300434153562
41178	2020-07-30 14:41:21	2020-07-30	Kisha Gleason	kisha.gleason@geemail.com	Rancho Cucamonga	California	3468631633830188	e5ec1ce9772e153c18548f494f5b5109	Diners Club / Carte Blanche	34.1247713324140776	-117.651505640522387
41179	2020-07-30 15:00:06	2020-07-30	Enzo Marquardt	enzo.marquardt@warmmail.com	San Francisco	California	869959014797285963	71dafd33e62b16adffdd5f8cf4fecc08	Discover	37.791223917936577	-122.418513562582433
41180	2020-07-30 15:02:07	2020-07-30	Rosario Marquardt Jr.	rosario.marquardt.jr.@woohoo.com	Allentown	Pennsylvania	4910594893752	5a8ddd48213a89a59014fc050732ce6f	Discover	40.6894440952934318	-75.4181497346158949
41181	2020-07-30 15:04:57	2020-07-30	Porfirio Terry	porfirio.terry@geemail.com	Portland	Oregon	3023706383843538	1e5e103e555acdcf67ae8c79ea1c8b89	JCB 16 digit	45.500381508737803	-122.642878693342212
41182	2020-07-30 15:11:31	2020-07-30	Lizeth Wisoky	lizeth.wisoky@geemail.com	Los Angeles	California	55992655340411629	47ef5e0f596b05d6ef6ba5580f3873a7	Discover	33.922075022184849	-118.38570200721658
41183	2020-07-30 15:19:17	2020-07-30	Miss Pearlene Ondricka MD	miss.pearlene.ondricka.md@geemail.com	Newark	New Jersey	4993704184035752	c51d148b36ffde3e88556d90cecc44f7	Discover	40.6503467475444111	-74.150559952922535
41184	2020-07-30 15:20:14	2020-07-30	Garner Bayer	garner.bayer@geemail.com	Nashville	Tennessee	3041963820346094	a6ab445f2039854c8741164940f6c0a3	JCB 15 digit	36.162166898477075	-86.6906332877837116
41185	2020-07-30 15:29:04	2020-07-30	Kennth Lueilwitz	kennth.lueilwitz@woohoo.com	San Francisco	California	3337158302055659932	35cdbf2df05f23206c0324a0ce07021b	JCB 16 digit	37.7509789684670878	-122.437011649285154
41186	2020-07-30 15:40:46	2020-07-30	Alaya VonRueden MD	alaya.vonrueden.md@geemail.com	League City	Texas	6011340182956898881	1a657ef0f875e64dee207950a46a4a01	VISA 16 digit	29.5186233524628001	-95.0134265235144682
41187	2020-07-30 15:44:37	2020-07-30	Stephany Romaguera	stephany.romaguera@geemail.com	Memphis	Tennessee	501869347116951	c6906e8507f728ced4de9552fefb5117	Discover	35.035136239190777	-90.0043257117062865
41188	2020-07-30 15:53:14	2020-07-30	Kathyrn Hayes	kathyrn.hayes@geemail.com	South Bend	Indiana	210021853791106872	0f1a1a2b88417b4ef10fd2405730f09d	Maestro	41.6595667858753416	-86.364528353750714
41189	2020-07-30 15:54:06	2020-07-30	Mr. Waymon Rowe	mr.waymon.rowe@geemail.com	Newark	New Jersey	6011249692971701003	f2b26bb278d54fbbc9a61a4ff81d2159	JCB 15 digit	40.6642056086014989	-74.2249105737753183
41190	2020-07-30 16:00:03	2020-07-30	Paityn Treutel	paityn.treutel@geemail.com	Macon	Georgia	54505906262389792	cd9464cb0d945155bf1f23d247178933	Voyager	32.8036217244818786	-83.6352873013082814
41191	2020-07-30 16:04:26	2020-07-30	Corene King	corene.king@geemail.com	Chandler	Arizona	561277889684740	1e0f8ffcbc3ebde701a5dc14666e5f1f	JCB 16 digit	33.2464367128998006	-111.847910931834576
41192	2020-07-30 16:04:40	2020-07-30	Chyna Hegmann-Kuphal	chyna.hegmann.kuphal@geemail.com	San Francisco	California	3442576694146787	9475a62eeae7197f54663657d363e5c9	Diners Club / Carte Blanche	37.7834522840857474	-122.438307996995633
41193	2020-07-30 16:08:17	2020-07-30	Dr. Tyron Rowe DDS	dr.tyron.rowe.dds@geemail.com	San Francisco	California	676257331003657	d751b0c4454a314ce2c9efb11f4e4089	Mastercard	37.7540739840434227	-122.427802785878271
41194	2020-07-30 16:08:30	2020-07-30	Burl Feest MD	burl.feest.md@geemail.com	Oakland	California	3048012468199325	ee81a9152f9e33d6e1d29ecf23df786f	VISA 16 digit	37.8078741820215143	-122.241704450679222
41195	2020-07-30 16:16:52	2020-07-30	Remington Kovacek	remington.kovacek@geemail.com	Phoenix	Arizona	3018114565504462	1419ae0719935cd1a3da66443829f81e	Discover	33.6683927068885467	-112.14196483641156
41196	2020-07-30 16:18:41	2020-07-30	Pinkney Fahey-Schroeder	pinkney.fahey.schroeder@geemail.com	Denver	Colorado	869921156416843246	997722b93c30b1c75a766278ddbd770c	VISA 16 digit	39.742364246962218	-104.888975412562871
41197	2020-07-30 16:19:18	2020-07-30	Orlena Borer-Kuvalis	orlena.borer.kuvalis@geemail.com	Victorville	California	4498132618543094	16f37ee8e0f14533f04dd2446d287967	American Express	34.4821606079813137	-117.357155898508054
41198	2020-07-30 16:22:38	2020-07-30	Mr. Winnie Marquardt PhD	mr.winnie.marquardt.phd@geemail.com	New York	New York	6011963610402818414	f697f47dbb93f2ed0b82dceae0779eaa	JCB 16 digit	40.5753810290936343	-73.8477840736869666
41199	2020-07-30 16:22:39	2020-07-30	Odalys Gleichner-Goldner	odalys.gleichner.goldner@geemail.com	Fort Worth	Texas	4652580085478	ca480e68eba1b3d8635ed729d5d90e5c	Mastercard	32.8033346730805917	-97.2953360013950572
41200	2020-07-30 16:26:48	2020-07-30	Vonnie Jenkins	vonnie.jenkins@geemail.com	Fort Wayne	Indiana	6011188119463058612	82a7617d4ce89bb25431042f47e8e661	Maestro	41.1782371205992987	-85.2158327960628981
41201	2020-07-30 16:45:11	2020-07-30	Rayburn Nolan DVM	rayburn.nolan.dvm@woohoo.com	Chicago	Illinois	3705402061527936	ba1a14fe03ec0028459b5b99a9087279	JCB 16 digit	41.7498798054944729	-87.6945161778043882
41202	2020-07-30 17:05:37	2020-07-30	Kamora Paucek	kamora.paucek@geemail.com	Miami	Florida	4169249924393192	960714be880188803f9818f27f30da50	VISA 16 digit	25.8570089733831594	-80.2741200987123023
41203	2020-07-30 17:13:10	2020-07-30	Mr. Gannon Wilkinson	mr.gannon.wilkinson@geemail.com	Los Angeles	California	3736921828589569	a9d7e17390dc8fe1b339013e85042142	Voyager	33.9216791787050624	-118.472942837699492
41204	2020-07-30 17:20:02	2020-07-30	Ms. Jazmyn Considine DDS	ms.jazmyn.considine.dds@geemail.com	Edison	New Jersey	53369013805116017	c5f25e29d6e3edf771eb4339c877f3d2	JCB 16 digit	40.4682628220841281	-74.2558427371136816
41205	2020-07-30 17:24:26	2020-07-30	Maria Hoeger	maria.hoeger@geemail.com	Waco	Texas	869990578293016453	7b0cb47664039827e61497536e807e77	JCB 16 digit	31.5657395471096009	-97.1266206387560942
41206	2020-07-30 17:40:20	2020-07-30	Marie Larson	marie.larson@geemail.com	New Orleans	Louisiana	869973476152350744	f29586fab91db154b68cd8a8e68f49c5	Voyager	30.0886254258468746	-89.9553983898628502
41207	2020-07-30 17:53:58	2020-07-30	Elfie Gislason DDS	elfie.gislason.dds@geemail.com	Jackson	Mississippi	3025239087956545	2ee7caeb76693ea88631f2ad2d72fdea	Discover	32.3762430709499895	-90.2995793613113449
41208	2020-07-30 18:12:38	2020-07-30	Dr. Lark Olson PhD	dr.lark.olson.phd@woohoo.com	Fremont	California	55557503526558465	815fbede1ef696e931d0b1b494096d09	Maestro	37.4787546911910212	-121.992284943441675
41209	2020-07-30 18:15:18	2020-07-30	Dr. Kordell Waelchi II	dr.kordell.waelchi.ii@woohoo.com	Sterling Heights	Michigan	210016247763705828	ec635051251fb497498fb9e8edda79a4	VISA 16 digit	42.5635411480989347	-83.087313289304447
41210	2020-07-30 18:29:54	2020-07-30	Mr. Myrtle Aufderhar	mr.myrtle.aufderhar@geemail.com	Independence	Missouri	4505643699718455	af086cfed4ff1385c9cd8d23ef10bb87	JCB 16 digit	39.0614527531452538	-94.2966837510749656
41211	2020-07-30 18:37:58	2020-07-30	Ofelia Roberts MD	ofelia.roberts.md@geemail.com	Anchorage	Alaska	4398617090160	e6ece45adb2d291a696955fdcd07294e	JCB 16 digit	61.132993383773794	-149.285671451281019
41212	2020-07-30 18:47:17	2020-07-30	Cloe Aufderhar DVM	cloe.aufderhar.dvm@geemail.com	Springfield	Massachusetts	3047693036175987	d2a71de50bc02e1276947556f081d0c4	American Express	42.129930593792345	-72.5848887550737771
41213	2020-07-30 19:00:44	2020-07-30	Hayes Kozey	hayes.kozey@geemail.com	Sacramento	California	53567024811103642	73ed7d21c83b7614dfd1059d04c765a8	Diners Club / Carte Blanche	38.547002213381603	-121.516717321263997
41214	2020-07-30 19:07:51	2020-07-30	Dr. Randolf Jacobs V	dr.randolf.jacobs.v@geemail.com	Oakland	California	51782327272111767	f2f1cf3f314a20172ab77d7f0cebfb92	American Express	37.7856289371529357	-122.280918747569856
41215	2020-07-30 19:08:19	2020-07-30	Hakim Boyle	hakim.boyle@geemail.com	Kansas City	Kansas	4270024489790	b7a98562f4a975a987d8f66376c77f1f	JCB 16 digit	39.0455717283673636	-94.680658561683444
41216	2020-07-30 19:12:56	2020-07-30	Ms. Rosetta Bashirian MD	ms.rosetta.bashirian.md@geemail.com	Berkeley	California	3158681333706041515	88bba968bc95ae291324901329936222	American Express	37.879493864755446	-122.267122578658075
41217	2020-07-30 19:14:24	2020-07-30	Mckenzie Larkin	mckenzie.larkin@woohoo.com	Arvada	Colorado	869935646920240255	4764ddd1577208c74cf815b129114d8d	Voyager	39.7742693082138885	-105.156628687351201
41218	2020-07-30 19:23:48	2020-07-30	Newell Volkman	newell.volkman@geemail.com	New York	New York	4438466449982	5f46780263e374443e9a6a7ee5b4728e	VISA 13 digit	40.6175998569224035	-73.8516866784904096
41219	2020-07-30 19:24:50	2020-07-30	Doyle Witting	doyle.witting@warmmail.com	Victorville	California	3088169917214583470	946f61694712bf00d145175357d390ed	Discover	34.5231860267229393	-117.27530860962942
41220	2020-07-30 19:27:44	2020-07-30	Dr. Olaf Mante	dr.olaf.mante@geemail.com	Joliet	Illinois	869954676170768743	a0b75236b0f4d9728b91f29bd2cfb083	American Express	41.5634608201075295	-88.2037081374425327
41221	2020-07-30 19:27:45	2020-07-30	Flonnie Carroll	flonnie.carroll@geemail.com	Los Angeles	California	3028054002169463	12fdbccb771100942fff944851771b1f	JCB 16 digit	33.960451477426659	-118.35753202820122
41222	2020-07-30 19:33:59	2020-07-30	Jevon Runolfsdottir-Witting	jevon.runolfsdottir.witting@woohoo.com	New York	New York	3733002007148411	f0a54e3afdec4460a572af441a45d5b9	Mastercard	40.6424222811348699	-73.8841978384543125
41223	2020-07-30 19:38:01	2020-07-30	Burnell Abshire	burnell.abshire@geemail.com	Oklahoma City	Oklahoma	4565953545495803	3feea74a0103f6f5dc39439dad10d85f	Diners Club / Carte Blanche	35.3731470793861931	-97.4166734395910083
41224	2020-07-30 19:41:58	2020-07-30	Reyna Weissnat	reyna.weissnat@geemail.com	New York	New York	3015095379379279	d646aadaef893aedd825f148447f791e	Mastercard	40.644446088489147	-74.029069798894966
41225	2020-07-30 19:49:53	2020-07-30	Kylee Kautzer	kylee.kautzer@geemail.com	San Francisco	California	6011527974667725733	c89c31411ec0ebdb1d645b9143b5d29e	JCB 16 digit	37.802243840003527	-122.43119342183239
41226	2020-07-30 19:57:27	2020-07-30	Jere Schmitt Jr.	jere.schmitt.jr.@geemail.com	Minneapolis	Minnesota	3043892026560943	d0984e4a8ea0408b3e61df35cbe45855	Maestro	44.9882876819085311	-93.2514340382806921
41227	2020-07-30 20:00:42	2020-07-30	Lady Dibbert	lady.dibbert@warmmail.com	New York	New York	3723439386016086	7bdc2de4ea401ca78bc9d9d9c5f59b70	Voyager	40.64124080517702	-73.9849122684344565
41228	2020-07-30 20:07:02	2020-07-30	Nathan Nienow-Farrell	nathan.nienow.farrell@geemail.com	Philadelphia	Pennsylvania	3088810757010120900	ba63c9657f83d6fe54cd34b7780f47c7	VISA 16 digit	40.0866859232500161	-75.1036856220934652
41229	2020-07-30 20:08:37	2020-07-30	Rayan Yost	rayan.yost@geemail.com	New York	New York	52110137224575065	ba18fac7e4ba66d13393e806748608db	VISA 13 digit	40.5976829292476182	-73.9438993268541935
41230	2020-07-30 20:23:10	2020-07-30	Peggy Ortiz	peggy.ortiz@geemail.com	Pittsburgh	Pennsylvania	869975727005158595	903f7ef9d6418101a9bcf3c22581d176	Voyager	40.4553023510567797	-80.0648074041757809
41231	2020-07-30 20:29:54	2020-07-30	Ms. Marian Moen DVM	ms.marian.moen.dvm@geemail.com	Fort Worth	Texas	3034782910805471	c3208a07da4e2a04717b259ea62dd38e	VISA 13 digit	32.8602218428216872	-97.2995550504706728
41232	2020-07-30 20:36:53	2020-07-30	Briana Hilll-Reilly	briana.hilll.reilly@geemail.com	New York	New York	4701454715766011	ee903b101310fbc224faf9b56eac72f0	VISA 16 digit	40.6330041805040096	-73.9726694899041206
41233	2020-07-30 20:44:35	2020-07-30	Isabel Tillman	isabel.tillman@woohoo.com	Denver	Colorado	3703975303374847	f917a7e1e17997a5f1c2dc37a5fbead9	Mastercard	39.6791729280311571	-104.873630985968191
41234	2020-07-30 20:45:17	2020-07-30	Evalyn White DDS	evalyn.white.dds@geemail.com	Ontario	California	869957866046514929	ff5e7c9cafd71e2772c19968be9da0ee	Discover	34.0009753799211225	-117.683593234010786
41235	2020-07-30 20:47:46	2020-07-30	Parlee Feeney	parlee.feeney@geemail.com	San Jose	California	3015580045406895	573e3dcc9cbd9df1bcdb5de04d397cf9	Diners Club / Carte Blanche	37.2344771661151199	-121.797748483785981
41236	2020-07-30 21:02:33	2020-07-30	Patsy Runte MD	patsy.runte.md@geemail.com	Fort Lauderdale	Florida	3710211017599359	f3ea356daae98c9f3aeadf466b213f54	JCB 15 digit	26.0631340329058467	-80.0514752182464946
41237	2020-07-30 21:09:43	2020-07-30	Ludie Wintheiser	ludie.wintheiser@geemail.com	New York	New York	3096932218360207972	efb0a2c1a922e82d00f647ebdc773ab4	Voyager	40.6678866475112741	-73.8481510997179811
41238	2020-07-30 21:11:26	2020-07-30	Hadley Schulist	hadley.schulist@geemail.com	Omaha	Nebraska	52423994576956414	9b2f1e5093bcd273aa05543f396e000f	Maestro	41.248870866341143	-96.0095084652420212
41239	2020-07-30 21:19:56	2020-07-30	Delphine Ebert	delphine.ebert@geemail.com	Toledo	Ohio	3528508833624512134	44fb6edc71d296e86182106b4f8f7987	JCB 16 digit	41.6681696378331594	-83.4912760617543057
41240	2020-07-30 21:20:32	2020-07-30	Rosendo O'Conner-Smith	rosendo.o'conner.smith@geemail.com	San Francisco	California	3485314194629781	2ceaa2d345627b38275f4ea96380d5e8	Diners Club / Carte Blanche	37.7909924340159336	-122.426416496298643
41241	2020-07-30 21:27:37	2020-07-30	Mr. Damon Welch II	mr.damon.welch.ii@geemail.com	Buffalo	New York	3743269866206923	348517fdf488c3f445b060554fdfbc08	JCB 15 digit	42.9087659356370565	-78.9473350544393071
41242	2020-07-30 21:28:51	2020-07-30	Salome Kling	salome.kling@geemail.com	Fairfield	California	869937504555699030	93f24eedc18a13dea6b8861b7131c393	JCB 16 digit	38.1820815482765497	-121.971277586603904
41243	2020-07-30 21:33:01	2020-07-30	Mr. Santino Hane Jr.	mr.santino.hane.jr.@geemail.com	Seattle	Washington	210019292863534469	28346d2e8eba4dddfe06676c62ca4885	JCB 16 digit	47.6282394363004684	-122.331468928597488
41244	2020-07-30 21:35:41	2020-07-30	Mr. Curtiss Hodkiewicz II	mr.curtiss.hodkiewicz.ii@geemail.com	Newark	New Jersey	869956804191232139	eb8e837286ecf74e90960c0268ac17f1	Diners Club / Carte Blanche	40.702983160168678	-74.2357477042566956
41245	2020-07-30 21:35:48	2020-07-30	Ms. Desiree Rosenbaum	ms.desiree.rosenbaum@woohoo.com	Fontana	California	3112924448668078607	544857d325c0244a323450235405c35c	American Express	34.1236154936403082	-117.416612754556908
41246	2020-07-30 21:40:36	2020-07-30	Arnett Hirthe	arnett.hirthe@woohoo.com	Chicago	Illinois	6011612317358557658	704c07061fb0cbfa7862269eced0c964	Maestro	41.8085909570869063	-87.7546246362414166
41247	2020-07-30 21:55:53	2020-07-30	Olene Gulgowski	olene.gulgowski@woohoo.com	Fort Worth	Texas	3403567261844505	d2734f16389e8a143c184fa36e971f58	VISA 16 digit	32.730801779503004	-97.256980595021318
41248	2020-07-30 21:58:11	2020-07-30	Amos Dach Sr.	amos.dach.sr.@geemail.com	Tucson	Arizona	3011880088131598	23892da3158d87bd3e609741fb95a608	Voyager	32.0696307471063022	-110.950603756890075
41249	2020-07-30 22:29:15	2020-07-30	Cora Mante	cora.mante@geemail.com	Charlotte	North Carolina	3758257628143114	b01b27953bfc25e23902f197b7f75c36	American Express	35.274796979014944	-80.8399443392120389
41250	2020-07-30 22:30:49	2020-07-30	Shay Wintheiser	shay.wintheiser@geemail.com	Aurora	Colorado	3088546164210032442	07dd4309f79237c1a71c733a7c96d5c5	JCB 16 digit	39.7603941734992006	-104.618475581251829
41251	2020-07-30 22:32:26	2020-07-30	Eric Collier-Volkman	eric.collier.volkman@geemail.com	Long Beach	California	6011850325090816689	169df4a299cb2bf6ceda240dd37a3b19	American Express	33.8570409728966624	-118.119953839031226
41252	2020-07-30 22:32:30	2020-07-30	Amiyah Goldner-Raynor	amiyah.goldner.raynor@geemail.com	Lowell	Massachusetts	3005712089436682	77a109aadf9b4a61c81e228c6355ef44	Voyager	42.5937628274653122	-71.3018372598443193
41253	2020-07-30 22:32:53	2020-07-30	Allene Tromp	allene.tromp@warmmail.com	Cleveland	Ohio	869988602687355311	4a3f79d82b166ebc9948dbf375d348b0	Mastercard	41.3959239729065445	-81.5968846768379166
41254	2020-07-30 22:35:46	2020-07-30	Lanny Schmitt	lanny.schmitt@geemail.com	Jacksonville	Florida	6011757795192851848	4a1834ddc21852996cb2c9ffe8a28b1e	VISA 16 digit	30.3910702406480908	-81.7515848328903445
41255	2020-07-30 22:36:21	2020-07-30	Ms. Presley Hartmann	ms.presley.hartmann@geemail.com	Vancouver	Washington	4662101676978	6f6cf21b9c5d7a23069bef255400bb14	Mastercard	45.6595339486911911	-122.6829141573578
41256	2020-07-30 22:37:47	2020-07-30	Helmer Wisozk	helmer.wisozk@geemail.com	Berkeley	California	3337036124143625040	f409f9996d7455209320dfcbeefdbcb5	VISA 16 digit	37.8909311938857485	-122.268442841769684
41257	2020-07-30 22:47:05	2020-07-30	Dr. Leamon Bins DVM	dr.leamon.bins.dvm@geemail.com	Indianapolis	Indiana	6011464594587659120	71d11c988f6a6ef4869161a37bfb03a3	Voyager	39.7053394126247596	-86.1141123222388245
41258	2020-07-30 22:52:52	2020-07-30	Marlo Hayes-Conroy	marlo.hayes.conroy@geemail.com	Berkeley	California	4858776305982074	bf0a874fbda56094f0b5fcecc76ad1ea	Maestro	37.8799492765410051	-122.256485070828617
41259	2020-07-30 23:00:18	2020-07-30	Merlin Reichert-Rempel	merlin.reichert.rempel@geemail.com	San Francisco	California	869966574262911915	f0110d61fa71aefa4d5628dc6af12b0c	VISA 16 digit	37.7944516388747545	-122.423915466039219
41260	2020-07-30 23:01:23	2020-07-30	Trae Spencer	trae.spencer@geemail.com	Atlanta	Georgia	4009381103158718	c219598a69ba5101d2109cbb63b95d8e	JCB 16 digit	33.693289084760103	-84.4124420267108917
41261	2020-07-30 23:01:49	2020-07-30	Marlene Steuber	marlene.steuber@woohoo.com	Denver	Colorado	3088994438381207489	a92bffab95e417c7f05847c991858562	Diners Club / Carte Blanche	39.8154788899753243	-104.835400000611699
41262	2020-07-30 23:09:22	2020-07-30	Jeanetta Jacobs	jeanetta.jacobs@woohoo.com	Washington	District of Columbia	869964527357708226	7beafd4cbc4a0c373293ee5ffd218fd7	JCB 16 digit	38.9141538059603391	-76.9419501635458403
41263	2020-07-30 23:10:30	2020-07-30	Marylyn O'Keefe	marylyn.o'keefe@geemail.com	Jacksonville	Florida	4757821414666945	e5ac30c95927f6064092e8b4792e2717	Diners Club / Carte Blanche	30.2555759596224867	-81.6848291776687034
41264	2020-07-30 23:19:51	2020-07-30	Jamila Hudson PhD	jamila.hudson.phd@woohoo.com	Los Angeles	California	4896506107023858	f1cef16019a50fe5b8e9e961e8573126	Discover	34.0497315035998795	-118.321664876350383
41265	2020-07-30 23:40:07	2020-07-30	Dewitt Hills	dewitt.hills@woohoo.com	Los Angeles	California	3337146659973099946	08d0f656f1dea1625d17487c83ca868d	Maestro	33.9977724450506216	-118.407454637716711
41266	2020-07-30 23:44:42	2020-07-30	Miss Alla Hammes DVM	miss.alla.hammes.dvm@geemail.com	Jackson	Mississippi	4738503643210	2d0a5ffd5079ad4059c26b679bfc3569	VISA 16 digit	32.2962573449771853	-90.3064263656709301
41267	2020-07-30 23:44:50	2020-07-30	Euna Rippin-Littel	euna.rippin.littel@geemail.com	Pittsburgh	Pennsylvania	3459561909741697	6a1db7e08794de9aa047e5e3c8da17b4	JCB 16 digit	40.419949531830099	-80.0558672495823345
41268	2020-07-30 23:50:21	2020-07-30	Gilmore Shields	gilmore.shields@geemail.com	Austin	Texas	180097906121481586	297fb18b218f04a1a330cf5f12bb2b27	American Express	30.2459839289203281	-97.6571185444254439
41269	2020-07-31 00:07:12	2020-07-31	Hildegarde Rolfson	hildegarde.rolfson@geemail.com	Reno	Nevada	3158021760230655312	32d764635bc5fb941075c773c12cbe6a	Maestro	39.606716978278385	-119.836966781241458
41270	2020-07-31 00:08:01	2020-07-31	Merilyn Nader	merilyn.nader@geemail.com	San Francisco	California	4068282985206	b155f567b9efe5e8fd94d182db64e1a8	Diners Club / Carte Blanche	37.7493120942007323	-122.390960412775755
41271	2020-07-31 00:09:23	2020-07-31	Chalmer Schamberger-Hahn	chalmer.schamberger.hahn@geemail.com	San Francisco	California	6011715689574022790	f750c0a7e9fa7614820d6085eed1c9e0	JCB 15 digit	37.7433821137880301	-122.433031405555738
41272	2020-07-31 00:11:51	2020-07-31	Kenan Murphy Jr.	kenan.murphy.jr.@geemail.com	Long Beach	California	060416064171412	e7d789c8b4a6ac59432915a34b88e966	Discover	33.7958943140979855	-118.084262034499275
41273	2020-07-31 00:20:59	2020-07-31	Dr. Deyanira Kling	dr.deyanira.kling@geemail.com	West Palm Beach	Florida	3528812756365707624	64432815a1689ce2d83b4b9172e09b38	JCB 16 digit	26.7985867676172411	-80.0608544796541395
41274	2020-07-31 00:23:41	2020-07-31	Mr. Davin Beahan PhD	mr.davin.beahan.phd@geemail.com	San Francisco	California	210096650530643748	a9d74c6662503249a1ffa48044f59830	Maestro	37.7708220210710834	-122.394885985731293
41275	2020-07-31 00:25:49	2020-07-31	Gussie Baumbach	gussie.baumbach@geemail.com	Houston	Texas	3337774608290137250	1592c80e294a26d7793525f4b27de998	VISA 16 digit	29.7693940838411457	-95.4063261095915038
41276	2020-07-31 00:31:01	2020-07-31	Mallie Hayes	mallie.hayes@woohoo.com	Long Beach	California	3001945172437381	e4b22de413266efd4c0ff39e422b1dad	JCB 16 digit	33.8162355793926821	-118.176021733104434
41277	2020-07-31 00:34:23	2020-07-31	Barry Smitham-Conn	barry.smitham.conn@geemail.com	Washington	District of Columbia	3414376145982532	b037c3aa528965aee89fd5278ce195aa	JCB 16 digit	38.8984694315850703	-77.0570856467101777
41278	2020-07-31 00:43:49	2020-07-31	Miss Dorothea Sporer PhD	miss.dorothea.sporer.phd@geemail.com	New York	New York	676256734679584	6c9aaf0667774a475fc92d31f980ef34	VISA 16 digit	40.6567525102049103	-73.9482394570846111
41279	2020-07-31 00:52:57	2020-07-31	Miss Deetta McGlynn MD	miss.deetta.mcglynn.md@geemail.com	San Antonio	Texas	3742856592448117	7ef01737d656a5afe6170f9e2d35e5e3	Discover	29.4038769843593251	-98.5144114720471151
41280	2020-07-31 00:53:51	2020-07-31	Carry Kub	carry.kub@geemail.com	New York	New York	589306264990745	7674d79c2b437078fa32eb1775548be6	Discover	40.664570163026454	-74.0078185991279724
41281	2020-07-31 01:04:44	2020-07-31	Margretta Romaguera-Howell	margretta.romaguera.howell@geemail.com	Philadelphia	Pennsylvania	4291689143348710	c3580bd6b7ffd369f21e34827d497ec7	Discover	39.9193218114744894	-75.1732399612099016
41282	2020-07-31 01:05:33	2020-07-31	Shawnna Batz	shawnna.batz@warmmail.com	San Antonio	Texas	561205877783034	88a54300c79f681cb83c26b49c8731a6	JCB 16 digit	29.536845623056962	-98.4791469778701583
41283	2020-07-31 01:15:19	2020-07-31	Mr. Howard Bogan DVM	mr.howard.bogan.dvm@geemail.com	Memphis	Tennessee	4531211332880484	4770abe017f232019f21c0e96968cb0b	JCB 16 digit	35.1382021062143153	-89.911150471146783
41284	2020-07-31 01:26:08	2020-07-31	Mrs. Mandy Volkman	mrs.mandy.volkman@warmmail.com	Wichita	Kansas	3048531671407530	23741068528774bfaff7c28617a94176	VISA 16 digit	37.6666790112264422	-97.2858438987951786
41285	2020-07-31 01:28:32	2020-07-31	Dr. Andrae McKenzie IV	dr.andrae.mckenzie.iv@warmmail.com	Las Vegas	Nevada	6011043861072628674	447451f951fa2070f09f3fea3a6b9b69	VISA 16 digit	36.2915779768589886	-115.254233212324223
41286	2020-07-31 01:34:28	2020-07-31	Darold Nitzsche	darold.nitzsche@geemail.com	San Jose	California	180008405620843402	e1a86e2a1512b20c8ce3400b01f15879	JCB 16 digit	37.2435481048010288	-121.902676777749875
41287	2020-07-31 01:46:34	2020-07-31	Miguel Collins DVM	miguel.collins.dvm@warmmail.com	Knoxville	Tennessee	4864059100351171	d0db09833559240a3c7ff30850e55534	Voyager	35.9969632562313251	-83.9277787835553255
41288	2020-07-31 01:48:36	2020-07-31	Jerrold Zboncak	jerrold.zboncak@warmmail.com	San Francisco	California	561202916708908	0188bfb6245a3bf2455ee1c9e1b16e9b	Maestro	37.7731768488147992	-122.442842663373739
41289	2020-07-31 01:53:16	2020-07-31	Leo Deckow-Ratke	leo.deckow.ratke@geemail.com	Berkeley	California	6011521991240960468	29835ea211327c37d293eab16acd260f	Mastercard	37.8494529996611462	-122.282625887180217
41290	2020-07-31 01:56:06	2020-07-31	Ms. Estell Douglas DVM	ms.estell.douglas.dvm@geemail.com	Virginia Beach	Virginia	3022485751673329	27dad1baa0deacb8b59eeb44110ae9a0	VISA 13 digit	36.7492441517952813	-76.1005885789308678
41291	2020-07-31 01:57:55	2020-07-31	Dallas Becker	dallas.becker@geemail.com	Nashville	Tennessee	3158534026905137063	fd220773061f53704b7a3c7822e4bd33	Maestro	36.1404719416640674	-86.8271348587144161
41292	2020-07-31 02:07:00	2020-07-31	Abbie Homenick-Farrell	abbie.homenick.farrell@geemail.com	Detroit	Michigan	4716506399030	6f0a0a93e77ec00ae7cf43a369e0c8ec	Mastercard	42.3155252202339511	-83.0969253174614124
41293	2020-07-31 02:10:33	2020-07-31	Ramiro Douglas	ramiro.douglas@warmmail.com	Spokane	Washington	3112671536000856634	daf6b2e3fb7da2a89e24d78be42584b7	Maestro	47.7615191127411975	-117.480658163492762
41294	2020-07-31 02:11:51	2020-07-31	Merry Dicki PhD	merry.dicki.phd@geemail.com	North Las Vegas	Nevada	3006962654049639	8dbbd42192586dc6e4ea4cfe1cb1b20d	American Express	36.3028531920321242	-115.177852054521068
41295	2020-07-31 02:12:06	2020-07-31	Tollie Cormier	tollie.cormier@geemail.com	Modesto	California	3088873680473383290	eb9d9ad17174606443b196c2f325c3d4	JCB 15 digit	37.5754498665686754	-120.925581025725236
41296	2020-07-31 02:14:49	2020-07-31	Dr. Jaslyn Reichert DDS	dr.jaslyn.reichert.dds@woohoo.com	San Francisco	California	869962928467974645	8d4d8ecf400f4466428af5d57a395dcc	VISA 16 digit	37.7632660327843794	-122.431333422284283
41297	2020-07-31 02:15:35	2020-07-31	Sasha Hansen MD	sasha.hansen.md@geemail.com	San Francisco	California	675904299015158	9ac55b4cbbc600a28eb2a54b89326d22	VISA 13 digit	37.7589176367095902	-122.486279484960818
41298	2020-07-31 02:22:34	2020-07-31	Dolores Frami	dolores.frami@geemail.com	San Francisco	California	52083314769744660	df182647f4ffbcfb9316e679e1817f88	VISA 16 digit	37.773304978685637	-122.394440947507178
41299	2020-07-31 02:26:06	2020-07-31	Michial Price-Shanahan	michial.price.shanahan@woohoo.com	Manchester	New Hampshire	4563744907114609	b17d14a844d6a55ea9eb8f3cdfdadee7	Voyager	42.887841735135396	-71.4359444951064972
41300	2020-07-31 02:45:20	2020-07-31	Elnora Rippin	elnora.rippin@geemail.com	San Francisco	California	52880163420455140	c3c7c23387831e1caaefd98f5f9133c3	Diners Club / Carte Blanche	37.772293278135308	-122.441499992212357
41301	2020-07-31 02:58:31	2020-07-31	Debbra Rippin	debbra.rippin@geemail.com	San Diego	California	3088033488909163980	5452bb31e55c3ca720bcea2031e2ab0c	American Express	32.8147333947077371	-117.144422367019587
41302	2020-07-31 03:05:02	2020-07-31	Dr. Taina Schuster DDS	dr.taina.schuster.dds@geemail.com	Tampa	Florida	3007775767615396	a219be896ce93f526c1fc6cc4fa84492	Voyager	27.949704144161565	-82.5618648668497741
41303	2020-07-31 03:10:12	2020-07-31	Kennedi Lang	kennedi.lang@geemail.com	Mesa	Arizona	53271742084942274	24cac2e293ea3ed204d82c37e951fd3c	VISA 16 digit	33.4393402807559781	-111.695651142427323
41304	2020-07-31 03:21:48	2020-07-31	Halsey Runolfsdottir	halsey.runolfsdottir@geemail.com	Austin	Texas	3787609287611432	eba9102858b40ab96a2e8c47791f22d2	Discover	30.3509256431493881	-97.8455306765396244
41305	2020-07-31 03:25:26	2020-07-31	Kara Lubowitz DDS	kara.lubowitz.dds@geemail.com	Washington	District of Columbia	589318208238875	5698b76d115b27f5dfc017fe6284c476	JCB 15 digit	38.8287261910069716	-77.1124198463957811
41306	2020-07-31 03:32:34	2020-07-31	Kevin Shanahan	kevin.shanahan@geemail.com	Scottsdale	Arizona	3410517721044221	77748ffbf826382078f1e434207c0c23	Diners Club / Carte Blanche	33.7354621578130889	-111.796457089294108
41307	2020-07-31 03:37:33	2020-07-31	Letty Parisian	letty.parisian@geemail.com	Dallas	Texas	869989208572912411	cac62e4d64aedadb91b61e6ce274898a	VISA 16 digit	32.7061168417140848	-96.7405268060471855
41308	2020-07-31 03:58:35	2020-07-31	Tyreek Stark	tyreek.stark@geemail.com	New York	New York	3337828560836897614	349224bbe345bfd974f870b44ebd4b41	Discover	40.7006896879281825	-73.9212374873355031
41309	2020-07-31 04:00:35	2020-07-31	Conor Towne	conor.towne@geemail.com	Davie	Florida	4876445787768	e9ead261c06cecc2a4d9680df0fafdb8	VISA 16 digit	25.9969068566601713	-80.2674944754131161
41310	2020-07-31 04:10:47	2020-07-31	Aaden Hagenes	aaden.hagenes@warmmail.com	Seattle	Washington	3112480716720169309	c109feebc1af04d8082dda1af611729c	JCB 15 digit	47.7132699440624535	-122.372699172973256
41311	2020-07-31 04:10:58	2020-07-31	Ms. Siobhan O'Reilly DDS	ms.siobhan.o'reilly.dds@woohoo.com	Los Angeles	California	4804395520204126	adeeccfba126965d166b5167e6b97c6b	Diners Club / Carte Blanche	34.0010238860133995	-118.465734518923981
41312	2020-07-31 04:11:30	2020-07-31	Alani Hegmann	alani.hegmann@woohoo.com	Lincoln	Nebraska	4163197077387501	2b45c039c110c7b5f0fc4af09dc20845	VISA 16 digit	40.7404661137629276	-96.7287724652022121
41313	2020-07-31 04:13:03	2020-07-31	Rahul Wilderman Sr.	rahul.wilderman.sr.@geemail.com	Washington	District of Columbia	675913341968272	e8bfdf76a1bea70e8475467bb2ed89d4	VISA 16 digit	38.9563969133686285	-77.0443982159931267
41314	2020-07-31 04:16:49	2020-07-31	Margretta Shanahan	margretta.shanahan@geemail.com	Memphis	Tennessee	3096996667347959761	02d261bca466337c648487d60ac7eaf7	JCB 16 digit	35.1283154674407143	-90.0047753114044724
41315	2020-07-31 04:21:51	2020-07-31	Bethzy Toy	bethzy.toy@warmmail.com	Waterbury	Connecticut	180003138760757349	7a43c4b6cac9c639ea9678a2f2f9fe93	JCB 15 digit	41.6314106225073388	-72.9884525269649913
41316	2020-07-31 04:27:29	2020-07-31	Mr. Dannie Morar	mr.dannie.morar@geemail.com	San Francisco	California	4103213676374	4f18eca218ebf8a6320d66e6dbcd7bf8	Discover	37.7725729696178902	-122.477944519648503
41317	2020-07-31 04:29:26	2020-07-31	Asbury Goodwin DVM	asbury.goodwin.dvm@geemail.com	North Charleston	South Carolina	4249563810219160	f0f9e90ef7b13fb60297371f61526131	American Express	32.9104119191572053	-80.1242635171022215
41318	2020-07-31 04:34:31	2020-07-31	Demian Lesch	demian.lesch@geemail.com	Pasadena	California	4929294514849	d16a3ab71f1f6902c370ee25014ca662	JCB 16 digit	34.1142257814615988	-118.201521293940402
41319	2020-07-31 04:59:32	2020-07-31	Kymani Gorczany	kymani.gorczany@geemail.com	New York	New York	3747158057831407	d62b85b403444be7b2147aa5d72712aa	Diners Club / Carte Blanche	40.66510245485604	-73.8408386334206881
41320	2020-07-31 05:08:09	2020-07-31	Dr. Kerrie Batz DVM	dr.kerrie.batz.dvm@geemail.com	San Antonio	Texas	4413813491143266	d1966858a1bc160a3e9a92db08128513	JCB 16 digit	29.4654064490530629	-98.530244430976353
41321	2020-07-31 05:09:47	2020-07-31	Mr. Merlin Lakin	mr.merlin.lakin@geemail.com	Oakland	California	4070618583911	cd8198570b1c982caf7d5b937acb0392	VISA 16 digit	37.7849753540209079	-122.281812560172
41322	2020-07-31 05:13:18	2020-07-31	Rasheed Casper	rasheed.casper@geemail.com	New York	New York	4729610561725884	71c7ea9054879d949bd12c3e97008956	JCB 16 digit	40.5715078057944751	-74.0294947898842395
41323	2020-07-31 05:15:04	2020-07-31	Alesia Auer	alesia.auer@woohoo.com	Columbus	Ohio	4304393596248	ac837200db1dc20835f210399a73f524	Maestro	39.9223125500183542	-83.0810055797223015
41324	2020-07-31 05:29:43	2020-07-31	Norma Ortiz	norma.ortiz@warmmail.com	Atlanta	Georgia	3792105528456458	ca6d98de46be5cccccd5073555f1e2c7	VISA 16 digit	33.8394305317472686	-84.3691139184914647
41325	2020-07-31 05:43:00	2020-07-31	Suzanne Hane-Spinka	suzanne.hane.spinka@geemail.com	Amarillo	Texas	4950807436676876	d118e1f1d75c5a7fb48f5f18bb9b8417	VISA 16 digit	35.2697375641834014	-101.907536922474208
41326	2020-07-31 06:02:32	2020-07-31	Nichol Jerde-Kautzer	nichol.jerde.kautzer@geemail.com	Oakland	California	869960220421353732	526362732ae69da24843784996439cb6	Discover	37.8082204415966459	-122.257189063565207
41327	2020-07-31 06:10:29	2020-07-31	Cameron Douglas-Pfannerstill	cameron.douglas.pfannerstill@geemail.com	Mesa	Arizona	6011163141651933678	3bdad26f5c20249f1f9fb2f1cbb22387	Voyager	33.3238598076306261	-111.631274214282257
41328	2020-07-31 06:11:11	2020-07-31	Leora Bogisich-Pfannerstill	leora.bogisich.pfannerstill@geemail.com	Detroit	Michigan	501850182595954	649142b9c44fe2e3e96918cf73c829d5	Diners Club / Carte Blanche	42.2877448724042679	-83.0731462181664995
41329	2020-07-31 06:21:58	2020-07-31	Dorr Shanahan	dorr.shanahan@warmmail.com	Salinas	California	4369024684166833	1119734be592d2b124c8dd659a6d41b5	VISA 16 digit	36.7165250106479917	-121.579680716170742
41330	2020-07-31 06:25:00	2020-07-31	Kirstin Bernier	kirstin.bernier@geemail.com	Fort Worth	Texas	869926778841153613	fbfaf373bc5be27833e0398bcf147a3f	JCB 15 digit	32.7758250588141422	-97.3755281443063154
41331	2020-07-31 06:25:36	2020-07-31	Mikeal Flatley	mikeal.flatley@geemail.com	New York	New York	6011454412608359038	0dd31c4bb6010efd9027bec66a538188	VISA 16 digit	40.6450860808361298	-73.8637719058793039
41332	2020-07-31 06:42:51	2020-07-31	Dr. Needham Koepp I	dr.needham.koepp.i@geemail.com	Austin	Texas	3112771038156630797	959c7cdbeab6e745a1eb540fd7aa0574	JCB 15 digit	30.3573972754307064	-97.8251351180259121
41333	2020-07-31 06:48:50	2020-07-31	Nallely Schmeler	nallely.schmeler@geemail.com	San Jose	California	869903288375371596	0396d18e82949d5e1b01e35ef97f3882	Diners Club / Carte Blanche	37.3144508024033144	-121.819578635947408
41334	2020-07-31 06:54:51	2020-07-31	Julien Swift	julien.swift@geemail.com	Naperville	Illinois	4948193656683	3be4d1c37488d6c2fa667abbc4a6b8c3	JCB 16 digit	41.6732355866029849	-88.125700302317739
41335	2020-07-31 06:58:08	2020-07-31	Babe Marvin-Tremblay	babe.marvin.tremblay@woohoo.com	Houston	Texas	639090206368012	eb883ad3f7b782b8afd4d87c1e59e545	VISA 13 digit	29.8225246246516704	-95.439038284217574
41336	2020-07-31 07:00:34	2020-07-31	Rowena Bradtke	rowena.bradtke@geemail.com	Houston	Texas	3088443202568641887	0cee5fb4ba4ff82252ede36d8f9d798e	Voyager	29.785465164490418	-95.4067773427363477
41337	2020-07-31 07:11:49	2020-07-31	Rylan Lueilwitz	rylan.lueilwitz@geemail.com	San Diego	California	4095876666017	961cfabf009fd8f2ab09d2751a07b3fd	VISA 16 digit	32.8202681797623654	-117.225412217145788
41338	2020-07-31 07:17:16	2020-07-31	Dr. Leonel Funk	dr.leonel.funk@geemail.com	Philadelphia	Pennsylvania	869967474623169064	e97daf2d960a52016abaf1639d5ed38a	Discover	40.006886052755263	-75.0420427256628955
41339	2020-07-31 07:20:14	2020-07-31	Fatima Jacobi	fatima.jacobi@warmmail.com	New York	New York	3096578769509641165	fda0bbfd1859958898edc9710546f9fd	JCB 16 digit	40.7045327082499853	-73.947514330911261
41340	2020-07-31 07:23:56	2020-07-31	Deonta Carter	deonta.carter@geemail.com	Philadelphia	Pennsylvania	51265136701632111	3aac8a72df20723014383dbb19032784	JCB 16 digit	39.9813538003206261	-75.1403636339019982
41341	2020-07-31 07:23:57	2020-07-31	Miss Kelsi Rolfson	miss.kelsi.rolfson@geemail.com	Las Vegas	Nevada	501892932647826	8387293b03ecb24f08e53697c8736f51	VISA 13 digit	36.2736788945373121	-115.187178548027191
41342	2020-07-31 07:25:02	2020-07-31	Mrs. Armani Green	mrs.armani.green@geemail.com	West Covina	California	4162653686988	b749e988f3e5601e56542d49ec506260	Mastercard	34.0575940952744318	-117.94055312239341
41343	2020-07-31 07:27:30	2020-07-31	Sydney Senger	sydney.senger@warmmail.com	Phoenix	Arizona	4838796815771598	c8df3afd674fff2d17dabb466120897f	JCB 16 digit	33.666313408075645	-112.094892960640053
41344	2020-07-31 07:30:02	2020-07-31	Dr. Georgiana O'Hara DDS	dr.georgiana.o'hara.dds@geemail.com	Columbus	Ohio	676165034579550	a524a37682499469a06531d7bb5a99e4	Voyager	39.9391939559530442	-82.9575399651892553
41345	2020-07-31 07:34:20	2020-07-31	Joel Heller	joel.heller@geemail.com	San Diego	California	4276112848383	7349a55666cc789b2f72b8b04b4e495d	Discover	32.777914353932438	-117.089235809342938
41346	2020-07-31 07:43:29	2020-07-31	Mr. Burdette Gislason	mr.burdette.gislason@woohoo.com	San Diego	California	4336729510527	4b648626801d657566409a32d990f8c7	Diners Club / Carte Blanche	32.8751619726952171	-117.176334116412335
41347	2020-07-31 07:47:47	2020-07-31	Dr. Lakesha Nienow	dr.lakesha.nienow@geemail.com	Omaha	Nebraska	3528272053709056519	a5edccfe4eae5b43218a641dfd98e095	VISA 16 digit	41.2530182145681223	-96.0239117168005549
41348	2020-07-31 07:53:29	2020-07-31	Angelia Brown-Kuhlman	angelia.brown.kuhlman@geemail.com	Atlanta	Georgia	180000944434718994	d5a0e4276e6cb3fa6b8a48160bf81bea	Voyager	33.8495458077449385	-84.423220107662317
41349	2020-07-31 08:11:42	2020-07-31	Goebel Tremblay-Walsh	goebel.tremblay.walsh@geemail.com	Honolulu	Hawaii	180009622517114189	f99a5874fcaa8f4623576e2500d0799c	JCB 15 digit	21.3070004244085425	-157.91452180247046
41350	2020-07-31 08:15:10	2020-07-31	Desiree Upton MD	desiree.upton.md@woohoo.com	Lowell	Massachusetts	3096462178174813621	de84e7eff008c8ca52ba7abecf4e9bea	Mastercard	42.6587595386765912	-71.3386913175102393
41351	2020-07-31 08:19:44	2020-07-31	Cyril Schmeler-Herzog	cyril.schmeler.herzog@geemail.com	Clinton	Michigan	4444118039931674	44f2ee6a6fac4e467eb46effd08efe9f	Mastercard	42.6003571572780615	-82.9739185649510489
41352	2020-07-31 08:21:01	2020-07-31	Sarai Bayer PhD	sarai.bayer.phd@woohoo.com	New Orleans	Louisiana	869972943780941831	54a2b74678c41dd2426b2e55fbe42f7e	VISA 13 digit	30.1173675260987146	-89.8346370175741669
41353	2020-07-31 08:27:18	2020-07-31	Exa Buckridge	exa.buckridge@geemail.com	Glendale	California	639084556771339	82d6db0499650c01855b5500ee539e47	Discover	34.1569876448471064	-118.150588813227785
41354	2020-07-31 08:28:15	2020-07-31	Joretta Bins-Mayer	joretta.bins.mayer@geemail.com	Philadelphia	Pennsylvania	180009084662923551	4042e66995d75bad1914e6b1975466e8	VISA 16 digit	39.9177917836658622	-75.1267901626780628
41355	2020-07-31 08:32:46	2020-07-31	Lou Emmerich	lou.emmerich@geemail.com	Milwaukee	Wisconsin	6011568349088953596	881f467a33d457a05c0501e0eafd56ac	JCB 15 digit	42.9957913153890487	-88.0394975687477768
41356	2020-07-31 08:34:44	2020-07-31	French Bernier-Glover	french.bernier.glover@warmmail.com	Houston	Texas	52804625807878253	23679d5fc49f834cdbb9bd1c923d8882	VISA 16 digit	29.7666049453042447	-95.3214612661875833
41357	2020-07-31 08:41:54	2020-07-31	Kennard Jaskolski	kennard.jaskolski@warmmail.com	San Francisco	California	3714203292346743	80091657636064f4e4ad37f9923bfb8f	VISA 16 digit	37.7539285443364179	-122.454704450478388
41358	2020-07-31 08:44:01	2020-07-31	Jeraldine Toy	jeraldine.toy@geemail.com	Corpus Christi	Texas	3410086149065077	f8b1128adaecd2430b3207a631d2fa4e	American Express	27.7117234861414872	-97.1460985787041551
41359	2020-07-31 08:47:43	2020-07-31	Violeta Waelchi	violeta.waelchi@woohoo.com	Riverside	California	3088621336987084529	0e75a6c6bc73ce73d6779bfd423994a0	Discover	33.9553603331506224	-117.485146882568287
41360	2020-07-31 08:53:50	2020-07-31	Alferd Willms	alferd.willms@geemail.com	Columbus	Ohio	869923218258273599	9ada776592128c250008c1e60fdb2dcc	Maestro	40.0161193058405047	-83.0012231414441146
41361	2020-07-31 08:55:22	2020-07-31	Clarisa West	clarisa.west@geemail.com	Providence	Rhode Island	51399543894801065	85a3fcb749b353e05c675dad286617d8	VISA 16 digit	41.8513852769829313	-71.4458364355295998
41362	2020-07-31 09:08:54	2020-07-31	Dr. Festus Connelly	dr.festus.connelly@geemail.com	San Bernardino	California	3088600684743274982	22a71c0007207e936c3a52f567b825ab	JCB 16 digit	34.0430751627109913	-117.229071853660415
41363	2020-07-31 09:16:20	2020-07-31	Dr. Yoshio Johnston	dr.yoshio.johnston@warmmail.com	New York	New York	4897185751826491	c42ef7dae09a47c888ff020847e558ef	American Express	40.6643643168024695	-73.9043523100566091
41364	2020-07-31 09:26:30	2020-07-31	Winfield Auer	winfield.auer@warmmail.com	San Francisco	California	3037884128521838	15645700258438f25974aa0b22d49b40	American Express	37.7597387024048317	-122.44753477498783
41365	2020-07-31 09:35:08	2020-07-31	Kent Moore	kent.moore@geemail.com	Eugene	Oregon	869914253608875042	94f7fb5a17723398130f2e41a428d4ae	American Express	44.1176646363183877	-123.118173299169925
41366	2020-07-31 09:41:10	2020-07-31	Thekla Jacobi MD	thekla.jacobi.md@geemail.com	West Valley City	Utah	4547668139386316	b708719e0c2508bd6ac3b4b57202bef1	Voyager	40.703613006625325	-111.976967130436748
41367	2020-07-31 09:41:18	2020-07-31	Albertine Rau	albertine.rau@warmmail.com	Spokane	Washington	6011943738062286518	9e5422f43bcc0fa0149d7c4dc463742a	VISA 13 digit	47.5811223442438944	-117.398671249569588
41368	2020-07-31 09:54:16	2020-07-31	Marietta Wunsch PhD	marietta.wunsch.phd@geemail.com	St. Louis	Missouri	3450507434420504	16bdf6e6f7feefd5604df4930c58f74e	Voyager	38.6932577275361851	-90.2335294486492927
41369	2020-07-31 10:04:27	2020-07-31	Goldie Wilkinson	goldie.wilkinson@geemail.com	Berkeley	California	502061367435411	ea301486597a2cba2ecafcf160dd3212	Diners Club / Carte Blanche	37.829119987711664	-122.238057041106302
41370	2020-07-31 10:06:54	2020-07-31	Anibal Leffler	anibal.leffler@geemail.com	Brownsville	Texas	3112651378010867606	131a2e2ee52f1b0ee683f2ce4ca249b4	Discover	25.971963404592497	-97.5406633025687171
41371	2020-07-31 10:09:40	2020-07-31	Darien Bashirian	darien.bashirian@woohoo.com	Berkeley	California	180026085603281123	ef4e5a48c55974f75fc49e2a90394538	JCB 15 digit	37.8699545618785365	-122.285469824105462
41372	2020-07-31 10:11:27	2020-07-31	Jaqueline Mante	jaqueline.mante@woohoo.com	Allentown	Pennsylvania	4911288012444989	1eb920db239786af64656fdb4ae941f6	Voyager	40.5303489395197474	-75.5468093155898117
41373	2020-07-31 10:12:52	2020-07-31	Isabel Kutch	isabel.kutch@woohoo.com	San Francisco	California	210077757387431995	dea03eccb7d909a12d6d47c1f753be70	JCB 16 digit	37.7829940823591528	-122.446758527370022
41374	2020-07-31 10:27:53	2020-07-31	Odile Schneider-Huel	odile.schneider.huel@geemail.com	New York	New York	180038630308048263	419c1e36649d41ac0006e937d27da22a	American Express	40.6416973993871338	-73.8610347345367018
41375	2020-07-31 10:32:39	2020-07-31	Reno Cummerata	reno.cummerata@woohoo.com	Clearwater	Florida	3059577879936480	a58cb4614be8a8ace2f8cb415f7dfa4d	VISA 16 digit	27.8868097332898515	-82.6963095312271292
41376	2020-07-31 10:32:41	2020-07-31	Bailee Reilly	bailee.reilly@warmmail.com	Cambridge	Massachusetts	4015592488676239	9603844da22814553086b3fae2e852a7	VISA 16 digit	42.389381545199079	-71.0731741947203943
41377	2020-07-31 10:36:30	2020-07-31	Ilda McKenzie	ilda.mckenzie@geemail.com	Modesto	California	3088568917846937646	a5100032062e67086bf9929f024d0b6e	JCB 16 digit	37.7234401779714972	-120.933206968262795
41378	2020-07-31 10:36:36	2020-07-31	Mychal O'Reilly	mychal.o'reilly@geemail.com	Akron	Ohio	4098139233330371	c6bcc348f6bc9652a6af2c8f684b1998	Maestro	41.0229379530828453	-81.5648723962098359
41379	2020-07-31 10:39:46	2020-07-31	Ean Simonis	ean.simonis@geemail.com	San Francisco	California	6011228909290986643	bee1d3d45239bd5d265609cac00f9616	Discover	37.7514532932240527	-122.462173799381659
41380	2020-07-31 10:47:28	2020-07-31	Dr. Douglas Breitenberg	dr.douglas.breitenberg@geemail.com	San Francisco	California	51357201823344505	f19a8b81e44005bce12263ca53c0d5b3	JCB 16 digit	37.7997069569768271	-122.409481779491998
41381	2020-07-31 10:54:33	2020-07-31	Marland D'Amore-Smith	marland.d'amore.smith@geemail.com	Charlotte	North Carolina	4535979484324008	1cb63ce748686425788a137068452bd0	VISA 16 digit	35.2479162433903639	-80.8514305890016232
41382	2020-07-31 11:05:28	2020-07-31	Dr. Pasquale Hartmann PhD	dr.pasquale.hartmann.phd@geemail.com	Chicago	Illinois	4611546066998	d517bea4a82866dc146e1be2c623ea24	Maestro	41.8819398615345406	-87.7566969796113625
41383	2020-07-31 11:07:15	2020-07-31	Miss Alesha Bauch MD	miss.alesha.bauch.md@geemail.com	Houston	Texas	3001049842565976	f1dd4fdf4048c47fe39c172e933dc7de	Discover	29.8110270003866411	-95.4611329216524922
41384	2020-07-31 11:09:17	2020-07-31	Algie Lebsack IV	algie.lebsack.iv@geemail.com	Boston	Massachusetts	3478346290294358	24b3c4c28c5bc5c17ce9889a9ae3923a	Mastercard	42.3338665476702189	-71.0027880387332289
41385	2020-07-31 11:14:53	2020-07-31	Mr. Santino Sawayn III	mr.santino.sawayn.iii@geemail.com	West Jordan	Utah	4251635684565	c8593a85a11d1e65215097db6b9a5a73	Maestro	40.5510918846610977	-111.961162531384446
41386	2020-07-31 11:19:57	2020-07-31	Masako Ankunding	masako.ankunding@warmmail.com	San Francisco	California	4287299108826118	17ac2141d3b5b59a7a5a8d286d0c0416	VISA 16 digit	37.8183158626222138	-122.403562151020424
41387	2020-07-31 11:29:15	2020-07-31	Mr. Bedford Yundt	mr.bedford.yundt@geemail.com	North Las Vegas	Nevada	51671215319139137	f9d60d5c3c51b14dbd428ec28cc09b8c	Discover	36.2611294010810568	-115.014009409699227
41388	2020-07-31 11:36:45	2020-07-31	Fabiola Mueller DDS	fabiola.mueller.dds@geemail.com	Arvada	Colorado	4283279477295	ff1a1c6df5639261adfe76c0caafbcdb	VISA 16 digit	39.8929918122187246	-105.128103279552604
41389	2020-07-31 11:37:01	2020-07-31	Estie Nicolas	estie.nicolas@geemail.com	Dallas	Texas	4811968678650000	d33f1b06b0262540df2a12f826026716	JCB 16 digit	32.8702015234429439	-96.83451301022059
41390	2020-07-31 11:37:33	2020-07-31	Jannette Zieme-DuBuque	jannette.zieme.dubuque@warmmail.com	Mobile	Alabama	6011479984769689065	704dc774f1d77da276ba5c0a17806986	Maestro	30.7644625180043256	-88.1776959259666455
41391	2020-07-31 11:40:29	2020-07-31	Ms. Gail Mraz DDS	ms.gail.mraz.dds@geemail.com	Phoenix	Arizona	869925496897281474	62d9d6599a10052d69a8a11039c36247	Discover	33.6412445651765921	-112.165953729760275
41392	2020-07-31 11:40:42	2020-07-31	Kennedi Armstrong	kennedi.armstrong@warmmail.com	New York	New York	4332120910705	6b3605976eb8c082c2a71ed59ebd640a	Voyager	40.6511526884734593	-74.0260172442428797
41393	2020-07-31 11:48:10	2020-07-31	Infant Boehm	infant.boehm@woohoo.com	Winston–Salem	North Carolina	3057949586310659	79cc6c69315bc3e872ae31fd838c67cf	JCB 16 digit	36.19802303144224	-80.2734928057193713
41394	2020-07-31 12:00:45	2020-07-31	Dr. Celesta McKenzie PhD	dr.celesta.mckenzie.phd@geemail.com	Gilbert	Arizona	4441361500362	5cab7bf3e1b500c9198dbdf6f9f3637c	Maestro	33.3764751909647117	-111.805746710081024
41395	2020-07-31 12:03:53	2020-07-31	Harland Wolff I	harland.wolff.i@geemail.com	Glendale	California	4240356911331	bf49e161a1f87a130a1b8225b52c6051	American Express	34.0819681528244161	-118.17233836635873
41396	2020-07-31 12:10:03	2020-07-31	Giuseppe O'Hara	giuseppe.o'hara@woohoo.com	San Francisco	California	869969744948153193	47ac3323805cdbfaa70c020f38d24954	Mastercard	37.7608474780758101	-122.414114185668552
41397	2020-07-31 12:25:16	2020-07-31	Zena Predovic	zena.predovic@geemail.com	San Francisco	California	55415549844220207	497757dc14d37cb13f345b7ea145d6ed	VISA 13 digit	37.7691167262898944	-122.433619038653049
41398	2020-07-31 12:49:56	2020-07-31	Luisa Nader-King	luisa.nader.king@geemail.com	San Francisco	California	3096023068215790650	010af9889c8a7855e8932478c46722d0	JCB 15 digit	37.7417457246846908	-122.430921383584021
41399	2020-07-31 12:50:19	2020-07-31	Dr. Sena Heaney	dr.sena.heaney@geemail.com	Salt Lake City	Utah	630417070535095	dd4704552863c8862c3ddfcc6ad72d43	VISA 16 digit	40.8685765603702507	-111.871244862996036
41400	2020-07-31 12:55:09	2020-07-31	Tierra Turner	tierra.turner@geemail.com	New York	New York	4184759925010497	69d2e9dbab19b833edc0c85a2f06f4a9	American Express	40.5664542859177999	-73.9802052551776086
41401	2020-07-31 12:57:00	2020-07-31	Elmer Koss	elmer.koss@geemail.com	Thousand Oaks	California	4280535532400	75485df0581f390ff27cf364ebd27f03	Voyager	34.1854152484603233	-118.866704797782745
41402	2020-07-31 13:00:36	2020-07-31	Carolann Gulgowski-Kuhlman	carolann.gulgowski.kuhlman@geemail.com	San Francisco	California	55551947168121627	67d51f8cc2add92c466770c453e2905b	American Express	37.810184420371364	-122.458066461533818
41403	2020-07-31 13:01:35	2020-07-31	Ms. Dona Weber	ms.dona.weber@geemail.com	Irving	Texas	4183025805981	a699e787accef0126855375e43b84432	American Express	32.8952140092335625	-97.0250324014853618
41404	2020-07-31 13:07:11	2020-07-31	Jayce Schumm	jayce.schumm@geemail.com	Boise	Idaho	869956211051662670	dff28e02bb37fb0659b2f8768bd5e9fe	VISA 13 digit	43.5889758088298152	-116.237371050259853
41405	2020-07-31 13:19:05	2020-07-31	Murphy McLaughlin	murphy.mclaughlin@geemail.com	Durham	North Carolina	55688991211156079	3b21127363647a1d435d2997143261a5	JCB 16 digit	35.964307090152424	-78.9914128819383734
41406	2020-07-31 13:19:56	2020-07-31	Infant Romaguera DVM	infant.romaguera.dvm@woohoo.com	Billings	Montana	6011530124900136901	81526301a4e59dec77e94c79993b90de	JCB 15 digit	45.7755625530369556	-108.485143085119873
41407	2020-07-31 13:29:45	2020-07-31	Mikaila DuBuque	mikaila.dubuque@geemail.com	Los Angeles	California	4815483423167	1864776678e8b20b7ecc8538a775901e	Maestro	33.950923195886979	-118.501772438547761
41408	2020-07-31 13:33:20	2020-07-31	Bea Nienow	bea.nienow@geemail.com	New York	New York	4304920092256868	434ddad614d9c7a6f4a36ed9739435e9	Discover	40.6512422222401923	-73.9755080980144442
41409	2020-07-31 13:34:37	2020-07-31	Hallie Friesen	hallie.friesen@geemail.com	Las Vegas	Nevada	53349778367075976	8a8d1ba83f3781989b964cfe666a3ba0	Discover	36.3026808869194255	-115.17711879436149
41410	2020-07-31 13:38:43	2020-07-31	Mr. Dimitrios Block	mr.dimitrios.block@geemail.com	Shreveport	Louisiana	3528559493671886747	60881f67f3014ce36fb21e0b2fcbff93	Diners Club / Carte Blanche	32.5537844125885556	-93.8460441382814139
41411	2020-07-31 13:41:44	2020-07-31	Levar Kuhn-Boyer	levar.kuhn.boyer@geemail.com	New York	New York	4667063908058649	07162d53ef0b0eddc9757e478f465eec	VISA 16 digit	40.6555501081272936	-73.9536828057736102
41412	2020-07-31 13:45:36	2020-07-31	Tameka Mann	tameka.mann@geemail.com	San Francisco	California	53100517910429077	8cae15eaee57aeee27bf71fc775c42dd	Maestro	37.8028332018454591	-122.430965785190907
41413	2020-07-31 14:03:18	2020-07-31	Dr. Leslie Bernier	dr.leslie.bernier@geemail.com	McAllen	Texas	4783660863781203	8758d026e4054000bc3c2eedc52c5922	JCB 16 digit	26.3019493580169978	-98.1853144910965057
41414	2020-07-31 14:11:07	2020-07-31	Dr. Gregorio Mohr	dr.gregorio.mohr@geemail.com	Chicago	Illinois	3088372432847276438	44c82ded33d3dc30dda11464d32c9e69	JCB 16 digit	41.8307615334004197	-87.6335174821346925
41415	2020-07-31 14:12:55	2020-07-31	Kegan Ferry	kegan.ferry@geemail.com	Nashville	Tennessee	869900800183427601	c435ea48f2a6263408ff8d8546a8732f	VISA 16 digit	36.2435505015898443	-86.7862833526357917
41416	2020-07-31 14:15:51	2020-07-31	Otha Stroman	otha.stroman@geemail.com	Alexandria	Virginia	3158844171709063449	d3ce66612a33440413c8ed5e85b661b0	Discover	38.8997075439546194	-77.0681347964316643
41417	2020-07-31 14:22:20	2020-07-31	Broderick Zulauf	broderick.zulauf@warmmail.com	Waterbury	Connecticut	4950306608572542	0c0c320ff670a1d77dd215cd66b9e523	Diners Club / Carte Blanche	41.5437616672869794	-73.1175924260083576
41418	2020-07-31 14:28:59	2020-07-31	Dr. Dana Parisian	dr.dana.parisian@woohoo.com	Kent	Washington	3718870767713189	60384af13e0fb2da242f164d61918621	JCB 16 digit	47.3698280019797338	-122.210606553698696
41419	2020-07-31 14:42:06	2020-07-31	Grant O'Kon	grant.o'kon@warmmail.com	Oakland	California	3112096466220303257	c1f060855dab990c8aec650bcf9ede20	VISA 16 digit	37.8067763922745641	-122.315409394754695
41420	2020-07-31 14:57:09	2020-07-31	Dashawn Gerlach PhD	dashawn.gerlach.phd@warmmail.com	Vacaville	California	3096579189082105802	722cf57aa97f297cb80bac1e7e1dbc5e	VISA 16 digit	38.3523124248847367	-121.876290236587835
41421	2020-07-31 15:10:09	2020-07-31	Salomon Hoppe	salomon.hoppe@woohoo.com	West Valley City	Utah	869999201520617123	01efabed0b6b984405f9babfc1381872	Voyager	40.5923167011924093	-112.046658861099928
41422	2020-07-31 15:10:16	2020-07-31	Jetta Bauch	jetta.bauch@geemail.com	San Francisco	California	639064052387327	e651d3502d710d663ce73fb5177e317b	Diners Club / Carte Blanche	37.7681258208791064	-122.45842221615267
41423	2020-07-31 15:10:27	2020-07-31	Branden Mayert	branden.mayert@geemail.com	Joliet	Illinois	3112646931687224515	391506d0a948b035b3073cb8f5e63763	Mastercard	41.4410658859506214	-88.1162893646966552
41424	2020-07-31 15:10:27	2020-07-31	Ms. Raelynn Rosenbaum	ms.raelynn.rosenbaum@geemail.com	Houston	Texas	3096856534518473957	fd571bafab003b1e772f73b00fbc8cb6	VISA 16 digit	29.7455644841849818	-95.4411226030919693
41425	2020-07-31 15:22:40	2020-07-31	Christian Streich	christian.streich@geemail.com	Fort Worth	Texas	4361546562086616	c2e2091251cc45ccb19c9c64508625d0	JCB 16 digit	32.8549146836679427	-97.328631622792031
41426	2020-07-31 15:25:36	2020-07-31	Mrs. Alondra Paucek	mrs.alondra.paucek@geemail.com	Simi Valley	California	4435742891830517	c927c8b096abb47f75ea1a2d830bf15e	VISA 13 digit	34.2223442440159644	-118.772571664409725
41427	2020-07-31 15:27:57	2020-07-31	Kyle VonRueden	kyle.vonrueden@geemail.com	Austin	Texas	3001722217233855	fbbe2a108fdb6f25bae25b4941945c68	Voyager	30.3864883005745696	-97.7075217152252833
41428	2020-07-31 15:34:52	2020-07-31	Merrilee Reichel	merrilee.reichel@geemail.com	Gainesville	Florida	676378378551960	aa62f9fc87758122e77c31afa9e61663	Diners Club / Carte Blanche	29.6096085284661505	-82.3818555072289058
41429	2020-07-31 15:42:58	2020-07-31	Billy Waters PhD	billy.waters.phd@woohoo.com	New York	New York	4987291362893	27fc48a9d059eff0d9555dc974ad3b2d	Maestro	40.6667033757306626	-73.913810696628687
41430	2020-07-31 15:45:55	2020-07-31	Vikki Connelly	vikki.connelly@geemail.com	San Antonio	Texas	4570650898070885	74485a3e9fdf9de1216ff9cc53c05342	Diners Club / Carte Blanche	29.5299910455081616	-98.4841758753940439
41431	2020-07-31 15:56:38	2020-07-31	Pierre Jacobson	pierre.jacobson@geemail.com	Memphis	Tennessee	3006443440969976	c87bc280e712f78665d20b73f4397f6a	VISA 13 digit	35.1489874382104759	-90.0608882454015287
41432	2020-07-31 15:57:04	2020-07-31	Chip Gorczany	chip.gorczany@woohoo.com	Tampa	Florida	210097438571715792	b0de627806565147322cc5c8891f8897	Mastercard	27.9492501154191793	-82.4999952324412646
41433	2020-07-31 16:11:12	2020-07-31	Codie Lockman	codie.lockman@woohoo.com	Honolulu	Hawaii	51799666801679013	b1bb9a4795fca02094435b44a14f3333	Discover	21.2293727382767941	-157.7822687776968
41434	2020-07-31 16:12:34	2020-07-31	Addisyn Brekke	addisyn.brekke@geemail.com	Manchester	New Hampshire	3337096222019269815	987c58d78d7864abc5bc460184612566	Discover	42.9169499542169319	-71.4953087072711497
41435	2020-07-31 16:16:07	2020-07-31	Carlisle Schneider	carlisle.schneider@warmmail.com	Louisville	Kentucky	869996736171024775	7c9b5addf34a5be62f13cdf9e5fa874b	JCB 16 digit	38.2539920180473487	-85.6290241542808701
41436	2020-07-31 16:17:12	2020-07-31	Whitney Lubowitz-Sauer	whitney.lubowitz.sauer@geemail.com	Houston	Texas	4223353037623752	f5fb0a5cbebce8d7b3c7b834ea2a2d2f	Diners Club / Carte Blanche	29.8564667018208638	-95.366793005449324
41437	2020-07-31 16:19:02	2020-07-31	Lalla Ziemann	lalla.ziemann@geemail.com	New York	New York	4552408314686665	94fe36d07312632d54b1f9aa619cac23	JCB 16 digit	40.6636843119971445	-73.8607115878619283
41438	2020-07-31 16:20:41	2020-07-31	Yadira Reilly	yadira.reilly@warmmail.com	Fresno	California	52678699514021948	5a0dcbd518369f9f73ada570461d2d55	Mastercard	36.8005278924819095	-119.828483631332972
41439	2020-07-31 16:27:52	2020-07-31	Brylee Mueller	brylee.mueller@geemail.com	San Francisco	California	4623752278101178	2df660ab77246035a5383eaa481fd30b	Maestro	37.7800480480751304	-122.444534332380172
41440	2020-07-31 16:35:26	2020-07-31	Kellee Langosh PhD	kellee.langosh.phd@geemail.com	Salem	Oregon	4215095374951631	8ea4911c30befec455bcf3a1faacc31c	VISA 16 digit	44.9849886697985184	-123.06225229908415
41441	2020-07-31 16:38:51	2020-07-31	Dr. Cesar Cummings Sr.	dr.cesar.cummings.sr.@woohoo.com	West Covina	California	3056901130879896	537e500b87959d7a8aee0127e59fac99	VISA 16 digit	34.1139680008977635	-117.957213645575195
41442	2020-07-31 16:44:30	2020-07-31	Dr. Teddy Schmeler DVM	dr.teddy.schmeler.dvm@geemail.com	Stockton	California	54833064025427393	a6de9b4145af0a7dad7b9026b0cbd595	JCB 15 digit	38.0484486651338685	-121.217917535322897
41443	2020-07-31 16:52:35	2020-07-31	Jacob Kessler	jacob.kessler@woohoo.com	Lexington	Kentucky	869926680876395202	ec27c03bde1e2dbaf03c7c3e020df74c	VISA 16 digit	37.9954089219558995	-84.4865931388821423
41444	2020-07-31 17:13:29	2020-07-31	Luis Jacobs	luis.jacobs@geemail.com	Manchester	New Hampshire	3029353371055512	8c1eacab0db6fde2bc37c272664a79ae	JCB 16 digit	43.0458662193339379	-71.4711321274642017
41445	2020-07-31 17:17:24	2020-07-31	Luverne Schroeder	luverne.schroeder@geemail.com	San Francisco	California	589356093723478	4bdb86049cbc10ed53b7db5d434312b1	JCB 16 digit	37.7574424376874731	-122.414501003565334
41446	2020-07-31 17:20:38	2020-07-31	Shana Deckow DDS	shana.deckow.dds@woohoo.com	Corona	California	210049250465318396	a55eb61c07fbd86531cd7fbb2e2b1cf5	Diners Club / Carte Blanche	33.8282352783139828	-117.481268773108724
41447	2020-07-31 17:25:50	2020-07-31	Dereck Langworth	dereck.langworth@warmmail.com	Overland Park	Kansas	210027197467747492	a5591512f0610967fa71fe72111483bb	JCB 16 digit	38.8173113448880613	-94.7102522063575663
41448	2020-07-31 17:26:40	2020-07-31	Rex Medhurst	rex.medhurst@warmmail.com	Winston–Salem	North Carolina	3112994109495758069	48f43579f35f128fd5e123c5a405e379	Discover	36.1045425953108818	-80.2976114908363598
41449	2020-07-31 18:35:14	2020-07-31	Austen Bernhard II	austen.bernhard.ii@geemail.com	Green Bay	Wisconsin	3002517863193364	e19d99d25db900b13f7c46b9587b64fb	Mastercard	44.451837798726558	-87.9219480450086337
41450	2020-07-31 18:43:16	2020-07-31	Ola Schmeler	ola.schmeler@geemail.com	San Francisco	California	869930201409226147	965b99d88cd4fc8147630598a2a8fd6d	Diners Club / Carte Blanche	37.7674634463320231	-122.435977225123622
41451	2020-07-31 18:49:37	2020-07-31	Crockett Prohaska-McDermott	crockett.prohaska.mcdermott@warmmail.com	Honolulu	Hawaii	6011605389218626352	61de9076f34da53ea4b6e4c7936ab120	Diners Club / Carte Blanche	21.3943784473214293	-157.801368666228285
41452	2020-07-31 18:59:56	2020-07-31	Odis Leffler	odis.leffler@warmmail.com	Tucson	Arizona	4865961952887617	100b82fe9e498f24fbe914f9734bff11	JCB 16 digit	32.2462174508761663	-110.945872103259333
41453	2020-07-31 19:00:04	2020-07-31	Hilbert Kris	hilbert.kris@geemail.com	Waco	Texas	6011651308154772080	d125cce3ac96aeac9cb0baddfcd065e9	Voyager	31.5194750254251055	-97.2502718253657292
41454	2020-07-31 19:15:41	2020-07-31	Fenton Jones PhD	fenton.jones.phd@geemail.com	Shreveport	Louisiana	3528171606817422600	92c18918d3b8499ac5a304d774b03b68	Diners Club / Carte Blanche	32.4910806243546304	-93.8278404524762095
41455	2020-07-31 19:16:33	2020-07-31	Jamar Heller	jamar.heller@geemail.com	San Antonio	Texas	3528033862363066816	0ec5db7c59907446a0a1dd9e88b5f998	VISA 16 digit	29.494176353381576	-98.5239745996262855
41456	2020-07-31 19:21:23	2020-07-31	Albin Streich	albin.streich@warmmail.com	Albuquerque	New Mexico	3088792657167050409	0d58b96caac93bdbabd8a677fa26431b	Diners Club / Carte Blanche	35.1073136593349275	-106.551525919844963
41457	2020-07-31 19:24:23	2020-07-31	Roni Braun	roni.braun@woohoo.com	Houston	Texas	869954269637163342	f75b462ab18c1f94e371c253cb7caf99	JCB 16 digit	29.7590126969464137	-95.424726905535536
41458	2020-07-31 19:34:01	2020-07-31	Ms. Arlyne Smith DDS	ms.arlyne.smith.dds@geemail.com	Indianapolis	Indiana	210037299003901266	291994c44c785297397c43308bd3f6b7	JCB 16 digit	39.7860171860091398	-86.2287078028280263
41459	2020-07-31 19:35:06	2020-07-31	Orvel Schaefer	orvel.schaefer@geemail.com	Tempe	Arizona	3014609221910742	64096817e513c0ea04ebcf3d348ca1aa	JCB 16 digit	33.3881683295980096	-111.923493910909812
41460	2020-07-31 19:35:18	2020-07-31	Hakeem White-Gibson	hakeem.white.gibson@geemail.com	New York	New York	6011092531596124803	af36add9825e7fbdd053aca74567e73d	American Express	40.5701088404040746	-73.9940844152949779
41461	2020-07-31 19:43:12	2020-07-31	Marcello Goodwin	marcello.goodwin@geemail.com	Bakersfield	California	54318574134987255	19bc1f127b27b3a0badff5f7c8057421	Maestro	35.3045696678280834	-119.007076213396331
41462	2020-07-31 19:48:38	2020-07-31	Lashawn Buckridge I	lashawn.buckridge.i@geemail.com	Fayetteville	North Carolina	501814230742992	14ed21d9838668ab674499970b316deb	VISA 16 digit	35.1699219720225784	-78.9958192820791112
41463	2020-07-31 19:52:20	2020-07-31	Iliana Abernathy	iliana.abernathy@woohoo.com	Oakland	California	3096527711494036227	8826b307911367376c1bfbc758206f59	Voyager	37.7878703531433118	-122.267726803890952
41464	2020-07-31 19:53:23	2020-07-31	Dr. Rosario Gaylord I	dr.rosario.gaylord.i@warmmail.com	Little Rock	Arkansas	6011736925446243304	6cc28ea14f0d35d359111bcb0c97a3f6	JCB 16 digit	34.8144503984410321	-92.2962176353078263
41465	2020-07-31 19:59:24	2020-07-31	Lorna Lindgren PhD	lorna.lindgren.phd@geemail.com	Milwaukee	Wisconsin	3437325779224078	afb88018786a2d53027bfa7ad272d0b6	VISA 16 digit	43.1395143864296386	-87.9342835843198003
41466	2020-07-31 19:59:35	2020-07-31	Dr. Zora Kling	dr.zora.kling@geemail.com	San Francisco	California	210031863164721593	0aec7431916262f7b5729c59c4a1b73b	JCB 15 digit	37.7826727107259828	-122.420495908260634
41467	2020-07-31 20:03:51	2020-07-31	Idamae Torphy DVM	idamae.torphy.dvm@warmmail.com	Amarillo	Texas	4233940656584501	deeab16b3be1a283495149768d6fd1be	VISA 16 digit	35.1691462363746012	-101.739572785501181
41468	2020-07-31 20:12:06	2020-07-31	Pinkey Walker	pinkey.walker@geemail.com	Chicago	Illinois	51380724560567187	f150f5ee184dcf5b53b5d84afcf2abaa	Mastercard	41.9051949704367672	-87.7580928640004174
41469	2020-07-31 20:18:15	2020-07-31	Genie Wintheiser	genie.wintheiser@warmmail.com	Wichita	Kansas	4472584058112428	33ca6d875eb2dbb173b209a52dcd90fd	Mastercard	37.7591488772880268	-97.3548716424234186
41470	2020-07-31 20:32:57	2020-07-31	Mikaila Kreiger	mikaila.kreiger@geemail.com	San Francisco	California	6011050896287081376	bfc6cfc0ce12d353d4d77f1a9c12a147	Discover	37.76916334513799	-122.37927414511428
41471	2020-07-31 20:33:02	2020-07-31	Santina Douglas	santina.douglas@geemail.com	Indianapolis	Indiana	3437961010407716	3608d087ffcce39691c72073ae1e3626	JCB 15 digit	39.7266051676131795	-86.1979095654763228
41472	2020-07-31 20:40:53	2020-07-31	Dr. Colette Feest DDS	dr.colette.feest.dds@geemail.com	New York	New York	869912832740349628	df2e6abf897a17cd0607887c3582f900	Mastercard	40.5894622849989659	-73.908077934839568
41473	2020-07-31 20:43:55	2020-07-31	Rayfield Cruickshank	rayfield.cruickshank@geemail.com	Phoenix	Arizona	3053535302665254	04114300176b7ec19db4db036d3f7666	Mastercard	33.6599066885586851	-112.115662991946948
41474	2020-07-31 20:53:31	2020-07-31	Oneta Wiza	oneta.wiza@geemail.com	San Antonio	Texas	4456043017686816	9df296b62f518f67f35ce2fe6646a44a	American Express	29.4551186395879832	-98.5836550437215635
41475	2020-07-31 20:54:08	2020-07-31	Woodroe Schaefer	woodroe.schaefer@geemail.com	Gilbert	Arizona	3528020725415873940	2ce95207e6c64b8adf0ee5393e8c12e0	Voyager	33.3436052335772644	-111.837750177657597
41476	2020-07-31 20:58:37	2020-07-31	Dr. Vernetta Upton	dr.vernetta.upton@geemail.com	Mesquite	Texas	4558714054191	909c377eabd4cfcfb17d77a3bbb2ee04	Mastercard	32.7710158041022765	-96.5926059141486917
41477	2020-07-31 21:04:31	2020-07-31	Kadin Monahan	kadin.monahan@geemail.com	Los Angeles	California	3047585326640318	dfc505dd76ffc2d90c032bc0cf31729e	Diners Club / Carte Blanche	33.9626488591875884	-118.436088265384726
41478	2020-07-31 21:14:29	2020-07-31	Blaise Anderson	blaise.anderson@geemail.com	Baton Rouge	Louisiana	502062520230327	b51366372224c9d1b569ea74d0e70b08	Maestro	30.4521694933276628	-91.174083293566099
41479	2020-07-31 21:14:50	2020-07-31	Shirley Littel	shirley.littel@geemail.com	Houston	Texas	4140554624597339	4e15d8dc7e1c46fc80d68ccfded5225e	JCB 16 digit	29.7672940831709667	-95.374362899597358
41480	2020-07-31 21:23:27	2020-07-31	Waymon Sauer	waymon.sauer@geemail.com	Charleston	South Carolina	51604458425906443	2edca0266e39ecbb2922163e38fbd18e	Mastercard	32.7990328086070733	-79.8998202887978408
41481	2020-07-31 21:28:50	2020-07-31	Shatara Rolfson	shatara.rolfson@warmmail.com	Minneapolis	Minnesota	3112788568969412471	6c7e431717ac93ee513c4e5302e5e23d	Voyager	45.0118817170236198	-93.2346711807224864
41482	2020-07-31 21:30:41	2020-07-31	Marry Reichel	marry.reichel@geemail.com	Minneapolis	Minnesota	869914583500969349	77d6098d8195396988ede184314e0c39	JCB 15 digit	44.8714632682122243	-93.2020039389647508
41483	2020-07-31 21:37:45	2020-07-31	Warner D'Amore DVM	warner.d'amore.dvm@woohoo.com	Santa Clarita	California	4396335060403799	422e443e99a0f1ca06c11b7ea602e32f	VISA 16 digit	34.4017885615788401	-118.577433671579513
41484	2020-07-31 21:47:52	2020-07-31	Kiefer Ritchie	kiefer.ritchie@geemail.com	San Francisco	California	6011646170880722211	52bc335308fb5d85adf7a4e04fe7769c	Voyager	37.7893431963615782	-122.400048985253349
41485	2020-07-31 21:52:10	2020-07-31	Tabatha Wolff	tabatha.wolff@geemail.com	Costa Mesa	California	55741229043380467	2b33d064492b98885de1f8ecae0faddc	VISA 13 digit	33.5882120678681915	-117.842625449304663
41486	2020-07-31 21:59:19	2020-07-31	Luc Ebert	luc.ebert@warmmail.com	Port St. Lucie	Florida	180036500789260343	c4e42b13a43a2d4add076f1213c17ce3	Mastercard	27.3706292341131707	-80.4871220334984372
41487	2020-07-31 21:59:28	2020-07-31	Raven Bartell	raven.bartell@geemail.com	Thornton	Colorado	6011526765057108360	5e7e652a2ff4fabf46f52a0fd4098ecc	Discover	39.8950945298984649	-105.017795322898039
41488	2020-07-31 22:07:54	2020-07-31	Larissa Keebler-Streich	larissa.keebler.streich@geemail.com	Lakewood	Colorado	210050189296778863	3af724a55c1a5ea936fd20400e4fcecb	Voyager	39.7368219541326155	-105.110798336800556
41489	2020-07-31 22:15:22	2020-07-31	Jaylee Veum	jaylee.veum@geemail.com	Berkeley	California	210079537725676198	974d0538eec9b06c16e98f6f94bb2813	Mastercard	37.8791242767472269	-122.253882963614345
41490	2020-07-31 22:17:15	2020-07-31	Miss Sarita Littel	miss.sarita.littel@geemail.com	Waterbury	Connecticut	3025628433262998	72c270be29dfa4b02ed15b12e34143ed	VISA 16 digit	41.4606365029737347	-73.1037710799284213
41491	2020-07-31 22:20:45	2020-07-31	Kareen Bergnaum	kareen.bergnaum@geemail.com	San Francisco	California	3088774870309312015	b6ffbcf527a6868bdf55a317b95aecdc	Mastercard	37.7668257967270478	-122.431106406158477
41492	2020-07-31 22:23:52	2020-07-31	Miss Babette Vandervort	miss.babette.vandervort@woohoo.com	New York	New York	501892526380529	a6bf5d529151fc94b333712e3c8171fc	Diners Club / Carte Blanche	40.7067248510420328	-73.8410349626921061
41493	2020-07-31 22:33:37	2020-07-31	Paulette Metz	paulette.metz@geemail.com	Joliet	Illinois	3409283151903815	cb108a1bf2d06ebaccc3f9c07fa4d17a	American Express	41.6033268899515249	-88.1104360391490076
41494	2020-07-31 22:45:25	2020-07-31	Lora Cremin III	lora.cremin.iii@warmmail.com	Oakland	California	503845094451858	7b1c464c2a54b742a2ab841beaa836c8	American Express	37.8155798926369116	-122.248182839489303
41495	2020-07-31 22:46:29	2020-07-31	Rolando Pouros-Larson	rolando.pouros.larson@geemail.com	San Diego	California	4703605957785	0c1c14fc70dac7ef782b3dfb7dad86a8	VISA 16 digit	32.8467453343395164	-117.226428157314658
41496	2020-07-31 22:53:29	2020-07-31	Greyson Shanahan	greyson.shanahan@geemail.com	Milwaukee	Wisconsin	3034595781586495	90f475c08c49f9f3381a594b3e79cc2c	Diners Club / Carte Blanche	43.0157321206379635	-88.0042619504135075
41497	2020-07-31 22:56:43	2020-07-31	Hoover Robel-Little	hoover.robel.little@geemail.com	Yonkers	New York	3047659249756103	8a27664d72287d6e12102d82c509ebb9	JCB 16 digit	40.9162513175249103	-73.7902715615812781
41498	2020-07-31 23:04:36	2020-07-31	Burley Frami	burley.frami@warmmail.com	Santa Ana	California	4580016051568	fa10fded1c1dca458a9d8696b5c833ee	JCB 16 digit	33.7049079461593166	-117.86938029289432
41499	2020-07-31 23:05:56	2020-07-31	Tillie Anderson	tillie.anderson@warmmail.com	Charlotte	North Carolina	4895904261226592	5dbbe303a7ed3c32936a604d649a4302	Maestro	35.1322300175458153	-80.7550202171262441
41500	2020-07-31 23:14:30	2020-07-31	Trinity Nikolaus-Bechtelar	trinity.nikolaus.bechtelar@geemail.com	San Francisco	California	3056038460866191	7bfdcc44d7960b0b8493b2e855cf8078	Diners Club / Carte Blanche	37.7717114318280025	-122.474981297115946
41501	2020-07-31 23:17:24	2020-07-31	Etha Brakus MD	etha.brakus.md@woohoo.com	Carlsbad	California	3088956958385220069	022a7850335d70dcc171b1c9f9c2a721	JCB 16 digit	33.2079772061143075	-117.209365265469245
41502	2020-07-31 23:26:44	2020-07-31	Zora Larkin DVM	zora.larkin.dvm@geemail.com	Cincinnati	Ohio	4152116361464498	b1ba14f206cb6a72361092c8a36048ea	JCB 16 digit	39.1356664026387051	-84.5729933766454423
41503	2020-07-31 23:31:15	2020-07-31	Isidor Brown-Lakin	isidor.brown.lakin@geemail.com	Little Rock	Arkansas	3054329249170498	0c140e36bbad1fa02b50396e062983fa	JCB 15 digit	34.6324639595389385	-92.4554613855540737
41504	2020-07-31 23:50:13	2020-07-31	Dr. Marely Watsica	dr.marely.watsica@geemail.com	Irvine	California	503854687278116	735c2d48549e382c8cb7e7f5c44614a2	Mastercard	33.6578540717266534	-117.797189154011377
41505	2020-07-31 23:52:33	2020-07-31	Dorsey Tromp	dorsey.tromp@geemail.com	Aurora	Colorado	503860783263258	705718e1d87a1808884cae8abbfa6498	Maestro	39.7603807628732184	-104.748063483380534
41506	2020-07-31 23:53:55	2020-07-31	Dr. Littleton Cormier	dr.littleton.cormier@geemail.com	Tyler	Texas	4778639323063	23e1ee251bdad02daa8076fd380d9c52	American Express	32.4100183926571219	-95.2182830875381825
41507	2020-08-01 00:01:31	2020-08-01	Barbra Carter	barbra.carter@geemail.com	Berkeley	California	6011063267038969225	d3958d51530553e3eaebd7ee5adeeb20	JCB 15 digit	37.8521836127917126	-122.279787222166945
41508	2020-08-01 00:13:14	2020-08-01	Carlos Robel	carlos.robel@geemail.com	Houston	Texas	3112897625677157133	4266af146c07ff27e45ec3bf7d6012bf	VISA 16 digit	29.854033252045884	-95.3878659924972823
41509	2020-08-01 00:21:07	2020-08-01	Devon Kuhn	devon.kuhn@geemail.com	Philadelphia	Pennsylvania	210077631836180703	ca6875d1a0c4ecbe798913698e5ffc88	JCB 16 digit	40.052427268629522	-75.1887616767913158
41510	2020-08-01 00:21:35	2020-08-01	Elease Nienow	elease.nienow@geemail.com	Tacoma	Washington	3088752852145641506	63bf9f48606e1f8b04ffb91f2ef3f52a	JCB 16 digit	47.1696834062811021	-122.408350659744073
41511	2020-08-01 00:22:27	2020-08-01	Robyn Mitchell DVM	robyn.mitchell.dvm@geemail.com	Chicago	Illinois	869993664256886251	f643de01c0640a43e2c45cc80132d6b6	JCB 16 digit	41.8504172409255091	-87.5886561384454296
41512	2020-08-01 00:31:01	2020-08-01	Melisa Walter MD	melisa.walter.md@woohoo.com	Gilbert	Arizona	3088499251164913391	ec9922a45f72bfb8cef5c63e3155ab73	American Express	33.3236687620516818	-111.771827618604902
41513	2020-08-01 00:53:04	2020-08-01	Torrey Sauer-Russel	torrey.sauer.russel@geemail.com	Omaha	Nebraska	54652709558520554	a23ba8584e5f29489f295a4695d7a0f6	Maestro	41.1790578408777748	-96.0299537376616144
41514	2020-08-01 00:58:02	2020-08-01	Sommer Schaden	sommer.schaden@geemail.com	New York	New York	53882103185800880	ba06528ab1e04b7241999378090670cf	Diners Club / Carte Blanche	40.6749580007735645	-73.9702792661625921
41515	2020-08-01 01:13:18	2020-08-01	Mrs. Cheryll Kemmer	mrs.cheryll.kemmer@geemail.com	Tulsa	Oklahoma	3734302916561277	4cd9e881ecca18172bd24270e503384b	VISA 16 digit	36.1714272130183829	-95.8809118768621147
41516	2020-08-01 01:21:52	2020-08-01	Ebony Lubowitz	ebony.lubowitz@geemail.com	New York	New York	6011137733108350606	08134e30afb6ce243774ba758f121145	American Express	40.6244966888558139	-73.9774467815075099
41517	2020-08-01 01:27:29	2020-08-01	Jethro Green Sr.	jethro.green.sr.@geemail.com	San Francisco	California	210003908669977051	116b277fc6095dbbf94c2290993d7f35	Voyager	37.7872714269375223	-122.425060409208101
41518	2020-08-01 01:46:36	2020-08-01	Ms. Christal Daniel	ms.christal.daniel@geemail.com	Lincoln	Nebraska	210073586313333346	7913ac563224aaf368a070e0b4dd5c11	JCB 15 digit	40.8758508084826175	-96.7325352605592457
41519	2020-08-01 02:01:06	2020-08-01	Mr. Foch Monahan DDS	mr.foch.monahan.dds@geemail.com	Spokane	Washington	180029362597755959	c2373e386b85d5672e2e187e26077f00	JCB 16 digit	47.6642602402955262	-117.431039664325496
41520	2020-08-01 02:05:33	2020-08-01	Yandel Kuhic II	yandel.kuhic.ii@geemail.com	New York	New York	3055246375688680	abb942abd697899d8490235f27994447	Mastercard	40.6837172549907109	-74.0369173350639613
41521	2020-08-01 02:12:13	2020-08-01	Dr. Oran Fadel DDS	dr.oran.fadel.dds@geemail.com	Colorado Springs	Colorado	3009202523987157	46c0451fc0e45fe5de15c0a0a8669143	JCB 16 digit	38.944536039377752	-104.75127653509081
41522	2020-08-01 02:13:34	2020-08-01	Ossie Leannon	ossie.leannon@geemail.com	Berkeley	California	6011398622815255733	d3f9a98691862738701845ea718af217	JCB 16 digit	37.8914052725517081	-122.284663509726599
41523	2020-08-01 02:14:42	2020-08-01	Mr. Shyheim Harber PhD	mr.shyheim.harber.phd@geemail.com	Berkeley	California	54502116704047817	dd533e891d0c5c7ab63a919fe3098fed	Voyager	37.8523754022446113	-122.276253109335897
41524	2020-08-01 02:15:54	2020-08-01	Ofelia O'Reilly DDS	ofelia.o'reilly.dds@warmmail.com	Dayton	Ohio	869949425249654759	0f13eb0379675f25f2e41e1a42b9d3c9	American Express	39.8112948801159874	-84.2538037425097173
41525	2020-08-01 02:18:14	2020-08-01	Payten Pfannerstill PhD	payten.pfannerstill.phd@geemail.com	Cleveland	Ohio	3112156750328358660	3aba25aa078f6d9b3b91e9fa8234e87c	Maestro	41.5587973125595553	-81.7525151210144116
41526	2020-08-01 02:18:39	2020-08-01	Mr. Harrie Tremblay PhD	mr.harrie.tremblay.phd@geemail.com	Milwaukee	Wisconsin	3004265982375433	5462aaa18d0a7aeaa17e73bab0a8af72	VISA 13 digit	43.0959325523201358	-88.0414923029121042
41527	2020-08-01 02:23:54	2020-08-01	Erla Haag	erla.haag@warmmail.com	Paterson	New Jersey	4623068146017	f28a3945390edd474dd9b49035739971	JCB 15 digit	40.9318613535679887	-74.2122153831154208
41528	2020-08-01 02:51:43	2020-08-01	Sheron Gaylord DVM	sheron.gaylord.dvm@geemail.com	Pembroke Pines	Florida	52273356177260169	6f355ebb9734ffabf5fe3df16a21d1c3	Mastercard	26.0669580329246813	-80.2426548123262791
41529	2020-08-01 02:59:13	2020-08-01	Dr. Brodie Prosacco	dr.brodie.prosacco@geemail.com	Everett	Washington	210011365276342965	5692e1b39a07e3568a8f17b641e64842	VISA 16 digit	47.9160176774844544	-122.127479502711068
41530	2020-08-01 02:59:33	2020-08-01	Jayden Marks	jayden.marks@woohoo.com	St. Petersburg	Florida	4194308248826946	e6bba5540f3461192536ea2fa7dd5701	VISA 16 digit	27.6942099180892107	-82.6000948138426878
41531	2020-08-01 02:59:37	2020-08-01	Miss Payton McGlynn PhD	miss.payton.mcglynn.phd@geemail.com	Fayetteville	North Carolina	180080076985883365	d5071ae0285b972825be8f26419e04cd	Diners Club / Carte Blanche	35.1391910824246665	-78.9288104518912803
41532	2020-08-01 03:02:31	2020-08-01	Angelia Gleichner	angelia.gleichner@geemail.com	Houston	Texas	4437728557117016	6b6f45b1ed63a1fb89493c19e83cb5c3	JCB 16 digit	29.8420960914421833	-95.3046615669984334
41533	2020-08-01 03:05:05	2020-08-01	Celestia Konopelski	celestia.konopelski@woohoo.com	Chicago	Illinois	6011054909331536752	31fb37a66a624047f4c6b548bd7683d9	VISA 16 digit	41.8416695650037411	-87.6559789022926168
41534	2020-08-01 03:07:14	2020-08-01	Agnes Dietrich PhD	agnes.dietrich.phd@geemail.com	New York	New York	869946752597063413	7b146bb0a9210c2295bd87375d9d5197	Voyager	40.577599505078048	-73.9147552053805441
41535	2020-08-01 03:09:10	2020-08-01	Mr. Daron Goodwin	mr.daron.goodwin@geemail.com	Denver	Colorado	4169305355235	520e02288c815bb564b09072e653c478	Voyager	39.8470418181322472	-104.914367367305232
41536	2020-08-01 03:18:10	2020-08-01	Dewayne Doyle	dewayne.doyle@geemail.com	New York	New York	4904510125900956	4e7b1551865ba03fc717132a35efc49b	Diners Club / Carte Blanche	40.6733955898545645	-73.9511593855813061
41537	2020-08-01 03:18:57	2020-08-01	Eathel Fisher	eathel.fisher@geemail.com	New York	New York	3046706829322607	2394efa5a610959bff792f90fd3913f6	JCB 16 digit	40.6867676264829896	-74.0105610138632386
41538	2020-08-01 03:24:29	2020-08-01	Ashley Gaylord	ashley.gaylord@geemail.com	Cape Coral	Florida	55987311315546026	38f8a819a30b6274419204f6d72d43b1	American Express	26.677617326143011	-81.9765765904054007
41539	2020-08-01 03:26:08	2020-08-01	Catherine Goodwin	catherine.goodwin@geemail.com	San Francisco	California	4611907553088821	fc6517003620a2aeb693ffaed538f594	JCB 15 digit	37.8146030462721683	-122.45026428688962
41540	2020-08-01 03:27:17	2020-08-01	Leamon Boyer	leamon.boyer@warmmail.com	Surprise	Arizona	4767899767929	6a4bad87ce7fe20bf78230ba32dcb9f1	JCB 16 digit	33.7412161903217438	-112.515348897897439
41541	2020-08-01 03:35:29	2020-08-01	Zion Block	zion.block@woohoo.com	Albuquerque	New Mexico	4299030507204	23ce34dc59c6bbfd2b019356d2d0f150	JCB 16 digit	35.0573253706231753	-106.731259537076212
41542	2020-08-01 03:38:08	2020-08-01	Dola Upton	dola.upton@geemail.com	Cambridge	Massachusetts	180014310017953883	25e78c20538dd038c102a357dde8deca	VISA 13 digit	42.4352457843944393	-71.0505145003635477
41543	2020-08-01 03:41:24	2020-08-01	Mr. Kade Towne	mr.kade.towne@geemail.com	Memphis	Tennessee	4504787895870791	04c03640c493abb47a288a521cc73ce0	Discover	35.0870179282102725	-90.0473550207704392
41544	2020-08-01 04:00:27	2020-08-01	Nanna Bradtke DVM	nanna.bradtke.dvm@warmmail.com	Lewisville	Texas	3337369153569319363	90d59b278aa2c6fae34889d01f89b7ee	VISA 16 digit	32.9792838976703564	-97.004979487371827
41545	2020-08-01 04:03:03	2020-08-01	Chip Hoeger	chip.hoeger@warmmail.com	Fort Worth	Texas	3733944194538146	d56f650163728fe30bfd059fd7a441de	VISA 13 digit	32.793042854737493	-97.2501154095221239
41546	2020-08-01 04:23:05	2020-08-01	Dr. Santana Tromp DDS	dr.santana.tromp.dds@woohoo.com	San Francisco	California	4281812747414	cfc8e17f303e12b7a43542f325f07a46	Voyager	37.7735067181689246	-122.434856644264087
41547	2020-08-01 04:41:06	2020-08-01	Dr. Yetta Bergnaum	dr.yetta.bergnaum@geemail.com	Everett	Washington	6011930255503088903	55c35d239340d36bd90f83f42eafd2c8	VISA 16 digit	48.026354579011354	-122.103314254771547
41548	2020-08-01 04:43:01	2020-08-01	Guilford McKenzie	guilford.mckenzie@geemail.com	San Francisco	California	210078659531000586	d66c20d90511c34be286c62069810f8c	JCB 15 digit	37.7752509397921159	-122.451536462959098
41549	2020-08-01 04:53:06	2020-08-01	Dr. Eliga Cormier	dr.eliga.cormier@geemail.com	New York	New York	869983139066356813	75ba52a0b5f8fe770ed187a1ae12e549	VISA 13 digit	40.7378961839471003	-73.8923585026886229
41550	2020-08-01 04:53:41	2020-08-01	Wayde Funk	wayde.funk@geemail.com	Naperville	Illinois	3716722677709330	d3f358fbe703019e8094afe5024427b8	VISA 13 digit	41.7876422841016222	-88.1215389070455046
41551	2020-08-01 04:57:30	2020-08-01	Trenton Hammes IV	trenton.hammes.iv@warmmail.com	Denver	Colorado	210023289911243154	692c70afcfa14446447b3b3d067a2f17	Maestro	39.8237969995994092	-104.898661785550786
41552	2020-08-01 05:00:03	2020-08-01	Bennett Bosco	bennett.bosco@geemail.com	San Francisco	California	3050440797121843	224adcb99cb8bda813dc58e4d932b537	VISA 16 digit	37.7658424657808922	-122.422957374235395
41553	2020-08-01 05:02:03	2020-08-01	Herschel Reynolds	herschel.reynolds@geemail.com	St. Louis	Missouri	210075666354598094	0d75b5eb7bfcb4cfc2e9e6f507cb3cc5	JCB 15 digit	38.707589496967195	-90.3366044569298623
41554	2020-08-01 05:06:01	2020-08-01	Dr. Rondal O'Kon I	dr.rondal.o'kon.i@woohoo.com	New York	New York	3158520784617048376	7616901ed2f0473666c319923370c392	VISA 16 digit	40.711393884172665	-73.872092101572818
41555	2020-08-01 05:19:55	2020-08-01	Kristin Kilback-Mann	kristin.kilback.mann@geemail.com	Irving	Texas	3729764916867359	8bd36dff607ea5cf85a86743c64306da	VISA 16 digit	32.8824506829444303	-96.888291629152377
41556	2020-08-01 05:32:28	2020-08-01	Amber Torphy	amber.torphy@geemail.com	Columbia	Missouri	4493849056376	9842f8788c37678d0d03dfbb8ab7b2df	VISA 13 digit	38.9000590938490447	-92.3594766747725231
41557	2020-08-01 05:48:14	2020-08-01	Chas Raynor	chas.raynor@geemail.com	Mobile	Alabama	210037233859222428	c4728fe76ac54879d451e35806af48b2	American Express	30.6218248794894663	-88.0095371273484091
41558	2020-08-01 05:52:52	2020-08-01	Kacie Hodkiewicz PhD	kacie.hodkiewicz.phd@geemail.com	Gilbert	Arizona	869916409483928482	021e0a259b538f1dafe38826595f1cfe	VISA 16 digit	33.3716578085787603	-111.793397310529272
41559	2020-08-01 06:01:07	2020-08-01	Dawne Kub	dawne.kub@woohoo.com	New Orleans	Louisiana	4457772652634	594fddb639d29c131e874f894342e6b2	Diners Club / Carte Blanche	30.0253763935077949	-89.9180492937825591
41560	2020-08-01 06:01:16	2020-08-01	Dr. Alec Lowe III	dr.alec.lowe.iii@woohoo.com	Orange	California	53540326164049492	093b401aa21348c4037bc49d6d9da3ae	VISA 13 digit	33.8565268089882991	-117.779015483298522
41561	2020-08-01 06:03:39	2020-08-01	Mr. Polk Conroy	mr.polk.conroy@geemail.com	Omaha	Nebraska	52834556339808563	db6b24778611304fae20ee89e8cca183	Discover	41.1689215736608958	-96.0939639679271806
41562	2020-08-01 06:13:32	2020-08-01	Benji Hettinger	benji.hettinger@woohoo.com	San Francisco	California	4327887205335637	3ff36414392110318ae969e0aa0aaf3f	VISA 13 digit	37.7914192470139909	-122.432692962075507
41563	2020-08-01 06:32:03	2020-08-01	Mrs. Daria Brakus DVM	mrs.daria.brakus.dvm@geemail.com	Birmingham	Alabama	51887783035773059	bc038bcf6665b4549911ddb976546678	American Express	33.5149355086754994	-86.7741412181649423
41564	2020-08-01 06:33:06	2020-08-01	Charlie Baumbach	charlie.baumbach@geemail.com	Portland	Oregon	675923406761355	6665ba3f30b57ce33333568ace330060	VISA 13 digit	45.5436345500294095	-122.707675252389166
41565	2020-08-01 06:41:40	2020-08-01	Brisa Beer	brisa.beer@geemail.com	Oakland	California	4206857261546399	7e08a285d3feff994a369b5d70f1c52d	American Express	37.7854444362327868	-122.280117882708041
41566	2020-08-01 06:56:45	2020-08-01	Theadore Jerde	theadore.jerde@geemail.com	Tulsa	Oklahoma	52432287017968810	caa0cc80c7d64ffb07575164f9cb3e27	VISA 16 digit	36.0354424626003933	-95.8082377419296591
41567	2020-08-01 06:56:53	2020-08-01	Amy Kassulke	amy.kassulke@geemail.com	Overland Park	Kansas	4791564616404339	7838222340a6a28211ab9beb6f3bde35	VISA 13 digit	38.9850347437299831	-94.7613472360227291
41568	2020-08-01 07:17:42	2020-08-01	Madalyn Orn	madalyn.orn@geemail.com	Spokane	Washington	3158612171240755354	f1bc33b67ac81bd484419b4a29a00d28	VISA 16 digit	47.599716026639193	-117.337885597943512
41569	2020-08-01 07:23:41	2020-08-01	Elsie Satterfield	elsie.satterfield@geemail.com	Bakersfield	California	3701776871337378	8f2bffefd25a12b78ea9579b27852961	American Express	35.2901675956964453	-119.058867268477755
41570	2020-08-01 07:24:40	2020-08-01	Ballard Carter	ballard.carter@geemail.com	Alexandria	Virginia	180057636891841374	e2fc799d8e6f69228ddfc2be0661015a	VISA 16 digit	38.9005228781256776	-77.1098908021565563
41571	2020-08-01 07:30:29	2020-08-01	Phillis Lueilwitz	phillis.lueilwitz@geemail.com	San Francisco	California	6011392076733779843	83534bb174382414d04cc6685063bdc1	Voyager	37.7737388642668321	-122.410920460883659
41572	2020-08-01 07:31:27	2020-08-01	Mrs. Kanesha Kreiger	mrs.kanesha.kreiger@geemail.com	Los Angeles	California	4863380898898814	ef017131e94be950de764ad9bfaa799d	Maestro	34.1129626192018378	-118.393353183799604
41573	2020-08-01 07:33:28	2020-08-01	King Towne	king.towne@geemail.com	Irving	Texas	6011212320992611349	6ffa996d713a6b07a614e011a4be39da	VISA 16 digit	32.9413094022262882	-96.9121926496084711
41574	2020-08-01 07:33:32	2020-08-01	Bartley Walter	bartley.walter@geemail.com	Charlotte	North Carolina	6011815592270713804	145f6f1986947492e12c7bb81bec9c3f	Diners Club / Carte Blanche	35.2829717635896074	-80.7726651311796218
41575	2020-08-01 07:33:56	2020-08-01	Shakira Gleason DVM	shakira.gleason.dvm@geemail.com	New York	New York	4284464396617594	255328ed03c219dd5c5d7b1541fece1d	JCB 16 digit	40.6305223701745248	-73.898103000446028
41576	2020-08-01 07:44:40	2020-08-01	Killian Schaden	killian.schaden@warmmail.com	Ontario	California	869970794085133653	f939a2fe455ae11075250b27759ff524	VISA 16 digit	33.9636068000603473	-117.534600036554792
41577	2020-08-01 07:52:37	2020-08-01	Camilla Kuhn PhD	camilla.kuhn.phd@woohoo.com	San Diego	California	4989425319302	a9ca210407c48485350f47c28e0d6c98	Voyager	32.739114840102566	-117.037736789546912
41578	2020-08-01 08:04:15	2020-08-01	Miss Zada Heathcote MD	miss.zada.heathcote.md@geemail.com	Augusta	Georgia	869937415650485805	830ee0c34b788b6b0a7989d3a83b615a	JCB 16 digit	33.4065607425030322	-82.1597181032706061
41579	2020-08-01 08:06:45	2020-08-01	Asa Hayes	asa.hayes@geemail.com	Waterbury	Connecticut	4067302265272310	26b69508301a704edd1cd9cdc6cd6fc4	JCB 15 digit	41.4608714218754315	-73.0971786102659991
41580	2020-08-01 08:09:47	2020-08-01	Dr. Teagan Dicki I	dr.teagan.dicki.i@warmmail.com	Albuquerque	New Mexico	869973486432538786	06a3278a175c583421a2bf134af90ca9	Diners Club / Carte Blanche	35.1332344681158659	-106.733381362219902
41581	2020-08-01 08:15:02	2020-08-01	Danna Flatley	danna.flatley@geemail.com	Davie	Florida	502069064051357	a8b81728d0bfdc7ed17ec48e393f0155	VISA 16 digit	26.1200899502061326	-80.2847098640538661
41582	2020-08-01 08:30:10	2020-08-01	Lyn Welch MD	lyn.welch.md@woohoo.com	Fort Worth	Texas	6011765497656462846	2107efc90988f1e5ed72edac19d450e8	VISA 13 digit	32.7156107287909848	-97.3255603746797817
41583	2020-08-01 08:31:53	2020-08-01	Dr. Hardie Funk V	dr.hardie.funk.v@woohoo.com	Newark	New Jersey	3435671339922251	3b90bd95f63ccb443cf0c9b429ce3d1c	VISA 13 digit	40.6877983246844295	-74.0739110300991683
41584	2020-08-01 08:35:40	2020-08-01	Marius Homenick-Bayer	marius.homenick.bayer@geemail.com	Arlington	Texas	3056535243616330	ef6fa8b7678f1447712b0f8a84651fac	Mastercard	32.7972224551968239	-97.2181309337753845
41585	2020-08-01 08:45:26	2020-08-01	Halbert Kihn	halbert.kihn@geemail.com	Tucson	Arizona	3337918092064463258	f8b2841e43d0cc780a5ebc33947b48a4	JCB 16 digit	32.1300574429374208	-110.93204816670567
41586	2020-08-01 08:48:54	2020-08-01	Jaleel Hoppe	jaleel.hoppe@geemail.com	Hialeah	Florida	3707452854277098	7122683e2fd900d7628c59cca4c7b206	JCB 16 digit	25.8172324641119708	-80.3758413424618539
41587	2020-08-01 09:05:31	2020-08-01	Jaidyn Moen	jaidyn.moen@warmmail.com	Garland	Texas	4744035998583139	78df2fbda4afe8cf5c104ab1f09a590e	JCB 16 digit	32.9686027376681565	-96.6661035027980802
41588	2020-08-01 09:05:54	2020-08-01	Jameson Moore PhD	jameson.moore.phd@woohoo.com	Fort Worth	Texas	4209604281430155	775435ec0c790e11b0e51f8c545caa9f	American Express	32.7266369529590051	-97.3553088528391015
41589	2020-08-01 09:05:57	2020-08-01	Amit Schaden	amit.schaden@woohoo.com	Athens	Georgia	4234140321287	fc1ab2595fbbd27f3cbcb685dc6fbc46	JCB 15 digit	33.9480791394323091	-83.3477825992390393
41590	2020-08-01 09:18:08	2020-08-01	Dr. Marissa McGlynn DVM	dr.marissa.mcglynn.dvm@geemail.com	Lubbock	Texas	180068921772331803	45abf4c55c94de324d7d1823d1d16e36	American Express	33.6349657287396511	-101.952654354591672
41591	2020-08-01 09:27:25	2020-08-01	Dominique Robel	dominique.robel@warmmail.com	Augusta	Georgia	6011541395561459660	3af2ac9b04c15101e11469b3c77a09ab	Mastercard	33.4525485431980343	-82.0643825193230185
41592	2020-08-01 09:40:38	2020-08-01	Ozie Cronin	ozie.cronin@geemail.com	Cincinnati	Ohio	676124521306167	cbbe0be9cf34b34f7c6e72c324073a06	Mastercard	39.2078845577545465	-84.5619154120136045
41593	2020-08-01 09:42:30	2020-08-01	Santana Kassulke PhD	santana.kassulke.phd@geemail.com	El Paso	Texas	3791906739307310	e9ea4c931f54e301f3f506d9d07ad091	Maestro	31.8839345848016471	-106.416647685177637
41594	2020-08-01 09:46:00	2020-08-01	Ms. Sunny Kessler MD	ms.sunny.kessler.md@woohoo.com	Portland	Oregon	3112492036547032887	8a23ac637a06a856e75472928f52a0e4	VISA 13 digit	45.4995876908190553	-122.70870960671455
41595	2020-08-01 09:46:44	2020-08-01	Tegan Feest DDS	tegan.feest.dds@geemail.com	Fayetteville	North Carolina	6011569719907444002	f91c4aec62b59546f9067a1c8ef34231	Voyager	35.062329119934887	-79.027773400874807
41596	2020-08-01 09:53:07	2020-08-01	Barnard Abernathy	barnard.abernathy@geemail.com	Milwaukee	Wisconsin	3038904422381215	d08382b579ba2c3dba539f99184ccfda	Voyager	43.1021125544879595	-87.9692426136795405
41597	2020-08-01 09:57:15	2020-08-01	Gigi Dicki	gigi.dicki@geemail.com	Newark	New Jersey	6011412865842727792	3944938fb401eb70f2618a83065425d3	JCB 16 digit	40.6655788687903481	-74.2341653247106876
41598	2020-08-01 10:02:34	2020-08-01	Savanna Runte	savanna.runte@geemail.com	Phoenix	Arizona	180097265295855319	a18b30add2d86e176caf4eafe4fbb1d0	Discover	33.6434396627757692	-111.995950345827652
41599	2020-08-01 10:13:30	2020-08-01	Hayes Vandervort-Kunze	hayes.vandervort.kunze@woohoo.com	Glendale	Arizona	4855213363746210	18a35c0a0bfddcc4e6cf8c0df28681fb	Diners Club / Carte Blanche	33.5159208891674822	-112.120832296533138
41600	2020-08-01 10:15:11	2020-08-01	Rylie Quitzon	rylie.quitzon@geemail.com	Philadelphia	Pennsylvania	3528346483684468946	3aaf2483130e75f5925435086a374eb6	JCB 16 digit	39.9919218298006811	-75.2116296894282215
41601	2020-08-01 10:18:25	2020-08-01	Dessie Goodwin	dessie.goodwin@woohoo.com	Baltimore	Maryland	3096883328498391942	db2d46ce82325230213d716ff4c302f7	Voyager	39.307831699075173	-76.5190419965442317
41602	2020-08-01 10:30:53	2020-08-01	Mr. Darius Fadel	mr.darius.fadel@geemail.com	Oklahoma City	Oklahoma	3799704721340353	39b09e179bc4945160f6724e2499db17	Mastercard	35.5093459707129782	-97.4673973032168988
41603	2020-08-01 10:48:56	2020-08-01	Dr. Jordan Johnson	dr.jordan.johnson@geemail.com	Sioux Falls	South Dakota	6011674828763408498	60510366d04a0ca5d909067e5eff2857	VISA 13 digit	43.4625396992631252	-96.6447465767785872
41604	2020-08-01 10:52:07	2020-08-01	Jarvis Rogahn	jarvis.rogahn@geemail.com	Chicago	Illinois	4022650417247612	f3e61e3f434d083c74c801f55f7cd337	VISA 16 digit	41.7530466441832502	-87.6341182777687919
41605	2020-08-01 10:58:22	2020-08-01	Nana Ryan	nana.ryan@geemail.com	Los Angeles	California	6011464075492120796	733b1dc71bc4ab5f1967af140db97a0a	Maestro	33.9206382953427692	-118.42709804861731
41606	2020-08-01 10:58:30	2020-08-01	Jerrad Skiles MD	jerrad.skiles.md@woohoo.com	San Francisco	California	4376779875781531	b4ba894add9ad82f8c33dafc6b8f3a02	JCB 16 digit	37.7652372792459019	-122.405883699934662
41607	2020-08-01 11:01:02	2020-08-01	Ms. Taylor Nader DVM	ms.taylor.nader.dvm@warmmail.com	Cleveland	Ohio	3158001950764038522	d6ea216afbeaa44907b8da8aa6e3d479	American Express	41.4710397993531075	-81.6633623798616242
41608	2020-08-01 11:10:06	2020-08-01	Merritt Murray	merritt.murray@warmmail.com	West Covina	California	3428391952314582	fa56b4bec378d5036d2d184e8a9b167b	Diners Club / Carte Blanche	34.1207985262494518	-117.860378564947837
41609	2020-08-01 11:15:09	2020-08-01	Ronal Prosacco	ronal.prosacco@woohoo.com	San Francisco	California	4931963229105	3c2d2abd267dd4a0ccd3dafe0c325cfd	VISA 16 digit	37.7951240037946192	-122.440759866416869
41610	2020-08-01 11:18:36	2020-08-01	Tillie Kuphal DDS	tillie.kuphal.dds@geemail.com	Phoenix	Arizona	869951716061379631	4932ca3e5014dbb8a3e88aee21ca02a0	American Express	33.5871120646528922	-112.095819920340929
41611	2020-08-01 11:30:54	2020-08-01	Deion Schowalter Sr.	deion.schowalter.sr.@geemail.com	Nashville	Tennessee	4408617637809632	c8456bc786566841cd1b376daadb4f92	Diners Club / Carte Blanche	36.2321469631168966	-86.7488497218955246
41612	2020-08-01 11:32:37	2020-08-01	Montel Hessel	montel.hessel@warmmail.com	Charlotte	North Carolina	6011857831864493996	9cbcb098770419870ff8c713b4b69bc6	VISA 16 digit	35.1785348182797435	-80.9070128137655615
41613	2020-08-01 11:34:11	2020-08-01	Delta Harris	delta.harris@warmmail.com	Jackson	Mississippi	869988280686663496	9171f89dcbe52c69c4e54afe1c6d00ec	Voyager	32.3156026129789709	-90.1654326947379872
41614	2020-08-01 11:37:26	2020-08-01	Cooper Welch	cooper.welch@geemail.com	Port St. Lucie	Florida	676213865901527	38a0f304eb91c1f5e821b31b021eb292	JCB 16 digit	27.3353407088335594	-80.3968934062954048
41615	2020-08-01 11:41:30	2020-08-01	Ms. Valarie Bruen	ms.valarie.bruen@geemail.com	Stockton	California	210057541417410748	8f814ca8ed86efe0c9c91b372983e390	American Express	37.9515015676815111	-121.356379499294974
41616	2020-08-01 11:56:42	2020-08-01	Ms. Magdalen Gutmann	ms.magdalen.gutmann@geemail.com	Berkeley	California	3498644273302016	9dc9b57da2a67a6bedb32e269e46bad0	Maestro	37.8591007129525039	-122.272130741717334
41617	2020-08-01 12:07:19	2020-08-01	Mr. Jameel Zboncak	mr.jameel.zboncak@geemail.com	Fort Wayne	Indiana	55344906708483832	b975964f92adfe74dad03014214e1164	Mastercard	41.1877426291134228	-85.0728280738215972
41618	2020-08-01 12:15:26	2020-08-01	Jax Jacobson	jax.jacobson@woohoo.com	Cape Coral	Florida	4293369215463	b781772975e4abc100216d5ce1fa626a	American Express	26.561900741091744	-82.0227277351148416
41619	2020-08-01 12:25:46	2020-08-01	Laurel Parker	laurel.parker@woohoo.com	Fontana	California	630433416095249	1e4546917e0accb0c77f6b5c4cf72b8d	Discover	34.0409029030855734	-117.455331371100257
41620	2020-08-01 12:44:40	2020-08-01	Keely Kutch	keely.kutch@geemail.com	Chicago	Illinois	3112996570220527152	fa899e8343ae91fc79e485a0d0a869a0	JCB 15 digit	41.7618583454120937	-87.7191051240108806
41621	2020-08-01 13:00:19	2020-08-01	Mr. Amarion Harris	mr.amarion.harris@geemail.com	Oakland	California	4547239503816	a8d8d36c19c2614c6d8bc17592176e8f	American Express	37.7858430678668853	-122.312050825353637
41622	2020-08-01 13:02:53	2020-08-01	Oakley Aufderhar	oakley.aufderhar@geemail.com	Hampton	Virginia	3528287220822703276	29be5d647901a159985a2af5361398df	Diners Club / Carte Blanche	37.0659615096189086	-76.2838512934841191
41623	2020-08-01 13:06:08	2020-08-01	Jeanetta Gerhold	jeanetta.gerhold@woohoo.com	Houston	Texas	4282252328823741	9dc6bb2628d8a0eac06fdfd6f05d40c5	American Express	29.6879090311549589	-95.4491421507220679
41624	2020-08-01 13:07:40	2020-08-01	Charlene Kiehn	charlene.kiehn@geemail.com	San Francisco	California	675990532801827	5db48ef407e46887a1b77aac589e3def	Mastercard	37.7698243957159576	-122.453344810707591
41625	2020-08-01 13:09:18	2020-08-01	Amil Dicki	amil.dicki@warmmail.com	New York	New York	4103091496044	b32899f109ca838e87843b4444e7cc03	Mastercard	40.6139259208217283	-73.8771197842329741
41626	2020-08-01 13:24:26	2020-08-01	Wess Hickle	wess.hickle@geemail.com	San Francisco	California	3096175355406480068	a34d03da40283b39ef7daa5029347c4c	Maestro	37.7890619493308648	-122.409100252035856
41627	2020-08-01 13:34:39	2020-08-01	Aimee Kunde-Rutherford	aimee.kunde.rutherford@woohoo.com	Downey	California	3337570654753186430	0f3810bbe44c0ee8da5fd62b210228bc	JCB 15 digit	33.9734241905871812	-118.175106394068891
41628	2020-08-01 13:36:57	2020-08-01	Pallie Stark	pallie.stark@geemail.com	Austin	Texas	3453780654858102	14b2f586e425f3c377345f3903d25994	Discover	30.2893870904237019	-97.7282589452579629
41629	2020-08-01 13:37:04	2020-08-01	Azalee Huels	azalee.huels@geemail.com	San Antonio	Texas	52807495250382014	862f2655253d68e0db2c4a5f226036c0	JCB 15 digit	29.5049358486734334	-98.5967267048381188
41630	2020-08-01 13:42:51	2020-08-01	Mr. Linnie Marquardt	mr.linnie.marquardt@woohoo.com	New York	New York	3024632882530070	3a83709e0e8eaf792faccbbd71456ae9	VISA 16 digit	40.7580541682187487	-73.8849836978957057
41631	2020-08-01 13:53:14	2020-08-01	Antonette Altenwerth	antonette.altenwerth@geemail.com	Los Angeles	California	501860475058313	6895deef1a00d0e763cf57360ed8bff8	VISA 16 digit	33.9518320512358045	-118.359892237045983
41632	2020-08-01 14:06:58	2020-08-01	Jeb Purdy	jeb.purdy@woohoo.com	Chandler	Arizona	4700959681623	0cf7933865211d060cec6f2ecdc0251d	American Express	33.2632583180531824	-111.927143812028319
41633	2020-08-01 14:09:20	2020-08-01	Edgardo Bashirian	edgardo.bashirian@geemail.com	San Francisco	California	4179199884520789	478cf8d2b4142b30ab728d65acb95b19	American Express	37.7808726231133321	-122.410751968382968
41634	2020-08-01 14:10:46	2020-08-01	Dawn Dooley	dawn.dooley@geemail.com	Kansas City	Missouri	53560544638552835	c762dc171ec5ebe2055fdc10011086bd	JCB 16 digit	39.0525981565307845	-94.459147322759037
41635	2020-08-01 14:24:55	2020-08-01	Cindi Ebert	cindi.ebert@geemail.com	San Francisco	California	55713084823588100	ce4eb6fadf779bffd74f668041db0eea	Voyager	37.7511709076501134	-122.40279630464407
41636	2020-08-01 14:33:29	2020-08-01	Deven Schmidt	deven.schmidt@woohoo.com	Naperville	Illinois	3415361239486656	214a175e48c5b08a5469b02dea0ed9e0	JCB 16 digit	41.7326733457304542	-88.1305510371811778
41637	2020-08-01 14:43:51	2020-08-01	Colonel Harber	colonel.harber@geemail.com	New York	New York	4740722400554	536a558feba626ea270cbafca05b0d01	VISA 16 digit	40.6448717253971807	-73.8739617776487023
41638	2020-08-01 14:45:44	2020-08-01	Devyn Herman	devyn.herman@warmmail.com	Tulsa	Oklahoma	4242259512808023	91e0f9d0ddd1f0aced5253c69a9050b0	JCB 16 digit	36.1954354106351701	-95.8414030647791861
41639	2020-08-01 14:51:57	2020-08-01	Mr. Hung Morissette	mr.hung.morissette@geemail.com	Huntington Beach	California	4851658198029	eb255b2686f9547bd837c547737df967	JCB 15 digit	33.6544068805914378	-118.025971504499381
41640	2020-08-01 15:09:02	2020-08-01	Sherman Lakin	sherman.lakin@warmmail.com	San Francisco	California	180074920961680576	1683e3c5587c374c9d0a5b5b12aa9d69	Mastercard	37.7692981242039423	-122.470398930854003
41641	2020-08-01 15:17:37	2020-08-01	Dr. Infant Treutel III	dr.infant.treutel.iii@woohoo.com	San Francisco	California	869952954281368683	6f7665ddd7d4685100974cc1500e5b5d	Maestro	37.7718915529139139	-122.428741937901208
41642	2020-08-01 15:39:26	2020-08-01	Tavion Marks-Weber	tavion.marks.weber@warmmail.com	San Francisco	California	3045965273794957	75d7d70726205c447dc3549f60a03b06	VISA 16 digit	37.7598763102864865	-122.445801305200249
41643	2020-08-01 15:41:32	2020-08-01	Nadia Kozey	nadia.kozey@geemail.com	San Francisco	California	3112194400720565876	d64083e99ec326e4f21b325808ff0cef	VISA 13 digit	37.7506332566420895	-122.441582925744484
41644	2020-08-01 15:46:19	2020-08-01	Mr. Merle Bode	mr.merle.bode@geemail.com	Tallahassee	Florida	869945569395183693	834816eb21454d32dd18a24eaf11342f	Diners Club / Carte Blanche	30.5107071635335707	-84.2977409922067125
41645	2020-08-01 15:50:16	2020-08-01	Valarie Boyer	valarie.boyer@geemail.com	Broken Arrow	Oklahoma	4703225379622940	5286eb78ede036f1850772753ec48391	Diners Club / Carte Blanche	36.0555077084582294	-95.796143581805751
41646	2020-08-01 15:52:04	2020-08-01	Karl Quitzon	karl.quitzon@geemail.com	Milwaukee	Wisconsin	4217751072369637	7852654b7987e1422e00d145a94bacf3	JCB 15 digit	42.9711378649428468	-88.0127818844381693
41647	2020-08-01 15:56:49	2020-08-01	Babyboy Toy	babyboy.toy@warmmail.com	Round Rock	Texas	6011188026002321759	bcb2eedc04211465e1646f31b1a1ba2b	Voyager	30.4498381205972315	-97.6205219274703353
41648	2020-08-01 15:57:04	2020-08-01	Nigel Frami	nigel.frami@warmmail.com	Peoria	Illinois	4582092583667657	af278f029395508da9eefb8194624ce7	Voyager	40.7124939326997861	-89.6344929514337423
41649	2020-08-01 16:04:05	2020-08-01	Ayleen Konopelski	ayleen.konopelski@geemail.com	Moreno Valley	California	3413473853694556	84e574db0bb8be25854972351c08362f	VISA 16 digit	33.8324347627341737	-117.233860095075144
41650	2020-08-01 16:07:55	2020-08-01	Miss Erica Casper MD	miss.erica.casper.md@geemail.com	Omaha	Nebraska	4088301140971	7f8beda06deb0502dc653b1525d2eed0	Discover	41.2554079529974658	-95.9936001892317137
41651	2020-08-01 16:37:12	2020-08-01	Talmage Wyman	talmage.wyman@geemail.com	Tulsa	Oklahoma	4477296725997	07f74628cf2dcfe08dd76280a5c27b9f	JCB 16 digit	36.2210872728280719	-95.9513262223873227
41652	2020-08-01 16:47:35	2020-08-01	Naima Cummings	naima.cummings@geemail.com	San Jose	California	3337705105888433781	9588241ecf4b2054751ffec59174d24a	American Express	37.303334062482044	-121.838092157778888
41653	2020-08-01 17:03:40	2020-08-01	Denton Schaden	denton.schaden@warmmail.com	Tucson	Arizona	869972049106028897	788b488de4d82554064d4d48cee08fb0	Mastercard	32.2389807890210349	-110.933024457585432
41654	2020-08-01 17:13:07	2020-08-01	Jaycee Heidenreich	jaycee.heidenreich@geemail.com	Chicago	Illinois	6011704165786721340	06ffdf3871244897565b30866122172d	Maestro	41.8770030047114972	-87.6116787007573947
41655	2020-08-01 17:16:52	2020-08-01	Dayna Cole	dayna.cole@geemail.com	New York	New York	869906128726742938	15fc3aec285678d30bba3117852e5efb	JCB 15 digit	40.5726001034714301	-73.9612662873126538
41656	2020-08-01 17:26:50	2020-08-01	Lolla Wiza	lolla.wiza@geemail.com	Berkeley	California	6011231318507413844	45654c91c66847aa1663db8df0b53a04	JCB 16 digit	37.8691778307707381	-122.23750988703911
41657	2020-08-01 17:26:58	2020-08-01	Amarion Ritchie-Watsica	amarion.ritchie.watsica@geemail.com	Raleigh	North Carolina	3112290071165555962	5a498d96276bcf209f9928d47417b1fb	VISA 13 digit	35.8306108729116559	-78.7333036417078205
41658	2020-08-01 17:29:15	2020-08-01	Dr. Salvatore Lehner PhD	dr.salvatore.lehner.phd@woohoo.com	Boston	Massachusetts	869901089999909585	face3a20436bc817fed664c8fcadb6f1	Maestro	42.2437597263772062	-70.9391133894629746
41659	2020-08-01 17:36:13	2020-08-01	Beryl Wehner-West	beryl.wehner.west@geemail.com	Fresno	California	4147174944917	4f7e4a029cb8efcbae9d4195e2af7419	Mastercard	36.8217470272783203	-119.857379640882471
41660	2020-08-01 17:37:06	2020-08-01	Dedric Ryan V	dedric.ryan.v@geemail.com	New York	New York	3096701922473904982	4f458c16b5df483265f98d71bdd19aa3	Voyager	40.6045470520146168	-73.9906584637135296
41661	2020-08-01 17:41:11	2020-08-01	Orris Gutkowski	orris.gutkowski@warmmail.com	Raleigh	North Carolina	6011647765235496822	181a543ab238ae4b0b19a3f4f360a0f5	VISA 16 digit	35.7570189974870516	-78.7135718519736116
41662	2020-08-01 17:45:19	2020-08-01	Alpheus McGlynn-Marks	alpheus.mcglynn.marks@woohoo.com	Seattle	Washington	3726987107278606	4c4a8d3f4ae3d913b57ab6ad10acaefe	Mastercard	47.5405444968882946	-122.363870574246718
41663	2020-08-01 17:50:44	2020-08-01	Perri Larkin	perri.larkin@geemail.com	San Francisco	California	6011127289324180725	a65b69f074ae5443bdb6eb2115a93537	Discover	37.7893670934172548	-122.435638714739568
41664	2020-08-01 17:54:26	2020-08-01	Dr. Webster Funk	dr.webster.funk@woohoo.com	Houston	Texas	3057753108326510	5549c36e035d97441c20b7271fe072c6	Voyager	29.8535657786376767	-95.3616677237223911
41665	2020-08-01 17:59:43	2020-08-01	Gee Shields Jr.	gee.shields.jr.@geemail.com	Downey	California	4861467441026290	a3f5b73de38ae8c5a2a3aa96d9b2fe5e	JCB 16 digit	33.9531388103745897	-118.119412564357361
41666	2020-08-01 18:08:47	2020-08-01	Ms. Penelope Kshlerin MD	ms.penelope.kshlerin.md@geemail.com	Reno	Nevada	4994889328451251	2cab970c317634a622c57acf6910215b	VISA 16 digit	39.4653644529249519	-119.934522127329942
41667	2020-08-01 18:19:24	2020-08-01	Ember Hauck	ember.hauck@geemail.com	Tucson	Arizona	869962757754363844	c66b80d3dba9a81a31ca10480203c045	Maestro	32.2248428410891492	-110.928913469262795
41668	2020-08-01 18:25:09	2020-08-01	Dr. Lionel Dickens	dr.lionel.dickens@warmmail.com	New York	New York	676176540592722	c29db1cd782d84eda38161a67c70fbcb	American Express	40.6145297859087577	-73.9933952225733549
41669	2020-08-01 18:53:40	2020-08-01	Matias Wisoky	matias.wisoky@geemail.com	Phoenix	Arizona	4256737154110	0cc9952d4969cf4e768054bb3235b2c0	American Express	33.5602098175257453	-112.011236112185202
41670	2020-08-01 18:57:41	2020-08-01	Kalel Ziemann	kalel.ziemann@woohoo.com	Dallas	Texas	869963012521688712	4c625345e86ec290dfc1db5634b2ce46	Diners Club / Carte Blanche	32.7274882853768787	-96.8585043296180572
41671	2020-08-01 19:00:13	2020-08-01	Mr. Zollie Denesik	mr.zollie.denesik@geemail.com	Louisville	Kentucky	3001823657189548	ca3b4bcce3b9745363a5c04c5ddd58af	American Express	38.0955418854854955	-85.6242003937788354
41672	2020-08-01 19:13:51	2020-08-01	Carrol Schneider-Jones	carrol.schneider.jones@geemail.com	Dallas	Texas	3088081097632330682	fad80c17f21c6396a89c4cf01354c24c	Diners Club / Carte Blanche	32.827420157174771	-96.7465827455706773
41673	2020-08-01 19:14:26	2020-08-01	Lavina Fritsch	lavina.fritsch@geemail.com	Mesa	Arizona	3112741743308808889	c3920e86c23bcef3ea3f4554e3fe19fe	VISA 16 digit	33.4980535192094706	-111.646130998234824
41674	2020-08-01 19:32:04	2020-08-01	Leota Conroy-Mraz	leota.conroy.mraz@warmmail.com	High Point	North Carolina	3006559702804823	c0dceb0100d39d02c66d478a93c19f8e	VISA 16 digit	35.9119544798135806	-80.0733068104106849
41675	2020-08-01 19:56:23	2020-08-01	Julious Rath	julious.rath@woohoo.com	Pearland	Texas	6011847123219870521	a234b91dd195f3e07e4fc0eb6ef2daaf	Discover	29.5477785846024759	-95.3595352655131308
41676	2020-08-01 20:07:29	2020-08-01	Miss Astrid Gorczany	miss.astrid.gorczany@warmmail.com	San Francisco	California	3112428161638873798	4afe6d19a0538a9c1b9851d50912a89a	VISA 16 digit	37.7636177696561361	-122.440103685694439
41677	2020-08-01 20:10:27	2020-08-01	Cornel Cassin DDS	cornel.cassin.dds@geemail.com	Tempe	Arizona	4406154588841	c281cd307a0ff3bedd4ff457888bf5c3	Discover	33.4213887640196816	-111.999489439374955
41678	2020-08-01 20:19:54	2020-08-01	Delsie Greenholt	delsie.greenholt@warmmail.com	New York	New York	4816662762242627	56cf4057ff886288fb1ad7123c633104	VISA 13 digit	40.702331101777034	-73.8487188921205728
41679	2020-08-01 20:23:56	2020-08-01	Leana Deckow-Casper	leana.deckow.casper@warmmail.com	San Francisco	California	52019649917005566	a5256e83113c34fec7de82cf47a33b72	VISA 13 digit	37.7743454113402208	-122.447890481478296
41680	2020-08-01 20:32:41	2020-08-01	Mrs. Syble Homenick DVM	mrs.syble.homenick.dvm@warmmail.com	Lexington	Kentucky	3491398038896377	f2af00fa4a676017f829eb26e485fe30	VISA 16 digit	38.0427277503877903	-84.3912875398427218
41681	2020-08-01 20:54:06	2020-08-01	Mr. Sergio Funk PhD	mr.sergio.funk.phd@geemail.com	San Francisco	California	4977954117940	1f8d971a5e3533e41f117d92549e5790	VISA 16 digit	37.7573213571210502	-122.430694884787854
41682	2020-08-01 21:01:36	2020-08-01	Davie Kutch	davie.kutch@geemail.com	Arlington	Texas	6011257942364968670	b556db645674a84ca738240cf0821d83	Diners Club / Carte Blanche	32.7363313864700487	-97.0789567704338623
41683	2020-08-01 21:05:31	2020-08-01	Wilton Morissette	wilton.morissette@geemail.com	Tampa	Florida	3112130453259299968	6f1592fd183604f2f7c6f8659d60f2f2	Voyager	28.0581682831630097	-82.512453734476864
41684	2020-08-01 21:11:41	2020-08-01	Clarisa Koelpin	clarisa.koelpin@geemail.com	Lexington	Kentucky	180068606865511193	b9f54bc585cdcab390e632e3b7955c6a	JCB 15 digit	38.0786394998773972	-84.4038808841157646
41685	2020-08-01 21:14:58	2020-08-01	Tyrese Krajcik	tyrese.krajcik@warmmail.com	Savannah	Georgia	4258555314426604	d73c3a494af583ad97bff9ddeaf3553f	JCB 15 digit	31.9835908401850588	-81.1646689356923048
41686	2020-08-01 21:17:59	2020-08-01	Jayson Cormier	jayson.cormier@geemail.com	Norfolk	Virginia	869954961644507202	72e2c746c01392fdf7680a8bcd0ae34a	VISA 13 digit	36.8232631286159204	-76.317168833129486
41687	2020-08-01 21:20:22	2020-08-01	Warren Herzog	warren.herzog@warmmail.com	Peoria	Arizona	180033160435430858	87d0427427e8ad44fd59ca93daae9e57	JCB 16 digit	33.8366374665208198	-112.326948587309573
41688	2020-08-01 21:30:03	2020-08-01	Blas Friesen MD	blas.friesen.md@geemail.com	San Francisco	California	4322944441885852	4adb9aad64fefa65ce841e294cb1b718	Diners Club / Carte Blanche	37.7543969841530824	-122.427534054155416
41689	2020-08-01 21:37:22	2020-08-01	Lannie Reichert	lannie.reichert@woohoo.com	Detroit	Michigan	6011445983601402795	4cf26bad2aa3eb0ce0ed6666a900abd9	Voyager	42.3215696143377613	-83.1445797714523991
41690	2020-08-01 21:38:06	2020-08-01	Callie Gusikowski-Schaefer	callie.gusikowski.schaefer@woohoo.com	Berkeley	California	4246915943400	5d339c07903fa279f58d57188b9e59c7	Discover	37.8372514786802867	-122.240209670018615
41691	2020-08-01 21:49:51	2020-08-01	Mr. Nicklaus Ward II	mr.nicklaus.ward.ii@geemail.com	Houston	Texas	53728060076048052	2eda283c6d91431624b4f4d2b2996aed	VISA 16 digit	29.8597001901440322	-95.4060154001709151
41692	2020-08-01 21:52:59	2020-08-01	Baron Tremblay-Yost	baron.tremblay.yost@geemail.com	Berkeley	California	55418559570147372	49bbe55516fb17686b22aaad69b5a23a	Maestro	37.8444553496129004	-122.282150568629177
41693	2020-08-01 21:55:06	2020-08-01	Mrs. Shalon Runte	mrs.shalon.runte@geemail.com	Huntsville	Alabama	4249563526937139	56ce292dcdcf77f8dbc0121fe4e9222f	VISA 16 digit	34.7242668316010352	-86.6193051523082005
41694	2020-08-01 22:01:27	2020-08-01	Marie Bechtelar	marie.bechtelar@geemail.com	New York	New York	3755550240518827	002585436819da39a6377546f336241c	Mastercard	40.6555777088962458	-73.9853564003843758
41695	2020-08-01 22:04:01	2020-08-01	Shane Murphy	shane.murphy@geemail.com	Charlotte	North Carolina	180020290019443269	fb8184397c782f49ded338692b7b489c	VISA 13 digit	35.2290126940023143	-80.8065442343652336
41696	2020-08-01 22:07:15	2020-08-01	Ms. Chandra Olson DVM	ms.chandra.olson.dvm@woohoo.com	New York	New York	3112571163272552709	4fd3e0e327615cb3b2514a6ea417016c	VISA 16 digit	40.7086648623682521	-73.9459905746754202
41697	2020-08-01 22:12:21	2020-08-01	Sienna Rodriguez MD	sienna.rodriguez.md@geemail.com	Fontana	California	4628623201235398	9a76be51ec99cb19bcdf66ce914119ce	Maestro	34.1153928747083981	-117.504144391817604
41698	2020-08-01 22:13:59	2020-08-01	Rob Bartoletti-Beer	rob.bartoletti.beer@warmmail.com	San Francisco	California	3337033018637232912	b9084174276e09eadeb74f22aa92ead5	American Express	37.7658168089836153	-122.420442655291097
41699	2020-08-01 22:14:35	2020-08-01	Yaretzi Gerlach	yaretzi.gerlach@geemail.com	Chandler	Arizona	3337465214897615329	85ea052a8e50d0e32206dff10c7bd985	American Express	33.3350267783828045	-111.929746854945648
41700	2020-08-01 22:16:26	2020-08-01	Earlie Will	earlie.will@geemail.com	San Francisco	California	4968165264787087	55ed121d1701433f574a621b60e45b44	Mastercard	37.7520830778008758	-122.433336466592493
41701	2020-08-01 22:17:38	2020-08-01	Almon McDermott Jr.	almon.mcdermott.jr.@geemail.com	New York	New York	3096672451809999735	6f7abd35f38f361241f7e929469e22d9	VISA 16 digit	40.6167734137494136	-73.947007392988354
41702	2020-08-01 22:35:13	2020-08-01	Allyn Okuneva	allyn.okuneva@geemail.com	Lexington	Kentucky	869969563273721022	b9c640d626bb4fe40a2b73742db3da4f	VISA 16 digit	37.9825889133259693	-84.4274567869391177
41703	2020-08-01 22:40:55	2020-08-01	Nicky Bailey	nicky.bailey@geemail.com	West Palm Beach	Florida	3096508128575143207	2cd4c1cc34f3a8ced663c2eb1d928d12	JCB 15 digit	26.7828460184704511	-80.1700988477863348
41704	2020-08-01 22:42:20	2020-08-01	Kim Torphy-Bradtke	kim.torphy.bradtke@woohoo.com	Milwaukee	Wisconsin	3088058015939030689	d52fc23ed59e851ed11874a50764dc53	VISA 16 digit	43.0225822053004023	-88.0083065658908339
41705	2020-08-01 22:44:56	2020-08-01	Laurette Hills	laurette.hills@warmmail.com	Austin	Texas	52342020391279325	ba85d88e3ec53ba354cf0db7f860041f	VISA 13 digit	30.2287710960149738	-97.7513442130066466
41706	2020-08-01 23:01:21	2020-08-01	Dr. Orvin Oberbrunner V	dr.orvin.oberbrunner.v@geemail.com	San Francisco	California	4247379417147	b1e77e8523247a14e16d96073f42a9de	Mastercard	37.7745952038945916	-122.450224138344439
41707	2020-08-01 23:08:59	2020-08-01	Alfred Walsh	alfred.walsh@geemail.com	Berkeley	California	51550898587090029	cae346ede682a229e1cc7fa3cb7fa7a1	VISA 13 digit	37.8821383994566645	-122.255238726835159
41708	2020-08-01 23:09:13	2020-08-01	Dr. Jaelynn Hand PhD	dr.jaelynn.hand.phd@warmmail.com	Omaha	Nebraska	869998085623342965	74d061bf113de4b5f075220b0b997be5	Discover	41.2557243687246	-96.0660189315792223
41709	2020-08-01 23:23:36	2020-08-01	Amina Crist	amina.crist@geemail.com	Eugene	Oregon	3528483121575733662	518000eca87dc091905382b8478def69	Maestro	44.1032102153830223	-123.067191922523833
41710	2020-08-01 23:27:00	2020-08-01	Lela Shields DVM	lela.shields.dvm@warmmail.com	Fort Worth	Texas	180078265556398499	cd7ac144c53ee50f72460a222906ff1a	American Express	32.8576638546828192	-97.3199953111175375
41711	2020-08-01 23:32:13	2020-08-01	Lloyd O'Reilly	lloyd.o'reilly@geemail.com	Berkeley	California	180063426729414103	81e49cba23f1318020e7319f4b58f412	VISA 16 digit	37.8564682018047662	-122.285365963077879
41712	2020-08-01 23:32:25	2020-08-01	Tinie O'Reilly	tinie.o'reilly@geemail.com	San Antonio	Texas	4403959987456589	d11cb3483c93b19b0f41bf6935050c08	JCB 15 digit	29.4826182626724247	-98.4341542279183841
41713	2020-08-01 23:34:12	2020-08-01	Hugh Lehner	hugh.lehner@woohoo.com	Chicago	Illinois	52377165419401225	1186c4a2013426b4c81b3b90473d42b6	JCB 15 digit	41.7575365755543118	-87.6583207669231967
41714	2020-08-01 23:36:41	2020-08-01	Taurean Kuhlman	taurean.kuhlman@geemail.com	Dallas	Texas	3096653223705719514	1ddc3b046ec862b3a4c676c03cd279e9	American Express	32.859972269254925	-96.7558202431965526
41715	2020-08-01 23:55:05	2020-08-01	Delle Parisian	delle.parisian@geemail.com	Santa Ana	California	060413311884939	2cb2c52a4e4c7044b68fce740a06dae0	VISA 16 digit	33.7008979766268268	-117.926617911124595
41716	2020-08-01 23:59:47	2020-08-01	Ami Mosciski	ami.mosciski@geemail.com	New York	New York	3088310225822596290	421ab50995ec7c3f42ec4fc23a38f274	JCB 16 digit	40.6971126046720855	-73.8560356660176041
41717	2020-08-02 00:03:21	2020-08-02	Dr. Rolland Schuppe Sr.	dr.rolland.schuppe.sr.@woohoo.com	Indianapolis	Indiana	3158022797252204891	40595b70106009050db8ad3c9c5f47cf	VISA 16 digit	39.8571566581267831	-86.1041160966936445
41718	2020-08-02 00:03:36	2020-08-02	Dr. Tessa Keebler DDS	dr.tessa.keebler.dds@warmmail.com	San Francisco	California	3718856676851749	760ba68c27f6346891c2c75f0639e1a0	Voyager	37.7550761410398721	-122.386924911440957
41719	2020-08-02 00:03:59	2020-08-02	Dr. Mallie Skiles DDS	dr.mallie.skiles.dds@geemail.com	Milwaukee	Wisconsin	4508661239904341	e4a3d15df41d3f16d4a1ec05e0419947	Mastercard	42.9968532476659817	-88.0630117262814167
41720	2020-08-02 00:18:45	2020-08-02	Reginal Brakus Sr.	reginal.brakus.sr.@warmmail.com	San Francisco	California	630452335822152	858922c5eb08045f3bbe709173f8bb14	American Express	37.8051000184435608	-122.419918783432053
41721	2020-08-02 00:20:03	2020-08-02	Caprice Schmitt PhD	caprice.schmitt.phd@geemail.com	Omaha	Nebraska	4181111888928211	c237083ad8e78069ee52c2c2c18fcfd1	VISA 16 digit	41.2381085574306567	-96.0084548378944476
41722	2020-08-02 00:22:17	2020-08-02	Brianne Roob	brianne.roob@geemail.com	New York	New York	4272826948015	f72bd194843de941940af6ce9fc3e544	Mastercard	40.7353737883027662	-73.932007733116663
41723	2020-08-02 00:23:04	2020-08-02	Ayaan Farrell I	ayaan.farrell.i@geemail.com	Chandler	Arizona	3112945884546878567	d5518cc3270ee09707a0ea870ef9d711	JCB 15 digit	33.3504794511567795	-111.900669244804973
41724	2020-08-02 00:26:14	2020-08-02	Mr. Cris Rogahn I	mr.cris.rogahn.i@geemail.com	Indianapolis	Indiana	4578185055439740	b0aaa646de0828de8ba25a616817e190	JCB 16 digit	39.8763355938725184	-86.1774715604461647
41725	2020-08-02 00:28:31	2020-08-02	Gust Schneider	gust.schneider@woohoo.com	Los Angeles	California	676153094751004	1fc81e18a4b92aed6304d2bdcb3af264	Mastercard	34.0939200703386192	-118.424648014408717
41726	2020-08-02 00:32:15	2020-08-02	Donaciano Mraz	donaciano.mraz@geemail.com	Baton Rouge	Louisiana	6011179989861685773	ce70dbef43daf3c84e483cbaa80d21fa	Maestro	30.4791939197786164	-91.0400248821932792
41727	2020-08-02 00:37:46	2020-08-02	Braylon Langosh Sr.	braylon.langosh.sr.@geemail.com	Charlotte	North Carolina	3001067099483396	001790a74ed8f0ce28d74a5015126c4e	American Express	35.128921068671346	-80.8658451394587843
41728	2020-08-02 00:42:13	2020-08-02	Angela Torphy-Schmeler	angela.torphy.schmeler@warmmail.com	Omaha	Nebraska	6011011577244774059	0967123c3bea1d93a85cef2401ae5fa1	Diners Club / Carte Blanche	41.3477997546229545	-96.0187867975443652
41729	2020-08-02 00:56:05	2020-08-02	Ira Swift	ira.swift@geemail.com	San Francisco	California	3770341769348395	657141f4550f241cd4ec7911ed684e51	Discover	37.7354237175734255	-122.440898394043145
41730	2020-08-02 01:01:44	2020-08-02	Ossie Wunsch II	ossie.wunsch.ii@woohoo.com	Fairfield	California	55422852445659380	50a1bf146fba0f332d34e7e675220fd7	Discover	38.2275884757407027	-122.043663033936539
41731	2020-08-02 01:16:34	2020-08-02	Dr. Leeroy Crist	dr.leeroy.crist@geemail.com	Gresham	Oregon	4075624725685298	70fd78101598a658f640f6ed7f00222a	American Express	45.5389014794446538	-122.504737482060108
41732	2020-08-02 01:19:40	2020-08-02	Osie Gaylord	osie.gaylord@warmmail.com	Houston	Texas	3112837440648348198	c05954b6237f6f5a917a595f774b9917	JCB 16 digit	29.724533278735727	-95.3390316476594677
41733	2020-08-02 01:24:18	2020-08-02	Santos Pacocha-Rosenbaum	santos.pacocha.rosenbaum@geemail.com	El Paso	Texas	180068044158641651	fa12b96152f8b7c606e496f69c9c4cce	Voyager	31.8200421839781136	-106.432807102750999
41734	2020-08-02 01:26:56	2020-08-02	Dr. Baxter Wisoky	dr.baxter.wisoky@geemail.com	Chula Vista	California	3088451247765143707	d1a19cde6cd5647d7820923e707787a1	Discover	32.7265144060596782	-117.086169993434837
41735	2020-08-02 01:31:37	2020-08-02	Janene DuBuque-Moen	janene.dubuque.moen@geemail.com	San Antonio	Texas	869912666729918965	56db80bd7ab5ddc0d1f441fd90add6e4	Discover	29.5252996850829561	-98.5369273221421906
41736	2020-08-02 01:32:01	2020-08-02	Mame Gibson	mame.gibson@woohoo.com	Lancaster	California	4094364722021174	033ced843fc50a261e9aae9f5f5162ad	VISA 13 digit	34.6789423929773335	-118.207352201917388
41737	2020-08-02 01:40:35	2020-08-02	Dr. Deangelo Effertz	dr.deangelo.effertz@geemail.com	Jacksonville	Florida	4120553426730902	7f413eb689437138d9e50ac90e8998fb	Diners Club / Carte Blanche	30.2781958478555069	-81.7137063313353877
41738	2020-08-02 02:10:46	2020-08-02	Dedrick Mraz	dedrick.mraz@woohoo.com	Sioux Falls	South Dakota	869917742705374385	7edface2bf76f25abb7e1607ea85f6eb	Voyager	43.6332625781271588	-96.7541230803988839
41739	2020-08-02 02:20:48	2020-08-02	Ashby Wilderman	ashby.wilderman@geemail.com	Dallas	Texas	3472956785237898	9760e5964945bd52db53b7d24470dae1	American Express	32.8432687800649603	-96.8081074120905214
41740	2020-08-02 02:21:22	2020-08-02	Lorrie Jacobs-Gorczany	lorrie.jacobs.gorczany@geemail.com	Atlanta	Georgia	6011329891358660534	1f495ef5918f37f52c552021716cf531	Discover	33.7497906929623355	-84.432457046727464
41741	2020-08-02 02:21:53	2020-08-02	Consuelo Skiles	consuelo.skiles@geemail.com	San Francisco	California	3056834918142627	ecf4adbba78e737ab17b38a95bcd4c14	American Express	37.7600758865263657	-122.44330359858337
41742	2020-08-02 02:24:00	2020-08-02	Jeramiah Effertz	jeramiah.effertz@geemail.com	Houston	Texas	6011226813121438232	b141858c5bf2c14f0868099b510d57c5	Diners Club / Carte Blanche	29.8751357746854431	-95.4693234313759973
41743	2020-08-02 02:25:49	2020-08-02	Shanda Sipes	shanda.sipes@geemail.com	Tallahassee	Florida	3112888563782786143	366e938ad820e7d23f19776cb2da95f3	VISA 13 digit	30.4385003834985213	-84.3378311780761862
41744	2020-08-02 02:26:03	2020-08-02	Electa Konopelski	electa.konopelski@geemail.com	Newport News	Virginia	4014663877187376	70b2d07d69e7744fbb1bd0bbcc281e9b	VISA 13 digit	37.1740408136870712	-76.4809359285309966
41745	2020-08-02 02:26:22	2020-08-02	Milo Morissette	milo.morissette@geemail.com	Los Angeles	California	3039037674219707	91279f4277de6b0393ab2897cebbeb4d	VISA 16 digit	34.0938708459824298	-118.485243545332168
41746	2020-08-02 02:29:52	2020-08-02	Dr. Steven Funk DVM	dr.steven.funk.dvm@geemail.com	San Francisco	California	4292243165200760	c1e6f0dd8d87d4510fc02008d9694450	JCB 16 digit	37.7777991256559673	-122.442730559469965
41747	2020-08-02 02:40:36	2020-08-02	Dannielle Grant	dannielle.grant@geemail.com	San Francisco	California	4657293329600	31fdaf67155dc2e480d789be0f56afd6	Diners Club / Carte Blanche	37.7733183847494374	-122.462140149421515
41748	2020-08-02 02:50:30	2020-08-02	Britta Cronin	britta.cronin@geemail.com	Wilmington	North Carolina	3158741794108821192	7026de80b10e7dfb781ee42b61cfbb7c	Mastercard	34.3051987530950484	-77.8120324521783715
41749	2020-08-02 02:53:22	2020-08-02	Elonzo Halvorson	elonzo.halvorson@geemail.com	Killeen	Texas	3495694716473307	e0ea9f72dfb2de5b65e051fea5dd5cb6	Mastercard	31.0693307093109929	-97.7357393053527943
41750	2020-08-02 02:53:34	2020-08-02	Miss Zandra Langosh PhD	miss.zandra.langosh.phd@geemail.com	Montgomery	Alabama	53187874336586576	667e2014796d7b812338d5bb706f17cb	Maestro	32.3230573601488018	-86.3372691026110175
41751	2020-08-02 02:59:54	2020-08-02	Mrs. Kellie Champlin	mrs.kellie.champlin@geemail.com	Gainesville	Florida	3088209739587373491	fe14a7aeb11f15cc5441c158f9813b29	VISA 16 digit	29.6917039000719782	-82.2471479555931069
41752	2020-08-02 03:01:16	2020-08-02	Taurus Konopelski	taurus.konopelski@woohoo.com	New York	New York	51418105781629707	17535b4b8d9817d8fddab19bf079d8d8	Voyager	40.7566772277690461	-73.9803156109422417
41753	2020-08-02 03:01:54	2020-08-02	Luvinia Ankunding	luvinia.ankunding@geemail.com	San Francisco	California	4348204729716513	8304973aa70a813753bbf4ea5a2a0dc5	JCB 16 digit	37.8107511358058517	-122.395289050674933
41754	2020-08-02 03:12:57	2020-08-02	Elmyra Zieme-Bernhard	elmyra.zieme.bernhard@warmmail.com	Berkeley	California	869935941649623141	981fc504586bda14fb9b15a2c0f5a60a	Maestro	37.8548178982593555	-122.258859069487656
41755	2020-08-02 03:31:23	2020-08-02	Erline Purdy	erline.purdy@geemail.com	Nashville	Tennessee	3528250698098129370	983bb9b8158e7089d13760967f20cc38	JCB 16 digit	36.2286114415276757	-86.726107380343592
41756	2020-08-02 03:33:35	2020-08-02	Melissa Cormier	melissa.cormier@woohoo.com	New York	New York	4976340113995484	701eadd4c33938e0662ae688f4170831	Diners Club / Carte Blanche	40.6734768379703127	-74.0253756315808715
41757	2020-08-02 03:33:46	2020-08-02	Karyme Kassulke	karyme.kassulke@geemail.com	Houston	Texas	4739540901363	4f435e77d4fbc5b2285d20bc2131484c	JCB 16 digit	29.7400614441916353	-95.4405078102383726
41758	2020-08-02 03:38:11	2020-08-02	Loren Moen III	loren.moen.iii@woohoo.com	Orange	California	3466742898342017	306b37406b05282a75869f202ba88392	VISA 16 digit	33.6974255204554609	-117.799096474713835
41759	2020-08-02 03:46:30	2020-08-02	Marquise Welch	marquise.welch@geemail.com	Sacramento	California	3038167342368577	f9caf1c672753da482467556b33a1e1a	Diners Club / Carte Blanche	38.5077234805360433	-121.388895652188353
41760	2020-08-02 04:01:16	2020-08-02	Mrs. Meggan Schuppe DDS	mrs.meggan.schuppe.dds@geemail.com	New York	New York	6011246251871668243	aefb159748cf3daabc2c7ba6781b0117	Diners Club / Carte Blanche	40.761899259336289	-73.9310327319789593
41761	2020-08-02 04:02:45	2020-08-02	Cherie Gerhold	cherie.gerhold@geemail.com	Arlington	Texas	502044866178385	ae63eb17175e4388fc1a5b49de9d4dda	Mastercard	32.799072044367712	-97.106109967830406
41762	2020-08-02 04:12:39	2020-08-02	Mr. Wilfred Wilderman	mr.wilfred.wilderman@geemail.com	San Francisco	California	3028429506528986	497374e60a4d36e2c4d0695594627aab	JCB 16 digit	37.7576838107998896	-122.422471195800981
41763	2020-08-02 04:30:41	2020-08-02	Glenna Lesch	glenna.lesch@geemail.com	Philadelphia	Pennsylvania	3455984678459842	a395970df69950450ac8f64e73df79bd	American Express	39.9722769950941199	-75.1255624917235281
41764	2020-08-02 04:43:13	2020-08-02	Dr. Billy Stoltenberg Jr.	dr.billy.stoltenberg.jr.@geemail.com	Chicago	Illinois	3457796824559665	1407c3ec0fda3ca5710da7efec58df9a	JCB 16 digit	41.8296116823166599	-87.6725167440745992
41765	2020-08-02 04:44:02	2020-08-02	Mr. Jordon Bode	mr.jordon.bode@geemail.com	San Francisco	California	180089279248524674	17890efc4f24dc47769f0dd9b539c1b1	Maestro	37.7367189175220972	-122.399231509226226
41766	2020-08-02 04:44:20	2020-08-02	Benedict Berge-Ernser	benedict.berge.ernser@woohoo.com	Mobile	Alabama	503859652457066	ae25ac3e3cfd88c25307c22f9101dfa2	JCB 16 digit	30.7246498644459969	-88.0303541921217061
41767	2020-08-02 04:49:40	2020-08-02	Joel Trantow	joel.trantow@geemail.com	Stockton	California	210097088869363266	914e8f6ede1244d8f8db357603f5bf88	JCB 16 digit	38.0458243006572161	-121.397037006923185
41768	2020-08-02 04:55:33	2020-08-02	Ozell Kub V	ozell.kub.v@warmmail.com	Oakland	California	6011185936719169130	4f926e76f7671af2a19e2ba9df898940	VISA 16 digit	37.7991538011020012	-122.280425711442234
41769	2020-08-02 04:56:19	2020-08-02	Ernesto Runte	ernesto.runte@warmmail.com	San Francisco	California	3006401056249604	01d402283db281162cd41fd06ba317b6	Mastercard	37.7481008795977715	-122.429327609567864
41770	2020-08-02 05:06:39	2020-08-02	Alvera Rau	alvera.rau@geemail.com	Corona	California	180021604986282949	e6408f247e3b5f7376391a32ad3cc736	JCB 16 digit	33.777336355753242	-117.633992985190829
41771	2020-08-02 05:15:04	2020-08-02	Erby Hauck	erby.hauck@geemail.com	San Antonio	Texas	3436223404934065	f229db5c46bb3f93860d58b14b24778c	Diners Club / Carte Blanche	29.5372359749466185	-98.5036066918004281
41772	2020-08-02 05:29:49	2020-08-02	Miller Marks	miller.marks@woohoo.com	Berkeley	California	869900315624715753	c29a956595a2437ac765d476c698abe5	VISA 16 digit	37.9003418306040984	-122.254137956712754
41773	2020-08-02 05:33:10	2020-08-02	Kerwin Bergnaum	kerwin.bergnaum@geemail.com	Tucson	Arizona	869987093251307568	bbea1215031236898751f8fb3fa1684e	Diners Club / Carte Blanche	32.2069646305911235	-110.875840356735878
41774	2020-08-02 05:44:54	2020-08-02	Angeles Paucek	angeles.paucek@woohoo.com	New York	New York	869999349836627979	94cb004e78d9f579b4bd2fde30a706c8	VISA 13 digit	40.6037449922170453	-74.0156284853711668
41775	2020-08-02 05:49:06	2020-08-02	Joslyn Spinka	joslyn.spinka@woohoo.com	Houston	Texas	3005011344222023	28d16cf7050375a60aa0fc9a5ed92909	Discover	29.8391611009448781	-95.4807384807165676
41776	2020-08-02 05:54:54	2020-08-02	Alvera Schimmel	alvera.schimmel@geemail.com	Charlotte	North Carolina	6011316089832967618	716ec7ae0fdbefae937f31910eda44ba	Maestro	35.1989050392780456	-80.9022040506769002
41777	2020-08-02 05:56:00	2020-08-02	Dr. Aaron Wolf	dr.aaron.wolf@geemail.com	San Francisco	California	3337187002959580888	4651ec29f80e4227c475fb060775ecde	VISA 13 digit	37.7330879880068437	-122.440961617620601
41778	2020-08-02 06:04:12	2020-08-02	Mr. Kelvin Mueller I	mr.kelvin.mueller.i@geemail.com	Denver	Colorado	6011537675055645262	41d8d4ac3c028738245622dc52fbd1e1	American Express	39.8588764206092776	-104.903602605011685
41779	2020-08-02 06:12:07	2020-08-02	Halsey Herman	halsey.herman@geemail.com	Dallas	Texas	630499360724027	8d89cc350db90c13a8f83bfa12fa3dd8	Voyager	32.7755269801516107	-96.769521626081314
41780	2020-08-02 06:14:40	2020-08-02	Campbell Kutch MD	campbell.kutch.md@geemail.com	Memphis	Tennessee	869978950782587094	43fa8933bc71cd52a2156885281a04b7	JCB 16 digit	35.0385098576147129	-90.0568233954511612
41781	2020-08-02 06:15:54	2020-08-02	Ebb Jaskolski	ebb.jaskolski@woohoo.com	Wichita	Kansas	869914339846581755	f4935e58b4b7fa01b11c9d6688c6dd72	Voyager	37.7279651946730894	-97.3925540238354301
41782	2020-08-02 06:16:14	2020-08-02	Holly Hickle	holly.hickle@geemail.com	Thousand Oaks	California	3029700028388383	88d88522499da42d0541c3e65b319702	VISA 16 digit	34.1967422014374307	-118.881951809107136
41783	2020-08-02 06:16:56	2020-08-02	Dr. Levern Keeling	dr.levern.keeling@geemail.com	Moreno Valley	California	4440932595752	9108053140251bc0812e59e895019cd0	Diners Club / Carte Blanche	33.9795037651892713	-117.231345175483071
41784	2020-08-02 06:19:19	2020-08-02	Mrs. Ivey Yundt	mrs.ivey.yundt@geemail.com	Cape Coral	Florida	639091328079537	320c4a7f91374b1b7484ab1c0f1ddf12	Discover	26.5829323442157346	-82.0258414812922467
41785	2020-08-02 06:22:57	2020-08-02	Araminta Kshlerin	araminta.kshlerin@geemail.com	Long Beach	California	503825354617281	1f677c257d5d1b6deb78160026f14058	VISA 16 digit	33.9010601570185273	-118.172891287288806
41786	2020-08-02 06:23:35	2020-08-02	Dr. Marget Yost	dr.marget.yost@warmmail.com	Raleigh	North Carolina	503868362850866	782c420bb2878f2cb4fbd27adf669c32	JCB 16 digit	35.7396580802876471	-78.6037248910341475
41787	2020-08-02 06:25:14	2020-08-02	Miss Loriann Wyman MD	miss.loriann.wyman.md@warmmail.com	Hampton	Virginia	3450027795571688	f4398b843c235255933f768899fe846d	JCB 16 digit	36.9831790850982074	-76.3866285549573547
41788	2020-08-02 06:28:12	2020-08-02	Roosevelt Ledner	roosevelt.ledner@woohoo.com	Odessa	Texas	3709234216689360	ed50b366c1c17f4d7ed87a3536fab7f9	VISA 16 digit	31.9739074586901815	-102.421730699312306
41789	2020-08-02 06:37:53	2020-08-02	Dr. Cordero Littel PhD	dr.cordero.littel.phd@geemail.com	Houston	Texas	3337948105659589552	67b5bf46096f7449c36c97e04ef4aba1	JCB 15 digit	29.8758197318840786	-95.3077752036523123
41790	2020-08-02 06:38:16	2020-08-02	Brady Sauer-Feest	brady.sauer.feest@geemail.com	Orlando	Florida	52394785881536528	cdb21da2a1830147ad46dc52050e733f	VISA 13 digit	28.4088846713569012	-81.1763496444061445
41791	2020-08-02 06:39:45	2020-08-02	Hezekiah Denesik	hezekiah.denesik@woohoo.com	Beaumont	Texas	4487253168370	ea0dce11e5a9c58846a6a098b12aa2cf	Voyager	30.0954485788546506	-94.2420057405039699
41792	2020-08-02 06:40:43	2020-08-02	Yoselin Mayert PhD	yoselin.mayert.phd@geemail.com	Chicago	Illinois	4837067634548	7f092edd0e7f33933827c9d82b6971d2	Discover	41.8817753934603232	-87.6879074283905311
41793	2020-08-02 07:12:38	2020-08-02	Kraig Mayer-Bailey	kraig.mayer.bailey@geemail.com	Houston	Texas	210059872222269138	d47ec7c8fc1c88ad80149be9482915b3	JCB 16 digit	29.8261868627820164	-95.3107484567925383
41794	2020-08-02 07:12:47	2020-08-02	Octavia Ankunding PhD	octavia.ankunding.phd@geemail.com	Louisville	Kentucky	6011476339907106832	dc57fd6a18fe0d01beb11751fd49dca2	JCB 16 digit	38.0725923629846434	-85.63419744936526
41795	2020-08-02 07:16:41	2020-08-02	Dr. Armin Lemke	dr.armin.lemke@geemail.com	Charlotte	North Carolina	51392960035526384	57a7ad7c57d51b34c3bf9299fad3eea2	JCB 16 digit	35.2585330245804016	-80.7471430887412254
41796	2020-08-02 07:24:32	2020-08-02	Miss Ressie Runte DVM	miss.ressie.runte.dvm@geemail.com	Durham	North Carolina	6011526858350906182	8c6d23af462b9e769125b1e1c5711259	Maestro	36.0618277377229148	-78.8366499692104838
41797	2020-08-02 07:29:59	2020-08-02	Tavaris Lang	tavaris.lang@geemail.com	Oakland	California	4390192653451982	055c35c6a210794ab5c3f6b6bff301f7	VISA 16 digit	37.7914552260034711	-122.261370027500931
41798	2020-08-02 07:45:07	2020-08-02	Dian Kovacek	dian.kovacek@geemail.com	Palm Bay	Florida	869913058007491841	0ce44cd0aa838a75aaaf42422fb47ba2	JCB 15 digit	28.0033188650239282	-80.6303630747202789
41799	2020-08-02 07:49:59	2020-08-02	Brad Stoltenberg	brad.stoltenberg@geemail.com	Wilmington	North Carolina	6011587201153801878	a1c9f849faa4f4910ea0fc29888612c0	American Express	34.300695743440464	-77.9276534071650389
41800	2020-08-02 08:02:36	2020-08-02	Love Prosacco	love.prosacco@geemail.com	New York	New York	4605049159011101	50f92ec5b66152af6235c4f93df32bb3	Maestro	40.6626923475172362	-73.9485662491887723
41801	2020-08-02 08:07:38	2020-08-02	Evander Casper I	evander.casper.i@geemail.com	Salt Lake City	Utah	4552657376227103	1c5555eeaa29665db8aebd15066f9cea	Diners Club / Carte Blanche	40.7423839087743289	-112.00410566622763
41802	2020-08-02 08:13:24	2020-08-02	Dr. Josefa Senger	dr.josefa.senger@woohoo.com	Long Beach	California	52796041546077233	3a8705a14ca3c00aadc925f0ef736338	Mastercard	33.7232942652244105	-118.209306040841341
41803	2020-08-02 08:13:54	2020-08-02	Chance Hickle	chance.hickle@woohoo.com	Washington	District of Columbia	6011108165363001811	67cf82770b574b0b235c16b1fc6a985a	Diners Club / Carte Blanche	38.8736924840401841	-76.9990040867336063
41804	2020-08-02 08:17:34	2020-08-02	Mrs. Nolie Kohler	mrs.nolie.kohler@woohoo.com	Pueblo	Colorado	3435563530906938	36e43c8a0ac082a9e2aeb96c7a048b9c	Diners Club / Carte Blanche	38.2933568780753788	-104.640148902018751
41805	2020-08-02 08:20:54	2020-08-02	Rahn Larkin	rahn.larkin@warmmail.com	Los Angeles	California	503812700131563	23837ccac1686f9f5af1b2bc8efeeec6	Diners Club / Carte Blanche	34.0573075013101061	-118.315569293637935
41806	2020-08-02 08:28:46	2020-08-02	Ms. Trula Gottlieb	ms.trula.gottlieb@geemail.com	San Jose	California	3096029086751379187	8b8ba5a4fd206454d14d49f2781b7595	Diners Club / Carte Blanche	37.3124505880109965	-121.899927255346995
41807	2020-08-02 08:44:17	2020-08-02	Miss Lucretia Bechtelar DVM	miss.lucretia.bechtelar.dvm@woohoo.com	Los Angeles	California	3096672973891072691	7666291521b00ec04b0675c8ee4cec1d	JCB 16 digit	34.0581035484891359	-118.391494697890423
41808	2020-08-02 08:45:30	2020-08-02	Sandy Schmeler-Grant	sandy.schmeler.grant@geemail.com	Colorado Springs	Colorado	869997738424318979	48c3806ad58cd64f083c15c88e3f6bc4	Diners Club / Carte Blanche	38.8917968115352082	-104.852856522441655
41809	2020-08-02 08:49:12	2020-08-02	Dr. Ronin Boyer II	dr.ronin.boyer.ii@geemail.com	Mesa	Arizona	4562281195960444	50c822d05aab22176e453ae6fa301bbb	American Express	33.4237706527724825	-111.745635407918684
41810	2020-08-02 08:52:59	2020-08-02	Bob Rowe	bob.rowe@geemail.com	Kansas City	Kansas	3433731271911746	3c6f7838ec1b260ca52b4df3f74093f5	Mastercard	39.1915264705102899	-94.6478809500049749
41811	2020-08-02 08:54:31	2020-08-02	Ryker Dicki	ryker.dicki@woohoo.com	Minneapolis	Minnesota	3112404619626555733	ce810f8d76d9f5b05af24a8dca4eaf01	Maestro	45.007061469190937	-93.3572110734220502
41812	2020-08-02 08:54:42	2020-08-02	Tammie Kohler MD	tammie.kohler.md@geemail.com	San Francisco	California	4054205780604401	1bc241b850a631ef8c0460db4ec08e26	JCB 16 digit	37.758410180392481	-122.420909246412677
41813	2020-08-02 09:02:39	2020-08-02	Ananias Veum	ananias.veum@geemail.com	North Charleston	South Carolina	3493176862894470	3d18a35409f28a8d6b73a34c69f6cf33	Discover	32.9372466938730355	-80.0631378463096866
41814	2020-08-02 09:12:59	2020-08-02	Dema Treutel	dema.treutel@geemail.com	San Francisco	California	6011891672166320562	2ee46163ccd87f403d8fd2e550ecd3bc	VISA 13 digit	37.8055236940209269	-122.426064938982748
41815	2020-08-02 09:14:41	2020-08-02	Ms. Ebony Kuvalis PhD	ms.ebony.kuvalis.phd@geemail.com	Dayton	Ohio	4190186568727314	b4181210e94d24296d4088d558c20d34	Mastercard	39.8511180075608209	-84.1249332029096877
41816	2020-08-02 09:18:01	2020-08-02	Benita Mante	benita.mante@geemail.com	Carlsbad	California	55020847684526080	e499838c5bba734aab7a841ed67ba001	Diners Club / Carte Blanche	33.1447935428876406	-117.36841169286258
41817	2020-08-02 09:19:04	2020-08-02	Foster Lang	foster.lang@geemail.com	McKinney	Texas	4090016307119	fcc594180ab637bdd9badedec516c186	VISA 13 digit	33.201436389716342	-96.5771670372989064
41818	2020-08-02 09:19:33	2020-08-02	Carly Braun	carly.braun@geemail.com	Nashville	Tennessee	3446222810859609	31a0c01c05c8260f390a515b2d55097f	JCB 15 digit	36.2366355699144265	-86.6914227554015753
41819	2020-08-02 09:20:20	2020-08-02	Stephaine Pfeffer	stephaine.pfeffer@geemail.com	Syracuse	New York	3088578679136234559	9da9b27f5777f022d8628a149a51d8f0	Diners Club / Carte Blanche	43.0260053280591919	-76.0530038255512721
41820	2020-08-02 09:26:26	2020-08-02	Dr. Renard Stark	dr.renard.stark@geemail.com	Augusta	Georgia	4146025615437	fe8153a0d4559ef5636365ef76ab5d7f	Diners Club / Carte Blanche	33.4031865777186994	-82.0477268950376697
41821	2020-08-02 09:27:31	2020-08-02	Valencia Mayert	valencia.mayert@geemail.com	Pembroke Pines	Florida	4947111758661780	b12097fc324da87aa61f5107aa94a098	VISA 13 digit	26.0107289372514927	-80.3953456337466861
41822	2020-08-02 09:29:13	2020-08-02	Mr. Carey Upton II	mr.carey.upton.ii@geemail.com	Pompano Beach	Florida	503841340943947	9f1fdf79b678d229854c82235078cb2b	Diners Club / Carte Blanche	26.2795710442852197	-80.0399221385676327
41823	2020-08-02 09:31:41	2020-08-02	Palma Botsford	palma.botsford@geemail.com	San Diego	California	589337975986094	d3a85c2ff2a489312dc3bd948c40fc3f	American Express	32.800591876969861	-117.209094305001202
41824	2020-08-02 09:31:56	2020-08-02	Annabell Farrell	annabell.farrell@geemail.com	San Francisco	California	4638731314671363	99d3b553cc1843aab74e72cab424778f	Voyager	37.7694897784359114	-122.446215711083084
41825	2020-08-02 09:42:26	2020-08-02	Mrs. Ariella Fadel PhD	mrs.ariella.fadel.phd@warmmail.com	Los Angeles	California	3158022705189625898	f699abe888b8bb9e11ac15afbcf6e59d	Voyager	33.9694402388628518	-118.422162448194996
41826	2020-08-02 09:44:07	2020-08-02	Flavia Williamson DDS	flavia.williamson.dds@geemail.com	El Paso	Texas	3009391176078156	913c5479694ee441358dffbf997f5476	JCB 16 digit	31.9396332717794955	-106.366874457940469
41827	2020-08-02 09:44:07	2020-08-02	Paris Ratke-Jacobs	paris.ratke.jacobs@geemail.com	Phoenix	Arizona	6011561253202486110	08501eac86e90e803c433f13a2edd054	VISA 16 digit	33.484068922924628	-112.040269955566529
41828	2020-08-02 09:45:46	2020-08-02	Freddie Kutch-Bartell	freddie.kutch.bartell@geemail.com	New York	New York	180030966836211785	b09e09caf6b309897ae10ff6f3f0ddc6	Diners Club / Carte Blanche	40.7401846184153129	-73.957985068335006
41829	2020-08-02 10:03:29	2020-08-02	Anissa Dooley	anissa.dooley@geemail.com	New York	New York	3708014271199492	56c9a1b01c18eb0c7ae8bcbeb9990675	JCB 15 digit	40.6610811988115302	-73.8989392856963008
41830	2020-08-02 10:04:00	2020-08-02	Lily Macejkovic	lily.macejkovic@geemail.com	Houston	Texas	55930148955976339	d2eb6530061dbd9bd208119eb83a8170	JCB 15 digit	29.7947403303425773	-95.3580713311225168
41831	2020-08-02 10:07:54	2020-08-02	Nehemiah Schmidt	nehemiah.schmidt@geemail.com	Moreno Valley	California	3482150538762927	ab1d26b3fdd51d957dd5115fcd08a510	JCB 16 digit	33.9194072269361442	-117.257669419466325
41832	2020-08-02 10:10:22	2020-08-02	Sylvanus Hammes-Baumbach	sylvanus.hammes.baumbach@geemail.com	Fayetteville	North Carolina	4564503067022	5bab78473ffb00145346b747c78a3ef1	Diners Club / Carte Blanche	35.1026768507689226	-79.0321252002511159
41833	2020-08-02 10:13:31	2020-08-02	Miss Ernestina Wolff	miss.ernestina.wolff@warmmail.com	Santa Rosa	California	3014297281449395	2fd896c947375262ad531743f037b792	JCB 16 digit	38.4668202638749079	-122.741793486128003
41834	2020-08-02 10:13:48	2020-08-02	Dr. Artelia Hamill MD	dr.artelia.hamill.md@woohoo.com	Orange	California	676394877420839	c3055f1f8d6cd14d9df02421385e6ec5	American Express	33.8768139414843148	-117.954696730348473
41835	2020-08-02 10:26:59	2020-08-02	Ayana Hauck DDS	ayana.hauck.dds@geemail.com	Pasadena	California	3096961956800569261	de54a2877747ae5db0553b346c24aa1c	American Express	34.1274090631254055	-118.188689868692677
41836	2020-08-02 10:30:07	2020-08-02	Ennis Funk III	ennis.funk.iii@geemail.com	Colorado Springs	Colorado	210074168864524463	e8bbda58dd247480bfd776198b9f14f1	Discover	38.843339690151808	-104.774370201366764
41837	2020-08-02 10:30:30	2020-08-02	Franklin Hilpert-Daniel	franklin.hilpert.daniel@woohoo.com	Toledo	Ohio	3158398212478683486	6be8d321a08d3488d08c3c3796cfcf8a	Voyager	41.6815585994798639	-83.6403639073349581
41838	2020-08-02 10:40:40	2020-08-02	Isai Jerde	isai.jerde@geemail.com	New York	New York	3798955157237874	e761e7a1cbe16a1c3c26f8fd40a80234	VISA 16 digit	40.6914467056039726	-73.9572852683149193
41839	2020-08-02 10:41:30	2020-08-02	Avery Turcotte	avery.turcotte@warmmail.com	Oakland	California	3051602973509690	656be305afb6c162e1b40f799df2c5ac	VISA 13 digit	37.8208970702884812	-122.249344032441684
41840	2020-08-02 10:42:20	2020-08-02	Verlyn Connelly	verlyn.connelly@geemail.com	Omaha	Nebraska	3112969052736890237	c27e77dfc9a972a842de8492f8b96414	Voyager	41.3320551888696883	-96.1261395014472413
41841	2020-08-02 10:50:02	2020-08-02	Miss Sannie Dooley	miss.sannie.dooley@woohoo.com	Columbia	Missouri	6011708972427187245	5d4634ff669cea5917b63b358c1c9e9d	JCB 15 digit	38.9795084629089246	-92.346913854783125
41842	2020-08-02 10:51:45	2020-08-02	Julie Konopelski	julie.konopelski@geemail.com	San Francisco	California	3712842484832168	ce33a3e97151cfb7c9ae630d3a8fec82	VISA 13 digit	37.7488745783209225	-122.466056908069646
41843	2020-08-02 11:02:39	2020-08-02	Miss Melany Reinger MD	miss.melany.reinger.md@woohoo.com	Torrance	California	3404577859119409	2f8860b7d3e4c66ec1437d10d1932f51	JCB 16 digit	33.8824111753515922	-118.416604770872368
41844	2020-08-02 11:04:40	2020-08-02	Armand Spencer	armand.spencer@woohoo.com	Tulsa	Oklahoma	180049008771953425	8174756b1e850477bfc24fda35f1b7b0	Mastercard	36.111974928332117	-95.805744849140936
41845	2020-08-02 11:06:46	2020-08-02	Ms. Beatrix Glover PhD	ms.beatrix.glover.phd@warmmail.com	San Francisco	California	180000251384890926	d934c87a73a9132c0541361690434fc5	Discover	37.7736086733157492	-122.387465658971408
41846	2020-08-02 11:10:25	2020-08-02	Hershel Cruickshank DDS	hershel.cruickshank.dds@geemail.com	New York	New York	4024320622041295	739b39e80b0af0e07d31fc3a45804407	VISA 13 digit	40.7106198320388799	-74.0225480482343556
41847	2020-08-02 11:10:46	2020-08-02	Mr. Lonny Schaefer III	mr.lonny.schaefer.iii@geemail.com	Baltimore	Maryland	869985725899673248	de287e1e65c3ec61aa7c422e0b44f4b2	JCB 16 digit	39.3067012940999092	-76.5163338804636197
41848	2020-08-02 11:35:04	2020-08-02	Odette Krajcik	odette.krajcik@geemail.com	San Francisco	California	3435784591707508	514c6d4bfffbf61f1ae4562b01c10cda	American Express	37.7677205385015569	-122.452469656031454
41849	2020-08-02 11:35:52	2020-08-02	Montana Cronin	montana.cronin@geemail.com	Los Angeles	California	4295140045887	cbf6743274493d2b8b50ea06cc052806	Mastercard	34.0105212396807914	-118.316079152095313
41850	2020-08-02 11:39:03	2020-08-02	Mrs. Brett Reinger	mrs.brett.reinger@woohoo.com	Baltimore	Maryland	869901265340572674	f9fa3a599d7a1d163c30b44e98423022	JCB 15 digit	39.3481040228623868	-76.5655104242749474
41851	2020-08-02 11:45:53	2020-08-02	Amie Greenholt-Trantow	amie.greenholt.trantow@geemail.com	Detroit	Michigan	4785718553047760	580842282094fd5b5ce9d15223068526	VISA 13 digit	42.3378275048844515	-83.0076865023586805
41852	2020-08-02 11:59:12	2020-08-02	Ms. China Larson	ms.china.larson@geemail.com	Athens	Georgia	4199320524002	510165570d403d7db058486a47a311a9	JCB 15 digit	33.9658055238615688	-83.4242227656416588
41853	2020-08-02 12:04:20	2020-08-02	Lavern Konopelski	lavern.konopelski@geemail.com	Tacoma	Washington	060489056790234	101bf4c1f3d8e3415d19e7234725d38f	American Express	47.239423913613706	-122.420753517723824
41854	2020-08-02 12:08:20	2020-08-02	Jolette Kiehn	jolette.kiehn@geemail.com	New York	New York	3528515736579681864	f656e650ab634f4b659dacff525f4a85	JCB 15 digit	40.6996096909269696	-73.9022492873843788
41855	2020-08-02 12:09:48	2020-08-02	Dr. Herschel Rutherford	dr.herschel.rutherford@geemail.com	Los Angeles	California	3096065021197249459	223834c53042c0bc671d9f66874ffe64	JCB 15 digit	34.0169903735496106	-118.39437920865528
41856	2020-08-02 12:12:00	2020-08-02	Tea Turner-Quigley	tea.turner.quigley@warmmail.com	Chicago	Illinois	3112817048426736569	86707189395e5f23e6cb6eaa92623aaa	Mastercard	41.7856185400694642	-87.6839281455177826
41857	2020-08-02 12:12:02	2020-08-02	Rose Cronin	rose.cronin@geemail.com	San Diego	California	6011709083749934014	01ad60f002244577cb6497e426fe3d5f	VISA 13 digit	32.7504981666870449	-117.095880520753568
41858	2020-08-02 12:14:48	2020-08-02	Verlyn Frami	verlyn.frami@woohoo.com	Los Angeles	California	502080667857009	6d2c17a0d7020192b23e52cb794cc148	Discover	34.0372061013575617	-118.342413158015532
41859	2020-08-02 12:22:25	2020-08-02	Sena Kling-Friesen	sena.kling.friesen@geemail.com	San Francisco	California	3722158083496828	6a2678e7edfc0d0090b5fdd92bfa87f2	Mastercard	37.7454375207208912	-122.428142087085106
41860	2020-08-02 12:24:25	2020-08-02	Tristian Larkin	tristian.larkin@geemail.com	Berkeley	California	676155620210561	62c12de44260e03eb10cd02c9cd15847	Maestro	37.8748782757742646	-122.265711614319855
41861	2020-08-02 12:34:56	2020-08-02	Mrs. Bridgett Bosco	mrs.bridgett.bosco@woohoo.com	Gresham	Oregon	3096319345172924131	d8066ecd2c7a7ce4563347506c40850a	Discover	45.4381430371154096	-122.411174421923604
41862	2020-08-02 12:36:08	2020-08-02	Delora Bernhard	delora.bernhard@geemail.com	Corona	California	4393283080558965	c006a40079bcaa667153bd00b6e7fbfb	VISA 16 digit	33.9323240192029658	-117.573080833230165
41863	2020-08-02 12:42:32	2020-08-02	Miss Arlene Kilback	miss.arlene.kilback@geemail.com	Oakland	California	4525379103417162	91bd0416acd8ecd7098a939e85894ad9	VISA 13 digit	37.7941218350950621	-122.252821279239015
41864	2020-08-02 12:46:01	2020-08-02	Mr. Preston Wiegand	mr.preston.wiegand@geemail.com	Clarksville	Tennessee	4195699013433937	55efb88bdd6597cc977f807b303ab7d9	JCB 15 digit	36.5604886757802205	-87.3926737219512546
41865	2020-08-02 12:51:55	2020-08-02	Carri Purdy	carri.purdy@geemail.com	Peoria	Arizona	3337075216988338747	8b8f4ae48800987112baa9168fc49b9e	JCB 16 digit	33.7181955278187999	-112.40373627971114
41866	2020-08-02 12:55:45	2020-08-02	Mrs. Cathryn Metz	mrs.cathryn.metz@geemail.com	Los Angeles	California	180064339307745849	093efe30b75a61d2843b53b9a33e6c92	JCB 15 digit	33.9725136214733112	-118.380112888057894
41867	2020-08-02 13:07:56	2020-08-02	Deante Halvorson	deante.halvorson@warmmail.com	Overland Park	Kansas	3029757675230359	d4a35b21b213e8f91b812cfafe043d25	Voyager	38.793591977503155	-94.7718060335651131
41868	2020-08-02 13:11:01	2020-08-02	Brittney Smith	brittney.smith@geemail.com	Fort Lauderdale	Florida	6011542921658216512	0ca543bdaff1e35daa19e4a6a61840d3	VISA 13 digit	26.1824420601118355	-80.1721781146068082
41869	2020-08-02 13:12:14	2020-08-02	Cristobal Orn	cristobal.orn@woohoo.com	Rancho Cucamonga	California	3158901162415686938	18c712659a7e2967ed2640d71c935438	Maestro	34.0563537629313799	-117.481600482483202
41870	2020-08-02 13:13:36	2020-08-02	Mardell Bahringer	mardell.bahringer@woohoo.com	Los Angeles	California	3005103295232356	54616b4f67f3c984c3e47f5ba0f3c572	Maestro	34.0883762509893629	-118.318176574631778
41871	2020-08-02 13:14:59	2020-08-02	Dr. Marnie Gottlieb	dr.marnie.gottlieb@geemail.com	Peoria	Illinois	6011828307416774007	b29ba16730e22d52f17f1bafc1d48ae1	Maestro	40.7959727363996194	-89.7090055083740481
41872	2020-08-02 13:22:19	2020-08-02	Shelton Trantow III	shelton.trantow.iii@geemail.com	Kansas City	Missouri	6011733705235389200	5cf417dd3734d6a6b904425c08cec96c	JCB 16 digit	39.1655780074022744	-94.566287794684996
41873	2020-08-02 13:27:03	2020-08-02	Regan Schneider	regan.schneider@geemail.com	St. Petersburg	Florida	869980760662827775	f270dfd9d8b053bebede856998f46a06	Maestro	27.8216180121880043	-82.7254461178913658
41874	2020-08-02 13:30:51	2020-08-02	Alva Lang	alva.lang@geemail.com	Fresno	California	3406031895128659	846c56786739ced9fa36ef5edd298199	VISA 13 digit	36.7048881697341827	-119.807006098527097
41875	2020-08-02 13:31:22	2020-08-02	Alvah Nitzsche	alvah.nitzsche@geemail.com	Green Bay	Wisconsin	55865409864666836	f1a055c04007ab30945fdc0162181979	JCB 16 digit	44.5338659179925926	-88.0517235737580819
41876	2020-08-02 13:43:47	2020-08-02	Benji Bahringer IV	benji.bahringer.iv@geemail.com	San Francisco	California	869975533427268180	75aed13ae9883e004efa4a0976b4de84	VISA 16 digit	37.8009634592669386	-122.420514906539509
41877	2020-08-02 13:53:23	2020-08-02	Ms. Shira Hoppe	ms.shira.hoppe@geemail.com	New York	New York	3528063099233212279	5271d6d597e00293d4e48f1efd8db9d2	Voyager	40.7001502478253059	-73.9034726680617808
41878	2020-08-02 14:00:22	2020-08-02	Henri Daniel	henri.daniel@geemail.com	Victorville	California	4508478550629	2f515064d7308f169ce138ae63d551dd	VISA 16 digit	34.4867289988555044	-117.36303662924692
41879	2020-08-02 14:09:55	2020-08-02	Antwan Abbott	antwan.abbott@warmmail.com	Seattle	Washington	4758882515015951	3b4bf63386037409abe393d288b80963	Discover	47.5423598166946348	-122.291475735503809
41880	2020-08-02 14:12:33	2020-08-02	Mr. Myrtle Bartoletti	mr.myrtle.bartoletti@geemail.com	Lakewood	Colorado	3337052556926512698	9a3c082df0a8d5d69aa8201a5a70f037	VISA 13 digit	39.7316149282209565	-105.042239453133561
41881	2020-08-02 14:23:23	2020-08-02	Clell Nolan	clell.nolan@warmmail.com	Los Angeles	California	6011055415976111595	28167401aad9719e1e0564ab394f4929	JCB 16 digit	33.9223831239487978	-118.330183489014573
41882	2020-08-02 14:26:12	2020-08-02	Ova Waters DDS	ova.waters.dds@geemail.com	Oklahoma City	Oklahoma	3007994842334374	06798fb8fceed5feab811787774ab61a	VISA 13 digit	35.5593733301296879	-97.5337904911849591
41883	2020-08-02 14:33:20	2020-08-02	Dr. Talmadge Rodriguez III	dr.talmadge.rodriguez.iii@geemail.com	Salem	Oregon	6011581530696565210	e48a43b1a2a0cd75a87208a2493ccffc	VISA 13 digit	44.9951718685019699	-123.03312732564919
41884	2020-08-02 14:35:03	2020-08-02	Boysie Raynor	boysie.raynor@warmmail.com	New York	New York	55495369223456303	504316f6cb764fcfdef33ad35f055fe6	JCB 16 digit	40.571732238516212	-73.9431558200053871
41885	2020-08-02 14:38:10	2020-08-02	Bula Stiedemann	bula.stiedemann@geemail.com	Aurora	Colorado	4744612912715201	d8a7201e07f2c7bdcd5df303ea45b986	American Express	39.6214403432905726	-104.621883899963279
41886	2020-08-02 14:45:04	2020-08-02	Dr. Patric Lockman PhD	dr.patric.lockman.phd@geemail.com	Eugene	Oregon	6011458664665357166	03423392e4c33ace731ca518bc19e277	American Express	44.1392681094545836	-123.186446670814234
41887	2020-08-02 14:45:15	2020-08-02	Kelis Nicolas	kelis.nicolas@geemail.com	San Francisco	California	3489359323327555	d2f8ffa908c8bff18ef7946ee6fa0456	Maestro	37.7383990432892773	-122.435245562111078
41888	2020-08-02 14:47:40	2020-08-02	Ean Reinger-Lang	ean.reinger.lang@woohoo.com	Fontana	California	51159966421890881	51c33fc797fc736b4b942b35d46b09e7	Discover	34.149339341014624	-117.53054291911387
41889	2020-08-02 14:53:50	2020-08-02	Yessenia Ziemann	yessenia.ziemann@geemail.com	Round Rock	Texas	3455359535968196	b1e3a0f00d34e9b6e25988247693eebc	Voyager	30.5813743397731344	-97.6484852646794081
41890	2020-08-02 15:01:32	2020-08-02	Mrs. Meggan Huel	mrs.meggan.huel@geemail.com	Cape Coral	Florida	3112704643137542458	33ac097558872742b89f78aa2ab122ea	American Express	26.594994386142865	-81.9681070917356749
41891	2020-08-02 15:04:39	2020-08-02	Levi Ferry	levi.ferry@geemail.com	Inglewood	California	6011848526719066276	01642b9ebb792cb3ce9a69296c5ce327	JCB 15 digit	34.0128930711433313	-118.270023049184317
41892	2020-08-02 15:09:08	2020-08-02	Mrs. Deloris Okuneva	mrs.deloris.okuneva@geemail.com	San Francisco	California	4137415207059	a818aa7d413c8d314a30c9f9380d0b06	VISA 16 digit	37.7367431069047896	-122.433326255134929
41893	2020-08-02 15:19:19	2020-08-02	Nyree Franecki	nyree.franecki@geemail.com	Frisco	Texas	869989715116489623	754cea6dca822d3166de9a21b6337066	VISA 13 digit	33.1543648184273394	-96.8268699538636923
41894	2020-08-02 15:23:29	2020-08-02	Angelina Carroll DDS	angelina.carroll.dds@geemail.com	New York	New York	3337419893270677167	6e1158ec87076996a9691f1cc5c0fdd6	Mastercard	40.6312510258276021	-74.0275625993859023
41895	2020-08-02 15:30:48	2020-08-02	Laci Stroman	laci.stroman@warmmail.com	Los Angeles	California	869925702682956661	bbdfcec018202641b0819c479c704d19	VISA 16 digit	34.0365397718135227	-118.477630082703371
41896	2020-08-02 15:31:27	2020-08-02	Lakendra Crooks	lakendra.crooks@geemail.com	New York	New York	3528659864243310862	99721b96ec8d88a87e2e03d8fbc60e5e	American Express	40.6490402955319752	-74.003416763375327
41897	2020-08-02 15:45:44	2020-08-02	Creed McCullough	creed.mccullough@geemail.com	New York	New York	503846159069643	69272918c049f03b6e1dd4e1741b4705	VISA 16 digit	40.5898291151728472	-73.9336262088164631
41898	2020-08-02 16:15:03	2020-08-02	Karina Ledner DVM	karina.ledner.dvm@geemail.com	Bakersfield	California	4805092770597700	bdcc0f3e8c363c0f8156ed81d1c78223	Diners Club / Carte Blanche	35.3031553561508602	-118.954629639283937
41899	2020-08-02 16:15:52	2020-08-02	Chanie Batz	chanie.batz@warmmail.com	Oxnard	California	869951703001661450	8ad48f079f1179c6647fa7aa69386ace	Voyager	34.155431006518377	-119.152879070900752
41900	2020-08-02 16:23:09	2020-08-02	Jetta Bernhard	jetta.bernhard@geemail.com	Oakland	California	869959727683012528	98b1c71fef77dd0dbd35af490fd8ed30	JCB 16 digit	37.8055968475343533	-122.26413137845887
41901	2020-08-02 16:26:10	2020-08-02	Asher Wisozk	asher.wisozk@geemail.com	New York	New York	3528280837097757922	edc0c76366e16ec94903d43f9fb82219	Diners Club / Carte Blanche	40.6908383586667455	-73.8748943431198626
41902	2020-08-02 16:26:14	2020-08-02	Aloysius Rippin II	aloysius.rippin.ii@geemail.com	Modesto	California	3053442589051268	59a2db10da5efb0695adb96014e45e3f	JCB 15 digit	37.544001089222732	-120.991074373453856
41903	2020-08-02 16:26:59	2020-08-02	Thos Farrell PhD	thos.farrell.phd@woohoo.com	Springfield	Illinois	869972929545414305	7c9387d37840b2a83e6488281a4f36c3	Mastercard	39.8787446436625004	-89.6659312368374231
41904	2020-08-02 16:34:01	2020-08-02	Gust Borer	gust.borer@geemail.com	San Bernardino	California	6011225626107016074	b24ff0eeebb559e3ad0fc00730819a97	VISA 13 digit	34.0521510043911633	-117.342896958185733
41905	2020-08-02 16:37:43	2020-08-02	Mrs. Perla Kutch PhD	mrs.perla.kutch.phd@geemail.com	Long Beach	California	3044751401318690	e391d46c71b3b35e06db9d5f0063a96f	JCB 15 digit	33.8580380847033098	-118.077988296018162
41906	2020-08-02 16:38:06	2020-08-02	Dr. Audy Smitham	dr.audy.smitham@woohoo.com	San Bernardino	California	3043571106526343	225c16adb49b044bf59ccd5fab432c0a	Discover	34.1576618876107005	-117.213558898425106
41907	2020-08-02 16:40:23	2020-08-02	Miss Sannie Rippin	miss.sannie.rippin@geemail.com	Evansville	Indiana	3700614329342271	5670fd1152ddad956290937a31c92478	VISA 16 digit	38.0861013114124489	-87.5163542096901637
41908	2020-08-02 17:10:34	2020-08-02	Judi Medhurst DVM	judi.medhurst.dvm@geemail.com	Los Angeles	California	3158163269016506218	a21620b7b5286946bc50a5a3a95c2b3c	Diners Club / Carte Blanche	33.9205135712731618	-118.369128458247701
41909	2020-08-02 17:12:59	2020-08-02	Talia Rath	talia.rath@geemail.com	Phoenix	Arizona	6011855582992655509	b3cb7864c594fe2cdb32020bbf6af3c4	Diners Club / Carte Blanche	33.4950212859481624	-112.090199669257188
41910	2020-08-02 17:18:47	2020-08-02	Ashby Hills	ashby.hills@warmmail.com	New York	New York	6011441301235109732	2c8f9616ddcc9611ec1b0859dc293d23	VISA 13 digit	40.7562741150371721	-73.9797821282770514
41911	2020-08-02 17:32:30	2020-08-02	Ella Feest	ella.feest@warmmail.com	Los Angeles	California	869919219735278140	d12d57b5068edfe299ff5534e9b57b34	JCB 16 digit	34.0064683202985663	-118.372218919544665
41912	2020-08-02 17:43:15	2020-08-02	Candi Walsh-Keebler	candi.walsh.keebler@woohoo.com	Carrollton	Texas	3005118483498924	f84b72e1964c91965f4e3e8346d7dcf3	American Express	32.9366088281772988	-96.9405543722074441
41913	2020-08-02 17:45:07	2020-08-02	Kieth Wehner	kieth.wehner@geemail.com	New York	New York	676136032718011	b15a107b60f8f91949ea8e9b66dcf293	Diners Club / Carte Blanche	40.6541093832571079	-73.9475575617875904
41914	2020-08-02 17:54:21	2020-08-02	Wilfredo Kertzmann	wilfredo.kertzmann@geemail.com	Dallas	Texas	3528931089622582127	7fc920cde608de9ae939349ef2562e5b	JCB 15 digit	32.7791277419582059	-96.678962249444794
41915	2020-08-02 18:03:03	2020-08-02	Earle Glover I	earle.glover.i@geemail.com	Los Angeles	California	6011731886797267968	7b471901ff98e80fb60fff654d68329f	Discover	34.0146026581857299	-118.440334397413949
41916	2020-08-02 18:04:39	2020-08-02	Ms. Maira Lang DVM	ms.maira.lang.dvm@geemail.com	San Francisco	California	4346471194204075	a2e561f3cb58c9ce7494dd08818f4ab1	VISA 16 digit	37.7611339715791274	-122.412414404865373
41917	2020-08-02 18:12:45	2020-08-02	Billy Bernier	billy.bernier@warmmail.com	Oklahoma City	Oklahoma	869967166012271259	448d35c9a0a0bae9a64370f71f9c0ab8	Discover	35.3984427888322628	-97.4847492100100936
41918	2020-08-02 18:18:43	2020-08-02	Tory Hahn	tory.hahn@geemail.com	Fresno	California	53717331195113900	9031bcea5d6cdd4b8d8ea012621d6963	Voyager	36.7556768973696961	-119.728291678951692
41919	2020-08-02 18:49:54	2020-08-02	Mordechai Herzog Jr.	mordechai.herzog.jr.@geemail.com	San Jose	California	3088856959449103987	ff32c6e7602fa0d8662d8b9860a76ee6	American Express	37.2285735784851042	-121.774620015102997
41920	2020-08-02 18:56:09	2020-08-02	Floyd Powlowski Sr.	floyd.powlowski.sr.@geemail.com	San Francisco	California	4737344632531	ebf19828bf9ece14ecbe00876c24b166	Mastercard	37.7474765401501458	-122.44410236522225
41921	2020-08-02 19:11:26	2020-08-02	Tabatha Kunze	tabatha.kunze@geemail.com	Washington	District of Columbia	4888388372499331	56e9e3b675d5160ac45608cd50343c35	Discover	38.9703742317654189	-76.9770710952326738
41922	2020-08-02 19:13:05	2020-08-02	Lina Olson-Kunze	lina.olson.kunze@woohoo.com	Fresno	California	869988932493124506	959d21468e218981d924c94ed76b01ee	Maestro	36.7400103063195971	-119.749396861262255
41923	2020-08-02 19:13:32	2020-08-02	Jamarcus Kessler MD	jamarcus.kessler.md@warmmail.com	Little Rock	Arkansas	4014835752537582	08312b4bc6717e1888e30c08203973b0	Voyager	34.7572163183517731	-92.293755855491753
41924	2020-08-02 19:13:50	2020-08-02	Anjali Swaniawski DDS	anjali.swaniawski.dds@geemail.com	New York	New York	3112516477541593825	97c378ea24887be06cae2ef45cf32bb3	American Express	40.7475711646713279	-73.963023654640466
41925	2020-08-02 19:18:03	2020-08-02	Miss Delilah Mertz	miss.delilah.mertz@geemail.com	Las Vegas	Nevada	54124821339879983	f5d2e69bdf9b44a7d2bdbe156ea55daa	VISA 13 digit	36.2636194433651866	-115.182491992434848
41926	2020-08-02 19:20:45	2020-08-02	Marci Frami DDS	marci.frami.dds@warmmail.com	Berkeley	California	6011361993791493058	3783e6be6281a32a7963217c8cac6413	Maestro	37.8197302222761209	-122.272396423086846
41927	2020-08-02 19:27:09	2020-08-02	Sophronia Farrell-Larson	sophronia.farrell.larson@warmmail.com	Chicago	Illinois	6011704573411435584	010f4af5b400075d4361c31a997a414d	VISA 16 digit	41.8133022116333279	-87.5883578754059897
41928	2020-08-02 19:28:46	2020-08-02	Mrs. Carrol Crist PhD	mrs.carrol.crist.phd@geemail.com	Topeka	Kansas	3337583541993745031	aa00dbbd20188c5c45a88f9e53ba71e9	Mastercard	38.9585449371885488	-95.6499148993927975
41929	2020-08-02 19:29:08	2020-08-02	Miss Eulah Abshire MD	miss.eulah.abshire.md@geemail.com	Houston	Texas	869968552595027706	677bfd5b7928392efdf9aefd99763efb	American Express	29.6883684604972586	-95.3734586176477421
41930	2020-08-02 19:30:52	2020-08-02	Waylon Harber	waylon.harber@warmmail.com	Salt Lake City	Utah	4798857728025	a17a026d80909b0e967eb81041c1747c	Mastercard	40.829993976108355	-112.019094872469083
41931	2020-08-02 19:34:11	2020-08-02	Reba Bayer	reba.bayer@geemail.com	Oxnard	California	3031568490316069	b109594067ead3e21c2649f463bc690e	JCB 16 digit	34.256279459777474	-119.149714499656483
41932	2020-08-02 19:36:02	2020-08-02	Mr. Wilkie Mosciski	mr.wilkie.mosciski@warmmail.com	Syracuse	New York	3337420218311097166	d4e3cb7e06f20013b725b4f904926bd3	Mastercard	43.1384905661772891	-76.1737296920515661
41933	2020-08-02 19:42:13	2020-08-02	Jewel Ebert	jewel.ebert@geemail.com	Hialeah	Florida	3528825436752361583	8536762496ab834cf154e3ca697469a6	Maestro	25.9141243154626366	-80.2692954516872703
41934	2020-08-02 19:43:43	2020-08-02	Mrs. Sabina Smitham	mrs.sabina.smitham@geemail.com	Detroit	Michigan	6011586763529030657	7efa6e0d2ff86edb4071d025b7c86634	JCB 16 digit	42.3853110189009499	-83.1596392134789397
41935	2020-08-02 19:48:36	2020-08-02	Miss Gertie Boehm	miss.gertie.boehm@geemail.com	Chattanooga	Tennessee	869907350071432118	a1e922baea2913ce639079c72e45f290	Diners Club / Carte Blanche	35.0792948510814497	-85.3183424633290599
41936	2020-08-02 19:56:19	2020-08-02	Kelli Kirlin PhD	kelli.kirlin.phd@woohoo.com	Syracuse	New York	3483543236624499	6f9a773570ee9ffc9dc4051f2b3c6992	VISA 16 digit	43.1207581594437315	-76.2052720500867906
41937	2020-08-02 19:57:24	2020-08-02	Reyna Spencer-Ankunding	reyna.spencer.ankunding@geemail.com	Thornton	Colorado	503808071613064	84e3615790ef98440617f06fe397ab40	Discover	40.0149119460821154	-105.032811692419656
41938	2020-08-02 20:04:52	2020-08-02	Kaylen Lakin	kaylen.lakin@geemail.com	Los Angeles	California	210085707443632664	e268443d0990814930f0aefb0af8bedb	Diners Club / Carte Blanche	34.0733568616077278	-118.313473856960599
41939	2020-08-02 20:05:47	2020-08-02	Rolanda Bechtelar	rolanda.bechtelar@woohoo.com	Oakland	California	3158479191383088803	52a15f803d942e320bdf308acc741849	American Express	37.7913831939591205	-122.300304145534454
41940	2020-08-02 20:10:18	2020-08-02	Miss Jocelyn Ratke	miss.jocelyn.ratke@geemail.com	Indianapolis	Indiana	3045280496506232	de57080ac5e17ac29c9089c63d308946	VISA 16 digit	39.702927503782135	-86.1661139450237101
41941	2020-08-02 20:13:38	2020-08-02	Bridget Lang	bridget.lang@warmmail.com	Midland	Texas	561201163808528	27cb67cc0751fd2b0725f385d58118bd	VISA 13 digit	32.0504637824095795	-102.11001191243902
41942	2020-08-02 20:16:09	2020-08-02	Dr. Claudio Klocko DDS	dr.claudio.klocko.dds@geemail.com	New York	New York	4501225826136746	0efe1c0141b39466ab37b0c7f96adfc2	American Express	40.7342976432051529	-73.8824065433710757
41943	2020-08-02 20:16:18	2020-08-02	Jeffry Conn	jeffry.conn@warmmail.com	Oakland	California	869928819209558494	8b6aa7a46d41f7a692f5b9fd6556b64b	Mastercard	37.800444538385868	-122.313266123412674
41944	2020-08-02 20:16:37	2020-08-02	Alisson Cassin	alisson.cassin@geemail.com	Fargo	North Dakota	52560402143782993	4008001ad799587d563f8eef796d47fc	Mastercard	46.8053475972961621	-96.7428132152147526
41945	2020-08-02 20:18:50	2020-08-02	Joelle Rice	joelle.rice@geemail.com	Berkeley	California	3088156543099165947	8bfd3de65a1b9d2c8adbb32fd05a262a	JCB 16 digit	37.8994493039503197	-122.285062186709851
41946	2020-08-02 20:20:50	2020-08-02	Miss Halie Effertz	miss.halie.effertz@geemail.com	Austin	Texas	55136282161760914	aca8f545321d364551eafbd03b663431	Discover	30.3371912248559283	-97.7136392823658895
41947	2020-08-02 20:27:05	2020-08-02	Genevra Stehr-Thompson	genevra.stehr.thompson@geemail.com	New York	New York	3756837819261601	00ba816b11e7972193f15eb668d746aa	JCB 15 digit	40.7040103799887021	-74.0229272594105367
41948	2020-08-02 20:31:27	2020-08-02	Freda McKenzie	freda.mckenzie@geemail.com	Nashville	Tennessee	51195343052806162	3d37b107e84dcf9ed380b075b459361d	VISA 16 digit	36.1788064451545424	-86.7360369326919312
41949	2020-08-02 20:37:07	2020-08-02	Tyquan Wiegand-Watsica	tyquan.wiegand.watsica@geemail.com	Dallas	Texas	4700873400782887	62392fd632b018b350dfc037b3c89031	Voyager	32.8792783318359412	-96.7158380094878254
41950	2020-08-02 20:40:22	2020-08-02	Danniel Crist	danniel.crist@geemail.com	Lewisville	Texas	502047324888156	55e46911f8b95065b5f1581865c177b7	VISA 13 digit	33.0902045986134539	-96.9575464619819201
41951	2020-08-02 20:41:18	2020-08-02	Janessa Hermann MD	janessa.hermann.md@geemail.com	San Francisco	California	3088304982608024602	5192af175a31d1872776987395c66d58	JCB 15 digit	37.7899154987807506	-122.397707327348868
41952	2020-08-02 20:44:53	2020-08-02	Sherry Jones-Kassulke	sherry.jones.kassulke@warmmail.com	Oakland	California	4892586359714754	d0112aac47b753067ddf203807aa2875	Maestro	37.7749345621923638	-122.262812996649728
41953	2020-08-02 20:48:28	2020-08-02	Matt Wehner	matt.wehner@geemail.com	Lansing	Michigan	4096568721508258	1004fee78eb6d2787aec62741ea02791	Maestro	42.7527628470987082	-84.6322583330452431
41954	2020-08-02 20:53:26	2020-08-02	Cephus Tremblay-Rau	cephus.tremblay.rau@geemail.com	San Antonio	Texas	869945191836040315	d2831cb366aa253d3edf8e58a5ac4a69	JCB 16 digit	29.5359104184970249	-98.5775450323078672
41955	2020-08-02 21:18:56	2020-08-02	Mrs. Cheyenne Gottlieb PhD	mrs.cheyenne.gottlieb.phd@warmmail.com	Dallas	Texas	4003082745774229	dc064dbf4d1503cc86b5333c94261297	Diners Club / Carte Blanche	32.7230566257417195	-96.6872794872112564
41956	2020-08-02 21:26:38	2020-08-02	Con Harvey	con.harvey@geemail.com	New York	New York	869944623436584517	289f63d101cb7b934a79d233eba7f892	Mastercard	40.6824382359851171	-73.8534987305186661
41957	2020-08-02 21:30:20	2020-08-02	Landen Hamill-Beahan	landen.hamill.beahan@geemail.com	Springfield	Missouri	3050992021570328	34cee5af0a157cc05c977e028d3c350f	VISA 16 digit	37.167508177106086	-93.3713600135233293
41958	2020-08-02 21:31:39	2020-08-02	Thekla Kshlerin	thekla.kshlerin@warmmail.com	Elk Grove	California	561274879253396	6324a940c3b318d5259aab53c2921e37	VISA 16 digit	38.3933983085494503	-121.441656882772222
41959	2020-08-02 21:35:33	2020-08-02	Simona Schuster-Trantow	simona.schuster.trantow@geemail.com	New York	New York	502019722404597	c24044852f6a815ef8289b9d42c46f60	Maestro	40.7381422111522369	-73.8872934631433367
41960	2020-08-02 21:38:18	2020-08-02	Epsie Schiller	epsie.schiller@warmmail.com	San Jose	California	4171910958841	b40b11806299d0f4186b71ba47327f40	VISA 16 digit	37.2733153862234232	-121.762224425304311
41961	2020-08-02 21:49:05	2020-08-02	Mr. Orie Veum	mr.orie.veum@warmmail.com	Philadelphia	Pennsylvania	3755103910196977	28e05db5ec95c4206a2e8afbe306cbf9	VISA 16 digit	40.0784317465458031	-75.0496960277568661
41962	2020-08-02 21:57:23	2020-08-02	Orland Hand	orland.hand@geemail.com	San Francisco	California	180079543076220412	99790fc6a30017c7e0b6b32dac914b2f	Mastercard	37.7655930424891437	-122.435740066967369
41963	2020-08-02 22:01:03	2020-08-02	Watt Lowe	watt.lowe@geemail.com	Richmond	Virginia	4259436533770669	ab9e7810999962b9f467de906880cdeb	American Express	37.5613615404568577	-77.4088614157158901
41964	2020-08-02 22:01:32	2020-08-02	Charle Runolfsdottir	charle.runolfsdottir@geemail.com	San Francisco	California	4722922391928407	68beecf31d1381a210bce8f386429328	Mastercard	37.753695022697471	-122.454031668474741
41965	2020-08-02 22:03:54	2020-08-02	Orelia Kilback	orelia.kilback@geemail.com	San Diego	California	4422121250167	b74d4f78e3607baba26e280e95c10752	Mastercard	32.7549694538649163	-117.035254388665791
41966	2020-08-02 22:17:55	2020-08-02	Marguerite Paucek	marguerite.paucek@warmmail.com	Manchester	New Hampshire	180089066781182220	1fe710b8f298e37662ebc1397c195550	American Express	43.0253155745636704	-71.5289794064950257
41967	2020-08-02 22:18:33	2020-08-02	Aliyah Larkin	aliyah.larkin@geemail.com	Riverside	California	675985514040956	8a97feccc6c11f6a3fe2e4c3b06b6ca0	JCB 16 digit	33.9817147032771274	-117.379839029392969
41968	2020-08-02 22:20:44	2020-08-02	Viridiana Morar	viridiana.morar@geemail.com	Berkeley	California	6011868406638214221	ad8c19db144ccb7143f4fc4410378a31	VISA 16 digit	37.8784802386698161	-122.258886369526849
41969	2020-08-02 22:35:04	2020-08-02	Mr. Kayden Fahey Jr.	mr.kayden.fahey.jr.@warmmail.com	Berkeley	California	869947218684585832	52b0b9ed54ad898f0fc530a5bcb83b00	Maestro	37.8824273088395955	-122.331036894720683
41970	2020-08-02 22:35:29	2020-08-02	Mr. Mart Stracke PhD	mr.mart.stracke.phd@geemail.com	Pueblo	Colorado	3425051454699350	237a76ec07389381fa9b54d42a3d8fd6	Diners Club / Carte Blanche	38.3052914517909286	-104.547492363522949
41971	2020-08-02 22:37:25	2020-08-02	Areli Ward	areli.ward@geemail.com	Irvine	California	4402859117317	a174a43e95f03327636acf718c6778a4	VISA 16 digit	33.767655275297912	-117.710301148147508
41972	2020-08-02 22:49:14	2020-08-02	Moe Roberts	moe.roberts@woohoo.com	Los Angeles	California	4381240290456	29dc87cae0ec4cf9e2cd46e4aa2406d7	JCB 15 digit	34.1035382517944967	-118.398934962040926
41973	2020-08-02 22:49:57	2020-08-02	Eben Terry	eben.terry@geemail.com	El Paso	Texas	3040258125889877	74b7da4ceb794cdfc2a33f479c8a3cb9	American Express	31.820626468194277	-106.426246661085642
41974	2020-08-02 22:50:42	2020-08-02	Dr. Adelaide Klocko	dr.adelaide.klocko@geemail.com	Midland	Texas	869994991263446723	c48aa176e52689002ea19c0da568cfae	Mastercard	31.9630460581466558	-102.123314221085977
41975	2020-08-02 23:02:24	2020-08-02	Tina Stiedemann	tina.stiedemann@geemail.com	Providence	Rhode Island	4495987099767204	c08b5cc144d12fddbc0e1c4cf2c2cbf8	VISA 13 digit	41.8301549590513062	-71.3533429966691983
41976	2020-08-02 23:03:09	2020-08-02	Keanu Klocko	keanu.klocko@warmmail.com	Victorville	California	4435779454158530	de5a1bdf4824e9e93888403052a8082b	Diners Club / Carte Blanche	34.5171913463387696	-117.292404189627987
41977	2020-08-02 23:09:02	2020-08-02	Oliver Schulist-Hansen	oliver.schulist.hansen@geemail.com	Boston	Massachusetts	4759543704248410	9634fdb5d8efbdb50637e486afe8c2d7	Maestro	42.2717624809294961	-71.0057050045065665
41978	2020-08-02 23:13:25	2020-08-02	Nathalia Cruickshank-Kuhn	nathalia.cruickshank.kuhn@geemail.com	Denver	Colorado	4172183589651849	27c0453d5c73704dc76e53d6fd2edcee	JCB 16 digit	39.7452334499038713	-104.799873583834994
41979	2020-08-02 23:15:17	2020-08-02	Elana Rau PhD	elana.rau.phd@geemail.com	Charlotte	North Carolina	4440275791408467	d40fd073a00279de3dae7255abd01fac	VISA 16 digit	35.1090496278621274	-80.9084001762736591
41980	2020-08-02 23:21:36	2020-08-02	Davon Ernser	davon.ernser@geemail.com	Waco	Texas	3043450649400045	0216a9d3d5a7a9f3d41cd8fcd87e4da7	VISA 13 digit	31.6212027449835062	-97.1118262358605904
41981	2020-08-02 23:34:31	2020-08-02	Layne Murray	layne.murray@geemail.com	Minneapolis	Minnesota	52356308911575782	84b8ad84a7431732ccbb0588dae44f73	VISA 16 digit	45.0102524400308681	-93.2803281058363609
41982	2020-08-02 23:38:01	2020-08-02	Earnestine Walker PhD	earnestine.walker.phd@geemail.com	Chicago	Illinois	3096526538464684780	e2a5ee47b56ee65f4a7245be2b3ceb27	VISA 13 digit	41.815188562108581	-87.6345542228810501
41983	2020-08-02 23:45:38	2020-08-02	Lisbeth Kautzer	lisbeth.kautzer@geemail.com	New Orleans	Louisiana	3096142815156172868	fa762557bf54bbe202df0f94d3e9c458	VISA 16 digit	30.1036821613568826	-89.9316577777061639
41984	2020-08-02 23:46:46	2020-08-02	Mr. Lavon Hartmann IV	mr.lavon.hartmann.iv@geemail.com	San Diego	California	3096650498876041350	401d45e4a5c5364238908c93202c58ca	Maestro	32.7837636438731082	-117.08684953231365
41985	2020-08-02 23:48:41	2020-08-02	Pranav Keebler	pranav.keebler@woohoo.com	Los Angeles	California	676380012507176	8805d26ac4056ff4742e6e63d82974fc	Mastercard	33.9879874579008643	-118.321917317248136
41986	2020-08-02 23:57:00	2020-08-02	Jaylin Borer V	jaylin.borer.v@geemail.com	Phoenix	Arizona	3484867539166869	c713fa8b94f267e278a5940f0413c8ee	VISA 16 digit	33.6648801785361016	-112.103868416084353
41987	2020-08-03 00:02:55	2020-08-03	Bridgette Robel	bridgette.robel@woohoo.com	Seattle	Washington	6011334813829638686	138b92c965bf597a9f76cd544400fe7f	Maestro	47.5505225924700525	-122.319371452500661
41988	2020-08-03 00:03:13	2020-08-03	Leigh O'Hara DDS	leigh.o'hara.dds@geemail.com	West Palm Beach	Florida	4438868414881161	2c84a46e5a283bab9ddeb39950e59dd5	JCB 16 digit	26.6920877642311183	-80.0953659854199742
41989	2020-08-03 00:03:16	2020-08-03	Elden Cummings	elden.cummings@woohoo.com	Boston	Massachusetts	3037824974101582	7d8a2bb2dc51c205d1fa9282bd1f1b71	VISA 16 digit	42.3539212614931202	-70.9255442889824508
41990	2020-08-03 00:06:54	2020-08-03	Brittni D'Amore-O'Keefe	brittni.d'amore.o'keefe@warmmail.com	San Francisco	California	6011487381852723424	be35422d54c728f4bceae9c3ec4f326e	Voyager	37.77090173473173	-122.432435975682694
41991	2020-08-03 00:30:15	2020-08-03	Jennette Brakus	jennette.brakus@geemail.com	Moreno Valley	California	6011315127635456412	72a22acd3a67d6cea7941caee09cb275	JCB 16 digit	33.8495750021647623	-117.177522286816313
41992	2020-08-03 00:41:47	2020-08-03	Alyssa Schmeler	alyssa.schmeler@woohoo.com	San Francisco	California	51754313365595821	3710d8ddee712516a6fff47b55b93bd3	Discover	37.7535908985473725	-122.437326681811399
41993	2020-08-03 00:43:43	2020-08-03	Ms. Missouri Crist	ms.missouri.crist@geemail.com	Arvada	Colorado	3463829536049006	b4e6f290249ed0c0f67ec074ea33c953	VISA 16 digit	39.8739384086512061	-105.091833835930757
41994	2020-08-03 00:48:52	2020-08-03	Kit Swift	kit.swift@warmmail.com	Hollywood	Florida	6011381985897307253	45035b0d73523d78041749fd173e47df	VISA 16 digit	25.9738861577995124	-80.1029724500890694
41995	2020-08-03 00:50:02	2020-08-03	Eduardo Hermiston	eduardo.hermiston@geemail.com	Fayetteville	North Carolina	54175009174200402	590f7e0f803783894ea9a9035d06b15e	VISA 16 digit	35.0320117282934476	-79.0330488403458133
41996	2020-08-03 01:01:19	2020-08-03	Cathrine Torphy	cathrine.torphy@warmmail.com	North Las Vegas	Nevada	6011822938132512820	35d8eb039851bb106084cad99cc7a4dc	VISA 16 digit	36.3290734035585032	-115.014181760999932
41997	2020-08-03 01:07:21	2020-08-03	Gannon Balistreri	gannon.balistreri@woohoo.com	Phoenix	Arizona	4255610198756	2977274a44ae01cf042dc8f0d55a3322	Mastercard	33.6561706368744424	-112.140493160339446
41998	2020-08-03 01:15:34	2020-08-03	Pepper Zieme	pepper.zieme@geemail.com	Naperville	Illinois	3337615400541032685	7658cd27171f52291d9848645051b6cf	VISA 16 digit	41.6810719153292482	-88.1662329316958875
41999	2020-08-03 01:24:03	2020-08-03	Yehuda Dietrich	yehuda.dietrich@geemail.com	Akron	Ohio	3096217254062366093	5593d38ca080da4478a4f0bb49b95a8d	JCB 16 digit	41.0173373628705775	-81.5119228277668384
42000	2020-08-03 01:29:50	2020-08-03	Emerson Conroy-Mraz	emerson.conroy.mraz@geemail.com	Philadelphia	Pennsylvania	869945465653634834	98709d9225e8215091bb1b0e3e4e74ad	Diners Club / Carte Blanche	40.0184603303629913	-75.1865369796186798
42001	2020-08-03 01:39:26	2020-08-03	Miss Francies Watsica	miss.francies.watsica@geemail.com	Memphis	Tennessee	51986898815097956	1a8e97c941e5f2b174851de13b90457e	Mastercard	35.1246054546974591	-89.9812627932779492
42002	2020-08-03 01:40:01	2020-08-03	Louisiana Barrows	louisiana.barrows@geemail.com	Indianapolis	Indiana	869915893142704841	ce2c56c0aaced8239e824a883f76a247	Mastercard	39.7681362855721261	-86.1297430919684501
42003	2020-08-03 01:42:44	2020-08-03	Hilah Oberbrunner	hilah.oberbrunner@woohoo.com	Plano	Texas	3158666489687251389	f0ee69099659c27e35dfef0ee7bb088d	Maestro	33.0004604300569753	-96.6583005124885659
42004	2020-08-03 02:03:45	2020-08-03	Chase Dooley	chase.dooley@woohoo.com	Syracuse	New York	4404134789752242	e89d626ae0a253124c3a0c40417745ad	VISA 16 digit	43.0825206111036181	-76.1923372292205698
42005	2020-08-03 02:12:30	2020-08-03	Dr. Hadley Kilback	dr.hadley.kilback@woohoo.com	Corpus Christi	Texas	869934876048081452	c98faa4bd7c08cf19e500d792d9bced1	Voyager	27.7142322776310159	-97.0945148513481087
42006	2020-08-03 02:19:01	2020-08-03	Dr. Alvah King V	dr.alvah.king.v@woohoo.com	Mesa	Arizona	4836448499975036	428d49b3d12c04cc3b1f2a3c8994b98b	JCB 16 digit	33.3574570418946408	-111.757268658035997
42007	2020-08-03 02:24:43	2020-08-03	Ottis Orn-Stokes	ottis.orn.stokes@warmmail.com	New York	New York	4217466757053451	0449716daef9f03afca1e5ae1ac79514	Mastercard	40.7520661729611433	-73.9117744727421524
42008	2020-08-03 02:39:19	2020-08-03	Dolphus Turcotte	dolphus.turcotte@warmmail.com	Tallahassee	Florida	4995059841713376	6941c0085e1e2de62bf304e60ebb9bdd	Diners Club / Carte Blanche	30.5236436736792349	-84.158840849484875
42009	2020-08-03 02:42:58	2020-08-03	Agatha Reichel	agatha.reichel@woohoo.com	San Francisco	California	180078744780349841	4521bf5e5aab54d2091cb64c8d49afe1	VISA 13 digit	37.7506343510572719	-122.445049296636185
42010	2020-08-03 02:46:28	2020-08-03	Dessie Larkin II	dessie.larkin.ii@geemail.com	Anchorage	Alaska	4502284419756807	6b640ec901cd8f8f03f6abcbca04a3be	Diners Club / Carte Blanche	61.2577199705161206	-149.217164402094852
42011	2020-08-03 02:52:25	2020-08-03	Birdie Orn	birdie.orn@geemail.com	Albuquerque	New Mexico	210072743266463346	9d5b6134d136f9d58b578c8c416974c4	Mastercard	35.1493642219942117	-106.702244600800427
42012	2020-08-03 03:06:11	2020-08-03	Miss Reatha Nienow PhD	miss.reatha.nienow.phd@geemail.com	San Francisco	California	3158221417273550433	cdb2011c9c43211ed8208e3c3c27f5c8	JCB 16 digit	37.7861786006572942	-122.440800644270837
42013	2020-08-03 03:06:16	2020-08-03	Talia O'Kon	talia.o'kon@geemail.com	Charlotte	North Carolina	55260097512680464	1b6cf0cf99c9c394c9341c8d1c563001	JCB 16 digit	35.1559642647646342	-80.8350667803026823
42014	2020-08-03 03:09:57	2020-08-03	Khalil Kilback	khalil.kilback@warmmail.com	Henderson	Nevada	3337516553702904819	f1b8435d904f174f509315f1cd2e70f7	Mastercard	35.9551163084737979	-114.969246875882902
42015	2020-08-03 03:20:22	2020-08-03	Dr. Levon Koch	dr.levon.koch@woohoo.com	Evansville	Indiana	4333441766366573	93fdaabd9832b785578f5354cd316446	Discover	37.9320683489691461	-87.5192516466070032
42016	2020-08-03 03:25:31	2020-08-03	Kelan Jerde	kelan.jerde@warmmail.com	Miami	Florida	3337208258470585807	44e521d190f972705088ff4fd35f5c98	JCB 16 digit	25.8141804201200635	-80.2222754088569445
42017	2020-08-03 03:26:06	2020-08-03	Linnea Tromp	linnea.tromp@geemail.com	New York	New York	52333822291868649	d58a673a95c08b8b7dfedec496967980	JCB 15 digit	40.7498272753544128	-73.9911809309747071
42018	2020-08-03 03:30:11	2020-08-03	Dr. Kara Stiedemann MD	dr.kara.stiedemann.md@geemail.com	Indianapolis	Indiana	6011313856777089464	db944f5260cf85028ed374c3014aec61	Diners Club / Carte Blanche	39.8677143497399982	-86.1035177331618939
42019	2020-08-03 03:33:30	2020-08-03	Davis Ward	davis.ward@geemail.com	Carlsbad	California	3499925886872035	daa04f93b8af0f9dea13a5aba28f92a8	JCB 16 digit	33.1453856959413713	-117.341482908443723
42020	2020-08-03 03:42:01	2020-08-03	Shyla Hegmann	shyla.hegmann@geemail.com	Denver	Colorado	3413754485116112	821ad08c225139de923dff0ba1e0ae3d	Mastercard	39.6844603250320986	-104.80846191530712
42021	2020-08-03 03:55:00	2020-08-03	Elam Towne-Huels	elam.towne.huels@geemail.com	Sparks	Nevada	3032267867838404	a818ae87562b7ec050a7413ed437cefe	VISA 13 digit	39.6529720454715218	-119.80057410177254
42022	2020-08-03 04:03:33	2020-08-03	Andrew Harvey Sr.	andrew.harvey.sr.@warmmail.com	Huntsville	Alabama	51338090501409258	f5e5c0ed3f7f0a2faa29d7dec4ccdf69	VISA 16 digit	34.7527173710297745	-86.6628948067799172
42023	2020-08-03 04:03:41	2020-08-03	Mr. Andy Ebert Sr.	mr.andy.ebert.sr.@geemail.com	San Francisco	California	4651987362172538	1ec0a657816f0ae4f22db1e069147438	Mastercard	37.7740397804698773	-122.412248073703964
42024	2020-08-03 04:03:49	2020-08-03	Jami Stokes	jami.stokes@woohoo.com	Las Vegas	Nevada	3059959001726866	7c147c7530ce8d7b97960616b2f00106	Voyager	36.165579708675665	-115.237537200909472
42025	2020-08-03 04:06:27	2020-08-03	Ilma Gulgowski	ilma.gulgowski@woohoo.com	Gainesville	Florida	4856464497309	5c49987f8f4ec58d16cf4ef01f95b3a0	American Express	29.7168452888552075	-82.2890538985248696
42026	2020-08-03 04:06:44	2020-08-03	Yolonda Smitham	yolonda.smitham@geemail.com	Los Angeles	California	3528559175079274440	2b329990411366aa9be94ceba5618c04	VISA 13 digit	34.0631754466663992	-118.457623468059296
42027	2020-08-03 04:13:05	2020-08-03	Isiah Swift	isiah.swift@geemail.com	San Francisco	California	3337063450958777980	e17b859815525d8683ecd1a4745b0217	Maestro	37.7499699020277717	-122.415376364162427
42028	2020-08-03 04:19:56	2020-08-03	Dante Goldner DDS	dante.goldner.dds@geemail.com	Oceanside	California	4011104995295059	b3a8f2b01a61231e14965376cba6dd37	American Express	33.1726563746463512	-117.363318284469472
42029	2020-08-03 04:20:49	2020-08-03	Ingrid Schinner	ingrid.schinner@geemail.com	Mobile	Alabama	3112234332272728465	b4e5fe5aa232dd9d67bc30b5f7c4c13b	Diners Club / Carte Blanche	30.6886188779599962	-88.1466326020795918
42030	2020-08-03 04:23:11	2020-08-03	Cornell Labadie	cornell.labadie@geemail.com	New York	New York	6011193547224418365	5cdeb32fbd949527b9ca9a53c77fff54	JCB 16 digit	40.7098851829990735	-73.912979623618341
42031	2020-08-03 04:30:09	2020-08-03	Laquan Konopelski	laquan.konopelski@geemail.com	Pembroke Pines	Florida	676291303649759	b9ac50b8af23e74a36ff7e4cf86d6ee1	JCB 16 digit	25.9302148374766119	-80.2733089972656302
42032	2020-08-03 04:31:21	2020-08-03	Ms. Melissa Romaguera	ms.melissa.romaguera@woohoo.com	Honolulu	Hawaii	4090893975905	fc311f3c1e170b09e85e966e9a8a3477	Mastercard	21.3127522576350721	-157.819458194563538
42033	2020-08-03 04:36:46	2020-08-03	Buelah Romaguera	buelah.romaguera@geemail.com	Lakewood	New Jersey	4024069255512532	0c193ea705843f46552114dd6cc887bf	JCB 15 digit	40.1046249506346868	-74.2551401998192091
42034	2020-08-03 04:42:25	2020-08-03	Inell Nolan	inell.nolan@warmmail.com	Milwaukee	Wisconsin	180088369397729702	ca44a181794612e242be91c0771a4ac9	VISA 16 digit	43.0633305199064296	-87.9538297431178364
42035	2020-08-03 04:44:45	2020-08-03	Gerry Abbott	gerry.abbott@geemail.com	San Diego	California	6011481752832597839	19355d65b521c01eabba87145bc91d84	Mastercard	32.8042140399638598	-117.139631004249679
42036	2020-08-03 04:52:03	2020-08-03	Nat Hills	nat.hills@geemail.com	Moreno Valley	California	3112443998951752609	37e271b37f99090f100444dd336b7ade	Mastercard	33.9197813042897707	-117.212504697401812
42037	2020-08-03 04:59:05	2020-08-03	Glennie Fisher	glennie.fisher@geemail.com	Kent	Washington	3337251530487703979	4bf5cdf03fd785109ce84797a150a55d	JCB 15 digit	47.356797519337384	-122.135219365185876
42038	2020-08-03 04:59:34	2020-08-03	Cheri Steuber	cheri.steuber@geemail.com	Virginia Beach	Virginia	210074749547660335	64af6f23c46eba50632ca057cd9cbced	VISA 16 digit	36.7880700781662	-76.0273992006339085
42039	2020-08-03 05:00:53	2020-08-03	Zella Bruen-Miller	zella.bruen.miller@woohoo.com	Jacksonville	Florida	869975161872905260	95486d76a47a1f3bfc82bc14d487265a	Maestro	30.2703029514808222	-81.5856473521873369
42040	2020-08-03 05:08:35	2020-08-03	Tatyanna Littel	tatyanna.littel@warmmail.com	Portland	Oregon	4477308954324357	065cd32362cb144691c4faf441f36076	JCB 16 digit	45.558594054577874	-122.63881235462614
42041	2020-08-03 05:20:41	2020-08-03	Mr. Clyde Trantow	mr.clyde.trantow@woohoo.com	New York	New York	51768751226611572	be55d4409e8f32ce314d6bbeab338457	JCB 16 digit	40.7453979671690618	-74.0376661193918437
42042	2020-08-03 05:26:04	2020-08-03	Needham Gottlieb	needham.gottlieb@woohoo.com	Lafayette	Louisiana	869975892876891847	617d155f36eea19a503d19f84bec165e	American Express	30.2673013534374533	-92.0087290689200046
42043	2020-08-03 05:27:57	2020-08-03	Grove Mosciski	grove.mosciski@geemail.com	Jacksonville	Florida	3088926429528470265	6a9af8a7cb6c50b18d2e6fba95dd5c70	Maestro	30.3696985009178526	-81.6235753294624402
42044	2020-08-03 05:29:38	2020-08-03	Jaylan Cruickshank	jaylan.cruickshank@geemail.com	Newport News	Virginia	503831579027033	43fb3e768675b0c0b8568cc1afca037e	JCB 15 digit	37.0219515744026779	-76.604050872780391
42045	2020-08-03 05:30:06	2020-08-03	Edwin Baumbach II	edwin.baumbach.ii@geemail.com	New York	New York	210002925058522794	b1e6a18a69cb3d6514f90bdb01cb9e57	JCB 15 digit	40.7314222646169384	-73.951866325585911
42046	2020-08-03 05:33:50	2020-08-03	Dr. Floy Homenick	dr.floy.homenick@warmmail.com	New York	New York	180058252689688396	7dc883c8fd75016f15acc45ace64a1a1	VISA 16 digit	40.7144270234964765	-74.0146473472367887
42047	2020-08-03 05:38:19	2020-08-03	Talia Hayes MD	talia.hayes.md@warmmail.com	San Diego	California	3112945226238045362	256de56fdaebc8e2a983ae1c6e4c159c	Discover	32.9070439352255306	-117.219104282129564
42048	2020-08-03 05:40:54	2020-08-03	Branson Bergstrom	branson.bergstrom@geemail.com	Los Angeles	California	3112024045789866586	6920ed9b30751923288cf4038f9cd177	Mastercard	34.0757701657578309	-118.334830993273471
42049	2020-08-03 05:42:43	2020-08-03	Ivory Kohler DDS	ivory.kohler.dds@geemail.com	San Antonio	Texas	6011682679090055092	14bf49d2309cc15e30fbe4934230f601	Diners Club / Carte Blanche	29.4458755828976635	-98.5764841294683407
42050	2020-08-03 05:45:15	2020-08-03	Exa Schaden	exa.schaden@warmmail.com	San Francisco	California	3740002990549600	1664af09b5d275e3be1a759776733ddf	Mastercard	37.7995929850416132	-122.449284531553602
42051	2020-08-03 06:02:17	2020-08-03	Othel Bode-Connelly	othel.bode.connelly@warmmail.com	Irving	Texas	869995464445928066	b913ffd366d9e7ba5a03263191549845	VISA 13 digit	32.8745405245058251	-96.9188346958998608
42052	2020-08-03 06:08:30	2020-08-03	Dr. Priscila Haley	dr.priscila.haley@woohoo.com	Colorado Springs	Colorado	4881880246196009	ab44df0519840f42aaf3f25b0033f564	Voyager	38.9547588129576283	-104.694154948477447
42053	2020-08-03 06:11:43	2020-08-03	Zavion Feeney	zavion.feeney@geemail.com	Jacksonville	Florida	4122940647887660	3909bb6220b76431de680b9102c3dd1e	Diners Club / Carte Blanche	30.3020014870963976	-81.5690422988574966
42054	2020-08-03 06:27:04	2020-08-03	Rosamond Kunde	rosamond.kunde@geemail.com	Atlanta	Georgia	180019297307471996	e2f1ef0748315319b218e8e30bfeb93f	Discover	33.8485661110650753	-84.3786030753560397
42055	2020-08-03 06:36:40	2020-08-03	Katina Rippin	katina.rippin@geemail.com	Tucson	Arizona	676357042017582	4c2aecce9613a52fd3c00aa3e7e2ac23	American Express	32.1383124390192378	-110.843344606621557
42056	2020-08-03 06:36:57	2020-08-03	Erika Pollich	erika.pollich@geemail.com	Chicago	Illinois	180072658341166708	e0623d3b43df7825c0407d8a7b8a9db3	JCB 16 digit	41.851760227403048	-87.6587746208097798
42057	2020-08-03 06:46:21	2020-08-03	Dr. Evaline Feeney MD	dr.evaline.feeney.md@geemail.com	Jacksonville	Florida	4602308137788	2329b34270a83da01f4d0fc070cce82e	JCB 16 digit	30.2484449375472977	-81.6205450482279105
42058	2020-08-03 06:46:25	2020-08-03	Reva McCullough DDS	reva.mccullough.dds@warmmail.com	Des Moines	Iowa	4819314740764317	9efbc8cbdd3f68b3d9b62b85c5aa0990	American Express	41.6223074188664555	-93.6671572312757377
42059	2020-08-03 06:48:20	2020-08-03	Misty Hoppe	misty.hoppe@woohoo.com	North Charleston	South Carolina	4677818664515670	5d4d702ce6c782b6e07702e89b9bf6aa	Mastercard	32.9446686678726195	-79.9944665002729778
42060	2020-08-03 06:48:49	2020-08-03	Dozier Jakubowski	dozier.jakubowski@geemail.com	Grand Prairie	Texas	3096638516441947848	1ae4dae8f81d3b7acaa2f074a769f648	Maestro	32.6879372225195155	-97.0915822753556057
42061	2020-08-03 06:51:36	2020-08-03	Barnie Prosacco PhD	barnie.prosacco.phd@geemail.com	Los Angeles	California	3449750960354077	c5b0761257b0f932fdcd30da255c16a4	JCB 16 digit	34.1110440734174105	-118.407724989344544
42062	2020-08-03 07:01:26	2020-08-03	Darla Jenkins	darla.jenkins@geemail.com	Jersey City	New Jersey	4298711419220846	6458b823c3980d3936af45413a9a083a	Maestro	40.8013660345632587	-74.037258224650472
42063	2020-08-03 07:08:50	2020-08-03	Alonso Jakubowski	alonso.jakubowski@geemail.com	Pembroke Pines	Florida	869972161332934218	0f03fce7ac45d3debd8c9b3ca241ca9f	Diners Club / Carte Blanche	26.0319163490124055	-80.3030098849810656
42064	2020-08-03 07:18:15	2020-08-03	Mrs. Joselin Skiles DVM	mrs.joselin.skiles.dvm@woohoo.com	Orlando	Florida	501864625443052	1674d7a55632789b92d4248cf0b87f55	VISA 16 digit	28.432774168372525	-81.2009613641038612
42065	2020-08-03 07:27:42	2020-08-03	Willene Krajcik	willene.krajcik@geemail.com	Pomona	California	675992284207740	bdd843b5e9822781980d0a05ddcdb524	JCB 15 digit	34.0028486946634985	-117.685581987580662
42066	2020-08-03 07:34:02	2020-08-03	Dr. Guss Pollich	dr.guss.pollich@geemail.com	New York	New York	4376173392401528	a0db7b3d89abf1c194eeb69cf21d3bd7	Mastercard	40.730137062979864	-73.9571358994476498
42067	2020-08-03 07:34:36	2020-08-03	Fredric Maggio-Heller	fredric.maggio.heller@geemail.com	Fort Worth	Texas	4699769844553822	209895dfef5e8a693694d60c0c3e1b92	Discover	32.7731158207692204	-97.3057050735976503
42068	2020-08-03 07:36:02	2020-08-03	Dr. Jarrod Gerlach DDS	dr.jarrod.gerlach.dds@geemail.com	San Antonio	Texas	180004467411044099	906063f9c14fbfecfaac1ce71e823363	Maestro	29.420739001229034	-98.4672752585098152
42069	2020-08-03 07:44:42	2020-08-03	Mr. Hampton Adams	mr.hampton.adams@geemail.com	New York	New York	6011229600940847504	e28d51d45a28fb02b76d06c2fe87ba5c	Diners Club / Carte Blanche	40.6449997572917496	-73.8491673819616352
42070	2020-08-03 07:47:26	2020-08-03	Hanna Brown	hanna.brown@geemail.com	Sacramento	California	6011143496319615595	63b5d74769dc889bdfa69db99dcfe9fa	Mastercard	38.4669544020000842	-121.535034450075031
42071	2020-08-03 07:57:55	2020-08-03	Berdie Goldner-Kris	berdie.goldner.kris@geemail.com	Louisville	Kentucky	210028635170578869	2e608d4316bb4dbe8a106e2041be88b1	VISA 16 digit	38.1785067825946953	-85.7102439455293137
42072	2020-08-03 08:03:08	2020-08-03	Sage Stamm PhD	sage.stamm.phd@geemail.com	Oakland	California	3777724352060829	fa7805140b924152a0ce978162dbdda4	Mastercard	37.8022818928142428	-122.276947698347172
42073	2020-08-03 08:03:35	2020-08-03	Dr. Ian Nitzsche	dr.ian.nitzsche@geemail.com	Los Angeles	California	180073262862935697	ee746bb794468352c2feec428f739bc1	JCB 16 digit	34.0485303645353738	-118.480766788124285
42074	2020-08-03 08:06:00	2020-08-03	Dr. Stonewall Ratke II	dr.stonewall.ratke.ii@warmmail.com	Pasadena	California	4853797898808	82e70db8457a1c911bc1245335cd35f4	Maestro	34.158666023923459	-118.21830116336271
42075	2020-08-03 08:07:44	2020-08-03	Mrs. Lea Collier	mrs.lea.collier@warmmail.com	Los Angeles	California	4864837924702	a21eb5fd9207a97a9bfaac6aabdf7d2e	Maestro	34.1144082871597263	-118.374126545059681
42076	2020-08-03 08:08:05	2020-08-03	Domonique Rosenbaum	domonique.rosenbaum@woohoo.com	San Francisco	California	4552790548257375	5625d13156c96ef82d5c4c531a6651a6	JCB 16 digit	37.7837357307906956	-122.425611654305271
42077	2020-08-03 08:12:00	2020-08-03	Manson Blanda-Klein	manson.blanda.klein@geemail.com	Miami	Florida	869947861546734070	a92a77452fcd59ee658d843a4e1fb284	JCB 16 digit	25.8095795790337057	-80.1247631540860965
42078	2020-08-03 08:17:05	2020-08-03	Ota Hayes	ota.hayes@woohoo.com	Sugar Land	Texas	869942029173223768	b3030578ec59ee19454eecbdea73dd04	Maestro	29.6270146385353037	-95.6859807734385157
42079	2020-08-03 08:20:36	2020-08-03	Berlin Hansen	berlin.hansen@geemail.com	Oakland	California	3049711495158654	6c57303cf01cb01ef627ba0ec98a0cc8	Maestro	37.8063603717519499	-122.245364340044333
42080	2020-08-03 08:25:29	2020-08-03	Gaven Walter	gaven.walter@woohoo.com	San Francisco	California	4921973127415	1699363e6c2f1865d2ea6a284578ede8	VISA 16 digit	37.741291794990282	-122.420146425278702
42081	2020-08-03 08:38:28	2020-08-03	Dr. Catrina Daugherty	dr.catrina.daugherty@geemail.com	Houston	Texas	3733775879328266	1598e3e68874738fd9d65b112c6e8a1e	American Express	29.6936891335140913	-95.3237160378150605
42082	2020-08-03 08:39:25	2020-08-03	Gunda Lynch-Ankunding	gunda.lynch.ankunding@geemail.com	Plano	Texas	869948698933985934	af2f6a374e69d69dbbfdc3576c4ee77d	Voyager	33.0542398435615041	-96.7928619787279558
42083	2020-08-03 08:48:58	2020-08-03	Dessie Halvorson-Breitenberg	dessie.halvorson.breitenberg@geemail.com	Milwaukee	Wisconsin	3002979189650073	1984b25f8219d04261fbd03bf230a482	American Express	43.0065113501708964	-88.0308989520285365
42084	2020-08-03 08:52:22	2020-08-03	Khalilah Wilkinson PhD	khalilah.wilkinson.phd@geemail.com	Fayetteville	North Carolina	869985940340208680	fdf99cad19d83921fbcc64ff3318069f	Discover	35.1496516492471116	-78.9739311322234556
42085	2020-08-03 08:54:17	2020-08-03	Berdie Gleason DVM	berdie.gleason.dvm@geemail.com	San Francisco	California	6011016082454261140	6e117bc6e758fdae086a4f06ba1adb86	JCB 15 digit	37.7715645257236403	-122.460750729968353
42086	2020-08-03 08:59:42	2020-08-03	Esco Bernier Sr.	esco.bernier.sr.@geemail.com	San Francisco	California	3528671882619543704	1591e9c66b4130f3eadd37097e6d8833	Voyager	37.7713088433755715	-122.407755876695617
42087	2020-08-03 09:00:22	2020-08-03	Ms. Annemarie Price DVM	ms.annemarie.price.dvm@geemail.com	Springfield	Illinois	4819979101060628	90fd9bbf41bfe3dd4ad6bdc85ee54c50	Diners Club / Carte Blanche	39.7239557362780005	-89.7445727988615545
42088	2020-08-03 09:07:27	2020-08-03	Bea Hegmann MD	bea.hegmann.md@geemail.com	Pembroke Pines	Florida	676223519791307	42830a7b692626dee69c23fe1695850f	Diners Club / Carte Blanche	26.0323440142013141	-80.4051837873548294
42089	2020-08-03 09:31:53	2020-08-03	Dr. Randy Macejkovic I	dr.randy.macejkovic.i@warmmail.com	Los Angeles	California	4924206941083426	2ce0239113a4ff0f2ddda2cf5db99b1a	Discover	34.0452455609902742	-118.484613247214995
42090	2020-08-03 09:34:30	2020-08-03	Anjanette Connelly	anjanette.connelly@warmmail.com	Durham	North Carolina	4431418020100684	920faae27f64da9ff7cbbe789a5dd57c	VISA 13 digit	35.9390720348119714	-78.9082502358496214
42091	2020-08-03 09:36:49	2020-08-03	Angelita Cummings	angelita.cummings@geemail.com	Winston–Salem	North Carolina	4412711622930471	f2dd42a401c20a30ba4f72d415ae55a7	JCB 16 digit	36.0903756493467824	-80.2930680156815697
42092	2020-08-03 09:38:28	2020-08-03	Buffy Ebert	buffy.ebert@geemail.com	Tulsa	Oklahoma	3415811515989948	e2588988b667492565b33546b1354709	Diners Club / Carte Blanche	36.1570957654058915	-95.892113156891611
42093	2020-08-03 09:41:46	2020-08-03	Ulises Bins Sr.	ulises.bins.sr.@warmmail.com	Oakland	California	3088616573634063699	40b99970772411fc90e71c27ac5c1552	VISA 13 digit	37.8055206078312196	-122.243590072996795
42094	2020-08-03 09:48:43	2020-08-03	Mafalda Cronin	mafalda.cronin@woohoo.com	Carrollton	Texas	52224799276012959	7dc7c9023bdbf127f24b6e536588c83a	VISA 13 digit	33.0678973321724641	-96.9424434458233435
42095	2020-08-03 09:59:46	2020-08-03	Nelie Schuppe	nelie.schuppe@geemail.com	San Francisco	California	4545794170674	cdcc70e46e67314947c9a441a6866e5c	JCB 15 digit	37.7409682365206649	-122.443073742144932
42096	2020-08-03 10:14:35	2020-08-03	Mamie Bruen	mamie.bruen@woohoo.com	Escondido	California	6011164195198955874	c53a6e09d5171883204603001ada288f	Voyager	33.2221616490505625	-116.976417816407974
42097	2020-08-03 10:15:04	2020-08-03	Grace Windler	grace.windler@geemail.com	Los Angeles	California	4519223352872	f29031c413a917b32cd2d2f219f9b2a1	JCB 15 digit	34.0612961171526436	-118.431934870406238
42098	2020-08-03 10:23:50	2020-08-03	Luanne Kautzer	luanne.kautzer@woohoo.com	Brownsville	Texas	4192643078894123	8d1d47f5f55c1c3d1dbb5975a331f79b	Voyager	25.956039737824721	-97.3621047888603073
42099	2020-08-03 10:25:32	2020-08-03	Cornell Upton-Dooley	cornell.upton.dooley@geemail.com	Phoenix	Arizona	6011971579904616396	d9965860d1a8b99f4942b254f2026942	American Express	33.6651147767834402	-112.022159943536309
42100	2020-08-03 10:25:55	2020-08-03	Mustafa Rice	mustafa.rice@woohoo.com	Fort Worth	Texas	3337316908198582457	d56639f49aa20644fdf87d0401f07a16	Discover	32.8141637313235535	-97.3429621320504737
42101	2020-08-03 10:26:28	2020-08-03	Lesli Thompson	lesli.thompson@warmmail.com	San Francisco	California	3096764158032521439	5d0fe81604346598abcd7ebb269ecde4	Voyager	37.8170919432985642	-122.384293186409209
42102	2020-08-03 10:27:12	2020-08-03	Nathanial Ferry	nathanial.ferry@warmmail.com	San Francisco	California	3453336428113462	9017361877d71ae443a39c126acf33f4	Maestro	37.7376620183949925	-122.430151076860582
42103	2020-08-03 10:31:48	2020-08-03	Mr. Brennan Heller	mr.brennan.heller@warmmail.com	Berkeley	California	4360836536055834	08dd42042f00b6b04cf49de7a68e8a66	Mastercard	37.8736363684350152	-122.287229956924349
42104	2020-08-03 10:35:52	2020-08-03	Oral Littel	oral.littel@geemail.com	Charlotte	North Carolina	3088110085384464184	5d9a50b429db30cf96fa7a8fc9265ab4	VISA 16 digit	35.1254294572185728	-80.7402951180879001
42105	2020-08-03 10:35:58	2020-08-03	Ginger Kub	ginger.kub@geemail.com	Fontana	California	6011154904929255047	cdd8219eeb114637536a40b04caea3cc	JCB 16 digit	34.1295621063709262	-117.546240584021064
42106	2020-08-03 10:37:49	2020-08-03	Parlee Conn	parlee.conn@woohoo.com	Los Angeles	California	501893384689639	a83152e0a9caf8f6ffa57b458cb90eb2	JCB 15 digit	33.9365397089958165	-118.356962480302144
42107	2020-08-03 10:39:52	2020-08-03	Mr. Daniel Stehr	mr.daniel.stehr@geemail.com	Inglewood	California	4989797843087	4bf8d7a973914b64366dacd4401f1d22	VISA 16 digit	33.9403717243824161	-118.338829661862178
42108	2020-08-03 10:42:36	2020-08-03	Brady Langosh	brady.langosh@geemail.com	New York	New York	180017122821938787	7f4da42a3199e631f180946a4e7e95d2	JCB 16 digit	40.6762943633589913	-74.0340340011648834
42109	2020-08-03 10:49:42	2020-08-03	Dr. Darrin Koelpin	dr.darrin.koelpin@geemail.com	Waco	Texas	54954562492439810	b9be98bb49bff0f0330aec8d4bebe5eb	American Express	31.5740112974051357	-97.1891809189356906
42110	2020-08-03 10:53:29	2020-08-03	Ms. Germaine Weissnat	ms.germaine.weissnat@woohoo.com	San Francisco	California	4280531142299242	c9fa60e701954fbe4113fadbc3997e53	Voyager	37.7759176362265023	-122.49179080158774
42111	2020-08-03 11:00:13	2020-08-03	Selmer O'Connell	selmer.o'connell@geemail.com	Sterling Heights	Michigan	869971917142926236	01cde23f476183adccace6b9a659e481	JCB 15 digit	42.5017326504074049	-83.0032450286831676
42112	2020-08-03 11:00:38	2020-08-03	Pepper Bosco	pepper.bosco@warmmail.com	New York	New York	3011250860087840	5b30caae8f621db76a70e7cf50c492f8	American Express	40.6018897467050692	-74.0099045629043104
42113	2020-08-03 11:05:09	2020-08-03	Fabian Kirlin	fabian.kirlin@warmmail.com	Plano	Texas	3731132470124144	e441c0c025ce3116c769ad111333fb94	VISA 16 digit	33.1455955134790443	-96.7355645821146624
42114	2020-08-03 11:13:01	2020-08-03	Chesley Osinski	chesley.osinski@geemail.com	Indianapolis	Indiana	3042571187583511	bc9edfc2b9677c058d7d76e26fb0354b	Discover	39.8549700860872846	-86.0856739578969723
42115	2020-08-03 11:21:48	2020-08-03	Mr. Kameron Altenwerth DDS	mr.kameron.altenwerth.dds@woohoo.com	Austin	Texas	869987002337367561	e69f4457a18a867168febe92c8582cb9	JCB 15 digit	30.3762131657112384	-97.7813545902032502
42116	2020-08-03 11:23:29	2020-08-03	Cristobal Rutherford	cristobal.rutherford@geemail.com	New York	New York	55088561888794365	b2439f57ef6d81e729e866cb59474762	JCB 16 digit	40.6418324317075275	-74.0048937016528043
42117	2020-08-03 11:25:36	2020-08-03	Alena Herzog	alena.herzog@woohoo.com	Salem	Oregon	4558156234354799	53cfdc149f6886989071d5c60e139ab3	Maestro	44.8709622246015769	-123.044084075341743
42118	2020-08-03 11:30:50	2020-08-03	Gwen Greenfelder	gwen.greenfelder@geemail.com	Anaheim	California	3036526718022179	abaddf661e9c2913f2ffd14e542100a5	American Express	33.9249013564381769	-117.749033173473919
42119	2020-08-03 11:42:24	2020-08-03	Illya Rowe	illya.rowe@geemail.com	Denton	Texas	210007067373998519	946f3095ce6b643c9c0c180ed4d05ed2	American Express	33.132504007293285	-97.0829136817842766
42120	2020-08-03 11:59:52	2020-08-03	Callie Ebert	callie.ebert@geemail.com	Seattle	Washington	4266857989669488	9f8fdd35b8ccc34794ca187606e43747	Maestro	47.5609672031290813	-122.412826779896022
42121	2020-08-03 12:06:56	2020-08-03	Phoebe Ryan	phoebe.ryan@geemail.com	Detroit	Michigan	869980208167840679	c4c55ccaa104dec282ef1b60cd0f4119	VISA 16 digit	42.3418482714723794	-83.2002465196538736
42122	2020-08-03 12:07:32	2020-08-03	Norwood Klein	norwood.klein@geemail.com	Albuquerque	New Mexico	3498361921242748	562c279802b8a7485dc3b5e9897f8954	VISA 16 digit	35.1943066807597873	-106.612679622189702
42123	2020-08-03 12:16:10	2020-08-03	Gaylord Osinski-Kautzer	gaylord.osinski.kautzer@geemail.com	Knoxville	Tennessee	3096300135815772026	495dfc9bf6fd274b98856a354a8e392e	JCB 16 digit	35.9678482428256459	-83.9489072167530566
42124	2020-08-03 12:27:21	2020-08-03	Nelia Smitham	nelia.smitham@warmmail.com	Fort Worth	Texas	4954532506732278	212f0a3279e7666e3a43a6e504d49728	JCB 16 digit	32.8393298125416067	-97.3167756927952183
42125	2020-08-03 12:35:46	2020-08-03	Ambers Ondricka	ambers.ondricka@geemail.com	Visalia	California	869910879174955893	dfb8a63427ddb572812acee0839b8489	VISA 16 digit	36.3678356987845177	-119.289038547467072
42126	2020-08-03 13:01:54	2020-08-03	Eldred Marquardt MD	eldred.marquardt.md@geemail.com	Albuquerque	New Mexico	3459891892367477	c4ea8c76d5f808148d42147830788a67	JCB 15 digit	35.1754039203416582	-106.596839356848605
42127	2020-08-03 13:17:03	2020-08-03	Dr. Lamarcus Ward	dr.lamarcus.ward@woohoo.com	Houston	Texas	3096231832427809899	2453c39c458774c771bf8a4887b3953e	American Express	29.7388605318576111	-95.3159538588501505
42128	2020-08-03 13:20:39	2020-08-03	Mr. Glynn Leuschke II	mr.glynn.leuschke.ii@geemail.com	Baltimore	Maryland	4922121392176532	7f21313d9bae274d1ff72e1466c22e17	VISA 13 digit	39.2064004955813274	-76.6410448027327647
42129	2020-08-03 13:30:58	2020-08-03	Aryan Lehner	aryan.lehner@geemail.com	Baltimore	Maryland	869945608005434417	6802004501e12270bed8ec9607c0824f	Mastercard	39.2802687301300466	-76.5569552358258534
42130	2020-08-03 13:40:52	2020-08-03	Patience McKenzie-Kovacek	patience.mckenzie.kovacek@geemail.com	Philadelphia	Pennsylvania	3158292324465364520	6a10e2a1654966da4808a482be1295ee	VISA 16 digit	40.0210246765013764	-75.1217188700933036
42131	2020-08-03 13:42:06	2020-08-03	Lia Carroll	lia.carroll@woohoo.com	Pomona	California	4300104186041320	63ed0dd1b4823b24e27628cdfe601d61	VISA 13 digit	34.0757145725693604	-117.833804867878925
42132	2020-08-03 13:45:41	2020-08-03	Dr. Kalen Grimes	dr.kalen.grimes@geemail.com	Chicago	Illinois	51494359865129095	fa014012480ed42a19058a6082ce00be	Voyager	41.7921542524196212	-87.6940544799931274
42133	2020-08-03 13:47:38	2020-08-03	Jabez Schiller-Gottlieb	jabez.schiller.gottlieb@woohoo.com	New York	New York	3088238760545676481	7a4717b24a1883266b830c727568a1cc	VISA 13 digit	40.5719064134396632	-73.8784097252309238
42134	2020-08-03 13:52:52	2020-08-03	Mrs. Bernardine Wuckert DDS	mrs.bernardine.wuckert.dds@geemail.com	San Francisco	California	3781587415132354	2ec64ce2228e87684988f646c618c3a2	American Express	37.7677569244496141	-122.425195347429408
42135	2020-08-03 13:54:42	2020-08-03	Elonzo Hudson IV	elonzo.hudson.iv@geemail.com	Lafayette	Louisiana	3487316408604516	c0df765b95ad6fa52718d1ca57213c57	VISA 13 digit	30.2113049696177249	-92.1111144303660723
42136	2020-08-03 13:54:44	2020-08-03	Hassie Spinka-Mills	hassie.spinka.mills@geemail.com	Phoenix	Arizona	3528873162477325031	5f0a602cd87c691c6607e96fe2d522e4	VISA 16 digit	33.5885501898292489	-112.035965093497566
42137	2020-08-03 13:56:05	2020-08-03	Albertine Langosh DVM	albertine.langosh.dvm@woohoo.com	Aurora	Colorado	4581100237741	4ce5270ac591c903f57d33584c29cd6a	VISA 16 digit	39.6505852507539132	-104.760731640050935
42138	2020-08-03 14:06:15	2020-08-03	Miss Hermina Deckow	miss.hermina.deckow@geemail.com	Costa Mesa	California	51607181301959495	812df69fbadd1b88de3a15e51773bfd6	JCB 16 digit	33.5978161776453277	-117.925251530795549
42139	2020-08-03 14:18:39	2020-08-03	Mrs. Ever Wilderman	mrs.ever.wilderman@geemail.com	Elk Grove	California	4380483141865426	31c1ef4b2e2ff12e53cb92510b3517b7	VISA 13 digit	38.4465466180633726	-121.346441336758446
42140	2020-08-03 14:30:46	2020-08-03	Andrew Casper	andrew.casper@geemail.com	St. Louis	Missouri	4461387435674	ed354d18913d82ea085298d3a91a62d8	Maestro	38.5650507011141599	-90.2437909696254934
42141	2020-08-03 14:47:25	2020-08-03	Mercy Jacobs PhD	mercy.jacobs.phd@geemail.com	Henderson	Nevada	4925476435952084	36a12f897d8c3ba52246e2b73b51acb6	Voyager	36.08850695532076	-115.041806471316889
42142	2020-08-03 14:54:24	2020-08-03	Buena Kuhlman	buena.kuhlman@woohoo.com	San Diego	California	676206063131707	3dca287f080bf162b4e46c873116b63a	American Express	32.7971242743611313	-117.214728055745368
42143	2020-08-03 14:58:02	2020-08-03	Patience Kub	patience.kub@geemail.com	Odessa	Texas	4660359843027	964dc685d6779093b48f572fe0f24fd3	Maestro	31.9131196585960701	-102.378781155605239
42144	2020-08-03 15:04:36	2020-08-03	Jameel Reichert	jameel.reichert@geemail.com	Charlotte	North Carolina	53906504696184619	e91564f127c07c3ad1d646ce8859a13e	Mastercard	35.2540285264395195	-80.779857538122684
42145	2020-08-03 15:06:12	2020-08-03	Mrs. Clotilda Weimann	mrs.clotilda.weimann@geemail.com	Garden Grove	California	4085863293225503	1091c2d5de83715037cc865326e9c222	Discover	33.7397631779603628	-118.019588120236989
42146	2020-08-03 15:07:18	2020-08-03	Dr. Liddie Bahringer	dr.liddie.bahringer@woohoo.com	Long Beach	California	3096900740973070032	d884ba7ab9563a4694706e43e884d28e	JCB 16 digit	33.8524894431985857	-118.179021401439982
42147	2020-08-03 15:11:59	2020-08-03	Sherron Dietrich	sherron.dietrich@geemail.com	Tampa	Florida	4490060409186039	b7f1633127f050b106b1926b3f3cdf98	VISA 16 digit	28.0528498676720979	-82.5776020888917088
42148	2020-08-03 15:14:41	2020-08-03	Darcy Mills	darcy.mills@warmmail.com	Hartford	Connecticut	3751529111407645	5da380c4a705fa66a3b5467c61f3f554	Voyager	41.8193243741538367	-72.775981801504642
42149	2020-08-03 15:15:45	2020-08-03	Mr. Aloys Reynolds DVM	mr.aloys.reynolds.dvm@warmmail.com	San Francisco	California	3045599677133924	c38fcded4f8a1bfc94dcdbc8274e71cc	JCB 16 digit	37.7621042967506924	-122.437867334385714
42150	2020-08-03 15:19:14	2020-08-03	Buna Carter	buna.carter@warmmail.com	San Jose	California	52434948647562517	70775ae4ede9b4fe6b040818e6c53759	JCB 15 digit	37.3035705868907286	-121.722879509323832
42151	2020-08-03 15:20:22	2020-08-03	Kristin Lindgren IV	kristin.lindgren.iv@geemail.com	Chicago	Illinois	3158176782677096621	6175660d866144bdb35e55373e442ff3	Diners Club / Carte Blanche	41.8559218397200112	-87.6349179151032018
42152	2020-08-03 15:29:46	2020-08-03	Josie Mosciski	josie.mosciski@geemail.com	Los Angeles	California	6011677842326267926	823b614dff84d2a4f81c29b1ff3e5daa	Discover	34.0964839752163726	-118.483468555565167
42153	2020-08-03 15:33:34	2020-08-03	Miss Gertha Kuhlman DDS	miss.gertha.kuhlman.dds@geemail.com	Washington	District of Columbia	4849000577024453	6ca4b2c3c6ba28e74b50aa21d1adb35e	American Express	38.9447936366576712	-77.0884352517061018
42154	2020-08-03 15:36:47	2020-08-03	Abner Little	abner.little@warmmail.com	Chicago	Illinois	4912343499946383	1266f2c2b8f9101ff1bbaeff86ac9b0b	Voyager	41.83902224179581	-87.6534040640603678
42155	2020-08-03 15:46:42	2020-08-03	Knute Walter-Friesen	knute.walter.friesen@geemail.com	Long Beach	California	502057163589237	cf5d3f5aec6df62808ee5696537d9ff3	American Express	33.8604254173867361	-118.165054578396678
42156	2020-08-03 16:16:23	2020-08-03	Benson O'Reilly	benson.o'reilly@geemail.com	Charlotte	North Carolina	3088360487387083150	f0dfecf3803f946ab8de0f5373f8f310	American Express	35.1967268261380468	-80.7833626086302132
42157	2020-08-03 16:23:44	2020-08-03	Amie Wolf	amie.wolf@geemail.com	Virginia Beach	Virginia	869951175552860957	9b914dbdfdd344ec926ec0702518c89b	Diners Club / Carte Blanche	36.685478385044263	-76.1077765919871609
42158	2020-08-03 16:24:22	2020-08-03	Skye Rohan	skye.rohan@woohoo.com	San Francisco	California	502073392906498	d97da641f130cc7da735b488d701e337	JCB 16 digit	37.7714453571560398	-122.440194458195407
42159	2020-08-03 16:25:45	2020-08-03	Eloise Stanton	eloise.stanton@geemail.com	San Diego	California	6011900695646386035	150622121e6d21941cbcb38b515f9722	VISA 13 digit	32.7483429300665847	-117.071128456844022
42160	2020-08-03 16:33:36	2020-08-03	Hill Stoltenberg	hill.stoltenberg@geemail.com	Jacksonville	Florida	3158975928525957588	87c38e55babf15ecec2748690912edb5	Maestro	30.4232814992830143	-81.609581320274998
42161	2020-08-03 16:35:20	2020-08-03	Clovis Bruen DDS	clovis.bruen.dds@geemail.com	Houston	Texas	3428727085299671	3a91fb76ff6659ca8bc1e6d1ead52651	Mastercard	29.6997875209044651	-95.2965115874554982
42162	2020-08-03 16:38:21	2020-08-03	Dusty Monahan DDS	dusty.monahan.dds@woohoo.com	Fayetteville	North Carolina	53178095040825636	a33953c1e78f6fc96f549bd01de6ff94	Voyager	35.0112516805782903	-79.041599788017578
42163	2020-08-03 16:38:45	2020-08-03	Amberly Hoppe	amberly.hoppe@geemail.com	Philadelphia	Pennsylvania	4033239420954518	f2cfcd41113af747f011758c96c39f61	VISA 13 digit	39.920715935198217	-75.0687569103568819
42164	2020-08-03 16:40:47	2020-08-03	Ryne Mohr	ryne.mohr@woohoo.com	Little Rock	Arkansas	869932694005139151	6cd12727bdbafb57f92d9825487ef6e0	Mastercard	34.7583452545382059	-92.3799499846868173
42165	2020-08-03 16:42:43	2020-08-03	Dominick Bashirian	dominick.bashirian@geemail.com	Charlotte	North Carolina	3403156777791168	20a5cccb08d8916a8a0a4227eea70158	Voyager	35.1444728825960269	-80.9064775034263732
42166	2020-08-03 16:53:29	2020-08-03	Lovie Schultz	lovie.schultz@woohoo.com	New York	New York	3021030472760749	068edf98db082d472865cf731c8c1600	VISA 16 digit	40.6371694244202217	-73.9113098787970841
42167	2020-08-03 17:06:06	2020-08-03	Kelly Roberts	kelly.roberts@geemail.com	West Covina	California	4986620422081128	65f10aab998cd34c64720bc29b689d45	VISA 16 digit	34.0179244299527284	-117.984967609781393
42168	2020-08-03 17:10:39	2020-08-03	Grayling Nolan	grayling.nolan@geemail.com	Louisville	Kentucky	3412878208410576	98a160940cf543e896107fd713598ad0	American Express	38.0761182157225875	-85.6656997790630896
42169	2020-08-03 17:11:27	2020-08-03	Russell Mitchell Sr.	russell.mitchell.sr.@woohoo.com	Milwaukee	Wisconsin	4922361846863661	38eacf94bbde36d0f25dfc1c1f27647f	JCB 16 digit	43.0265905163802174	-87.9960053222820164
42170	2020-08-03 17:13:46	2020-08-03	Dr. Moises Kutch	dr.moises.kutch@woohoo.com	Buffalo	New York	6011669611519877845	5c09f1820e18f0c121971b71203c3790	JCB 16 digit	42.9888013266213207	-78.8214802714463332
42171	2020-08-03 17:24:17	2020-08-03	Gerald Oberbrunner	gerald.oberbrunner@geemail.com	El Monte	California	3337043318645723920	b086ac1eca72e54480167f3e72e642b3	JCB 16 digit	34.0424079191595297	-118.014092874460289
42172	2020-08-03 17:25:40	2020-08-03	Josiah Erdman	josiah.erdman@warmmail.com	Miami Gardens	Florida	3017415758810165	18dd6cd432efc0bd4803b26052f0dde6	JCB 15 digit	26.021390770323201	-80.1606730001293073
42173	2020-08-03 17:27:41	2020-08-03	Karren Jacobson DDS	karren.jacobson.dds@geemail.com	Newark	New Jersey	6011147275951412123	e78bcae8dd950fb597d83c0d0dc83ae7	VISA 16 digit	40.7570822414856408	-74.1171555075537469
42174	2020-08-03 17:29:16	2020-08-03	Mr. Gale Parker	mr.gale.parker@warmmail.com	Orlando	Florida	3096588496436646210	ba931a9d27492ac7742e540f2fa9ba08	Diners Club / Carte Blanche	28.4014899649921801	-81.3477950555704581
42175	2020-08-03 17:31:25	2020-08-03	Cassidy Schneider PhD	cassidy.schneider.phd@geemail.com	Plano	Texas	4967090456302	85e7234d600fa678aa23b12d277d2264	Voyager	32.9974450519859843	-96.7274035860966848
42176	2020-08-03 17:35:22	2020-08-03	Lisbeth Pouros	lisbeth.pouros@warmmail.com	Denver	Colorado	210081252310865984	94b68e54594a6524807e3b41268e35a9	JCB 16 digit	39.780085002636163	-104.975222716737917
42177	2020-08-03 17:44:02	2020-08-03	Audy Gottlieb	audy.gottlieb@geemail.com	Davie	Florida	3714228884617797	bf1665325a3fcff1afd9d38a9b04b553	JCB 15 digit	26.121062657775731	-80.3114871395193006
42178	2020-08-03 17:46:45	2020-08-03	Dink Dach DDS	dink.dach.dds@geemail.com	Arlington	Texas	210020661600675495	573113289122efbfb86de923bc5bd215	VISA 16 digit	32.7124739087902014	-97.070019716725497
42179	2020-08-03 17:54:12	2020-08-03	Mozell Lakin-Schowalter	mozell.lakin.schowalter@geemail.com	San Mateo	California	210088271461632699	cf6856afe0937e6dfb1d38ef6e26fc74	Mastercard	37.4767827035740027	-122.232528679989642
42180	2020-08-03 17:54:20	2020-08-03	Miss Starla Baumbach	miss.starla.baumbach@geemail.com	Phoenix	Arizona	869900733396957603	5e4d479d7a327acba282f50ec661901c	VISA 16 digit	33.547969578944894	-112.088896527925883
42181	2020-08-03 17:59:42	2020-08-03	Burrel Parisian	burrel.parisian@geemail.com	Berkeley	California	6011408743265816754	72b53b23ec38c09f1b5dad6dc324c30d	Maestro	37.8759910205773451	-122.289093820458135
42182	2020-08-03 18:11:35	2020-08-03	Mrs. Rosaria Bradtke	mrs.rosaria.bradtke@geemail.com	Bakersfield	California	869903606431014241	8651f84f00a9ada36cce8d270516c34e	American Express	35.4136212103709553	-119.023626656717809
42183	2020-08-03 18:19:29	2020-08-03	Dr. Deondre Shields V	dr.deondre.shields.v@geemail.com	Fresno	California	3027294088609815	1d8e5503853683223a048caee48dec2f	Mastercard	36.8735842883925855	-119.816313312865432
42184	2020-08-03 18:27:48	2020-08-03	Shane Lynch	shane.lynch@geemail.com	Virginia Beach	Virginia	51546511019199949	55bffd3f2061532cbb9245bbeda0d7ed	VISA 16 digit	36.7813355119619558	-75.9417335294790519
42185	2020-08-03 18:29:09	2020-08-03	Zula Bashirian-Koepp	zula.bashirian.koepp@geemail.com	Glendale	Arizona	51747125316799389	d97bce790b5baf63c581407092d2c146	JCB 15 digit	33.6152953844279025	-112.259901684315494
42186	2020-08-03 18:32:20	2020-08-03	Leonora Kling PhD	leonora.kling.phd@geemail.com	Jacksonville	Florida	3158982131479297033	99e322588e7d31ab0f12eca6fbdf42a2	American Express	30.3810688514314577	-81.6389513123393158
42187	2020-08-03 18:36:59	2020-08-03	Dr. Scot Davis	dr.scot.davis@geemail.com	San Francisco	California	3003676165234935	7aa655d2842a2654a995d5b78e1bca11	JCB 16 digit	37.759630772029702	-122.460306767824875
42188	2020-08-03 18:43:31	2020-08-03	Meghann Jast-Effertz	meghann.jast.effertz@geemail.com	New York	New York	3088414162642770133	ba2daa5081f49eb97980516561bc649a	Discover	40.756216102488338	-73.8681845541939168
42189	2020-08-03 18:57:34	2020-08-03	Antonetta Ullrich PhD	antonetta.ullrich.phd@geemail.com	Memphis	Tennessee	210091734771754128	d9f1eec2a570f30b1dbf18bd6d148690	Maestro	35.1030450271975241	-89.9066993921320972
42190	2020-08-03 19:05:43	2020-08-03	Marilyn Johnson	marilyn.johnson@warmmail.com	Provo	Utah	4740324490145033	6cbaf56410752822a02774f458b3ee9c	Discover	40.2275701795492324	-111.704064014568189
42191	2020-08-03 19:16:06	2020-08-03	Mr. Elvis Gutkowski V	mr.elvis.gutkowski.v@geemail.com	Los Angeles	California	6011593310819082104	2ebcb7861981719ebcfb6a91a8a1f2b4	VISA 13 digit	33.9209416608657648	-118.340931020396937
42192	2020-08-03 19:28:21	2020-08-03	Fed Sawayn	fed.sawayn@woohoo.com	Hillsboro	Oregon	3001304576823954	ec28cbc7f9354442215be7295cd76494	Discover	45.5717031945213691	-122.915205185876033
42193	2020-08-03 19:28:30	2020-08-03	Humberto Hills	humberto.hills@geemail.com	San Francisco	California	3158722722242529002	0adae306622f2c62a748b1e8ba2e9901	JCB 16 digit	37.7772711818391826	-122.450613741998581
42194	2020-08-03 19:34:21	2020-08-03	Alexander Kuphal	alexander.kuphal@geemail.com	Berkeley	California	3008469949418981	801a41e50b0e44ed12b9d126327237c4	VISA 16 digit	37.8565435444175478	-122.272349661768047
42195	2020-08-03 19:34:33	2020-08-03	Bryan Hettinger	bryan.hettinger@geemail.com	Atlanta	Georgia	3420530572364919	b6c0ff2761cdb6824c9aea4c6a4990a1	VISA 16 digit	33.8581860116492948	-84.4299133406531155
42196	2020-08-03 19:36:11	2020-08-03	Mr. Kerwin Bosco Sr.	mr.kerwin.bosco.sr.@geemail.com	Madison	Wisconsin	180021959720337437	3fc3e838ea6ab3f991c911afa7efa091	JCB 16 digit	43.1480485602721586	-89.4114562712028658
42197	2020-08-03 19:36:15	2020-08-03	Giada Gleason	giada.gleason@warmmail.com	Miami Gardens	Florida	3096158231651463599	9f5ba34ef8b80e4b856920270f0f6d39	Discover	25.9626507208622961	-80.2567389475893265
42198	2020-08-03 19:48:25	2020-08-03	Bryon West-Borer	bryon.west.borer@geemail.com	Berkeley	California	180037227467649428	59e3bd9e9ea10eab45c8b76f34404552	VISA 13 digit	37.8776190569169273	-122.301268166741153
42199	2020-08-03 19:50:55	2020-08-03	Mrs. Hailey Hills	mrs.hailey.hills@geemail.com	Lansing	Michigan	869973310378681832	c73e802894ebb6c9d415f240a085db5c	Voyager	42.6803988561809078	-84.5249467359047344
42200	2020-08-03 19:58:48	2020-08-03	Dr. Orris Kihn DVM	dr.orris.kihn.dvm@geemail.com	Denver	Colorado	3112751777883116786	3645ac58072e40c0041f493f75975a85	American Express	39.8117656682204455	-104.90784792720936
42201	2020-08-03 20:05:36	2020-08-03	Lashunda Crona PhD	lashunda.crona.phd@warmmail.com	New York	New York	869922641918714127	1d41d742164cb9f4894fba49d5cf46a4	Maestro	40.6923317945320164	-73.9309511218581292
42202	2020-08-03 20:06:46	2020-08-03	Thora Spencer	thora.spencer@geemail.com	New York	New York	3008916860587327	98f2fbfa1b768e65cf56ce42b8e6fd87	Maestro	40.6641511041428885	-74.0026314770698548
42203	2020-08-03 20:07:04	2020-08-03	Lew Fritsch	lew.fritsch@geemail.com	Boston	Massachusetts	3337245666591629764	a09501f2136cd1b8a593276e8951b6a9	Diners Club / Carte Blanche	42.3358576213642976	-71.1128490124780654
42204	2020-08-03 20:07:32	2020-08-03	Dr. Devaughn Pagac	dr.devaughn.pagac@geemail.com	Tampa	Florida	4424903737926082	24556b4b58db5b5d1874a7580301ad9b	VISA 13 digit	27.9725088745936752	-82.5377708927009195
42205	2020-08-03 20:13:54	2020-08-03	Phylicia Osinski	phylicia.osinski@woohoo.com	Simi Valley	California	3754599821744899	62c3512864d285728ac18c2754e028ad	American Express	34.3008119391981481	-118.801968286618603
42206	2020-08-03 20:18:09	2020-08-03	Chelsey Kuhlman	chelsey.kuhlman@geemail.com	San Francisco	California	55391730379190985	7a52cc302bb98549e4c452340ef1a561	Diners Club / Carte Blanche	37.7727392419344028	-122.476897011480773
42207	2020-08-03 20:20:15	2020-08-03	Jovanni Bergnaum	jovanni.bergnaum@geemail.com	Boston	Massachusetts	4482119376051	ec5520f3784c2d14531e34b6f46582f0	American Express	42.3753495630510173	-70.9536299671463695
42208	2020-08-03 20:43:29	2020-08-03	Miss Callie Hegmann	miss.callie.hegmann@geemail.com	Fayetteville	North Carolina	3701243979185696	0d215ffb77b38854564605cdc1ca4657	Voyager	35.0736064037095758	-78.9391085272785347
42209	2020-08-03 20:50:27	2020-08-03	Ferman Sanford	ferman.sanford@geemail.com	Los Angeles	California	6011891217465075333	ca68859e7cca1baed5595fe5bfc0714a	Discover	33.9455818538419862	-118.402106725144378
42210	2020-08-03 21:00:55	2020-08-03	Miss Elouise Bernier	miss.elouise.bernier@warmmail.com	Tempe	Arizona	3088194799803658767	b3a58fdbe83b15cf24366cdf56d95996	JCB 15 digit	33.300234415700281	-111.86381190186664
42211	2020-08-03 21:26:05	2020-08-03	Deandra Bruen	deandra.bruen@woohoo.com	San Francisco	California	869957656445855522	4910780b441880fe9cb440d4ae7b0f8a	VISA 13 digit	37.7846260743835174	-122.414074354380901
42212	2020-08-03 21:28:34	2020-08-03	Mrs. Loriann Kihn DDS	mrs.loriann.kihn.dds@geemail.com	Stamford	Connecticut	4470328522605357	f93f601e57c10c2e0fb06101cd31d61d	JCB 16 digit	41.16634221061841	-73.5591449736189134
42213	2020-08-03 21:31:22	2020-08-03	Dwain Dickinson	dwain.dickinson@geemail.com	Fort Wayne	Indiana	3096069545143538256	37b2671912ef38b79575a6897eb736fb	VISA 16 digit	41.1717119992960221	-85.1390236248947758
42214	2020-08-03 21:37:51	2020-08-03	Jereme Bashirian	jereme.bashirian@woohoo.com	Jersey City	New Jersey	4334622466046	66b88b11d7cbe61408854f2cfbcef88e	American Express	40.7863155311845205	-74.1179040736474093
42215	2020-08-03 21:43:35	2020-08-03	Neva Prosacco-Fahey	neva.prosacco.fahey@geemail.com	Arlington	Texas	55816011233536417	e4d1d8ab141f3ae090c24686d27958fe	JCB 15 digit	32.7692658070724434	-97.0575720410354421
42216	2020-08-03 21:43:41	2020-08-03	Barnett Morar	barnett.morar@woohoo.com	Winston–Salem	North Carolina	869906584396279942	cb7a6decb14efb8d8935ac075cdd63e2	VISA 16 digit	36.1755249707724857	-80.2672352046370463
42217	2020-08-03 21:52:57	2020-08-03	Janey Rohan	janey.rohan@woohoo.com	San Francisco	California	4083747289728848	b2a48ee2e5e5e0c7d39621be9863a3ac	JCB 16 digit	37.7427008893174829	-122.43748904376605
42218	2020-08-03 21:57:40	2020-08-03	Zachary Kshlerin	zachary.kshlerin@geemail.com	New York	New York	3096728821327413076	f69383a6371d8692aa0b5868eb6daabd	Diners Club / Carte Blanche	40.7565357247125348	-73.9112925324950396
42219	2020-08-03 21:58:57	2020-08-03	Theophile Batz	theophile.batz@geemail.com	San Francisco	California	4621680309893293	f5cf8325202f33c73d151bbdab358771	JCB 16 digit	37.7758692763288124	-122.425283929819727
42220	2020-08-03 22:02:08	2020-08-03	Claus Rath II	claus.rath.ii@geemail.com	New York	New York	676190639004093	da9468b607cf2efdae96cf4a25255008	Discover	40.7554304556678986	-73.9523965084355268
42221	2020-08-03 22:14:09	2020-08-03	Mrs. Norah Klocko	mrs.norah.klocko@geemail.com	Chicago	Illinois	3054901356731476	0b51e0759de48a4fcd2bbc4ba6bbae07	Discover	41.8490140351302955	-87.6425248449697989
42222	2020-08-03 22:18:46	2020-08-03	Aaliyah Ortiz-Crona	aaliyah.ortiz.crona@geemail.com	Denver	Colorado	4474620781218682	8bcae1b38f3fa2d5d934d459281c1d4b	Mastercard	39.7063593117106706	-104.847443691432858
42223	2020-08-03 22:24:41	2020-08-03	Dr. Oneal Dach DVM	dr.oneal.dach.dvm@geemail.com	El Paso	Texas	6011232116575448489	97e4c78a0e7a0f9417a6047b7fb53ec5	American Express	31.8400947748977714	-106.478580280251805
42224	2020-08-03 22:29:56	2020-08-03	Latrice Nikolaus	latrice.nikolaus@geemail.com	Hayward	California	4381725756316247	452e3696178c11621658140a0c13b0b9	Maestro	37.5549502126395751	-122.023807975023615
42225	2020-08-03 22:31:37	2020-08-03	Mr. Okey Reichel I	mr.okey.reichel.i@geemail.com	New York	New York	4160814200349306	8d65cc3adc1e5526a73200bd00cc74c9	JCB 16 digit	40.6577577884532531	-74.033087808814642
42226	2020-08-03 22:36:19	2020-08-03	Laurel Funk	laurel.funk@warmmail.com	Cincinnati	Ohio	4506403367043739	bd6d252f404be368fa15564534b1c961	VISA 16 digit	39.1639547482829542	-84.5656614657763299
42227	2020-08-03 22:39:36	2020-08-03	Elenora Berge	elenora.berge@geemail.com	San Francisco	California	53232120332713326	e57162db0aebba0ffdd9a584840e9b1a	Discover	37.7946255943878029	-122.43166317453948
42228	2020-08-03 22:41:06	2020-08-03	Dr. Alwin Cartwright	dr.alwin.cartwright@geemail.com	Augusta	Georgia	869989485177210371	95ea4b0fd01d147e1f08f248ac758414	Diners Club / Carte Blanche	33.4157250256948117	-81.9873961070381228
42229	2020-08-03 22:44:37	2020-08-03	Travon Rempel	travon.rempel@woohoo.com	New York	New York	4002236612531515	5286c10136df3d7aeda0a2ef5010971a	VISA 16 digit	40.6985786153692715	-73.9640221660386743
42230	2020-08-03 22:47:44	2020-08-03	Lawton Hoeger	lawton.hoeger@woohoo.com	Phoenix	Arizona	503874696291686	1ce0d5ea48dbedda9524a5f4c5fddcef	Voyager	33.5008134201567671	-112.189328349002082
42231	2020-08-03 22:52:01	2020-08-03	Tavon Kihn-Bergnaum	tavon.kihn.bergnaum@geemail.com	Los Angeles	California	3088423347578355079	6e201894a1422d002243930c579b86c5	Mastercard	34.0259781332552436	-118.311949831153441
42232	2020-08-03 22:52:12	2020-08-03	Stuart Bins III	stuart.bins.iii@geemail.com	Columbus	Georgia	3047354714739798	e024c3e2006b1dc8360b7ab8bb8b3fa2	Discover	32.5771356541708101	-84.8234309534240509
42233	2020-08-03 22:52:51	2020-08-03	Arlyn Erdman	arlyn.erdman@geemail.com	Richmond	Virginia	3034085080196865	70952e719f44ac05e2990ffbda6161e4	JCB 16 digit	37.5440639520749428	-77.4966447183154514
42234	2020-08-03 23:06:36	2020-08-03	Miss Caren Raynor	miss.caren.raynor@geemail.com	San Francisco	California	4293639192768209	c34d9705111bb4bfd7df1992b9a2ac2a	VISA 13 digit	37.7830598306400063	-122.45540178663768
42235	2020-08-03 23:14:24	2020-08-03	Jaydon Koepp	jaydon.koepp@geemail.com	Orange	California	4663238845833	e0d163ba27a5e9cda06e9fe46449f5cf	Maestro	33.7817746391408136	-117.835661761938781
42236	2020-08-03 23:20:45	2020-08-03	Holli Kunde	holli.kunde@geemail.com	Pearland	Texas	4936415869739	7d1f2d8a29dc1df5c85f04bd22421a59	Maestro	29.5112157289210728	-95.3937301494035808
42237	2020-08-03 23:25:36	2020-08-03	Dr. Kiel Parisian	dr.kiel.parisian@geemail.com	San Francisco	California	4643991548696502	58d40eb7fa69c2fdc8f196ef3502ff5c	JCB 16 digit	37.7333294438326234	-122.40204858841787
42238	2020-08-03 23:29:02	2020-08-03	Koby Tillman IV	koby.tillman.iv@geemail.com	Wichita	Kansas	869998685924734701	97346f43368183ed2a1466039a39d134	Mastercard	37.7682354067794961	-97.4397203917816341
42239	2020-08-03 23:30:35	2020-08-03	Kendall Hoeger-Hyatt	kendall.hoeger.hyatt@geemail.com	Daly City	California	180075930126274693	e732370c1d64da1a90705c4d6d3fa054	JCB 16 digit	37.7301665093671517	-122.426044602375484
42240	2020-08-03 23:40:41	2020-08-03	Amiya Hills	amiya.hills@geemail.com	Gilbert	Arizona	4441512244326782	c4b7d08231a46617d6e7955af9e67d50	Discover	33.2835026767916986	-111.799960452378173
42241	2020-08-03 23:44:35	2020-08-03	Shyla Graham PhD	shyla.graham.phd@geemail.com	San Francisco	California	6011488038033164493	74a8bc38f424dedb126061eb543d3813	VISA 16 digit	37.7497888606831538	-122.430965995429631
42242	2020-08-03 23:49:30	2020-08-03	Tyreese Morissette	tyreese.morissette@geemail.com	Philadelphia	Pennsylvania	3096556087966801651	f11263632dce7ca8c4cd7ae194e9b256	Mastercard	39.9478441759437288	-75.063986497455474
42243	2020-08-03 23:55:40	2020-08-03	Hester Abernathy	hester.abernathy@warmmail.com	Miami Gardens	Florida	3734125230370913	e138cf4a3df030c6c3e717fd4b8047e9	VISA 16 digit	26.0463281719885735	-80.3072595384217749
42244	2020-08-03 23:58:35	2020-08-03	Dr. Kipp Kuvalis	dr.kipp.kuvalis@geemail.com	Escondido	California	589362637876673	a04b8ba7771d297d6e5f0b08b95372d5	JCB 15 digit	33.0787783104687918	-117.136784793227903
42245	2020-08-03 23:58:40	2020-08-03	Shira Schamberger DDS	shira.schamberger.dds@geemail.com	New York	New York	3019762811607296	85a0b986700d5b91bbfb4d044140555a	JCB 16 digit	40.6694448962099813	-73.9365398772887801
42246	2020-08-04 00:02:14	2020-08-04	Trudi Streich	trudi.streich@woohoo.com	Tampa	Florida	53603760926233354	1a2ff22f0b100376e473b264c3137cb2	Voyager	27.8791335890650736	-82.4261857789222034
42247	2020-08-04 00:03:10	2020-08-04	Jacey Monahan	jacey.monahan@warmmail.com	Columbus	Georgia	869962670434698606	7937a4cdf179f1c40b91b07bcd916401	VISA 16 digit	32.4939080429773739	-84.8527914374299286
42248	2020-08-04 00:11:22	2020-08-04	Jaron Murazik	jaron.murazik@geemail.com	Anaheim	California	4994498626773539	2ebf48c197d791a061e774ca4a9e871e	JCB 16 digit	33.95037933353521	-117.764327599222213
42249	2020-08-04 00:20:29	2020-08-04	Mr. Zeb Hintz	mr.zeb.hintz@geemail.com	San Francisco	California	55958957753665960	1ed94d30645612b482370a73053ef2d0	Maestro	37.7337038096838242	-122.449665600049144
42250	2020-08-04 00:24:09	2020-08-04	Dondre Ritchie-Thompson	dondre.ritchie.thompson@geemail.com	Temecula	California	3337710963468658703	c1eb3c13db9ad9fc5f0062e54b4e787c	VISA 13 digit	33.5005746609665422	-117.055583167607708
42251	2020-08-04 00:24:54	2020-08-04	Dania Cremin-Von	dania.cremin.von@geemail.com	Lafayette	Louisiana	3791525056024991	da1ce75771a5a1cdb200114595f8edcc	American Express	30.117832631056757	-92.0429093465991315
42252	2020-08-04 00:27:11	2020-08-04	Lenord Kunze III	lenord.kunze.iii@geemail.com	Norfolk	Virginia	210017190344060215	c3ca043905e6d1c49a748d64ce4a88b3	VISA 16 digit	36.8402503204550626	-76.2691920450426721
42253	2020-08-04 00:30:38	2020-08-04	Rome Stanton	rome.stanton@geemail.com	Chicago	Illinois	3721836924451646	fe3ec40c95d87b54b2f4138cf4235b5f	VISA 13 digit	41.928432617599519	-87.72033511665947
42254	2020-08-04 00:37:39	2020-08-04	Merle Yost	merle.yost@woohoo.com	Columbia	South Carolina	55398541152829431	a171752e4606489c5268ca59571ecb4d	VISA 16 digit	33.9778009948585193	-80.880382937427612
42255	2020-08-04 00:56:02	2020-08-04	Marti Stamm	marti.stamm@warmmail.com	Louisville	Kentucky	210093333593185567	1a570eacf5b6fdf5a79f3ba06e77e137	Maestro	38.0869696187224207	-85.5918428225979255
42256	2020-08-04 00:59:29	2020-08-04	Holmes Hartmann	holmes.hartmann@geemail.com	San Francisco	California	3044303718353638	79ec44d76e216a3f10bb8c2e78b5d62b	Discover	37.7581545868118411	-122.432730417004137
42257	2020-08-04 01:08:49	2020-08-04	Damarcus West	damarcus.west@geemail.com	San Diego	California	3777039870791890	00066215f4221d63221f0234852961d1	VISA 16 digit	32.7163199232958277	-117.091628370378174
42258	2020-08-04 01:10:44	2020-08-04	Verle Douglas	verle.douglas@geemail.com	San Francisco	California	3774825504272189	338305f6ae197d0c76e9c0c6146bb8ad	JCB 16 digit	37.7294518346044896	-122.430295682406864
42259	2020-08-04 01:35:31	2020-08-04	Ms. Hermine Koepp PhD	ms.hermine.koepp.phd@warmmail.com	Fremont	California	4607663158303521	778e2ad50bb378f8fd788a5edb25c4a2	Mastercard	37.527994543237611	-121.973000978444517
42260	2020-08-04 01:40:57	2020-08-04	Dr. Dorothea Schmitt PhD	dr.dorothea.schmitt.phd@geemail.com	Augusta	Georgia	3005822636776207	e14ca498850c5485041564f90358db39	American Express	33.3504620367400335	-82.1459952504668394
42261	2020-08-04 01:49:00	2020-08-04	Lollie Heathcote	lollie.heathcote@geemail.com	Greensboro	North Carolina	3404911732679984	8884d21d598e428e7265f6202312fef4	JCB 16 digit	36.1690962695632123	-79.8302737709116172
42262	2020-08-04 01:56:15	2020-08-04	Dr. Crissy Sawayn	dr.crissy.sawayn@geemail.com	Elizabeth	New Jersey	54299272716943068	1fa9c031aadb3728cb2701caeb664189	VISA 16 digit	40.6202859700784131	-74.1702873279750321
42263	2020-08-04 02:06:07	2020-08-04	Johnathan Senger	johnathan.senger@geemail.com	St. Petersburg	Florida	4677780853727161	e8485f779e0c2fff9f7fe15ec4f9bffe	Mastercard	27.8440626306347561	-82.6508321901209655
42264	2020-08-04 02:06:15	2020-08-04	Isom Keebler	isom.keebler@geemail.com	Chicago	Illinois	4486434627853256	473c6454b774bedfd132d8bcca531ee4	VISA 16 digit	41.7486008402261888	-87.6389546459570425
42265	2020-08-04 02:12:36	2020-08-04	Dr. Holden Erdman DVM	dr.holden.erdman.dvm@woohoo.com	San Francisco	California	180015260786645930	5729b9c10a8eae531833399ae6515a87	Diners Club / Carte Blanche	37.7614388771131289	-122.425899858089281
42266	2020-08-04 02:13:00	2020-08-04	Domenico Bruen	domenico.bruen@geemail.com	Oakland	California	4888493568362	a92432418de6e0d024ead54aae58f696	JCB 15 digit	37.8244384392138784	-122.233367248356785
42267	2020-08-04 02:14:52	2020-08-04	Bonita King-Kessler	bonita.king.kessler@geemail.com	McAllen	Texas	55366796529152994	98ab7ffc1f89489f6239e967f71286f0	Mastercard	26.301570295898987	-98.3087664135578905
42268	2020-08-04 02:29:26	2020-08-04	Ms. Stefani Hartmann	ms.stefani.hartmann@geemail.com	San Francisco	California	4148924252965	7691d0c127e64ba3e2504b2b0a3f31e0	Voyager	37.7732062686191554	-122.446310168911964
42269	2020-08-04 02:36:58	2020-08-04	Lorine Herman-Reynolds	lorine.herman.reynolds@geemail.com	Salt Lake City	Utah	4609242892992382	dc4ef369dcfe54aca4ca35e4307566d7	Mastercard	40.8684659415069973	-111.875717264687637
42270	2020-08-04 02:50:58	2020-08-04	Ms. Tabatha Wisoky MD	ms.tabatha.wisoky.md@geemail.com	Denver	Colorado	54763269460677360	d54a618c69cbdf9af094276eaf584b51	JCB 16 digit	39.7107228360190945	-104.921907104669515
42271	2020-08-04 03:00:34	2020-08-04	Rico Labadie	rico.labadie@woohoo.com	Raleigh	North Carolina	3415188482063423	d8bd914fccadf6d4f52e4324e077988b	American Express	35.9215693447407318	-78.5527308639541246
42272	2020-08-04 03:02:23	2020-08-04	Irwin Harris	irwin.harris@geemail.com	San Francisco	California	869929895091433698	8e200759c6057ce87cea560eb603fce9	American Express	37.7586784778140654	-122.450442009837545
42273	2020-08-04 03:15:11	2020-08-04	Burk Reynolds V	burk.reynolds.v@woohoo.com	Modesto	California	869925863990137046	74a96779182ed56f57699022fda81fc9	JCB 16 digit	37.690504168719059	-121.028375546980655
42274	2020-08-04 03:18:25	2020-08-04	Karma Grant	karma.grant@warmmail.com	St. Petersburg	Florida	4875439649461920	07bce20a3746382558bbe85544d1f881	JCB 16 digit	27.7213205738347028	-82.6692433081459228
42275	2020-08-04 03:22:10	2020-08-04	Mr. Waino Kutch MD	mr.waino.kutch.md@woohoo.com	Houston	Texas	3020601430752423	7cb4e9afc40ccfc953952d08478ed3cf	Maestro	29.8678370993196971	-95.440607465386023
42276	2020-08-04 03:34:49	2020-08-04	Jay Johnson-Runte	jay.johnson.runte@geemail.com	St. Louis	Missouri	561286762467917	cdb1c7e3c28dfe1a9381a4f8bb8d1820	VISA 13 digit	38.6862048271734267	-90.3387482484806412
42277	2020-08-04 03:40:21	2020-08-04	Fern Dietrich-Reilly	fern.dietrich.reilly@woohoo.com	Plano	Texas	4623026138924	ceab66ade900036cce399401a94e88be	VISA 13 digit	33.0839968169659429	-96.7904196201540543
42278	2020-08-04 03:43:10	2020-08-04	Gaylord Wolff	gaylord.wolff@geemail.com	New York	New York	6011867602688830731	546ef67f6dc3b708407d7ec23da2fda0	JCB 16 digit	40.7164642069246625	-73.9487732235237871
42279	2020-08-04 03:45:59	2020-08-04	Esperanza Muller DVM	esperanza.muller.dvm@geemail.com	New York	New York	3027861767910944	2af52937c6076d0c12f1e91921571bff	Diners Club / Carte Blanche	40.7536462741196175	-73.8575645203132183
42280	2020-08-04 03:50:27	2020-08-04	Guy Bartell	guy.bartell@geemail.com	New York	New York	55219350303074245	569a6417115f03c92c0be58eecaab0f7	JCB 15 digit	40.6325879610367124	-73.8965555170912296
42281	2020-08-04 03:53:31	2020-08-04	Macey Wolff DVM	macey.wolff.dvm@geemail.com	Thornton	Colorado	6011548162630350038	56b3806c37c8ac05bf2cbe2cce117de8	Voyager	40.007745962716271	-104.99215044250451
42282	2020-08-04 03:56:03	2020-08-04	Lulah Murazik	lulah.murazik@woohoo.com	San Francisco	California	3776271009435732	cb4731bb377954e1c4068651dff758ed	Discover	37.7896527163360787	-122.43736283541385
42283	2020-08-04 03:57:40	2020-08-04	Mr. Nico Stehr III	mr.nico.stehr.iii@geemail.com	Denver	Colorado	3435359245053987	1f69fcef7d85f18ad1e20a1612f2983a	VISA 16 digit	39.7175903874035896	-104.900651644846803
42284	2020-08-04 03:58:14	2020-08-04	Waldemar Dibbert	waldemar.dibbert@geemail.com	New York	New York	676282334530563	30cc6a923079371ecc43aa1ca6838958	VISA 16 digit	40.7258810883145799	-73.9889605684101497
42285	2020-08-04 04:03:20	2020-08-04	Namon Bernier	namon.bernier@geemail.com	Oakland	California	501812629951356	01c78dd5e474108b4a8917b4a6223336	American Express	37.8016608875389366	-122.230049523938007
42286	2020-08-04 04:20:39	2020-08-04	Merrie Schulist	merrie.schulist@geemail.com	Indianapolis	Indiana	4976135550491371	6113b6f1dd3517cd1a39c6520f22071c	Diners Club / Carte Blanche	39.6840743523564186	-86.1160395623385853
42287	2020-08-04 04:27:22	2020-08-04	Bird Mosciski-Dibbert	bird.mosciski.dibbert@geemail.com	Columbus	Ohio	675993083935093	5888e2186249b950cac822b262f4e8f7	Voyager	40.0131180038254683	-83.0310423640303412
42288	2020-08-04 04:33:20	2020-08-04	Korey O'Keefe	korey.o'keefe@geemail.com	Kent	Washington	3408607870230632	5041e8f1a9400c67b05263f3c3b992ab	VISA 13 digit	47.3432497412543754	-122.205131873921303
42289	2020-08-04 04:39:02	2020-08-04	Miss Zillah Berge	miss.zillah.berge@geemail.com	Frisco	Texas	3037011532975802	c48bfe3fecb27f980c7f23b0a5a48954	Maestro	33.1103623295664775	-96.7279610880859195
42290	2020-08-04 04:39:21	2020-08-04	Kindra Nader	kindra.nader@warmmail.com	San Francisco	California	180098445939655999	42ea807bfbf10e9897d50a2515814cf7	Maestro	37.7901517106456595	-122.413173845681769
42291	2020-08-04 04:41:48	2020-08-04	Raoul Ruecker	raoul.ruecker@geemail.com	San Diego	California	869958563329277394	fbbbb0ce9365768dd0ea24491bf8cd2e	JCB 15 digit	32.9152803716316811	-117.070245479550223
42292	2020-08-04 04:57:20	2020-08-04	Earnestine Johns	earnestine.johns@geemail.com	Seattle	Washington	3337262084335131840	3f053266f9592618c280c94290fde9e7	Discover	47.5641694529373211	-122.369578431538855
42293	2020-08-04 04:59:01	2020-08-04	Miss Amie Harvey	miss.amie.harvey@woohoo.com	Columbus	Ohio	53861452098654347	bce6f785c4016d4d057ca011b11857f9	Voyager	39.9386274800214878	-82.9800523114159745
42294	2020-08-04 05:02:41	2020-08-04	Tara Doyle	tara.doyle@geemail.com	Columbus	Ohio	4701132569668604	04bb5cfc390d1f79a5de73d1b7244c26	JCB 16 digit	39.9806130362719259	-82.9953022976174992
42295	2020-08-04 05:06:46	2020-08-04	Linwood Wisozk-O'Kon	linwood.wisozk.o'kon@geemail.com	Akron	Ohio	3112831085333142509	5fbffc151669673cf0a3057751b8c9f5	Maestro	41.0062258664350949	-81.5675695620324461
42296	2020-08-04 05:10:05	2020-08-04	Harvy Hilpert	harvy.hilpert@geemail.com	Indianapolis	Indiana	501832784864137	6cde0139f6f6e7526c97303aba76cc64	JCB 16 digit	39.8023310371216397	-86.1519054950881724
42297	2020-08-04 05:35:49	2020-08-04	Crissie Kling	crissie.kling@warmmail.com	Garden Grove	California	630484810552863	45fe48b241eab203299328881abb2d75	Voyager	33.7059051597315786	-118.000876080851995
42298	2020-08-04 05:56:52	2020-08-04	Kyson Sporer MD	kyson.sporer.md@geemail.com	Plano	Texas	869992431312793132	c53c1b07e297160eb188053042587ab7	JCB 15 digit	33.1089144055351667	-96.8083820023290826
42299	2020-08-04 06:10:57	2020-08-04	Willene Greenfelder	willene.greenfelder@woohoo.com	Los Angeles	California	4803002193930281	5d9c5ff5671859c96dd8c2f0c688fce9	VISA 13 digit	34.0025095524132226	-118.48041408383213
42300	2020-08-04 06:21:41	2020-08-04	Tonda Boyer	tonda.boyer@geemail.com	San Francisco	California	3403339815238844	9659aabc874917dba0ac7a0e4cffe3ed	VISA 16 digit	37.7769987570823531	-122.424605640476543
42301	2020-08-04 06:32:12	2020-08-04	Ursula Boyle	ursula.boyle@warmmail.com	McKinney	Texas	3723627227035006	088fd2d6f41e7c260c329aeb899d231a	VISA 16 digit	33.2429408567622318	-96.6408826998733019
42302	2020-08-04 06:37:40	2020-08-04	Bambi Hodkiewicz	bambi.hodkiewicz@geemail.com	Scottsdale	Arizona	3700322865666703	ccec6a7935a84571217d9f92c8bcf313	VISA 16 digit	33.7370701553422947	-111.847809535634141
42303	2020-08-04 06:37:50	2020-08-04	Arlena Legros	arlena.legros@geemail.com	San Diego	California	4730764138727886	85474e57e080a6d9cf6be8f640363e27	VISA 16 digit	32.7800051091305917	-117.101645474033432
42304	2020-08-04 06:51:57	2020-08-04	Miracle Wintheiser-Marvin	miracle.wintheiser.marvin@geemail.com	San Antonio	Texas	4268155090593	91aeabc2c17f8cd13eaccca5169b351a	VISA 16 digit	29.4040415583714854	-98.4611261977650116
42305	2020-08-04 07:17:38	2020-08-04	Doyle Baumbach	doyle.baumbach@geemail.com	San Francisco	California	869941565363218085	3d9f8eb1c2a7ad8fee817fc0a49a1b9a	VISA 16 digit	37.7960412524600713	-122.436348874973746
42306	2020-08-04 07:20:58	2020-08-04	Francisca Larkin	francisca.larkin@woohoo.com	Philadelphia	Pennsylvania	3788435300214114	e4745cc55d50ebc3a4d5b3f4a75c69da	Voyager	39.9990514553111041	-75.1519362271662885
42307	2020-08-04 07:29:36	2020-08-04	Iyana Walsh	iyana.walsh@geemail.com	Newark	New Jersey	503849087672439	3c6973b494df1b3db59091d672c7710f	VISA 16 digit	40.739925280810148	-74.1446962312538176
42308	2020-08-04 07:41:40	2020-08-04	Jeffie Altenwerth	jeffie.altenwerth@warmmail.com	Miami	Florida	676376778571422	e6dec03864ba91fd8c9fb533675f743a	JCB 16 digit	25.7545967264704423	-80.24357841027566
42309	2020-08-04 07:48:42	2020-08-04	Mrs. Leana Kihn PhD	mrs.leana.kihn.phd@warmmail.com	Las Vegas	Nevada	54845590805238887	caa3ac6e6f67c243cfc7e404dcf6c728	JCB 15 digit	36.1641186917301241	-115.160972635748237
42310	2020-08-04 07:53:11	2020-08-04	Mrs. Veronica Schinner DDS	mrs.veronica.schinner.dds@geemail.com	Huntsville	Alabama	3096220172321491624	f2727423385f1aac1ff85f0a25561f8b	VISA 16 digit	34.6475419808421279	-86.6443810977060309
42311	2020-08-04 07:57:33	2020-08-04	Firman Cronin	firman.cronin@geemail.com	Philadelphia	Pennsylvania	869900639942311346	f0447a2f305236cabea4a14972b8c8c5	JCB 15 digit	40.0756646275479369	-75.1497120823610629
42312	2020-08-04 08:00:32	2020-08-04	Eber Goyette	eber.goyette@geemail.com	Oakland	California	869972596143948875	67c9376cd8cec243a427639c487be88f	Voyager	37.7993149315080643	-122.259922198525061
42313	2020-08-04 08:09:19	2020-08-04	Ethyle Strosin-Green	ethyle.strosin.green@woohoo.com	Jersey City	New Jersey	869916991913844314	e835f9eee65108bbcbfda2861c0543ea	VISA 16 digit	40.757860200613365	-74.1611894824031737
42314	2020-08-04 08:13:21	2020-08-04	Paralee Cremin DVM	paralee.cremin.dvm@geemail.com	Sterling Heights	Michigan	180022574889421531	61bf22dc52298fdaf427861ee467cf92	JCB 16 digit	42.625295634855334	-83.0838895967855962
42315	2020-08-04 08:21:34	2020-08-04	Danelle Carter	danelle.carter@warmmail.com	New York	New York	210062892478189330	d0ed1e6ff211bb2699dd4775dc091647	American Express	40.6932583135776227	-73.917697510485354
42316	2020-08-04 08:26:56	2020-08-04	Emett Ward DVM	emett.ward.dvm@geemail.com	Denver	Colorado	6011829921833609197	6c3a3f788a8ee9bcdbc4ac7950632aa4	JCB 16 digit	39.7137366618547532	-104.914891669690988
42317	2020-08-04 08:55:48	2020-08-04	Dr. Ronaldo Friesen V	dr.ronaldo.friesen.v@geemail.com	Las Vegas	Nevada	210091240119517771	a9645cef3bc872b750a48153d248944c	Voyager	36.225969648185	-115.256352843597895
42318	2020-08-04 09:00:59	2020-08-04	Susannah Shanahan-Fay	susannah.shanahan.fay@woohoo.com	San Francisco	California	3337768364279113957	349d36409e1d0da41381e1853707ff79	JCB 16 digit	37.7730414409350175	-122.449211356476894
42319	2020-08-04 09:02:24	2020-08-04	Wong Purdy	wong.purdy@geemail.com	El Paso	Texas	503817414030761	b0a181c6c7a3b52da314f6b2f5ec8c26	VISA 16 digit	31.8971471745815158	-106.517311010507868
42320	2020-08-04 09:04:53	2020-08-04	Delwin Boyer	delwin.boyer@geemail.com	Lansing	Michigan	060448727892795	d3fc20fc6b156bdd0922524d1bffd5bd	VISA 16 digit	42.6981739514816567	-84.5609803171951313
42321	2020-08-04 09:05:32	2020-08-04	Boyd Fahey	boyd.fahey@warmmail.com	Richmond	Virginia	4017205364341574	136070b93caf51f652a5247abd8fbec2	American Express	37.5598211952239254	-77.3790086352489936
42322	2020-08-04 09:06:12	2020-08-04	Verda Kovacek	verda.kovacek@geemail.com	Colorado Springs	Colorado	6011078280549007834	6b4610aabfaf97b7fddce4a655387260	Maestro	38.7887448594488191	-104.807943451001123
42323	2020-08-04 09:23:32	2020-08-04	Demarcus Beatty-Thiel	demarcus.beatty.thiel@geemail.com	Chesapeake	Virginia	4037980675782056	e7160a4aad7dff46f256d27282c4b84c	Voyager	36.7200907310243707	-76.2174507125124308
42324	2020-08-04 09:24:00	2020-08-04	Dr. Michial Romaguera I	dr.michial.romaguera.i@geemail.com	Dallas	Texas	3054356737500266	7b6cc8ff13d2b39900d4b6b1286ea26f	VISA 16 digit	32.8606524330370178	-96.6727893645372234
42325	2020-08-04 09:25:29	2020-08-04	Dr. Male Schmidt	dr.male.schmidt@warmmail.com	Boston	Massachusetts	4588181979218417	f93f47d4ff0cd6211bc61ce13f6a8408	Maestro	42.2869732864834376	-70.9783989353522742
42326	2020-08-04 09:26:13	2020-08-04	Denton Okuneva	denton.okuneva@geemail.com	San Francisco	California	3158876920418413720	6b717128205da644eae72052f647417b	Diners Club / Carte Blanche	37.7784514129971924	-122.394136262518984
42327	2020-08-04 09:49:16	2020-08-04	Dr. Soren Schinner	dr.soren.schinner@geemail.com	Costa Mesa	California	54286728659416755	3011ec696b10e1538f1ae477dc0490ad	Voyager	33.6148141078200169	-117.982237163358562
42328	2020-08-04 09:59:19	2020-08-04	Tana Spinka	tana.spinka@geemail.com	Oakland	California	3768680804546628	d6702546d1308b8c2a95f614bfb1c51e	Mastercard	37.8042127823456653	-122.268825745676139
42329	2020-08-04 10:19:43	2020-08-04	Aracely Ebert	aracely.ebert@geemail.com	Tallahassee	Florida	3337938597206938724	8fdbf6c2a7ba16968b9f3c2d02f1af6f	VISA 16 digit	30.4742914260853084	-84.2587801969625048
42330	2020-08-04 10:28:12	2020-08-04	Najee Dicki	najee.dicki@warmmail.com	Berkeley	California	3528752207604111873	1f805d9e56968475f6118b5ecb791851	Mastercard	37.866424669923191	-122.268898938260563
42331	2020-08-04 10:36:33	2020-08-04	Mr. Burton Wilderman	mr.burton.wilderman@geemail.com	Phoenix	Arizona	676136786526297	ac40f325d5f5df0ae835172f717368d5	Discover	33.5208965829972172	-112.158913984282322
42332	2020-08-04 10:39:22	2020-08-04	Micah Osinski V	micah.osinski.v@woohoo.com	Mobile	Alabama	869985374840313164	7d828bb856e66c7a2326c51de6c5e578	Voyager	30.6577584080971768	-88.1193250341944463
42333	2020-08-04 10:40:16	2020-08-04	Colten Gorczany	colten.gorczany@geemail.com	New York	New York	4339332423707701	defbc200163b77abc567ab66308dcd21	Diners Club / Carte Blanche	40.6133434968292732	-74.0192119007825795
42334	2020-08-04 10:41:26	2020-08-04	Ms. Suzy Doyle DVM	ms.suzy.doyle.dvm@geemail.com	Visalia	California	869997062513224125	0954b26809c0b46ad1e1dbfa5c74fd9d	JCB 15 digit	36.4225544161118577	-119.340183834185453
42335	2020-08-04 10:49:50	2020-08-04	Mellie Mayer	mellie.mayer@geemail.com	Irvine	California	3096267501522915045	fef62484e7fe050e9ded9f4c050d79da	American Express	33.7644291530378169	-117.754793120130145
42336	2020-08-04 11:02:31	2020-08-04	Domenick Crona-Gorczany	domenick.crona.gorczany@geemail.com	Dayton	Ohio	4835101940196493	1717bc83c77ef87bf146808ff3506303	VISA 16 digit	39.8402592853900046	-84.2125148189909822
42337	2020-08-04 11:06:04	2020-08-04	Zebulon Ziemann	zebulon.ziemann@geemail.com	Oakland	California	6011088614257931892	8ed6282bae73c3ca2708b1536b1fed39	American Express	37.7934986030291498	-122.26812362525331
42338	2020-08-04 11:07:27	2020-08-04	Adriana O'Reilly	adriana.o'reilly@geemail.com	San Antonio	Texas	4290285020795	37c292171a4c7d35c09e393610db3578	Diners Club / Carte Blanche	29.4549765952467908	-98.5521047230180329
42339	2020-08-04 11:11:54	2020-08-04	Alejandra Dare-Hintz	alejandra.dare.hintz@geemail.com	Phoenix	Arizona	3007569606528815	0743055052ae6a196285e1e5262ee9df	Voyager	33.52089026495144	-112.178417225966612
42340	2020-08-04 11:20:19	2020-08-04	Cris Rosenbaum	cris.rosenbaum@geemail.com	San Francisco	California	3016769604643381	150ac193d0909ef5f713670bbc162056	VISA 13 digit	37.7672997959259149	-122.45894393372518
42341	2020-08-04 11:20:20	2020-08-04	Ola Mohr	ola.mohr@geemail.com	Oakland	California	3088501299535087276	fe774dc115d3f52f1881d6561612ec74	VISA 16 digit	37.7991008662675085	-122.28094166677549
42342	2020-08-04 11:24:06	2020-08-04	Izabella Bartell-O'Reilly	izabella.bartell.o'reilly@woohoo.com	Richmond	Virginia	4888708025486056	8f5b58bcaad45ade5c55ca3fc0c66fcf	VISA 16 digit	37.6165770496461533	-77.4212662653755359
42343	2020-08-04 11:28:08	2020-08-04	Camryn Sporer-Fritsch	camryn.sporer.fritsch@warmmail.com	Garland	Texas	52151803983212949	634ec7fb707d9c7fc056188fb29ded53	VISA 13 digit	32.8177908343031959	-96.6492978610258575
42344	2020-08-04 11:42:21	2020-08-04	Virge Okuneva	virge.okuneva@geemail.com	Phoenix	Arizona	4385584117313260	d310a7799a2eeed9196f6c8d50e13d55	American Express	33.5533339085456035	-112.112775091028226
42345	2020-08-04 11:47:45	2020-08-04	Miss Rhonda Schamberger	miss.rhonda.schamberger@geemail.com	San Antonio	Texas	52644919883481791	6bf555139c4cccb3793de0812f7db4a8	Voyager	29.3847331395443518	-98.591083362542463
42346	2020-08-04 11:56:08	2020-08-04	Lexie Schmidt PhD	lexie.schmidt.phd@geemail.com	San Francisco	California	4520665344492	a17a2b2aea391fe099936a8f6c8c6359	Discover	37.7782781487082246	-122.438385600230518
42347	2020-08-04 12:24:27	2020-08-04	Vennie Marks-O'Reilly	vennie.marks.o'reilly@geemail.com	San Angelo	Texas	3459044210559447	cc574c7e90f4e0c09b78193ac37a718e	JCB 16 digit	31.3505806316308657	-100.45199897537195
42348	2020-08-04 12:25:22	2020-08-04	Lulah Schmeler	lulah.schmeler@geemail.com	Long Beach	California	3444253762624057	4f770fe535aeba03b50501510ec8f69f	American Express	33.8470413551021352	-118.117492069459701
42349	2020-08-04 12:27:31	2020-08-04	Marely Schroeder-Heller	marely.schroeder.heller@warmmail.com	Seattle	Washington	6011608219486127857	2239ea7d63a375b31a7ceb3bb966a6a7	VISA 16 digit	47.7177542200703186	-122.389498592206834
42350	2020-08-04 12:27:31	2020-08-04	Ms. Dorotha Blanda DDS	ms.dorotha.blanda.dds@geemail.com	Seattle	Washington	180063052507914617	324b2b74ba8033791a43d740e24e7cd7	JCB 16 digit	47.5695146222524343	-122.375296604532366
42351	2020-08-04 12:37:11	2020-08-04	Christel Emard-Runolfsson	christel.emard.runolfsson@woohoo.com	Los Angeles	California	869921522360749350	30497cdbfbe167ab7bacc3c14adf3d84	JCB 15 digit	33.9759524563658957	-118.343816866119568
42352	2020-08-04 12:37:55	2020-08-04	Dr. Campbell Welch PhD	dr.campbell.welch.phd@geemail.com	Santa Ana	California	210055650240416558	410e7fd4b8518c938af70c11a22efbca	JCB 16 digit	33.7587616639316082	-117.970326407013459
42353	2020-08-04 12:44:03	2020-08-04	Eugene Block	eugene.block@geemail.com	Renton	Washington	869924139039401193	719ad42f0763cd10fc806f774a71eac0	JCB 15 digit	47.4237652568206229	-122.114789358720174
42354	2020-08-04 12:52:33	2020-08-04	Kaylan Wiegand	kaylan.wiegand@geemail.com	Richardson	Texas	3337427223604884091	725e4710992bce75fba6fd10848d22f4	JCB 15 digit	33.0155127558626234	-96.8009781464230343
42355	2020-08-04 12:54:55	2020-08-04	Marva Beahan	marva.beahan@geemail.com	Dayton	Ohio	3769836257539010	ba2cd7a32c1b3e5a15fa799ae91d2142	JCB 16 digit	39.8679615651980015	-84.2622701553817848
42356	2020-08-04 13:03:44	2020-08-04	Jasper Langosh	jasper.langosh@geemail.com	Lubbock	Texas	4612358146415353	a8c3a5ac9c476d92dfa5d0741592219b	Mastercard	33.6567433767993052	-101.790703413999452
42357	2020-08-04 13:05:27	2020-08-04	Ms. Elisha Little	ms.elisha.little@geemail.com	Chicago	Illinois	4774168931059843	11a6283bc2e1a1c2ccb5d349336581db	JCB 16 digit	41.7930856128990698	-87.7501209429494935
42358	2020-08-04 13:11:35	2020-08-04	Lylah Runolfsdottir	lylah.runolfsdottir@geemail.com	Kansas City	Missouri	3112589960644512133	ac0695ca1027541a42404f0a80a65a62	VISA 13 digit	39.1056451866705004	-94.553829941967507
42359	2020-08-04 13:13:48	2020-08-04	Deegan Barton	deegan.barton@geemail.com	Waterbury	Connecticut	502099260310034	befe5b7f9e636918aae35f5e3c33ce29	American Express	41.5897371830921614	-73.0972948881246083
42360	2020-08-04 13:14:11	2020-08-04	Edith Schoen	edith.schoen@geemail.com	San Francisco	California	4816098183372919	c6a7144e05bd14171c893188fef8139c	VISA 16 digit	37.7607767419254827	-122.411391432903713
42361	2020-08-04 13:16:06	2020-08-04	Dakotah Cole Jr.	dakotah.cole.jr.@geemail.com	Greensboro	North Carolina	3528425553034551692	5b50fadd7b2adba2061463ed2ee11fde	VISA 13 digit	36.1702640093512855	-79.9189086833484481
42362	2020-08-04 13:23:16	2020-08-04	Ms. Rochelle Wyman	ms.rochelle.wyman@geemail.com	New York	New York	869954611092154276	014294821b16371f7bac9c6d45a265d6	JCB 16 digit	40.6751766528226426	-73.9381894702918743
42363	2020-08-04 13:27:47	2020-08-04	Christy Gerhold	christy.gerhold@geemail.com	Orange	California	3112048705322888890	a151a5eee4a66e4474047638d2a55fd0	Maestro	33.806691346585751	-117.787157413979244
42364	2020-08-04 13:31:55	2020-08-04	Lella Rohan-Nitzsche	lella.rohan.nitzsche@geemail.com	New York	New York	869984937904871060	f35c8585cbfdcb389383e2f1c8b296da	Maestro	40.5978923819717039	-73.9029428783699842
42365	2020-08-04 14:01:43	2020-08-04	Deidra Rogahn-Strosin	deidra.rogahn.strosin@woohoo.com	Saint Paul	Minnesota	869951735956364805	04262ee0e16599d3e3dfaeae86f4d9ed	JCB 16 digit	44.9363062763061407	-93.0068770712040447
42366	2020-08-04 14:07:03	2020-08-04	Rory Kulas PhD	rory.kulas.phd@geemail.com	San Francisco	California	4529251940661946	81664c3c4065d45dff725b4eab84ae88	American Express	37.7536538150320382	-122.381229853056936
42367	2020-08-04 14:25:33	2020-08-04	Ms. Kizzy McCullough	ms.kizzy.mccullough@woohoo.com	Cary	North Carolina	3337742174581734569	30dd40e724819e71681f492b41634d53	JCB 16 digit	35.8329877254661184	-78.7981426897078734
42368	2020-08-04 14:34:23	2020-08-04	Dr. Prentiss Witting I	dr.prentiss.witting.i@geemail.com	Columbus	Ohio	6011734984513782811	a4a96eed9a4f4c81633462d8018e00fc	VISA 13 digit	40.0139004830315699	-82.9480619109004778
42369	2020-08-04 14:36:45	2020-08-04	Trenten Konopelski	trenten.konopelski@geemail.com	Pembroke Pines	Florida	4125591466904	bc96d95167136a7c278a95b3f11e0069	Discover	26.0888393950220205	-80.267730679818996
42370	2020-08-04 14:46:13	2020-08-04	Patrice Bins	patrice.bins@geemail.com	San Diego	California	180097944189065041	1605e9a85de26e47673635f4fe66ec68	JCB 15 digit	32.8005600710466538	-117.109754222203051
42371	2020-08-04 14:52:11	2020-08-04	Mellisa Nienow-Marvin	mellisa.nienow.marvin@warmmail.com	Miami	Florida	6011032478097329080	958672c7092c3a27eef5690b8d6cf199	VISA 13 digit	25.8187710802208663	-80.1688363427169719
42372	2020-08-04 15:01:43	2020-08-04	Dr. Urban Rolfson Jr.	dr.urban.rolfson.jr.@geemail.com	Scottsdale	Arizona	869922584569080937	a3937208b3a099e403908c3b9fb5b793	Mastercard	33.6267676778726283	-111.868962868485966
42373	2020-08-04 15:04:43	2020-08-04	Jeramy Connelly-Harvey	jeramy.connelly.harvey@warmmail.com	Lansing	Michigan	501812196231513	6acfe64d80f89ec5076095b5a15cf846	VISA 16 digit	42.7756503378815935	-84.5397799299687023
42374	2020-08-04 15:09:30	2020-08-04	Johney Schuster	johney.schuster@geemail.com	Roseville	California	676208533821123	be5fa0e4466ff92df7712770e19549ee	Voyager	38.728673282410945	-121.377752037228646
42375	2020-08-04 15:17:54	2020-08-04	Willie Koelpin-Emard	willie.koelpin.emard@geemail.com	Los Angeles	California	4478122732525923	8c225f18ed61a8faecd79f3fc54f0d45	VISA 13 digit	34.0675556287035306	-118.489374105864385
42376	2020-08-04 15:25:14	2020-08-04	Donie Thompson	donie.thompson@geemail.com	Indianapolis	Indiana	6011069680554392842	cfd28ba559259f4882a998acfb1280e9	VISA 13 digit	39.7992290859583733	-86.0839699263419931
42377	2020-08-04 15:30:06	2020-08-04	Alvan Kautzer	alvan.kautzer@geemail.com	Nashville	Tennessee	869940455241278322	14c399204bfe5d507842fc172a5e7ef4	JCB 15 digit	36.2599259072571982	-86.7529225470870671
42378	2020-08-04 15:31:10	2020-08-04	Maebell Torphy-Glover	maebell.torphy.glover@woohoo.com	Memphis	Tennessee	55280900784245799	9df4a8d02d1d7e9c0f606c3bb378000c	VISA 16 digit	35.187690926163647	-90.071787091835958
42379	2020-08-04 15:31:58	2020-08-04	Dr. Newman Greenholt PhD	dr.newman.greenholt.phd@geemail.com	San Francisco	California	3469739587538357	c3281d4a097d87e4c07c50950f38a1e3	Discover	37.7850200428990277	-122.47272544895209
42380	2020-08-04 15:40:59	2020-08-04	Dr. Leontine Braun DVM	dr.leontine.braun.dvm@geemail.com	Vacaville	California	52651825222152334	4ec0036c8752b9fc4b955ac98d27d9fe	Discover	38.3477274459913389	-121.988814681011448
42381	2020-08-04 15:46:22	2020-08-04	Littleton Hane	littleton.hane@warmmail.com	Newport News	Virginia	6011499571896685888	a4f47ecf4f7f70367e73814e1eb912a2	Discover	37.0784597489878536	-76.5283011313322987
42382	2020-08-04 15:48:23	2020-08-04	Ozell Ruecker	ozell.ruecker@geemail.com	Tyler	Texas	675933988184991	70f93857d3675b6bfb10fb2d6f20ceb7	American Express	32.3120747844737082	-95.2145245007347256
42383	2020-08-04 16:03:08	2020-08-04	Machelle Kshlerin	machelle.kshlerin@warmmail.com	Wichita Falls	Texas	501898146542331	c72b4def8aef3423495b6e284b1eef7f	Mastercard	33.8883044507082545	-98.5562950121626216
42384	2020-08-04 16:03:28	2020-08-04	Elizah Mills	elizah.mills@geemail.com	Richmond	Virginia	4219351758434	e02ccacc5bfc715a95630399d23af71d	Mastercard	37.5281482081614399	-77.5512488079480846
42385	2020-08-04 16:05:23	2020-08-04	Rhea McKenzie	rhea.mckenzie@geemail.com	Jacksonville	Florida	869916825290874389	366f1dedad7d556f91af0fe33b495f37	JCB 16 digit	30.2786930684052393	-81.651380591800816
42386	2020-08-04 16:30:19	2020-08-04	Draven Jaskolski	draven.jaskolski@warmmail.com	Berkeley	California	676102863655573	7f9da7a41c39ef32c6c4bd2a7de7f2d4	Mastercard	37.8617366770757258	-122.277871895829847
42387	2020-08-04 16:35:55	2020-08-04	Aidyn Kulas	aidyn.kulas@geemail.com	New York	New York	4247163992086925	6d57776dc79e354f53a7c03bf270f8fc	American Express	40.6922639080546773	-73.8768663227453857
42388	2020-08-04 16:45:18	2020-08-04	Skye Ziemann	skye.ziemann@geemail.com	Nashville	Tennessee	4471118868237983	9fe6846421274716fe814d94fc38a388	VISA 13 digit	36.1317248418584427	-86.8313583997450706
42389	2020-08-04 16:46:59	2020-08-04	Breana Nolan-Schowalter	breana.nolan.schowalter@geemail.com	Pembroke Pines	Florida	180026468696919413	74cb1eb8adfd9e5195e527764a8aafbb	Diners Club / Carte Blanche	26.0552755749821685	-80.2657682670183448
42390	2020-08-04 16:53:55	2020-08-04	Boston Mueller-Kessler	boston.mueller.kessler@warmmail.com	Omaha	Nebraska	3337222428555151625	49d02945d3a01d1cf54a7e355e3cd24b	Discover	41.2852276334218686	-96.0267663777921427
42391	2020-08-04 16:54:04	2020-08-04	Frank Konopelski	frank.konopelski@warmmail.com	San Antonio	Texas	676341552229332	8d5a2318196f5063cbb80688c4c91624	American Express	29.4125340603828427	-98.509666460782654
42392	2020-08-04 17:02:08	2020-08-04	Sienna Collier	sienna.collier@warmmail.com	Des Moines	Iowa	4676722138822400	45101c00b1c3a405b56c05de7aa0d249	VISA 13 digit	41.5726695850234478	-93.6528134899258617
42393	2020-08-04 17:08:28	2020-08-04	Micky Douglas	micky.douglas@geemail.com	Tallahassee	Florida	3727824939964674	9c6825c96579b37c51a2a434e0f85a28	JCB 15 digit	30.5358700886391112	-84.2369360658355077
42394	2020-08-04 17:09:54	2020-08-04	Dr. Enos Stark I	dr.enos.stark.i@geemail.com	Newark	New Jersey	180083253875548351	afb95a6324295affc300ef762cbeef4d	JCB 15 digit	40.7341101373925838	-74.0732956083700032
42395	2020-08-04 17:13:12	2020-08-04	Ova Little	ova.little@geemail.com	Providence	Rhode Island	502070785379002	e6d056d7c44f906ba8a395bd1c140316	VISA 13 digit	41.7544930096104707	-71.4961061614949358
42396	2020-08-04 17:29:35	2020-08-04	Margot Collins-Stroman	margot.collins.stroman@geemail.com	Chicago	Illinois	3024711739707139	4a363ac56e0421b25cb278048fbf87e4	Voyager	41.8975938212893908	-87.7588490733906639
42397	2020-08-04 17:59:17	2020-08-04	Magdalen Ernser	magdalen.ernser@geemail.com	Philadelphia	Pennsylvania	675999161441391	4b3de08c85a0e04328e7c9d1622f3781	VISA 13 digit	39.9873369797557601	-75.1901071256857421
42398	2020-08-04 18:16:39	2020-08-04	Junious Windler-Herzog	junious.windler.herzog@geemail.com	Oxnard	California	3096108780142060829	ba5e156856506958eac7d5dfe80b6282	JCB 15 digit	34.1125562959771642	-119.11574488812164
42399	2020-08-04 18:19:40	2020-08-04	Dr. Hunter Spencer	dr.hunter.spencer@geemail.com	Bellevue	Washington	51706676231282306	801b4b462749e6a3d01f8db474349647	Mastercard	47.5502073239251999	-122.201080592494449
42400	2020-08-04 18:21:42	2020-08-04	Miss Judith Morar MD	miss.judith.morar.md@warmmail.com	Denver	Colorado	869974227720354596	c1dad58bace6d9fecb327e1b13c4a11e	JCB 16 digit	39.668976446432616	-104.932584091533357
42401	2020-08-04 18:23:08	2020-08-04	Harlen Harvey	harlen.harvey@geemail.com	Berkeley	California	3112272563502169152	25010165589f77ded7eee95605a1a857	JCB 16 digit	37.8604308179852893	-122.258419262186109
42402	2020-08-04 18:23:46	2020-08-04	Mr. Callie Carter V	mr.callie.carter.v@geemail.com	Long Beach	California	54033898678168541	807c8895daf0e8e581596e3e4dd85fd5	Discover	33.7572151552241237	-118.13343294841907
42403	2020-08-04 18:28:32	2020-08-04	Camisha Lubowitz	camisha.lubowitz@geemail.com	Norfolk	Virginia	55010737843522983	1fca8d66318ec5c293138a3db6dcc938	JCB 15 digit	36.832577537095176	-76.2714501260783635
42404	2020-08-04 18:44:05	2020-08-04	Brandan Witting	brandan.witting@warmmail.com	Los Angeles	California	3731994340698718	88df0f9aa6e9a56eada8a6ec04e64509	JCB 16 digit	34.0631486255075728	-118.480659378179524
42405	2020-08-04 18:54:36	2020-08-04	Silver Gibson-Murazik	silver.gibson.murazik@woohoo.com	Dallas	Texas	3528006632019833387	4543103975f1066132262263b7e3967f	JCB 15 digit	32.7779388075035101	-96.8516086575072137
42406	2020-08-04 19:03:21	2020-08-04	Alfredo Kunde	alfredo.kunde@geemail.com	Raleigh	North Carolina	4450059181861569	fc7b5e1c97d32586f44d04d69391d610	Diners Club / Carte Blanche	35.790058776982498	-78.5641550011403922
42407	2020-08-04 19:04:09	2020-08-04	Melvina Weissnat	melvina.weissnat@woohoo.com	Arlington	Texas	3088045607391203162	c9010e08747633e57907596aed47b4f6	JCB 16 digit	32.6254303878888479	-97.0893783813834261
42408	2020-08-04 19:04:09	2020-08-04	Mal Dicki	mal.dicki@geemail.com	Everett	Washington	4501437045219175	b226ddf5546740d5d3d68836bf06c064	Maestro	47.9468512767817856	-122.132343922987204
42409	2020-08-04 19:05:24	2020-08-04	Tye Schowalter	tye.schowalter@geemail.com	Oakland	California	6011389969585379602	d4bc8f888e8d0c1bcdfb123faeda2794	VISA 16 digit	37.8085337497872018	-122.292685443893333
42410	2020-08-04 19:10:45	2020-08-04	Jimena Gerhold	jimena.gerhold@warmmail.com	Fontana	California	3767053794973635	3ecd23b3fb58db301cf0933891232281	VISA 16 digit	34.0435488121733059	-117.460641223359488
42411	2020-08-04 19:16:35	2020-08-04	Elenore Osinski	elenore.osinski@woohoo.com	Atlanta	Georgia	3528443492496205364	af4562cdb0207975fbe25f85b4e63fc1	Maestro	33.8166917735520798	-84.3337655348748001
42412	2020-08-04 19:27:21	2020-08-04	Isabell Tremblay-Glover	isabell.tremblay.glover@geemail.com	New York	New York	3158869680687615913	77f24e3c15469c74e360619153b416e7	Maestro	40.7168631277270592	-73.9159793035954209
42413	2020-08-04 19:29:18	2020-08-04	Dorthey Halvorson	dorthey.halvorson@geemail.com	Los Angeles	California	3713957534576190	b35b5b55649d0f3ec67ea2faa2cce214	JCB 16 digit	34.1113122071005392	-118.479583654179422
42414	2020-08-04 19:31:39	2020-08-04	Kelvin Farrell-Kerluke	kelvin.farrell.kerluke@woohoo.com	Dallas	Texas	4956830498197171	a8bdac878ad4eb308e8559c445151247	VISA 16 digit	32.7649331618838033	-96.7689503901600716
42415	2020-08-04 19:34:46	2020-08-04	Enriqueta Nader	enriqueta.nader@woohoo.com	Stamford	Connecticut	3484427931343267	faa2650dc177df7ec1b8f95a16e6b191	Maestro	41.0926219789195812	-73.5575044325124594
42416	2020-08-04 19:47:32	2020-08-04	Ms. Patrica Kovacek	ms.patrica.kovacek@geemail.com	Oceanside	California	3096100158377608224	a2d90126d7a606e820159189aa531447	Discover	33.2845632783491183	-117.242864271913476
42417	2020-08-04 19:50:30	2020-08-04	Wilton Koch-Rodriguez	wilton.koch.rodriguez@geemail.com	Hartford	Connecticut	3046628354386684	cf310e359aedf857a46832179d9224f0	JCB 16 digit	41.7525388007998473	-72.6988675402369324
42418	2020-08-04 19:53:29	2020-08-04	Mr. Duane Reichert	mr.duane.reichert@geemail.com	Virginia Beach	Virginia	55603212778034076	4960936946668683eef091d976856cbb	American Express	36.7217031419929114	-75.95329749422595
42419	2020-08-04 20:18:56	2020-08-04	Averie Lynch PhD	averie.lynch.phd@geemail.com	Washington	District of Columbia	4382019690146590	152a46304e8fe1f08ab13433d7475bbf	Maestro	38.9692644955389227	-76.9572651166215564
42420	2020-08-04 20:21:22	2020-08-04	Mrs. Nayeli Schroeder	mrs.nayeli.schroeder@woohoo.com	Moreno Valley	California	4822304197057682	67ba8d85ff1c96309e76fc55e6a5a3c7	Mastercard	33.9588136241298173	-117.161486950653412
42421	2020-08-04 20:33:36	2020-08-04	Dr. Sammie Hamill	dr.sammie.hamill@geemail.com	Durham	North Carolina	4030463120235	e7937eb82719c52eaf6296df3490d305	Diners Club / Carte Blanche	36.0099416708819575	-78.8117068877812557
42422	2020-08-04 20:36:39	2020-08-04	Noreen Mueller	noreen.mueller@woohoo.com	Chandler	Arizona	4519197034266	f3fe8839fdc45e27742da4028743eab8	Voyager	33.3111381511293345	-111.810424963838983
42423	2020-08-04 20:39:40	2020-08-04	Mrs. Chandra Nolan DVM	mrs.chandra.nolan.dvm@geemail.com	Saint Paul	Minnesota	4093800223956625	ed433a07b2f70068d7265e3b115b755a	VISA 16 digit	44.8672315128553691	-93.0747695380155022
42424	2020-08-04 20:45:06	2020-08-04	Hope McCullough	hope.mccullough@geemail.com	Pueblo	Colorado	3007838413344009	e3f796000e9663cdf7085102ee6275a9	JCB 15 digit	38.3305348619330672	-104.577959209480511
42425	2020-08-04 20:47:16	2020-08-04	Esmeralda Abshire	esmeralda.abshire@geemail.com	Knoxville	Tennessee	3401300750663430	8f2abebd532e9996deed63480be132ae	Maestro	35.9339252559065798	-84.0118618561170933
42426	2020-08-04 20:48:54	2020-08-04	Lonzo Ledner	lonzo.ledner@geemail.com	Kansas City	Missouri	3417152201745593	311dd1f63e6cbe9f38465e4f0f2dd75c	Maestro	39.1045463917613034	-94.5278600482027969
42427	2020-08-04 20:51:35	2020-08-04	Dr. Darrian Runolfsson	dr.darrian.runolfsson@geemail.com	San Francisco	California	869943072718140427	dbd7f4c208a25028d7cf06fd79ec3760	Mastercard	37.7428461389910197	-122.443343632082133
42428	2020-08-04 20:58:12	2020-08-04	Benedict Emard Jr.	benedict.emard.jr.@woohoo.com	Arvada	Colorado	4911515879279532	8c39867f947e6b09be0a195e2562152d	JCB 16 digit	39.8316974803049106	-105.225017094888912
42429	2020-08-04 21:16:10	2020-08-04	Markus Hoppe	markus.hoppe@geemail.com	Palm Bay	Florida	3096228097723683332	b85df8bc4b5615a19f4171149a3d45fd	JCB 16 digit	27.9315785685874545	-80.6452596551109053
42430	2020-08-04 21:22:21	2020-08-04	Mr. Gaven Funk Jr.	mr.gaven.funk.jr.@geemail.com	New York	New York	3528389598821317801	171651a719f44237ebf0f3666501b009	VISA 13 digit	40.6017935073692371	-74.0386365630559595
42431	2020-08-04 21:23:09	2020-08-04	Loring Rippin-Lueilwitz	loring.rippin.lueilwitz@geemail.com	Chattanooga	Tennessee	3096294947350812704	5c47a9dbceee11567f8562c62c047c63	VISA 13 digit	35.1149788621664101	-85.303055144922439
42432	2020-08-04 21:25:22	2020-08-04	Geraldo Schultz	geraldo.schultz@geemail.com	Berkeley	California	676297954867848	164ab8e071b4aaeec5ff3e43af90f022	Discover	37.8787199465659228	-122.288499926428798
42433	2020-08-04 21:28:02	2020-08-04	Siena Stroman	siena.stroman@woohoo.com	Lakewood	New Jersey	561272729212745	8edf3139b25352142f2a62bce36cac5c	JCB 16 digit	40.1228744257524639	-74.22282153966799
42434	2020-08-04 21:28:14	2020-08-04	Mrs. Naomi Morissette	mrs.naomi.morissette@geemail.com	Berkeley	California	4699101237957776	23fa5ae32943a46c918bb8394f61b3ff	JCB 15 digit	37.8913246527797227	-122.266670921565023
42435	2020-08-04 21:32:55	2020-08-04	Dr. Lilburn Klein	dr.lilburn.klein@warmmail.com	San Antonio	Texas	3026954789064690	1c7adb9ec4a7d0ee3221dd8953298833	Voyager	29.4903851413704459	-98.5481686944443709
42436	2020-08-04 21:34:10	2020-08-04	Mr. Solomon Leannon Jr.	mr.solomon.leannon.jr.@geemail.com	Anchorage	Alaska	501816976711206	6486348301bc594261945ec8e85e98be	JCB 16 digit	61.1703732963401876	-149.328357235913359
42437	2020-08-04 21:54:36	2020-08-04	Dr. Anika Hoppe	dr.anika.hoppe@geemail.com	New York	New York	4763748286195	5debea68c6da40a894a287f27a6c29e0	VISA 16 digit	40.746209070621056	-74.0218061498727593
42438	2020-08-04 22:00:17	2020-08-04	Pauletta Walsh	pauletta.walsh@geemail.com	Philadelphia	Pennsylvania	3088111502518017679	669d02a81d98286142128c20d434a0cb	Maestro	39.977552405368165	-75.216891628493741
42439	2020-08-04 22:03:16	2020-08-04	Mr. Brennen Price IV	mr.brennen.price.iv@geemail.com	Hialeah	Florida	4952859874986	dbe0958ceebae74b36ab72c06c6116c8	VISA 13 digit	25.8862473966065814	-80.20517281600236
42440	2020-08-04 22:18:31	2020-08-04	Zariah Luettgen	zariah.luettgen@geemail.com	El Paso	Texas	4294295066913	c60d460a258fa8537118e28875f3ccba	Diners Club / Carte Blanche	31.8576291392851623	-106.439888494599614
42441	2020-08-04 22:54:11	2020-08-04	Faye Hyatt	faye.hyatt@geemail.com	Stamford	Connecticut	3000176243364997	f81815f8f2fd75acb4272d1d106426d3	JCB 15 digit	40.9950177813298993	-73.5704058618322136
42442	2020-08-04 22:55:57	2020-08-04	Alani Schaden	alani.schaden@geemail.com	Minneapolis	Minnesota	210000076449272921	9c69a1600053b9cb50b308cc3b9e98d9	VISA 16 digit	45.0310843640092742	-93.3168042165964806
42443	2020-08-04 22:58:32	2020-08-04	Terese Moen	terese.moen@geemail.com	Seattle	Washington	4887094347008261	5fc04593e2f8d241473b9e365ea2180b	VISA 13 digit	47.6096758295241713	-122.274921723866456
42444	2020-08-04 22:59:45	2020-08-04	Wilson Roob	wilson.roob@geemail.com	Tucson	Arizona	52507085046830641	0494b1d5a525ddbe6b3d5e1a8b9acb4f	JCB 15 digit	32.0838410437613746	-110.806769588705521
42445	2020-08-04 23:02:31	2020-08-04	Oralia Greenfelder-Veum	oralia.greenfelder.veum@geemail.com	Cleveland	Ohio	6011820558619550580	19b7b9ab78336870c83df7071a332a46	VISA 16 digit	41.5634303279537676	-81.6816895407397254
42446	2020-08-04 23:02:37	2020-08-04	Ms. Shantell Schinner DDS	ms.shantell.schinner.dds@geemail.com	Oakland	California	54296346271775462	1c1bde3286cf19534afea7630d409148	Mastercard	37.8233940659417271	-122.284808674477404
42447	2020-08-04 23:10:19	2020-08-04	Kayleigh Dietrich-Fadel	kayleigh.dietrich.fadel@woohoo.com	Glendale	California	3528844997795139705	65266d69b6c1f415bcab4b09ac588610	Mastercard	34.2011345180436948	-118.323825379870087
42448	2020-08-04 23:17:47	2020-08-04	Gracia Klein	gracia.klein@geemail.com	Sugar Land	Texas	639064818093995	fc5b60f50f98982a053c0fb600d714c6	American Express	29.6713469527248286	-95.5826804575517741
42449	2020-08-04 23:18:42	2020-08-04	Ettie Wisoky	ettie.wisoky@geemail.com	Columbus	Georgia	4988786741194666	3b7b7c6de40f657cfd6c9d2ec0ebcceb	JCB 16 digit	32.4759327142544052	-84.8060355783138391
42450	2020-08-04 23:22:18	2020-08-04	Romaine Emard	romaine.emard@geemail.com	Reno	Nevada	54746733613084115	3a197062d6c7052f204be6f03546cb55	JCB 16 digit	39.5737937273070273	-119.87071565633417
42451	2020-08-04 23:23:29	2020-08-04	Mr. Adolph Gleichner	mr.adolph.gleichner@warmmail.com	Los Angeles	California	210051223740325275	75f3095ed984fb368e9d7cd252acc465	VISA 16 digit	34.0602145384397303	-118.410865504992373
42452	2020-08-04 23:28:28	2020-08-04	Dr. Gwenda Bashirian	dr.gwenda.bashirian@woohoo.com	Jacksonville	Florida	869937511666242139	a2a9721d1b799b0a2f44776da0f12ac0	JCB 15 digit	30.2913964846223607	-81.6373344984915121
42453	2020-08-04 23:33:19	2020-08-04	Mildred Wolf-Marvin	mildred.wolf.marvin@warmmail.com	New York	New York	4386709861589539	34b3bf85d371a0f02462708225dbd17b	VISA 16 digit	40.6566506827473617	-73.9768650804076344
42454	2020-08-04 23:33:51	2020-08-04	Miss Jaylee Simonis	miss.jaylee.simonis@warmmail.com	Albuquerque	New Mexico	6011585412870341443	836559a5aa29199f9c15fe5176d7b810	Maestro	35.0365776310343335	-106.560742110067608
42455	2020-08-04 23:42:30	2020-08-04	Lucille Haag-Conn	lucille.haag.conn@geemail.com	San Antonio	Texas	6011241157046253636	4a0a9a72a43a302c9a9223263bf1d6de	VISA 16 digit	29.4734168225504476	-98.6094620335683203
42456	2020-08-04 23:51:51	2020-08-04	Jacklyn Rutherford	jacklyn.rutherford@geemail.com	Los Angeles	California	869902833246538138	2c6e5ce75a46f8621ff906cf2feeda4e	VISA 16 digit	34.0110355438064786	-118.377273432024936
42457	2020-08-05 00:00:17	2020-08-05	Ms. Elisa Stoltenberg DVM	ms.elisa.stoltenberg.dvm@warmmail.com	Chicago	Illinois	869972804641842222	1b1073574e3b3e7204ac2bcf04c36772	VISA 13 digit	41.8930831759538549	-87.6670722540497707
42458	2020-08-05 00:05:28	2020-08-05	Moises Carter	moises.carter@geemail.com	Chicago	Illinois	4235795025839996	b36629ca019f5a63b72c3c985e96517b	Diners Club / Carte Blanche	41.806570390688627	-87.7583534582547742
42459	2020-08-05 00:12:37	2020-08-05	Ms. Shona Reichert DVM	ms.shona.reichert.dvm@woohoo.com	Oakland	California	869922329049426940	69ac096415a657adb677ae3a36bc2c5e	Diners Club / Carte Blanche	37.8005717749285068	-122.260165092880925
42460	2020-08-05 00:18:01	2020-08-05	Cannon Smitham MD	cannon.smitham.md@geemail.com	Philadelphia	Pennsylvania	3055545104459788	336cc947dbd5d7390593db39a202474e	JCB 15 digit	39.957510765591266	-75.148992596742886
42461	2020-08-05 00:27:16	2020-08-05	Ferne Schamberger	ferne.schamberger@geemail.com	San Francisco	California	4075308855941	ee7e4a2d541f7ce748ad9d9a1ec52bc0	JCB 16 digit	37.780670918612131	-122.42607952714998
42462	2020-08-05 00:33:43	2020-08-05	Atha Borer	atha.borer@warmmail.com	Peoria	Arizona	4240815191795500	d644481756f488a8aa5bcb5478d512e5	Mastercard	33.8322037423297743	-112.39944034166821
42463	2020-08-05 00:35:26	2020-08-05	Rogelio Schoen	rogelio.schoen@geemail.com	San Francisco	California	180010913222981153	098641782e9a0d572efd2d846321cd6e	Discover	37.7737445855188341	-122.447616379130366
42464	2020-08-05 00:46:09	2020-08-05	Latrina Bergstrom	latrina.bergstrom@warmmail.com	Clinton	Michigan	180036249793287377	b9e112d888b95173eaa0c1f10aa57f4b	VISA 16 digit	42.6676926103487588	-82.9807443999294208
42465	2020-08-05 01:04:02	2020-08-05	Gavin Hand	gavin.hand@geemail.com	Moreno Valley	California	210055049244865581	d39496eb830659938e3e2c856b8c8e87	VISA 13 digit	33.9070145597208281	-117.175209868649759
42466	2020-08-05 01:17:32	2020-08-05	Averie Schimmel-Homenick	averie.schimmel.homenick@geemail.com	Portland	Oregon	3409886349514623	2b93ab1b4b6f4f1eaa01f88a438cb2a0	VISA 16 digit	45.5951451313104457	-122.607544855587193
42467	2020-08-05 01:29:58	2020-08-05	Prince Bailey	prince.bailey@geemail.com	Round Rock	Texas	3465820452692711	d23cdd6a14208887ce006362f3ec16ff	JCB 16 digit	30.5085175383973883	-97.6076969677899058
42468	2020-08-05 01:34:47	2020-08-05	Miles Bednar	miles.bednar@geemail.com	Chicago	Illinois	53554371302708172	520a48fde3b2701d641700597ca736ab	Diners Club / Carte Blanche	41.7760430040605399	-87.5904592697072673
42469	2020-08-05 01:38:15	2020-08-05	Dr. Armstead Kiehn PhD	dr.armstead.kiehn.phd@geemail.com	Kent	Washington	3088668000835910418	6091162170e424e2b5fa70997b5276a3	Maestro	47.3324792726542753	-122.13201415423751
42470	2020-08-05 01:48:31	2020-08-05	Mills Ritchie	mills.ritchie@geemail.com	Seattle	Washington	180056479296599037	fccb7674f55ef9109ec2c1b9cb47a022	VISA 16 digit	47.5579580225441632	-122.340915048021444
42471	2020-08-05 01:48:59	2020-08-05	Shaunna Sawayn	shaunna.sawayn@geemail.com	Allen	Texas	51762369600633777	da04b9c1433c4a778029db19c0dbe5ef	VISA 16 digit	33.1917474517159121	-96.6468453438900355
42472	2020-08-05 01:59:07	2020-08-05	Hayes Oberbrunner PhD	hayes.oberbrunner.phd@geemail.com	San Francisco	California	210098344188520188	92165e9a079db92ca358cb52ed8239eb	VISA 16 digit	37.7641932338976218	-122.442105551836278
42473	2020-08-05 02:09:39	2020-08-05	Arlen Upton	arlen.upton@warmmail.com	Birmingham	Alabama	180090127608527265	8010199e0cd7d3745f8f044f073ba490	JCB 16 digit	33.442963873806967	-86.7111492967475215
42474	2020-08-05 02:13:53	2020-08-05	Tristin Kuhn	tristin.kuhn@geemail.com	Riverside	California	869985186700712511	fc00657f5534050665f2fa9b177c19ef	Mastercard	34.0255960064887972	-117.455630171761655
42475	2020-08-05 02:21:39	2020-08-05	Auston Paucek	auston.paucek@warmmail.com	Austin	Texas	3709383472956607	a84b311396bd857ee2454cdb12acc634	VISA 16 digit	30.4016245109155747	-97.7843678417388418
42476	2020-08-05 02:31:28	2020-08-05	Mr. Kamden Smitham	mr.kamden.smitham@warmmail.com	Los Angeles	California	4854230207356759	e3219d9c2a03770b9b231020dbaf0a7b	VISA 16 digit	33.9298135932400768	-118.393229999252782
42477	2020-08-05 02:37:14	2020-08-05	Mara Kirlin	mara.kirlin@woohoo.com	Ventura	California	3096689361328322775	43c99787625f9f7f543df83ae283b740	Maestro	34.2121298919592078	-119.256621970851711
42478	2020-08-05 02:38:16	2020-08-05	Rosalinda Barton	rosalinda.barton@woohoo.com	San Francisco	California	4173468809640840	307d94a3f1ec09fb5929a8b338a8c5c1	VISA 13 digit	37.7982753690523552	-122.405821493338181
42479	2020-08-05 02:43:28	2020-08-05	Carleton Adams	carleton.adams@warmmail.com	Denver	Colorado	4618361880574876	a703a69172a8c939759696875a91834a	Maestro	39.7944491091236472	-104.938744219044594
42480	2020-08-05 02:44:48	2020-08-05	Mrs. Kandice Dietrich	mrs.kandice.dietrich@geemail.com	Miami	Florida	869905691766364492	ad79d6a5325511bfabc0a32530cb6791	Diners Club / Carte Blanche	25.7985736826572598	-80.2337710387412528
42481	2020-08-05 02:50:49	2020-08-05	Dr. Claus Cummings IV	dr.claus.cummings.iv@warmmail.com	San Francisco	California	51043295595350534	c60455e3d79167acd4a1ef20d7066325	JCB 16 digit	37.7959049373123221	-122.417140152119089
42482	2020-08-05 02:51:38	2020-08-05	Luverne Bogan-Bode	luverne.bogan.bode@woohoo.com	Seattle	Washington	4644888788085116	f8f5a65718091392a92b9ae1c251771e	VISA 13 digit	47.5395629976801573	-122.258718807614969
42483	2020-08-05 02:52:53	2020-08-05	Lavinia Medhurst-Boehm	lavinia.medhurst.boehm@geemail.com	New York	New York	52914046410494452	8d2ae6e98d06394d4612daa96e128d1e	VISA 16 digit	40.6881997133363029	-74.0348485127918394
42484	2020-08-05 02:56:17	2020-08-05	Thurlow McKenzie MD	thurlow.mckenzie.md@woohoo.com	Houston	Texas	54068286422917934	b0d411df52656fd0ffbefa6f38cb782b	JCB 16 digit	29.8073956075202666	-95.4719269128531209
42485	2020-08-05 03:12:00	2020-08-05	Darin Zboncak	darin.zboncak@geemail.com	Port St. Lucie	Florida	3029861640200644	7516ecd9ac0266d6f7422cb51436324d	Diners Club / Carte Blanche	27.2564915977552538	-80.3911006738051839
42486	2020-08-05 03:17:28	2020-08-05	Preston Lockman	preston.lockman@geemail.com	San Francisco	California	675970467933381	d4a28748dfabf178727eab70d0c11b75	VISA 13 digit	37.7423070890643757	-122.450538204615242
42487	2020-08-05 03:21:15	2020-08-05	Elian Kutch	elian.kutch@geemail.com	Mesa	Arizona	4821085763690508	c036d4dd68ce151dd844528752f82569	Maestro	33.3207830074388482	-111.758781450882182
42488	2020-08-05 03:30:24	2020-08-05	Ezell Nienow	ezell.nienow@warmmail.com	Baton Rouge	Louisiana	869968082958341866	3de9471aab2661c0866e9d6a4559dc30	Mastercard	30.5149517053950561	-91.1219183706786424
42489	2020-08-05 03:35:35	2020-08-05	Duncan McClure II	duncan.mcclure.ii@geemail.com	Buffalo	New York	3045943911409932	4df894443c43f65768cb4922851fcd16	JCB 15 digit	42.797443055659528	-78.7771538906663693
42490	2020-08-05 03:45:35	2020-08-05	Burney Ortiz	burney.ortiz@geemail.com	Los Angeles	California	503857375218963	24019dc4ce4b02230a190b86132c4de1	Diners Club / Carte Blanche	34.0960993004828694	-118.346539326989273
42491	2020-08-05 03:53:17	2020-08-05	Ms. Cristen Kassulke MD	ms.cristen.kassulke.md@geemail.com	Berkeley	California	3423845230685316	9b48eb3f0c1e680bdd1cf38f060c274a	Discover	37.9177718240320232	-122.265088820283523
42492	2020-08-05 03:56:30	2020-08-05	Auther Schaefer	auther.schaefer@geemail.com	Richardson	Texas	3722151335802281	08667c733ab9f15ba4885807b125299c	VISA 16 digit	32.9116714372068628	-96.6612695931684271
42493	2020-08-05 03:57:43	2020-08-05	Jaylah Emmerich-McKenzie	jaylah.emmerich.mckenzie@woohoo.com	Columbus	Ohio	51010609701467397	e5f475d2573b099358a481ab38608d8f	Diners Club / Carte Blanche	39.935060625294966	-82.9327520332999626
42494	2020-08-05 04:04:45	2020-08-05	Dorine Legros	dorine.legros@geemail.com	Tuscaloosa	Alabama	6011488376643351435	7b602862dd853139eae21df7e1d01d48	Maestro	33.2001101388651847	-87.5415542925804857
42495	2020-08-05 04:09:54	2020-08-05	Tate Schmidt	tate.schmidt@geemail.com	Palmdale	California	210042763214886585	aeaccc7022e83e35b5a6012eb10372c6	JCB 16 digit	34.5411481159124563	-118.139287460362169
42496	2020-08-05 04:19:09	2020-08-05	Egbert Cronin-Botsford	egbert.cronin.botsford@geemail.com	Lubbock	Texas	3758942926564745	b0e5fc1f03d1104d827d854e2cd77aad	Mastercard	33.4824176348786864	-101.835773631269859
42497	2020-08-05 04:26:46	2020-08-05	Murl Wilkinson	murl.wilkinson@geemail.com	Philadelphia	Pennsylvania	4502064199842	5f4f2ac0a567aa5c30e4feb2f0ad3932	Voyager	39.9945291523780639	-75.0436396409191246
42498	2020-08-05 04:32:05	2020-08-05	Walker Daugherty MD	walker.daugherty.md@geemail.com	Chicago	Illinois	3414701624585490	b5f212ef2da793822a0170ff12fc6cbd	Mastercard	41.8609598973602104	-87.5866351746052487
42499	2020-08-05 04:36:20	2020-08-05	Taurean Kessler	taurean.kessler@geemail.com	San Francisco	California	4101779607032478	8686920ef4a608e02df357516cc18e0e	VISA 13 digit	37.7673625201355136	-122.402371434073387
42500	2020-08-05 04:45:01	2020-08-05	Neil Borer	neil.borer@geemail.com	Oakland	California	4937585119800041	a6dcf4e5178d156032b0acde95a0ffae	Diners Club / Carte Blanche	37.7983680919134741	-122.265739487134823
42501	2020-08-05 04:46:53	2020-08-05	Shamar Lueilwitz	shamar.lueilwitz@geemail.com	Boise	Idaho	3791339925697999	73150763f21147a61ae4dd53a97c2111	Mastercard	43.529470618502053	-116.30342188563273
42502	2020-08-05 05:14:20	2020-08-05	Glover Kreiger	glover.kreiger@warmmail.com	Miami Gardens	Florida	675951735574132	89efeae7c5c9a736254536332902416b	JCB 15 digit	25.8662659585416286	-80.2160556537345002
42503	2020-08-05 05:20:20	2020-08-05	Almond Fadel-Fritsch	almond.fadel.fritsch@geemail.com	San Francisco	California	4920184032589615	a73a1d64b5f327836c2d156454c9fbb0	Voyager	37.753111771401457	-122.394524583231103
42504	2020-08-05 05:21:28	2020-08-05	Trilby Boyer	trilby.boyer@geemail.com	San Diego	California	3773405682038263	c143baa27e8027d3c3ba768b3623e805	VISA 16 digit	32.797153095348925	-117.05195089833812
42505	2020-08-05 05:32:35	2020-08-05	Earl West Jr.	earl.west.jr.@woohoo.com	New York	New York	676276578247173	405fc70ed18a108a6f36464c1affdd15	American Express	40.6933209825530611	-74.0172696280654492
42506	2020-08-05 05:46:13	2020-08-05	Dr. Federico Yundt DVM	dr.federico.yundt.dvm@geemail.com	San Antonio	Texas	4166302023270143	3b04349645f464c6dc235a7284ea0138	VISA 16 digit	29.5592040882982303	-98.5018788880039011
42507	2020-08-05 05:50:10	2020-08-05	Olene Green	olene.green@geemail.com	Chicago	Illinois	869972684255201976	06eff3f50847683277697ca3ba5f95cb	American Express	41.7708698347512666	-87.7319133429352149
42508	2020-08-05 05:50:50	2020-08-05	Mrs. Eda Hessel	mrs.eda.hessel@woohoo.com	Oakland	California	210024461886183553	89277f572e630f8a69011c42a08e3693	American Express	37.7686807016514976	-122.30934004130232
42509	2020-08-05 05:51:47	2020-08-05	Grayling Farrell	grayling.farrell@geemail.com	St. Louis	Missouri	3158493816676220885	bc01c5d71704ba4f3bf4ab578c3bdbe0	Diners Club / Carte Blanche	38.671382794684547	-90.3174696879930821
42510	2020-08-05 05:56:18	2020-08-05	Shaun Lynch	shaun.lynch@geemail.com	San Francisco	California	4814138936341373	c2ec97889830ae0cf200a5b9af939fcb	VISA 16 digit	37.761732413748625	-122.433623974396909
42511	2020-08-05 05:57:32	2020-08-05	Miss Shavonne Dooley	miss.shavonne.dooley@warmmail.com	Cleveland	Ohio	6011335299308887599	80f850bf74bb24667d3976fbffaae98e	American Express	41.3804109320826825	-81.6770586256641877
42512	2020-08-05 06:10:33	2020-08-05	Myrl Hagenes	myrl.hagenes@warmmail.com	Washington	District of Columbia	4422016449056544	eb31099f93417277c38737c5c3259bc6	JCB 16 digit	38.8378097737938148	-76.9551805044736739
42513	2020-08-05 06:12:26	2020-08-05	Charlie Gulgowski	charlie.gulgowski@geemail.com	San Francisco	California	4785629594465772	47e0690e49c3440325dfd1590b8f6e29	American Express	37.7668643703434199	-122.418954191058688
42514	2020-08-05 06:16:47	2020-08-05	Rosemarie Leffler	rosemarie.leffler@woohoo.com	El Paso	Texas	51670942970880839	0e5e2d502d6845c5293ae66392673836	Mastercard	31.7634936521589779	-106.430836337942637
42515	2020-08-05 06:17:23	2020-08-05	Isom Bins	isom.bins@geemail.com	Berkeley	California	54247277356411907	439fa689c335b2c0e5f4e91aea5bf18a	JCB 16 digit	37.8584235618344422	-122.271600419327697
42516	2020-08-05 06:37:06	2020-08-05	Johnnie Mertz	johnnie.mertz@geemail.com	Fremont	California	3158458552342601884	41b2d938c6885dc5e041abd1304845db	JCB 16 digit	37.4747715732716031	-121.951292548746608
42517	2020-08-05 06:45:22	2020-08-05	Blanca Johns-Rau	blanca.johns.rau@geemail.com	Kansas City	Missouri	6011663335705167631	37e903d1a407ced471aeb2c99202af46	VISA 13 digit	39.1518420150805326	-94.5856880524419239
42518	2020-08-05 06:45:58	2020-08-05	Gilbert Rath	gilbert.rath@woohoo.com	New York	New York	4256113733339	9c932fc70e44876c12ea0b2893b01b6a	JCB 16 digit	40.6952239340394755	-73.8470500617649321
42519	2020-08-05 06:46:58	2020-08-05	Texie Wehner	texie.wehner@woohoo.com	Dallas	Texas	4977949829849	0f8ba3315513ed00ead5b0fb29ffb5a0	VISA 16 digit	32.6973178689174375	-96.7315589558295841
42520	2020-08-05 06:48:28	2020-08-05	Ronna Fahey	ronna.fahey@warmmail.com	Minneapolis	Minnesota	4740874537088	22bbec5f2c587ccc0dd74fcc5e7b1f8c	JCB 16 digit	45.022845534709468	-93.3492210335370061
42521	2020-08-05 06:48:59	2020-08-05	Florene Runolfsdottir	florene.runolfsdottir@geemail.com	San Angelo	Texas	3337978428848654035	4cdf8af08fda87ec2ede454e25875c4e	VISA 16 digit	31.375591488430647	-100.454392283607277
42522	2020-08-05 06:53:08	2020-08-05	Raymon Huel	raymon.huel@geemail.com	Los Angeles	California	180096862167668670	967b16a61fa6a51a2e760deed2b20977	Maestro	34.0421142616640751	-118.366551123232767
42523	2020-08-05 06:53:43	2020-08-05	Jim Becker IV	jim.becker.iv@geemail.com	Vallejo	California	3499607141166797	b8083e5b12823f21474b835dac84d1d4	Diners Club / Carte Blanche	38.1952315135948339	-122.325389116058119
42524	2020-08-05 06:53:48	2020-08-05	Gerry Shields	gerry.shields@warmmail.com	North Charleston	South Carolina	4427614414592	1e86ee6f8d88c7bd9db56cc4e5ecf1b5	VISA 16 digit	32.832711853149533	-80.1527882655709902
42525	2020-08-05 06:53:49	2020-08-05	Dr. Glendon Okuneva DDS	dr.glendon.okuneva.dds@geemail.com	Fremont	California	53516581221327352	b91bfacb512b364e213ee2c9979ced0d	JCB 15 digit	37.5281291091516636	-121.909603601367024
42526	2020-08-05 07:02:43	2020-08-05	Benjiman Dare	benjiman.dare@geemail.com	Mesa	Arizona	3158718526997930992	d4a97dcfa6bc4b92e8f7a1ebd30f8c50	VISA 16 digit	33.4365750319469726	-111.77042919438108
42527	2020-08-05 07:03:46	2020-08-05	Dr. Presley Hessel	dr.presley.hessel@warmmail.com	Henderson	Nevada	3158785283984695737	c06d00787d35b25a5415435f487d1c8f	Diners Club / Carte Blanche	36.1050641050029597	-115.127549032789474
42528	2020-08-05 07:04:29	2020-08-05	Casen Kiehn-Hermiston	casen.kiehn.hermiston@geemail.com	Columbus	Ohio	4980271699482171	b4c01e58521eb44dcd242c2b4453001c	VISA 13 digit	39.8937031176917216	-82.9159432293616305
42529	2020-08-05 07:12:22	2020-08-05	Shelley Bergnaum	shelley.bergnaum@geemail.com	Jacksonville	Florida	4990714975381193	c40b5495b1b05dc4b31f1594570d5f8a	VISA 16 digit	30.4172997946437462	-81.565880424164618
42530	2020-08-05 07:16:05	2020-08-05	Ramona Gerlach PhD	ramona.gerlach.phd@geemail.com	Santa Rosa	California	3477863009258699	4b4da34ac71dea5d1ef167caef863781	JCB 16 digit	38.4545424257528055	-122.657042083401606
42531	2020-08-05 07:18:52	2020-08-05	Ms. Lauri Gutkowski PhD	ms.lauri.gutkowski.phd@geemail.com	New York	New York	4995230739032027	43e9c8e1b587685e861f05d0dd87c3a2	Discover	40.653210127655413	-73.9536754768237472
42532	2020-08-05 07:18:54	2020-08-05	Rafe Gusikowski	rafe.gusikowski@geemail.com	Springfield	Illinois	3767298459959904	311959707ab1187ae057c22fd6ce32bf	VISA 16 digit	39.8002736428439619	-89.6281699564311651
42533	2020-08-05 07:19:51	2020-08-05	Woodroe Jaskolski	woodroe.jaskolski@geemail.com	Abilene	Texas	4613893489609	f288c823bf4ba59f11a2acf27030901a	Maestro	32.3884202140457944	-99.7739622773550536
42534	2020-08-05 07:24:16	2020-08-05	Mrs. Terra Bahringer	mrs.terra.bahringer@woohoo.com	New York	New York	51368926053697837	21e30836dc21fafba7f59c68324cb59a	Maestro	40.6978651708215438	-73.9226603659696906
42535	2020-08-05 07:24:46	2020-08-05	Marshall Walker	marshall.walker@warmmail.com	Aurora	Illinois	55146429675903419	3d73f9a01444e4df6f50ce45c00cb6ad	JCB 15 digit	41.7373706353120539	-88.2815542000740692
42536	2020-08-05 07:25:19	2020-08-05	Meaghan Jones	meaghan.jones@geemail.com	Hayward	California	3035764771217037	5e7163b3673c3bb2322b953152807e1b	VISA 16 digit	37.70007173577212	-122.08292391237579
42537	2020-08-05 07:32:17	2020-08-05	August Schneider III	august.schneider.iii@geemail.com	Mobile	Alabama	869919297231625105	69697c3c7cbe75116c503b1532941f32	Diners Club / Carte Blanche	30.7680380661148547	-88.037692148252205
42538	2020-08-05 07:36:30	2020-08-05	Ulises Treutel-Schiller	ulises.treutel.schiller@geemail.com	Dallas	Texas	54997275374784000	edd9c09ffd75acecd19af4c33f8c283f	JCB 16 digit	32.847151757990197	-96.8233652325309748
42539	2020-08-05 07:37:48	2020-08-05	Ginger Tillman	ginger.tillman@geemail.com	San Diego	California	210097214895178334	9b8978ea51b19dcdc6d2c5bf699c2c6a	VISA 13 digit	32.7667190234709551	-117.112908551460137
42540	2020-08-05 07:38:51	2020-08-05	Sharee Bernier	sharee.bernier@geemail.com	San Antonio	Texas	3158081906708300439	bcc19ffad32586e1329b4e40c8347f43	JCB 15 digit	29.4517887045234446	-98.4846464705023834
42541	2020-08-05 07:47:41	2020-08-05	Alisson Jerde	alisson.jerde@woohoo.com	San Francisco	California	3050893148115593	3305ede314fb2c757b7f388bdf4a2370	VISA 16 digit	37.8206357572497041	-122.427018328541877
42542	2020-08-05 07:48:52	2020-08-05	Brianne Roob	brianne.roob@geemail.com	Hampton	Virginia	676334015115388	e7667f7ad677b11faab62408e12fab01	Voyager	37.0863346638176594	-76.256957220295817
42543	2020-08-05 07:50:25	2020-08-05	Monnie Tillman	monnie.tillman@warmmail.com	San Diego	California	869916603344796019	21ab95dcceffd0709ab4aef846621667	JCB 16 digit	32.7547987847656046	-117.066939207203689
42544	2020-08-05 07:55:27	2020-08-05	Mr. Santino Kub	mr.santino.kub@geemail.com	Henderson	Nevada	52102609661284633	d87d0c0413219ddc19e642bcede9c223	Mastercard	35.9942277197659024	-114.9903458750032
42545	2020-08-05 07:57:32	2020-08-05	Mr. Barnard Waters	mr.barnard.waters@geemail.com	San Francisco	California	180008721439638191	33ff8c5716ac759285ba83fa5400ea9e	Discover	37.736436875428609	-122.409517379080697
42546	2020-08-05 08:01:23	2020-08-05	Suzanna Kassulke	suzanna.kassulke@geemail.com	Durham	North Carolina	180097368844085766	6d3a50550fd0084ba37caa4e65a7e9fb	JCB 16 digit	35.8854015093076981	-78.9016619673833333
42547	2020-08-05 08:05:48	2020-08-05	Jones Koepp	jones.koepp@geemail.com	Palmdale	California	4534475433652939	e747728e9f298b6cc8a67b83105c4a72	VISA 16 digit	34.4923059447519478	-118.161500259302187
42548	2020-08-05 08:19:33	2020-08-05	Rocco Okuneva-Lindgren	rocco.okuneva.lindgren@geemail.com	New York	New York	180052504936346202	9f92bc641f78292abbe8997053a68f9d	JCB 15 digit	40.592666813660415	-73.9936354246817558
42549	2020-08-05 08:24:47	2020-08-05	Caitlin Legros-Purdy	caitlin.legros.purdy@geemail.com	Carlsbad	California	6011712024517472964	e4fa87457a917d79868c06fa21555513	JCB 15 digit	33.1805161965019977	-117.366879198958344
42550	2020-08-05 08:32:09	2020-08-05	Candida Stoltenberg	candida.stoltenberg@geemail.com	Cedar Rapids	Iowa	4731545684656	627757707cf454e643970d023824aa83	VISA 16 digit	41.9954281521569897	-91.6184714645680032
42551	2020-08-05 08:37:10	2020-08-05	Loretta Stroman	loretta.stroman@geemail.com	Dayton	Ohio	869948847510222167	f482477e851d4c89dbc527955898d5a0	JCB 15 digit	39.8414501709189253	-84.2726087410192974
42552	2020-08-05 08:41:36	2020-08-05	Admiral O'Kon	admiral.o'kon@geemail.com	Kansas City	Kansas	210008212978577867	d38531508bce0e5a1717cfea2921dc3b	JCB 15 digit	39.0928537239693128	-94.7520396243251781
42553	2020-08-05 08:52:29	2020-08-05	Dr. Makala Watsica	dr.makala.watsica@woohoo.com	San Francisco	California	4101260590548	3a4a35c545b89e10040676efdbd4c4f7	JCB 15 digit	37.7782397608071321	-122.458316916971185
42554	2020-08-05 08:55:49	2020-08-05	Ilona Hayes	ilona.hayes@woohoo.com	Indianapolis	Indiana	4600485314618452	4ed0ed982df884e58b7002a182c79566	Discover	39.7228915389634665	-86.1265928399484579
42555	2020-08-05 08:56:09	2020-08-05	Rosendo Fahey-Toy	rosendo.fahey.toy@geemail.com	Lubbock	Texas	6011555977780809826	3aa46ad65042122decb6aafeac38804f	Voyager	33.5740812867920866	-101.808194594728576
42556	2020-08-05 08:58:40	2020-08-05	Milly Feil	milly.feil@geemail.com	Davie	Florida	210057449630395631	6ad2f10b1da26e7cce310f930d4e8135	VISA 13 digit	26.1584964890297513	-80.2907063870597568
42557	2020-08-05 09:09:36	2020-08-05	Anice Bradtke-Senger	anice.bradtke.senger@geemail.com	Milwaukee	Wisconsin	4420539370693979	9580e58ca37da6234c7dfc446fdb4cee	JCB 16 digit	42.9644243090499174	-87.9711313682243201
42558	2020-08-05 09:20:15	2020-08-05	Mr. Rueben King	mr.rueben.king@geemail.com	Long Beach	California	55304866678792927	1ad51cee900419c0e71092d1d8d3ecef	VISA 16 digit	33.8696384060949072	-118.170314015138146
42559	2020-08-05 09:37:19	2020-08-05	Santina Ritchie	santina.ritchie@geemail.com	Philadelphia	Pennsylvania	180076661919155471	1515fddb5c28bfaa777f083da0460fd7	VISA 16 digit	39.9173304469749297	-75.1392241440147188
42560	2020-08-05 09:38:53	2020-08-05	Markita Kuhic	markita.kuhic@warmmail.com	Columbus	Ohio	3013699815127036	a781ad9a9766315d104e4f3171546616	JCB 16 digit	39.9356973431583455	-83.0718308693032839
42561	2020-08-05 09:39:36	2020-08-05	Mr. Mickey Bins	mr.mickey.bins@geemail.com	Salem	Oregon	3528650361987015053	53e527aebb6d4c9e410a1263897546c6	American Express	44.9593859512627105	-123.016015486807376
42562	2020-08-05 10:07:44	2020-08-05	Damond Bartoletti	damond.bartoletti@geemail.com	Fremont	California	180010776681642743	8fc933a65d9669056c9aafb1e1da2b45	Mastercard	37.4455024684015712	-122.029801903570814
42563	2020-08-05 10:08:09	2020-08-05	Miss Skye Murray	miss.skye.murray@geemail.com	Honolulu	Hawaii	6011659593528751348	9dadf406b482dfe2a6e2e78dfb233766	Maestro	21.4184900394391278	-157.749406963607669
42564	2020-08-05 10:12:50	2020-08-05	Amil Waelchi-Macejkovic	amil.waelchi.macejkovic@geemail.com	Carlsbad	California	6011675416125844409	a45475dcc5020af83fec804ec93ae570	American Express	33.1215079339627181	-117.349553921099002
42565	2020-08-05 10:13:48	2020-08-05	Pamala McClure	pamala.mcclure@geemail.com	Fort Worth	Texas	3767822260226607	c762ba68f4b09c27df8ab6a36406856d	Diners Club / Carte Blanche	32.7402574205361319	-97.3927797064472003
42566	2020-08-05 10:34:34	2020-08-05	Byrd Johns	byrd.johns@geemail.com	Los Angeles	California	3019461936210470	526a286af9e75c9458db2c733fdae115	Maestro	33.9806288907635903	-118.421788865140826
42567	2020-08-05 10:36:34	2020-08-05	Marjory Collier-Mitchell	marjory.collier.mitchell@woohoo.com	New York	New York	3112977549391769150	9fd6de731d2172f1ed953ef54063c306	VISA 16 digit	40.6380571729261391	-73.8606797444529803
42568	2020-08-05 10:43:54	2020-08-05	Destiney Konopelski	destiney.konopelski@geemail.com	Sioux Falls	South Dakota	3112512295048441130	a093755214ba7f8bf3c20bb308a06ceb	VISA 16 digit	43.4666753383904663	-96.7882757071107562
42569	2020-08-05 11:03:56	2020-08-05	Miss Breanna Turcotte MD	miss.breanna.turcotte.md@warmmail.com	Philadelphia	Pennsylvania	3112762245481375227	a9b12bc1d41e3fd2ec1a4c486371795e	VISA 13 digit	40.0076989352196435	-75.2222845126308499
42570	2020-08-05 11:06:58	2020-08-05	Eleonore Turcotte	eleonore.turcotte@geemail.com	Kansas City	Missouri	3096822838624276167	369bee20e9e52d16886b4e5d635c4de1	JCB 16 digit	39.055605295796326	-94.615615994505589
42571	2020-08-05 11:16:26	2020-08-05	Mrs. Maebell Gislason DVM	mrs.maebell.gislason.dvm@geemail.com	Boise	Idaho	4908048977387523	be34fad7fea78bc2c5f02c539ecd2d36	Mastercard	43.548161481520907	-116.175868540835381
42572	2020-08-05 11:37:55	2020-08-05	Dr. Polly Murray	dr.polly.murray@warmmail.com	New York	New York	4835116144194318	95ba6a1b9b12ade604d0c219f8566acb	American Express	40.6440770131759308	-73.9539404446154833
42573	2020-08-05 11:57:28	2020-08-05	Auther Grimes	auther.grimes@geemail.com	Cape Coral	Florida	3088487102847846942	8277642f783951d147215a0904a416eb	Discover	26.5663780248694117	-81.9298667308013933
42574	2020-08-05 12:22:11	2020-08-05	Dr. Jewell Ward I	dr.jewell.ward.i@geemail.com	Gilbert	Arizona	210067842952258775	5d3e03f93edeb17e2c0093f6ff9c55f1	Voyager	33.3959590847484762	-111.693598608825724
42575	2020-08-05 12:26:56	2020-08-05	Lavona McCullough	lavona.mccullough@geemail.com	Fresno	California	210048554278991161	ad59aad33ba457a31eeb982df97cb2ec	American Express	36.8096948792099923	-119.75206749607959
42576	2020-08-05 12:42:52	2020-08-05	Obed Kilback	obed.kilback@geemail.com	Tacoma	Washington	52363454815863196	1a4f9dd4f74d9d6e55bbfba4aa797742	Discover	47.3228878561526543	-122.409721726342298
42577	2020-08-05 12:46:17	2020-08-05	Mr. Erby Zboncak	mr.erby.zboncak@geemail.com	San Francisco	California	4574826507610495	ba7dbd0a959e71cc98bdf4eba1972906	Discover	37.7834589276792698	-122.450362963463178
42578	2020-08-05 12:47:43	2020-08-05	Novella Stark	novella.stark@geemail.com	Seattle	Washington	869961869058952718	3c9fe85b6dde0c3627e967ef9e11543c	VISA 13 digit	47.6677691839095203	-122.396730728672438
42579	2020-08-05 12:48:11	2020-08-05	Harrison Bergnaum-Smith	harrison.bergnaum.smith@woohoo.com	Baltimore	Maryland	52371849429154652	1a89199762e966df0be1038b79c5d972	VISA 16 digit	39.280411571217698	-76.6825560734625924
42580	2020-08-05 13:09:38	2020-08-05	Fitzhugh Abshire	fitzhugh.abshire@geemail.com	Columbus	Georgia	54676391838710701	2a7f8fbd2c617d8ffabf1b0a0117831b	Maestro	32.5023736090443975	-84.8431922445703322
42581	2020-08-05 13:12:13	2020-08-05	Dr. Noel Strosin Jr.	dr.noel.strosin.jr.@geemail.com	Des Moines	Iowa	676347512542052	353cf66effa8b5504b94ca055b23343d	VISA 13 digit	41.4925307267088428	-93.6338017412040386
42582	2020-08-05 13:14:35	2020-08-05	Mr. Basil Dicki DVM	mr.basil.dicki.dvm@geemail.com	New York	New York	53004916210271154	4315bcd7ab8663691b667b26d35dc9bd	American Express	40.70195540033653	-73.8818067818310027
42583	2020-08-05 13:19:45	2020-08-05	Sherrill Stokes	sherrill.stokes@geemail.com	Salt Lake City	Utah	4362217469539	b63d7d22fc21127c7182a6691e2014dc	JCB 15 digit	40.6992186744377022	-111.943853094981975
42584	2020-08-05 13:20:59	2020-08-05	Mr. Rodney Sawayn I	mr.rodney.sawayn.i@geemail.com	Oakland	California	676127308092223	1dca82b10dcb4341b0171d751803e8dd	VISA 16 digit	37.8076099588759007	-122.302261446570668
42585	2020-08-05 13:21:48	2020-08-05	Ettie Grimes	ettie.grimes@woohoo.com	San Francisco	California	869975475015468998	9f9fcee712de04b368d981db23bfd7b4	VISA 16 digit	37.7740074003561475	-122.420178542185781
42586	2020-08-05 13:42:56	2020-08-05	Hayley Crona	hayley.crona@warmmail.com	Berkeley	California	3779217789854904	ba61a951eeaf183fab3f179ab6f744c2	VISA 16 digit	37.9121751540851335	-122.267451012150204
42587	2020-08-05 13:44:27	2020-08-05	Eleanora Lebsack	eleanora.lebsack@geemail.com	Phoenix	Arizona	3112636456100594759	95d019766f61f5d01450f098eade3772	VISA 16 digit	33.6629269936054953	-112.063912343692408
42588	2020-08-05 13:46:22	2020-08-05	Dr. Johan Haag Sr.	dr.johan.haag.sr.@warmmail.com	New York	New York	4228052018813961	9a6f303d6763eeca2f3cc6f617415785	Mastercard	40.6295848706495022	-73.9228824734117751
42589	2020-08-05 13:48:34	2020-08-05	Osa Lynch	osa.lynch@warmmail.com	Chicago	Illinois	3337634429273824933	bb89ebba4af7ad2d1dfba88295c49ee4	Voyager	41.8281766125302781	-87.7179821872647807
42590	2020-08-05 13:53:43	2020-08-05	Kenyon Labadie	kenyon.labadie@geemail.com	Boston	Massachusetts	3019117866980074	7a53c3d19ce3644dd7e091d97fb57d30	American Express	42.4167805851139121	-71.0272468347985324
42591	2020-08-05 13:58:42	2020-08-05	Samual Berge	samual.berge@geemail.com	Allentown	Pennsylvania	4134903559489	525ed9effada1b8938157ddc7af2dd78	VISA 16 digit	40.6808295903041994	-75.4087807073272671
42592	2020-08-05 13:59:31	2020-08-05	Isabella Schaefer-Sawayn	isabella.schaefer.sawayn@warmmail.com	Louisville	Kentucky	3491354075326521	c3d37111741f1b298b2ba60779726358	JCB 15 digit	38.1118911731425669	-85.7244448127295868
42593	2020-08-05 14:06:17	2020-08-05	Jeannie Bosco	jeannie.bosco@geemail.com	San Francisco	California	869907025714128428	bdf3ac6b1d0e0aeaf52f0251dc2ed1ac	Discover	37.7829072287249375	-122.40943646997566
42594	2020-08-05 14:07:33	2020-08-05	Noble Jerde-Sanford	noble.jerde.sanford@geemail.com	Jacksonville	Florida	54146838477672834	cb536b53e510a9ed8e4adb08662db992	Discover	30.2620877136528499	-81.565007495375724
42595	2020-08-05 14:24:40	2020-08-05	Miss Geri Nikolaus DDS	miss.geri.nikolaus.dds@geemail.com	Newport News	Virginia	3444199225336997	4f326f1eae358f3029b8b160e72385c8	JCB 15 digit	36.9930181467335686	-76.610691264996305
42596	2020-08-05 14:27:48	2020-08-05	Helaine Sawayn	helaine.sawayn@geemail.com	Washington	District of Columbia	869914752939716890	09180ca43442b6057619fb377c0f4b1c	Diners Club / Carte Blanche	38.9796821671336886	-77.0978852316483909
42597	2020-08-05 14:32:19	2020-08-05	Liberty Corkery	liberty.corkery@geemail.com	San Francisco	California	4831724799901574	bc181a4e166516c7b4d84bcf16caa61a	JCB 16 digit	37.7721072012597006	-122.440906836629011
42598	2020-08-05 14:41:21	2020-08-05	Sherie White-Blanda	sherie.white.blanda@geemail.com	Brownsville	Texas	6011873351176712553	489cdf7994df291128ad1ff7c3235a12	VISA 13 digit	26.044789876563847	-97.4810873008985084
42599	2020-08-05 14:49:20	2020-08-05	Lillard Mayert	lillard.mayert@geemail.com	New York	New York	676361982272553	bd82a17a973d213e1d69abff1e953e58	American Express	40.744641329510138	-73.9078625338047743
42600	2020-08-05 14:55:12	2020-08-05	Ivey Kessler	ivey.kessler@geemail.com	San Francisco	California	4654003243493544	66f28f0159503c03ab3f9d3cc691a475	Maestro	37.845669447396169	-122.419127910186688
42601	2020-08-05 15:00:36	2020-08-05	Maximiliano Ferry	maximiliano.ferry@woohoo.com	New York	New York	3112977499579387542	564ba1454eeb7e55e89375e8dfef1038	VISA 16 digit	40.5870729240346719	-73.9330525344133349
42602	2020-08-05 15:01:32	2020-08-05	Miss Ferne Ziemann	miss.ferne.ziemann@geemail.com	North Charleston	South Carolina	3478600315778971	7fb060eed3bb31c1a4ba88d3d0175751	VISA 16 digit	32.9857020086769026	-80.0957864827569495
42603	2020-08-05 15:06:30	2020-08-05	Vinson Koch PhD	vinson.koch.phd@geemail.com	Tulsa	Oklahoma	4184305459194248	78debeb02fc16d2bc2a67972d73089e7	VISA 16 digit	36.2175822279784825	-95.8752975143447514
42604	2020-08-05 15:17:41	2020-08-05	Marquita Harvey	marquita.harvey@geemail.com	Chicago	Illinois	4431604904704945	4af0be7adb6c1cd68543af13c91e49be	JCB 16 digit	41.8638040361762052	-87.6053445674508708
42605	2020-08-05 15:19:36	2020-08-05	Edrie Nikolaus	edrie.nikolaus@geemail.com	Houston	Texas	4458660609512	808a59f6115509db90179ccd4c8df835	Discover	29.7136428198389702	-95.4300086469870052
42606	2020-08-05 15:21:49	2020-08-05	Gurney Baumbach	gurney.baumbach@geemail.com	Pasadena	Texas	503874429286482	3c18fb3644af9bf8a539cbf3685a0ed0	Diners Club / Carte Blanche	29.7228320197541258	-95.0738162182219355
42607	2020-08-05 15:23:09	2020-08-05	Dr. Golden Wunsch IV	dr.golden.wunsch.iv@geemail.com	Washington	District of Columbia	55194275904673880	73bf783d53a1dbd29fe1349f9e2f2b1f	Mastercard	38.9829195214699951	-77.0201889747500417
42608	2020-08-05 15:25:26	2020-08-05	Mr. Greyson Zulauf Jr.	mr.greyson.zulauf.jr.@geemail.com	Carrollton	Texas	3029860509193817	eba3add33f45a0ecfa0e183324ae4927	VISA 13 digit	32.9492539689332204	-96.9569746079716879
42609	2020-08-05 15:29:07	2020-08-05	Augustus Tillman	augustus.tillman@geemail.com	Los Angeles	California	6011384160939701171	66b17e83d3e10ed9d5f0fa22f8f03913	Maestro	33.9952449434302721	-118.439119105040277
42610	2020-08-05 15:34:15	2020-08-05	Eleanore Vandervort	eleanore.vandervort@warmmail.com	Akron	Ohio	4253267307458074	7bf3093fea8570490ffa5b25a1641b86	VISA 13 digit	41.1057167161088444	-81.6127710536435274
42611	2020-08-05 15:35:39	2020-08-05	Concepcion Hickle-Anderson	concepcion.hickle.anderson@geemail.com	Houston	Texas	561286112968317	1b8379ba9e7cc8785e36673703a66345	VISA 16 digit	29.7330346371125422	-95.3053396895542733
42612	2020-08-05 15:36:09	2020-08-05	Karly Schiller	karly.schiller@geemail.com	Palm Bay	Florida	210063363893032934	6bd9bd6d26c5a2866d6da13d1dccca42	Mastercard	27.9441758381988876	-80.6577265734154736
42613	2020-08-05 15:37:51	2020-08-05	Rene Runolfsdottir DDS	rene.runolfsdottir.dds@woohoo.com	Oklahoma City	Oklahoma	3088263492025626046	850751cb513381eac93876d7dcf7ce37	VISA 16 digit	35.3849336511366062	-97.5398492588091699
42614	2020-08-05 15:40:09	2020-08-05	Josiephine Yost PhD	josiephine.yost.phd@geemail.com	Glendale	California	6011372978603267102	6a2bf1a45c58ea73e57b358a7e0e0b04	Voyager	34.2596934738323071	-118.302869495785984
42615	2020-08-05 16:11:27	2020-08-05	Marius Kassulke	marius.kassulke@geemail.com	San Francisco	California	6011959670324870444	ca6e1d5cf29ae58d3bd1e815331c446f	Maestro	37.8053116480745572	-122.425452599816623
42616	2020-08-05 16:20:44	2020-08-05	Monte Mueller	monte.mueller@geemail.com	San Diego	California	210098216898025338	f31f802cb7eed2a862970a523ef1bd1c	Mastercard	32.8311728650771073	-117.059025102285673
42617	2020-08-05 16:26:01	2020-08-05	Ardelle Kunze	ardelle.kunze@geemail.com	New York	New York	6011401545862573101	42c216bd84c443d5abad9ee38dc6d210	American Express	40.6234350783508233	-74.0203344082355414
42618	2020-08-05 16:31:17	2020-08-05	Dr. Halley Runte Jr.	dr.halley.runte.jr.@geemail.com	Joliet	Illinois	52890581113614160	0a48179d1a63f246793903474ab362a8	Discover	41.4586614858683191	-88.1530750317603236
42619	2020-08-05 16:45:09	2020-08-05	Mr. Joseluis Strosin Sr.	mr.joseluis.strosin.sr.@geemail.com	Sacramento	California	3096254294984998981	10e5b8d85743ea27f32acde76f69dc5f	Maestro	38.5812547854878005	-121.370267168131093
42620	2020-08-05 16:50:30	2020-08-05	Shane Kunze	shane.kunze@geemail.com	Jacksonville	Florida	869967722961575015	889999add226249dcd999a6f42040174	Mastercard	30.278872534451633	-81.6957850594151864
42621	2020-08-05 17:03:57	2020-08-05	Geo Lynch	geo.lynch@geemail.com	Greeley	Colorado	6011553214950199412	636ab086cd6d10d1de49c07fc1a8f5ca	Discover	40.3319373630519991	-104.674795437541604
42622	2020-08-05 17:15:29	2020-08-05	Dr. Kristal Farrell	dr.kristal.farrell@geemail.com	New York	New York	3479440339566782	82f3fa41e8db27fd79a2cd92a169dc6b	VISA 16 digit	40.7290486363917594	-73.9117081421323121
42623	2020-08-05 17:15:32	2020-08-05	Esperanza Pfeffer PhD	esperanza.pfeffer.phd@geemail.com	Kansas City	Missouri	869921567754991175	d7c901d918ea5c63cff31fda2df57827	Maestro	39.0255454148467678	-94.5666264233868645
42624	2020-08-05 17:26:03	2020-08-05	Gerardo Dibbert-Volkman	gerardo.dibbert.volkman@geemail.com	Indianapolis	Indiana	589398155766607	a0d40b8cd2dde66013ca892dce532634	Mastercard	39.7961064683280838	-86.2031530969046003
42625	2020-08-05 17:59:32	2020-08-05	Corine Franecki	corine.franecki@geemail.com	Irving	Texas	3112029508991565432	8086e34619970a2a89abe86bd687f4d5	VISA 16 digit	32.773251046701148	-96.9888679480925191
42626	2020-08-05 18:05:01	2020-08-05	Lindsay Gottlieb	lindsay.gottlieb@geemail.com	New York	New York	4074441354011	83111f4abe3d3c0d1376bf50c860b660	JCB 16 digit	40.7556959664206957	-73.9047827341023833
42627	2020-08-05 18:09:16	2020-08-05	Moshe Nienow	moshe.nienow@woohoo.com	Huntington Beach	California	869958908642397967	214631378dd1db03121ac10e2dcc4957	Voyager	33.7483584797050824	-118.063700190338494
42628	2020-08-05 18:10:31	2020-08-05	Jaslyn Roob	jaslyn.roob@woohoo.com	Los Angeles	California	6011370414788501562	c11ff2422340f42e6991e3f88e9d6f67	Voyager	34.0020232247054537	-118.502931869122378
42629	2020-08-05 18:21:35	2020-08-05	Dr. Erie Casper III	dr.erie.casper.iii@geemail.com	Montgomery	Alabama	630451405163448	60d2daf8125dcb41bd335aa02e23e227	Diners Club / Carte Blanche	32.3647477240700283	-86.2683493027616208
42630	2020-08-05 18:27:10	2020-08-05	Pearley Wehner	pearley.wehner@woohoo.com	Riverside	California	6011335577565304022	5abdda377ba0352663363d2a0b0f89c7	VISA 13 digit	34.0284595508076251	-117.446412534403422
42631	2020-08-05 18:32:53	2020-08-05	Ronny Ernser	ronny.ernser@geemail.com	Phoenix	Arizona	4547460633803578	8a98cdc3a444011b7f80396a4d6b493c	VISA 16 digit	33.524153601976856	-112.137104528809346
42632	2020-08-05 18:34:08	2020-08-05	Preston Jaskolski	preston.jaskolski@warmmail.com	New York	New York	4718565341339369	8277d4876516604e98bd571fc99fbcd9	Diners Club / Carte Blanche	40.6164634441249035	-73.9618169769540401
42633	2020-08-05 18:48:49	2020-08-05	Luann Abernathy	luann.abernathy@geemail.com	Jacksonville	Florida	6011106583271932426	6a225784898a5cc3a50d55e9ba16deec	JCB 15 digit	30.3725921317055807	-81.6720317008517753
42634	2020-08-05 18:49:25	2020-08-05	Trevor Kozey	trevor.kozey@woohoo.com	Portland	Oregon	6011752035261872796	18f2b5566fe5027b30cec6badaada0b8	VISA 16 digit	45.448956633580849	-122.581299105426297
42635	2020-08-05 19:05:01	2020-08-05	Gay Schmitt	gay.schmitt@woohoo.com	Los Angeles	California	4922466257172	e5f8f2ccea51cbc2566a2eb5211577c1	Voyager	34.0413919855706339	-118.477096092839901
42636	2020-08-05 19:19:44	2020-08-05	Darby Moore	darby.moore@geemail.com	Philadelphia	Pennsylvania	4010512155416	5baa18c6234265686bc53fe9b3c2f742	JCB 15 digit	39.9820749607361847	-75.1514488411035444
42637	2020-08-05 19:22:31	2020-08-05	Lem Rodriguez-Jerde	lem.rodriguez.jerde@woohoo.com	North Las Vegas	Nevada	6011577617170121721	1f571ae947018f280b3b25559e7d0150	JCB 16 digit	36.2015921771682798	-115.168859085090091
42638	2020-08-05 19:24:31	2020-08-05	Albion Wiza II	albion.wiza.ii@geemail.com	Milwaukee	Wisconsin	869933337971774077	1fa99bc2a9d294ee0b3de0e5240fba83	VISA 13 digit	43.0074599433775973	-88.0374607972435683
42639	2020-08-05 19:26:59	2020-08-05	Dr. Liane Larkin	dr.liane.larkin@geemail.com	Norfolk	Virginia	6011296179335037946	d9aa8889e311d2c4cf7bb4215a6626e5	Diners Club / Carte Blanche	36.9859564647562848	-76.2177840456370319
42640	2020-08-05 19:35:32	2020-08-05	Clotilde Bednar	clotilde.bednar@woohoo.com	San Francisco	California	675919150169266	19efd7a9ee7c98e433af60cc3b81d74a	VISA 13 digit	37.7847771642675809	-122.476633670478932
42641	2020-08-05 19:37:48	2020-08-05	Mrs. Jerrica Schultz PhD	mrs.jerrica.schultz.phd@warmmail.com	Miami Gardens	Florida	3730787314717972	fd074602eef7a00276ad784fa4b28f6c	Voyager	25.9591039043791589	-80.1757347141172687
42642	2020-08-05 19:43:00	2020-08-05	Daryn Buckridge	daryn.buckridge@geemail.com	Baltimore	Maryland	4790749789430820	f446e4a56fbac3b1213efbaafa93bbac	JCB 16 digit	39.3826870417222352	-76.516357303412633
42643	2020-08-05 19:49:51	2020-08-05	Floy Okuneva	floy.okuneva@geemail.com	New York	New York	4129044420435	2faac1d6aecf40191475ccdb4294eac1	VISA 16 digit	40.6493067692257455	-73.8703572688054209
42644	2020-08-05 20:04:19	2020-08-05	German Lindgren	german.lindgren@geemail.com	Detroit	Michigan	3337207797813091909	bec98c5f0faa7dce2233a028daabceda	JCB 16 digit	42.4083439730498952	-83.0532113772004834
42645	2020-08-05 20:09:22	2020-08-05	Jessie Mraz	jessie.mraz@geemail.com	Omaha	Nebraska	3112133177220653600	ab07abe6654399b5e950e214f7d825da	Voyager	41.2494194340571809	-95.9749631005920492
42646	2020-08-05 20:21:42	2020-08-05	Mr. Tracey Stehr	mr.tracey.stehr@geemail.com	Los Angeles	California	180048175266005002	09f4ed82f190fe8be9ac6f3369ec3aee	Discover	34.0576189965806861	-118.315558991627015
42647	2020-08-05 20:27:32	2020-08-05	Carolynn Schaden	carolynn.schaden@geemail.com	Lincoln	Nebraska	4803351356930764	29aa0a2c947c5ff69dc3c20d3b76e799	Diners Club / Carte Blanche	40.8106937996596102	-96.5866338587060653
42648	2020-08-05 20:30:55	2020-08-05	Bird Kunde	bird.kunde@geemail.com	Las Vegas	Nevada	3088417552701732569	dc5ee0925bf57cf86db04343bf411802	American Express	36.285713585522771	-115.349369952708855
42649	2020-08-05 20:39:35	2020-08-05	Axel Doyle DVM	axel.doyle.dvm@geemail.com	Louisville	Kentucky	54136970916670731	e7d0a4c5dcdf4c14369a01cd1d9d35c5	Discover	38.210852487794682	-85.6701701135911122
42650	2020-08-05 20:39:43	2020-08-05	Montgomery Jast-Schulist	montgomery.jast.schulist@geemail.com	Fort Worth	Texas	55667094508550032	23b9746148c218a24fe6b88cf95a91b6	Diners Club / Carte Blanche	32.8516240685302776	-97.3638791114378677
42651	2020-08-05 20:40:51	2020-08-05	Magdalene Jakubowski	magdalene.jakubowski@geemail.com	Green Bay	Wisconsin	869910572870997166	7f3b760b7a68363c294097c26427423c	Diners Club / Carte Blanche	44.5824389707360424	-87.9852511833243085
42652	2020-08-05 20:56:55	2020-08-05	Orlo Smith	orlo.smith@warmmail.com	Portland	Oregon	3015779890523008	d6c9b2a12f804696b411bc37e9f2d86e	Voyager	45.5246156198326517	-122.612094133347284
42653	2020-08-05 20:58:42	2020-08-05	Cristopher Nolan	cristopher.nolan@geemail.com	Berkeley	California	501868366316849	322e211a039dfaf9ffee2905932903f8	VISA 16 digit	37.8729490373322264	-122.257771539574307
42654	2020-08-05 21:05:12	2020-08-05	Merwin Leuschke	merwin.leuschke@geemail.com	San Antonio	Texas	3465129916609851	402a70a612ad744a0ab704f3de215770	JCB 16 digit	29.5596482156381022	-98.5276994229595999
42655	2020-08-05 21:05:28	2020-08-05	Cris Bailey III	cris.bailey.iii@geemail.com	Chicago	Illinois	3088441928116178822	aceb8044c0e6faf23d031c0e1dded93c	Mastercard	41.7379379141446236	-87.661254340552901
42656	2020-08-05 21:08:28	2020-08-05	Berenice Huels	berenice.huels@woohoo.com	Phoenix	Arizona	6011779557258421120	f12534751d390c31c505fb2e1ba1e626	JCB 16 digit	33.556662807048113	-112.138237464514006
42657	2020-08-05 21:26:55	2020-08-05	Britton Schoen	britton.schoen@geemail.com	San Diego	California	52349175378541528	836bda1762a09e81b51ded75a5d4eaf5	Discover	32.884291854414343	-117.113856512205686
42658	2020-08-05 21:32:47	2020-08-05	Aryanna Kassulke	aryanna.kassulke@geemail.com	Los Angeles	California	3337345067206926050	1f9538f559e61ada2e9798525e590ecd	Voyager	34.0935479108110044	-118.378685599192224
42659	2020-08-05 21:41:58	2020-08-05	Furman Ernser	furman.ernser@geemail.com	Wichita	Kansas	4094274538041250	068379b7a1887adaa028fe2935a5100b	JCB 16 digit	37.6517946002416295	-97.2753503027573174
42660	2020-08-05 21:53:16	2020-08-05	Clydie Runte	clydie.runte@geemail.com	San Francisco	California	4814896590647	fe17e20df00f6761ee6e238087559076	VISA 13 digit	37.8027808408620913	-122.42273715566364
42661	2020-08-05 21:56:12	2020-08-05	Kerrie Braun	kerrie.braun@geemail.com	Chicago	Illinois	210091956544514386	d408cc83f98500b2ce846967f0780136	VISA 16 digit	41.8488025697249952	-87.6309180598270103
42662	2020-08-05 22:04:07	2020-08-05	Lavar Emmerich	lavar.emmerich@woohoo.com	Birmingham	Alabama	4694613824810494	494d13403078a79288b0f6f8c79bc107	Discover	33.5711670533545288	-86.7617869881689643
42663	2020-08-05 22:11:27	2020-08-05	Treasure Thiel MD	treasure.thiel.md@woohoo.com	West Covina	California	3088728868635115554	a5a7343beb27f39140b0d2eb3532bdc6	JCB 16 digit	34.0217196734730152	-117.876364723320677
42664	2020-08-05 22:12:40	2020-08-05	Gail Runte DDS	gail.runte.dds@geemail.com	Phoenix	Arizona	4036867599728599	a22f633186da825c97339114f74fec9c	JCB 16 digit	33.5176598532523968	-112.057714050349233
42665	2020-08-05 22:13:46	2020-08-05	Jalen Bednar	jalen.bednar@geemail.com	Houston	Texas	6011298351852917713	168e055386697598ff8a5bb432544563	Mastercard	29.8854870174158371	-95.4888422831907917
42666	2020-08-05 22:14:51	2020-08-05	Adelle Kuhic	adelle.kuhic@woohoo.com	San Francisco	California	3337028887236719298	085c66d7de769ec2b0a08f8ff6b82dec	American Express	37.7578891899397249	-122.423287267224637
42667	2020-08-05 22:17:51	2020-08-05	Corean Jerde DVM	corean.jerde.dvm@geemail.com	San Francisco	California	3045433546840248	9400ee1b6e9f32dd1c09336f49ad2088	Maestro	37.7723168190646064	-122.420128945072463
42668	2020-08-05 22:21:36	2020-08-05	Britt O'Conner	britt.o'conner@geemail.com	Scottsdale	Arizona	3528653867195904505	79cdf785359bf713e4ec4e34c34047e4	Maestro	33.7359620903741586	-111.942573005749281
42669	2020-08-05 22:35:47	2020-08-05	Darla Roberts	darla.roberts@woohoo.com	New York	New York	4288821059211294	4ab55670492cf15730192c3e921bc27e	Voyager	40.6348506296742684	-74.0145513793814871
42670	2020-08-05 22:37:19	2020-08-05	Dr. Deonta Terry DDS	dr.deonta.terry.dds@geemail.com	New York	New York	4034160792211197	45be05eaeb1a3449a8eeffd2be748758	Diners Club / Carte Blanche	40.7129457564316652	-73.9778092718113243
42671	2020-08-05 22:58:41	2020-08-05	Luverne Daugherty	luverne.daugherty@geemail.com	Nashville	Tennessee	3058956161581884	3c02f3aba8585eeca6d76decfef62cae	JCB 16 digit	36.2389762843616268	-86.7786123494058756
42672	2020-08-05 23:02:38	2020-08-05	Dr. Darron Greenholt	dr.darron.greenholt@geemail.com	San Francisco	California	3158495824531801517	bde9f3a7b25c0077e6fe36b2935d4194	Discover	37.7467821422565635	-122.41638160473677
42673	2020-08-05 23:03:39	2020-08-05	Dr. Giovanni Herzog II	dr.giovanni.herzog.ii@geemail.com	San Antonio	Texas	6011177578174300733	f0824ed584d23e6369c2a4860d4ce903	Maestro	29.4662781587872651	-98.5081434304196364
42674	2020-08-05 23:14:14	2020-08-05	Monica Mills	monica.mills@warmmail.com	Columbus	Ohio	4957063247378202	756a0d229cbb39247246c40ae37dde78	American Express	39.9555620243351868	-82.9322907539784921
42675	2020-08-05 23:17:18	2020-08-05	Kayden Kessler	kayden.kessler@geemail.com	Las Vegas	Nevada	6011361320130691194	6b82b61b44328d25abc98309965ec30d	Voyager	36.3143556134410161	-115.209089262338722
42676	2020-08-05 23:51:25	2020-08-05	Zella Goldner	zella.goldner@geemail.com	San Francisco	California	3158846389939172289	2fce4b15d0eb83ba4ffe78e28023f3ef	JCB 16 digit	37.7717629633490262	-122.417623643526326
42677	2020-08-06 00:01:43	2020-08-06	Paisley Yost	paisley.yost@woohoo.com	Nashville	Tennessee	4343417132977770	e3a1e84b181298dbf93da612fa14bde1	American Express	36.1981818751089222	-86.7023841275274663
42678	2020-08-06 00:06:34	2020-08-06	Javier Will	javier.will@geemail.com	Houston	Texas	3714028998999739	b1fe02fc188cef8fdba4d710e8d6486b	VISA 13 digit	29.8829600625284009	-95.3872955006562222
42679	2020-08-06 00:09:23	2020-08-06	Ms. Amanda Howell DDS	ms.amanda.howell.dds@geemail.com	Cleveland	Ohio	4169639182674277	284397b0b1913670e7287d5bece7e5c2	Maestro	41.5358663421906513	-81.6029343552660151
42680	2020-08-06 00:10:52	2020-08-06	Erling Cartwright	erling.cartwright@geemail.com	Chicago	Illinois	869913573455223892	468cb67c081ef9fc63952b6108eaa9f1	Voyager	41.8929726175799999	-87.604314117136596
42681	2020-08-06 00:22:43	2020-08-06	Ferris Herman-Watsica	ferris.herman.watsica@geemail.com	Saint Paul	Minnesota	4826317958677379	52ff13e461ee49dc400446569aea6bf0	Maestro	45.0248074294008305	-93.1274960343990443
42682	2020-08-06 00:34:07	2020-08-06	Paulina Ziemann	paulina.ziemann@warmmail.com	Chicago	Illinois	51375202022300494	0df757c1ba6857981449b5391a3fd868	Maestro	41.745822819212826	-87.6730950294557942
42683	2020-08-06 00:42:51	2020-08-06	Danial Ledner	danial.ledner@woohoo.com	San Francisco	California	3158849335551059228	8130487a896ab9e142eecf4763dea6ad	Mastercard	37.7795683230783155	-122.454234808251854
42684	2020-08-06 00:43:34	2020-08-06	Catrina Feeney	catrina.feeney@geemail.com	Santa Clara	California	630497175987722	86485916ccb44c81f19950f3603079ed	Diners Club / Carte Blanche	37.3809824983406855	-121.977041603112227
42685	2020-08-06 00:46:23	2020-08-06	Tamera Little	tamera.little@warmmail.com	San Antonio	Texas	54272553362816018	fa140a4bbc206846d33a325c678bd0de	Diners Club / Carte Blanche	29.5132602414652716	-98.5040277726318578
42686	2020-08-06 00:54:25	2020-08-06	Dr. Grover Rippin	dr.grover.rippin@geemail.com	Moreno Valley	California	4288093529967711	abce6a02be4fb7460d05e1763c94d11c	Diners Club / Carte Blanche	33.8817493718575662	-117.209831542798128
42687	2020-08-06 01:12:10	2020-08-06	Barbie Mayert	barbie.mayert@geemail.com	New York	New York	54683896642324300	90d9ab89ee88b4a1ce17484058aed2a7	VISA 16 digit	40.7550784516837439	-73.9662745800230681
42688	2020-08-06 01:13:05	2020-08-06	Colvin Bosco	colvin.bosco@geemail.com	Charlotte	North Carolina	3056279190855944	b47f5a3531fc20d81c3a33e01ca2f45f	JCB 16 digit	35.1628354183185863	-80.8813331464715333
42689	2020-08-06 01:15:30	2020-08-06	Venessa Johns	venessa.johns@woohoo.com	Austin	Texas	869923163212560063	463fedd1373c314928378b79c02da745	JCB 16 digit	30.3435553146187189	-97.7693553291499597
42690	2020-08-06 01:15:39	2020-08-06	Irving Halvorson	irving.halvorson@geemail.com	West Valley City	Utah	52586228198042961	8da2da3bda8050d3dc476f7afa5cb947	JCB 16 digit	40.7797427389528551	-112.013398077407103
42691	2020-08-06 01:16:46	2020-08-06	Aloysius Lind	aloysius.lind@geemail.com	Meridian	Idaho	4059256274906641	290281e2ea5de13c2f2e53068239883c	American Express	43.534538255772361	-116.451625864667449
42692	2020-08-06 01:18:17	2020-08-06	Shelby Pagac MD	shelby.pagac.md@woohoo.com	Boston	Massachusetts	4105055100249	44ef4ecdb8acc4bd8dbd87b4eaac16a2	Diners Club / Carte Blanche	42.4249425302892931	-70.9337539530310863
42693	2020-08-06 01:18:28	2020-08-06	Adolphus Upton IV	adolphus.upton.iv@geemail.com	Arvada	Colorado	4805947214534	366a7db0bc01b768dc3e6103f10f04a4	VISA 16 digit	39.9221487496688994	-105.146599090329559
42694	2020-08-06 01:19:08	2020-08-06	Mr. Moody Skiles	mr.moody.skiles@geemail.com	San Francisco	California	53595256603809186	c8403147aaa7ad7b0fd6014240422133	Mastercard	37.7454528127928342	-122.448657865310693
42695	2020-08-06 01:24:29	2020-08-06	Shannan Bayer	shannan.bayer@geemail.com	New York	New York	6011756055835448929	3be315b4dc248f6f854925531cdf1c65	VISA 13 digit	40.6850018076356506	-73.8911177382234428
42696	2020-08-06 01:34:15	2020-08-06	Phillis Bins	phillis.bins@warmmail.com	Seattle	Washington	4511504703519	cc7120318aef9d45919c414b28692889	Maestro	47.7071109031718237	-122.367055835753305
42697	2020-08-06 01:38:36	2020-08-06	Ms. Madelene Friesen	ms.madelene.friesen@woohoo.com	Fort Worth	Texas	3088076242807119000	7c4dbb4dfa21d4ce10fb917f26b2928c	JCB 16 digit	32.7860059717260341	-97.4035759344518226
42698	2020-08-06 01:40:14	2020-08-06	Cheryll Cartwright DDS	cheryll.cartwright.dds@geemail.com	Los Angeles	California	6011732617286742404	80d85b44b948ad783a2fbcb6b0fd02df	Mastercard	34.0507330906443286	-118.411896588792274
42699	2020-08-06 01:43:31	2020-08-06	Natalee Johnson	natalee.johnson@geemail.com	New York	New York	4025588909194404	c4d0e737e75a9b7a99b3ef393e611a58	Mastercard	40.6095627968888735	-73.9458407923009275
42700	2020-08-06 01:57:48	2020-08-06	Thora Ortiz	thora.ortiz@warmmail.com	Columbus	Georgia	503880185740216	8f62e8fa830f6f57c7f429d0c0bad1af	Maestro	32.6045459074478572	-84.8120050974354172
42701	2020-08-06 02:00:32	2020-08-06	Marlee Crist-Altenwerth	marlee.crist.altenwerth@geemail.com	Sugar Land	Texas	4598818395684072	46251d96d6b67c694d20bfa6874c1a5e	VISA 16 digit	29.6221843289263553	-95.6603459549609596
42702	2020-08-06 02:03:04	2020-08-06	Loyd Dach-Bartoletti	loyd.dach.bartoletti@geemail.com	Norfolk	Virginia	4114387340250004	348997178326e3167b32298204d6d679	JCB 16 digit	36.9995403143130233	-76.3412383785009467
42703	2020-08-06 02:14:32	2020-08-06	Tristian Torp	tristian.torp@geemail.com	New York	New York	55247958769949019	abc782d39cd3d082f7091e9a38673ead	VISA 13 digit	40.717140136960893	-73.9580467365577761
42704	2020-08-06 02:20:23	2020-08-06	Salina Schuppe	salina.schuppe@geemail.com	Houston	Texas	55369001490692897	3a0c3458f50b2ab08ec1c199c49c1653	Voyager	29.7742413405407227	-95.3631459047567063
42705	2020-08-06 02:20:57	2020-08-06	Ashely Quitzon	ashely.quitzon@geemail.com	San Jose	California	3158023988121607344	74366fb859786bc5bf3f7605c357706d	JCB 16 digit	37.307962480216105	-121.798753586386894
42706	2020-08-06 02:26:12	2020-08-06	Burt DuBuque III	burt.dubuque.iii@geemail.com	New York	New York	3768367133387151	a12e11aaffccd004f6a5cfee2345e2bc	JCB 16 digit	40.6663089474420971	-73.9825106580637311
42707	2020-08-06 02:26:24	2020-08-06	Tavares Cremin	tavares.cremin@geemail.com	San Francisco	California	3474776236562332	f5860c834d77245723b7e84d9ab01c01	Mastercard	37.7343905459708751	-122.4088804228263
42708	2020-08-06 02:27:03	2020-08-06	Eden Herzog DVM	eden.herzog.dvm@geemail.com	Honolulu	Hawaii	4696003132698	0dfa4a61ef50539754c5cd1e4c6b66b0	JCB 16 digit	21.3414549202874326	-157.836236466208845
42709	2020-08-06 02:30:14	2020-08-06	Devon Fahey-Predovic	devon.fahey.predovic@geemail.com	Nashville	Tennessee	53217557200637286	4e1946442baf3d8e55f9c5bed5e0023d	JCB 16 digit	36.1430808936368635	-86.7188193128351088
42710	2020-08-06 02:35:42	2020-08-06	Mal Konopelski	mal.konopelski@woohoo.com	New York	New York	6011483216995629407	61ae9ead7782c5f16b1dcef63e4e4a36	JCB 15 digit	40.5653226713407804	-74.0152359951183172
42711	2020-08-06 02:47:43	2020-08-06	Illya Ryan DDS	illya.ryan.dds@geemail.com	El Monte	California	4825514142756546	699ddc9c772fd6b2d5b0d9ee6f06d7a0	Discover	33.995829129005223	-118.110657245971638
42712	2020-08-06 02:49:01	2020-08-06	Dayana Schinner	dayana.schinner@warmmail.com	San Jose	California	3055019818631348	1380e81b7be12cfd1b39c53aea93c4a5	Diners Club / Carte Blanche	37.2064194184083519	-121.733113306410232
42713	2020-08-06 02:49:39	2020-08-06	Dr. Sharlene Gottlieb DDS	dr.sharlene.gottlieb.dds@geemail.com	Vista	California	3096466694162312554	b0bcb0a01d14340bc2af621896556fcf	VISA 16 digit	33.1984728535618672	-117.158857327659064
42714	2020-08-06 02:55:52	2020-08-06	Kerry Monahan-O'Hara	kerry.monahan.o'hara@geemail.com	Berkeley	California	6011432426183066799	672de99ddf33f234ba58f8cc59f51a7a	VISA 13 digit	37.8763446488785007	-122.265625506725542
42715	2020-08-06 03:04:39	2020-08-06	Hasan Schuppe	hasan.schuppe@geemail.com	San Francisco	California	4888098493851522	6a1a81a3995756ef8aa0e3a9f80bb500	Maestro	37.7965476453065179	-122.442829986641584
42716	2020-08-06 03:06:33	2020-08-06	Kathie Langosh-Little	kathie.langosh.little@woohoo.com	New Orleans	Louisiana	52687765886833241	c177026b49fe3f43a1d635ff487f2647	Discover	30.0656857051901518	-89.9724994677845444
42717	2020-08-06 03:12:55	2020-08-06	Dr. Westin Haley DVM	dr.westin.haley.dvm@geemail.com	Pearland	Texas	869976177942758785	c0e66ab044141bc86147cbf30796ccf1	American Express	29.5301764280341565	-95.3884322185389664
42718	2020-08-06 03:15:17	2020-08-06	Mrs. Gwyn Mills MD	mrs.gwyn.mills.md@geemail.com	New York	New York	210063699676504825	13568e1d0da854aa97bf94319df7a1e9	JCB 15 digit	40.6736486362982532	-73.9557780481770664
42719	2020-08-06 03:27:49	2020-08-06	Ms. Luanne Rohan MD	ms.luanne.rohan.md@geemail.com	San Francisco	California	3528004200875324784	c57ef0839a40d6ab65a2003fa8de4397	Diners Club / Carte Blanche	37.7424445568514315	-122.460360787536715
42720	2020-08-06 03:33:25	2020-08-06	Ms. Sherron Kautzer	ms.sherron.kautzer@geemail.com	New York	New York	3422352745864412	d7248d110390941ab94eb64d42d184d7	VISA 16 digit	40.602372413570059	-73.8654373722512219
42721	2020-08-06 03:33:55	2020-08-06	Kaiya Krajcik	kaiya.krajcik@woohoo.com	Jersey City	New Jersey	503852113910286	400df2631cfe5fec849129954993f2de	Discover	40.7704695914346686	-74.0273601754058177
42722	2020-08-06 03:35:51	2020-08-06	Rosario Boehm MD	rosario.boehm.md@geemail.com	New York	New York	4928913736880777	f86e2a08b8d6a8b98e410ea66d40df84	VISA 13 digit	40.5652740633804356	-74.0289821044437559
42723	2020-08-06 03:38:01	2020-08-06	Evelynn Prosacco-Mraz	evelynn.prosacco.mraz@geemail.com	Lexington	Kentucky	55297724260291627	b8bed07e8bf73aeb3241a0957aded14e	JCB 15 digit	37.9560997866902525	-84.3687044034145686
42724	2020-08-06 03:42:25	2020-08-06	Hunt Schinner	hunt.schinner@geemail.com	Pasadena	California	3007579796658363	8db76e549705ac417eea2c9b3946ff8d	Maestro	34.2331814128294596	-118.204050400741778
42725	2020-08-06 03:42:43	2020-08-06	Mr. Reinhold Trantow DVM	mr.reinhold.trantow.dvm@woohoo.com	Springfield	Massachusetts	4985164705910787	d095648176d32c2a1f39e99fac75e496	Discover	42.1604581377673853	-72.5425284818839344
42726	2020-08-06 03:47:05	2020-08-06	Garrison Zemlak-Tromp	garrison.zemlak.tromp@geemail.com	Bakersfield	California	55948565542579393	895b36ec2830a8d392924c977656a706	Maestro	35.3549915562558894	-119.006096481791886
42727	2020-08-06 03:47:43	2020-08-06	Shannan Champlin-Kohler	shannan.champlin.kohler@warmmail.com	Richardson	Texas	4192291626914	a5d2d01523c09aaf18ef27398c597359	VISA 16 digit	32.9959748633440526	-96.7166597174242213
42728	2020-08-06 04:01:46	2020-08-06	Makayla Schroeder	makayla.schroeder@warmmail.com	Detroit	Michigan	3337082009355040207	0df488c8fb0d31ef8a008be150ab9e12	Mastercard	42.3188248807489913	-83.1186780414663247
42729	2020-08-06 04:05:28	2020-08-06	Ms. Katelyn Bergnaum	ms.katelyn.bergnaum@geemail.com	Las Cruces	New Mexico	180042702490059004	47d43441e2bca676f7370dc032569664	JCB 16 digit	32.3417816833626475	-106.757461293146761
42730	2020-08-06 04:09:11	2020-08-06	Mrs. Zillah Robel MD	mrs.zillah.robel.md@warmmail.com	Washington	District of Columbia	6011181872121485786	423d8d9e266f38535435c663151808e3	Diners Club / Carte Blanche	38.9850287857264277	-77.0413478279233033
42731	2020-08-06 04:12:37	2020-08-06	Glenn McDermott-Gibson	glenn.mcdermott.gibson@geemail.com	Moreno Valley	California	3088923170813406241	ae7110808acd7bf470901d7159c5647a	VISA 16 digit	34.0090492770068309	-117.25694890380538
42732	2020-08-06 04:14:47	2020-08-06	Sylvia Lynch DVM	sylvia.lynch.dvm@woohoo.com	Phoenix	Arizona	51196784095884147	f62f84e8923f1054401de034e48c6f45	VISA 13 digit	33.541702667756752	-112.133885310303796
42733	2020-08-06 04:26:11	2020-08-06	Marvin Cruickshank	marvin.cruickshank@geemail.com	New York	New York	4041997990843045	8f289e62e9af7cc9ef8584ad356dbe43	JCB 16 digit	40.7224727132581137	-73.8580894681055042
42734	2020-08-06 04:28:40	2020-08-06	Tilda Marvin-Bode	tilda.marvin.bode@warmmail.com	Corpus Christi	Texas	210093245410665557	1418feca9f99befa8c29fa4f7c3a9658	Maestro	27.8285729659192285	-97.1626024118453273
42735	2020-08-06 04:29:09	2020-08-06	Michelina Bode	michelina.bode@geemail.com	Seattle	Washington	4683678500219	b47ddfc3d66dac94cbd58c5c4218a5ee	Maestro	47.68244526106119	-122.355036233683677
42736	2020-08-06 04:29:48	2020-08-06	Clyde Hermann	clyde.hermann@geemail.com	San Francisco	California	52200751879158554	484ba9c7da7a5acff8e5fbd1924c3f6b	Mastercard	37.7900728959785823	-122.433714321231534
42737	2020-08-06 04:35:29	2020-08-06	Hayden Hettinger	hayden.hettinger@woohoo.com	Louisville	Kentucky	4753157884867596	c656f871e75b2ad300caddfff7e6449f	JCB 16 digit	38.0856827715780568	-85.6518889697339461
42738	2020-08-06 04:43:38	2020-08-06	Seldon Schamberger	seldon.schamberger@warmmail.com	New York	New York	4655674453729188	58a361c627521af7b5be33f7226aaf4b	Voyager	40.6254601004291303	-73.8707639047305946
42739	2020-08-06 04:47:11	2020-08-06	Wayne Volkman	wayne.volkman@warmmail.com	Wichita	Kansas	3024621783963027	b66d9c44d8a3022aa196884cc32f304f	Voyager	37.7117489649791295	-97.29035225168019
42740	2020-08-06 04:50:40	2020-08-06	Weaver Kohler	weaver.kohler@geemail.com	New York	New York	3158593249509710733	75d8491c4ace0b7669cfb12451fb7495	JCB 16 digit	40.6785453161448203	-74.0344400239072655
42741	2020-08-06 04:53:33	2020-08-06	Dr. Darrian Marvin MD	dr.darrian.marvin.md@geemail.com	Austin	Texas	4691527659656	d16ea6fd50c7f6b30c1632f0cbddee59	VISA 16 digit	30.2513391300696881	-97.7910454302333392
42742	2020-08-06 04:58:35	2020-08-06	Evaline Weimann	evaline.weimann@woohoo.com	Modesto	California	3096397722153234992	63f96895b8c3cf73ba37c57671b86837	JCB 16 digit	37.6965803779196023	-120.967324205927554
42743	2020-08-06 04:59:52	2020-08-06	Landyn Streich	landyn.streich@woohoo.com	San Francisco	California	3096714727019550768	2cf46d61ee2003393a8cc99f83078333	American Express	37.8189474111453237	-122.456329198766284
42744	2020-08-06 05:03:33	2020-08-06	Dr. Shyheim Hoppe Jr.	dr.shyheim.hoppe.jr.@geemail.com	Lansing	Michigan	060412057425378	269a2bbff2ddcc14763f739a51b8fa63	Mastercard	42.6920463409118369	-84.5927965460467988
42745	2020-08-06 05:13:39	2020-08-06	Florance Franecki	florance.franecki@warmmail.com	Murrieta	California	6011537507350832362	27265d28c7cbc36689c8edc7d40d9210	Mastercard	33.6621384186767045	-117.191885794875773
42746	2020-08-06 05:56:45	2020-08-06	Vinson Nolan	vinson.nolan@woohoo.com	New York	New York	6011526585478064806	12fcc7982a99b224bb96975d201f563f	VISA 16 digit	40.5657721523418999	-74.0326063091296618
42747	2020-08-06 06:05:30	2020-08-06	Marilynn Maggio	marilynn.maggio@geemail.com	Lakewood	Colorado	3734865493739524	f3c9b506c382678a60b4cb8f6c7ec5b3	Maestro	39.7471632702216553	-105.024253975788497
42748	2020-08-06 06:07:22	2020-08-06	Jossie Lindgren PhD	jossie.lindgren.phd@geemail.com	Riverside	California	4907221441382849	a28deaff96aa34b4a828d3c719fa6a5b	VISA 16 digit	33.9714244624547632	-117.444115935216459
42749	2020-08-06 06:44:28	2020-08-06	Janna Turner	janna.turner@geemail.com	Lansing	Michigan	561209227895787	0445bc1cf12324328b2850edef5bfe65	JCB 15 digit	42.7884566643118873	-84.6115330417763403
42750	2020-08-06 06:46:40	2020-08-06	Robley Stracke	robley.stracke@woohoo.com	Peoria	Illinois	4959137285961166	401f1ddeee6ce5ee24c04facad0cb241	JCB 16 digit	40.8335171971805408	-89.6085444867961201
42751	2020-08-06 06:47:38	2020-08-06	Tianna Dach	tianna.dach@geemail.com	Newport News	Virginia	3528933782668819225	0d0c5c255717938c4f8783ce6f196f65	VISA 16 digit	37.1450242619857178	-76.5439235370866982
42752	2020-08-06 06:51:31	2020-08-06	Gibson Jacobs I	gibson.jacobs.i@geemail.com	New York	New York	3013082163973139	4897a77a72e95f2ec391ba8c9317bf01	JCB 16 digit	40.6825417306032051	-73.902545032686362
42753	2020-08-06 06:55:09	2020-08-06	Bulah Collins	bulah.collins@geemail.com	San Francisco	California	4372988005139809	3e220716dafd3084978775066359f927	JCB 16 digit	37.7720696223743744	-122.421587890601714
42754	2020-08-06 06:55:21	2020-08-06	Tillman Hills III	tillman.hills.iii@geemail.com	Naperville	Illinois	54294242421968937	4bc7868f608690e42164402c5c857657	VISA 16 digit	41.6616526496045338	-88.0914175740331444
42755	2020-08-06 06:57:10	2020-08-06	Ozzie Senger II	ozzie.senger.ii@geemail.com	Albuquerque	New Mexico	210046230805854774	9bda4dfb82c5b97f0b097340d5eb8222	JCB 16 digit	35.1401456046983611	-106.742926290545242
42756	2020-08-06 07:03:39	2020-08-06	Jaydin Windler	jaydin.windler@geemail.com	Spokane	Washington	6011473457047844550	f632538bac8aa8a6fdd12a8401cacccf	VISA 16 digit	47.6421752376254659	-117.334967530974382
42757	2020-08-06 07:06:26	2020-08-06	Samantha Okuneva	samantha.okuneva@geemail.com	Dallas	Texas	4176403908424033	137b50bc4d671e20f94fbc033a9b5839	Diners Club / Carte Blanche	32.7502381169509178	-96.7609886518642242
42758	2020-08-06 07:06:46	2020-08-06	Maura Turner PhD	maura.turner.phd@geemail.com	New Orleans	Louisiana	210097404262684333	8a161ce995096f0d3a9efd1d4feb8180	JCB 16 digit	30.0207909262754029	-90.009319326866418
42759	2020-08-06 07:11:03	2020-08-06	Rosita Hyatt	rosita.hyatt@geemail.com	Washington	District of Columbia	4428414056176669	a4269ddc044f9160609b5dfda93dbac1	Mastercard	38.9149754910063024	-76.9285003879785592
42760	2020-08-06 07:12:51	2020-08-06	Mikeal Koch	mikeal.koch@geemail.com	Anaheim	California	869913945390488709	2ef666629c12804563311d519de6443f	Discover	33.8055916881952427	-117.685773445919523
42761	2020-08-06 07:14:05	2020-08-06	Ms. Nobie Bailey PhD	ms.nobie.bailey.phd@geemail.com	Amarillo	Texas	3088306161558581022	829775b01425e64ad507cde47e579a27	Diners Club / Carte Blanche	35.2855388572603488	-101.799137872769322
42762	2020-08-06 07:16:42	2020-08-06	Dr. Citlali Heaney	dr.citlali.heaney@geemail.com	Fontana	California	55836504845760983	733102fe60aa31c85035bc138944255d	JCB 15 digit	34.1934334828201685	-117.364379464164003
42763	2020-08-06 07:17:10	2020-08-06	Refugio Macejkovic	refugio.macejkovic@warmmail.com	Los Angeles	California	3337999033264684618	dbff7aa20fbc55e35b7fd26d3e44ebb5	Voyager	34.061726356144618	-118.430886812321091
42764	2020-08-06 07:37:45	2020-08-06	Onnie McLaughlin	onnie.mclaughlin@geemail.com	San Francisco	California	6011076014073542730	d82b01270380fd2dc0bd6cfd963887c6	American Express	37.7941086699218047	-122.452067242028377
42765	2020-08-06 07:41:20	2020-08-06	Tina Lesch	tina.lesch@geemail.com	Los Angeles	California	869914449359161778	833148e5a6e30db55cdd721291f40d6b	VISA 13 digit	33.9613227778445932	-118.449203790164731
42766	2020-08-06 07:47:42	2020-08-06	Yoel Parker	yoel.parker@geemail.com	San Francisco	California	4045062460093724	f6db55e13d7e7accd765b9640e9b15c0	Maestro	37.7760797916162261	-122.414772611939227
42767	2020-08-06 07:58:55	2020-08-06	Jeffry Kuvalis	jeffry.kuvalis@geemail.com	Tempe	Arizona	561291761673697	0b00acd50dc5723855dfc342d18cb7b5	Maestro	33.4465404038704932	-111.994504154476516
42768	2020-08-06 08:02:13	2020-08-06	Kristen Quigley	kristen.quigley@geemail.com	Hialeah	Florida	3054139950658718	23ad680640444cd9a655ed689987da93	JCB 16 digit	25.9181656308449817	-80.3962776143006863
42769	2020-08-06 08:02:33	2020-08-06	Tamisha Quigley	tamisha.quigley@geemail.com	West Covina	California	4857063878782	4071b06530136be55811c885990b460c	Mastercard	34.1372122550491284	-117.976858669060832
42770	2020-08-06 08:20:23	2020-08-06	Mrs. Quinn Gorczany DVM	mrs.quinn.gorczany.dvm@woohoo.com	San Francisco	California	52829436125075049	ca24b443b2e3074fdb3c6cb10f765942	JCB 16 digit	37.7801525378531764	-122.443865831600561
42771	2020-08-06 08:21:13	2020-08-06	Muhammad Mayert	muhammad.mayert@geemail.com	Santa Maria	California	4663297303236269	1268c69251f0e3b91b486f7a3b7f7ccd	VISA 13 digit	34.833929742320251	-120.499841553663089
42772	2020-08-06 08:22:34	2020-08-06	Isobel Ward-Leannon	isobel.ward.leannon@geemail.com	San Francisco	California	180094655879871752	132e33a389a0a88f764ef5d9a442bbd2	JCB 16 digit	37.778144619756354	-122.391487016927769
42773	2020-08-06 08:23:33	2020-08-06	Mrs. Rosena Goldner	mrs.rosena.goldner@warmmail.com	Miami	Florida	4118754084805416	e896f5abe18201e245cdcdc12cbcb328	VISA 16 digit	25.7441632567111434	-80.1723197326868871
42774	2020-08-06 08:23:58	2020-08-06	Acey Stiedemann	acey.stiedemann@woohoo.com	Houston	Texas	3088075270807008320	9c87731887315d5ef312b988369d70c4	Mastercard	29.7289263804987058	-95.3908608657322787
42775	2020-08-06 08:31:54	2020-08-06	Annabella Hoeger	annabella.hoeger@warmmail.com	New York	New York	4845654141316425	81ab200d9f317f134aca2bafd1224d42	Voyager	40.5682735174186533	-73.9215173726331471
42776	2020-08-06 08:40:59	2020-08-06	Ms. Tamera Cassin	ms.tamera.cassin@geemail.com	Lincoln	Nebraska	4940962517984252	5b3a17d12ae144cfd36b28b5009940b6	VISA 16 digit	40.7653275098670278	-96.6087726494457542
42777	2020-08-06 08:51:11	2020-08-06	Javonte Grady	javonte.grady@geemail.com	Irvine	California	4532282097242821	eaf4e10a81a28bed74d0c4ce22f9c709	VISA 16 digit	33.6578495190493783	-117.829583769013354
42778	2020-08-06 08:52:31	2020-08-06	Kadijah Kunze	kadijah.kunze@geemail.com	Los Angeles	California	3158217123942257238	195af78efa39decb489df6574934b361	Mastercard	33.9236799031827587	-118.355790825466812
42779	2020-08-06 08:55:14	2020-08-06	Mr. Glenwood Nienow	mr.glenwood.nienow@woohoo.com	Victorville	California	869927684884398140	34434521fc329d499401f248f9794b36	VISA 16 digit	34.5035815755136355	-117.253850370008877
42780	2020-08-06 08:57:50	2020-08-06	Miss Somer Koelpin	miss.somer.koelpin@warmmail.com	Vacaville	California	4928502579752332	98df76495076d41e1561a9a3070dd8ed	JCB 16 digit	38.4330310030967013	-121.978837429394204
42781	2020-08-06 09:00:59	2020-08-06	Presley Goyette	presley.goyette@geemail.com	Sandy Springs	Georgia	4764077835495	941547a5e61f35d44021e26bac239f20	VISA 16 digit	33.933931156486274	-84.3981061933644128
42782	2020-08-06 09:06:11	2020-08-06	Quinn Gutkowski	quinn.gutkowski@geemail.com	Dallas	Texas	4829564493999	bfb296494dd1a0ce6d050a98a84ed2c7	JCB 16 digit	32.8135269246336065	-96.8306628849320106
42783	2020-08-06 09:07:08	2020-08-06	Orris Effertz IV	orris.effertz.iv@geemail.com	Los Angeles	California	4664554162605	65053c29cf65ffa93d348c3163943cec	Mastercard	33.9527684226032349	-118.399910992010675
42784	2020-08-06 09:07:58	2020-08-06	Michial Heaney DDS	michial.heaney.dds@geemail.com	Oklahoma City	Oklahoma	3112641440047154730	8912c9715af143875d88d6e2de2439ea	JCB 16 digit	35.3938554455902477	-97.5913552558410942
42785	2020-08-06 09:24:04	2020-08-06	Alissa Ortiz	alissa.ortiz@woohoo.com	Philadelphia	Pennsylvania	3407018913686072	8e7c2e4874e6cb8011732539235fbf4a	Discover	40.0239527204964318	-75.0910115708962138
42786	2020-08-06 09:24:19	2020-08-06	Markell Hickle	markell.hickle@geemail.com	Huntington Beach	California	3053139557694117	654f44182af00ed6c9605ca234ef2fc2	VISA 16 digit	33.7105807719793233	-117.915155031451206
42787	2020-08-06 09:32:29	2020-08-06	Angie Schuster	angie.schuster@geemail.com	San Francisco	California	54001531397911150	bf4ed03c77e3422e4e343e7ee45add84	JCB 16 digit	37.802110407459935	-122.420626048080521
42788	2020-08-06 09:34:07	2020-08-06	Neal Douglas	neal.douglas@warmmail.com	Fresno	California	3112352004964104992	683b10f5792ae5c8212d7d106270283b	VISA 13 digit	36.7985747399613246	-119.83734591911697
42789	2020-08-06 09:44:10	2020-08-06	Marion Toy	marion.toy@woohoo.com	Austin	Texas	589335954452690	34e27cd8cb835dec169fd42d8dd5b9e6	Mastercard	30.3028662616047981	-97.7588311478734084
42790	2020-08-06 09:46:43	2020-08-06	Corey Wiegand	corey.wiegand@geemail.com	Houston	Texas	4858197163091	f8a18827bd67336fdf7bc63e2873d34e	VISA 16 digit	29.8460255819916718	-95.4432827050812591
42791	2020-08-06 09:46:49	2020-08-06	Codey Luettgen	codey.luettgen@geemail.com	Chicago	Illinois	54720393272422278	281eba3dc3b2a7166dcb2ad996248bf8	JCB 15 digit	41.8203392474748199	-87.5945844822592932
42792	2020-08-06 09:57:56	2020-08-06	Jaydon Frami MD	jaydon.frami.md@geemail.com	Aurora	Colorado	4191107488618	de68875f4f37ea5af8407f7b9b1bb966	Mastercard	39.6372738625500389	-104.761037024308749
42793	2020-08-06 10:02:02	2020-08-06	Kamari Rice-Boehm	kamari.rice.boehm@geemail.com	Miramar	Florida	676369291366404	18f003fbe3415e9758a10dafbc867b37	JCB 15 digit	25.8985437197592105	-80.2435280076686297
42794	2020-08-06 10:02:20	2020-08-06	Josefa Schowalter	josefa.schowalter@geemail.com	Chicago	Illinois	4547256791575283	03c4f79ecfb2c3c174b87e0ca957af65	JCB 16 digit	41.7617830773185972	-87.7119924898754704
42795	2020-08-06 10:20:55	2020-08-06	Ednah Larkin	ednah.larkin@geemail.com	Santa Ana	California	3158833801285504357	e131157aa208283f4305695396707236	JCB 15 digit	33.6951328366167857	-117.98178854653797
42796	2020-08-06 10:23:44	2020-08-06	Shreya Howell DVM	shreya.howell.dvm@geemail.com	Little Rock	Arkansas	3004317980635456	ae988744b0233d6d50667cad58c63f25	JCB 16 digit	34.6921592240497461	-92.3828253028787572
42797	2020-08-06 10:29:52	2020-08-06	Delinda Hagenes	delinda.hagenes@woohoo.com	Berkeley	California	51590113730608400	067078d6a3013c546a85317236c69720	Discover	37.9054367582424874	-122.29026704693139
42798	2020-08-06 10:36:12	2020-08-06	Wilfrid Purdy	wilfrid.purdy@woohoo.com	San Francisco	California	3528334477153980500	1bdb414981b64e2dc3b1a1fc698e2dc8	Discover	37.7776911880206612	-122.454386188688261
42799	2020-08-06 10:43:25	2020-08-06	Rocio Nienow	rocio.nienow@woohoo.com	Riverside	California	3489360926613425	bc810d868336995e7688762e00cc7305	American Express	33.8758977537922519	-117.350762398351719
42800	2020-08-06 10:49:44	2020-08-06	Dessie Pagac PhD	dessie.pagac.phd@geemail.com	Charlotte	North Carolina	060479849256791	1b028e452b77deb07805e18cdb7d0f97	Maestro	35.2291104376103732	-80.7992361560873746
42801	2020-08-06 10:50:54	2020-08-06	Tavaris Vandervort	tavaris.vandervort@warmmail.com	San Francisco	California	3052542919276815	ec497d61bdd92e6ce516f81f08b87164	JCB 15 digit	37.7725907533096148	-122.415992958824006
42802	2020-08-06 10:52:30	2020-08-06	Melba Waelchi	melba.waelchi@woohoo.com	Oakland	California	6011410688680741895	143ab01a10055ef370c9059cedb3b0c1	Mastercard	37.8239125871716197	-122.263749153507831
42803	2020-08-06 10:55:17	2020-08-06	Dell Champlin	dell.champlin@warmmail.com	Fullerton	California	4568507510747	4db47993928eac6043e9ca18443ecec0	JCB 16 digit	33.8507416468735798	-117.966773801550261
42804	2020-08-06 11:03:33	2020-08-06	Miss Erla Dare DVM	miss.erla.dare.dvm@warmmail.com	Riverside	California	3004303322905625	e7562dbb9976cd46031f27e493241d48	VISA 16 digit	33.8495534316118807	-117.367973811176412
42805	2020-08-06 11:07:04	2020-08-06	Konnor Prohaska-Kuhlman	konnor.prohaska.kuhlman@geemail.com	Tallahassee	Florida	4694987451689	1ab25ee804d676538885a0783371f811	Diners Club / Carte Blanche	30.5173290425002577	-84.2652421328254064
42806	2020-08-06 11:07:34	2020-08-06	Roby Kub	roby.kub@geemail.com	El Paso	Texas	180022716871797531	7642218f6b44aacc7bb665a176e78695	VISA 16 digit	31.7568784116595992	-106.413757198162386
42807	2020-08-06 11:11:40	2020-08-06	Saundra Sanford	saundra.sanford@woohoo.com	Sacramento	California	4664716725327934	0478dc7c943814e493219d4ac9599465	American Express	38.6476864058323244	-121.382921726839982
42808	2020-08-06 11:18:57	2020-08-06	Hadley Kuhic	hadley.kuhic@geemail.com	Charlotte	North Carolina	501862587581844	3a79cd1426dc4e51d6415c1df137bd3a	American Express	35.2460439224515127	-80.7505708831306634
42809	2020-08-06 11:41:57	2020-08-06	Aurelia White	aurelia.white@geemail.com	San Francisco	California	3096098687434027568	3247aec4c780026f81074006f2664707	JCB 16 digit	37.7544704919929828	-122.47083372118324
42810	2020-08-06 11:52:07	2020-08-06	Karson Cole-Wintheiser	karson.cole.wintheiser@geemail.com	Fresno	California	6011082432316823752	15b1810285790ee5339c7fd4b9ea5b24	American Express	36.8515571338929249	-119.708994911295932
42811	2020-08-06 11:55:53	2020-08-06	Mrs. Ciara Labadie DDS	mrs.ciara.labadie.dds@geemail.com	Colorado Springs	Colorado	869940614736865676	8f767eebfd2f046a9ec7fdb09e31e93e	American Express	38.9092301969464884	-104.829688166516647
42812	2020-08-06 12:17:58	2020-08-06	Tyrone Heidenreich III	tyrone.heidenreich.iii@woohoo.com	Huntsville	Alabama	210014713002661801	dd53fc7f1f3c1e4230e3117c0bbbc31e	VISA 16 digit	34.7738066136147808	-86.7098011170998291
42813	2020-08-06 12:19:00	2020-08-06	Miss Mia Parker MD	miss.mia.parker.md@geemail.com	Milwaukee	Wisconsin	3337540387269181523	349b3013d1656e328b5c4e06b0c21a57	Discover	43.1066719363529245	-88.0014887889016393
42814	2020-08-06 12:21:58	2020-08-06	Mr. Rey Murphy	mr.rey.murphy@woohoo.com	Lewisville	Texas	54045339290054740	7114e8cd9ebf79e110f4388c9d9d72c5	American Express	33.0299230581134537	-96.9951021602872885
42815	2020-08-06 12:30:07	2020-08-06	Hayley Effertz	hayley.effertz@woohoo.com	Orange	California	4468383311794114	d24ede8d47bd96da189cc123895c1b66	American Express	33.8110538864396517	-117.816888471237576
42816	2020-08-06 12:30:53	2020-08-06	Manuelita Koepp MD	manuelita.koepp.md@geemail.com	Salem	Oregon	869972641227449414	f2b679c568e5b72632806f3729369b8b	JCB 15 digit	44.8376249074738453	-122.938861989385259
42817	2020-08-06 12:41:16	2020-08-06	Dot Daugherty	dot.daugherty@woohoo.com	Phoenix	Arizona	51384815692343640	934773a0d6cea6bf61107d622e5b6fe3	Discover	33.5013913741733873	-112.083174003001687
42818	2020-08-06 12:43:23	2020-08-06	Derick Schmidt	derick.schmidt@woohoo.com	Fort Worth	Texas	55342182828399025	e31bdfb8db85c3581bb5eed1cb2fe283	JCB 16 digit	32.6931156398784353	-97.3240888472467702
42819	2020-08-06 13:00:03	2020-08-06	Wilfrid Leannon	wilfrid.leannon@geemail.com	Houston	Texas	4060613063571233	45aed1f6aa77af208eda23a83a2c5e6e	Maestro	29.7214465552087859	-95.460357607250657
42820	2020-08-06 13:01:12	2020-08-06	Miss Emilee Mann	miss.emilee.mann@warmmail.com	Winston–Salem	North Carolina	3112546616494253275	98354be312dfb131020255235313a884	Maestro	36.0110757452666732	-80.2075993210207656
42821	2020-08-06 13:07:35	2020-08-06	Sol Kozey II	sol.kozey.ii@geemail.com	Madison	Wisconsin	6011609123470629846	338d1966da40418a074bbab77baada82	Voyager	43.101342330916971	-89.4243190104957648
42822	2020-08-06 13:11:57	2020-08-06	Dr. Del Kuphal IV	dr.del.kuphal.iv@woohoo.com	Murfreesboro	Tennessee	210027925482044093	5e27bc5d085e761c774df6289f376b9d	Voyager	35.9163037156339797	-86.3599281821250884
42823	2020-08-06 13:14:11	2020-08-06	Dr. Worley Rosenbaum II	dr.worley.rosenbaum.ii@geemail.com	San Francisco	California	869946679864272379	1c21945c247279eed7ec5334b3dff464	Voyager	37.7174734629421025	-122.444708938253356
42824	2020-08-06 13:19:23	2020-08-06	Katie Luettgen	katie.luettgen@geemail.com	Mesquite	Texas	4774775843276800	2e2ca3516df22921d3d943d22ec66ca5	VISA 13 digit	32.847150124264509	-96.576927736421311
42825	2020-08-06 13:43:25	2020-08-06	Mettie Hermiston	mettie.hermiston@geemail.com	Norfolk	Virginia	4105639649185997	2b239534a234c4bb404b1eae3426be0e	VISA 16 digit	36.9002771562915299	-76.1929612547628636
42826	2020-08-06 13:53:38	2020-08-06	Benjamen Watsica	benjamen.watsica@geemail.com	Moreno Valley	California	3052312052404305	b2c1f133bc8cf017a617734f98466baf	VISA 16 digit	34.0030970825806236	-117.154055892999096
42827	2020-08-06 13:57:05	2020-08-06	Giovanny Hyatt-Lang	giovanny.hyatt.lang@geemail.com	Provo	Utah	4158620769155313	2cc951723547c812395215c840ac8e47	JCB 15 digit	40.1786781152497952	-111.659660394224531
42828	2020-08-06 13:58:00	2020-08-06	Dante Conn	dante.conn@geemail.com	Columbus	Ohio	3088666349273597019	3365a1a70054a8c9127e774137000d57	JCB 16 digit	40.0747113538950686	-82.9933689659230538
42829	2020-08-06 14:02:33	2020-08-06	Sandie Schaden	sandie.schaden@geemail.com	Indianapolis	Indiana	3158179846485768007	e063700fd0d9dbfb2ffdf153e5852e97	JCB 16 digit	39.8351582835435849	-86.2126838456574802
42830	2020-08-06 14:07:35	2020-08-06	Albertha Padberg	albertha.padberg@warmmail.com	Santa Clara	California	4991955906748	00e228626633e10bdeb59f1c254fd396	Voyager	37.280251632891968	-121.917543610278145
42831	2020-08-06 14:10:39	2020-08-06	Mr. Bennie Heller	mr.bennie.heller@geemail.com	Fresno	California	3088362477612807463	a8e16edc4562a752b571e1a8aa370bc9	VISA 13 digit	36.7410990115128442	-119.812533090041583
42832	2020-08-06 14:15:02	2020-08-06	Sandy Prosacco	sandy.prosacco@geemail.com	Murfreesboro	Tennessee	4083801280201766	38d19d1064ce4925f7ec132bc1558857	JCB 16 digit	35.7737325749479282	-86.3180936126355078
42833	2020-08-06 14:21:38	2020-08-06	Miss Socorro Schmitt	miss.socorro.schmitt@geemail.com	New York	New York	4715787232944	d916394c405ab2c37101fb617c5e0537	VISA 16 digit	40.6578079190794384	-73.8823102865263763
42834	2020-08-06 14:23:19	2020-08-06	Furman Abshire	furman.abshire@woohoo.com	North Las Vegas	Nevada	4354085634427	f8891dcbcf838a7704be1665482a4359	Discover	36.3044186482362434	-115.167687023546179
42835	2020-08-06 14:26:55	2020-08-06	Ilda Streich-Jacobi	ilda.streich.jacobi@geemail.com	Grand Rapids	Michigan	4420533958079289	351d7bde35e331e693a6279761c75599	Voyager	42.8791233795963223	-85.5685779039416587
42836	2020-08-06 14:27:29	2020-08-06	Patric Herzog-Morissette	patric.herzog.morissette@geemail.com	Atlanta	Georgia	3088087975549603537	41a7eaa59517050489c1df30aa7dca23	Mastercard	33.6976021698951769	-84.3258233083922448
42837	2020-08-06 14:32:12	2020-08-06	Winifred Nienow	winifred.nienow@geemail.com	Fairfield	California	210027292989187457	6adbf91e6ecad30c96c474dffafe85fd	Voyager	38.3157648797269914	-122.050925114192438
42838	2020-08-06 14:40:57	2020-08-06	Foch Daugherty	foch.daugherty@woohoo.com	McKinney	Texas	3761649022667588	a01df77d3e31ec6286dbd26ae96c3144	Voyager	33.2969180199913737	-96.6173263674899943
42839	2020-08-06 14:41:01	2020-08-06	Emry Cartwright	emry.cartwright@geemail.com	Aurora	Illinois	869914658727602822	5c012ccb8cd9d4b5623b2ae64ffbf8b2	Maestro	41.6999462629891937	-88.353822493639214
42840	2020-08-06 14:43:59	2020-08-06	Mr. Adalberto Upton MD	mr.adalberto.upton.md@geemail.com	Long Beach	California	3158543563051792597	61c84e8b97156de51423f6f0c28c9b50	Diners Club / Carte Blanche	33.7155872815575393	-118.106435686272746
42841	2020-08-06 14:48:12	2020-08-06	Neola Carter	neola.carter@geemail.com	San Francisco	California	3528945109006554957	b295c6d7a3f232839407c7d5740af5cf	JCB 15 digit	37.7890085639573741	-122.437325680346603
42842	2020-08-06 14:50:01	2020-08-06	Santiago Jacobson	santiago.jacobson@geemail.com	Houston	Texas	4997255972827	60c1bdc8e5a6722dbb2b40ccc732a2fa	Maestro	29.7089663102835431	-95.3022623956218382
42843	2020-08-06 14:56:41	2020-08-06	Anthoney Jones	anthoney.jones@geemail.com	Denver	Colorado	3022208641947202	0777ca26af2912dbd9234ce4cb640fe1	JCB 16 digit	39.7743395792838186	-104.931772614760703
42844	2020-08-06 15:06:24	2020-08-06	Alan Kuhlman DVM	alan.kuhlman.dvm@geemail.com	Anchorage	Alaska	210050698023515232	58dbe7c9fa4de2edbd334b8a3e421f8e	VISA 16 digit	61.1358337484050551	-149.376909559325497
42845	2020-08-06 15:08:28	2020-08-06	Albert Homenick	albert.homenick@warmmail.com	Seattle	Washington	180001651374915741	d5bcf3d9a713fa3a57ed1ac28ab05fec	Mastercard	47.5842035557068854	-122.273651119779416
42846	2020-08-06 15:10:15	2020-08-06	Maxie Kunze	maxie.kunze@warmmail.com	Mesquite	Texas	3432699511570591	31c6150189aacf58b5688df45eca3fe4	JCB 16 digit	32.7029051061995375	-96.5689747974008412
42847	2020-08-06 15:26:43	2020-08-06	Aedan Schaden	aedan.schaden@geemail.com	San Antonio	Texas	3337118429845689942	14dacef38ddfd1cc8876ec00344e75d8	JCB 15 digit	29.5211418966833499	-98.6168913324665226
42848	2020-08-06 15:29:38	2020-08-06	Lawton Bogisich	lawton.bogisich@geemail.com	Los Angeles	California	55007187150039855	4eb28af2b140e3fed66fd8d7aefb5ef5	JCB 16 digit	34.1003562484733749	-118.337088753561673
42849	2020-08-06 15:36:29	2020-08-06	Domenick Lockman IV	domenick.lockman.iv@geemail.com	Fort Worth	Texas	4846771431917719	af16c69ecaedc8e4c6e55d8e65d688b6	VISA 16 digit	32.853850466297942	-97.3029078154645788
42850	2020-08-06 15:43:37	2020-08-06	Mr. Sampson Hills Sr.	mr.sampson.hills.sr.@geemail.com	Berkeley	California	3436740508416103	f1a26006bc936ecccb4332bc1b40c14f	American Express	37.8911495893796015	-122.259071723235138
42851	2020-08-06 16:13:15	2020-08-06	Parley Crist	parley.crist@geemail.com	Milwaukee	Wisconsin	3734402870185020	e3b20bdd714ceb5c592ad071e7a301af	Voyager	43.0459024723239239	-87.9740619698639961
42852	2020-08-06 16:18:32	2020-08-06	Sybilla Hickle	sybilla.hickle@geemail.com	Torrance	California	3413431884571581	0fca0cbfc326a4f97b605c91379d22cc	Discover	33.864310574382543	-118.336170205020892
42853	2020-08-06 16:25:25	2020-08-06	Esta Paucek	esta.paucek@geemail.com	Philadelphia	Pennsylvania	3002473030044975	0194ac87cf052aa3faeaf86450505195	JCB 16 digit	40.0443066690076108	-75.1578138860307661
42854	2020-08-06 16:28:26	2020-08-06	Evelynn Schmidt MD	evelynn.schmidt.md@geemail.com	San Francisco	California	4602895876194593	3a63fe4801368af32778a0eeb442de3e	Voyager	37.7645459751401162	-122.431966406008414
42855	2020-08-06 16:33:09	2020-08-06	Margie Fahey MD	margie.fahey.md@geemail.com	Albuquerque	New Mexico	3428728427520741	1e39e9d89390e28b6f21ffadbf7031a3	Discover	35.0458778856456306	-106.706423118903871
42856	2020-08-06 16:42:39	2020-08-06	Jean Hammes-Ritchie	jean.hammes.ritchie@geemail.com	Clearwater	Florida	3096728749955446540	9ae56a365978a8660715dcf068bc62a1	American Express	27.9977927310518915	-82.8360067682605177
42857	2020-08-06 16:43:47	2020-08-06	Ms. Olympia Hudson DVM	ms.olympia.hudson.dvm@geemail.com	Boston	Massachusetts	502032170921541	1ba4ce0f8794e09e1137e664158143f4	VISA 16 digit	42.3468725150618681	-70.978003888665512
42858	2020-08-06 16:56:44	2020-08-06	Dr. Loreen Weissnat	dr.loreen.weissnat@geemail.com	Chicago	Illinois	869943968667886573	11334b1753024656bb996f3ebc7af32e	Discover	41.8592179656796191	-87.6492091701395708
42859	2020-08-06 17:03:29	2020-08-06	Raoul Fritsch	raoul.fritsch@geemail.com	Warren	Michigan	3112574233528579090	f4f2bf2b5b703659569311afee0538d8	JCB 16 digit	42.3971873538564878	-82.9275009457953303
42860	2020-08-06 17:06:32	2020-08-06	Olof Ondricka V	olof.ondricka.v@geemail.com	Charlotte	North Carolina	869954957106794536	8ad2cb572de24352d6d36ed4def458e5	JCB 16 digit	35.1575776358854029	-80.7801961746476564
42861	2020-08-06 17:07:52	2020-08-06	Valentine Shanahan	valentine.shanahan@warmmail.com	New York	New York	4539332543687229	f7f4258ed3c28f0b603777b3f0b592fb	Maestro	40.6419629615023723	-73.9931697551522376
42862	2020-08-06 17:09:24	2020-08-06	Dr. Jagger Padberg	dr.jagger.padberg@woohoo.com	San Francisco	California	869925042992608086	ba0710196085016a6fa5ca4633368c59	VISA 13 digit	37.7883528652066403	-122.449549559003955
42863	2020-08-06 17:16:54	2020-08-06	Lillian Ryan	lillian.ryan@geemail.com	Renton	Washington	869901535875885877	dda9b2030a86494e8a13e13b90c5b0fc	VISA 16 digit	47.4618941815629611	-122.186841630384322
42864	2020-08-06 17:32:55	2020-08-06	Mr. Webb Flatley	mr.webb.flatley@warmmail.com	Riverside	California	6011918557295122519	98789fda0719087054c1b72c30413b85	VISA 16 digit	33.8960591177403927	-117.451043781029796
42865	2020-08-06 17:37:48	2020-08-06	Dr. Camron Kautzer	dr.camron.kautzer@woohoo.com	Fayetteville	North Carolina	3158463071971231643	9869e21f1979eed19302a215a104686b	VISA 16 digit	35.0395838401999313	-78.9911461091265039
42866	2020-08-06 17:41:32	2020-08-06	Dr. Lorelei Paucek	dr.lorelei.paucek@warmmail.com	New York	New York	3056262383851466	855685538b055a28122df3c55d791ba7	Mastercard	40.6362794346399596	-73.8836628884904059
42867	2020-08-06 18:08:15	2020-08-06	Miss Leonore Greenholt DVM	miss.leonore.greenholt.dvm@geemail.com	North Las Vegas	Nevada	4042772495007605	7a02a303720408bd35c2de750a3861d6	JCB 16 digit	36.2807998996384455	-115.188773704575013
42868	2020-08-06 18:15:04	2020-08-06	Nigel Nienow-Kreiger	nigel.nienow.kreiger@geemail.com	Mesa	Arizona	4852581385998	bec7fd1dd249295b32c26e969e439313	VISA 13 digit	33.4360502779629059	-111.795298027189077
42869	2020-08-06 18:17:56	2020-08-06	Deven Becker Jr.	deven.becker.jr.@woohoo.com	Chicago	Illinois	3088744926508667646	730a6d08d78139fb602d580a31eb6334	VISA 16 digit	41.9261511811357011	-87.7350108138315363
42870	2020-08-06 18:24:23	2020-08-06	Coen Runolfsdottir-Bode	coen.runolfsdottir.bode@geemail.com	San Francisco	California	6011498541564901967	00cd77240fc225d099f1d157778c62a8	Voyager	37.763340422893819	-122.432904753346932
42871	2020-08-06 18:26:01	2020-08-06	Ms. Rosanne Von	ms.rosanne.von@warmmail.com	Louisville	Kentucky	3158819738997545195	0256cc067007d8d98d9682d38b2499a4	JCB 15 digit	38.1013075273387116	-85.6473995193909872
42872	2020-08-06 18:35:18	2020-08-06	Larissa Labadie-Watsica	larissa.labadie.watsica@geemail.com	Houston	Texas	4554105131337393	af46425b55be01e5767e84bfaa688bde	JCB 16 digit	29.6935123807363226	-95.408914339450746
42873	2020-08-06 18:38:37	2020-08-06	Mrs. Beryl Moen	mrs.beryl.moen@geemail.com	Chicago	Illinois	52801094947096164	d8fff50c24b8fd1a29fed984b2ecd2ae	Discover	41.9120926546234642	-87.7272518693499279
42874	2020-08-06 18:44:31	2020-08-06	Isadora Barton	isadora.barton@geemail.com	Mobile	Alabama	869941531109915160	13ac8e93517840cbe702f21b35a42784	JCB 15 digit	30.6757018643073707	-88.1285892955631027
42875	2020-08-06 18:45:21	2020-08-06	Isom Gottlieb	isom.gottlieb@geemail.com	Saint Paul	Minnesota	3088079594698637756	1a4fb578bd22700a81b8c25905ce9d15	JCB 16 digit	45.0024948758479226	-93.0627759943515116
42876	2020-08-06 18:46:13	2020-08-06	Ilo Kuhic PhD	ilo.kuhic.phd@geemail.com	Cleveland	Ohio	3440475477050724	772bef044d6a96e63b40351b635d9d56	VISA 13 digit	41.3833265895340574	-81.7313234080798878
42877	2020-08-06 18:53:08	2020-08-06	Mr. Dejuan Upton	mr.dejuan.upton@geemail.com	Arlington	Texas	3112564914819797598	345eaa7b9b1a8bbcae3b05a9857f397d	Maestro	32.7026201682414808	-97.2209503218557671
42878	2020-08-06 18:56:07	2020-08-06	Taylor Larson	taylor.larson@warmmail.com	Fayetteville	North Carolina	6011992614302359094	f0c647fb9cc211f1be6778fc5a39864a	JCB 15 digit	35.0551886553663721	-78.9636756108272806
42879	2020-08-06 19:02:23	2020-08-06	Alexzander O'Hara-Muller	alexzander.o'hara.muller@geemail.com	San Diego	California	4320458232933	4f3ae5cfb51e6bc7f4d3b9185ca615a1	American Express	32.730159662111852	-117.046163590848451
42880	2020-08-06 19:03:52	2020-08-06	Miss Allie Labadie	miss.allie.labadie@geemail.com	Los Angeles	California	3528775810663609837	44e0ea2290c1f8cd67b543cfa2cbbaee	JCB 16 digit	34.1068687196221205	-118.323504620370642
42881	2020-08-06 19:07:22	2020-08-06	Verlin Reinger MD	verlin.reinger.md@geemail.com	Oakland	California	4214584399513089	770a959be7839a19d0ac8d1d5924b7c4	Diners Club / Carte Blanche	37.8194734929245087	-122.292598839320348
42882	2020-08-06 19:16:41	2020-08-06	Tex Jacobson	tex.jacobson@geemail.com	Minneapolis	Minnesota	3158038352033005951	04483cc5ce104c296c14df62de0c9e1a	Diners Club / Carte Blanche	45.0547146271068542	-93.3086130986262106
42883	2020-08-06 19:17:08	2020-08-06	Dillon Cruickshank-Jones	dillon.cruickshank.jones@geemail.com	New York	New York	501815446281600	b07a0e7b4fb95c9fe83165b30e2e09fc	JCB 16 digit	40.7088054303768985	-73.9702975459758107
42884	2020-08-06 19:20:51	2020-08-06	Angie Glover	angie.glover@geemail.com	New York	New York	4058925654038	68a3ae46a5cb853ea03815655158f14c	VISA 13 digit	40.6315982957594102	-73.9190426919970633
42885	2020-08-06 19:29:01	2020-08-06	Haden Kessler	haden.kessler@geemail.com	San Francisco	California	52683943985490437	644879f6ccdefc9c887c63cc765ff54c	JCB 15 digit	37.7632340556160031	-122.447534659642955
42886	2020-08-06 19:40:06	2020-08-06	Codi Carroll	codi.carroll@geemail.com	Fort Worth	Texas	180039015409693788	cea837101c62714e6ecb199ed14c9b10	Maestro	32.7915373425055279	-97.3059645269818532
42887	2020-08-06 19:44:14	2020-08-06	Ferdinand Hauck	ferdinand.hauck@geemail.com	San Francisco	California	4747826504926	3c42c14c1d0dfcf23ccdb03edc09f574	JCB 16 digit	37.7871110936604708	-122.436697162946757
42888	2020-08-06 19:57:09	2020-08-06	Kimberely Braun	kimberely.braun@warmmail.com	Indianapolis	Indiana	3088068144246633171	a6cc18eb8528e7c41f5bd2934c2b2070	Discover	39.69374266476445	-86.101116405401001
42889	2020-08-06 20:10:55	2020-08-06	Wava Zemlak	wava.zemlak@warmmail.com	New York	New York	869951859928088910	74bd898456cf0cd98aef2e865caae480	JCB 16 digit	40.6384099490232771	-74.0080450613412921
42890	2020-08-06 20:12:55	2020-08-06	Dr. Kem Kris	dr.kem.kris@geemail.com	Aurora	Illinois	4317702989808810	0f0e468e25efebb50b2961babc1785e0	Mastercard	41.8606367764752392	-88.3848549436707032
42891	2020-08-06 20:13:51	2020-08-06	Medora Schuppe	medora.schuppe@geemail.com	Fontana	California	676314938326999	2e83d6cce880198016c68687854076ab	VISA 13 digit	34.0099081002790484	-117.449686318430679
42892	2020-08-06 20:21:37	2020-08-06	Elick Raynor-Pagac	elick.raynor.pagac@geemail.com	Plano	Texas	3764608256534879	8d572b00d7f4de472eff70946ec9cc5d	VISA 13 digit	33.0012293459933304	-96.6770014830116224
42893	2020-08-06 20:31:47	2020-08-06	Lovisa Nikolaus	lovisa.nikolaus@geemail.com	Santa Maria	California	3096507084134656166	3b9b41e9b71137a68e8c89bc2f5a630d	JCB 15 digit	34.9373578166186789	-120.468644734696667
42894	2020-08-06 20:37:47	2020-08-06	Nicki Collins	nicki.collins@woohoo.com	Oklahoma City	Oklahoma	3054786162463608	fb34aa367951951f92361a084d7eaf0c	Discover	35.4360835993107415	-97.4581624878466073
42895	2020-08-06 20:44:34	2020-08-06	Dr. Bella Murphy MD	dr.bella.murphy.md@geemail.com	Hartford	Connecticut	6011009428024080487	77571720d917759450be371f57732119	JCB 16 digit	41.7696455611396615	-72.6616795094110159
42896	2020-08-06 20:57:33	2020-08-06	Ms. Lovie Bernhard DVM	ms.lovie.bernhard.dvm@warmmail.com	Phoenix	Arizona	869971750219119710	f2407b67779a04f6c3aad32db638513a	VISA 16 digit	33.5223889229752174	-112.18310910108724
42897	2020-08-06 21:06:55	2020-08-06	Renata Zulauf MD	renata.zulauf.md@geemail.com	Denver	Colorado	51096014610359081	32eef45b5bb536881b6c0f2ff8ba5f7b	Diners Club / Carte Blanche	39.7094228547584223	-104.9374394132536
42898	2020-08-06 21:10:59	2020-08-06	Calhoun Kunze	calhoun.kunze@woohoo.com	Manchester	New Hampshire	561235764421414	2c094f5ab5e4d1df744e02cf134d7282	VISA 16 digit	43.037935234706481	-71.4205929462224276
42899	2020-08-06 21:23:31	2020-08-06	Winfield Von-Kshlerin	winfield.von.kshlerin@woohoo.com	San Francisco	California	3158168474759670990	bc0a2b7c47613d06d688d2260af41725	Voyager	37.792278874768499	-122.399847706920468
42900	2020-08-06 21:27:12	2020-08-06	Jaquez Stehr	jaquez.stehr@geemail.com	San Francisco	California	180011202772373881	0ea553c973ae4109f9744d8dc2862020	Discover	37.7857161393443235	-122.445111424600796
42901	2020-08-06 21:30:33	2020-08-06	Dr. Salina Stokes	dr.salina.stokes@geemail.com	Pasadena	Texas	3716124764388401	a397fbe3d30c0e50a9feb0113c678816	JCB 15 digit	29.5797861726827911	-95.0599611074145798
42902	2020-08-06 21:33:53	2020-08-06	Atha Gulgowski	atha.gulgowski@geemail.com	New York	New York	4282080384478740	c5e18ab623c2f2d91b9d8c63dd8db8fa	VISA 13 digit	40.7354493150711079	-73.9681643035158487
42903	2020-08-06 21:34:18	2020-08-06	Megan Gutkowski	megan.gutkowski@warmmail.com	Escondido	California	3158434326605102222	2aceaa75c492cd12bfa562169f366104	VISA 13 digit	33.135942824719848	-117.125266572577871
42904	2020-08-06 21:51:27	2020-08-06	Dr. Shani Maggio	dr.shani.maggio@geemail.com	Oxnard	California	3714790866671357	380122ca60a077a072201c388b7652b0	JCB 16 digit	34.1751637111373228	-119.139470809642603
42905	2020-08-06 22:03:46	2020-08-06	Jamie Gulgowski	jamie.gulgowski@woohoo.com	Oakland	California	4495456194390	e87943508c41f65ad0a6d3d85b35e1ea	Discover	37.8066150880594449	-122.282270300887546
42906	2020-08-06 22:09:03	2020-08-06	Kittie Streich	kittie.streich@woohoo.com	Riverside	California	869902733863194357	af48624cf37937500e5ec7558e973f6b	Voyager	33.9439997950516599	-117.349980915614211
42907	2020-08-06 22:13:32	2020-08-06	Armin Smith DDS	armin.smith.dds@geemail.com	Arvada	Colorado	4271410045243154	e388dc51e95b2eab006956f76ff39e58	Diners Club / Carte Blanche	39.7761004543107006	-105.163034819762416
42908	2020-08-06 22:45:55	2020-08-06	Latoria Toy	latoria.toy@woohoo.com	San Francisco	California	3008586749070900	96bedfa485a511e15ffee30aa6a33369	Maestro	37.7603826937959042	-122.413423733038528
42909	2020-08-06 22:49:30	2020-08-06	Joye Abbott-Kozey	joye.abbott.kozey@geemail.com	Pomona	California	6011967137735619315	47acd1dcb6b6344373f46aabdec1fe3c	Voyager	34.0275054683946081	-117.766714001257341
42910	2020-08-06 22:50:49	2020-08-06	Dr. Hailee Johnston	dr.hailee.johnston@geemail.com	Athens	Georgia	4092430721477436	8ea0b7090276d45c29d0e5f58d9d03f7	American Express	33.9704190819248524	-83.287115612963575
42911	2020-08-06 23:16:06	2020-08-06	Diego Bednar V	diego.bednar.v@geemail.com	Springfield	Massachusetts	869957566816253860	ee877b0ac4ab6982aa2e17d82029b3c7	VISA 13 digit	42.1274045590981814	-72.6010531315207572
42912	2020-08-06 23:17:15	2020-08-06	Dr. Mylie Stamm DVM	dr.mylie.stamm.dvm@warmmail.com	Miami	Florida	4155168047613	93393cfebfa425dcfb5b4a7a13de5011	Mastercard	25.8740431820645931	-80.1213583104651406
42913	2020-08-06 23:27:49	2020-08-06	Mr. Rosco Stokes	mr.rosco.stokes@geemail.com	Chula Vista	California	3043578381265539	76cbd3181e0c572c3d727887b6bd4c61	Diners Club / Carte Blanche	32.5821328170362818	-117.013307870575034
42914	2020-08-06 23:39:10	2020-08-06	Mr. Braydon Fay V	mr.braydon.fay.v@warmmail.com	Philadelphia	Pennsylvania	3751079302710985	784e966771c8330dd6f2444e12ba7be4	VISA 13 digit	40.0062172517139487	-75.0875011665180381
42915	2020-08-06 23:43:06	2020-08-06	Len McDermott	len.mcdermott@warmmail.com	Chicago	Illinois	210072976310664739	ca372fb370c96a4249d426aa0032cb70	VISA 16 digit	41.7822052249055389	-87.7292205082748069
42916	2020-08-06 23:44:47	2020-08-06	Danniel Keebler	danniel.keebler@geemail.com	Anchorage	Alaska	3528630699299924644	bf4ec38065c65bca9900882cb40aa90f	JCB 16 digit	61.1611799167219559	-149.323336731002854
42917	2020-08-06 23:51:52	2020-08-06	Brayan Schaden	brayan.schaden@geemail.com	Santa Ana	California	6011367621959282260	778f5a7a66e69bb3f644a2b0958716f0	VISA 16 digit	33.715525476412104	-117.957833252886303
42918	2020-08-06 23:53:58	2020-08-06	Roena Ferry	roena.ferry@geemail.com	Reno	Nevada	4424181468483660	3cb7e4a14924d02ec1a5a2567a1c6ba6	JCB 16 digit	39.4626813492350337	-119.76723416374773
42919	2020-08-06 23:56:33	2020-08-06	Paris Schmidt	paris.schmidt@woohoo.com	Albuquerque	New Mexico	675993918431995	485f29b6f214f26ef312194c76d0c7bf	Diners Club / Carte Blanche	35.1549121061939758	-106.704787567125265
42920	2020-08-06 23:56:34	2020-08-06	Anaya Stark-Halvorson	anaya.stark.halvorson@geemail.com	Des Moines	Iowa	210043727299024452	648de288e9808dcd1c2926c8d30a12e2	Diners Club / Carte Blanche	41.642833736140652	-93.7037171696357518
42921	2020-08-06 23:58:09	2020-08-06	Mrs. Vassie Satterfield PhD	mrs.vassie.satterfield.phd@geemail.com	Palmdale	California	6011754704225725386	e3f1ba8a1b6ac7961a2c961874f704b5	Mastercard	34.4991647888757313	-118.091769435582307
42922	2020-08-06 23:58:58	2020-08-06	Ela Kessler	ela.kessler@geemail.com	Los Angeles	California	4765194182856597	35e1befaed33494be6b1fd052d46f398	American Express	34.098382548322526	-118.441931337070827
42923	2020-08-07 00:05:30	2020-08-07	Collie Kirlin	collie.kirlin@warmmail.com	Kansas City	Missouri	4609959182216673	23e2ead80cfaf8455e8e20736d8e1729	VISA 16 digit	39.0429788650315288	-94.4543107011113392
42924	2020-08-07 00:18:30	2020-08-07	Eryn Zboncak	eryn.zboncak@woohoo.com	Fremont	California	4813609893760780	ead824d3616e41dacd7fb9e8b3236a2c	JCB 16 digit	37.4610591457858675	-122.021514429011191
42925	2020-08-07 00:19:49	2020-08-07	Nyasia Flatley	nyasia.flatley@geemail.com	Dayton	Ohio	869959322236083836	886bfd3047a7ee9d2f1644b199a023e9	Maestro	39.6882454485889511	-84.2646286351796334
42926	2020-08-07 00:22:11	2020-08-07	Yaretzi Kulas	yaretzi.kulas@geemail.com	Overland Park	Kansas	3746363393667124	83bfa20a2fff2dac03d2fd76b6790850	JCB 16 digit	38.8758830555118635	-94.7455547633621933
42927	2020-08-07 00:25:59	2020-08-07	Ova Corwin	ova.corwin@geemail.com	Berkeley	California	3716179350171728	c1df5b8f09f8fde1a6272bcf968539e7	JCB 16 digit	37.8583122350254442	-122.275888056970032
42928	2020-08-07 00:37:51	2020-08-07	Nikolai Stiedemann-Waters	nikolai.stiedemann.waters@geemail.com	Oakland	California	3337972935729459264	187d891bfcc08979b99bdc0bba04479c	Voyager	37.7753577563243397	-122.288200515013372
42929	2020-08-07 00:46:35	2020-08-07	Jeraldine Kilback	jeraldine.kilback@warmmail.com	New York	New York	676393989633560	239697c4b6dbfd0b53fdd8bb92797569	Mastercard	40.6112927655912941	-73.8756079598225597
42930	2020-08-07 00:51:13	2020-08-07	Cornie Zulauf	cornie.zulauf@geemail.com	Concord	California	869921074993038504	19486586f82d516464df4bd7923f9c96	Mastercard	38.029387693705786	-121.927668583922454
42931	2020-08-07 00:53:33	2020-08-07	Ansley Lakin	ansley.lakin@geemail.com	Houston	Texas	4502566881593282	961125496bd1a92117b071375c3c4902	American Express	29.8717784408092513	-95.3991001440227109
42932	2020-08-07 01:01:26	2020-08-07	Ms. Alexina Erdman	ms.alexina.erdman@woohoo.com	Bakersfield	California	4646204663675831	658b8d704c9c676b488a140c1f7bce57	VISA 16 digit	35.3318876692268944	-118.947562254061168
42933	2020-08-07 01:06:28	2020-08-07	Aloma Smitham	aloma.smitham@geemail.com	Honolulu	Hawaii	3528559203091076914	a005fed844e1f9a5ef80c054e77aa3a1	VISA 16 digit	21.3978465231817232	-157.845881405679876
42934	2020-08-07 01:10:54	2020-08-07	Hartley Zieme	hartley.zieme@woohoo.com	Reno	Nevada	639003720496607	e014333f3dbe022d8b0fe06b68593e19	JCB 16 digit	39.4851914194956422	-119.896369269366943
42935	2020-08-07 01:39:58	2020-08-07	Dr. Nathalia Luettgen PhD	dr.nathalia.luettgen.phd@geemail.com	Yonkers	New York	6011319721893587847	84a3883578f14cf4c45caf9b992cc998	Mastercard	40.9040007083412291	-73.8575545065920807
42936	2020-08-07 01:42:58	2020-08-07	Bettyjane Lubowitz	bettyjane.lubowitz@geemail.com	New York	New York	4547666946488	4971f6b241588f42ad2a5ff7bc09b1f3	Maestro	40.7247258500885181	-73.9150879983220221
42937	2020-08-07 01:48:30	2020-08-07	Lorenza Gusikowski Sr.	lorenza.gusikowski.sr.@warmmail.com	Chicago	Illinois	4310529460963278	03dc54bec081568dd690771e347a9f8e	Maestro	41.8686697204433429	-87.6215281680256055
42938	2020-08-07 01:52:46	2020-08-07	Bettyjane Ebert-Funk	bettyjane.ebert.funk@geemail.com	New York	New York	4947271434433309	4549607775d2c0533100d3fb60ee7666	Discover	40.7318578256517654	-73.8587301631353768
42939	2020-08-07 01:56:59	2020-08-07	Dr. Terrie Block DDS	dr.terrie.block.dds@geemail.com	West Valley City	Utah	210064077545244957	58e68ff9bb5336b1297f0a306fee1452	VISA 16 digit	40.6385708169769444	-112.054880880073824
42940	2020-08-07 01:57:05	2020-08-07	Eller Sanford	eller.sanford@warmmail.com	Dallas	Texas	3054630957418429	039089a3ad0f1042f66a02bb7c6d6fdd	JCB 15 digit	32.7758772440060966	-96.7555052638482209
42941	2020-08-07 02:01:55	2020-08-07	Skip Keebler	skip.keebler@woohoo.com	Long Beach	California	4096086340281058	fd43a979d4eb5591fbae2d8258759cb0	Discover	33.8801347393363699	-118.139377112423247
42942	2020-08-07 02:05:00	2020-08-07	Luka Gutkowski	luka.gutkowski@geemail.com	Rancho Cucamonga	California	4275874754722672	ab40b4024d7c791d40ceef660a0e787e	Maestro	34.0434164802070711	-117.61922699441277
42943	2020-08-07 02:07:35	2020-08-07	Grisel Daniel	grisel.daniel@warmmail.com	Houston	Texas	4740703976002265	7d05047911af2893f7518360a58b95ac	Maestro	29.8517538056787117	-95.3685295509655049
42944	2020-08-07 02:09:08	2020-08-07	Genie Bogisich	genie.bogisich@geemail.com	Fresno	California	3088271720885827803	7803082b21a55ae77a5097db20567d9e	VISA 16 digit	36.7612103698648482	-119.887383068130916
42945	2020-08-07 02:12:48	2020-08-07	Stonewall Dach	stonewall.dach@geemail.com	Seattle	Washington	3528249770513648443	c471db829b3d70b09c0b90d7097ae58c	Voyager	47.617465375728905	-122.314817007809495
42946	2020-08-07 02:18:08	2020-08-07	Gustave Macejkovic	gustave.macejkovic@geemail.com	High Point	North Carolina	210007345429122411	5a6b07bd96acc120d7e90fa0662eca4f	Maestro	35.9508752741478403	-80.0261937213335131
42947	2020-08-07 02:19:55	2020-08-07	Marley Friesen	marley.friesen@geemail.com	San Antonio	Texas	3096368658277163763	0a8dd93a67fca0f7aece34c33ec14d8e	JCB 15 digit	29.4204177998077121	-98.5009987450972204
42948	2020-08-07 02:20:15	2020-08-07	Mr. Truman Corkery	mr.truman.corkery@geemail.com	San Diego	California	676265687502727	e5e03f2f9083b6b7e5ca960c52f32ffc	American Express	32.7782265905823564	-117.194529435448359
42949	2020-08-07 02:23:36	2020-08-07	Miss Wilhelmine Larkin	miss.wilhelmine.larkin@geemail.com	Berkeley	California	3421232802840409	9b05362bf44d5bd9e55b7fe059ed9ccd	VISA 13 digit	37.8624857661296872	-122.265952742328736
42950	2020-08-07 02:24:14	2020-08-07	Holden Hoppe IV	holden.hoppe.iv@geemail.com	Greensboro	North Carolina	3112607338650697692	1b1de4ebac8d958d9d3ad407ecaa0d48	Discover	36.0728247237972965	-79.8177872180454386
42951	2020-08-07 02:30:59	2020-08-07	Madden Konopelski-Orn	madden.konopelski.orn@geemail.com	San Francisco	California	676239902860137	7cb050a922cacc3ca7bd923491dd3065	VISA 13 digit	37.7645275795582194	-122.428464594254137
42952	2020-08-07 02:38:44	2020-08-07	Teagan Marquardt-VonRueden	teagan.marquardt.vonrueden@warmmail.com	Torrance	California	3057873409466433	3147ef968b1f94b28167ca600c3d6a48	JCB 16 digit	33.8451414599455873	-118.273674772552766
42953	2020-08-07 02:44:22	2020-08-07	Dr. Lelah Kris	dr.lelah.kris@warmmail.com	Santa Rosa	California	4777424546080311	b79e8d5c53ed2a36f969899948e27bc3	Discover	38.3574283003464345	-122.673010740453762
42954	2020-08-07 02:46:28	2020-08-07	Nyasia Veum	nyasia.veum@geemail.com	Memphis	Tennessee	210064598017312162	a47e46d1bd023d27980a791fd9874df0	American Express	35.0778761092174847	-90.017022783428061
42955	2020-08-07 02:48:36	2020-08-07	Jared Gleichner	jared.gleichner@woohoo.com	Chandler	Arizona	4849137503843927	8f66ac1f78239956f2a0f6002f2a4c2f	Mastercard	33.3213027040097813	-111.851041276648274
42956	2020-08-07 02:49:22	2020-08-07	Skip Hettinger-Hackett	skip.hettinger.hackett@geemail.com	New York	New York	4697363545461	d105d341d4a9c6ecd95651904ad911a7	VISA 13 digit	40.6655470954477778	-73.9160440442513647
42957	2020-08-07 02:55:17	2020-08-07	Annmarie Kozey	annmarie.kozey@woohoo.com	Centennial	Colorado	210064779094814755	e2f997d1ee4e64ed410c0a4c1e0fc4cc	Mastercard	39.6875470096286378	-104.870589634765309
42958	2020-08-07 02:56:00	2020-08-07	Shyheim Pollich	shyheim.pollich@woohoo.com	Charlotte	North Carolina	3452440562967666	0b8b746c098efad4ae590f7deb5b7be2	VISA 16 digit	35.1873881956815708	-80.7931426423545958
42959	2020-08-07 03:09:06	2020-08-07	Shade Greenfelder	shade.greenfelder@geemail.com	New York	New York	060416287425256	8bb946abc36f596b585d41d5f6f1df41	Voyager	40.6386597743015727	-74.0252181825123756
42960	2020-08-07 03:09:48	2020-08-07	Orrie Ritchie PhD	orrie.ritchie.phd@geemail.com	New York	New York	210018481018214124	489039f81714979115d1cc06e462e8fe	Mastercard	40.6232125355154281	-74.0351172128587933
42961	2020-08-07 03:12:13	2020-08-07	Paris Daniel DVM	paris.daniel.dvm@geemail.com	Kenosha	Wisconsin	6011322999421352836	815720a85a59c1622a15fac2ccfe0c9b	Diners Club / Carte Blanche	42.6115310687411579	-87.8030488710146386
42962	2020-08-07 03:14:07	2020-08-07	Kenyon Nikolaus	kenyon.nikolaus@geemail.com	Dallas	Texas	4543533169461096	3e5cd5b850f6822aec9f6e45e3e2c24a	Diners Club / Carte Blanche	32.7514735252868405	-96.7445539928935432
42963	2020-08-07 03:18:20	2020-08-07	Queenie Crona	queenie.crona@geemail.com	Edison	New Jersey	4244070054964	1801a3d1730c49022ac9a72b774a82e7	Voyager	40.4712252750955486	-74.4216199936863063
42964	2020-08-07 03:27:02	2020-08-07	Loree Goyette	loree.goyette@geemail.com	Chicago	Illinois	52481684306798470	3a4323aae4324416c941a856fbaa9ab5	JCB 15 digit	41.8628831597812479	-87.6920497246582045
42965	2020-08-07 03:35:40	2020-08-07	Taylor Kessler	taylor.kessler@geemail.com	Chicago	Illinois	53707217132511276	6905519c4946324d36ed35d4ce7e1880	Maestro	41.7801151788629639	-87.6830770731002076
42966	2020-08-07 03:39:03	2020-08-07	Wyman Cremin	wyman.cremin@woohoo.com	Palmdale	California	55838260520929637	2695963cf843aad17498c1c9f549ce1b	American Express	34.6104033040199468	-118.138328314153114
42967	2020-08-07 03:40:52	2020-08-07	Dangelo Goyette	dangelo.goyette@warmmail.com	Mesquite	Texas	3096902319011714469	adbd433de7f7616af4530408ae92fd4e	Mastercard	32.7649481298211995	-96.6611670678678934
42968	2020-08-07 03:42:22	2020-08-07	Georgeann Sawayn PhD	georgeann.sawayn.phd@woohoo.com	Dallas	Texas	869957087923912116	577bb3c29d50bf5ea36998b1621350f5	VISA 16 digit	32.7221437694311135	-96.8601041607987128
42969	2020-08-07 03:53:27	2020-08-07	Adel Denesik	adel.denesik@geemail.com	Elizabeth	New Jersey	4841980838358311	ccca09856a5758f3bc95a64267d2ac43	JCB 16 digit	40.762103217107807	-74.282683808118108
42970	2020-08-07 04:02:43	2020-08-07	Vallie Hintz	vallie.hintz@geemail.com	Wilmington	North Carolina	869952766568540853	8d2ce49d6a69d3cc1c28ad79891ab9dd	Diners Club / Carte Blanche	34.30104521278367	-77.8529168597415122
42971	2020-08-07 04:06:04	2020-08-07	Tatsuo Denesik-Dooley	tatsuo.denesik.dooley@geemail.com	Clinton	Michigan	869908657563481737	c02cffcd2e90784eee39f2ae0e69a6f3	Mastercard	42.5607799271188654	-83.0079180736634896
42972	2020-08-07 04:24:09	2020-08-07	Phoebe Ondricka	phoebe.ondricka@geemail.com	Newark	New Jersey	869985213404699628	83e56fb739117aff42cbb9797ab66e86	VISA 16 digit	40.7320156983945552	-74.1678139728702632
42973	2020-08-07 04:29:53	2020-08-07	Howell Reynolds	howell.reynolds@woohoo.com	Chicago	Illinois	6011625119546087860	db38224532a5a792940be087429b2bc9	Maestro	41.7452313585508605	-87.6328485198814349
42974	2020-08-07 04:32:27	2020-08-07	Miss Georgette Wintheiser	miss.georgette.wintheiser@warmmail.com	Washington	District of Columbia	4258803396658	29522136d274f0f8205e3e64ca71521c	American Express	38.9761507533755136	-76.9969005584463559
42975	2020-08-07 04:35:29	2020-08-07	Ms. Bethann DuBuque MD	ms.bethann.dubuque.md@geemail.com	Seattle	Washington	630429087059829	c7665244f04c6e3ab357deef59fcd6f7	JCB 15 digit	47.6478324762936651	-122.429490456582599
42976	2020-08-07 04:40:29	2020-08-07	Shirlee O'Conner	shirlee.o'conner@geemail.com	Los Angeles	California	4238258220645	8aa3138ce5380fc83a6fa2b28950a17e	Maestro	34.1157170025963339	-118.41976645504981
42977	2020-08-07 04:41:38	2020-08-07	Kiyoshi Christiansen V	kiyoshi.christiansen.v@geemail.com	Houston	Texas	51437580165553680	4d52278d45ff9108e99a0f335c943597	Discover	29.7387632109303013	-95.3658866678845101
42978	2020-08-07 04:45:25	2020-08-07	Miss Janet Erdman DDS	miss.janet.erdman.dds@geemail.com	San Antonio	Texas	3158093225798307527	a765ed3e964092060caee03a029a570a	Discover	29.4878462634120133	-98.5972623442135756
42979	2020-08-07 04:46:11	2020-08-07	Miss Porsha Toy MD	miss.porsha.toy.md@geemail.com	Costa Mesa	California	180044729461276760	ad8a65ae7002522623bf977f1966b1e1	Mastercard	33.5887568928781874	-117.886957459091391
42980	2020-08-07 04:46:35	2020-08-07	Aloysius Schulist DVM	aloysius.schulist.dvm@geemail.com	Seattle	Washington	6011671441240798532	6ec5d5b3085542aa5b3439153f440447	Diners Club / Carte Blanche	47.6633409572225091	-122.398114485518633
42981	2020-08-07 04:54:09	2020-08-07	Buren Upton	buren.upton@warmmail.com	Berkeley	California	4920111445473	ea9033f446f15a412339b0d4bfd2f96b	Diners Club / Carte Blanche	37.8848201328978647	-122.322840164893435
42982	2020-08-07 04:56:05	2020-08-07	Dr. Darrius Gutmann	dr.darrius.gutmann@geemail.com	Berkeley	California	869989160794783627	d7a7b7f809bf96763f01fbf7d8b44575	Mastercard	37.8910990401525396	-122.256985843710083
42983	2020-08-07 05:15:02	2020-08-07	Bettylou Mohr DDS	bettylou.mohr.dds@geemail.com	Reno	Nevada	4107911016778516	79e5b8ef54594da8cbcb02c94970caf6	VISA 13 digit	39.4809138625938445	-119.942954216820752
42984	2020-08-07 05:17:42	2020-08-07	Mrs. Jannette Walsh	mrs.jannette.walsh@geemail.com	San Antonio	Texas	4694453816579033	54376a77a00df1b7468fdf146ead1997	American Express	29.4356256703916941	-98.4905359543230361
42985	2020-08-07 05:23:27	2020-08-07	Minervia Lindgren PhD	minervia.lindgren.phd@warmmail.com	San Francisco	California	3471427859604562	7b7e14ff98a7a6b8d0372d612aee6088	Voyager	37.7501391776395607	-122.432232933004883
42986	2020-08-07 05:26:48	2020-08-07	Jeanine Lakin	jeanine.lakin@warmmail.com	Colorado Springs	Colorado	869998104504846893	350217b4b8bd9a8d1986904aafca4edb	Maestro	38.8787838711917431	-104.830062812675536
42987	2020-08-07 05:29:02	2020-08-07	Jerel Mueller	jerel.mueller@woohoo.com	Greensboro	North Carolina	3112585940648799906	c4f24954e4eaf772b70bac2e6d1f8f35	JCB 15 digit	36.0594197819590576	-79.7504859543852547
42988	2020-08-07 05:33:49	2020-08-07	Keanu Howell	keanu.howell@geemail.com	Los Angeles	California	4935317549172532	19bb809f9794d2da7d68060877499dd5	JCB 15 digit	34.0575644937209745	-118.448318353573967
42989	2020-08-07 05:42:14	2020-08-07	Danyell Farrell-Kuhic	danyell.farrell.kuhic@woohoo.com	Visalia	California	869981992670917905	400220752feba77a9e04ca90c19cb227	JCB 16 digit	36.3414419887542763	-119.403287483624752
42990	2020-08-07 05:44:29	2020-08-07	Brandin Quitzon	brandin.quitzon@geemail.com	New York	New York	4485420937479	528dd4dd359e3b315d2d90e240b83f27	Maestro	40.5956678614709503	-73.9567663330946061
42991	2020-08-07 05:49:03	2020-08-07	Shavon Gerlach	shavon.gerlach@geemail.com	Thousand Oaks	California	3737583377183118	dda5295ebca260c9cbb9ce97871a6c8d	Discover	34.2550598012555412	-118.81103500527405
42992	2020-08-07 05:50:19	2020-08-07	Louie Hoeger-Ortiz	louie.hoeger.ortiz@woohoo.com	Oakland	California	3158975705347258134	aee1ed03d7ed459b84102dd2b2674597	VISA 16 digit	37.7727137099300094	-122.276491740566414
42993	2020-08-07 05:53:08	2020-08-07	Ms. Brooklyn Runolfsson	ms.brooklyn.runolfsson@geemail.com	Arlington	Texas	4064386953867997	520d85fc7a89fd75a07dcecd9f0d8bb4	Discover	32.6518491009499883	-97.1375682160284413
42994	2020-08-07 05:55:59	2020-08-07	Mr. Palmer Steuber	mr.palmer.steuber@warmmail.com	San Bernardino	California	869939828308406171	f3a0bbd69002797fba0673b2c22ec841	VISA 16 digit	34.2041393591821148	-117.389888416394967
42995	2020-08-07 05:56:51	2020-08-07	Marquis Leffler	marquis.leffler@geemail.com	San Francisco	California	4523061628476921	bfabba5f6ccaa251e4cb331c4925248b	JCB 16 digit	37.7527682976552654	-122.405436555168748
42996	2020-08-07 05:58:38	2020-08-07	Miss Sage Kohler MD	miss.sage.kohler.md@geemail.com	New York	New York	210049581411073937	42dd45e05e4f1a93cdc16d35bceba941	Diners Club / Carte Blanche	40.6163662946075164	-73.9869868510764093
42997	2020-08-07 06:00:51	2020-08-07	Bud Feest Jr.	bud.feest.jr.@geemail.com	Dallas	Texas	51998081574527804	5166a2b64130aee62f1b24177676966d	Maestro	32.8797802779629862	-96.7660286199264164
42998	2020-08-07 06:01:33	2020-08-07	Erving Cole	erving.cole@geemail.com	Austin	Texas	6011430721721602960	8b0e10bcadfd2a0d09abb565728d1f1c	Maestro	30.3243228364862496	-97.7647489246685097
42999	2020-08-07 06:10:47	2020-08-07	Charlottie Daniel	charlottie.daniel@woohoo.com	New York	New York	676348722528618	b21966b669165e50c144d935216e6c54	Diners Club / Carte Blanche	40.5703220739718518	-73.8837769143179059
43000	2020-08-07 06:31:01	2020-08-07	Jonnie Stanton DVM	jonnie.stanton.dvm@geemail.com	Seattle	Washington	869945158680703702	350b8f7e20ea56966b162bd8f24d1975	Discover	47.5298681165017172	-122.353239392574494
43001	2020-08-07 06:32:27	2020-08-07	Derl Waelchi	derl.waelchi@warmmail.com	Raleigh	North Carolina	4885218126536661	c7c1d303af5c63beb55cb71d7fa6d495	Discover	35.901641298750782	-78.5429067410931054
43002	2020-08-07 06:34:59	2020-08-07	Elva Jaskolski	elva.jaskolski@geemail.com	San Francisco	California	4087880396080534	96c01351cfc2fe861ba5d0a02879ce78	JCB 16 digit	37.7519686244632808	-122.473870898130798
43003	2020-08-07 06:37:28	2020-08-07	Ariella Schaden-Hayes	ariella.schaden.hayes@geemail.com	Henderson	Nevada	3088426701058890335	cf14c8f12779293edf4a8ae5fbcd19c1	Maestro	35.9420214000090965	-114.981413331643495
43004	2020-08-07 06:53:42	2020-08-07	Elliot Hane-Halvorson	elliot.hane.halvorson@geemail.com	Las Vegas	Nevada	51198197620153573	2e90efdfc0b6d3264c46e8a25e3232bf	Discover	36.3185828802276376	-115.311756882744277
43005	2020-08-07 07:01:42	2020-08-07	Loyal Mante	loyal.mante@geemail.com	San Francisco	California	4482706182974815	729263f86eab7a39800794ae99f49572	VISA 16 digit	37.7735311062052332	-122.458321999188627
43006	2020-08-07 07:08:37	2020-08-07	Dr. Marvin Mueller IV	dr.marvin.mueller.iv@warmmail.com	Raleigh	North Carolina	3158068919983383753	56920749e4ee6dc78111bafafab0c14a	Diners Club / Carte Blanche	35.7924893353268487	-78.6069590491645016
43007	2020-08-07 07:23:40	2020-08-07	Miss Vertie Kunze MD	miss.vertie.kunze.md@geemail.com	Kansas City	Kansas	3472707235386532	6ed3c45094f5d8e048a3f466333df46c	VISA 16 digit	39.2078178143035672	-94.7938000871270816
43008	2020-08-07 07:24:50	2020-08-07	Orion Schaden	orion.schaden@geemail.com	San Francisco	California	3158530572510452532	8fb69780f2719a20abcb7d8baba6155d	VISA 16 digit	37.7516360009303611	-122.439353734928005
43009	2020-08-07 07:26:58	2020-08-07	Ms. Jerilyn Wolf	ms.jerilyn.wolf@warmmail.com	Newport News	Virginia	3405779684450376	bdd1a74d8353a96d3c22c92ff72a8b4c	JCB 16 digit	36.9938152543630423	-76.5942678622696604
43010	2020-08-07 07:43:08	2020-08-07	Cambria Quitzon	cambria.quitzon@woohoo.com	Boston	Massachusetts	4868150003063611	dcd7bc25ea6d28cbfe542a6751d10976	Discover	42.2821812510658077	-71.0252139924045736
43011	2020-08-07 07:45:05	2020-08-07	Diallo Upton	diallo.upton@warmmail.com	San Francisco	California	3019544251603120	3884e8e4b35db66b4e96aaf884c41b55	VISA 16 digit	37.7898903086519908	-122.469679440609482
43012	2020-08-07 07:47:33	2020-08-07	Mrs. Tangela Ondricka PhD	mrs.tangela.ondricka.phd@geemail.com	Phoenix	Arizona	6011534565620767142	ddb83c3c6c923065a5eadd74dd7f34ca	Maestro	33.4982709561407574	-112.104056205127762
43013	2020-08-07 07:55:44	2020-08-07	Mae Schulist	mae.schulist@woohoo.com	Chicago	Illinois	3001072573636329	b0ead8b3acc906a650a240a90477af40	VISA 16 digit	41.8847695313230162	-87.5868640014931543
43014	2020-08-07 07:56:40	2020-08-07	Milissa Ondricka-Wolf	milissa.ondricka.wolf@woohoo.com	Hillsboro	Oregon	3337638907644279289	779abe6ab7d19f6da0e40396fc76c01b	JCB 15 digit	45.5785560505203904	-122.870390328780559
43015	2020-08-07 07:57:39	2020-08-07	Branden Harris	branden.harris@warmmail.com	Seattle	Washington	869949279498944423	7c0f2232a0bbe82dcd3e35469600b70b	Mastercard	47.5667857723701744	-122.408687816226475
43016	2020-08-07 07:57:45	2020-08-07	Illa Bins	illa.bins@warmmail.com	San Francisco	California	4748353511565194	3e41d9d17a0f0459ee8e16fda3128cba	VISA 13 digit	37.7395718247910636	-122.445322467614545
43017	2020-08-07 07:58:58	2020-08-07	Davonte Bahringer PhD	davonte.bahringer.phd@geemail.com	Houston	Texas	4165619019723012	097470df9ffeee3f105572ef680e994e	VISA 16 digit	29.7538348081599935	-95.3105403550915469
43018	2020-08-07 07:58:59	2020-08-07	Wellington Murazik	wellington.murazik@geemail.com	Long Beach	California	869982364595588808	c9300975abdc034cedb6820f67a71519	American Express	33.7159610917612866	-118.142959598607561
43019	2020-08-07 08:06:17	2020-08-07	Claudie Mills-Wolff	claudie.mills.wolff@warmmail.com	Chula Vista	California	53020816044423858	4ee8ebed219038b4b21b628b3883755c	VISA 16 digit	32.6375606581334026	-116.982644102652358
43020	2020-08-07 08:12:36	2020-08-07	Kennard Herman	kennard.herman@geemail.com	Dallas	Texas	4428530739518694	6e1b785348866dbb120379dfeb26e97f	VISA 16 digit	32.6940634073961576	-96.7236087259799149
43021	2020-08-07 08:26:16	2020-08-07	Burton Lang	burton.lang@geemail.com	Milwaukee	Wisconsin	3716240863794644	d2a7d577fe1f1bef784e82368afda82c	American Express	43.0370281612120564	-87.8974061635889115
43022	2020-08-07 08:27:18	2020-08-07	Dirk Stracke	dirk.stracke@geemail.com	Bakersfield	California	3013223219989030	cf3b1e34dcd1271c4c74121e2702e48a	JCB 15 digit	35.3598468528304224	-118.993778500546881
43023	2020-08-07 08:30:29	2020-08-07	Merle McClure	merle.mcclure@woohoo.com	Berkeley	California	4823994426537105	26f907c65527c6b133f2682bb4348d4b	Diners Club / Carte Blanche	37.8810796651597457	-122.283661456082697
43024	2020-08-07 08:35:10	2020-08-07	Zollie Kris	zollie.kris@geemail.com	Fort Worth	Texas	3705795953815297	8ff9758c36de0c094e9d423234533ecf	Discover	32.8075914695914861	-97.3951643943142074
43025	2020-08-07 08:52:32	2020-08-07	Dr. Annemarie Paucek DDS	dr.annemarie.paucek.dds@warmmail.com	Saint Paul	Minnesota	53150437086679836	70f3b8cf333faef28e8fb92bdc262318	JCB 15 digit	44.9101275023013358	-93.1307370988916574
43026	2020-08-07 08:53:25	2020-08-07	Mr. Javonte Spinka	mr.javonte.spinka@geemail.com	Cleveland	Ohio	3528345598910157038	36e144414c2301b237f4d02ca4ae7edd	American Express	41.4040767516326156	-81.5892745687864789
43027	2020-08-07 08:59:20	2020-08-07	Kayden Cassin	kayden.cassin@geemail.com	Dallas	Texas	4567955279683346	ada1ddab5659b97407ccfe2d10743d52	JCB 16 digit	32.7801161521386391	-96.8299994063060723
43028	2020-08-07 09:06:37	2020-08-07	Ayesha Bogan	ayesha.bogan@geemail.com	Fort Wayne	Indiana	3158694016391914832	e1c73bdc05b232cb18ffd9f5c3d31f15	Discover	41.1016559635538599	-85.2066011035569062
43029	2020-08-07 09:17:40	2020-08-07	Oswald Pacocha	oswald.pacocha@geemail.com	San Francisco	California	869974970835060828	8952fe42dae64989b515b749ac120559	Maestro	37.7851613136255082	-122.428672516339006
43030	2020-08-07 09:25:43	2020-08-07	Mr. Olaf Langworth	mr.olaf.langworth@geemail.com	Baltimore	Maryland	869960338794426636	683f69e5bd32654f01629023ec764995	VISA 16 digit	39.3505717457737774	-76.6052179262060662
43031	2020-08-07 09:34:24	2020-08-07	Brain Schulist IV	brain.schulist.iv@geemail.com	Rancho Cucamonga	California	4694540148954	d3c809165c3d68e8ab3f7fca039b9632	Voyager	34.1623356526244422	-117.466742643388727
43032	2020-08-07 09:39:42	2020-08-07	Juluis Sauer	juluis.sauer@woohoo.com	Omaha	Nebraska	3337589699740734767	28209352efe5010f8d48ac3fcfdd83e5	JCB 16 digit	41.2431465265486423	-96.0048984892781903
43033	2020-08-07 09:40:43	2020-08-07	Donell Koss	donell.koss@warmmail.com	Oxnard	California	3112408396419067517	59ae70dd967a399c249928e1f6f82a24	Maestro	34.1985970925960672	-119.151696824599426
43034	2020-08-07 09:41:32	2020-08-07	Pryor Walter	pryor.walter@geemail.com	St. Petersburg	Florida	51257548091079432	9085e870838f4b5a2ae623dfe10bbe46	VISA 13 digit	27.7731482174135742	-82.6106682597085751
43035	2020-08-07 09:45:39	2020-08-07	Izetta Jacobson	izetta.jacobson@geemail.com	Atlanta	Georgia	869917384216066984	1253ecf17bacb2ce0b1bb84ce5836004	JCB 16 digit	33.8079145288370597	-84.4236491656441359
43036	2020-08-07 09:48:26	2020-08-07	Maxie Heidenreich IV	maxie.heidenreich.iv@woohoo.com	Miami	Florida	4965034723001	4d55e36273deb3b00d7faefd5b56e0e6	JCB 16 digit	25.7734093206606829	-80.2128100530117791
43037	2020-08-07 09:52:59	2020-08-07	Chadd Keeling	chadd.keeling@warmmail.com	Moreno Valley	California	639068833417105	457781f31fcd3fac457d9b2849a83840	Mastercard	33.9773623845532526	-117.220329119588058
43038	2020-08-07 10:04:18	2020-08-07	Mr. Montana Bogan V	mr.montana.bogan.v@geemail.com	Houston	Texas	869991010241041374	481f7ab2978014fc7287d85b04d8f762	Voyager	29.7559366436753407	-95.460584284878891
43039	2020-08-07 10:05:26	2020-08-07	Holmes Metz	holmes.metz@geemail.com	Durham	North Carolina	869933972221625883	67a5052378f50f2c8a853a57a1cd5ec3	Discover	36.075833840413388	-78.8255492722053077
43040	2020-08-07 10:12:04	2020-08-07	Cherilyn Bins	cherilyn.bins@geemail.com	Chicago	Illinois	3528052270849992330	74a4869c03cb9cb2b6539364e7e63acc	JCB 16 digit	41.9181176183581385	-87.718069716266541
43041	2020-08-07 10:18:16	2020-08-07	Mikal Stanton Jr.	mikal.stanton.jr.@geemail.com	Houston	Texas	4989975608666	bb59d2df1c0afcba5ca202716c65f2c2	JCB 16 digit	29.8117840961631373	-95.4504717439427992
43042	2020-08-07 10:21:47	2020-08-07	Vidal Stroman-Johnson	vidal.stroman.johnson@woohoo.com	Frisco	Texas	51503252642264773	fc3b6dbb2a754548207fe27e37d73d58	VISA 16 digit	33.2119574495121839	-96.8854629309590791
43043	2020-08-07 10:41:15	2020-08-07	Dr. Linwood Steuber I	dr.linwood.steuber.i@geemail.com	Tallahassee	Florida	3096711605220308650	e8fbd7e9e847b391c177d508545db518	American Express	30.4724920520115674	-84.1873957895688676
43044	2020-08-07 10:42:28	2020-08-07	Antwan Fritsch-Wunsch	antwan.fritsch.wunsch@woohoo.com	Philadelphia	Pennsylvania	060478289583839	1563a4c8be780fff32cf852588a4d5e6	VISA 16 digit	39.9387423585593666	-75.1692124751761668
43045	2020-08-07 10:48:19	2020-08-07	Zaid McLaughlin	zaid.mclaughlin@warmmail.com	New York	New York	869958704781939713	dcf2e5a0dabb9c6d907da1f3a0462a36	VISA 16 digit	40.5995477667301898	-73.9189444898057673
43046	2020-08-07 10:49:42	2020-08-07	Robby Legros	robby.legros@geemail.com	San Antonio	Texas	3088194671880763721	3826c00948c9cf9f3f9517f241584e7a	Voyager	29.4415826709080477	-98.6210077694453275
43047	2020-08-07 10:54:00	2020-08-07	Ms. Alvina Larkin	ms.alvina.larkin@geemail.com	Charleston	South Carolina	3112609314606114890	fe0b5c1fc729729f820d199c6dc6589d	Diners Club / Carte Blanche	32.8570055543441342	-79.9387322038095505
43048	2020-08-07 11:07:30	2020-08-07	Laureen Weimann	laureen.weimann@geemail.com	Washington	District of Columbia	55694094231153390	b9df47e83f7d7f08d00d232bf1431aca	Mastercard	38.8721153585039048	-77.0919828892432122
43049	2020-08-07 11:17:43	2020-08-07	Mr. Joe D'Amore	mr.joe.d'amore@geemail.com	Vista	California	6011410961968045036	810f023465f2b3b1f74d35fa7e94e260	JCB 16 digit	33.2260994592662939	-117.142576945066835
43050	2020-08-07 11:18:26	2020-08-07	Mr. Tavares Waelchi	mr.tavares.waelchi@geemail.com	San Francisco	California	4181028782108	304b6d1ff9917566e7cf37c464625d57	American Express	37.7408459694484364	-122.471073046731448
43051	2020-08-07 11:18:55	2020-08-07	Dagmar Rippin-Buckridge	dagmar.rippin.buckridge@geemail.com	Memphis	Tennessee	4548028448489666	81af704f8e9ac064d65f8d3007cccbd7	Diners Club / Carte Blanche	35.0486268058020656	-89.8956925245258986
43052	2020-08-07 11:19:02	2020-08-07	Fenton Stamm	fenton.stamm@geemail.com	Macon	Georgia	53416880192405390	77813613b9cc216cf6f7b867c655634d	VISA 13 digit	32.7142220524150886	-83.6893653337571664
43053	2020-08-07 11:30:23	2020-08-07	Buddy Kerluke	buddy.kerluke@geemail.com	Indianapolis	Indiana	869945304841186334	a48f839be80fdcf8cd55cc63672ecb07	Discover	39.7328231134459386	-86.1152153560627198
43054	2020-08-07 11:37:37	2020-08-07	Dr. Kelsea Schinner PhD	dr.kelsea.schinner.phd@warmmail.com	San Francisco	California	6011576199587977863	346e5677b181ea3c94fe1289034cce59	American Express	37.7866505441236455	-122.416545144032014
43055	2020-08-07 11:43:28	2020-08-07	Patti Lind	patti.lind@geemail.com	Houston	Texas	180044866019740150	48a9b7500f487b2e161d258dc10a1ef1	JCB 16 digit	29.7541825180020183	-95.3234691354461035
43056	2020-08-07 11:46:39	2020-08-07	Callie Jaskolski	callie.jaskolski@geemail.com	Newark	New Jersey	4008632242999	4f16a9943c6def9ab31508b6f104995e	JCB 16 digit	40.6695413890674757	-74.0870434595014871
43057	2020-08-07 11:48:38	2020-08-07	Adell Schinner	adell.schinner@warmmail.com	Berkeley	California	3008202176078776	6ce0499e44c3c4da743e33564901f785	VISA 16 digit	37.8489455965276065	-122.30361736696635
43058	2020-08-07 11:54:54	2020-08-07	Wilburn Cruickshank DVM	wilburn.cruickshank.dvm@warmmail.com	Phoenix	Arizona	3096192349032239351	784782eea2e836fee3a4af636a26e5c3	American Express	33.5389832721956083	-112.102148232415701
43059	2020-08-07 11:56:02	2020-08-07	Leatrice Kunde	leatrice.kunde@geemail.com	Berkeley	California	502094832516796	618f418e2d7510b1f9fa80b1b7709855	JCB 16 digit	37.8547888508433132	-122.292510290505874
43060	2020-08-07 11:56:41	2020-08-07	Mr. Juelz Bashirian	mr.juelz.bashirian@warmmail.com	New York	New York	060415299076362	0d46871dedaef197d4adf39315a31d56	Discover	40.6506899261139338	-73.9075389793969606
43061	2020-08-07 12:13:15	2020-08-07	Khiry Block-Fay	khiry.block.fay@geemail.com	Syracuse	New York	3528189384788434695	e501b091f481b30525cce4a86f3e6ba7	Discover	43.0611843631919413	-76.0796130635090293
43062	2020-08-07 12:16:36	2020-08-07	Artis Willms	artis.willms@geemail.com	Irving	Texas	6011294859181777941	5fdce525735bde4ef2bd97817ae1cdf1	VISA 16 digit	32.931465475209805	-96.9585996536817447
43063	2020-08-07 12:21:32	2020-08-07	Doretta Purdy	doretta.purdy@warmmail.com	San Francisco	California	6011636259483987677	9101719947abcb008fc95cdf674ce5d0	VISA 13 digit	37.782970789800892	-122.40824987471386
43064	2020-08-07 12:25:48	2020-08-07	Deryl Zboncak	deryl.zboncak@geemail.com	Los Angeles	California	3112289109221700397	c8511a30eab53bbedd6ebdd4aa5a34d8	Maestro	34.0492449762165492	-118.41009645354859
43065	2020-08-07 12:27:59	2020-08-07	Albertus Leannon-Monahan	albertus.leannon.monahan@warmmail.com	Los Angeles	California	4207310036008963	0f2c84987a6ec560bd0863005a82061a	JCB 16 digit	34.1125636119727034	-118.477882183947784
43066	2020-08-07 12:29:02	2020-08-07	Dr. Eustace Kunze	dr.eustace.kunze@geemail.com	Cleveland	Ohio	501863839955620	574b7f0a0bf449e212b5ea60c86ac807	Discover	41.4047108685448748	-81.6271263269014611
43067	2020-08-07 12:30:15	2020-08-07	Maiya Fahey-Jerde	maiya.fahey.jerde@geemail.com	Milwaukee	Wisconsin	4236579871027461	b3f758af232b63b45714284a21b65011	Mastercard	42.9790394972629812	-88.0527518986359325
43068	2020-08-07 12:32:37	2020-08-07	Firman Baumbach	firman.baumbach@woohoo.com	Kansas City	Missouri	4814592809022249	abb6d1c05b5cf11e1d405ac218572f79	VISA 16 digit	39.2077105198357287	-94.5725082969516535
43069	2020-08-07 12:34:50	2020-08-07	Margret White	margret.white@geemail.com	Chesapeake	Virginia	561201789308390	f2eb598578fedffa2483d385da84b83c	JCB 16 digit	36.6608571959897915	-76.2120548362687202
43070	2020-08-07 12:38:54	2020-08-07	Daryle Watsica	daryle.watsica@geemail.com	Eugene	Oregon	3038595117626037	276c87ecb49431bcf358a8caf9cf30ee	VISA 16 digit	44.0241624056089691	-123.074509951936832
43071	2020-08-07 12:39:34	2020-08-07	Tammie Schaden PhD	tammie.schaden.phd@woohoo.com	New York	New York	4988391981970	f2ffd3bc7cfaea40f9fda0f20c888bd5	Mastercard	40.71703076644242	-73.9671508014097725
43072	2020-08-07 12:44:48	2020-08-07	Dell Dach	dell.dach@geemail.com	Chicago	Illinois	4374363160904777	da184c816fa9fa36447c0f92bdbe8952	VISA 16 digit	41.8289028280716408	-87.6197475997760904
43073	2020-08-07 12:48:23	2020-08-07	Vennie Homenick	vennie.homenick@warmmail.com	Milwaukee	Wisconsin	6011401183402149131	d957380a252f036bb547f22a739aff84	American Express	43.0839320022232783	-88.01341717132442
43074	2020-08-07 12:53:10	2020-08-07	Arvil Mraz	arvil.mraz@warmmail.com	Shreveport	Louisiana	4261782639924924	01fcbec717c58bba1cfa120af11bb291	VISA 16 digit	32.3995535847038028	-93.7722581668503494
43075	2020-08-07 13:06:59	2020-08-07	Clare Hettinger	clare.hettinger@warmmail.com	San Jose	California	6011422226009479610	e0df695314e128ed10bc6ddce6042f6c	American Express	37.2852228110011694	-121.865435552293064
43076	2020-08-07 13:07:43	2020-08-07	Hortensia Thompson	hortensia.thompson@geemail.com	Fort Worth	Texas	4436575727363	292781868477cb95e68aa1f31058c3ae	Maestro	32.8440546188559424	-97.29337705032043
43077	2020-08-07 13:11:04	2020-08-07	Kandace Schroeder	kandace.schroeder@geemail.com	Dallas	Texas	53433256363251831	8fc77e31e6d6cd921acfaad7385612e5	Voyager	32.7729321345958908	-96.866289592251178
43078	2020-08-07 13:18:59	2020-08-07	Julie Upton	julie.upton@geemail.com	Los Angeles	California	3762329861702700	500f43a8f58e672bbabc46f773ba80d7	American Express	34.1114251030474875	-118.454537431336192
43079	2020-08-07 13:31:39	2020-08-07	Myrl Kessler	myrl.kessler@geemail.com	Phoenix	Arizona	3432901179520599	2b719104340d2d2829c3bccb5ac58377	Mastercard	33.5328899009551904	-112.03364915171862
43080	2020-08-07 13:51:32	2020-08-07	Miss Bulah Smith	miss.bulah.smith@warmmail.com	Tucson	Arizona	210052073646367551	ae5cb6017b0afdaac6a16b7e22145b62	Diners Club / Carte Blanche	32.248879226487503	-110.853240732405709
43081	2020-08-07 14:03:29	2020-08-07	Marylin Robel	marylin.robel@geemail.com	Portland	Oregon	3528188511883911133	24392a30edce6a89b96b93bc9ce8797a	JCB 16 digit	45.5044066758714578	-122.577202357724317
43082	2020-08-07 14:03:40	2020-08-07	Mr. Kimberly Tremblay Jr.	mr.kimberly.tremblay.jr.@woohoo.com	Columbia	Missouri	3096837027300986553	9a9fc5788d5308878976fdc060d63722	VISA 16 digit	38.87360986409454	-92.2840293748823086
43083	2020-08-07 14:12:02	2020-08-07	Windy Borer	windy.borer@geemail.com	Los Angeles	California	4983009483865	65e0e946722590a86c68414b7b783221	Discover	34.1094938691105654	-118.353696070145062
43084	2020-08-07 14:12:50	2020-08-07	Blake Toy	blake.toy@geemail.com	San Francisco	California	4796087676410	3bcd15a0e023972b2d6ae8022c6a8585	Discover	37.7816474312283148	-122.417116688118156
43085	2020-08-07 14:25:35	2020-08-07	Payten Hills	payten.hills@warmmail.com	New Orleans	Louisiana	869908914083572754	eab1fcc1b9bf951d7761b521cde11b1d	Discover	30.0838848841857178	-89.9413197548855123
43086	2020-08-07 14:26:06	2020-08-07	Davonte Schroeder DVM	davonte.schroeder.dvm@geemail.com	San Francisco	California	4236100844820658	6a65b2551849fe6a43e8e6b58eeaea30	Discover	37.7651713169584013	-122.441045447745353
43087	2020-08-07 14:28:01	2020-08-07	Adda Smith	adda.smith@geemail.com	Berkeley	California	4387998989995749	a1c4cbfef667381a459155a9d421dc4f	Mastercard	37.8907169806121047	-122.274113578405434
43088	2020-08-07 14:52:50	2020-08-07	Mr. Abdul Hauck III	mr.abdul.hauck.iii@geemail.com	Chicago	Illinois	210027067541755755	131bb324abcd298bacb834ed7c9a17d1	VISA 13 digit	41.7822412902325411	-87.6364135640703097
43089	2020-08-07 14:53:41	2020-08-07	Shane Schuppe	shane.schuppe@geemail.com	Chicago	Illinois	3096060114152189458	75e6d01832882e89c29e8cf38aa1f698	VISA 16 digit	41.9243474151309599	-87.5957767507091063
43090	2020-08-07 14:55:22	2020-08-07	Clementina Weissnat	clementina.weissnat@geemail.com	Riverside	California	4936245494922	7db8418eee7b80eb5034f02427c6ddd7	JCB 15 digit	33.9377503844857173	-117.49066396983973
43091	2020-08-07 15:00:08	2020-08-07	Virgia Carroll	virgia.carroll@warmmail.com	Houston	Texas	3001565589472258	464c8888ce5c286ae65b83b93d938449	JCB 16 digit	29.7948401365973048	-95.4398433877635739
43092	2020-08-07 15:04:10	2020-08-07	Kanesha Hansen	kanesha.hansen@geemail.com	Tucson	Arizona	676352086894350	af43d6d312489ed21077290333f79b4f	JCB 16 digit	32.119313030554359	-110.927783507038271
43093	2020-08-07 15:14:11	2020-08-07	Dr. Tab Douglas	dr.tab.douglas@warmmail.com	Clinton	Michigan	869928407551927556	e6e3c529ebef72a339f3a546909f6461	Voyager	42.6769433071903848	-82.8735228787250833
43094	2020-08-07 15:21:03	2020-08-07	Ms. Aiyanna Schaden	ms.aiyanna.schaden@geemail.com	Cleveland	Ohio	210082916960600474	145662c4e87766076bf70dc074235633	American Express	41.397650613993406	-81.7400005937326739
43095	2020-08-07 15:28:38	2020-08-07	Maureen Rempel	maureen.rempel@woohoo.com	Cincinnati	Ohio	4051819478382	511a06d664957c6829d87e3808eafa32	VISA 16 digit	39.0895090498261126	-84.5845969469558412
43096	2020-08-07 15:33:53	2020-08-07	Mrs. Dione Herman PhD	mrs.dione.herman.phd@geemail.com	San Francisco	California	4067583006541127	8f812f613789b69c08c827913d390f8a	VISA 16 digit	37.8070517825033292	-122.431027394716651
43097	2020-08-07 15:46:24	2020-08-07	Era Johnson PhD	era.johnson.phd@geemail.com	Berkeley	California	630450717373083	1a3d3b693ea47147594a1146d49b3e60	VISA 13 digit	37.8545075308418717	-122.256390568076782
43098	2020-08-07 15:48:48	2020-08-07	Ardyce Thompson	ardyce.thompson@woohoo.com	Tucson	Arizona	4181143650485252	78e81bbaaaeb5b7703e4a1b9cb906590	Discover	32.1453159190755358	-110.822160734491789
43099	2020-08-07 15:57:26	2020-08-07	Bethel Roob	bethel.roob@warmmail.com	Tulsa	Oklahoma	4961173383821438	59f4ed36cdd41952d601cc15cb99862b	JCB 16 digit	36.1932131355997129	-95.8299104046963066
43100	2020-08-07 15:58:12	2020-08-07	Cristian Kautzer	cristian.kautzer@geemail.com	Fort Wayne	Indiana	3050238475951261	36388f09552ecdcfccef3cb5fe220fd3	VISA 13 digit	41.0527261685363953	-85.136715524991601
43101	2020-08-07 16:05:41	2020-08-07	Giovani Pagac-Carroll	giovani.pagac.carroll@woohoo.com	Warren	Michigan	3158238991904652777	61136e1dd4af5bf1313c96e3f4a95ec5	American Express	42.411641342378779	-83.0237246729899283
43102	2020-08-07 16:11:54	2020-08-07	Macarthur Walter	macarthur.walter@geemail.com	Portland	Oregon	869919901785207158	7d6f1be1fbdb01b855711947ef307259	Mastercard	45.58686654394306	-122.645384046807891
43103	2020-08-07 16:13:11	2020-08-07	Ninnie Bruen MD	ninnie.bruen.md@woohoo.com	Boulder	Colorado	6011416200379574076	21fc91040b0eaa0e7d1c4dc441a08ec8	VISA 13 digit	39.9803594590611766	-105.206347946697477
43104	2020-08-07 16:13:25	2020-08-07	Mr. Amasa Mills	mr.amasa.mills@woohoo.com	San Diego	California	3528951494592414555	855ca948c038c423014bb545968b300e	Maestro	32.79692312200293	-117.095928239580246
43105	2020-08-07 16:24:52	2020-08-07	Dr. Kylah Bechtelar MD	dr.kylah.bechtelar.md@geemail.com	New York	New York	3096838839624179999	e36f1fd576a0f7ecaa475108777ecef3	VISA 16 digit	40.7146086289770892	-73.8687523512065383
43106	2020-08-07 16:31:13	2020-08-07	Baby Hammes	baby.hammes@geemail.com	Independence	Missouri	3088716178405676601	419943d30ec4ad412167041436b34f66	Mastercard	39.0221568470839415	-94.3368479911055289
43107	2020-08-07 16:33:16	2020-08-07	Ardeth Larson-Funk	ardeth.larson.funk@geemail.com	Los Angeles	California	3059198752474307	c3c57d5aa31caa67696b74d15e8a802a	VISA 16 digit	34.1186696119006712	-118.457747436733172
43108	2020-08-07 16:41:44	2020-08-07	Vela Anderson	vela.anderson@geemail.com	Vacaville	California	4169174500275391	9720851389b510fd51ffa16d03bcb11f	Voyager	38.3716278217393949	-121.953683591575555
43109	2020-08-07 16:46:08	2020-08-07	Willie O'Hara	willie.o'hara@geemail.com	Cedar Rapids	Iowa	3112966673753286810	78b26d5f6eb413aa08c6d9ca7d1860a2	VISA 16 digit	41.9267968077287065	-91.6757506094008789
43110	2020-08-07 16:51:27	2020-08-07	Baxter Volkman-Skiles	baxter.volkman.skiles@warmmail.com	Dallas	Texas	3419440018413572	27317fc82eebc561fb909f354ecc0338	VISA 13 digit	32.8637472215846174	-96.8273416189439473
43111	2020-08-07 16:53:38	2020-08-07	Clifford Prohaska-Daniel	clifford.prohaska.daniel@woohoo.com	Scottsdale	Arizona	4452756870157955	44d269e0880632313b3c862bfc838d29	VISA 16 digit	33.6045958553563793	-111.798548967201626
43112	2020-08-07 16:59:39	2020-08-07	Allyssa Abshire	allyssa.abshire@geemail.com	Nashville	Tennessee	3042320917466989	4600438e4739348f73cdefd457db2e3f	Voyager	36.2124792813912038	-86.7349159163795349
43113	2020-08-07 17:11:15	2020-08-07	Kelley Cremin	kelley.cremin@geemail.com	San Francisco	California	3337192098547950420	f81aeb48bce04eadaef267ecc295d56c	VISA 16 digit	37.7896304694097935	-122.434553130051867
43114	2020-08-07 17:18:01	2020-08-07	Jade Mitchell	jade.mitchell@woohoo.com	Dallas	Texas	3497559523930948	893426dc7ee27d4d57c547d81033bd76	JCB 15 digit	32.7936088507801315	-96.694003499714654
43115	2020-08-07 17:28:31	2020-08-07	Quentin Lueilwitz DVM	quentin.lueilwitz.dvm@geemail.com	Berkeley	California	53169388966379071	7fb101320b839fa8c1e17dd776aa2fd7	Maestro	37.8501672420126454	-122.278597609064391
43116	2020-08-07 17:28:31	2020-08-07	Lavern Halvorson	lavern.halvorson@warmmail.com	Arvada	Colorado	676284441044827	6d16ddcfa641a1109eda352e70deabce	Maestro	39.8509857040073712	-105.051442180990435
43117	2020-08-07 17:32:31	2020-08-07	Walt Bogan DVM	walt.bogan.dvm@geemail.com	St. Louis	Missouri	3470709532150977	c4fe91300b9d199719af4fc6d66f1ac2	VISA 16 digit	38.6706883137270836	-90.1539771524261795
43118	2020-08-07 17:35:54	2020-08-07	Roxanne Beier	roxanne.beier@geemail.com	Seattle	Washington	3096998531851487114	f3038e2bcdafdb19f10f8de214aef619	JCB 15 digit	47.5903001553304463	-122.341995713712265
43119	2020-08-07 17:36:40	2020-08-07	Lurana Halvorson DDS	lurana.halvorson.dds@warmmail.com	San Antonio	Texas	676152007289573	82131c8f5fc45560ad21feca198da5ed	Maestro	29.5376096779551354	-98.4780729900415963
43120	2020-08-07 17:40:49	2020-08-07	Octave Nitzsche	octave.nitzsche@geemail.com	Charlotte	North Carolina	4553578984700332	8a085e4cd59bfa84d921adea468ebb27	JCB 15 digit	35.1965928048148768	-80.7535321546662601
43121	2020-08-07 17:43:53	2020-08-07	Janene Yundt	janene.yundt@geemail.com	San Francisco	California	6011851262288897271	f4d1da2326884abbe6fdb58505b052c9	VISA 13 digit	37.7697975928419254	-122.44885972247809
43122	2020-08-07 17:52:05	2020-08-07	Park Ullrich	park.ullrich@geemail.com	Gainesville	Florida	210005626971225492	9fb4155cef92842101948c569df6d94d	Diners Club / Carte Blanche	29.7239221741270256	-82.3935251780659001
43123	2020-08-07 17:53:04	2020-08-07	Walton Schroeder	walton.schroeder@geemail.com	Detroit	Michigan	3498505406309295	c9ff72f78d3cb42bad0edaed3715f4e9	JCB 16 digit	42.3561923362705883	-83.1184404754664712
43124	2020-08-07 18:03:27	2020-08-07	Danette West	danette.west@woohoo.com	Dallas	Texas	4193420096219	6edc6b27e66d85d5c2034ecfe063a8bd	VISA 13 digit	32.7146977069593987	-96.7370793021712387
43125	2020-08-07 18:05:45	2020-08-07	Conrad Bechtelar	conrad.bechtelar@geemail.com	Tampa	Florida	3112138336171782934	7b49d20082a85294c72bb090ba942730	VISA 16 digit	28.0344815912771956	-82.4923402595546094
43126	2020-08-07 18:18:20	2020-08-07	Christop Abernathy	christop.abernathy@geemail.com	Washington	District of Columbia	6011947818610621345	fa3b90d5a5ae269b6443619e32a48f2d	American Express	38.8302661198455823	-77.0915314370978706
43127	2020-08-07 18:20:56	2020-08-07	Erik Schuppe	erik.schuppe@warmmail.com	Thousand Oaks	California	3112008426721590411	aecc6d0ed551ac2b26709773f7165b6c	Diners Club / Carte Blanche	34.1166440622687333	-118.807679844871913
43128	2020-08-07 18:23:57	2020-08-07	Dr. Samara Daugherty DDS	dr.samara.daugherty.dds@geemail.com	Arvada	Colorado	3044450435940583	cebc8d83d06ddcf435979b716768b953	Voyager	39.7432129686873381	-105.070899699253218
43129	2020-08-07 18:51:02	2020-08-07	Dr. Eliga Dare	dr.eliga.dare@geemail.com	Salinas	California	3528719799489729946	f22baa53f5e6d9adc908573157e6f79e	JCB 16 digit	36.6228180495321709	-121.674254013615482
43130	2020-08-07 18:53:08	2020-08-07	Ferdinand Stracke	ferdinand.stracke@warmmail.com	Renton	Washington	53454771490066377	1652c3361bcc5cadbefc4bcb361bb58a	Discover	47.5052462633758807	-122.275407129859545
43131	2020-08-07 19:08:21	2020-08-07	Mr. Acy Gibson	mr.acy.gibson@geemail.com	Rochester	New York	4024762895988993	cd45aa14fefe4ffd795c9ea6dfbbd287	JCB 16 digit	43.1500731489133074	-77.6786490452248586
43132	2020-08-07 19:15:42	2020-08-07	Oley Lockman	oley.lockman@geemail.com	Newark	New Jersey	869993576617100794	3454c8b492af4eedb277ad72835d80ff	Voyager	40.6742613127835142	-74.2581358195025558
43133	2020-08-07 19:17:48	2020-08-07	Racquel Block DVM	racquel.block.dvm@geemail.com	Boston	Massachusetts	3048640904766586	9ba83c99da2dd605b632766cc4628f9b	Discover	42.2612497785296313	-70.9727873600971009
43134	2020-08-07 19:27:20	2020-08-07	Lida Schneider	lida.schneider@geemail.com	Elgin	Illinois	4488173262171917	fb3254aade9085b8ee92db5d52183872	JCB 16 digit	42.0333829844187932	-88.3416618081562319
43135	2020-08-07 19:28:31	2020-08-07	Ms. Sheila Hintz PhD	ms.sheila.hintz.phd@woohoo.com	Moreno Valley	California	4190851319120628	261134f1e7d2c00c52389f8d68f84e29	JCB 15 digit	33.9838959007982169	-117.229550991250946
43136	2020-08-07 19:30:47	2020-08-07	Charissa Nader	charissa.nader@warmmail.com	Thousand Oaks	California	869941189941045710	a1bf92c3a510a208cdbe13a830e6809f	Diners Club / Carte Blanche	34.2421108261954075	-118.783584341724222
43137	2020-08-07 19:36:33	2020-08-07	Dr. Tianna Monahan DVM	dr.tianna.monahan.dvm@geemail.com	Waco	Texas	639080310641206	60f349f969264e080e28da36f5077177	VISA 16 digit	31.637570247121527	-97.2421288898345182
43138	2020-08-07 19:39:32	2020-08-07	Fielding Herzog-Padberg	fielding.herzog.padberg@geemail.com	Austin	Texas	55568945991553330	f1d13afc5abbbac692f0dd844502c2cb	Maestro	30.3810434130147087	-97.7161434043902943
43139	2020-08-07 19:39:52	2020-08-07	Lilyan Murray	lilyan.murray@geemail.com	Oakland	California	869959605451723437	cd18199856b0ce89a5a8a47f5af015a2	Discover	37.8194597596872555	-122.251856305050879
43140	2020-08-07 19:44:11	2020-08-07	Dr. Johnson Satterfield	dr.johnson.satterfield@geemail.com	McAllen	Texas	3492449383487491	6cbc92025183d37ab95eb353862c8aa2	JCB 16 digit	26.2137404010470938	-98.165076092475644
43141	2020-08-07 19:49:29	2020-08-07	Miss Jessenia Mosciski MD	miss.jessenia.mosciski.md@warmmail.com	Carrollton	Texas	4206850902787	991f0f9cf68bb918345d2aee1b1888fd	Maestro	33.0540152461189791	-96.8859928713042251
43142	2020-08-07 19:49:51	2020-08-07	Lessie McCullough	lessie.mccullough@geemail.com	Nashville	Tennessee	4609777336508153	65606dedab5c6c7f0bd54ffed46796a9	Diners Club / Carte Blanche	36.1251597333822403	-86.7830118352454178
43143	2020-08-07 19:52:25	2020-08-07	Rigoberto Reichert	rigoberto.reichert@woohoo.com	Meridian	Idaho	639062938948684	1b8cf572fae65266d32d51c2fa14b16e	JCB 16 digit	43.7040475098889303	-116.31796562615186
43144	2020-08-07 20:00:59	2020-08-07	Ms. Carry Schamberger PhD	ms.carry.schamberger.phd@geemail.com	Phoenix	Arizona	501804943928814	74250b254b9f04b44fc3249d31b2e678	Diners Club / Carte Blanche	33.4956403451904663	-112.14269684594349
43145	2020-08-07 20:03:39	2020-08-07	Maegan Leuschke DVM	maegan.leuschke.dvm@warmmail.com	Fort Worth	Texas	4319737071326733	2600b98fa0a8472a6b63075887744210	VISA 13 digit	32.8785632634591352	-97.3564254431340856
43146	2020-08-07 20:06:01	2020-08-07	Newt Kuhlman	newt.kuhlman@geemail.com	Tempe	Arizona	6011712941028340044	bf36ca115d7e714bdd1a7b373f815c05	Diners Club / Carte Blanche	33.4348790147263557	-111.977799946072693
43147	2020-08-07 20:06:12	2020-08-07	Nana Orn-Herman	nana.orn.herman@geemail.com	Los Angeles	California	4076021156389335	77fe59147ce1b438d1b7ea449aaf2e2c	JCB 15 digit	33.9519535330921371	-118.430419974400849
43148	2020-08-07 20:08:21	2020-08-07	Mr. Orley Kerluke	mr.orley.kerluke@geemail.com	Lakewood	Colorado	4647362379519229	0d804f192e679a218526b8ac4711debe	Mastercard	39.6365843374222564	-105.166568319594859
43149	2020-08-07 20:09:37	2020-08-07	Judyth Corwin-Conroy	judyth.corwin.conroy@geemail.com	New York	New York	6011965314073108779	c8afca6bb69b1a9c38a0636dcc9da32b	Diners Club / Carte Blanche	40.6716246358342488	-73.924850079499933
43150	2020-08-07 20:13:23	2020-08-07	Conor Wuckert	conor.wuckert@geemail.com	Garland	Texas	869967212067818592	d288b21dd5c8e252f08fffb862518b88	VISA 13 digit	32.9585699950113877	-96.5725455247491595
43151	2020-08-07 20:21:03	2020-08-07	Marcel Torphy	marcel.torphy@geemail.com	San Francisco	California	210035540757991314	c669453af93e05654d66e496e66f8bbc	JCB 16 digit	37.8047828184695547	-122.465164457596927
43152	2020-08-07 20:21:20	2020-08-07	Cameron Russel	cameron.russel@woohoo.com	Philadelphia	Pennsylvania	4151974221328	f0ce150a13e8d52dfb101150ce1b2cda	Voyager	40.035345867877453	-75.1708709477812107
43153	2020-08-07 20:32:22	2020-08-07	Odis Fisher	odis.fisher@geemail.com	Dallas	Texas	4438921701931239	d94729c18218a4772147cfb780376856	Discover	32.8778465941820315	-96.7452225749809287
43154	2020-08-07 20:39:42	2020-08-07	Yasmeen Zboncak	yasmeen.zboncak@geemail.com	New York	New York	6011411334483355836	5645c21caf5d3d3b3484d12d162647d7	VISA 13 digit	40.7592716387230922	-73.919875492703909
43155	2020-08-07 20:40:10	2020-08-07	Budd Raynor	budd.raynor@geemail.com	San Francisco	California	3727164878347585	39817a43755caf4cba2e9199e89c976b	Discover	37.7622373096732034	-122.445906192248358
43156	2020-08-07 20:48:10	2020-08-07	Benjiman Tromp	benjiman.tromp@geemail.com	San Francisco	California	3158142819874483037	a2095e9f9276ba9fca9e03a26e46fd7d	American Express	37.7925394653983133	-122.410119956964749
43157	2020-08-07 21:04:11	2020-08-07	Norita Dicki	norita.dicki@geemail.com	Philadelphia	Pennsylvania	4799933930598989	335436974c45aa77b65a16305c1f6999	American Express	40.0116900546900922	-75.0742891036339159
43158	2020-08-07 21:06:32	2020-08-07	Nick Schoen	nick.schoen@geemail.com	New York	New York	3012592407013402	a9cd9d64c5ddb6818432ac31554dd7e3	Voyager	40.6201650824155678	-73.9986350622389466
43159	2020-08-07 21:08:43	2020-08-07	Annice Goodwin	annice.goodwin@warmmail.com	New York	New York	4671821189692376	9a52823e2a6bc6de4886ee7726405d89	VISA 16 digit	40.7350781134087612	-73.9318725848931848
43160	2020-08-07 21:22:58	2020-08-07	Orlando Gerhold	orlando.gerhold@geemail.com	Wichita Falls	Texas	3337740462256885721	ff0e3d2ea6bfada3ef40018aa2781139	Mastercard	33.8194264853566864	-98.4896475913390503
43161	2020-08-07 21:32:29	2020-08-07	Bernita Feeney	bernita.feeney@warmmail.com	Oakland	California	676315560284810	f58e13c32e38972a03516147e9dd14ed	Mastercard	37.7587918406256406	-122.273003155914097
43162	2020-08-07 21:38:21	2020-08-07	Donavan O'Reilly	donavan.o'reilly@geemail.com	New York	New York	55595109814294203	cf76343a4e0e4cb347e30dc2e43f11a0	Diners Club / Carte Blanche	40.6286121335104085	-73.9586866360519082
43163	2020-08-07 21:39:15	2020-08-07	Kennth Walter	kennth.walter@woohoo.com	Springfield	Illinois	3767001541462394	a0aefb283e581bcfe8de1ca0054e96b2	VISA 16 digit	39.7177353806015105	-89.6137751115489749
43164	2020-08-07 21:42:54	2020-08-07	Chelsy Prohaska	chelsy.prohaska@woohoo.com	Anchorage	Alaska	869995463285684193	5156bf0be2decb87e54731fb25e1478d	JCB 15 digit	61.2634010970342899	-149.368573022646075
43165	2020-08-07 21:44:24	2020-08-07	Drusilla Crooks	drusilla.crooks@geemail.com	Lincoln	Nebraska	4384947799677255	9dc535e2e98f8fa4ba757564a9cc1527	Maestro	40.7323946492299385	-96.711099985816702
43166	2020-08-07 21:49:01	2020-08-07	Delano Russel	delano.russel@geemail.com	New York	New York	4738175184758	826ea38f3abb2cf2167dd869aec72ce9	VISA 16 digit	40.7629733578525446	-73.8995769513200997
43167	2020-08-07 21:56:55	2020-08-07	Sydnie Hayes	sydnie.hayes@geemail.com	Louisville	Kentucky	060486026061860	3c659f41dfa2292a87e905efab321d1c	Voyager	38.2202348358366635	-85.6654317187216208
43168	2020-08-07 21:57:30	2020-08-07	Miss Katharyn Hilll DVM	miss.katharyn.hilll.dvm@geemail.com	Daly City	California	4731608622205	ea898b094bc5661efea8a8a7c7063e55	Diners Club / Carte Blanche	37.6329528681389931	-122.49235954248347
43169	2020-08-07 21:59:03	2020-08-07	Cappie Prohaska	cappie.prohaska@geemail.com	Fresno	California	3528012879589517815	6430ccb44d37703fab2de5af907268b9	VISA 13 digit	36.7888995016332743	-119.71187182144412
43170	2020-08-07 22:07:59	2020-08-07	Joel Gaylord	joel.gaylord@geemail.com	Philadelphia	Pennsylvania	4431725293281466	d6d4be50208051de11e2f36d36ada5d8	Maestro	40.0033378846436705	-75.1889221962440786
43171	2020-08-07 22:14:50	2020-08-07	Kirby Graham	kirby.graham@woohoo.com	New York	New York	869944896421077198	0381b5166f01cea54559f39ba400d5f6	VISA 16 digit	40.61907827823795	-73.9845813391160192
43172	2020-08-07 22:19:24	2020-08-07	Carlee Howell	carlee.howell@warmmail.com	Philadelphia	Pennsylvania	4573683358853	e2446fcf256b23453dc5fef607aca620	Mastercard	39.9267990044742831	-75.1403007868111246
43173	2020-08-07 22:37:35	2020-08-07	Erich Stark	erich.stark@geemail.com	Rochester	New York	3088750237044253706	1293a1cbf814ec6fb91729d4274b3189	Diners Club / Carte Blanche	43.1417265867792068	-77.5398032145813119
43174	2020-08-07 22:59:59	2020-08-07	Algie Conroy	algie.conroy@geemail.com	Nashville	Tennessee	869980317932955413	45a660e9d48a3d87c4ac2d87ae9ac086	VISA 16 digit	36.1406933055382211	-86.8064194117113885
43175	2020-08-07 23:02:23	2020-08-07	Harper Swaniawski	harper.swaniawski@geemail.com	Jacksonville	Florida	3112007437924332320	04a7c74f4e6e97c92ae7e8bee6534d03	JCB 16 digit	30.2687618330173187	-81.6080771692641207
43176	2020-08-07 23:07:51	2020-08-07	Santana Hamill	santana.hamill@woohoo.com	Bellevue	Washington	4620542102635712	c24185e9f7fb61adeed9a2fd6d4e2de2	VISA 13 digit	47.5960166306417491	-122.07205185364559
43177	2020-08-07 23:16:40	2020-08-07	Tella McKenzie	tella.mckenzie@geemail.com	Torrance	California	4400111646056086	0c0410103ef50fb83cdeb68e7f58f047	Voyager	33.9111781036853799	-118.328940036207058
43178	2020-08-07 23:36:36	2020-08-07	Dr. Daunte Dicki III	dr.daunte.dicki.iii@geemail.com	New York	New York	4908761787062	dd7e38a9905af261ed1f6c5400bd94c5	Discover	40.6577828537430577	-73.9980793636653544
43179	2020-08-07 23:37:38	2020-08-07	Denzel Kihn	denzel.kihn@geemail.com	San Francisco	California	6011276150974007494	47908f3ee5231c2483d549f3e58809e7	JCB 16 digit	37.764222884660029	-122.438077162097969
43180	2020-08-07 23:47:26	2020-08-07	Jean Miller	jean.miller@geemail.com	Phoenix	Arizona	589350420006491	06928de1522985f32c96e326c173f7d7	VISA 16 digit	33.5078040139216924	-112.147683885407076
43181	2020-08-07 23:56:56	2020-08-07	Mr. Winston Hammes Sr.	mr.winston.hammes.sr.@geemail.com	New York	New York	53585640091142873	933d53c8319ab38d9cdf523093e873ff	Mastercard	40.7584704105500109	-74.0219627401687177
43182	2020-08-07 23:57:07	2020-08-07	Nealie Larson	nealie.larson@geemail.com	New York	New York	4909605578063	cc8b4563c18af5c475db226c595450d0	Discover	40.5650986108221119	-73.9151285929500972
43183	2020-08-07 23:59:00	2020-08-07	Antony Kunde	antony.kunde@woohoo.com	North Las Vegas	Nevada	3739787022116856	5cd6fc8375c0e64d4202eeeec3fc6a9e	Diners Club / Carte Blanche	36.2930943794704959	-115.04615101541728
43184	2020-08-08 00:01:10	2020-08-08	Bree Kuhic-Bashirian	bree.kuhic.bashirian@geemail.com	Phoenix	Arizona	3088088749365743274	8fe941622cb3d26ac99991e791bf5efc	JCB 15 digit	33.5305064029458961	-112.053482068555809
43185	2020-08-08 00:01:50	2020-08-08	Demetra Trantow	demetra.trantow@geemail.com	Houston	Texas	3158751203049141055	6bd5fe5d00203dd8809544ad74b78119	Diners Club / Carte Blanche	29.8188022349108017	-95.3778335599709379
43186	2020-08-08 00:07:35	2020-08-08	Dr. Victoria Schmeler	dr.victoria.schmeler@geemail.com	Newport News	Virginia	502035202824989	a0520bc4d0c8003e2411373ef15abac1	Discover	37.1353574875637875	-76.4871419885922279
43187	2020-08-08 00:16:02	2020-08-08	Kyle Jones	kyle.jones@geemail.com	San Francisco	California	869949185111412708	58020e3fdd618945155e2f08345d0244	VISA 16 digit	37.7587664609772844	-122.428935377154062
43188	2020-08-08 00:22:25	2020-08-08	William Heller V	william.heller.v@woohoo.com	Torrance	California	4460948523551888	39d291c6acef88a32703e45b09f44821	VISA 16 digit	33.8096046704705842	-118.42884836174882
43189	2020-08-08 00:33:06	2020-08-08	Mr. Mearl Bauch	mr.mearl.bauch@geemail.com	San Francisco	California	4123191262100000	a61927fc449e1b554926162be6d61a1a	Diners Club / Carte Blanche	37.7331017114986764	-122.455838112997981
43190	2020-08-08 00:35:03	2020-08-08	Brianne Stanton DVM	brianne.stanton.dvm@geemail.com	Gilbert	Arizona	3733945729944220	648fd7ba02f137d7d09ba721f6153392	Diners Club / Carte Blanche	33.2182917976632694	-111.660967865692825
43191	2020-08-08 00:41:25	2020-08-08	Brenna Buckridge	brenna.buckridge@geemail.com	Portland	Oregon	3778556880424872	120c5f46caf919ef729d3c1a0cd3663f	JCB 16 digit	45.4591615754999196	-122.635979803279042
43192	2020-08-08 00:52:35	2020-08-08	Amiya Lebsack	amiya.lebsack@geemail.com	New Haven	Connecticut	6011256679225563461	a49452e2ff1b09ec3891a56b2f6438b2	VISA 16 digit	41.2787591202642759	-72.865913410810748
43193	2020-08-08 00:52:54	2020-08-08	Will Moore	will.moore@geemail.com	New York	New York	3790343135955453	0abdfd2e12ee98bfd4616395b07c5d16	VISA 16 digit	40.7439880915675303	-73.9892525643005996
43194	2020-08-08 00:59:42	2020-08-08	Salina Murazik	salina.murazik@geemail.com	Los Angeles	California	3042187560921010	7b3787016cfed7626eba78501c4994bd	JCB 15 digit	34.0632319694716443	-118.334560908143587
43195	2020-08-08 01:02:32	2020-08-08	Justyn Wintheiser	justyn.wintheiser@warmmail.com	Round Rock	Texas	3038870264236173	837f3d75e5c14e19f4eb99b8263074bf	VISA 16 digit	30.578644026270883	-97.7489365964047607
43196	2020-08-08 01:05:06	2020-08-08	Dariana Wiegand	dariana.wiegand@geemail.com	Los Angeles	California	52038667135750364	2a459a3a8ee49357fe6ad37b80b62813	JCB 16 digit	34.1093183655623307	-118.427510135014728
43197	2020-08-08 01:28:06	2020-08-08	Cyndi Hansen DDS	cyndi.hansen.dds@geemail.com	San Diego	California	501894375582809	af986685cd83b8dc6ba005436d7412fc	JCB 16 digit	32.8062124551340943	-117.189597365530219
43198	2020-08-08 01:40:01	2020-08-08	Florentino Marks Sr.	florentino.marks.sr.@geemail.com	Lewisville	Texas	869991996355359794	583019fbdaf6dd616fd857d2759390ae	Mastercard	33.08348629157841	-97.0726947630319756
43199	2020-08-08 01:50:33	2020-08-08	Dr. Chris Leffler DDS	dr.chris.leffler.dds@warmmail.com	Los Angeles	California	4443130504642497	6461d5b74ec408fbed5c549f36538901	Maestro	33.9848292400926297	-118.34556333492435
43200	2020-08-08 02:00:33	2020-08-08	Mrs. Madelyn Wolff DVM	mrs.madelyn.wolff.dvm@geemail.com	Bakersfield	California	4325187223640	87b4e375517dab619f7e510d9100eecf	Mastercard	35.2681759194180344	-118.988199975368744
43201	2020-08-08 02:02:46	2020-08-08	Graves Gutmann	graves.gutmann@warmmail.com	San Francisco	California	6011756627564203400	a7b90e80fd96580da1399acd6be3d102	Diners Club / Carte Blanche	37.7866186455627613	-122.434006707768845
43202	2020-08-08 02:04:30	2020-08-08	Nikita Streich	nikita.streich@geemail.com	San Francisco	California	4989781063466858	194c4b9008d951a760974ac0c4f14a95	Maestro	37.7224373120599523	-122.413337935544163
43203	2020-08-08 02:13:34	2020-08-08	Darcie Veum	darcie.veum@geemail.com	New York	New York	3088086452303413736	e80c7408b4fc4ca0127f418d500e716a	Voyager	40.618681311955676	-73.9914811286970888
43204	2020-08-08 02:19:24	2020-08-08	Leyla Medhurst MD	leyla.medhurst.md@woohoo.com	Houston	Texas	53575771647090480	79cf6fdbbc896d35ecf20f662fb351f2	JCB 15 digit	29.7763792935371399	-95.4462031519521048
43205	2020-08-08 02:23:03	2020-08-08	Ms. Joana Waelchi DVM	ms.joana.waelchi.dvm@geemail.com	Berkeley	California	502067949444441	a926fc59b83a216de51300bac198f8a4	JCB 15 digit	37.8426828772622557	-122.28633715193132
43206	2020-08-08 02:24:41	2020-08-08	Beckham Bergstrom	beckham.bergstrom@geemail.com	Providence	Rhode Island	3112805362712667006	d90268e7e13d1c2d0ad6f0e25e68831a	Discover	41.8745633051585386	-71.4474530579440312
43207	2020-08-08 02:26:10	2020-08-08	Jaeden Brakus Sr.	jaeden.brakus.sr.@geemail.com	San Francisco	California	3337113193735558956	aee7f79dc62ee389141274dcdd81a18c	Maestro	37.7791841518394023	-122.428573732993826
43208	2020-08-08 02:40:16	2020-08-08	Dequan Wolff DVM	dequan.wolff.dvm@geemail.com	Mobile	Alabama	3088848522956843568	5429a2b396b5e6574537b67f5ee0a3a3	Diners Club / Carte Blanche	30.737558815592525	-88.0609363458257235
43209	2020-08-08 02:41:36	2020-08-08	Dosia Denesik	dosia.denesik@geemail.com	Arlington	Texas	3002621213999239	b52971407a0b90bb41468fec14dfda65	Mastercard	32.7438620705407075	-97.1375800650592964
43210	2020-08-08 02:42:13	2020-08-08	Latoya Reichert-Hackett	latoya.reichert.hackett@geemail.com	Indianapolis	Indiana	6011854304920588269	5183e510177300a9dfc8bf0f885732cf	VISA 16 digit	39.8576338641818566	-86.1328161546230291
43211	2020-08-08 02:57:30	2020-08-08	Mrs. Nealie Hauck	mrs.nealie.hauck@geemail.com	Baltimore	Maryland	3461198448900892	5ba7e6ba48e8a65ec5b0c5927caec433	VISA 16 digit	39.2360353531781527	-76.5489975991211793
43212	2020-08-08 03:06:01	2020-08-08	Ettie Howell	ettie.howell@geemail.com	Columbus	Georgia	3088879891881709018	06043e52c5b912d47f9aa9cb3e5e8be7	Diners Club / Carte Blanche	32.4715040502648762	-84.8991027792148287
43213	2020-08-08 03:14:40	2020-08-08	Lulu Hegmann	lulu.hegmann@geemail.com	Cincinnati	Ohio	6011705245493101553	70ff709468b9527c21c4a03505e537da	JCB 16 digit	39.220873151509835	-84.5702487407058356
43214	2020-08-08 03:24:16	2020-08-08	Dr. Less Funk Sr.	dr.less.funk.sr.@warmmail.com	Miami	Florida	180012034413924411	ff1c825ef04845a6f24bb82b7c3a5d62	JCB 16 digit	25.7817232328604931	-80.2666934918485566
43215	2020-08-08 03:32:27	2020-08-08	Clella Brakus	clella.brakus@geemail.com	Lexington	Kentucky	4254586193553444	fb3b1b78a7bef48915ca2bda968e26a7	VISA 16 digit	37.9865181821275542	-84.4807942363332955
43216	2020-08-08 03:35:19	2020-08-08	Ebert Borer	ebert.borer@woohoo.com	Portland	Oregon	51030026296147357	a513d2d10fe7dbac24091d2d6e3c12e6	JCB 16 digit	45.5543377163242553	-122.667660606233412
43217	2020-08-08 03:37:28	2020-08-08	Edrie Walsh	edrie.walsh@geemail.com	Arlington	Texas	869997705906768674	ca719a9a212979c6f0ad06bb542aff96	Mastercard	32.6601332189299143	-97.1243910346206292
43218	2020-08-08 03:42:30	2020-08-08	Kennedy Ferry DDS	kennedy.ferry.dds@geemail.com	Tyler	Texas	869923812136997245	006117e189f99f363003d14096a079be	Diners Club / Carte Blanche	32.2355586271315815	-95.2850739918291509
43219	2020-08-08 03:45:31	2020-08-08	Dexter Blanda	dexter.blanda@geemail.com	Miramar	Florida	3528345099526774142	f200a40ec453c62387e6aa51315b6d15	JCB 16 digit	26.0430362629219907	-80.3004666747517888
43220	2020-08-08 03:55:51	2020-08-08	Dr. Alvaro Hermiston II	dr.alvaro.hermiston.ii@geemail.com	Moreno Valley	California	52027196103973124	2caf5822b718a6d16db05086f36da45c	Voyager	33.9190875197753314	-117.157896601126339
43221	2020-08-08 04:03:43	2020-08-08	Adrianne Goodwin DDS	adrianne.goodwin.dds@geemail.com	New York	New York	3784892476895890	a5d379f7e7fcb551e35482eafdfa5291	VISA 13 digit	40.6437663386799386	-73.9149294636573586
43222	2020-08-08 04:06:53	2020-08-08	Jens Marquardt	jens.marquardt@geemail.com	Irvine	California	3112651956584323088	4cd7bb37f99f5cfc6c810a8df4b92317	Discover	33.7569807595122668	-117.838260017988461
43223	2020-08-08 04:06:53	2020-08-08	Ara Torp DDS	ara.torp.dds@woohoo.com	Philadelphia	Pennsylvania	3047362546817419	141ff6acabd53d8fbef824901fe3b3d4	VISA 16 digit	40.023246327271309	-75.1375617613915381
43224	2020-08-08 04:11:09	2020-08-08	Kittie Doyle	kittie.doyle@woohoo.com	Alexandria	Virginia	6011780296401382445	3d67d69732395e110351fb63e4ee248d	JCB 16 digit	38.9125036456271971	-77.018263158200682
43225	2020-08-08 04:17:55	2020-08-08	Erasmus Bechtelar	erasmus.bechtelar@warmmail.com	Boulder	Colorado	180054624479392575	22f438c466a2f27c51ec660a1485b012	Voyager	39.992080068306997	-105.33756120187752
43226	2020-08-08 04:22:56	2020-08-08	Merrily Wisozk	merrily.wisozk@geemail.com	Jacksonville	Florida	4910712067819333	c87c4bbaa946f9374540d672f1ee05ca	JCB 16 digit	30.3306819256447255	-81.7084334522564006
43227	2020-08-08 04:27:04	2020-08-08	Carrol Weber	carrol.weber@warmmail.com	Austin	Texas	3006368438841905	e76d62f955f9181922288f36a4c9e64a	American Express	30.261587185984105	-97.7588824003241967
43228	2020-08-08 04:35:33	2020-08-08	Ms. Noemie Schulist	ms.noemie.schulist@geemail.com	Houston	Texas	4221016384903	e4242e7277a3091e74c17cc18fa84d88	JCB 15 digit	29.7835211290124811	-95.3640007583905032
43229	2020-08-08 04:40:01	2020-08-08	Tiarra Lockman	tiarra.lockman@geemail.com	Philadelphia	Pennsylvania	3112483730606070330	378165877d4affcd41993112ee600834	Mastercard	39.9583848616998623	-75.1550146629002001
43230	2020-08-08 04:46:28	2020-08-08	Shane Gibson	shane.gibson@geemail.com	San Francisco	California	3487966027294568	f4df2553b604969d68e067381cce4a96	VISA 16 digit	37.7538189198337264	-122.475679049899938
43231	2020-08-08 04:56:55	2020-08-08	Crissie Hamill	crissie.hamill@geemail.com	San Francisco	California	3400642799322234	998f375f7e1673a077e02ada80bc231e	VISA 16 digit	37.802283296741038	-122.439783602302739
43232	2020-08-08 05:01:12	2020-08-08	Deforest Jaskolski	deforest.jaskolski@woohoo.com	Daly City	California	3055297648253877	78e63853813943e761a9a849641ba488	Maestro	37.6119199487768086	-122.382929807119069
43233	2020-08-08 05:21:00	2020-08-08	Keenan Emmerich	keenan.emmerich@geemail.com	Virginia Beach	Virginia	869924007493640376	ae95b6b7c388b380bab5cd4a31669500	VISA 13 digit	36.7978584780078393	-75.977795470752568
43234	2020-08-08 05:21:21	2020-08-08	Opha Effertz-Streich	opha.effertz.streich@geemail.com	Portland	Oregon	639007896242588	7f46b959f2c4edf101cd4799f0ff4f67	Maestro	45.591587270366027	-122.591762888571253
43235	2020-08-08 05:31:59	2020-08-08	Mrs. Micaela Runolfsson PhD	mrs.micaela.runolfsson.phd@warmmail.com	Oakland	California	3112353586873585807	7b970ff83c3278618d5595c4aadcf87e	Diners Club / Carte Blanche	37.7731044090981456	-122.292332037055189
43236	2020-08-08 05:35:45	2020-08-08	Marietta Moen	marietta.moen@geemail.com	Fremont	California	4193481958083	e3a341715c02fea0ddde1c99222d2881	JCB 16 digit	37.4023362486325226	-121.870963931501649
43237	2020-08-08 05:36:30	2020-08-08	Bethzy Tromp	bethzy.tromp@geemail.com	El Paso	Texas	639022064682804	4377ab17ad19728002a0c5e46a20c432	Maestro	31.865734527103232	-106.41677331938223
43238	2020-08-08 05:38:06	2020-08-08	Nikolai Bechtelar	nikolai.bechtelar@geemail.com	Coral Springs	Florida	210024395146703778	3619aeffc93aee59225ffbadfba013d9	Diners Club / Carte Blanche	26.3444640608102105	-80.2857446771238017
43239	2020-08-08 05:41:56	2020-08-08	Carmen Mayer	carmen.mayer@geemail.com	Providence	Rhode Island	3027489554869121	38fccb023256a3544c642d2de55ff85d	Diners Club / Carte Blanche	41.7321916051994961	-71.4876829676713896
43240	2020-08-08 05:45:52	2020-08-08	Victoria Crooks	victoria.crooks@woohoo.com	San Francisco	California	3489274982119955	c8f2deedf83614dbc906e97cbf3f53ac	VISA 13 digit	37.7901197164203921	-122.447809761952129
43241	2020-08-08 05:47:50	2020-08-08	Dewey Jacobs V	dewey.jacobs.v@woohoo.com	Tucson	Arizona	4418192500934741	81044d63bf53b7eed2ace7664f30ed4b	JCB 16 digit	32.1254105998244128	-110.929401800943907
43242	2020-08-08 05:49:33	2020-08-08	Kimberlee Gislason	kimberlee.gislason@warmmail.com	Memphis	Tennessee	4346474375670221	92b04babe642a5c1d567d80029e74045	JCB 16 digit	35.0663620397049982	-90.0395857745107264
43243	2020-08-08 05:51:48	2020-08-08	Sharon Batz	sharon.batz@geemail.com	San Antonio	Texas	3088050533048515067	e53c332ce0a08328accce7c56ab62896	VISA 13 digit	29.5135796422209609	-98.4377051162835102
43244	2020-08-08 05:52:06	2020-08-08	Miss Shanna Hermiston	miss.shanna.hermiston@warmmail.com	Santa Rosa	California	4528761734623	2e4e98263dcb2977d1b0719d7d3ac995	Diners Club / Carte Blanche	38.519742696278918	-122.740935228463641
43245	2020-08-08 05:53:34	2020-08-08	Babyboy Fritsch PhD	babyboy.fritsch.phd@warmmail.com	Berkeley	California	210059728275097190	e331c72c56c7be48d4f498a29fb25b75	VISA 13 digit	37.9026589735041526	-122.251975338883199
43246	2020-08-08 06:06:04	2020-08-08	Dr. Chace Hettinger III	dr.chace.hettinger.iii@geemail.com	Houston	Texas	4219917650262852	0ff31f1f81dc6201232d55ec9952e2b9	JCB 15 digit	29.7226452307853855	-95.3789389447789659
43247	2020-08-08 06:06:06	2020-08-08	Gene Jacobson	gene.jacobson@geemail.com	Renton	Washington	4594662616277	f8234eb925c77e28f3a638f5d29aeda3	American Express	47.4067947006378319	-122.229939087022089
43248	2020-08-08 06:09:03	2020-08-08	Dr. Hazen Rolfson Sr.	dr.hazen.rolfson.sr.@geemail.com	San Francisco	California	4235425201080542	d6d089ba9ef649c2f8ae35a4ed0bd9af	Mastercard	37.7610434854092816	-122.463256365803559
43249	2020-08-08 06:10:33	2020-08-08	Dr. Josiah Effertz DVM	dr.josiah.effertz.dvm@geemail.com	Alexandria	Virginia	869932207720054728	3ab78bf1851c511e29df3895ac13e42b	VISA 16 digit	38.8938427782267269	-77.0824583854511474
43250	2020-08-08 06:10:36	2020-08-08	Dr. Kenya Quitzon PhD	dr.kenya.quitzon.phd@geemail.com	San Francisco	California	869942495517208072	5afdba83a3d034ee7401d75751b80b1d	JCB 16 digit	37.7853580744372124	-122.426335357345508
43251	2020-08-08 06:12:54	2020-08-08	Dr. Edmonia McGlynn DDS	dr.edmonia.mcglynn.dds@warmmail.com	Washington	District of Columbia	4957859935786204	45e99122cfd004944ac56d87ea6b1621	Discover	38.9662545862406517	-77.0445209738545174
43252	2020-08-08 06:24:13	2020-08-08	Val Harber	val.harber@geemail.com	Chicago	Illinois	3096035192824260867	560f87fb122d2563ea4c05074e3bd228	American Express	41.8615761542063254	-87.7369695543806927
43253	2020-08-08 06:33:21	2020-08-08	Manerva Abernathy	manerva.abernathy@geemail.com	Oakland	California	3026129063590443	1d4e41793b832e26eb1be6c4f9552867	Maestro	37.752797626043737	-122.225097404385892
43254	2020-08-08 06:38:24	2020-08-08	Jazmyne Hagenes	jazmyne.hagenes@woohoo.com	Berkeley	California	3158500199160036286	4a3e133425c2c76bdaea362168fa7cdb	Maestro	37.851227375336002	-122.269778020201983
43255	2020-08-08 07:05:17	2020-08-08	Orlena Lindgren	orlena.lindgren@warmmail.com	Omaha	Nebraska	3025699777796271	3dccae7f5d0741df9bff697390c7895b	JCB 16 digit	41.3288852116704035	-96.1125109105020812
43256	2020-08-08 07:06:09	2020-08-08	Millard Smitham	millard.smitham@woohoo.com	El Cajon	California	4492977464255912	84dfa1e3ae57d884254ff82022bc382e	JCB 16 digit	32.7769147738821758	-116.99583542828411
43257	2020-08-08 07:10:56	2020-08-08	Mr. Henry Raynor	mr.henry.raynor@geemail.com	San Bernardino	California	3088664252729123400	f81609aff36241ac0917401fc6294868	Discover	34.2066007829535721	-117.332410179335994
43258	2020-08-08 07:12:13	2020-08-08	Alex Pfannerstill DDS	alex.pfannerstill.dds@geemail.com	Gainesville	Florida	3016346021635249	0d3eff35912601135d45cea355a44103	JCB 15 digit	29.7003927328914408	-82.389811231416104
43259	2020-08-08 07:27:46	2020-08-08	Mittie Wolff	mittie.wolff@geemail.com	San Antonio	Texas	210088785092040253	ca06aab49a8069fd01ee27ceff730346	JCB 16 digit	29.419454575895891	-98.4730837808292279
43260	2020-08-08 07:31:29	2020-08-08	Jennings Abbott	jennings.abbott@woohoo.com	Pompano Beach	Florida	869949565317388184	182880b0baab2cee8c4bee5d0333645a	Discover	26.294697052592781	-80.1442380180895242
43261	2020-08-08 07:32:42	2020-08-08	Ebony Kovacek	ebony.kovacek@geemail.com	San Francisco	California	3158082720896090267	efae0bc7a95a6f582b5b6953333c3020	VISA 13 digit	37.7502244008974586	-122.434030861594067
43262	2020-08-08 07:33:11	2020-08-08	Dr. Arnoldo Jacobs	dr.arnoldo.jacobs@geemail.com	North Las Vegas	Nevada	6011398357656139361	98a61dadfe405371951ad45ef2541194	JCB 16 digit	36.2927427852217122	-115.019704106192663
43263	2020-08-08 07:38:39	2020-08-08	Eden Dibbert	eden.dibbert@geemail.com	Tacoma	Washington	4713931725185890	2db801d2e33170d9d83ca140d8a8341f	Discover	47.27159268438146	-122.545600755582754
43264	2020-08-08 07:52:16	2020-08-08	Kandy Ryan PhD	kandy.ryan.phd@geemail.com	Minneapolis	Minnesota	639047387786172	f0784f9bd7354bfe62188e3b052134ee	JCB 16 digit	44.9933997088197586	-93.3423967096760805
43265	2020-08-08 07:53:38	2020-08-08	Chadwick Bashirian	chadwick.bashirian@woohoo.com	Oakland	California	3042721117376235	03f575102eca676fe629576c326edb99	Voyager	37.8208690703501986	-122.294090569176817
43266	2020-08-08 07:57:32	2020-08-08	Norwood Schneider	norwood.schneider@geemail.com	Houston	Texas	3799423304185024	5b323fd22540a02a4e0d0aa1872125d3	Diners Club / Carte Blanche	29.7682350192297243	-95.367124871259179
43267	2020-08-08 08:03:13	2020-08-08	Ms. Clementine Dooley	ms.clementine.dooley@geemail.com	Berkeley	California	4893751858588	7da0eb88dc5f78783ef5e111fd0ba5be	VISA 16 digit	37.8857162638678915	-122.233113873714387
43268	2020-08-08 08:04:35	2020-08-08	Geneva Kreiger-Greenfelder	geneva.kreiger.greenfelder@geemail.com	Palm Bay	Florida	4503084514176	c82fa76ab6cb4ee6533950e1ef23be7b	American Express	28.0756399035308526	-80.7230247282259086
43269	2020-08-08 08:05:48	2020-08-08	Beecher Flatley	beecher.flatley@warmmail.com	Norman	Oklahoma	3112319876860308864	2e1d71db4492466c4ad02c662d93916f	Diners Club / Carte Blanche	35.1889981040772071	-97.342002633192763
43270	2020-08-08 08:09:01	2020-08-08	Haylee Labadie	haylee.labadie@warmmail.com	Houston	Texas	3781861051963236	73bc9b32e399610b5f4f7561edf55566	JCB 16 digit	29.7058414610180996	-95.3611482085674993
43271	2020-08-08 08:17:36	2020-08-08	Mrs. Ayla Hagenes DDS	mrs.ayla.hagenes.dds@geemail.com	Phoenix	Arizona	51449990139906268	d92afbbd0af6bb974f2de1fb899549f1	JCB 16 digit	33.5397547853112243	-112.152986704131962
43272	2020-08-08 08:18:46	2020-08-08	Araceli Koepp	araceli.koepp@geemail.com	Berkeley	California	869938001465441354	9baf76be761a55c828f42beb87314f27	Mastercard	37.8484756257739292	-122.248680763824339
43273	2020-08-08 08:23:19	2020-08-08	Sydney Welch	sydney.welch@warmmail.com	San Francisco	California	3495241558959173	724f2c67f52da413689ae5494b8a750e	Discover	37.7584881095153122	-122.431492306474695
43274	2020-08-08 08:34:49	2020-08-08	Jacquline Lind	jacquline.lind@geemail.com	San Diego	California	3112455152827408799	3aeb4e7938930d53143a2a76ef94592d	Voyager	32.8954535797305425	-117.143748854091399
43275	2020-08-08 08:36:18	2020-08-08	Corry Marvin-Effertz	corry.marvin.effertz@woohoo.com	Lubbock	Texas	4696021338890515	a53843cb2011648538fbc1d92e0099a1	JCB 16 digit	33.6151564430486474	-101.815347754201667
43276	2020-08-08 08:36:34	2020-08-08	Edwina Rodriguez-Hilll	edwina.rodriguez.hilll@geemail.com	Chicago	Illinois	3005362205048720	6e0a8e885abe3ca4c0e13494207235ce	Mastercard	41.8664830626290296	-87.6537481188803866
43277	2020-08-08 08:41:23	2020-08-08	Halle Parisian	halle.parisian@geemail.com	Philadelphia	Pennsylvania	3056303009181175	220148f80fb96149ce0c49f64455cb45	Diners Club / Carte Blanche	40.0871902521658683	-75.1767088977985196
43278	2020-08-08 08:43:39	2020-08-08	Braylon Kuhic	braylon.kuhic@warmmail.com	New Haven	Connecticut	869926386673357615	476e8ea5984cc61be473c888e627d21f	JCB 15 digit	41.3179934310719403	-72.9147984068840742
43279	2020-08-08 08:52:49	2020-08-08	Tyreek Anderson	tyreek.anderson@geemail.com	Pomona	California	3024266917815162	7540be7de893b03e105f63c82e5301f2	Voyager	34.0436564834825717	-117.766845098600157
43280	2020-08-08 09:02:41	2020-08-08	Ms. Eryn Bayer MD	ms.eryn.bayer.md@warmmail.com	Torrance	California	4281947601319843	c1f939b7cc280ed94d6297c9b8d00c4d	Voyager	33.750153222857044	-118.34624328512102
43281	2020-08-08 09:04:59	2020-08-08	Dolphus Fritsch	dolphus.fritsch@geemail.com	San Francisco	California	561261878789611	7f80221c4ae6fe7cf7a749c47a3f56e0	VISA 13 digit	37.8037037289281344	-122.401677841150558
43282	2020-08-08 09:09:45	2020-08-08	Lillard Heathcote	lillard.heathcote@geemail.com	Boise	Idaho	4691236843120464	22e1a2ae4bbad7789a9a57cced72579e	American Express	43.5847748949795957	-116.229909533235059
43283	2020-08-08 09:12:11	2020-08-08	Sebrina Armstrong-Kuphal	sebrina.armstrong.kuphal@warmmail.com	Roseville	California	503821580842033	9d81b89b7d21a2055f368cb7b0da353f	JCB 15 digit	38.7316670479308769	-121.360968289266893
43284	2020-08-08 09:18:46	2020-08-08	Ethie Streich	ethie.streich@geemail.com	New York	New York	6011856456897069026	8024202df0ef876a3e17d9a5a3a9444d	VISA 16 digit	40.7476736854985333	-73.922416670610005
43285	2020-08-08 09:19:56	2020-08-08	Dr. Kolton Botsford	dr.kolton.botsford@warmmail.com	New York	New York	869995411485494012	c599a17618cb7efab17f73b94297cd2e	Diners Club / Carte Blanche	40.5930507071539779	-73.8665385710436766
43327	2020-08-08 14:08:46	2020-08-08	Konnor Hansen	konnor.hansen@geemail.com	San Francisco	California	4361229652407014	25e9a42af45052da6f47311f900fcc17	Maestro	37.7762355777081851	-122.406060239456849
43286	2020-08-08 09:22:53	2020-08-08	Ms. Sharla Price	ms.sharla.price@warmmail.com	Las Vegas	Nevada	6011802968240115574	a9006a273a70be7ee3e5243b0dcfa7a3	Diners Club / Carte Blanche	36.2797615876521888	-115.247203176815432
43287	2020-08-08 09:28:31	2020-08-08	Brantley Halvorson	brantley.halvorson@woohoo.com	Los Angeles	California	3088527186066267338	ab138e3536717e7fe31e2f3f85fef8c5	JCB 16 digit	33.9734468636434528	-118.3474950736381
43288	2020-08-08 09:28:34	2020-08-08	Osa Walsh	osa.walsh@woohoo.com	San Francisco	California	3096793961366334484	661f2462396dec60af9e2cd912509af2	JCB 16 digit	37.7937525136915795	-122.436187742575754
43289	2020-08-08 09:31:49	2020-08-08	Dorla Schamberger	dorla.schamberger@geemail.com	Bakersfield	California	501804078501063	2cef352d85f81161052c719d5b7565ce	JCB 16 digit	35.27740336779393	-119.020435551348328
43290	2020-08-08 09:37:40	2020-08-08	Braedon Swift-Mitchell	braedon.swift.mitchell@warmmail.com	New York	New York	53286742743556872	a966ddbf3418298091748b385e3a4184	VISA 13 digit	40.75457726602815	-73.9507676121208846
43291	2020-08-08 09:49:21	2020-08-08	Graham Wunsch	graham.wunsch@geemail.com	Birmingham	Alabama	3112467711809982893	3e324b454309e296eacb7c9ae484206a	VISA 16 digit	33.431893744019419	-86.7743388078417723
43292	2020-08-08 10:07:29	2020-08-08	Kerrie Nikolaus	kerrie.nikolaus@geemail.com	New York	New York	4038557845543359	d9672be466dfff90735a54e6afe8bd2b	Maestro	40.5738979214094542	-73.9371481912571937
43293	2020-08-08 10:19:09	2020-08-08	Alvy Hettinger-Schiller	alvy.hettinger.schiller@warmmail.com	Hialeah	Florida	4287402756749745	2c730be7f7c839f90f441010c5dd024c	JCB 16 digit	25.936078027912977	-80.254646531622484
43294	2020-08-08 10:30:14	2020-08-08	Kacie Ortiz DDS	kacie.ortiz.dds@geemail.com	St. Petersburg	Florida	3481914654075732	7a4a4b9afe0f3b901fbf55f76e4174d4	Voyager	27.6993010650277149	-82.5763663604747506
43295	2020-08-08 10:32:04	2020-08-08	Dr. Lucious Grady DVM	dr.lucious.grady.dvm@geemail.com	Joliet	Illinois	54035119010401484	bf0b155ee5960678a0180e435d5c3c89	VISA 16 digit	41.4690631819747395	-88.1741352145198647
43296	2020-08-08 10:50:55	2020-08-08	Rice Willms	rice.willms@woohoo.com	Boston	Massachusetts	3112927765138918568	659fd802721ebf062c4a29cfaa3c345e	JCB 16 digit	42.3128786333538613	-71.0638422272585331
43297	2020-08-08 10:54:07	2020-08-08	Kale Green-Roberts	kale.green.roberts@warmmail.com	Portland	Oregon	4189334132508959	3d68024cfb6c7e12675cdcdf193561a7	VISA 16 digit	45.4627201804313827	-122.571777849877265
43298	2020-08-08 10:59:25	2020-08-08	Alline Labadie	alline.labadie@geemail.com	Newark	New Jersey	3528561589861232745	11a9363e43b436e3a90e68645c2dcbca	Discover	40.7217872622337254	-74.2643632559314426
43299	2020-08-08 11:04:00	2020-08-08	Margeret Volkman	margeret.volkman@geemail.com	Pittsburgh	Pennsylvania	180061583115645013	992b362bbdd4cbbe3e83f564a645f3d9	JCB 16 digit	40.3629348610948782	-79.9233038160655695
43300	2020-08-08 11:08:58	2020-08-08	Mrs. Evelyne Keebler DVM	mrs.evelyne.keebler.dvm@woohoo.com	Los Angeles	California	180023391993111513	643377e4980090448d4bf5e98dcad648	Mastercard	33.9239872354879921	-118.436892963339758
43301	2020-08-08 11:16:05	2020-08-08	Affie Dooley	affie.dooley@geemail.com	Dallas	Texas	55820099443424361	141faa1e45ded9caf02782dbc7def03e	VISA 13 digit	32.7608314489286414	-96.712906238619226
43302	2020-08-08 11:24:52	2020-08-08	Dennie Lindgren	dennie.lindgren@geemail.com	McKinney	Texas	4028609362720159	c549c8a83b4000efcf8e83322f9c0245	Diners Club / Carte Blanche	33.2275099445730504	-96.6399433839898592
43303	2020-08-08 11:26:18	2020-08-08	Hazelle Huels-Hettinger	hazelle.huels.hettinger@geemail.com	Raleigh	North Carolina	3004112455008184	212225dd9fe88710631a5fca35e35cc0	VISA 16 digit	35.8395805737603439	-78.6370311180066324
43304	2020-08-08 11:27:06	2020-08-08	Enola Ernser	enola.ernser@geemail.com	San Antonio	Texas	4560097825545070	0da7b25010a57f76633085b726761e2f	VISA 16 digit	29.5631331565395001	-98.6234884754125005
43305	2020-08-08 11:42:44	2020-08-08	Laquan Moen-Hahn	laquan.moen.hahn@geemail.com	Modesto	California	3038653027321221	19d7d101aebd93e67dbd2cb04622dc84	American Express	37.5515001977328211	-121.099022568969062
43306	2020-08-08 11:50:53	2020-08-08	Russel Cartwright PhD	russel.cartwright.phd@geemail.com	Los Angeles	California	869930807999838735	2d39d9df3ea566b51ec82a294d7ceeb7	JCB 16 digit	34.1124288103874775	-118.466354628977541
43307	2020-08-08 11:51:02	2020-08-08	Francisco Cassin PhD	francisco.cassin.phd@geemail.com	Macon	Georgia	4420144169622121	3f4ef8818bf88039903d60ea457e13a5	Voyager	32.8275709468416821	-83.7097359377618773
43308	2020-08-08 11:54:27	2020-08-08	Miss Ashleigh Dibbert PhD	miss.ashleigh.dibbert.phd@geemail.com	Philadelphia	Pennsylvania	3004474663742909	d010485f49c6c32bb95366b314ff3f11	Mastercard	40.062461093762515	-75.0960066969405915
43309	2020-08-08 12:00:08	2020-08-08	Odin Batz	odin.batz@geemail.com	San Antonio	Texas	3029946035343503	7b51be77e762d580b57ada84d9613745	VISA 16 digit	29.4684899479687203	-98.5540600005839025
43310	2020-08-08 12:21:31	2020-08-08	Georgeann Kuhic	georgeann.kuhic@geemail.com	Akron	Ohio	3011818992290670	5c94366a348179ec410fe2a282b38a2c	VISA 16 digit	41.1696682362183921	-81.5917176476992694
43311	2020-08-08 12:26:18	2020-08-08	Gladys Powlowski	gladys.powlowski@geemail.com	Columbus	Ohio	3112411864370197644	808f476b57cbeb26063d2615250f2bca	VISA 13 digit	40.053995387493444	-82.988422269956402
43312	2020-08-08 12:29:18	2020-08-08	Clemens Auer	clemens.auer@warmmail.com	New York	New York	4216394835158749	882c6c6e05afe3a0fbc11a7b37206066	American Express	40.59358101526648	-73.931239950087658
43313	2020-08-08 12:29:44	2020-08-08	Trish Sauer	trish.sauer@geemail.com	Oakland	California	4357051809162	dfd9554de4088dbb8d0a4f51c84c4d61	Voyager	37.8014881000045406	-122.255842716591275
43314	2020-08-08 12:55:13	2020-08-08	Sheri McClure DVM	sheri.mcclure.dvm@geemail.com	Nashville	Tennessee	6011937622319571237	3fde7c5239c0c1ed902bf136f8b805f6	Mastercard	36.1508750668849785	-86.7987329970020767
43315	2020-08-08 12:58:51	2020-08-08	Geno Schroeder DVM	geno.schroeder.dvm@geemail.com	Chicago	Illinois	630448055488042	ef8d51f7c1134c6c921061364d0efa0a	VISA 16 digit	41.8620412286207113	-87.6519030652970059
43316	2020-08-08 13:00:51	2020-08-08	Ahmad Tremblay	ahmad.tremblay@geemail.com	Reno	Nevada	3528842219942106327	40516e11e296f959a08b0847535d80b4	Diners Club / Carte Blanche	39.5338335712984232	-119.76508246298657
43317	2020-08-08 13:04:34	2020-08-08	Dawne Haley	dawne.haley@geemail.com	Boise	Idaho	3112312711723658709	e01b47cb3228352ad119d02f1a0c01b5	VISA 16 digit	43.5144522919923062	-116.234575455282638
43318	2020-08-08 13:10:52	2020-08-08	Norah Wiegand DDS	norah.wiegand.dds@geemail.com	Yonkers	New York	4122201220695537	538263d7819c46c502de23205182e2f5	Maestro	40.9912135658986898	-73.833628043753663
43319	2020-08-08 13:29:25	2020-08-08	Dillard Kunde	dillard.kunde@geemail.com	Memphis	Tennessee	3046117613475843	f10a708bdf1d069b215d7c529e03cd35	VISA 16 digit	35.0827385571386685	-89.9993809053465696
43320	2020-08-08 13:33:08	2020-08-08	Tessie Johnston PhD	tessie.johnston.phd@geemail.com	New Haven	Connecticut	4136072839949	a9958c6f1e84e25a4b3f17496621001a	JCB 15 digit	41.2702189735129465	-72.9253761040978077
43321	2020-08-08 13:35:22	2020-08-08	Bethzy Durgan DDS	bethzy.durgan.dds@geemail.com	Stamford	Connecticut	869970507093686201	d2a808642b90d09bdb37a2955021357b	Diners Club / Carte Blanche	41.0902324124123908	-73.4656687055751689
43322	2020-08-08 13:35:26	2020-08-08	Asa Renner III	asa.renner.iii@geemail.com	Winston–Salem	North Carolina	3040935363077675	9e59f055413b9e05ad097744b71909dc	Mastercard	36.1817772989857929	-80.1749771651010974
43323	2020-08-08 13:52:52	2020-08-08	Campbell Schroeder	campbell.schroeder@geemail.com	Phoenix	Arizona	3337730331782590281	8d4c923fd809a1de18ceceffe1cdcff6	JCB 16 digit	33.5281585238806912	-112.077108020514629
43324	2020-08-08 13:58:04	2020-08-08	Aleck Kerluke	aleck.kerluke@warmmail.com	Baltimore	Maryland	53464659625488459	af3fe16cd5ea30ab57420ec9f91cc592	Maestro	39.2760801498312446	-76.6148924888595957
43325	2020-08-08 13:59:09	2020-08-08	Hudson O'Hara	hudson.o'hara@geemail.com	Temecula	California	3036795406401470	bfc42c2d08e88a049db9bf567e48bdc2	VISA 13 digit	33.5331376484263686	-117.228462708621095
43326	2020-08-08 14:00:21	2020-08-08	Domingo Heaney	domingo.heaney@geemail.com	San Francisco	California	6011644578533815822	5e7b03c9ed709cf220753d550a8bfa0d	VISA 13 digit	37.7722942913982251	-122.411565951886416
43328	2020-08-08 14:12:18	2020-08-08	Dr. Gwyn Schoen PhD	dr.gwyn.schoen.phd@geemail.com	Tacoma	Washington	3045660167195003	120eb96206ed6d74ceeb3aa7264eecf0	Voyager	47.295880805899202	-122.517478704103453
43329	2020-08-08 14:18:14	2020-08-08	Dr. Cas Sauer Jr.	dr.cas.sauer.jr.@woohoo.com	Thornton	Colorado	3112851281940790435	63af0f1bed1659ddc1a917e5c4eaab90	Mastercard	39.9147629970550568	-104.977568357547
43330	2020-08-08 14:18:19	2020-08-08	Dr. Kenney Swift	dr.kenney.swift@geemail.com	League City	Texas	210093875151161000	bfaf4a9e80233a3c5382a67d50a1b299	Maestro	29.5503547246031495	-95.0625873605240059
43331	2020-08-08 14:19:35	2020-08-08	Osborne Hansen	osborne.hansen@geemail.com	Renton	Washington	3000204237370430	00a6d06a4620b2b977ceca014f43f80d	VISA 16 digit	47.4450942454919229	-122.276115132456638
43332	2020-08-08 14:36:43	2020-08-08	Mrs. Delisa Walsh PhD	mrs.delisa.walsh.phd@geemail.com	Chicago	Illinois	676257520453069	b74e55720cf60056fa6e7a016c50c05e	VISA 16 digit	41.8419808760121512	-87.755388303336872
43333	2020-08-08 14:45:00	2020-08-08	Anner Stroman-Harvey	anner.stroman.harvey@geemail.com	Chicago	Illinois	3096462284089096698	b593f5264792b2764ecba3ca64d3e431	Diners Club / Carte Blanche	41.8827332012657081	-87.743596209076415
43334	2020-08-08 14:46:30	2020-08-08	Allison Feest	allison.feest@geemail.com	Oakland	California	6011068041040059571	f0da40a1a547a8945ceebf1c5f18e758	American Express	37.8452834888740739	-122.282324105487049
43335	2020-08-08 15:01:25	2020-08-08	Phillip Johns	phillip.johns@geemail.com	Richardson	Texas	6011250214167974306	6ab028be2641cae0cec6cbd930e63f99	Discover	33.0504579271890222	-96.7129946637194564
43336	2020-08-08 15:01:49	2020-08-08	Judith Schiller	judith.schiller@geemail.com	Jackson	Mississippi	53756017166053090	ed58eb0fd72aab49e4dd5f3640b72575	JCB 16 digit	32.3436275853488624	-90.2182473117925241
43337	2020-08-08 15:05:15	2020-08-08	Isla Schamberger	isla.schamberger@warmmail.com	San Francisco	California	676152739346592	6d9eb26ed0279d77980da49054353590	Maestro	37.7520373201735566	-122.418015345053419
43338	2020-08-08 15:12:09	2020-08-08	Kellen Grimes	kellen.grimes@geemail.com	Las Vegas	Nevada	6011727207198042858	f57bb5dfe2db7c69c98a41f07452c3fc	Diners Club / Carte Blanche	36.3210459787033457	-115.306350405674792
43339	2020-08-08 15:19:35	2020-08-08	Mireya Brown-Waelchi	mireya.brown.waelchi@geemail.com	Miami	Florida	4123562251967	d843a8c4bf8d650cb9a9632368e63382	JCB 15 digit	25.793515378436819	-80.1535415320064857
43340	2020-08-08 15:23:13	2020-08-08	Verlon Collier	verlon.collier@geemail.com	New York	New York	3055600280295223	0f7cc8f10f1c43122390a79af0d58160	Discover	40.7275825746580935	-73.9149134593911441
43341	2020-08-08 15:32:05	2020-08-08	Ricci Walter DVM	ricci.walter.dvm@geemail.com	Berkeley	California	6011503409943728720	c0cb90d83e464c31c45bb47a3f698e1b	Discover	37.8531261732256041	-122.297063369285851
43342	2020-08-08 15:38:48	2020-08-08	Zetta Abernathy	zetta.abernathy@geemail.com	Oakland	California	6011539341944347374	aff293c80c0fdebbb0687d74990f5bbf	Voyager	37.8039660471101442	-122.285051148026866
43343	2020-08-08 15:40:01	2020-08-08	Ford Becker	ford.becker@geemail.com	New York	New York	3096554196079883506	7235d86f544ce934b273276a76f533da	JCB 16 digit	40.6180907006133367	-73.9675180442526852
43344	2020-08-08 15:40:27	2020-08-08	Dr. Rolla Runolfsdottir	dr.rolla.runolfsdottir@woohoo.com	Wichita	Kansas	675972107117151	d3723bf74af5ac0a4713e00dbc0b44b0	Voyager	37.7614871275488255	-97.3711742584329158
43345	2020-08-08 15:43:54	2020-08-08	Joanna Heaney	joanna.heaney@geemail.com	Cleveland	Ohio	3112826534436468664	395477d1daed4d8bd733d31eaa47becc	JCB 16 digit	41.4379679346308052	-81.5988422213826397
43346	2020-08-08 15:49:43	2020-08-08	Mikayla Rodriguez	mikayla.rodriguez@geemail.com	Fort Worth	Texas	3112610278696546450	d1cae2fbd1f9d265f7d99eb4020e5112	VISA 16 digit	32.8558752225302158	-97.2498959407031549
43347	2020-08-08 15:50:10	2020-08-08	Abner Wehner	abner.wehner@warmmail.com	Huntington Beach	California	6011835898125198729	89b9d83fe5e707c736a09115eb2ec455	Discover	33.737546692140775	-118.045494190802046
43348	2020-08-08 15:53:55	2020-08-08	Mr. Prentice Langosh IV	mr.prentice.langosh.iv@geemail.com	Tempe	Arizona	3096039226584833921	e83affbc6c4bd2d0619fc7ae8fbbae62	Diners Club / Carte Blanche	33.4197332827761713	-111.835279607077311
43349	2020-08-08 15:58:24	2020-08-08	Mrs. Joslyn Bergstrom	mrs.joslyn.bergstrom@geemail.com	Elk Grove	California	4639204564206180	4f55db1a1f71f43065b59cf153661dd4	VISA 16 digit	38.5041144708454581	-121.467406666828325
43350	2020-08-08 16:11:47	2020-08-08	Helen Hills	helen.hills@woohoo.com	Savannah	Georgia	869925782009273099	2baf68062b3979fad9a85b2bbb9c42a1	Voyager	31.9659588453918673	-81.2529143930099877
43351	2020-08-08 16:13:12	2020-08-08	Kaia Buckridge	kaia.buckridge@geemail.com	Centennial	Colorado	3726416315446821	121a8ca38680482750be5645b3644000	VISA 16 digit	39.6498533938121085	-104.915421961283684
43352	2020-08-08 16:16:05	2020-08-08	Miss Jenifer Lowe	miss.jenifer.lowe@warmmail.com	New York	New York	3528285354726319731	d160e1a225ba4b2af48f975013d4de0d	American Express	40.724112598247828	-73.9109768213599949
43353	2020-08-08 16:16:28	2020-08-08	Denver King	denver.king@geemail.com	Provo	Utah	502078182957437	1f4e04db5e1886ffe8f3f2c95443f900	JCB 16 digit	40.2860781371381123	-111.605742005366096
43354	2020-08-08 16:17:53	2020-08-08	Kiel Stehr	kiel.stehr@warmmail.com	Berkeley	California	210035435651497635	7cddd644098a8926958db22b44baca05	Maestro	37.8745566004818031	-122.284580798502958
43355	2020-08-08 16:26:31	2020-08-08	Lashunda Orn MD	lashunda.orn.md@geemail.com	Lafayette	Louisiana	4787690366878533	bfb64a7fe10f49a51cfb309d16ef9191	Voyager	30.2252049725014729	-92.0139517760220826
43356	2020-08-08 16:29:35	2020-08-08	Garnett Cartwright	garnett.cartwright@geemail.com	Pearland	Texas	4070364471613443	e2d23af1c0f6fe11a9a33bf6a8ce4ac2	VISA 13 digit	29.5098165857411949	-95.3315907554089961
43357	2020-08-08 16:30:17	2020-08-08	Dr. Marquis Bins V	dr.marquis.bins.v@geemail.com	Colorado Springs	Colorado	4100371613546997	e303b2eff3ca611787e119d2b3ba60b3	Diners Club / Carte Blanche	38.9382658451844037	-104.782765427992487
43358	2020-08-08 16:35:33	2020-08-08	Myrtis Hagenes-Lesch	myrtis.hagenes.lesch@woohoo.com	Palm Bay	Florida	6011634658611251272	9420977f78324736d5c7844983026517	VISA 16 digit	27.9643533605936945	-80.6195559263996699
43359	2020-08-08 16:42:39	2020-08-08	Durwood Jenkins	durwood.jenkins@geemail.com	San Bernardino	California	51813252390988784	d16d8693a59efc3dd8649aefdc508756	JCB 16 digit	34.1128956039700597	-117.389165810985858
43360	2020-08-08 16:47:55	2020-08-08	Miss Melvina Kutch PhD	miss.melvina.kutch.phd@geemail.com	Hartford	Connecticut	3012099958635724	f9d7ce81ccbd0650cf76616a4be428a1	JCB 16 digit	41.8303835636485388	-72.7108746157385468
43361	2020-08-08 17:00:38	2020-08-08	Purl Hansen	purl.hansen@geemail.com	Arlington	Texas	3158039719905235354	c403b8cb9757813f2999be8bf052cba0	JCB 16 digit	32.6950262583110458	-97.0398703187264573
43362	2020-08-08 17:18:01	2020-08-08	Karyme Zulauf	karyme.zulauf@geemail.com	Denver	Colorado	3028116179577602	e728e7ef6458d2ca313446fe957e635f	JCB 16 digit	39.7456053251452701	-104.838143241336951
43363	2020-08-08 17:27:58	2020-08-08	Tabatha Pfannerstill	tabatha.pfannerstill@geemail.com	Los Angeles	California	180008150539146410	c30e49fffcf4e147aabdd6e4679bf67a	VISA 16 digit	33.9506309489585405	-118.329556388640029
43364	2020-08-08 17:29:27	2020-08-08	Lona Reinger	lona.reinger@geemail.com	Gilbert	Arizona	6011480094469891966	7e4078fe8ddb20a98dad3191aaf3386e	VISA 13 digit	33.4047295106455664	-111.76356357304789
43365	2020-08-08 17:31:02	2020-08-08	Dr. Thedore Rath	dr.thedore.rath@woohoo.com	Fresno	California	676324835386558	d46ca213bb98d8c5a16e5855f1459af1	VISA 13 digit	36.7721004200506982	-119.766523986553409
43366	2020-08-08 17:31:07	2020-08-08	Kayli Kerluke	kayli.kerluke@geemail.com	San Francisco	California	3112851485611389233	edbafb31176f2ce49b620642c2d83024	VISA 16 digit	37.793179735572707	-122.393236411040434
43367	2020-08-08 17:33:43	2020-08-08	Dr. Felton Kassulke PhD	dr.felton.kassulke.phd@geemail.com	Cincinnati	Ohio	6011365715818426894	c1486db7c5765604a1d224610f5c3a24	American Express	39.1369832376249107	-84.4845384975701563
43368	2020-08-08 17:39:30	2020-08-08	Fleeta Rice	fleeta.rice@geemail.com	Houston	Texas	3052413109302177	36e3aa3e97188c70a09bba3611c75b29	VISA 16 digit	29.691840429518745	-95.4621613560259306
43369	2020-08-08 17:49:26	2020-08-08	Celena Leffler-Green	celena.leffler.green@geemail.com	Jacksonville	Florida	3043776266054404	e9061e66b9f5b6ca039003ea7bf180df	JCB 16 digit	30.3561314596381031	-81.630458992261822
43370	2020-08-08 17:53:37	2020-08-08	Travis Bechtelar	travis.bechtelar@woohoo.com	Phoenix	Arizona	3158593227887017905	b9c0a7d9ced06c33dae39cf0be47e103	Diners Club / Carte Blanche	33.5431185800515124	-112.163205334443973
43371	2020-08-08 18:05:59	2020-08-08	Mrs. Wava Shanahan	mrs.wava.shanahan@geemail.com	Charlotte	North Carolina	869944622396039660	652163e35fb5f0d96da0e20ffa6d839e	VISA 13 digit	35.1293947279240939	-80.869882519025353
43372	2020-08-08 18:25:11	2020-08-08	Lorie Harber	lorie.harber@woohoo.com	Tampa	Florida	3088540894040828157	0f1d7da1884c84276759193a491c700e	VISA 16 digit	27.8737186171229929	-82.4957963866393982
43373	2020-08-08 18:29:41	2020-08-08	Niles Bahringer	niles.bahringer@geemail.com	Albuquerque	New Mexico	210022147006417847	8d6e5fffa5f97f6cb566b998c0eb3d8d	Maestro	35.084903045803685	-106.658943001653626
43374	2020-08-08 18:29:45	2020-08-08	Lakesha Bahringer	lakesha.bahringer@warmmail.com	Sunnyvale	California	210076373375727419	a42bf79ad044dcdda8282fdb4a495426	Discover	37.3617197209496084	-122.035393620907527
43375	2020-08-08 18:46:41	2020-08-08	Mr. Finn Kemmer	mr.finn.kemmer@geemail.com	Amarillo	Texas	55066846411665265	59396ea14dacb2fe442ca76b26dbf6d7	JCB 15 digit	35.1599508620496835	-101.855811535552888
43376	2020-08-08 18:49:52	2020-08-08	Kem DuBuque	kem.dubuque@geemail.com	Manchester	New Hampshire	180082521488045309	ac2f10e16701a5cfd4f9fd71e9b57f23	VISA 16 digit	42.9907196761179762	-71.3986789517462341
43377	2020-08-08 18:52:26	2020-08-08	Mr. Francisco King Sr.	mr.francisco.king.sr.@geemail.com	New York	New York	4976363252362415	9bf968fcb66546c6b1ab1abdce90c4d2	American Express	40.7499362532272897	-73.9540396665118607
43378	2020-08-08 18:57:05	2020-08-08	Kaylie Yost	kaylie.yost@woohoo.com	Lakewood	New Jersey	3088177554898108520	57844af6ace758125db7a7521a408b2f	Voyager	40.0470195102788509	-74.1594462306514401
43379	2020-08-08 18:57:58	2020-08-08	Kermit Rice-Brakus	kermit.rice.brakus@geemail.com	San Antonio	Texas	4294431910492794	1468d26fa83c32efd1b41df3a33501d2	Voyager	29.5018580607209344	-98.5899881630040653
43380	2020-08-08 19:07:26	2020-08-08	Lilian Satterfield DVM	lilian.satterfield.dvm@geemail.com	Killeen	Texas	3112316375416128846	6dde22c5c4f4825dff8c844ab59b209f	JCB 15 digit	31.0153188223715865	-97.6764636482279798
43381	2020-08-08 19:09:55	2020-08-08	April Johnston	april.johnston@woohoo.com	San Antonio	Texas	676306822620222	2fbc8a762e8d8c65e244ae81023c6e87	JCB 16 digit	29.4649314185209583	-98.4409690615557054
43382	2020-08-08 19:10:39	2020-08-08	Brianda Wolf	brianda.wolf@warmmail.com	New York	New York	3337733018815620014	ed3cfe29389455ce6a1ff1cda2ca2fee	VISA 16 digit	40.6044727624617536	-73.9700781231176023
43383	2020-08-08 19:22:09	2020-08-08	Cheryl Larson	cheryl.larson@geemail.com	Everett	Washington	4986745604637	da797adbf2db39b5c1668adf6d3f53c7	Discover	47.9330619618654268	-122.236659831892325
43384	2020-08-08 19:22:50	2020-08-08	Zelma Gerhold MD	zelma.gerhold.md@warmmail.com	Springfield	Illinois	3337526393934389648	5dc230f602ed7317ed2510054403d438	JCB 16 digit	39.7858611988056481	-89.7218314803209154
43385	2020-08-08 19:25:57	2020-08-08	Bruno Satterfield I	bruno.satterfield.i@woohoo.com	New York	New York	869934804574449802	d3cc32b0e5195e8b92f113ab22e56b39	Diners Club / Carte Blanche	40.6916155211385302	-73.8850934744708212
43386	2020-08-08 19:31:01	2020-08-08	Mrs. Shelba Fritsch	mrs.shelba.fritsch@geemail.com	Amarillo	Texas	4596648240700	2525fe29943ac09d98ac84294169d057	Mastercard	35.199277685319629	-101.869894398781284
43387	2020-08-08 19:35:42	2020-08-08	Jordy McKenzie-Johns	jordy.mckenzie.johns@woohoo.com	Milwaukee	Wisconsin	4171258569309	7e8fe5bab8d01b9763fcdfe6ab7692b4	VISA 16 digit	43.0159069677434829	-88.0367606998987497
43388	2020-08-08 19:36:06	2020-08-08	Julius Hoeger	julius.hoeger@geemail.com	Long Beach	California	3419997508274350	398861c24fa406176ddb9f64ee93d24d	Diners Club / Carte Blanche	33.8489621924523263	-118.237047527793052
43389	2020-08-08 19:39:50	2020-08-08	Shannon McClure	shannon.mcclure@geemail.com	Charlotte	North Carolina	3528221857818323939	277ab33f62e9d940bd7e3a1c0087134b	VISA 16 digit	35.280072184910253	-80.8267661395426842
43390	2020-08-08 19:41:41	2020-08-08	Shani Schroeder	shani.schroeder@geemail.com	Dallas	Texas	4388700993195038	e356ae53f295c25caf1705d89e2a26b0	Voyager	32.6997653478097163	-96.7906840089671192
43391	2020-08-08 19:43:51	2020-08-08	Ms. Miya Greenfelder	ms.miya.greenfelder@warmmail.com	Phoenix	Arizona	4201168087996320	42836c14725d229fb8019fa240579714	JCB 16 digit	33.6512888580028005	-112.039879955437414
43392	2020-08-08 19:46:11	2020-08-08	Dr. Beryl King PhD	dr.beryl.king.phd@geemail.com	Cape Coral	Florida	52637808305292101	24977700192b88e41e1fb36af795c9fb	Diners Club / Carte Blanche	26.608605177650972	-82.0455821278110164
43393	2020-08-08 19:48:42	2020-08-08	Miss Lilah Johns	miss.lilah.johns@geemail.com	Rialto	California	4098814560730	f0d3414c8caa1330bd0157b5c95c46e4	Diners Club / Carte Blanche	34.0277064996521972	-117.427550443596388
43394	2020-08-08 19:52:57	2020-08-08	Jacquez Lindgren	jacquez.lindgren@geemail.com	Jackson	Mississippi	210058113775044862	6ee467c69d6d9d285500757654cf6468	Maestro	32.2574672365739943	-90.2386573567494708
43395	2020-08-08 20:00:30	2020-08-08	Foch Hermann	foch.hermann@geemail.com	Philadelphia	Pennsylvania	52207726558090743	0f3fdbf5fc8d1a23af108b721d704a30	JCB 15 digit	39.9365768430713572	-75.1736683924581968
43396	2020-08-08 20:09:04	2020-08-08	Melodee Raynor-Rau	melodee.raynor.rau@woohoo.com	Worcester	Massachusetts	3022445020454034	0fd93cc6814cb410b974f1736b54482f	JCB 16 digit	42.3660127338189625	-71.8920641348484963
43397	2020-08-08 20:16:02	2020-08-08	Riley Walker	riley.walker@geemail.com	Oakland	California	180082654675807478	559b23776ce792363157f0143c44247b	American Express	37.7459950856591533	-122.249445466362218
43398	2020-08-08 20:16:14	2020-08-08	Dr. Drury Steuber	dr.drury.steuber@geemail.com	Elgin	Illinois	3528544633546012676	9e6939838fd1f0909406f4534746dcb7	JCB 16 digit	41.9697108190789834	-88.3459322681471804
43399	2020-08-08 20:24:00	2020-08-08	Edra Miller	edra.miller@geemail.com	Bakersfield	California	502052456043554	af220974411b0ce426e738b360077e1e	Maestro	35.3965434709738886	-119.05144661574549
43400	2020-08-08 20:46:20	2020-08-08	Layne Abbott	layne.abbott@warmmail.com	Amarillo	Texas	4116830702149189	16f81669edd4d68524b2c01cdb8fa1c8	JCB 16 digit	35.1921846737783426	-101.884050301867362
43401	2020-08-08 20:54:39	2020-08-08	Briana Monahan-Bernhard	briana.monahan.bernhard@warmmail.com	New York	New York	869944502838889163	1b58bd74b0d746fd4d33d53e48d5162b	JCB 16 digit	40.5898436645269385	-73.9907285144913942
43402	2020-08-08 21:01:04	2020-08-08	Mearl Hamill-Bruen	mearl.hamill.bruen@geemail.com	San Francisco	California	3714574865575219	3cc9991f6a8f6b232e7689a082a527e1	JCB 16 digit	37.7589181367157636	-122.457965958716244
43403	2020-08-08 21:05:58	2020-08-08	Donovan Mitchell	donovan.mitchell@geemail.com	El Paso	Texas	869935318913713454	dfdbd335698d892e0d772b4873075e12	JCB 16 digit	31.7576689911834897	-106.492435689827431
43404	2020-08-08 21:14:40	2020-08-08	Mr. Foster Hilll	mr.foster.hilll@woohoo.com	San Bernardino	California	6011928359366023454	9acf1ae325dd9e8ae2e70063652c7b0e	JCB 16 digit	34.184924715131892	-117.232468771679692
43405	2020-08-08 21:15:38	2020-08-08	Adelina Collier	adelina.collier@geemail.com	Riverside	California	3337905065421925065	c1c3b7d499dbcf241e9aa70fbba70402	Discover	33.9682888678222881	-117.354172807416688
43406	2020-08-08 21:22:32	2020-08-08	Elmina Cormier MD	elmina.cormier.md@geemail.com	Fairfield	California	4390897018849791	5e4f06bdef43a2805bfbeeb9d9da8f28	JCB 16 digit	38.3580828053534049	-122.114964148169761
43407	2020-08-08 21:22:37	2020-08-08	Coolidge Bosco-Fisher	coolidge.bosco.fisher@warmmail.com	Dallas	Texas	52204428456982302	6e5996446fc4f0768a3f26d1e5ab75b1	VISA 16 digit	32.7348188944432934	-96.6746615210045093
43408	2020-08-08 21:23:30	2020-08-08	Gael Hermiston	gael.hermiston@geemail.com	Los Angeles	California	55950913818041265	c1be5e31f3701c576aa6ff067c0cf09e	Maestro	34.0085472371295054	-118.356009620567036
43409	2020-08-08 21:28:11	2020-08-08	Alvin Hodkiewicz	alvin.hodkiewicz@geemail.com	Oakland	California	3015431315690596	c9237760ff654064747346a1ff7b16e9	American Express	37.8359482527189002	-122.301711816368964
43410	2020-08-08 21:43:04	2020-08-08	Miss Karon Considine PhD	miss.karon.considine.phd@geemail.com	Louisville	Kentucky	3045821858391364	e5598a36ec8280e1b530451c25339342	JCB 15 digit	38.1254539213977708	-85.5735489440687047
43411	2020-08-08 21:45:41	2020-08-08	Sebastian Lockman II	sebastian.lockman.ii@woohoo.com	Portland	Oregon	675930328263337	fa93ad2cf37680a58b971c87895a8d51	JCB 16 digit	45.5630350807569897	-122.612749302061275
43412	2020-08-08 21:47:48	2020-08-08	Dora Ratke	dora.ratke@woohoo.com	Washington	District of Columbia	4428061010336945	f71875b6a3a0f456f0151b484176b02c	JCB 16 digit	38.8943255343273293	-77.0131114911966108
43413	2020-08-08 21:50:44	2020-08-08	Alvah Bode	alvah.bode@geemail.com	Tampa	Florida	180024885493194373	e915c56846d4e3bef68a9df84e92f8f2	American Express	28.0568252597119638	-82.4174727218903485
43414	2020-08-08 21:59:50	2020-08-08	Janeen Nader	janeen.nader@geemail.com	Plano	Texas	3054349042136280	cb9c56012a5bb28df6725895991f91e8	Maestro	33.0320038165982837	-96.7938810440894173
43415	2020-08-08 22:01:02	2020-08-08	Ashley Durgan	ashley.durgan@geemail.com	San Diego	California	3012782436690847	a351e7567eed5bebf35b0a6f3f9c5c58	VISA 16 digit	32.8281220519050976	-117.089262998513888
43416	2020-08-08 22:05:38	2020-08-08	Lamarcus O'Reilly	lamarcus.o'reilly@geemail.com	Dallas	Texas	639080890044276	10599a724a1bc3156a345e246b746381	JCB 16 digit	32.7107638909753433	-96.7647104082126077
43417	2020-08-08 22:06:06	2020-08-08	Casen Kihn	casen.kihn@woohoo.com	Jersey City	New Jersey	53019465393877034	e4a822ee543e54dcbb65c66ca516870d	Voyager	40.7475243950668684	-74.0244708964090847
43418	2020-08-08 22:06:38	2020-08-08	Osa Sporer MD	osa.sporer.md@woohoo.com	San Francisco	California	4924061543244573	26a3c4378642e66e6bb063170f41498a	Mastercard	37.7831582804700261	-122.412196417297011
43419	2020-08-08 22:13:10	2020-08-08	Mr. Alva Bauch I	mr.alva.bauch.i@woohoo.com	Las Cruces	New Mexico	180012265536541902	ac0ec898e41927fc5da98d8b585dc376	JCB 16 digit	32.3671933697104421	-106.830267545406514
43420	2020-08-08 22:26:23	2020-08-08	Vlasta Howe	vlasta.howe@warmmail.com	Charlotte	North Carolina	4633005048747	1cf7c1b6d1fc6777c38da2c98f8c4a0b	American Express	35.1621133479543033	-80.8801355393081991
43421	2020-08-08 22:32:24	2020-08-08	Jered Bednar IV	jered.bednar.iv@geemail.com	Phoenix	Arizona	639096158692259	5e7c29ce530eff603379a089a2722e63	Discover	33.5942843460410856	-112.091267420623836
43422	2020-08-08 22:35:05	2020-08-08	Meghann Barrows	meghann.barrows@geemail.com	New York	New York	3112414301366865030	df99ee073a84e851813150467a59ee11	VISA 13 digit	40.6484289278965463	-73.8909848999127661
43423	2020-08-08 22:37:14	2020-08-08	Anastacio Hermann-Pouros	anastacio.hermann.pouros@warmmail.com	Abilene	Texas	3053242361486223	e4fa44a7c9f4212c6306d328beea8166	VISA 13 digit	32.3917630527243077	-99.7245637889899399
43424	2020-08-08 22:37:32	2020-08-08	Malik Hammes	malik.hammes@geemail.com	San Francisco	California	55914879348338262	11a549e26da8c35cc85377cbf0f730a0	VISA 16 digit	37.7668619826402008	-122.437104730863993
43425	2020-08-08 23:08:00	2020-08-08	Dr. Nelson Dietrich PhD	dr.nelson.dietrich.phd@geemail.com	Knoxville	Tennessee	869949588068980975	ea0db02ce7d8fe6305937b18f0e3002e	VISA 16 digit	36.0585307155333439	-83.9614025260537744
43426	2020-08-08 23:11:38	2020-08-08	Mariel Lynch	mariel.lynch@geemail.com	Houston	Texas	589348486244170	fe07788257725bf86f9cc397e36a9a42	VISA 16 digit	29.7059592711817473	-95.3014351199395975
43427	2020-08-08 23:15:06	2020-08-08	Kinsey Kris DDS	kinsey.kris.dds@geemail.com	Fort Wayne	Indiana	6011969974802254016	0edda792af1f0a361a39a27e488bb47c	VISA 16 digit	41.1272371860004995	-85.234043176773568
43428	2020-08-08 23:17:24	2020-08-08	Mr. Kenji Cruickshank III	mr.kenji.cruickshank.iii@geemail.com	Odessa	Texas	869960734268106730	2ec55ac296c53cc68a966394290221b0	Voyager	31.9326138294313111	-102.395404599808529
43429	2020-08-08 23:20:34	2020-08-08	Kayden Mayert	kayden.mayert@geemail.com	Charlotte	North Carolina	6011263700694653905	afa58332626df1007bc66702a9b19920	VISA 16 digit	35.2883068178567996	-80.8060729727093161
43430	2020-08-08 23:20:50	2020-08-08	Deyanira Boyer	deyanira.boyer@geemail.com	Berkeley	California	6011844597117564869	4517b8850d893a92c60d1ec26f7b473e	Voyager	37.8720658177592711	-122.277174225397928
43431	2020-08-08 23:23:51	2020-08-08	Miss Else Ortiz DDS	miss.else.ortiz.dds@geemail.com	Miami	Florida	4746462042725326	f628cee73f638e9056b8448185a8a3e8	Voyager	25.833489330266417	-80.2020212435036939
43432	2020-08-08 23:27:26	2020-08-08	Ms. Rettie Stamm MD	ms.rettie.stamm.md@woohoo.com	Irving	Texas	55216872308110222	6a344fea6abf67ed3746099b7504486a	VISA 16 digit	32.8336474874474149	-96.9572141271363961
43433	2020-08-08 23:50:26	2020-08-08	Wilkie Hansen	wilkie.hansen@geemail.com	Oklahoma City	Oklahoma	3725454761330802	5251ced91422d53b8a226adbf619cbec	JCB 15 digit	35.3986044908784336	-97.5457713319815696
43434	2020-08-09 00:02:34	2020-08-09	Destin Heller-Marvin	destin.heller.marvin@geemail.com	Lancaster	California	3023141669880303	05821338c96a3fc3c07a1af7c639e04d	Diners Club / Carte Blanche	34.7205974888768054	-118.133488996044917
43435	2020-08-09 00:09:06	2020-08-09	Dorris Streich	dorris.streich@geemail.com	New York	New York	639047346191597	754b7ed1c9b073c8c4994a050b59db4a	JCB 16 digit	40.5800556107647736	-73.9051112750906469
43436	2020-08-09 00:12:46	2020-08-09	Thompson Hodkiewicz	thompson.hodkiewicz@geemail.com	Des Moines	Iowa	6011320580492722388	161fd5894d4447452c433f4b8ede87fb	VISA 16 digit	41.5397167526859832	-93.6404948768250733
43437	2020-08-09 00:12:53	2020-08-09	Eunice O'Hara DVM	eunice.o'hara.dvm@warmmail.com	Columbia	Missouri	4387553167880658	05d33de47818cb1706677bd1daf1e6be	American Express	38.8545502594087822	-92.3690629965213219
43438	2020-08-09 00:14:02	2020-08-09	Ronan O'Reilly III	ronan.o'reilly.iii@geemail.com	Washington	District of Columbia	53747917504355267	8c679fa73d27022177a0b8688fcd5381	Mastercard	38.8063917998023342	-77.0021821022246087
43439	2020-08-09 00:16:07	2020-08-09	Duane Grady IV	duane.grady.iv@woohoo.com	Carlsbad	California	4305391756734	357ade1e4f7f21af6e8309ec22cb3cb7	VISA 16 digit	33.2095369183398788	-117.230287273300064
43440	2020-08-09 00:19:34	2020-08-09	Gidget O'Conner	gidget.o'conner@geemail.com	Boise	Idaho	4987412308387	86de4aab77cafb29de5521c7ea857f0e	Voyager	43.5351585666786889	-116.137652841322875
43441	2020-08-09 00:35:51	2020-08-09	Dr. True Powlowski MD	dr.true.powlowski.md@warmmail.com	Pembroke Pines	Florida	3028900589145773	a9cc6aea0453ef73856061d2ac80a175	JCB 16 digit	26.0459911597464249	-80.2720340207587952
43442	2020-08-09 00:40:08	2020-08-09	Andra Streich	andra.streich@geemail.com	Murrieta	California	4257099576855300	546e29be04ba7231d8b59a27f39045b9	VISA 13 digit	33.4983257869355384	-117.119775196481115
43443	2020-08-09 00:42:49	2020-08-09	Donie Hoeger-Schuppe	donie.hoeger.schuppe@geemail.com	Modesto	California	210058826785846337	f53ea1fe5e2d0f6c620ac1f365e81220	American Express	37.614821735303849	-120.964057782219726
43444	2020-08-09 00:47:09	2020-08-09	Ryder Lockman	ryder.lockman@geemail.com	Fremont	California	3088505112436119625	1cff11cae02e236e24af1c0d9d49fb43	VISA 13 digit	37.4155211383178852	-121.845834779179469
43445	2020-08-09 01:05:02	2020-08-09	Chantal Kuhn	chantal.kuhn@warmmail.com	San Antonio	Texas	4477089933743970	21e881a24cbad63a6209851a1275e1e2	Voyager	29.5030691467761983	-98.4881341329146096
43446	2020-08-09 01:07:54	2020-08-09	Mr. Tucker Leuschke Jr.	mr.tucker.leuschke.jr.@geemail.com	San Francisco	California	3158398387594622996	d7f5a6221681f54c411dd8b8fc3fa736	Diners Club / Carte Blanche	37.7458454136536332	-122.418297351893145
43447	2020-08-09 01:13:11	2020-08-09	Gavin Johnston-Hammes	gavin.johnston.hammes@warmmail.com	Naperville	Illinois	210057245585491569	2c1d0217070ef518b4ae43feaba021fa	VISA 16 digit	41.7235649004492899	-88.1656896718666019
43448	2020-08-09 01:14:53	2020-08-09	Celesta Kemmer DVM	celesta.kemmer.dvm@geemail.com	Springfield	Missouri	3337458486070423528	d53b34eb567ec7e048e01cd1f1fb169e	Discover	37.1898371155567489	-93.3342659824818384
43449	2020-08-09 01:16:57	2020-08-09	Julisa Swift	julisa.swift@geemail.com	Grand Rapids	Michigan	3489630057331256	a6b9ed53040f2d6ba11f60b61ad26ddd	VISA 16 digit	42.9394198778353626	-85.6978001954168178
43450	2020-08-09 01:18:15	2020-08-09	Auston Willms	auston.willms@warmmail.com	Dallas	Texas	4127349438837766	73af26966fde73fffc9fc3f49988e952	JCB 16 digit	32.8123529427956839	-96.8228303499016789
43451	2020-08-09 01:21:59	2020-08-09	Curley McDermott DDS	curley.mcdermott.dds@geemail.com	Baton Rouge	Louisiana	3482799131723676	00627366f3fe19fa347bfba7c0319837	Mastercard	30.4435421717099857	-91.1970257920786764
43452	2020-08-09 01:23:24	2020-08-09	Gerhard Denesik	gerhard.denesik@warmmail.com	Sacramento	California	3047264324974232	0da8792c9c6c99aecb02d2bf2faf1ca7	VISA 13 digit	38.5222741970125568	-121.385404709564895
43453	2020-08-09 01:34:16	2020-08-09	Dr. Bart Herzog	dr.bart.herzog@warmmail.com	San Francisco	California	4138635806326854	42d6168953cccacc7a714d390c6abae7	Diners Club / Carte Blanche	37.7408522491577259	-122.446428489327786
43454	2020-08-09 01:36:28	2020-08-09	Mr. Gerhard Lockman	mr.gerhard.lockman@geemail.com	Chattanooga	Tennessee	210003593249908774	217cd349dcbbe9347cdcedc2953c33d6	VISA 13 digit	35.141052595604215	-85.1691578037399779
43455	2020-08-09 01:41:21	2020-08-09	Jovany Herman	jovany.herman@geemail.com	Springfield	Illinois	3158750721870201905	8b5795059a5d3a3ddea0bc3f81a70370	VISA 13 digit	39.7946773627925694	-89.7049300293441831
43456	2020-08-09 01:42:30	2020-08-09	Aron Monahan	aron.monahan@geemail.com	Miami	Florida	180006701671421326	5d51697c288463de746eb35b24aab58e	JCB 15 digit	25.7020262946046891	-80.3071235166735988
43457	2020-08-09 02:03:11	2020-08-09	Chase Wuckert DVM	chase.wuckert.dvm@geemail.com	Greensboro	North Carolina	4716282786111	bf78913255d8e9e582724ce56e2e6fc7	JCB 16 digit	36.0507209714617574	-79.9246716305129183
43458	2020-08-09 02:06:08	2020-08-09	Geno Kreiger	geno.kreiger@geemail.com	San Francisco	California	869974191491674493	8dd66adc613c14e86eaab043a80b5b9d	American Express	37.7810125131808974	-122.475486975640152
43459	2020-08-09 02:07:13	2020-08-09	Martika Waelchi DDS	martika.waelchi.dds@warmmail.com	Concord	California	3337902543372769479	de2bd1464ad662f6db6372637bc9a1e6	Mastercard	37.8792573975797779	-121.958197208930173
43460	2020-08-09 02:07:40	2020-08-09	Mahalie Prosacco	mahalie.prosacco@geemail.com	San Francisco	California	6011072860138656368	ef9fa0f5ae43ca6f81b979a22e9c0b78	Mastercard	37.785094703456366	-122.473177574046034
43461	2020-08-09 02:13:03	2020-08-09	Selene Doyle	selene.doyle@geemail.com	Pembroke Pines	Florida	3726341885530939	fee2025621a09d0fe61d0ca9baabbc7a	JCB 16 digit	26.0224309080317617	-80.2882207761421824
43462	2020-08-09 02:17:38	2020-08-09	Mr. Karson Robel	mr.karson.robel@geemail.com	Columbus	Ohio	869917142698451524	300a0c32925c11bf3679d32e5e9acdf3	JCB 16 digit	39.9578310389582043	-83.0053012171529332
43463	2020-08-09 02:33:10	2020-08-09	Lorraine Bergstrom MD	lorraine.bergstrom.md@woohoo.com	New Orleans	Louisiana	3088598307908545244	8ef55ee8d800783773367bb626043c63	VISA 16 digit	30.1424773729421211	-89.9754026761073646
43464	2020-08-09 02:39:10	2020-08-09	Mrs. Lillianna Schmeler DVM	mrs.lillianna.schmeler.dvm@geemail.com	Wilmington	North Carolina	6011841108817080355	a9a0dd094ed13f52b72937d568aca3f5	American Express	34.1241938440881682	-77.9288092626716917
43465	2020-08-09 02:41:16	2020-08-09	Calista Aufderhar	calista.aufderhar@geemail.com	Garden Grove	California	52126946543884921	7e653a47125cba11627085c005228643	Voyager	33.8244384253688111	-117.864065872553738
43466	2020-08-09 02:46:39	2020-08-09	Dr. Antione Lind	dr.antione.lind@geemail.com	Elk Grove	California	3040377633915568	f1e3ce6125399b5fe248a8d6cef62d65	Mastercard	38.3374185572195785	-121.476507097613066
43467	2020-08-09 02:53:41	2020-08-09	Izaiah Auer-Krajcik	izaiah.auer.krajcik@geemail.com	Aurora	Illinois	51247964480411768	de2d3bdc0440379f79ff7aa1cd49f988	JCB 16 digit	41.6661961520779869	-88.3662030122637674
43468	2020-08-09 02:56:38	2020-08-09	Mr. Lemmie Wehner	mr.lemmie.wehner@warmmail.com	Rancho Cucamonga	California	639033992269549	a7be5de6456956669fe50f350ce83766	VISA 13 digit	34.1508673830416072	-117.562946315063911
43469	2020-08-09 03:05:44	2020-08-09	Littleton Hickle	littleton.hickle@warmmail.com	Philadelphia	Pennsylvania	4987315426506167	86d342efd35eef941237ab7edd4bd521	VISA 16 digit	40.0339463680010255	-75.0697922450855373
43470	2020-08-09 03:06:53	2020-08-09	Denice Russel	denice.russel@geemail.com	New York	New York	3415208741439527	c7a4b7d24914a8b959795bab09b7098a	Voyager	40.6228139726668616	-74.0011546360690176
43471	2020-08-09 03:09:31	2020-08-09	Mr. Carlie Toy Sr.	mr.carlie.toy.sr.@geemail.com	Provo	Utah	869968151690274253	dffa0eaf719e01697436322e94a9ee20	American Express	40.2371167216237637	-111.723838295894865
43472	2020-08-09 03:23:36	2020-08-09	Stephany O'Connell	stephany.o'connell@geemail.com	New York	New York	3528047228192160622	ab25b8912c55b42c383f6483f5597b09	American Express	40.6285275422725789	-73.9776816868118914
43473	2020-08-09 03:25:36	2020-08-09	Julian Prosacco-Waelchi	julian.prosacco.waelchi@geemail.com	College Station	Texas	503863848312904	2f92027d55de39ac02e332b3e2c68e12	VISA 16 digit	30.6308242665182817	-96.2857710061907852
43474	2020-08-09 03:35:06	2020-08-09	Gabe Kuhn-Ledner	gabe.kuhn.ledner@geemail.com	Madison	Wisconsin	561279096314004	dc7e4980e3a8159cf275f6369094052c	VISA 16 digit	43.0139445557232989	-89.333415398688615
43475	2020-08-09 03:39:52	2020-08-09	Berdie Rohan DDS	berdie.rohan.dds@woohoo.com	Akron	Ohio	4823517807182629	f30de1634b1046c543989f76394fa129	VISA 16 digit	41.0484047145880737	-81.5353332140795857
43476	2020-08-09 03:44:37	2020-08-09	Alabama Schroeder MD	alabama.schroeder.md@warmmail.com	Huntsville	Alabama	51084727084149225	c7f9795e5da9a73e748fd5c5b123326b	American Express	34.7258505535554107	-86.7030421101506761
43477	2020-08-09 03:46:38	2020-08-09	Irwin Lakin	irwin.lakin@warmmail.com	New York	New York	54038855881240876	c27f7d2ed6f474d69939a88f5a5e3a63	JCB 15 digit	40.6340345716327391	-73.9621943282790397
43478	2020-08-09 03:47:49	2020-08-09	Jeff Stamm	jeff.stamm@geemail.com	San Mateo	California	3013835575160169	2366bf1f73acd5219260ad012b9f06fc	American Express	37.6038846053529525	-122.389802131554475
43479	2020-08-09 03:47:58	2020-08-09	Samantha Harris	samantha.harris@geemail.com	New York	New York	4402931554123	5ce7879de31506c8c2ebb5226a31e12c	Voyager	40.6821116558033964	-73.8932159656088743
43480	2020-08-09 03:57:32	2020-08-09	Jermaine Labadie	jermaine.labadie@woohoo.com	Fort Worth	Texas	3528193210529448377	97b327e6e64ff7cf4540c69b887f7f6a	VISA 16 digit	32.752366738213226	-97.3942660604890449
43481	2020-08-09 03:57:39	2020-08-09	Ms. Araminta Treutel DDS	ms.araminta.treutel.dds@geemail.com	San Diego	California	55566497944499429	790ba983302b85fc670fa7292271b281	Mastercard	32.758466120257232	-117.050836752811449
43482	2020-08-09 04:00:13	2020-08-09	Roberta Wunsch PhD	roberta.wunsch.phd@geemail.com	San Francisco	California	3717896300874593	b5d1c99cf47c56667a5192ce121bdb52	American Express	37.78255910646714	-122.421972337086629
43483	2020-08-09 04:06:27	2020-08-09	Dr. Green Schmidt	dr.green.schmidt@geemail.com	Clearwater	Florida	180064989182780673	948007be697574f990412f5a38a6457e	JCB 16 digit	27.9152904900383199	-82.7817802236679938
43484	2020-08-09 04:26:07	2020-08-09	Dr. Edmond Bartoletti	dr.edmond.bartoletti@geemail.com	Sterling Heights	Michigan	501882177414073	c6855f1c16e7d9278d7b03ef49cf9fa1	VISA 13 digit	42.5891050122294601	-82.9503924134347557
43485	2020-08-09 04:37:46	2020-08-09	Odell Schmidt	odell.schmidt@geemail.com	Billings	Montana	561224244888657	ee9aff9c4f90ee326943038049060b6b	VISA 16 digit	45.8376446407511793	-108.592415754373732
43486	2020-08-09 04:43:43	2020-08-09	Jethro Block	jethro.block@woohoo.com	Corpus Christi	Texas	4146738312561	1464cf9b4a0c33f3a95564a3d2582762	Maestro	27.7252580716677031	-97.1599462510380931
43487	2020-08-09 04:45:12	2020-08-09	Willie Sawayn-McClure	willie.sawayn.mcclure@geemail.com	Houston	Texas	4551252751211	d3149ff97ee41971decd63141d747072	VISA 13 digit	29.8643438655029989	-95.411217087974407
43488	2020-08-09 04:49:14	2020-08-09	Nikole Marvin-Boehm	nikole.marvin.boehm@woohoo.com	Boston	Massachusetts	502003112377332	c1f3e460bedd6474b42d398b4c73130c	VISA 16 digit	42.3294253278691315	-71.0077233143568094
43489	2020-08-09 04:54:16	2020-08-09	Ray Crooks	ray.crooks@geemail.com	Philadelphia	Pennsylvania	3785103610075160	1d86f7e371dc20cfb522fb70437ba46b	VISA 13 digit	40.1009580281522133	-75.1383074150785859
43490	2020-08-09 04:55:47	2020-08-09	Kirk Gulgowski	kirk.gulgowski@woohoo.com	New York	New York	3337023797265650279	b3110fc13c505979548c53aad7daee36	JCB 16 digit	40.7126065759677402	-74.0112178627297226
43491	2020-08-09 04:57:29	2020-08-09	Jamarcus Rutherford	jamarcus.rutherford@geemail.com	Concord	California	3528243358486119158	04df4ba2c3029be2ba73b00c9c0785cf	VISA 16 digit	37.9094612596489497	-122.003233995911103
43492	2020-08-09 05:17:44	2020-08-09	Norris Berge	norris.berge@geemail.com	Cincinnati	Ohio	54711559723360959	8b2c347a3d40b35cef7375a62d414df9	American Express	39.1131283824563027	-84.512569640417766
43493	2020-08-09 05:22:34	2020-08-09	Dr. Cannon Little IV	dr.cannon.little.iv@geemail.com	Kansas City	Kansas	3088304660067999999	67d1798b78356cc00138ad47d73d8bb7	JCB 16 digit	39.2038055124599509	-94.8069308829896187
43494	2020-08-09 05:28:54	2020-08-09	Vic Douglas	vic.douglas@geemail.com	New York	New York	4628654458527484	7f3697d7e4799d93cde510044cac2a36	American Express	40.6437930450998266	-73.9332564326364547
43495	2020-08-09 05:31:40	2020-08-09	Addyson Hodkiewicz	addyson.hodkiewicz@geemail.com	Oakland	California	3158894435257717154	7c098d6254dc1974c5308321c0392ad3	American Express	37.811300037942587	-122.295520007925035
43496	2020-08-09 05:36:04	2020-08-09	Mr. Haskell Donnelly DVM	mr.haskell.donnelly.dvm@geemail.com	New York	New York	6011549375642192672	ba804e3ccf5ccbc98722f43fd32171ce	JCB 16 digit	40.5938497641813001	-73.8805719710782114
43497	2020-08-09 05:39:01	2020-08-09	Veola Carroll-Hoeger	veola.carroll.hoeger@geemail.com	Eugene	Oregon	3750268693251276	82a17d9cc264ae02eca93b459da22592	VISA 16 digit	44.0838088080014998	-123.183269401824859
43498	2020-08-09 05:40:41	2020-08-09	Jannette Hirthe-Yundt	jannette.hirthe.yundt@woohoo.com	Portland	Oregon	4179418859205584	fccbfd4d1d1c28582db045844f95a0c3	VISA 13 digit	45.6323920492902388	-122.644173047272488
43499	2020-08-09 05:45:38	2020-08-09	Shanika Altenwerth	shanika.altenwerth@woohoo.com	Fort Collins	Colorado	6011898634502757462	c3b1d99dffba2938a7e1f9ff40913b53	VISA 13 digit	40.608885625812043	-105.064359847963985
43500	2020-08-09 05:46:09	2020-08-09	Kaela Parker-Rippin	kaela.parker.rippin@geemail.com	Kenosha	Wisconsin	4048834994641	5c37672b2584e46bc59d6b70b8286a07	JCB 16 digit	42.5056464445617053	-87.8506070036202686
43501	2020-08-09 06:01:40	2020-08-09	Laurine Homenick	laurine.homenick@warmmail.com	San Francisco	California	3044057535052084	11a3d3839d2bd2c69c06d3a7e7b45ce5	Discover	37.7635080387679096	-122.447908988104857
43502	2020-08-09 06:02:07	2020-08-09	Pedro Kris I	pedro.kris.i@geemail.com	Sandy Springs	Georgia	3158236704299205859	be17ff8bc0154b7d87e69b5548234a63	VISA 16 digit	33.8472043596263958	-84.2858980675775626
43503	2020-08-09 06:07:08	2020-08-09	Cassidy Blick-Stehr	cassidy.blick.stehr@geemail.com	Pembroke Pines	Florida	3054764985036034	25ccdb6a7a4f4061be7e5b5dcfddd6fb	Mastercard	25.932861146008598	-80.2605677788980358
43504	2020-08-09 06:12:05	2020-08-09	Timmy Langosh	timmy.langosh@geemail.com	Thousand Oaks	California	4231375166225729	e82489cc873cfd4adfcba7bfae33ecbf	Maestro	34.0946578345533453	-118.913343164455895
43505	2020-08-09 06:12:24	2020-08-09	Doss Wilkinson	doss.wilkinson@geemail.com	San Francisco	California	54213081736800064	c747f065d3ce64e1a8626608a069e2cf	VISA 16 digit	37.7547579914244054	-122.4349468225153
43506	2020-08-09 06:16:47	2020-08-09	Braden Schaden	braden.schaden@geemail.com	Fort Collins	Colorado	3057994385624074	22a51c8f583ee3fb48aefafa51c26704	VISA 13 digit	40.5778736706513925	-104.966355003877737
43507	2020-08-09 06:19:54	2020-08-09	Domenica Armstrong-Kohler	domenica.armstrong.kohler@woohoo.com	Philadelphia	Pennsylvania	869984089327734242	c7491882c4b11d7842a9ebf4ce97e2bd	VISA 16 digit	40.0505709559150063	-75.0337080855753271
43508	2020-08-09 06:30:59	2020-08-09	Ms. Letha Blanda	ms.letha.blanda@geemail.com	New York	New York	52862086396807220	26d2c1972372e9cf60b07e95184fa182	Diners Club / Carte Blanche	40.6726803116258253	-73.9777412434004162
43509	2020-08-09 06:40:12	2020-08-09	Dr. Gerry Hermann Sr.	dr.gerry.hermann.sr.@geemail.com	Ann Arbor	Michigan	869998729852117867	b5698f6a6a3231af82fbb6e9975c00a6	JCB 15 digit	42.2518897925097505	-83.7818789488744073
43510	2020-08-09 06:46:04	2020-08-09	Beverly Feest DVM	beverly.feest.dvm@geemail.com	Laredo	Texas	6011024747738916996	96700435d7ff47882e1478703f382532	VISA 16 digit	27.5765438060924417	-99.4517170396640893
43511	2020-08-09 06:46:23	2020-08-09	Jobe Gusikowski	jobe.gusikowski@woohoo.com	Oakland	California	54219999942738014	0a4982cea1cd17d3410ed67308831924	JCB 16 digit	37.7967086659579437	-122.269207302930155
43512	2020-08-09 06:48:34	2020-08-09	Marisa Quitzon-Reichel	marisa.quitzon.reichel@geemail.com	Los Angeles	California	3096123750099743124	6e987bd4432534ae88ae333b6d2ae67e	VISA 16 digit	33.9805164772417356	-118.4685691134531
43513	2020-08-09 06:58:33	2020-08-09	Keshawn Williamson	keshawn.williamson@geemail.com	New York	New York	589358804624003	de7f7982ba78513c852bb779acedb152	Discover	40.6305487055089287	-73.9645706024382292
43514	2020-08-09 07:04:43	2020-08-09	Shyanne Schulist-Botsford	shyanne.schulist.botsford@geemail.com	San Francisco	California	4106501663285	52dc73b9ecd70526801276df732411b9	JCB 16 digit	37.7845893122765659	-122.366175696681026
43515	2020-08-09 07:07:27	2020-08-09	Ms. Hallie Hauck MD	ms.hallie.hauck.md@geemail.com	Pittsburgh	Pennsylvania	3158058961445680220	1e2a89211bd786b29b9a778f8b7b392d	Voyager	40.372516611633074	-79.9042064873673041
43516	2020-08-09 07:09:02	2020-08-09	Junius Kuvalis-Mosciski	junius.kuvalis.mosciski@geemail.com	San Francisco	California	501818481807958	cb59068f436098a07f52fb9463c93066	Mastercard	37.7908944573839989	-122.441338968354003
43517	2020-08-09 07:11:45	2020-08-09	Evalyn Dickens	evalyn.dickens@geemail.com	Centennial	Colorado	3036252012798659	a1b7d6dff2b707f166b70785bae1b217	VISA 16 digit	39.654419193467497	-104.889269683685527
43518	2020-08-09 07:12:57	2020-08-09	Salvatore Littel	salvatore.littel@geemail.com	Indianapolis	Indiana	4545543050178210	f101185f1c907b227782597774f62c0a	JCB 15 digit	39.8376970766585288	-86.1173792934246336
43519	2020-08-09 07:20:07	2020-08-09	Keanna Beer-Bauch	keanna.beer.bauch@geemail.com	San Jose	California	3096180818724181299	2c3d37bf89fcc0c6dc3514e6ba5507bf	VISA 16 digit	37.2588279367711408	-121.726280297360944
43520	2020-08-09 07:28:26	2020-08-09	Pallie Huel	pallie.huel@warmmail.com	Berkeley	California	4133832866690999	76ec03d16a8c2f1eb083f9a4994fd7f6	JCB 16 digit	37.8539663313994552	-122.292787542675626
43521	2020-08-09 07:34:26	2020-08-09	Wes Reichel	wes.reichel@geemail.com	Baton Rouge	Louisiana	3789946841641788	f26fa9834698e2b1a555d5a289e324b4	American Express	30.4793391030028467	-91.1277548862729248
43522	2020-08-09 07:34:34	2020-08-09	Jacquline Hickle	jacquline.hickle@geemail.com	Santa Ana	California	3096368789190578678	242aba7b38d862fcfcfc6ff734e29676	Mastercard	33.6551700741156949	-117.861924124129118
43523	2020-08-09 07:44:45	2020-08-09	Maxim Hane	maxim.hane@geemail.com	Columbus	Georgia	869943131550722716	488f184f62789c7bf9fa0181688c1a8f	American Express	32.4348493417303985	-84.9312723836094108
43524	2020-08-09 07:54:16	2020-08-09	Ron Rippin	ron.rippin@warmmail.com	Grand Prairie	Texas	52296974772070479	07f8cf96d0ad4068566b37bec658c312	JCB 16 digit	32.7277241270110011	-97.08853205813692
43525	2020-08-09 07:57:47	2020-08-09	Danna Davis	danna.davis@geemail.com	San Diego	California	3047605816607443	159fb23dae76b1aedd161a0cf733e8ee	Mastercard	32.8953432724412522	-117.207402939479806
43526	2020-08-09 07:58:00	2020-08-09	Brittani Lindgren-Kris	brittani.lindgren.kris@geemail.com	Gresham	Oregon	6011475717915739887	b94ca79832f13f335c8bbfa622c7e859	VISA 16 digit	45.4781200389798741	-122.375363370523218
43527	2020-08-09 08:02:09	2020-08-09	Dr. Adolphus Vandervort DVM	dr.adolphus.vandervort.dvm@geemail.com	Columbia	South Carolina	6011031607646105838	85058b9689e18926ea29786b89dc5121	Diners Club / Carte Blanche	33.9876317119490352	-80.8491451504193179
43528	2020-08-09 08:06:20	2020-08-09	Vlasta Keebler DDS	vlasta.keebler.dds@geemail.com	Honolulu	Hawaii	3024345364419627	923ad63a3b11602ed7d803359107b82b	Discover	21.3880926624622205	-157.911762170141941
43529	2020-08-09 08:13:59	2020-08-09	Dr. Kazuo Roberts	dr.kazuo.roberts@geemail.com	San Francisco	California	180039116400385729	580eaef3bfce6cbd2649d012d2f8e162	JCB 16 digit	37.7992257803712306	-122.430238540475997
43530	2020-08-09 08:14:06	2020-08-09	Lorene Konopelski	lorene.konopelski@geemail.com	San Antonio	Texas	210074382281136617	0ac3b5a1c48906193107acc1d124fa25	American Express	29.4899379020161945	-98.4722561039797881
43531	2020-08-09 08:14:37	2020-08-09	Jennie Koss	jennie.koss@geemail.com	Springfield	Missouri	501838535629562	37d6c1b19af433cbddc0091a6da54693	Diners Club / Carte Blanche	37.1991382473807803	-93.1959948603354462
43532	2020-08-09 08:15:29	2020-08-09	Mr. Verner Hackett	mr.verner.hackett@geemail.com	Newark	New Jersey	869978342420868427	232313ceb266769a063b5f73da4b7661	VISA 13 digit	40.6533593369562212	-74.1225191816896256
43533	2020-08-09 08:25:10	2020-08-09	Mr. Wendell Tromp Jr.	mr.wendell.tromp.jr.@geemail.com	Columbus	Ohio	3158427238070329140	ec7315cc53d7e4c12ce1a2140aad74b9	JCB 15 digit	39.934879833510891	-83.0051950165771046
43534	2020-08-09 08:25:27	2020-08-09	Epsie O'Conner MD	epsie.o'conner.md@geemail.com	Amarillo	Texas	3112961360914751594	9060710b4e6c4258cc7d9d43c761185f	JCB 15 digit	35.1519154313184288	-101.776408545984708
43535	2020-08-09 08:28:24	2020-08-09	Delmas Brown	delmas.brown@geemail.com	Springfield	Missouri	501815369379845	c3e147e6d547167f2b46902cbb8e9b70	VISA 16 digit	37.2475271178603222	-93.2653339656826148
43536	2020-08-09 08:40:21	2020-08-09	Justice Borer	justice.borer@geemail.com	Tacoma	Washington	3036031246542590	8ffda940f6ffc90aa20de36e9b08da55	JCB 16 digit	47.2469258434258421	-122.536325101019074
43537	2020-08-09 08:42:57	2020-08-09	Needham Ryan Sr.	needham.ryan.sr.@geemail.com	Los Angeles	California	4924826912412443	55aaa74a15b4c72fec59b9d4c322fae5	Mastercard	33.9712905485980201	-118.337612383579085
43538	2020-08-09 08:42:59	2020-08-09	Lorna Kiehn PhD	lorna.kiehn.phd@geemail.com	New York	New York	561217812388506	aa5c433c7b52bcebf7e21693d4535a71	JCB 15 digit	40.7186465079188338	-74.0277958047937545
43539	2020-08-09 08:47:33	2020-08-09	Hunter Lebsack	hunter.lebsack@geemail.com	San Francisco	California	180017985738709230	0b681dbd05113fba635923db986c0207	VISA 16 digit	37.78699159669344	-122.435789348178801
43540	2020-08-09 08:53:09	2020-08-09	Mr. Irl Deckow PhD	mr.irl.deckow.phd@geemail.com	Nashville	Tennessee	3096518285886217118	7748926d5156c77667d6776b369a9294	Discover	36.1544388486195345	-86.8099200914055018
43541	2020-08-09 08:58:13	2020-08-09	Donald Bechtelar	donald.bechtelar@woohoo.com	San Diego	California	3096768767028466718	bf183d5380d976df2c6906dd16de8185	Voyager	32.7909455714348681	-117.150802335366606
43542	2020-08-09 09:16:13	2020-08-09	Daunte West	daunte.west@warmmail.com	Los Angeles	California	6011178332380821150	5498f216a63e8bdf51c06d89a00e31c9	JCB 16 digit	34.0821179554663587	-118.431200362275533
43543	2020-08-09 09:20:54	2020-08-09	Ms. Lular Schamberger	ms.lular.schamberger@warmmail.com	Toledo	Ohio	6011198903873411562	17b82e6df0932c6e683546d6350d2472	JCB 16 digit	41.758052199118211	-83.650828115535532
43544	2020-08-09 09:21:56	2020-08-09	Rashad Lueilwitz	rashad.lueilwitz@geemail.com	Henderson	Nevada	3112030015471131344	4898d9c3e8f9616e7bd6856abd711031	JCB 16 digit	36.0459972040195069	-115.104005783439433
43545	2020-08-09 09:25:54	2020-08-09	Mr. Josue Fadel	mr.josue.fadel@geemail.com	League City	Texas	869981093349327319	b3fcf22000f8f3f7bc46e83714df6b63	VISA 16 digit	29.5890565647672865	-95.1966499217770945
43546	2020-08-09 09:28:46	2020-08-09	Teressa Bradtke	teressa.bradtke@geemail.com	Seattle	Washington	4877331637904821	e4d3a61f0ae3e7fdf85040987f13de7d	VISA 13 digit	47.5969138241298495	-122.385496628881981
43547	2020-08-09 10:02:38	2020-08-09	Brodie Paucek	brodie.paucek@geemail.com	Henderson	Nevada	4769753925221	d0db7b4e2866769cac2d2b9d197a8503	American Express	35.9225736876882635	-115.112350188071659
43548	2020-08-09 10:06:13	2020-08-09	Thor Crist	thor.crist@woohoo.com	Albuquerque	New Mexico	675931745615331	0d5ddf1bc2c99aa10f07218224524b31	Maestro	35.1110583705496069	-106.687494629116358
43549	2020-08-09 10:13:11	2020-08-09	Loma Schultz	loma.schultz@geemail.com	New York	New York	3158442515572768839	f1e46fdeb1c4fa68d895d4642eed4ede	VISA 13 digit	40.5740402498505972	-73.971421435232088
43550	2020-08-09 10:18:59	2020-08-09	Benjamen Fahey	benjamen.fahey@geemail.com	San Francisco	California	869977056747559136	8c54aed58f1a50a1c88f11c5f8423b66	JCB 16 digit	37.781011113999547	-122.437506697471719
43551	2020-08-09 10:34:48	2020-08-09	Effa Thiel	effa.thiel@geemail.com	Berkeley	California	501860717485399	7f26dca8cbbf8747ec69b1f1f303fc5b	American Express	37.8649272302820634	-122.287395846097098
43552	2020-08-09 10:37:00	2020-08-09	Dominga Bednar PhD	dominga.bednar.phd@geemail.com	San Diego	California	3112319677074666299	725694e8cbde1df6f683d9041e29d45e	JCB 16 digit	32.746970628720895	-117.05608326633461
43553	2020-08-09 10:41:49	2020-08-09	Ms. Dyan Johnston MD	ms.dyan.johnston.md@woohoo.com	Topeka	Kansas	6011299883082425108	f3b2bdc4f6a1801fb30cff55ca051dbe	Maestro	39.0709289859447608	-95.7193003308668722
43554	2020-08-09 11:10:32	2020-08-09	Hermine Kutch DVM	hermine.kutch.dvm@woohoo.com	Jacksonville	Florida	4912918121159149	f8469e7e043a02513d5856f5e88bea1c	JCB 16 digit	30.3345174607407309	-81.7125636107832207
43555	2020-08-09 11:16:49	2020-08-09	Cherie Von	cherie.von@geemail.com	Murfreesboro	Tennessee	3096649156352381682	3eb59f2fc1b1d1a93c6c26780a8f7fe9	JCB 16 digit	35.9143611218899537	-86.3380365651417492
43556	2020-08-09 11:30:30	2020-08-09	Leatha Littel	leatha.littel@geemail.com	Naperville	Illinois	3703213813363104	8d2c67c18cb3272f820c4972c7eb2e66	Maestro	41.8194108306810293	-88.2397941043954432
43557	2020-08-09 11:31:25	2020-08-09	Mr. Giles Ankunding III	mr.giles.ankunding.iii@geemail.com	San Jose	California	4044536605794438	90f4cf52ee29c5d7c06b39a6989b9588	American Express	37.2939225685603901	-121.770517182511838
43558	2020-08-09 11:35:59	2020-08-09	Miss Linette Barton MD	miss.linette.barton.md@geemail.com	Saint Paul	Minnesota	3158356400287470738	71b682819ba54e56a6cd2ee1b117b5a3	VISA 16 digit	44.9998332220535744	-93.1791281163957024
43559	2020-08-09 11:36:16	2020-08-09	Dr. Donie Bahringer	dr.donie.bahringer@woohoo.com	Oklahoma City	Oklahoma	3035078836438888	b760469f41006be6b0945c1d13a44903	VISA 16 digit	35.4011158055536441	-97.5658765435114503
43560	2020-08-09 11:41:18	2020-08-09	Lauryn Terry	lauryn.terry@geemail.com	Peoria	Illinois	4231072414856195	f0a4c8115d69febdc3b82f0f00998f16	Discover	40.7856116129420698	-89.6481917958125507
43561	2020-08-09 11:41:21	2020-08-09	Kenya Hodkiewicz	kenya.hodkiewicz@warmmail.com	New York	New York	3112862974844454036	c5fc611413af36d99d66dd8551433220	JCB 15 digit	40.6415633051414034	-73.933977109043667
43562	2020-08-09 11:41:21	2020-08-09	Jaden McLaughlin	jaden.mclaughlin@geemail.com	Akron	Ohio	4257213801898346	abbe6ebc682cc5fa0e6a26219387efd6	JCB 16 digit	40.9885344024114318	-81.5085579195838363
43563	2020-08-09 11:43:45	2020-08-09	Hunt Schneider	hunt.schneider@geemail.com	Bridgeport	Connecticut	54158633924712241	7a750ea0274b185fed76485726f358fe	Voyager	41.1645165834739757	-73.189518772986915
43564	2020-08-09 11:47:48	2020-08-09	Chancy Bins-Erdman	chancy.bins.erdman@woohoo.com	Honolulu	Hawaii	869955978817255731	0b16e6d4ffc656c43fed44154add5e3e	VISA 16 digit	21.3495188323996956	-157.935479765406257
43565	2020-08-09 11:51:56	2020-08-09	Karyme Schuppe-Buckridge	karyme.schuppe.buckridge@geemail.com	San Francisco	California	6011242437715024362	b767ea356726eae887fa4ee3bd508b63	Maestro	37.7836024437236233	-122.455793200574618
43566	2020-08-09 11:54:49	2020-08-09	Peter Gleichner	peter.gleichner@geemail.com	Miramar	Florida	869926615712436133	8ad9ba048fe7bad0a9a1ff9ed8e45289	VISA 16 digit	25.9223181546181429	-80.2726687145877662
43567	2020-08-09 11:57:49	2020-08-09	Colleen Kling-Marvin	colleen.kling.marvin@geemail.com	Norfolk	Virginia	3096256800332127434	628d246bd97b89884eb3722477c98735	Mastercard	36.8454954949226234	-76.3084880291953738
43568	2020-08-09 11:58:38	2020-08-09	Valentino Parker	valentino.parker@geemail.com	Newport News	Virginia	3017546579610648	acc2915e7ded4b2217a464a1cf3533fb	Diners Club / Carte Blanche	37.0042672076158254	-76.4688101597391068
43569	2020-08-09 12:06:57	2020-08-09	Ingram West	ingram.west@geemail.com	Kansas City	Kansas	4337818536803	b98565cf98cc5ec6c014ada098faa459	Mastercard	39.1038069784548128	-94.6776443109318535
43570	2020-08-09 12:12:13	2020-08-09	Dr. Emmit Larson IV	dr.emmit.larson.iv@geemail.com	San Francisco	California	869959126116505770	13735aa53552dc9b7eb1127f31f994ac	Discover	37.7823595345451793	-122.395719944433338
43571	2020-08-09 12:15:07	2020-08-09	Kailee Greenfelder	kailee.greenfelder@geemail.com	Broken Arrow	Oklahoma	4373450062680026	7c0bfa0900b4427dd8451dac1450caea	VISA 16 digit	36.0893054133988898	-95.8639152415040883
43572	2020-08-09 12:17:16	2020-08-09	Olene Stroman	olene.stroman@geemail.com	San Francisco	California	3528155175606942970	d9f18c6b196dad2b307905cf0ffd30b1	Discover	37.7566125341060683	-122.437224423953282
43573	2020-08-09 12:25:02	2020-08-09	Krissy Kulas	krissy.kulas@woohoo.com	Oceanside	California	52145728779198730	7177da557ed842a39640f157f23ec658	VISA 16 digit	33.2502978183217337	-117.341200112373386
43574	2020-08-09 12:28:49	2020-08-09	Ozie Torp	ozie.torp@geemail.com	Yonkers	New York	561244473615001	960e6620aad848d23985bcf43f294009	VISA 13 digit	41.0348027164317699	-73.7816184237483981
43575	2020-08-09 12:32:10	2020-08-09	Dayse Ullrich PhD	dayse.ullrich.phd@geemail.com	Berkeley	California	6011448376298569884	2a716efe4baf4f42cbb07b03ac0bc390	American Express	37.8674685176051824	-122.262929813152056
43576	2020-08-09 12:47:33	2020-08-09	Manilla Bode	manilla.bode@geemail.com	New York	New York	210011707462986024	38fbfe049b16dfe5e9571b3e61e5a382	American Express	40.5836046465896061	-74.0261968914780795
43577	2020-08-09 12:52:14	2020-08-09	Abdiel Rolfson	abdiel.rolfson@geemail.com	Phoenix	Arizona	6011178126284554572	65e53577aefec7e8cfc2f42db2a46eaf	Maestro	33.5731087984450198	-112.139647819327564
43578	2020-08-09 12:52:20	2020-08-09	Elinore Jacobs	elinore.jacobs@warmmail.com	Los Angeles	California	676375571335787	d933c6dd1f58c13ca5d50042c6a0e6dd	Maestro	34.0034276284143289	-118.508689868589116
43579	2020-08-09 12:57:53	2020-08-09	Aimee Kilback-Ferry	aimee.kilback.ferry@geemail.com	Sterling Heights	Michigan	6011310947165488526	c349105180d7dce97b48808a92336fbd	JCB 16 digit	42.6170913379721341	-82.9563953678283781
43580	2020-08-09 12:58:00	2020-08-09	Vassie Price MD	vassie.price.md@geemail.com	Albuquerque	New Mexico	3058811983253933	14f01488412a89acd686db9043d21ddc	VISA 16 digit	35.1574218208104412	-106.670441734658183
43581	2020-08-09 13:05:47	2020-08-09	Annabella Ryan	annabella.ryan@geemail.com	Cincinnati	Ohio	3002684832584154	8236259ac432928158191d9ac83e5260	VISA 13 digit	39.0645221538141385	-84.5654416230313473
43582	2020-08-09 13:22:37	2020-08-09	Bettylou Larson	bettylou.larson@woohoo.com	Berkeley	California	3757248620768132	f212d4c49fdbf76314bfe9d52d33dfa2	Discover	37.8561961793735762	-122.292072220456035
43583	2020-08-09 13:29:12	2020-08-09	Mr. Winfred Lesch V	mr.winfred.lesch.v@geemail.com	New York	New York	676168146074288	b40402e54067a526218b14c94edb88a4	American Express	40.6157363344207383	-73.9664498567476869
43584	2020-08-09 13:38:33	2020-08-09	Dr. Jaclyn Fahey	dr.jaclyn.fahey@geemail.com	Arlington	Texas	6011548489441178047	d32223add4a1058c6a719e8795a678c3	JCB 15 digit	32.6149327642533891	-97.1026492539353683
43585	2020-08-09 13:39:41	2020-08-09	Denton Koch	denton.koch@geemail.com	Los Angeles	California	4558402394258242	49aa0047f7f45f64574d925bbabf8557	Maestro	34.1134706739667806	-118.356802353215585
43586	2020-08-09 13:40:14	2020-08-09	Edwin Cassin IV	edwin.cassin.iv@geemail.com	San Francisco	California	869915164061700586	f30a5f0f4e06683688ecac2a1069df61	American Express	37.7694869323100164	-122.449244587173752
43587	2020-08-09 13:42:08	2020-08-09	Rolland Marvin	rolland.marvin@geemail.com	Virginia Beach	Virginia	3112093716716852818	9568dca9c65863a9cad00771787c87b6	JCB 16 digit	36.6839686793461439	-76.0877372603535633
43588	2020-08-09 13:49:06	2020-08-09	Mr. Duard Hammes Sr.	mr.duard.hammes.sr.@geemail.com	Chicago	Illinois	4993802904853866	4d3032ed487949798948e828401d93e1	Maestro	41.7551780582241747	-87.6472397173784685
43589	2020-08-09 13:52:12	2020-08-09	Dinah Friesen	dinah.friesen@geemail.com	Raleigh	North Carolina	4175406108696905	1daead2de5529a6bc655f3563dcac1c3	VISA 13 digit	35.9291421812161786	-78.6536387658149039
43590	2020-08-09 14:02:40	2020-08-09	Miss Lucretia Mills PhD	miss.lucretia.mills.phd@geemail.com	Anchorage	Alaska	3096009054977725249	e780a3557b985803a7f3cf61118bcc37	Voyager	61.2161294938746892	-149.257774812693896
43591	2020-08-09 14:06:10	2020-08-09	Mrs. Madelene Hammes	mrs.madelene.hammes@geemail.com	San Francisco	California	4856020982975032	c5e401b7ab7c4413a265c01665754894	Voyager	37.7852125643662333	-122.443588229806451
43592	2020-08-09 14:13:58	2020-08-09	Jameson DuBuque	jameson.dubuque@geemail.com	Fort Worth	Texas	4609513217008	17f39b635e5656baed06bba9c6fdc8f6	Maestro	32.8515169807765659	-97.2986674494862598
43593	2020-08-09 14:16:40	2020-08-09	Mr. Jonathan Dietrich	mr.jonathan.dietrich@woohoo.com	Glendale	Arizona	6011327408960438704	336423f5d1ac2fb0eac7ff9daa3e2bb3	American Express	33.5377427651774127	-112.263558673465241
43594	2020-08-09 14:20:47	2020-08-09	Cleo Conroy-Rath	cleo.conroy.rath@geemail.com	Oakland	California	53935127689772730	7bedef5476ad11fd4f87ee9aafe74b40	VISA 13 digit	37.8227618706561017	-122.23483175212057
43595	2020-08-09 14:25:57	2020-08-09	Verl Hoppe V	verl.hoppe.v@geemail.com	Santa Clarita	California	6011791980250759137	acb15fb11c4008b690da36728d74ea14	VISA 16 digit	34.4215697637498366	-118.588079887638614
43596	2020-08-09 14:46:05	2020-08-09	Gabe Bernier	gabe.bernier@geemail.com	San Francisco	California	4774719692437808	571caf27f3c6e9ee84f4b6f7f668b452	Mastercard	37.792240441090847	-122.427794034209143
43597	2020-08-09 14:46:26	2020-08-09	Garret Hoppe	garret.hoppe@warmmail.com	Torrance	California	210052917879725945	58bdf6603bcc8706e0ab75b281cd1280	JCB 16 digit	33.7411230503954016	-118.370608126943551
43598	2020-08-09 14:51:42	2020-08-09	Mrs. Ina Price	mrs.ina.price@geemail.com	Anchorage	Alaska	4528621041245305	ea8ea4095f73ab6ee6d6a3e81ea7ce9e	JCB 16 digit	61.2618153274275414	-149.31461548303551
43599	2020-08-09 15:00:26	2020-08-09	Che Jenkins	che.jenkins@geemail.com	Kansas City	Missouri	3337801225458031956	94cf1ed1ca950e0136535999b21de93b	JCB 16 digit	39.1557455425452474	-94.6453731927778534
43600	2020-08-09 15:01:48	2020-08-09	Casimer Abernathy	casimer.abernathy@geemail.com	Fort Worth	Texas	6011638816159092336	b1cf4fd8889a1234b58a7932a9651689	Mastercard	32.7606769619099794	-97.3316473454989506
43601	2020-08-09 15:08:45	2020-08-09	Janiya Crooks	janiya.crooks@woohoo.com	Tallahassee	Florida	3012848554673178	dd3e1278e293970134b95796dd180f86	JCB 16 digit	30.5180443161655219	-84.200889410964777
43602	2020-08-09 15:21:49	2020-08-09	Mr. Gaetano Bogisich	mr.gaetano.bogisich@warmmail.com	Los Angeles	California	180063335732563683	3286e0651b524d4c190e9fe52044b6d0	VISA 13 digit	33.9473598968569164	-118.500209358706314
43603	2020-08-09 15:37:41	2020-08-09	Kasandra Dietrich	kasandra.dietrich@geemail.com	North Charleston	South Carolina	4033614289412	8497d66cb27f7bc65740518a407a956d	American Express	32.9379325499452662	-80.0828333488758659
43604	2020-08-09 15:40:16	2020-08-09	Mr. Talon Leuschke	mr.talon.leuschke@geemail.com	Memphis	Tennessee	4120647698196	21764ab1323ba00ae9bf9cc2148d7f22	Discover	35.0680870940044542	-90.0391286400869575
43605	2020-08-09 15:48:30	2020-08-09	Dr. Yamilet Hintz	dr.yamilet.hintz@geemail.com	Carrollton	Texas	4540239263425820	11ce52161f1b9eacdb7448cdeacce88d	VISA 13 digit	32.9271122639920577	-96.8017962244667132
43606	2020-08-09 15:51:10	2020-08-09	Dr. Isai Ziemann I	dr.isai.ziemann.i@geemail.com	San Francisco	California	3096216223395529827	fc36c866a1c565acfd345a62d18dd8a1	JCB 16 digit	37.7923536809990068	-122.404769748129198
43607	2020-08-09 15:51:23	2020-08-09	Pearline Bradtke DVM	pearline.bradtke.dvm@geemail.com	Hialeah	Florida	4167619391595226	7344aeed603f28c9e709a6427cb9e126	VISA 16 digit	25.8960822074651738	-80.3729499056372703
43608	2020-08-09 15:55:37	2020-08-09	Mr. Love Larson II	mr.love.larson.ii@woohoo.com	Montgomery	Alabama	869920340523706576	f2276403e4acc52dbdb6288bb8052c60	Mastercard	32.3164059539258517	-86.3519727526851
43609	2020-08-09 15:57:34	2020-08-09	Brion Larkin MD	brion.larkin.md@warmmail.com	Plano	Texas	3746541365447001	ffa01ae7ebeba929c779afd555e53f99	JCB 16 digit	32.9659327614206816	-96.757457974804197
43610	2020-08-09 16:19:29	2020-08-09	Zaiden Jacobi I	zaiden.jacobi.i@geemail.com	New York	New York	55117653409327570	7d6ec81cb9c7d1c0e3cd2d365927afd9	Voyager	40.7478093149363971	-73.9039693879324915
43611	2020-08-09 16:21:43	2020-08-09	Desi Prohaska	desi.prohaska@warmmail.com	Atlanta	Georgia	4239220384729544	c9e41a6ebbde45b312965591639fbb97	Diners Club / Carte Blanche	33.778672477677091	-84.4501975350126628
43612	2020-08-09 16:23:55	2020-08-09	Daron Stracke	daron.stracke@geemail.com	Memphis	Tennessee	3036336272837289	f1074060b0443ffecbbf5b461d74ff18	VISA 13 digit	35.1413792737826753	-89.919263398812717
43613	2020-08-09 16:29:03	2020-08-09	Spurgeon Ankunding	spurgeon.ankunding@geemail.com	New York	New York	54832144003015799	f75cebabf2cb0ce09b9d591e9e0ceb37	Maestro	40.5845919497068977	-74.0001452005363944
43614	2020-08-09 16:33:50	2020-08-09	Palma Bins	palma.bins@warmmail.com	Murfreesboro	Tennessee	51369387376527228	95c391b4caa45d956687deefe9d71bfe	Voyager	35.8999716320659985	-86.3533350884299722
43615	2020-08-09 16:36:35	2020-08-09	Mr. Beryl Bechtelar DVM	mr.beryl.bechtelar.dvm@geemail.com	Spokane	Washington	3528744884901521532	1fb6061141d4abd2318e5d24701fbb7e	Maestro	47.6462329603970005	-117.362922877202934
43616	2020-08-09 16:37:21	2020-08-09	Floy Hammes	floy.hammes@geemail.com	Clovis	California	51004603301041478	b6bfd7bdfe13857ae0ab08d73a5f61fd	Maestro	36.7345626699615266	-119.615379680187999
43617	2020-08-09 16:52:02	2020-08-09	Mr. Gust Hansen	mr.gust.hansen@warmmail.com	Orlando	Florida	53185603621465853	a63f336ebd6b6d768eef8f99eb241696	Discover	28.4579953927811218	-81.2694307507447888
43618	2020-08-09 16:54:33	2020-08-09	Frieda Hirthe	frieda.hirthe@geemail.com	Aurora	Colorado	54867759637903538	b312bbd04fa49b82f3d9daa3e600de59	JCB 16 digit	39.6849868532847623	-104.720591968682413
43619	2020-08-09 17:01:51	2020-08-09	Rollin Gleichner	rollin.gleichner@geemail.com	New York	New York	869990726365409011	02e12741a07c27f899d9a7665abb54a5	VISA 16 digit	40.6139326072521527	-73.8638380319241463
43620	2020-08-09 17:02:41	2020-08-09	Vaughn Berge-Bayer	vaughn.berge.bayer@geemail.com	St. Petersburg	Florida	52983388680483344	b2a0bb6103880e987974202c43db9b81	VISA 16 digit	27.7062918626591568	-82.6837996241994091
43621	2020-08-09 17:05:44	2020-08-09	Karma Maggio PhD	karma.maggio.phd@woohoo.com	Los Angeles	California	3112204223114055900	f08bf7fecc5c96ec62fc97ebfc94377a	VISA 16 digit	34.0348552343301449	-118.324028514278297
43622	2020-08-09 17:09:18	2020-08-09	Volney Hermann	volney.hermann@geemail.com	Fort Worth	Texas	3096021442326792578	be3d2b6901c015fb9855972e17478e7a	VISA 16 digit	32.8216816330384447	-97.4317371851120129
43623	2020-08-09 17:10:12	2020-08-09	Jerad Dicki	jerad.dicki@geemail.com	San Francisco	California	3337327717083669718	db3ebdcb065c74d1d93ece9ceaece3ff	JCB 15 digit	37.7698387303401759	-122.448772836064464
43624	2020-08-09 17:10:33	2020-08-09	Gideon Kshlerin-Haag	gideon.kshlerin.haag@geemail.com	Cleveland	Ohio	869950086184118725	d300116fe080f5d973d72d09c4e690ce	Maestro	41.4867918975036574	-81.6693946652352878
43625	2020-08-09 17:11:01	2020-08-09	Miesha Leffler	miesha.leffler@geemail.com	Houston	Texas	53602358171167855	8c1a0d9f686a61df7805822c477c05ba	Mastercard	29.7263725665476173	-95.3253949353951953
43626	2020-08-09 17:22:03	2020-08-09	Alwin Cassin	alwin.cassin@geemail.com	Los Angeles	California	3088747789479845212	3dfe3ae6a72247ac5e1bedcc42ccf83f	VISA 16 digit	34.0503873279184077	-118.49487651777379
43627	2020-08-09 17:22:25	2020-08-09	Kaycee Cartwright	kaycee.cartwright@geemail.com	San Francisco	California	4357637759697384	05e786f2c596444830953b3a5c44b928	VISA 16 digit	37.7655073314647112	-122.437118703344154
43628	2020-08-09 17:26:21	2020-08-09	Kennith Beier I	kennith.beier.i@geemail.com	New York	New York	3158854490030681886	3a97b04d5017a43053a1f36f515a4cb3	JCB 16 digit	40.7010502000562866	-73.9129059187497859
43629	2020-08-09 17:37:25	2020-08-09	Tamiko Larson	tamiko.larson@geemail.com	Dallas	Texas	180032427650763888	248005058b44df3ab9c119bd68a37d63	Discover	32.7295133742775803	-96.8164546205624816
43630	2020-08-09 17:39:43	2020-08-09	Gina Bogan	gina.bogan@geemail.com	Phoenix	Arizona	4591645574045	7783ac521dd19add4500ca48c9467d05	Maestro	33.6111980273786983	-112.185684412990142
43631	2020-08-09 17:44:13	2020-08-09	Lorean Veum	lorean.veum@geemail.com	Los Angeles	California	3792411874067869	7690dde38db1fcf8a5c17ded893dfe16	Diners Club / Carte Blanche	34.1113323876034471	-118.449341592843822
43632	2020-08-09 17:46:15	2020-08-09	Miss Carri Bartoletti PhD	miss.carri.bartoletti.phd@geemail.com	Honolulu	Hawaii	54178593611675695	22da18743c53c2aa441051388f829f58	Voyager	21.2958499632991867	-157.869989677353203
43633	2020-08-09 17:50:31	2020-08-09	Antwan McCullough	antwan.mccullough@geemail.com	San Bernardino	California	3044614223951769	e0501b627be60a62a17375bc2165bae7	Maestro	34.2323518981955885	-117.35153880755081
43634	2020-08-09 18:08:21	2020-08-09	Oma Wolf	oma.wolf@geemail.com	Oakland	California	3718393685573841	d9a9f3a3be5281aa9e360850692f4a07	Diners Club / Carte Blanche	37.7873538402986355	-122.310340512430443
43635	2020-08-09 18:10:55	2020-08-09	Blaze Koch	blaze.koch@warmmail.com	Oakland	California	4256983315361327	bb18594a95d3cb1c46e458e9350a6ca3	Voyager	37.7885545323347927	-122.327503317242176
43636	2020-08-09 18:17:50	2020-08-09	Nicki Kuhic	nicki.kuhic@geemail.com	New York	New York	869984486950915090	3d4f7dafe01c3fc4081c771ddcd72df5	VISA 16 digit	40.7019053078480084	-73.9521493128396514
43637	2020-08-09 18:22:06	2020-08-09	Allie Morar	allie.morar@geemail.com	Billings	Montana	3088773563477636684	db55664c1e625b494259b53b5beb0670	Voyager	45.8485981103722011	-108.537933148925745
43638	2020-08-09 18:26:36	2020-08-09	Dr. Ivy Hayes	dr.ivy.hayes@geemail.com	Chicago	Illinois	4905508696960	105ce0ffbf68d852816443ea42774211	JCB 15 digit	41.7747100317686844	-87.7685236163001434
43639	2020-08-09 18:27:13	2020-08-09	Mr. Mordechai Prohaska V	mr.mordechai.prohaska.v@warmmail.com	New York	New York	869925663237275033	4c0c4faa0116ad06ce7420a564984bc8	Voyager	40.6548558588828897	-73.9763516441348941
43640	2020-08-09 18:36:08	2020-08-09	Elianna Bartell	elianna.bartell@warmmail.com	San Francisco	California	55631284177596571	e027ab9771c10cc2d11612e2fbc0edf2	Voyager	37.7785499295492713	-122.440976393864617
43641	2020-08-09 18:39:35	2020-08-09	Dr. Danny Huels	dr.danny.huels@woohoo.com	San Jose	California	3337896158186993757	c91b0bd582a1b22e60419cbb6740b0db	JCB 16 digit	37.2934081243637934	-121.866556423784786
43642	2020-08-09 18:43:39	2020-08-09	Urban Langosh Jr.	urban.langosh.jr.@geemail.com	New York	New York	869916528781040409	d649eb9aaabae4b7f42f2216e8693360	Mastercard	40.6526090379562248	-74.0047672236233893
43643	2020-08-09 18:49:09	2020-08-09	Aisha Gleichner DVM	aisha.gleichner.dvm@geemail.com	Allen	Texas	3015574428555519	64d2b17c5065f5feb02d3d6e89798d5d	VISA 16 digit	33.0318015569381416	-96.6976391800627084
43644	2020-08-09 18:55:44	2020-08-09	Gwyneth Moen	gwyneth.moen@geemail.com	Chesapeake	Virginia	54503668076182555	811c2640d451c5a4f66bfac8fb1dc730	JCB 16 digit	36.6973185095243153	-76.2061785394169391
43645	2020-08-09 18:57:48	2020-08-09	Mrs. Vada Wisoky	mrs.vada.wisoky@geemail.com	Memphis	Tennessee	3445605158185051	5a3ba6551dc717e243b049f5ad31c031	JCB 16 digit	35.1470164392210549	-89.8980302023492754
43646	2020-08-09 19:00:40	2020-08-09	Mrs. Tressie Jast MD	mrs.tressie.jast.md@geemail.com	New York	New York	6011624693026733400	972816a3922b531a073476a4148695f1	JCB 15 digit	40.7244317298978586	-74.0200972485251754
43647	2020-08-09 19:02:25	2020-08-09	Kathryne Hackett MD	kathryne.hackett.md@warmmail.com	Cleveland	Ohio	4864117614437975	042ae709892a734eba9a7a0fa2676256	Voyager	41.4124703483972638	-81.5914689536910487
43648	2020-08-09 19:13:25	2020-08-09	Darian Toy MD	darian.toy.md@geemail.com	Elk Grove	California	3096800768361385192	2ff8c1fb88e3226194c38e59f2c1b3a2	JCB 15 digit	38.4898005076967209	-121.426449238220229
43649	2020-08-09 19:21:23	2020-08-09	Brandy Kessler-Upton	brandy.kessler.upton@geemail.com	New York	New York	6011733826714320365	ff2dea2b0791e1f03c8e10409334bd62	VISA 16 digit	40.6698423026353097	-73.8515585768397926
43650	2020-08-09 19:21:39	2020-08-09	Brigid Mante	brigid.mante@woohoo.com	Ontario	California	869990466209384118	fb28c1c67824da95beb44d8f45f03b4d	Voyager	34.1012672360666116	-117.656693953239184
43651	2020-08-09 19:24:41	2020-08-09	Harlene Kris-Price	harlene.kris.price@warmmail.com	San Jose	California	869969272863244508	e942331b3b02435cf97daf1d90c502e2	Voyager	37.252423064905031	-121.777283363531907
43652	2020-08-09 19:27:55	2020-08-09	Guthrie D'Amore	guthrie.d'amore@geemail.com	New York	New York	55574012992050725	a6a187a9f32656120f00c2be646922e6	JCB 15 digit	40.6446653759796135	-73.9087100669637351
43653	2020-08-09 19:30:52	2020-08-09	Kyrie Wuckert	kyrie.wuckert@geemail.com	McAllen	Texas	4582463454367380	b05b55fe4fbe7b92fa3cd551013513f8	Maestro	26.3276182170331481	-98.1933555282033979
43654	2020-08-09 19:31:52	2020-08-09	Hildred Schultz	hildred.schultz@geemail.com	New York	New York	3528940233717497986	78bb6add976bc6cf65ba936a8205b86e	VISA 16 digit	40.7580601326413472	-73.997951187741748
43655	2020-08-09 19:34:02	2020-08-09	Montie Corkery	montie.corkery@geemail.com	Los Angeles	California	630432094086835	c072c2c7dbc2ae89be000dde49cc225c	Discover	34.0576896716706443	-118.392769388434658
43656	2020-08-09 19:42:14	2020-08-09	Bilal Schroeder-Senger	bilal.schroeder.senger@warmmail.com	San Francisco	California	869957338136936313	4cc102713eb393833dc835f9886a3890	Mastercard	37.7783228446311625	-122.459388996406147
43657	2020-08-09 19:44:17	2020-08-09	Huston Herzog-Waelchi	huston.herzog.waelchi@geemail.com	Hillsboro	Oregon	3112960477723650543	6f6967baf25d908f9561b003208164e6	Maestro	45.5952509712167071	-122.88048863165713
43658	2020-08-09 19:46:00	2020-08-09	Dr. Lizette Schaden	dr.lizette.schaden@geemail.com	Oakland	California	210092793679484161	d6c58e7d6610a62b0b9bb28f4025a23e	VISA 16 digit	37.7897907988588884	-122.262273870044254
43659	2020-08-09 19:46:42	2020-08-09	Derrick Nader-Goyette	derrick.nader.goyette@geemail.com	New York	New York	4585137715702	ca360832f812790960e866f7d2babf77	VISA 16 digit	40.6959717038311055	-74.0060337463289528
43660	2020-08-09 19:51:12	2020-08-09	Colvin Hoeger IV	colvin.hoeger.iv@geemail.com	San Francisco	California	869949877389572664	5b51af7fe3bf2c6ae709d1de7dfb6cad	VISA 16 digit	37.7879262327340086	-122.430102808512174
43661	2020-08-09 19:56:57	2020-08-09	Ms. Coletta Gulgowski DDS	ms.coletta.gulgowski.dds@geemail.com	Yonkers	New York	4011846487657	02436b1d4747e6b408563a9712db12a3	American Express	40.8517888281229915	-73.8256111621741269
43662	2020-08-09 20:11:42	2020-08-09	Miss Babette Douglas MD	miss.babette.douglas.md@geemail.com	Evansville	Indiana	3047153637144460	ea6712dbb302470517f09556262dab90	Discover	37.982793202916902	-87.5287699383150795
43663	2020-08-09 20:25:17	2020-08-09	Drema Volkman	drema.volkman@geemail.com	Corpus Christi	Texas	3096246199099826608	5105da914f5eb898ececfc72590c423c	Voyager	27.7670519826404743	-97.2593388323966366
43664	2020-08-09 20:40:06	2020-08-09	Mrs. Mariah Gibson	mrs.mariah.gibson@warmmail.com	Kansas City	Kansas	4108878116222076	9090a954b7bf114a4364115bb01a5d7a	VISA 13 digit	39.1612029062490947	-94.7292451447278268
43665	2020-08-09 20:43:29	2020-08-09	Ms. Juliana Kuhlman MD	ms.juliana.kuhlman.md@warmmail.com	Salem	Oregon	3112096598888126255	c4e068420c84b1f451328feede0a978a	VISA 13 digit	44.9332778352580959	-123.049686373692751
43666	2020-08-09 20:45:05	2020-08-09	Mr. Eden Schulist	mr.eden.schulist@geemail.com	Nashville	Tennessee	210095387665071038	3a3b454ab4b7f060d88fc96ae343ccdd	American Express	36.1267329642672053	-86.7134497370943365
43667	2020-08-09 20:48:18	2020-08-09	Betsey Roberts	betsey.roberts@warmmail.com	New York	New York	3528081492127261288	61eb2510ba498a6c7ee97c4d7e7ae2e2	JCB 15 digit	40.6759784404411917	-73.9574601993326013
43668	2020-08-09 20:52:34	2020-08-09	Angel Lehner	angel.lehner@geemail.com	Los Angeles	California	4159571060237723	ae5ccd94874f255cd618637b3b59e5ec	JCB 16 digit	34.0999066624190661	-118.415385007252169
43669	2020-08-09 20:57:19	2020-08-09	Amari Gaylord V	amari.gaylord.v@warmmail.com	Garland	Texas	3002980268416162	c32764ca7f1ae8693c24397a3758601c	VISA 16 digit	32.8701739676531375	-96.5926954799957684
43670	2020-08-09 20:58:13	2020-08-09	Dr. Cohen Wilderman	dr.cohen.wilderman@warmmail.com	Fort Worth	Texas	3790823035241617	61c7af11c1c28dcaa384dfeca711636a	Maestro	32.8424560789540436	-97.4314688006237191
43671	2020-08-09 21:13:01	2020-08-09	Forest Schmidt	forest.schmidt@warmmail.com	Richmond	California	210004264490925078	bb61a10b6f35ab33ccbed12e4252f4c7	JCB 16 digit	37.9786342283666158	-122.393889179624992
43672	2020-08-09 21:15:12	2020-08-09	Vita Bogisich	vita.bogisich@geemail.com	Oakland	California	3088007914437131233	11e13ed6c57a69c8b0550cb8b66a39f6	JCB 16 digit	37.7720130228765072	-122.285044702903193
43673	2020-08-09 21:18:53	2020-08-09	Antony Kub	antony.kub@geemail.com	Anaheim	California	210081210185098560	ee1cbd7c7a14b4c952e18e8094b3659a	VISA 16 digit	33.9396483748983613	-117.671267052248481
43674	2020-08-09 21:31:28	2020-08-09	Lindsey Von	lindsey.von@geemail.com	Chicago	Illinois	53327875862674646	98a6af355b686242ba10623a79456a9e	Maestro	41.9356366605799664	-87.6603304862074566
43675	2020-08-09 21:34:05	2020-08-09	Paulette Keebler PhD	paulette.keebler.phd@geemail.com	Miami	Florida	3040252397366391	ec93c005b322b96a29f44ce9ebbece5c	VISA 16 digit	25.7727459411274644	-80.1199654162269184
43676	2020-08-09 21:40:10	2020-08-09	Lilah Carter-Lind	lilah.carter.lind@warmmail.com	Philadelphia	Pennsylvania	210073922286422024	f81849bdbe37abf867f88fbdf5a6f1db	VISA 16 digit	39.9772034412674628	-75.1380826293855932
43677	2020-08-09 21:41:01	2020-08-09	Dr. Andreas Kohler PhD	dr.andreas.kohler.phd@warmmail.com	Sugar Land	Texas	54202825858500222	c2388de9fc68e34dc92f69874bdfe586	American Express	29.6864418677572139	-95.6319841726224809
43678	2020-08-09 21:48:26	2020-08-09	Rachael Hills	rachael.hills@geemail.com	Tulsa	Oklahoma	3112512063187775985	d4f7c67c7228f808abeb4b9594c2dfa8	American Express	36.2101903025895311	-95.9626768895845856
43679	2020-08-09 21:52:13	2020-08-09	Mrs. Yesenia Collins DVM	mrs.yesenia.collins.dvm@warmmail.com	Philadelphia	Pennsylvania	3404162499275695	80850928ccd1357a2503eec2157e3128	Discover	39.9835743857972332	-75.1345209583539599
43680	2020-08-09 21:55:27	2020-08-09	Anibal Homenick-Muller	anibal.homenick.muller@geemail.com	Philadelphia	Pennsylvania	3158756198303828543	cc009ff7ad98eeb261afb23fe39bf035	JCB 16 digit	39.9168502112343901	-75.1821368805963601
43681	2020-08-09 22:02:15	2020-08-09	Mrs. Kaitlyn Durgan	mrs.kaitlyn.durgan@warmmail.com	Provo	Utah	3112837842445904646	266b08967258a14045696ae7add6997f	VISA 16 digit	40.1515973353080469	-111.655425883564362
43682	2020-08-09 22:12:18	2020-08-09	Mr. Lannie Sawayn MD	mr.lannie.sawayn.md@geemail.com	Vallejo	California	3337624474271924931	9aa5095aca17e88b1655fb13348742e3	Discover	38.0641918113544619	-122.359252325572072
43683	2020-08-09 22:15:43	2020-08-09	Mr. Alphonsus Yost	mr.alphonsus.yost@geemail.com	San Antonio	Texas	4453525086584	480070baae648a7e7fba074806cc4b6a	JCB 16 digit	29.4374590382516388	-98.4451514496769704
43684	2020-08-09 22:18:08	2020-08-09	Miss Daisy Schinner	miss.daisy.schinner@warmmail.com	Los Angeles	California	6011513975980019627	886ae48221964ebf5a3c19077b2d317f	VISA 16 digit	34.0906781338021148	-118.475029268347839
43685	2020-08-09 22:28:32	2020-08-09	Dr. Nohely Bechtelar	dr.nohely.bechtelar@geemail.com	New York	New York	52014623596187479	0dc001639d2a339fcdebd36fe78b772a	JCB 16 digit	40.7398137726578824	-73.8964270865440369
43686	2020-08-09 22:28:54	2020-08-09	Ivy Yundt	ivy.yundt@woohoo.com	Akron	Ohio	3042439263423202	2b551c60fdaaa8a19aab8646cd20aae9	JCB 15 digit	40.9938291315753034	-81.5871075370196195
43687	2020-08-09 22:33:30	2020-08-09	Paulo Koch	paulo.koch@geemail.com	San Francisco	California	4866646234553	a4b51d7e98deace7fd12ec98d9626493	VISA 16 digit	37.7624308269576758	-122.42449428507021
43688	2020-08-09 22:36:54	2020-08-09	Elda Hauck PhD	elda.hauck.phd@woohoo.com	Oklahoma City	Oklahoma	3088928331805923578	6bca075f7bbe835595101533be6f3ea6	Mastercard	35.4628914166152498	-97.5168224819365861
43689	2020-08-09 22:37:39	2020-08-09	Shawnna Konopelski	shawnna.konopelski@geemail.com	Scottsdale	Arizona	4224449722287892	63fa7240cf087261815d5285b8c23a63	VISA 16 digit	33.6911875050172185	-111.948795543095457
43690	2020-08-09 22:41:46	2020-08-09	Ms. Leanne Emard	ms.leanne.emard@warmmail.com	Houston	Texas	869966525359121289	d97d33541d5e4e9c0d6afbe77200d156	VISA 16 digit	29.7269618816286325	-95.3664729235243129
43691	2020-08-09 23:01:43	2020-08-09	Joesph Bruen	joesph.bruen@geemail.com	Chicago	Illinois	3112089190736979207	2aacc7bcd4aa25febea9136ddddd5bbd	VISA 16 digit	41.8865279237110215	-87.7804408735625401
43692	2020-08-09 23:16:48	2020-08-09	Nevaeh Welch	nevaeh.welch@woohoo.com	Long Beach	California	4430496289611972	be51431d132f86defd98bc959bfbd34c	Diners Club / Carte Blanche	33.7278395000666364	-118.09681583532803
43693	2020-08-09 23:18:17	2020-08-09	Jewell Berge	jewell.berge@geemail.com	Oxnard	California	3011629283447501	1a5ba7d800aab144be2b849dcb180ab6	JCB 16 digit	34.1153982031114396	-119.281099772025271
43694	2020-08-09 23:28:02	2020-08-09	Douglas Funk	douglas.funk@woohoo.com	San Francisco	California	3022630514995556	5682b509f8167acbaf4c9535d002e53a	Mastercard	37.7395275985583538	-122.413438462720933
43695	2020-08-09 23:34:04	2020-08-09	Nealy Wolff	nealy.wolff@geemail.com	Washington	District of Columbia	3158921592537135578	0c8eca7816781a632f904353dc9968a9	VISA 13 digit	38.8654610957749185	-76.9787584654267931
43696	2020-08-09 23:35:21	2020-08-09	Myrtle Tremblay	myrtle.tremblay@geemail.com	Hampton	Virginia	869932109196594874	6e6dc6d99e85cc8a8b1cef12b5b1fb97	VISA 16 digit	37.0735195787176508	-76.2353115672342483
43697	2020-08-09 23:36:31	2020-08-09	Noemi Purdy	noemi.purdy@geemail.com	Los Angeles	California	869999339153694660	9485cbd014b2fad61e5f8102cefa1429	Maestro	34.0045783864200075	-118.502618132624022
43698	2020-08-09 23:37:16	2020-08-09	Robbie Padberg	robbie.padberg@geemail.com	San Francisco	California	4385162752362577	da8484c9d040bfa1e992ed4cbd97aaef	Voyager	37.7756538045166792	-122.410272711540344
43699	2020-08-09 23:40:10	2020-08-09	Jeannette Weber	jeannette.weber@geemail.com	New York	New York	210050380631717001	07889be26eb0d7e0fc75966acdc96001	Discover	40.6668342747483393	-73.9277985811129241
43700	2020-08-09 23:40:24	2020-08-09	Mr. Dillion Rippin IV	mr.dillion.rippin.iv@warmmail.com	New York	New York	6011313798371289431	f60b16cd7f89d2a0744b82e36d7a2e70	VISA 13 digit	40.659462861739101	-73.923780822138113
43701	2020-08-09 23:59:02	2020-08-09	Leoma Becker	leoma.becker@geemail.com	Detroit	Michigan	4190943967689846	c369f70b763da4c54fa1f908b025eb83	JCB 16 digit	42.2979917744565768	-83.0405062237407918
43702	2020-08-10 00:00:34	2020-08-10	Ahmed Ritchie-O'Keefe	ahmed.ritchie.o'keefe@geemail.com	Elk Grove	California	3158432043212406142	f4e6389efeaec7641aa4001390e71cc4	American Express	38.4932886448506295	-121.287151830354716
43703	2020-08-10 00:03:05	2020-08-10	Ms. Melvina Sawayn DDS	ms.melvina.sawayn.dds@geemail.com	New Orleans	Louisiana	3035487682394642	964b2dd066752922ad52dc942451d42f	JCB 16 digit	30.0115753649748846	-89.8792964765131472
43704	2020-08-10 00:17:05	2020-08-10	Dr. Demond Kshlerin DVM	dr.demond.kshlerin.dvm@warmmail.com	Denver	Colorado	4081765944970508	4f0b329441d7202cba0ac5ea46c23299	Diners Club / Carte Blanche	39.6849547588784191	-104.935235818919168
43705	2020-08-10 00:18:44	2020-08-10	Antonette Roob	antonette.roob@geemail.com	Detroit	Michigan	3096398198610062152	258ec59cde0dd25ee5a86624a4a4397b	Mastercard	42.3302686680499463	-83.1527486554931841
43706	2020-08-10 01:02:42	2020-08-10	Omer Schumm	omer.schumm@warmmail.com	Denver	Colorado	3731521037603527	f4f403f8a497e5f3b7768e244b803346	Maestro	39.8360632383316755	-104.973970633909488
43707	2020-08-10 01:08:47	2020-08-10	Deante O'Reilly	deante.o'reilly@geemail.com	Chicago	Illinois	4227362569490882	b9d91f30e9453ba1043534abcaf523cf	Diners Club / Carte Blanche	41.7863997218500813	-87.6909375505551623
43708	2020-08-10 01:26:03	2020-08-10	Fanny Rosenbaum	fanny.rosenbaum@geemail.com	Oakland	California	561285944068148	a4c57acee386f74d8dad83a1ba9906ef	VISA 13 digit	37.784368609113848	-122.268363645830206
43709	2020-08-10 01:35:19	2020-08-10	Hanna Haley DVM	hanna.haley.dvm@geemail.com	Las Cruces	New Mexico	869969937849725941	b570bd5fa55bba4c5235f5a0d23ff083	American Express	32.3851884252425251	-106.817177486850696
43710	2020-08-10 01:35:49	2020-08-10	Yair Bruen	yair.bruen@woohoo.com	McAllen	Texas	4455358104202	4e6164bab81233034d7768ab5cc533aa	American Express	26.3022280085206006	-98.2426891643401206
43711	2020-08-10 01:42:04	2020-08-10	Mr. Denton Sipes	mr.denton.sipes@geemail.com	Nashville	Tennessee	869918813010315774	7295801aed669faf5c7723e231e2b1ed	JCB 15 digit	36.076227904821927	-86.828172302190211
43712	2020-08-10 02:13:12	2020-08-10	Gillian Lowe-Armstrong	gillian.lowe.armstrong@geemail.com	Chicago	Illinois	4038491988929	badeaa904b9fcc2b8f7d397fa8399cee	VISA 13 digit	41.7486038356855502	-87.7387144095759766
43713	2020-08-10 02:19:24	2020-08-10	Karyn Gerlach	karyn.gerlach@geemail.com	Columbus	Ohio	4305332811736544	5a2f51699a073ceb936311961cd08e7a	VISA 16 digit	39.9100901819810261	-83.0367522323273164
43714	2020-08-10 02:19:56	2020-08-10	Stanley Koepp-Hammes	stanley.koepp.hammes@geemail.com	New York	New York	53052730242516770	398f4438177c8f27fe16255f21183f07	Discover	40.6270330135468356	-73.8663751783210785
43715	2020-08-10 02:22:26	2020-08-10	Rowan Rutherford	rowan.rutherford@geemail.com	Philadelphia	Pennsylvania	3483142764279345	4f8cb1b594f5a97ff53dddfd6a695e0c	American Express	39.98873226888999	-75.2319716641578822
43716	2020-08-10 02:33:49	2020-08-10	Jonell O'Conner	jonell.o'conner@geemail.com	New York	New York	4492725418478	1044ebb1756411e2ed47247c9c31e418	VISA 16 digit	40.7217595693878849	-73.8904893149051816
43717	2020-08-10 02:38:10	2020-08-10	Mr. Junious Runolfsdottir	mr.junious.runolfsdottir@geemail.com	League City	Texas	4441335032714112	5f8411cbd0820a168054335a452d4ff5	Voyager	29.5735786739200357	-95.1594529769368478
43718	2020-08-10 02:46:18	2020-08-10	Deyanira Predovic-Lockman	deyanira.predovic.lockman@geemail.com	Jacksonville	Florida	676263768439430	66e96511644c35199d08b84b16fef698	American Express	30.3827751141093678	-81.6121989430938015
43719	2020-08-10 02:51:28	2020-08-10	Jeffie Jakubowski	jeffie.jakubowski@woohoo.com	Miramar	Florida	4476336225869	86bd3a9f3c21940da15ec598fe8f217e	Discover	25.927404670462014	-80.3627489766098648
43720	2020-08-10 02:59:27	2020-08-10	Theodore Zieme	theodore.zieme@geemail.com	Oakland	California	210024890879460810	4ce9500af66f84569fe2cf436ccba70c	Voyager	37.7896230145481269	-122.258377112577676
43721	2020-08-10 02:59:54	2020-08-10	Van Gaylord	van.gaylord@geemail.com	Phoenix	Arizona	4451886122857	b30ebf31ad26925ec05526ed8f6e100a	JCB 16 digit	33.577581776764994	-112.037622131353629
43722	2020-08-10 03:00:12	2020-08-10	Sydnee Waelchi	sydnee.waelchi@geemail.com	Oklahoma City	Oklahoma	869943437646402019	329d37ee262cdc3252bdc4a0c149fc74	Discover	35.4236228501334836	-97.473467489042136
43723	2020-08-10 03:04:10	2020-08-10	Karlie Dickinson	karlie.dickinson@warmmail.com	Salem	Oregon	6011146665656425324	2a15ff14bd2fab12c6e7bccee3f6c473	JCB 15 digit	44.9309260126937176	-122.997649325026941
43724	2020-08-10 03:07:45	2020-08-10	Regenia Considine	regenia.considine@warmmail.com	New York	New York	4892671160047840	1ae67e225b827b8425d3cf2a54f7f26d	Discover	40.7155139809232196	-73.9828654929425511
43725	2020-08-10 03:23:52	2020-08-10	Quinten Cole	quinten.cole@geemail.com	San Francisco	California	3096154049202970498	1e31275ff646bc07c05bae5393e2c810	Diners Club / Carte Blanche	37.7584992230416603	-122.448926639594973
43726	2020-08-10 03:33:08	2020-08-10	Kathlene Lesch	kathlene.lesch@woohoo.com	Modesto	California	869940585925159438	a4d019f36f54de87456da4075ef61ad8	American Express	37.6439659118186682	-121.096890938907862
43727	2020-08-10 03:33:40	2020-08-10	Elvis Gerlach	elvis.gerlach@geemail.com	Phoenix	Arizona	51125300094770884	c0409bb2e3c0d224840191d1a2ed7678	Discover	33.6494465008776658	-112.178947361598176
43728	2020-08-10 03:40:34	2020-08-10	Lionel Bogisich	lionel.bogisich@geemail.com	Philadelphia	Pennsylvania	4226496783646142	9da846012da7584bb3ddf056f5e6b80d	Mastercard	40.0629034351050848	-75.1439381569523448
43729	2020-08-10 03:48:10	2020-08-10	Georgiana Rohan	georgiana.rohan@woohoo.com	Cleveland	Ohio	639056437420591	f0e4d05d7a858ec73b5ecc842e2e8b0b	VISA 16 digit	41.4383118952941132	-81.7479699956957262
43730	2020-08-10 03:52:12	2020-08-10	Cohen Moore	cohen.moore@geemail.com	Akron	Ohio	676153588048701	50148a9288d9352779054eb5c9d078d3	VISA 16 digit	41.0943630738016239	-81.4788462349526554
43731	2020-08-10 03:59:27	2020-08-10	Webster Blick	webster.blick@geemail.com	New York	New York	3428351468858233	28007afc281af3fcca2aff1e18ff8ca3	Discover	40.5874976210053973	-73.9816212243761839
43732	2020-08-10 04:03:13	2020-08-10	Lizette Wisoky	lizette.wisoky@geemail.com	Dallas	Texas	3088065760238328620	a35f71d28c5db019c9ec85731eb104f5	Maestro	32.8841653435297303	-96.771927271267387
43733	2020-08-10 04:07:37	2020-08-10	Aleah Wisoky	aleah.wisoky@geemail.com	Houston	Texas	54102376031191787	ff78b273cb8ce5b31d61c7ccfa7a1283	Discover	29.7247706965155913	-95.3283061249196493
43734	2020-08-10 04:08:39	2020-08-10	Debera Leuschke-Raynor	debera.leuschke.raynor@warmmail.com	Plano	Texas	869920007264895088	793aca77702cd589cb3d747bc710a5ee	JCB 15 digit	33.0950398174665921	-96.6964153370536934
43735	2020-08-10 04:08:49	2020-08-10	Darnell Jenkins	darnell.jenkins@geemail.com	Philadelphia	Pennsylvania	4941959205750861	d30b8eedea77e5fdab5d1a6f2c6f5246	American Express	40.0402571327477688	-75.0547004003442879
43736	2020-08-10 04:15:01	2020-08-10	Glennis McDermott	glennis.mcdermott@woohoo.com	Omaha	Nebraska	676166172774268	6140e72d12a4b4e003fea144f827b012	VISA 13 digit	41.2573496448487091	-95.9806709058698289
43737	2020-08-10 04:34:23	2020-08-10	Karl Denesik	karl.denesik@geemail.com	Fort Worth	Texas	3528406580144843183	38072a5abdaa12198d5306eb033e9c7a	Diners Club / Carte Blanche	32.7591207583956461	-97.356511162203546
43738	2020-08-10 04:44:39	2020-08-10	Aggie Grimes	aggie.grimes@geemail.com	Oakland	California	3433995682961703	2a65bae595c29295966c9ad50a649fe4	JCB 16 digit	37.8141127542291287	-122.248614177762121
43739	2020-08-10 04:50:05	2020-08-10	Dr. Olena Schaefer	dr.olena.schaefer@geemail.com	Oakland	California	3059367618749042	7c72b5257c0913ad98e80233bd518937	Mastercard	37.7956569345525963	-122.298804952952793
43740	2020-08-10 04:57:24	2020-08-10	Cloe Cummerata	cloe.cummerata@geemail.com	Pearland	Texas	4590769666453150	48319647dc9d3a6bac0f68b8870d1348	VISA 16 digit	29.6056581583146006	-95.2731016752630495
43741	2020-08-10 05:00:41	2020-08-10	Jefferey Roob	jefferey.roob@geemail.com	Anaheim	California	3722037920065816	0df0049b4f4880573b729dc5c3e9596a	VISA 16 digit	33.7979032615497701	-117.701166932771343
43742	2020-08-10 05:07:19	2020-08-10	Kieth Pfeffer	kieth.pfeffer@warmmail.com	Columbia	Missouri	52436370203252078	f5d588a6cec8c6ea2f9154de154233f6	VISA 16 digit	38.9739438822839972	-92.4178685350862423
43743	2020-08-10 05:19:45	2020-08-10	Larue Harvey MD	larue.harvey.md@geemail.com	Milwaukee	Wisconsin	3528320564632737456	781a50ff0c6ba45d9d92d8b5868e5048	Maestro	43.0869607621889514	-87.8832257461369011
43744	2020-08-10 05:21:24	2020-08-10	Selmer Toy	selmer.toy@geemail.com	Amarillo	Texas	53947967578479145	20be7225b75db057f1ca2456dc57c244	Mastercard	35.1663302206132542	-101.911979852462935
43745	2020-08-10 05:28:12	2020-08-10	Grove Ortiz	grove.ortiz@geemail.com	El Cajon	California	4638678141635758	40c952eb35d3f90a8bc95489e5bde20d	Diners Club / Carte Blanche	32.8325158897794722	-117.034843580815576
43746	2020-08-10 05:31:10	2020-08-10	Archer Keeling	archer.keeling@woohoo.com	Chesapeake	Virginia	4673955172060015	da0e15cfebdede1e464573827012ab11	Diners Club / Carte Blanche	36.7332094193209002	-76.332573216998199
43747	2020-08-10 05:37:09	2020-08-10	Albert Swift III	albert.swift.iii@warmmail.com	Anaheim	California	51400847506493543	82d3d030b7bb5ccdc2d13f8f7d7a49a0	Voyager	33.7899384210184195	-117.720675406113628
43748	2020-08-10 05:40:15	2020-08-10	Ashley Borer	ashley.borer@geemail.com	Long Beach	California	3158711878796960416	4abe3a95aeaa70139feeedd48dfc9e27	Discover	33.8971261224530593	-118.09285441620014
43749	2020-08-10 05:44:56	2020-08-10	Harlen McDermott	harlen.mcdermott@woohoo.com	Oakland	California	869930545010386942	cf418a93ffefd20282517d7ad0ad382a	VISA 16 digit	37.8052845152495394	-122.257501395975197
43750	2020-08-10 05:46:18	2020-08-10	Cyndi Sanford	cyndi.sanford@geemail.com	Los Angeles	California	4866050351181001	b1fc65aad44a13b70e1821ce4d055c0a	VISA 16 digit	34.1146652075793568	-118.368888565664363
43751	2020-08-10 05:52:18	2020-08-10	Mrs. Exa Kreiger	mrs.exa.kreiger@geemail.com	Port St. Lucie	Florida	3006919337532597	006673d621c9f0f04f4a65cadd178aca	Maestro	27.2724498646933569	-80.4225670218087743
43752	2020-08-10 05:59:13	2020-08-10	Mr. Russ Hagenes Jr.	mr.russ.hagenes.jr.@geemail.com	McKinney	Texas	869979849125040085	8214893a2cdf5574ca05beb0e8de1017	JCB 16 digit	33.1327641187366098	-96.6184184107761865
43753	2020-08-10 06:00:19	2020-08-10	Alexander Borer	alexander.borer@geemail.com	Philadelphia	Pennsylvania	3039675367065992	04e63b9f2ab74989b650b8dc4cdc6e04	Maestro	40.0169210278388121	-75.1930776195965791
43754	2020-08-10 06:02:21	2020-08-10	Mrs. Nonie Maggio	mrs.nonie.maggio@geemail.com	Nashville	Tennessee	4910200182863	75b2d0bfe7e6089a453b9b344bb97dc9	Discover	36.2527440397657443	-86.7900124102272059
43755	2020-08-10 06:05:52	2020-08-10	Dink O'Reilly	dink.o'reilly@warmmail.com	Pompano Beach	Florida	3403987652903829	58a4426ca7f5d086ad97d9d4bdcdb3eb	Diners Club / Carte Blanche	26.1999735979627815	-80.2321113166712223
43756	2020-08-10 06:12:01	2020-08-10	Robby Huel II	robby.huel.ii@geemail.com	Kansas City	Kansas	4865555574044175	6312aed18b77a6453e4e3ddc738bade1	American Express	39.0322531697247186	-94.6459715148370719
43757	2020-08-10 06:15:12	2020-08-10	Ms. Mavis Toy	ms.mavis.toy@geemail.com	Santa Clara	California	3463161474172800	b908497935818a25a7dcd69de98f7edb	American Express	37.389996805303177	-122.033990078651911
43758	2020-08-10 06:21:21	2020-08-10	Dr. Merwin Will Sr.	dr.merwin.will.sr.@geemail.com	St. Petersburg	Florida	4533239600786	8355c6b34ce3804a6fa89c26710fff3a	JCB 15 digit	27.6805076908208427	-82.6745810552392157
43759	2020-08-10 06:21:21	2020-08-10	Harvey Tillman	harvey.tillman@woohoo.com	Chicago	Illinois	3732995977271660	83d5dccee8ea9d5d1fd2e21eb4fad329	Voyager	41.7715831640943875	-87.7094461960747793
43760	2020-08-10 06:22:31	2020-08-10	Kadyn Crist	kadyn.crist@geemail.com	San Francisco	California	4034271727136613	3a3f0b20a10d7ffec6d9943dd36fee46	VISA 16 digit	37.7618951337324802	-122.467468173690051
43761	2020-08-10 06:23:25	2020-08-10	Mr. Jacoby Gislason MD	mr.jacoby.gislason.md@geemail.com	Houston	Texas	4415796701126	9621bd0d4f1a377b395a29c0bc3bdeed	Maestro	29.8393194244321442	-95.3607545903898739
43762	2020-08-10 06:28:35	2020-08-10	Kimberli Dietrich	kimberli.dietrich@geemail.com	San Francisco	California	3096243825139188038	04721eae90e6905645b04c12d53c8c24	VISA 16 digit	37.7944666428211633	-122.452582021873909
43763	2020-08-10 06:32:11	2020-08-10	Jeri Altenwerth	jeri.altenwerth@geemail.com	Little Rock	Arkansas	676256756526309	087e3b60376bf34cc80f5ec02bfd28e1	VISA 13 digit	34.8239009637661283	-92.4577485745646044
43764	2020-08-10 06:32:14	2020-08-10	Lolita Quitzon DDS	lolita.quitzon.dds@woohoo.com	Wichita	Kansas	639020367149802	8c421b0f65a48e19e6b55c5efceab9a3	JCB 16 digit	37.7338510258000355	-97.3409404841452783
43765	2020-08-10 06:33:16	2020-08-10	Pinkney Ernser	pinkney.ernser@geemail.com	Wichita	Kansas	54865875096861371	dad865402ba4717ddddcdd88e7aff0ed	JCB 16 digit	37.6394334628589462	-97.3304016423612808
43766	2020-08-10 06:47:26	2020-08-10	Yolonda Herman	yolonda.herman@warmmail.com	Hampton	Virginia	3112659061828075511	4a51d5b50923c1df406ce19dd6e9e253	Voyager	37.0920581437666002	-76.2617779206115785
43767	2020-08-10 06:48:54	2020-08-10	Gavyn Murazik	gavyn.murazik@geemail.com	Berkeley	California	869984058552106848	8b795ca3125cda4d1ce94589d1586e25	Voyager	37.8943630035925523	-122.233056556873436
43768	2020-08-10 06:57:03	2020-08-10	Kyrie Hilpert-Herman	kyrie.hilpert.herman@geemail.com	San Francisco	California	3414793224560924	3d3d6e9e42dce58e86c080ee6ed32ef0	Maestro	37.7660072630748616	-122.435038800327661
43769	2020-08-10 07:26:38	2020-08-10	Stephanie Bernhard	stephanie.bernhard@woohoo.com	Eugene	Oregon	3030852761239288	aaa10abffb5c5d0e06eb938825b6629f	American Express	44.109174959753453	-123.067982209612438
43770	2020-08-10 07:28:41	2020-08-10	Ms. Norita Schroeder	ms.norita.schroeder@geemail.com	San Francisco	California	3112256751459976980	3902ea3dfd39bedc39fb8bacf3d5a5fa	VISA 13 digit	37.772614533097574	-122.43159538178152
43771	2020-08-10 07:29:13	2020-08-10	Mrs. Gabriella Rogahn	mrs.gabriella.rogahn@geemail.com	Shreveport	Louisiana	3158703755168127297	48a5b39bac3ca547090220b793cf4bb0	JCB 15 digit	32.4556193304952245	-93.7311374928083154
43772	2020-08-10 07:34:15	2020-08-10	Moises Green	moises.green@geemail.com	Dallas	Texas	869951551145497814	eb0e01adb75e73f492562810e7388d01	VISA 16 digit	32.7406010890185826	-96.7763315611015997
43773	2020-08-10 07:35:06	2020-08-10	Mr. Nile Bashirian	mr.nile.bashirian@geemail.com	San Diego	California	3708651316631391	247e3212891718ee83f14f4f10d5758c	VISA 13 digit	32.7389422209069139	-117.158334105731925
43774	2020-08-10 07:39:22	2020-08-10	Akeem Morar	akeem.morar@geemail.com	San Francisco	California	869945312644317402	4a3aa6213e051bf1e1282fb20877cdbe	Diners Club / Carte Blanche	37.8014944715512655	-122.419523898445419
43775	2020-08-10 07:40:14	2020-08-10	Ms. Molly Willms MD	ms.molly.willms.md@geemail.com	Newport News	Virginia	869927541127447813	4f58dc1ca69feb645f55de1e515caf4f	Diners Club / Carte Blanche	36.9803525250766398	-76.5425638681072797
43776	2020-08-10 07:42:13	2020-08-10	Hunter Carter	hunter.carter@geemail.com	Phoenix	Arizona	180086825255060219	bfae245d2617961ea1dcb5d290e71482	Voyager	33.5315623626511581	-112.038374529445917
43777	2020-08-10 07:42:30	2020-08-10	Litzy Gutkowski PhD	litzy.gutkowski.phd@woohoo.com	Philadelphia	Pennsylvania	4357008204129	0f5eceaccc8426eac7a878463871a7a4	JCB 16 digit	40.088535878477245	-75.1921524347636847
43778	2020-08-10 07:46:57	2020-08-10	Dr. Horton Toy	dr.horton.toy@woohoo.com	Memphis	Tennessee	3158649773404202623	dabfc15ae9844f36d7d3cdca0ee7b95b	Voyager	35.0099724101435399	-89.9350665541157213
43779	2020-08-10 07:51:03	2020-08-10	Zelda Carter	zelda.carter@warmmail.com	San Francisco	California	4883951008829	54477802a2de8e94ed74f7957e8721b9	VISA 16 digit	37.792286143724688	-122.44537129396079
43780	2020-08-10 07:52:38	2020-08-10	Hardie Kemmer	hardie.kemmer@warmmail.com	Charlotte	North Carolina	3096669488518797666	66ed7820988f5c1aaf08dca11f30ef68	JCB 16 digit	35.1916730064220715	-80.9247501925509454
43781	2020-08-10 07:53:21	2020-08-10	Venus Jast	venus.jast@woohoo.com	Fayetteville	North Carolina	3158350583459152451	d19a7e529999a6fb4ae1cd9c7b59ca99	JCB 16 digit	35.0457059499129642	-78.9231568530332339
43782	2020-08-10 07:58:06	2020-08-10	Dr. Liza Mayert	dr.liza.mayert@woohoo.com	Philadelphia	Pennsylvania	3096846680402383969	d7f46f85516d52c3b31c4c23ab91f7cc	VISA 16 digit	40.1000041825655842	-75.11211631692872
43783	2020-08-10 07:58:49	2020-08-10	Dr. Deanna Kuvalis DDS	dr.deanna.kuvalis.dds@warmmail.com	Oakland	California	3059309365332036	c9ff8d21acc26acb0ded9f0f9a58fd8c	American Express	37.8174834986527344	-122.268721982802191
43784	2020-08-10 08:01:58	2020-08-10	Jens Walker	jens.walker@geemail.com	Denver	Colorado	589383001933189	f1b15df1a3415da279794d6ba5721828	JCB 16 digit	39.7912911261484012	-104.907066824824
43785	2020-08-10 08:02:50	2020-08-10	Carisa Christiansen-Mohr	carisa.christiansen.mohr@geemail.com	Tuscaloosa	Alabama	53696036175054108	e78fba8c8ffda23856e4feb89a254e16	JCB 15 digit	33.1519113841056807	-87.5230022780228438
43786	2020-08-10 08:18:07	2020-08-10	Miss Iva Block DDS	miss.iva.block.dds@geemail.com	Los Angeles	California	3021084158633324	33ab7f3ed12a8a13cdcd2b67f8aa002f	VISA 13 digit	34.0270875085942421	-118.484377288351951
43787	2020-08-10 08:23:41	2020-08-10	Skylar Bogan	skylar.bogan@warmmail.com	Nashville	Tennessee	6011568090856995035	bfc59f50435c31aca1fbfd5c63a89bfe	VISA 16 digit	36.2400624036446217	-86.7737300453614466
43788	2020-08-10 08:26:07	2020-08-10	Uriah Stark	uriah.stark@geemail.com	New York	New York	180050342681208885	e02fbd74856f3ab5e59e8a5f162a36e0	Mastercard	40.6717832769025094	-73.94108876068033
43789	2020-08-10 08:27:40	2020-08-10	Channie Rowe DDS	channie.rowe.dds@geemail.com	Escondido	California	53241267438195418	0803dc141162e60b2e696d2347a2fb78	American Express	33.2051303666312236	-117.065593721834944
43790	2020-08-10 08:40:06	2020-08-10	Betty Bahringer MD	betty.bahringer.md@geemail.com	Berkeley	California	4385076823157	ab56a3207a5a0fd56ee9d64a2a492d8f	Maestro	37.9033512068164669	-122.290938546760415
43791	2020-08-10 08:42:54	2020-08-10	Dr. Eben Wuckert PhD	dr.eben.wuckert.phd@warmmail.com	Riverside	California	561291770774882	36f56a18452246b36f11c83fe6cc24e3	JCB 16 digit	33.9215528439678238	-117.34524875064082
43792	2020-08-10 08:43:36	2020-08-10	Tod Schaden	tod.schaden@geemail.com	Phoenix	Arizona	589335313924348	3dd968d1e8b87f4d1b09068701dc5875	VISA 16 digit	33.6362007545705879	-111.991583626943083
43793	2020-08-10 08:43:45	2020-08-10	Damond Gusikowski-Shanahan	damond.gusikowski.shanahan@geemail.com	Albuquerque	New Mexico	3006457914163239	adebb5f0aa41e96372fd28f1d9d28e07	VISA 13 digit	35.1349003810104037	-106.714633516788112
43794	2020-08-10 08:46:28	2020-08-10	Carlisle Stiedemann	carlisle.stiedemann@geemail.com	Boise	Idaho	6011244347854494458	c1f194bc10d90a159f81453bb7f69b3a	Mastercard	43.5034812222372764	-116.307951380797476
43795	2020-08-10 08:46:50	2020-08-10	Patrick Kunde	patrick.kunde@geemail.com	Hayward	California	869989285545204597	80aceb5190e750f60ea4328144cdeffa	Voyager	37.6169740317843875	-122.103838375562432
43796	2020-08-10 08:56:38	2020-08-10	Mrs. Margarette Friesen PhD	mrs.margarette.friesen.phd@geemail.com	New York	New York	4397799547054	10f51c1539df0376db4ff3664fabd425	JCB 16 digit	40.5884856045003986	-73.8635643002472762
43797	2020-08-10 08:57:00	2020-08-10	Wayde Gleichner	wayde.gleichner@geemail.com	Elizabeth	New Jersey	6011163271513500421	9daeb2410773bdf74ecb501437ef6e3b	Voyager	40.707449097198996	-74.2668235214836869
43798	2020-08-10 09:00:41	2020-08-10	Mr. Lars Huels III	mr.lars.huels.iii@woohoo.com	San Francisco	California	53887883662741567	888e52be54f72c038f85a90e69b02d14	American Express	37.7818325826823624	-122.421369242580454
43799	2020-08-10 09:16:26	2020-08-10	Glenn Wehner	glenn.wehner@geemail.com	San Francisco	California	3528803600950335998	8373196bf2957139b008208a584a0fb3	JCB 16 digit	37.7866142843990573	-122.446676467783576
43800	2020-08-10 09:17:29	2020-08-10	Permelia Farrell	permelia.farrell@geemail.com	Chicago	Illinois	180048569241091261	f228e240b44bbafe0cf497e1cbc3f852	American Express	41.7746513385627409	-87.7315375079896285
43801	2020-08-10 09:30:21	2020-08-10	Mrs. Linnea Quitzon MD	mrs.linnea.quitzon.md@warmmail.com	Baltimore	Maryland	676359035186507	188fb281f506b44be78f4279053d3711	Voyager	39.3762032154016168	-76.5263505904953973
43802	2020-08-10 09:32:26	2020-08-10	Francis Witting	francis.witting@geemail.com	Tempe	Arizona	4872402741112	8ea0ffe621bde516fb9dbebac77d6fdc	JCB 16 digit	33.3994354612581432	-111.907776076489313
43803	2020-08-10 09:35:40	2020-08-10	Mrs. Orah Aufderhar DVM	mrs.orah.aufderhar.dvm@woohoo.com	Houston	Texas	3112860736427729882	9a6cdda1bda93d3dd9006c4bb2a3d9ee	Discover	29.7296552757345154	-95.401285503619917
43804	2020-08-10 09:35:52	2020-08-10	Roselyn Christiansen-Rempel	roselyn.christiansen.rempel@geemail.com	Baltimore	Maryland	4876606451119775	d98ef89f1deee343459c440b66031efc	JCB 16 digit	39.2652238029055241	-76.5978719204217242
43805	2020-08-10 09:36:14	2020-08-10	Chyna Lind-Collier	chyna.lind.collier@geemail.com	Orlando	Florida	3088888958513392320	a351367fba7c5ac7da1bc5e968b225ac	VISA 16 digit	28.4210232993386676	-81.3476911913570007
43806	2020-08-10 09:42:20	2020-08-10	Morton Mertz	morton.mertz@geemail.com	Hayward	California	6011197338111705338	0b1518a0e11a805cefb8a476a39667d7	VISA 13 digit	37.6884716385498635	-122.124010168786725
43807	2020-08-10 09:42:26	2020-08-10	Zella Stark	zella.stark@geemail.com	San Francisco	California	3088166814344184076	cd62512784e3375acb93a2ffa4c63546	JCB 15 digit	37.7721575799704397	-122.426829061192706
43808	2020-08-10 09:43:00	2020-08-10	Dora Harris	dora.harris@geemail.com	Stockton	California	210032277028856389	dad28495ece21b1ffb7331f533941393	Voyager	38.0470931158132899	-121.404364368421213
43809	2020-08-10 09:48:58	2020-08-10	Jeff Kreiger-Treutel	jeff.kreiger.treutel@geemail.com	Virginia Beach	Virginia	869902062301103451	65ab34c336304a9f3cca963b786bf511	VISA 16 digit	36.762279630284759	-76.0950912283871332
43810	2020-08-10 09:49:00	2020-08-10	Nels Tillman MD	nels.tillman.md@warmmail.com	Phoenix	Arizona	4101600911295413	9bd6096565f81085375395ac2155aa2d	American Express	33.5771672557041043	-112.025798116198189
43811	2020-08-10 09:53:37	2020-08-10	Lott VonRueden	lott.vonrueden@warmmail.com	Fort Worth	Texas	3096338295628735192	ba6cdc69307eafcfb6d4b8eb83b692d9	Discover	32.7339376939050837	-97.4071424852412235
43812	2020-08-10 09:53:43	2020-08-10	Arielle Pollich	arielle.pollich@geemail.com	Santa Ana	California	4688456099092226	16bfd1e2da43306d7c1e07d6ca96457a	VISA 13 digit	33.8151225491531164	-117.960408964512865
43813	2020-08-10 09:55:16	2020-08-10	Ms. Lannie Farrell	ms.lannie.farrell@geemail.com	Grand Rapids	Michigan	4242495931475198	a40acd1da3e4e880c4329eb4d9f07691	VISA 16 digit	42.9606905588217032	-85.6390773268550731
43814	2020-08-10 10:00:18	2020-08-10	Lewis Smitham-McLaughlin	lewis.smitham.mclaughlin@geemail.com	New York	New York	561296412675157	12de544bb0d3a541c1c292c5ddfc9d66	Voyager	40.6287847983874357	-73.9793042032409431
43815	2020-08-10 10:06:43	2020-08-10	Mathias Gulgowski	mathias.gulgowski@geemail.com	Boston	Massachusetts	589338399874684	6bf66fe7544262421c7b369bf18b610b	American Express	42.3747174589596725	-71.0510254182804459
43816	2020-08-10 10:14:42	2020-08-10	Mr. Ingram Rempel PhD	mr.ingram.rempel.phd@geemail.com	New York	New York	6011092533758894140	003ade5c8d7b6f74447446181cbbe17a	Diners Club / Carte Blanche	40.5739314867872736	-73.9424204507272691
43817	2020-08-10 10:16:58	2020-08-10	Mrs. Anie Wilderman	mrs.anie.wilderman@geemail.com	Downey	California	4368732886335532	6d0a3576ff54486cb3ed6f6cea61e227	JCB 16 digit	33.9424832223698516	-118.15722578113116
43818	2020-08-10 10:20:22	2020-08-10	Sasha Turcotte	sasha.turcotte@geemail.com	Phoenix	Arizona	3337143910302544489	daecc410ca44090870a1921a7f26be28	Voyager	33.5027535395164051	-112.180034896212078
43819	2020-08-10 10:20:53	2020-08-10	Kalene Hamill-Larson	kalene.hamill.larson@woohoo.com	Inglewood	California	3463673914009707	958d66e9d6b34231bfe615eb841d891d	JCB 16 digit	33.9163571774739765	-118.269911786404634
43820	2020-08-10 10:29:25	2020-08-10	Alana Hudson-Mills	alana.hudson.mills@warmmail.com	Oakland	California	4838933188032197	d0c2a30e7d86af1afff979512b8a753a	American Express	37.8513667516592065	-122.278723116201462
43821	2020-08-10 10:34:43	2020-08-10	Ms. Valentina Padberg	ms.valentina.padberg@geemail.com	San Bernardino	California	53737606480668890	a2af7f39a0b77696f13b7929956e94b5	Voyager	34.1248495283801105	-117.305511753145979
43822	2020-08-10 10:38:44	2020-08-10	Reagan Fisher	reagan.fisher@warmmail.com	Houston	Texas	4855046645864	4ed63f60bccad0c9d71e2bdce4296332	VISA 16 digit	29.8137167954429998	-95.4332691730480605
43823	2020-08-10 10:41:20	2020-08-10	Hattie Kihn	hattie.kihn@geemail.com	Port St. Lucie	Florida	180036055305577118	052f32ded0e06c12ea8d94e32a05f1a1	Discover	27.3656457868073133	-80.296057023535667
43824	2020-08-10 10:45:02	2020-08-10	Miss Karel Wisozk DDS	miss.karel.wisozk.dds@woohoo.com	Dayton	Ohio	4683507703446417	7ea8492eea6f37653f0c0bcb9bdb4dc8	VISA 13 digit	39.8058295479766997	-84.2090816800206881
43825	2020-08-10 10:49:21	2020-08-10	Oscar Green	oscar.green@geemail.com	Phoenix	Arizona	503893045407405	fcbdf31602a90b479ed4f181bffd7cb8	VISA 16 digit	33.5594622038237773	-112.121729227939994
43826	2020-08-10 11:08:28	2020-08-10	Flint Wintheiser	flint.wintheiser@geemail.com	Henderson	Nevada	180043817507660757	2aa9b565982e68a41b98a795371e68ad	Discover	35.9347775577966146	-114.956564392351368
43827	2020-08-10 11:11:37	2020-08-10	Miss Cailyn Cruickshank	miss.cailyn.cruickshank@geemail.com	Chicago	Illinois	6011764914103409619	3cf3ebedcaa8ee2e8803f33e30d09a92	JCB 16 digit	41.8815534299075622	-87.6357084162097379
43828	2020-08-10 11:13:16	2020-08-10	Miss Jaqueline Toy	miss.jaqueline.toy@geemail.com	Phoenix	Arizona	4824239130771981	e68f221c273e5f8bc2d80e7a7792e8ca	JCB 16 digit	33.4754684471458219	-112.16023468523511
43829	2020-08-10 11:15:29	2020-08-10	Boston Rutherford	boston.rutherford@geemail.com	Long Beach	California	3112901102184960726	1bd394aa2a9027f93f93bb3cb5e5ab16	American Express	33.8402339039657249	-118.172777344628415
43830	2020-08-10 11:16:07	2020-08-10	Angele Denesik	angele.denesik@geemail.com	Atlanta	Georgia	3528561803544273244	bfbb0aa3f2e76790205153a88fb4393c	American Express	33.743418365278842	-84.3271391723349808
43831	2020-08-10 11:18:19	2020-08-10	Keshaun Hansen IV	keshaun.hansen.iv@geemail.com	Los Angeles	California	3721541036541751	442de26cd04c850e14ebd2203b896c18	American Express	34.0434233344025898	-118.474262117966262
43832	2020-08-10 11:19:06	2020-08-10	Dr. Luis Halvorson	dr.luis.halvorson@geemail.com	Modesto	California	52994161960879185	8863212cec5648804ec4b50e8f10a030	Maestro	37.6787576499395129	-121.003927061308175
43833	2020-08-10 11:20:17	2020-08-10	Aubra Gusikowski	aubra.gusikowski@geemail.com	Aurora	Colorado	3013549252045078	51004792d687250b89f51fd4b58c2930	JCB 16 digit	39.6336149441655721	-104.598745655280354
43834	2020-08-10 11:36:34	2020-08-10	Merrily Schinner	merrily.schinner@warmmail.com	San Francisco	California	3158113924137686577	8d474cd5ee528981dae91088b42abfa0	JCB 16 digit	37.7778239412853551	-122.448838168674072
43835	2020-08-10 12:00:05	2020-08-10	Hardin O'Connell	hardin.o'connell@woohoo.com	Peoria	Illinois	4895883065884154	6dbb24141327339cac7a514729bcf4a0	JCB 16 digit	40.839192839326337	-89.6323776294827468
43836	2020-08-10 12:04:34	2020-08-10	Miss Patience Christiansen	miss.patience.christiansen@woohoo.com	Allen	Texas	869961221929443701	442a4863e85d6a909a6cc66a984f7214	VISA 16 digit	33.0931685701970011	-96.7422398136876467
43837	2020-08-10 12:16:25	2020-08-10	Dorinda Lesch	dorinda.lesch@warmmail.com	Pittsburgh	Pennsylvania	3418331391505145	8d28cfdb285d667572489597385b0f32	American Express	40.4275303168177587	-80.0234146420084045
43838	2020-08-10 12:19:47	2020-08-10	Amya Padberg	amya.padberg@warmmail.com	Knoxville	Tennessee	4438891231078142	a199b6fda55f66844e9b9b7f31e64489	Diners Club / Carte Blanche	36.0633374111324585	-83.9066995722923394
43839	2020-08-10 12:22:55	2020-08-10	Lorine Hudson	lorine.hudson@woohoo.com	Portland	Oregon	3023304396299888	856567607d0fe608a5a3e66374ea0116	Maestro	45.5398692094143485	-122.688832713291049
43840	2020-08-10 12:24:10	2020-08-10	Sheyla Hodkiewicz MD	sheyla.hodkiewicz.md@woohoo.com	Sparks	Nevada	3797367184071618	f93f49910d2d74da913b9eb3f1d34107	VISA 13 digit	39.5751869444508131	-119.75155660177991
43841	2020-08-10 12:28:17	2020-08-10	Karyme Herzog-Wiza	karyme.herzog.wiza@warmmail.com	Phoenix	Arizona	4913387825148	85b30c75391aa55cb19417590e9afece	VISA 16 digit	33.5289704124376229	-112.109591854449747
43842	2020-08-10 12:36:13	2020-08-10	Adelbert Heller	adelbert.heller@geemail.com	Elizabeth	New Jersey	3337773904006909426	4ff7754d28c6b24bcad4d793a2eaf240	Voyager	40.6543958759527655	-74.2484841281492294
43843	2020-08-10 12:41:02	2020-08-10	Windell Kerluke	windell.kerluke@geemail.com	Los Angeles	California	3739313815434016	f8eaa01269b381305cca3875be254e2a	JCB 16 digit	34.0215158447954806	-118.405165953421218
43844	2020-08-10 12:47:34	2020-08-10	Mrs. Kyrie Yost DVM	mrs.kyrie.yost.dvm@geemail.com	Fayetteville	North Carolina	4765379327644	eb3b128e73e3c63390f9cc8ef983eb83	Maestro	35.1400066199965764	-78.8918580703567756
43845	2020-08-10 12:48:45	2020-08-10	Ethen Wolf	ethen.wolf@geemail.com	Miramar	Florida	4905307363970224	a84ac6c8f4b727aa1484d38c1e90c726	JCB 15 digit	25.9179590603783723	-80.2820981372140352
43846	2020-08-10 12:59:35	2020-08-10	Crockett Eichmann	crockett.eichmann@geemail.com	Phoenix	Arizona	55822244409763356	5ed80acb79f193fd33cb89cb553ea6b1	JCB 15 digit	33.5303794508732906	-111.997583231462542
43847	2020-08-10 12:59:55	2020-08-10	Colette Donnelly	colette.donnelly@geemail.com	Pittsburgh	Pennsylvania	3158130869975860033	c8cc019f06fc800becb871f4a5a90d71	American Express	40.3702268974810821	-80.0500543573576948
43848	2020-08-10 13:24:43	2020-08-10	Dr. Neil Kohler V	dr.neil.kohler.v@geemail.com	Allen	Texas	3025662474020544	d1641c375759f9654a660ca6cd1f3fc9	VISA 16 digit	33.0825584169503273	-96.6538909700181392
43849	2020-08-10 13:31:08	2020-08-10	Miss Kendra O'Conner	miss.kendra.o'conner@woohoo.com	Boston	Massachusetts	4208370075633732	8aca6925adb81d1c9498c5d5a99e08e2	Discover	42.2888890989758082	-71.07661373083927
43850	2020-08-10 13:37:20	2020-08-10	Theron Keebler	theron.keebler@geemail.com	Fort Worth	Texas	210093799459219742	902f39a18d89ad7bfabc043d26b9776a	VISA 13 digit	32.7943894679713992	-97.3844375159412579
43851	2020-08-10 13:39:48	2020-08-10	Pasquale Stracke	pasquale.stracke@geemail.com	Springfield	Illinois	3158444102330561661	d2ff60344330bfa5bc1a6ef49ca1e10a	American Express	39.8875626732748003	-89.6033795122526584
43852	2020-08-10 13:44:47	2020-08-10	Dr. Weldon Barrows	dr.weldon.barrows@geemail.com	Bakersfield	California	4168257154068377	1275926374e4b2eb6c320393f2c20815	VISA 16 digit	35.3134722961753553	-118.933397521990528
43853	2020-08-10 13:49:48	2020-08-10	Toy Ankunding	toy.ankunding@geemail.com	Nashville	Tennessee	3337817389075509380	315b26d9ee48a28e48a03744460d3c66	JCB 15 digit	36.1947210814461116	-86.8139183021988714
43854	2020-08-10 13:56:58	2020-08-10	Dr. Julianna Lueilwitz	dr.julianna.lueilwitz@geemail.com	Tulsa	Oklahoma	3158395098037345763	390aab9b7108754153541433ea8bbe20	Maestro	36.1664724205523669	-95.8983494467057227
43855	2020-08-10 14:06:37	2020-08-10	Tisa Muller	tisa.muller@geemail.com	Bakersfield	California	3158235933959757807	5b03b8f7c63c3d148cda1cf8378976d7	VISA 13 digit	35.3024472802586828	-119.04640141197406
43856	2020-08-10 14:12:43	2020-08-10	Branson Zieme-Lubowitz	branson.zieme.lubowitz@warmmail.com	Oakland	California	6011652415219942407	a150b8a09fb55ab46256c5486a809a8e	Mastercard	37.7968440728237169	-122.25807588911637
43857	2020-08-10 14:16:04	2020-08-10	Orrie Baumbach DVM	orrie.baumbach.dvm@geemail.com	Fayetteville	North Carolina	869924725481840506	38f4cda05246fa7bdf5851d4b52c06aa	American Express	35.0142486298244435	-78.8751314159613059
43858	2020-08-10 14:16:51	2020-08-10	Coy Schimmel	coy.schimmel@geemail.com	Jacksonville	Florida	6011221521514465317	491d8610e136311125f76c6a3cc017d7	JCB 15 digit	30.3828071204997592	-81.6963012431360909
43859	2020-08-10 14:17:19	2020-08-10	Deon Donnelly	deon.donnelly@geemail.com	Tulsa	Oklahoma	869982068899550659	6e1ff6854cb4c871a460de2127d8e774	JCB 16 digit	36.1307184279799429	-95.8386242701627253
43860	2020-08-10 14:19:00	2020-08-10	Letty Ziemann DVM	letty.ziemann.dvm@woohoo.com	Los Angeles	California	180069392499464328	99efe0b0662713690ebb2e5510dde444	JCB 16 digit	34.0070556237228203	-118.493819917504851
43861	2020-08-10 14:20:43	2020-08-10	Lillie Von	lillie.von@geemail.com	High Point	North Carolina	3528421650592049046	f9980fa946ada6e69c3747f33b0dd922	JCB 16 digit	36.0813581912871442	-80.079905202539635
43862	2020-08-10 14:29:36	2020-08-10	Makayla Weimann	makayla.weimann@geemail.com	New York	New York	3004271295693892	93f5ad68f06db362c570b4a7cdad124b	VISA 16 digit	40.6407206662688409	-73.9237014137104183
43863	2020-08-10 14:29:44	2020-08-10	Mrs. Marilla Corwin MD	mrs.marilla.corwin.md@geemail.com	Hayward	California	4149338174318382	0aff29b47541fc4a0d466c1cc60eca91	JCB 15 digit	37.6073661121528602	-122.162207589370766
43864	2020-08-10 14:31:13	2020-08-10	Hernan Durgan	hernan.durgan@warmmail.com	San Francisco	California	589386523139805	441435bc2c803d9b9bae09c5eef2c605	Diners Club / Carte Blanche	37.75116128043814	-122.427067498976058
43865	2020-08-10 14:33:11	2020-08-10	Landan Gutkowski	landan.gutkowski@geemail.com	San Francisco	California	4892623577048325	c2143f10c0c6b7aa8837a056bc431a48	Discover	37.7272701160342407	-122.461252210675923
43866	2020-08-10 14:42:32	2020-08-10	Ayesha Gutmann	ayesha.gutmann@geemail.com	San Jose	California	4857457710642493	e6a3182adc4b49c96d34a616aabb56a2	Diners Club / Carte Blanche	37.2305370484765632	-121.82077827232294
43867	2020-08-10 14:45:14	2020-08-10	Mr. Milton Moore	mr.milton.moore@geemail.com	Richardson	Texas	3416114950083817	6c7717633d6f8a694a7b235d47965fd7	Discover	32.976373429293929	-96.6878547036316291
43868	2020-08-10 14:46:12	2020-08-10	Sommer Armstrong-Corwin	sommer.armstrong.corwin@woohoo.com	San Francisco	California	869908957984867096	dc66a04e0aa4bd470c3dddabe113c136	Voyager	37.7516674679412318	-122.406990252847535
43869	2020-08-10 14:53:27	2020-08-10	Manuelita Lakin	manuelita.lakin@warmmail.com	Mesa	Arizona	6011106274550555704	c6a7392e62a7061f5c1e304202e61ee6	JCB 16 digit	33.4295488681789479	-111.764265127794445
43870	2020-08-10 14:54:03	2020-08-10	Carlo Corkery	carlo.corkery@geemail.com	Vancouver	Washington	3337098860747431146	8cf9b946de215925a60e580753aa8f8c	JCB 15 digit	45.5888101982954907	-122.636972928146633
43871	2020-08-10 14:56:25	2020-08-10	Williams Hane-Gulgowski	williams.hane.gulgowski@geemail.com	Los Angeles	California	180051098806123420	8a09e50c473f55771591a09aca28a58b	VISA 16 digit	33.9238346540234943	-118.368312755924833
43872	2020-08-10 14:59:08	2020-08-10	Desiree Howe DDS	desiree.howe.dds@geemail.com	Miami	Florida	3096258371079263996	6ad85c0f648d36f9fe5988102a05559f	VISA 16 digit	25.8417572730358707	-80.1943283620629472
43873	2020-08-10 15:11:08	2020-08-10	Mr. Long Reynolds	mr.long.reynolds@warmmail.com	Berkeley	California	4028888498624	93df4a24bd797a48b543f82760bd40b1	JCB 15 digit	37.8504781816857658	-122.290117196631797
43874	2020-08-10 15:15:19	2020-08-10	Kian Kuhlman-O'Keefe	kian.kuhlman.o'keefe@geemail.com	Phoenix	Arizona	4959426614801155	2b4ad24b453f4cce35521aca49518156	American Express	33.5403350226048431	-112.072285420300815
43875	2020-08-10 15:22:56	2020-08-10	Willow Franecki	willow.franecki@warmmail.com	Irving	Texas	54323647558588974	d5680db7ff72e91c04744dcb9ceae65a	VISA 16 digit	32.857620255411419	-96.8878044217173056
43876	2020-08-10 15:51:29	2020-08-10	Dr. Fulton Cole Jr.	dr.fulton.cole.jr.@geemail.com	Phoenix	Arizona	3417284185289197	879a43dc80a4944e5d366b91482397f0	JCB 16 digit	33.5732724903550022	-112.091212209120769
43877	2020-08-10 15:51:45	2020-08-10	Garnet O'Reilly-Huels	garnet.o'reilly.huels@geemail.com	El Paso	Texas	3112130663604630788	061fdd3044c6dbd03fb577da7f63f575	Diners Club / Carte Blanche	31.7941029041834184	-106.381188699647794
43878	2020-08-10 15:54:40	2020-08-10	Bernard Ondricka	bernard.ondricka@geemail.com	Orange	California	561281839697745	0b3ed0b758cef3834813e8d721955ede	Diners Club / Carte Blanche	33.7219204011261482	-117.935609162655851
43879	2020-08-10 16:12:38	2020-08-10	Branson Eichmann-Hyatt	branson.eichmann.hyatt@woohoo.com	San Francisco	California	3009051440056681	4789e263bc59c9f47fdc7735b09c691d	Mastercard	37.7880265156249067	-122.452859146531452
43880	2020-08-10 16:17:01	2020-08-10	Davonte Kuhn	davonte.kuhn@warmmail.com	Huntington Beach	California	630459703672630	943a8007675e234a6c0be935916cc164	JCB 16 digit	33.7217806101351982	-118.108634658449517
43881	2020-08-10 16:30:55	2020-08-10	Rolanda Boyer	rolanda.boyer@geemail.com	Oakland	California	210018025601277855	875e67fbb79dfe5a80232d84969e0d61	Mastercard	37.8178338750806375	-122.280037526572684
43882	2020-08-10 16:32:39	2020-08-10	Sigrid Dach MD	sigrid.dach.md@geemail.com	Mobile	Alabama	4073065539836176	775c7427e5214db0f0f70ad720261227	JCB 15 digit	30.6334655407924181	-88.1334765335217156
43883	2020-08-10 16:38:04	2020-08-10	Lennie Vandervort	lennie.vandervort@warmmail.com	St. Louis	Missouri	3088953391334676491	4e576163d723a2c9643d56ea6a3f64ef	JCB 15 digit	38.6893189553327872	-90.2337883256379598
43884	2020-08-10 16:39:54	2020-08-10	Maida Wilkinson	maida.wilkinson@geemail.com	Denton	Texas	869990646059439720	2fa91469b4ece69767e3dca7e28f9348	JCB 16 digit	33.2871098194070143	-97.1073034007228983
43885	2020-08-10 16:43:27	2020-08-10	Robt Ritchie	robt.ritchie@warmmail.com	Corona	California	3018819521924428	83ae783046ecda463e622115226f57f5	Mastercard	33.8938859878927516	-117.63437864549644
43886	2020-08-10 16:48:08	2020-08-10	Braxton Carroll	braxton.carroll@geemail.com	Phoenix	Arizona	4154029626471471	c0cc8588174d58763f873f84e9a6546d	VISA 13 digit	33.5606872714523234	-112.070467888463668
43887	2020-08-10 16:51:07	2020-08-10	Dr. Porter Shields	dr.porter.shields@warmmail.com	Carlsbad	California	54063485642685603	4b0efabc84c91645da91756a6d4bca3a	American Express	33.1160628908254182	-117.319596634551132
43888	2020-08-10 16:55:10	2020-08-10	Karter Schmidt	karter.schmidt@geemail.com	Orlando	Florida	3112907690076273434	4af04a9a17fc4db73906e6ea49642788	Maestro	28.3539622477520261	-81.2346715286340526
43889	2020-08-10 16:58:47	2020-08-10	Mr. Matias Yost	mr.matias.yost@geemail.com	Columbus	Ohio	4468589252840407	7e3157efcd080675eb9ac953789ea995	JCB 15 digit	39.9883046097166854	-82.9451396303486206
43890	2020-08-10 16:59:54	2020-08-10	Teri Hartmann	teri.hartmann@geemail.com	Westminster	Colorado	3158982878479802028	c07341d5663aaa45023215373b14fc09	Diners Club / Carte Blanche	39.7863578670032325	-105.120957284854356
43891	2020-08-10 17:10:44	2020-08-10	Theodora Eichmann	theodora.eichmann@geemail.com	Spokane	Washington	060414801748188	50cfd917ce81fc9b184aa65fed26aeab	VISA 13 digit	47.5735798256710183	-117.34896369156354
43892	2020-08-10 17:14:23	2020-08-10	Dr. Claud Cormier	dr.claud.cormier@geemail.com	San Francisco	California	4667986068747850	c4c573e43440c2da1fd88a1ad964c188	JCB 15 digit	37.7852207265138915	-122.416202623099934
43893	2020-08-10 17:16:50	2020-08-10	Anais Crooks	anais.crooks@warmmail.com	Austin	Texas	3463472542737031	4b1f478e5a1d9ecf81081451e6a8fbef	Diners Club / Carte Blanche	30.2805517804469915	-97.6658591714926132
43894	2020-08-10 17:18:09	2020-08-10	Van Padberg	van.padberg@geemail.com	Greensboro	North Carolina	4071298810665	f996f8503c99a752b1e785921ed0e332	American Express	36.078970043884965	-79.8539531210418829
43895	2020-08-10 17:19:04	2020-08-10	Bernice Dibbert	bernice.dibbert@geemail.com	Murrieta	California	53975101747126867	b005f0818dcda275bb9123a762144089	Mastercard	33.5781168925207112	-117.286776272989428
43896	2020-08-10 17:19:44	2020-08-10	Makhi Wunsch I	makhi.wunsch.i@geemail.com	New York	New York	6011265805176290080	6be40e0c93b2c06c155484e78a6d30b8	VISA 16 digit	40.6631002557687466	-73.8664553766500234
43897	2020-08-10 17:36:28	2020-08-10	Vanesa Renner PhD	vanesa.renner.phd@geemail.com	Fresno	California	4271765013385	94702b47687adeb496af4b5eb370758e	Mastercard	36.7597619570199399	-119.820963657518476
43898	2020-08-10 17:51:09	2020-08-10	Lidie Schmitt	lidie.schmitt@geemail.com	Fremont	California	4447720958182887	d9a5984b7c6fe1684587c60e27b19ef3	VISA 16 digit	37.567550811002036	-121.883282094727079
43899	2020-08-10 18:00:43	2020-08-10	Dr. Cinthia Harris	dr.cinthia.harris@geemail.com	Cleveland	Ohio	6011037007540285246	5aadeaca2af52416dfd0f2e5095aff1a	Mastercard	41.4752131870798735	-81.6541457528952463
43900	2020-08-10 18:02:17	2020-08-10	Tess Yost	tess.yost@geemail.com	Pompano Beach	Florida	210052463126977971	5e8ed915084d3b0ce83a218941d9f3e9	Diners Club / Carte Blanche	26.3137940819639695	-80.1564482966285112
43901	2020-08-10 18:25:32	2020-08-10	Gwenda Hackett	gwenda.hackett@geemail.com	Chicago	Illinois	3528823919632477663	15048d7fb5447982aee1bf2632785783	VISA 16 digit	41.8751244895461952	-87.661864709112038
43902	2020-08-10 18:29:33	2020-08-10	Nikole Herzog	nikole.herzog@warmmail.com	New York	New York	3088785786640020454	068611703829778a57778856e838315b	Discover	40.68722428965755	-73.8679051895987158
43903	2020-08-10 18:40:40	2020-08-10	Nakia Zemlak	nakia.zemlak@geemail.com	Macon	Georgia	4298704379582982	fcd7d1022df88c1c316b1c1022c30adb	JCB 16 digit	32.8936878505639712	-83.673849736545975
43904	2020-08-10 18:51:56	2020-08-10	Craig Kling	craig.kling@geemail.com	Tucson	Arizona	3741752039419020	b520c3e8170b1f0533b3af882fb08551	JCB 16 digit	32.1345669820945758	-110.890244248625265
43905	2020-08-10 18:54:10	2020-08-10	Kenya Hagenes IV	kenya.hagenes.iv@woohoo.com	Worcester	Massachusetts	4331234209244	b7b84051bc649351eda731392b403cbd	VISA 16 digit	42.2895809290166937	-71.8782398000612801
43906	2020-08-10 19:00:58	2020-08-10	Thorwald Von	thorwald.von@geemail.com	Miami Gardens	Florida	3096679115991881315	2d9033e4fb01514ba74484258313f7e5	JCB 16 digit	25.9052441337551898	-80.3362183818839526
43907	2020-08-10 19:03:10	2020-08-10	Monserrat Purdy	monserrat.purdy@geemail.com	High Point	North Carolina	3027050069555140	c2b9c1cd73d3c891311df1fa6e7b0daf	Mastercard	36.0577960763685397	-79.9579051062669635
43908	2020-08-10 19:03:38	2020-08-10	Glenn Bahringer	glenn.bahringer@warmmail.com	Corpus Christi	Texas	4762215888685064	eaea16b1b0260a36c25ea62b1d9fdf03	Discover	27.7660768304422518	-97.1902248551431995
43909	2020-08-10 19:13:00	2020-08-10	Dr. Waymon Mitchell	dr.waymon.mitchell@geemail.com	San Francisco	California	3041194003092509	3ff80e4d65ed0c87ad48d65df6c4bf49	JCB 16 digit	37.7761326984520736	-122.447657907921283
43910	2020-08-10 19:15:49	2020-08-10	Miss Rubie Bins	miss.rubie.bins@woohoo.com	Torrance	California	3426894691926717	0561faf62a4e962bdcdd0d7fc7181a60	Voyager	33.9042976010497696	-118.398926256702836
43911	2020-08-10 19:19:32	2020-08-10	Miss Edwina Kirlin MD	miss.edwina.kirlin.md@geemail.com	Boston	Massachusetts	3749410711408280	184cacc1ad48abae946e5265c0ff8974	Maestro	42.2802699876185528	-71.094484470314157
43912	2020-08-10 19:20:04	2020-08-10	Keenen Kuhlman	keenen.kuhlman@geemail.com	Newport News	Virginia	3088694443159625949	d7d18cb1ca8b3be5d4d8506a568841c1	Maestro	37.0388965899486067	-76.431776948951196
43913	2020-08-10 19:24:33	2020-08-10	Sarrah Gottlieb	sarrah.gottlieb@geemail.com	Los Angeles	California	3096524436259934142	75264c94d44a81fd8b8fa959b3340853	Discover	34.0112769347015771	-118.481375124025334
43914	2020-08-10 19:44:29	2020-08-10	Xena Windler	xena.windler@warmmail.com	Louisville	Kentucky	51194202715811566	257ba6677bfd7f2f0283f55d5091e582	JCB 16 digit	38.1614554192308333	-85.6198257135298206
43915	2020-08-10 19:47:28	2020-08-10	Mildred Lubowitz	mildred.lubowitz@warmmail.com	New York	New York	3096278823471494088	4fb6c77345484f295f3c67fe86f3c933	VISA 16 digit	40.6326152147017439	-73.9722324272978966
43916	2020-08-10 19:49:42	2020-08-10	Dr. Emmer Marvin	dr.emmer.marvin@warmmail.com	Austin	Texas	3158284222352826660	8e8ef132a300c72a5c92b88624c1c9b1	Diners Club / Carte Blanche	30.3093019387811395	-97.6600412881705893
43917	2020-08-10 19:50:59	2020-08-10	Lyndsey Hermiston	lyndsey.hermiston@woohoo.com	Fresno	California	4100360495831924	802c68a1d5163c19ff4c43bf3d52e209	American Express	36.8007781580895212	-119.739027412199974
43918	2020-08-10 19:54:55	2020-08-10	Manuel Bergstrom	manuel.bergstrom@woohoo.com	Austin	Texas	3528142542149784944	db9fc749df7cd122b812ce6647077c21	Discover	30.3804356400515871	-97.8027522571157704
43919	2020-08-10 19:58:15	2020-08-10	Matthew Thiel	matthew.thiel@geemail.com	San Francisco	California	180097798654766446	a2cc05f985a09c184db211fb2c756a4e	JCB 15 digit	37.7646674882573166	-122.446427295894907
43920	2020-08-10 20:01:49	2020-08-10	Al Wyman	al.wyman@woohoo.com	Scottsdale	Arizona	3158034752149590990	4d9de542672800ab444beb02297d036c	Maestro	33.7158832410473366	-111.891831526808801
43921	2020-08-10 20:07:02	2020-08-10	Lashunda Wilderman DDS	lashunda.wilderman.dds@warmmail.com	San Francisco	California	4235888295781	a51f7f22fe25f2c8e7111ab5a3d5c28f	Discover	37.7836225119309717	-122.466689377976422
43922	2020-08-10 20:18:25	2020-08-10	Ima Muller	ima.muller@geemail.com	New York	New York	675962697429793	ba9d2e6fec360c0536efe8f08abf9e18	JCB 15 digit	40.6868194655273072	-73.9552478478651523
43923	2020-08-10 20:28:20	2020-08-10	Rosaline Kirlin	rosaline.kirlin@woohoo.com	San Diego	California	3088802963750716242	4eb0bfd034ec9da7aa155978d326131c	Maestro	32.9110834886387025	-117.160873457361021
43924	2020-08-10 20:37:18	2020-08-10	Enriqueta Baumbach	enriqueta.baumbach@geemail.com	New York	New York	869924394262677791	e188f44b07aef35e6abbe8537b00b94a	VISA 16 digit	40.7352586250510029	-73.8450198264688282
43925	2020-08-10 20:43:12	2020-08-10	Sabrina Ruecker-Reichert	sabrina.ruecker.reichert@geemail.com	Waterbury	Connecticut	52406180899625511	2c00ca170e8370bc5017c39c707a0d5a	American Express	41.581486593050883	-73.0079578906677682
43926	2020-08-10 20:45:57	2020-08-10	Orlena Jacobs	orlena.jacobs@geemail.com	San Francisco	California	210022357315241818	5591231bfd2eae02856cf93d4d841345	JCB 16 digit	37.7868158969443684	-122.411541673971684
43927	2020-08-10 20:51:53	2020-08-10	Lyric Moore PhD	lyric.moore.phd@geemail.com	Houston	Texas	3719322207729036	8e65bb15baa8312acbed9f9f82babc16	American Express	29.714912353044749	-95.4616244827877694
43928	2020-08-10 20:54:58	2020-08-10	Mrs. Freda Rau	mrs.freda.rau@woohoo.com	Dallas	Texas	3486400309033487	57b1af560f9853caafac5f85050f677b	Diners Club / Carte Blanche	32.7924649779491162	-96.7905424205548996
43929	2020-08-10 20:57:06	2020-08-10	Kristyn Erdman	kristyn.erdman@woohoo.com	Evansville	Indiana	53453617112410611	2836bb2504fcbdf5b706db5bccd9c1cd	Discover	38.0865423552364106	-87.4994822437807898
43930	2020-08-10 21:12:02	2020-08-10	Jean Swaniawski	jean.swaniawski@geemail.com	Philadelphia	Pennsylvania	4516618909768976	a00c6ba659364ef9f895dd2cf6431d5d	VISA 16 digit	40.0782123467843974	-75.0718299497749655
43931	2020-08-10 21:31:53	2020-08-10	Dr. Egbert Hand	dr.egbert.hand@warmmail.com	Hampton	Virginia	503877841545617	148b31b35aff7a61c22c44be2f630179	American Express	37.0458707754053194	-76.2591896773412827
43932	2020-08-10 21:32:25	2020-08-10	Tegan Kuhn	tegan.kuhn@geemail.com	Round Rock	Texas	3528599371403379797	5ea38db44c9a8d9edd8728aca4ea8563	JCB 16 digit	30.6099300788853341	-97.673932642754167
43933	2020-08-10 21:45:12	2020-08-10	Leesa Kovacek-Deckow	leesa.kovacek.deckow@geemail.com	San Jose	California	4236194992258522	6a2cf8035849b8c0786cc56883bf5b27	Discover	37.3848334147416068	-121.799773006908225
43934	2020-08-10 22:00:27	2020-08-10	Dr. Bebe Nikolaus MD	dr.bebe.nikolaus.md@geemail.com	Berkeley	California	4926853323921596	63bc73404cca52964a5deaa2e04d5b21	Discover	37.9003215010678929	-122.279565450748805
43935	2020-08-10 22:03:48	2020-08-10	Ewald Klein	ewald.klein@geemail.com	San Francisco	California	6011331539406165818	995fbf0edbe66e6d8f593943a6f460b7	Diners Club / Carte Blanche	37.7660009972155919	-122.437711883456146
43936	2020-08-10 22:05:34	2020-08-10	Foster Maggio	foster.maggio@geemail.com	San Francisco	California	869969344791284169	4aa8cee2ed016e2f6a01a73c0bee59d1	American Express	37.7750105258224593	-122.418391566926289
43937	2020-08-10 22:05:54	2020-08-10	Arbie Hilll	arbie.hilll@geemail.com	Los Angeles	California	4194508256931559	256f22b384655f8277341069ab5a73f5	Diners Club / Carte Blanche	33.9353778180532117	-118.454833404439682
43938	2020-08-10 22:10:45	2020-08-10	Dr. Elvis Russel	dr.elvis.russel@geemail.com	Clovis	California	4093816440157623	86c51575d1deed19fc6509c98cca9f8c	Discover	36.7499192662414202	-119.733131240734451
43939	2020-08-10 22:11:10	2020-08-10	Georgeann Sawayn MD	georgeann.sawayn.md@geemail.com	Fremont	California	210041070109228589	307cd8d857486d4f7e0a1912008da164	Discover	37.571821414323523	-121.944719817721094
43940	2020-08-10 22:11:39	2020-08-10	Calhoun Klein	calhoun.klein@geemail.com	Chicago	Illinois	3088119607436552657	8cf2ee93316d71165282e104a0eb2698	Maestro	41.873204328522462	-87.7654712566204296
43941	2020-08-10 22:26:13	2020-08-10	Merry Gutkowski-Mohr	merry.gutkowski.mohr@warmmail.com	Lafayette	Louisiana	51968969120854035	495dad0b0b23c385d37e075c0ae174fd	JCB 16 digit	30.1573901443254186	-91.9568880909904749
43942	2020-08-10 22:40:12	2020-08-10	Torry Walker Jr.	torry.walker.jr.@geemail.com	San Francisco	California	675984053325951	e4f499f392314452229445edb64fcbd7	Mastercard	37.783847391987905	-122.418002340608908
43943	2020-08-10 22:45:10	2020-08-10	Dr. Debbra Mayert DVM	dr.debbra.mayert.dvm@geemail.com	San Jose	California	3778483664785883	d014f4c880f955f4d4ff85b257f57c9f	Diners Club / Carte Blanche	37.2458286657284958	-121.817459721140196
43944	2020-08-10 22:57:45	2020-08-10	Roswell Funk	roswell.funk@geemail.com	Meridian	Idaho	3337830500745767454	d406ce743bf5c466fdcbeba702d2f0db	JCB 16 digit	43.5772979703739267	-116.459679615445054
43945	2020-08-10 22:59:20	2020-08-10	Bettyjane Lynch	bettyjane.lynch@geemail.com	Newark	New Jersey	3088135329444606462	27271fded051d445ef2b719c265a513e	VISA 16 digit	40.7186149635732235	-74.1138619173526791
43946	2020-08-10 23:11:35	2020-08-10	Othel Barrows	othel.barrows@geemail.com	Memphis	Tennessee	55153831456183527	e33b658336204faaa646bbab248938df	American Express	35.0524303068008294	-89.9996549500875176
43947	2020-08-10 23:26:22	2020-08-10	Berry Tremblay	berry.tremblay@woohoo.com	Irvine	California	4671744188168	99c01bba1cc345a1327d90dc648a8bf7	JCB 16 digit	33.7495687529459616	-117.728348779586327
43948	2020-08-10 23:31:08	2020-08-10	Milissa Kozey	milissa.kozey@geemail.com	Salem	Oregon	4861981611008755	bc109e9b9099fc8dc152f6879b4ccaf8	Diners Club / Carte Blanche	44.9037795583520065	-122.935416317933061
43949	2020-08-10 23:32:38	2020-08-10	Stephenie Crist	stephenie.crist@woohoo.com	Tucson	Arizona	3158862758698169885	b76d665aaf1b66cdf4fc7739075c7a9c	Mastercard	32.1379028697539155	-110.932404000148551
43950	2020-08-10 23:33:47	2020-08-10	Collette Padberg	collette.padberg@geemail.com	Milwaukee	Wisconsin	630486564757713	5124dc6405fcc7d760bce3c1f3de7e50	Voyager	43.0755812433633949	-88.0453565619520901
43951	2020-08-10 23:34:18	2020-08-10	Mikhail Maggio	mikhail.maggio@woohoo.com	Lansing	Michigan	4709805992860	3b5f1b8f1414d49445999d0193208ae3	Diners Club / Carte Blanche	42.629098089768739	-84.6230737394310495
43952	2020-08-10 23:35:58	2020-08-10	Nasir Kshlerin	nasir.kshlerin@geemail.com	New York	New York	3337744738866490713	b31ddd368c6efd08a2ef6ad786622438	VISA 13 digit	40.6306377108432315	-73.9823202829703632
43953	2020-08-10 23:36:56	2020-08-10	Acie Stoltenberg I	acie.stoltenberg.i@woohoo.com	Charlotte	North Carolina	869917134257690139	b2931f74b4e041c90c20420c1a770340	Mastercard	35.1634892060674744	-80.8644788994398027
43954	2020-08-10 23:37:37	2020-08-10	Bethel Renner V	bethel.renner.v@geemail.com	Vancouver	Washington	561287224927753	9af7334c34a01b805e2f7cc0c7a87df5	Voyager	45.561625694630294	-122.6714320174016
43955	2020-08-10 23:39:37	2020-08-10	Ibrahim Dickens	ibrahim.dickens@warmmail.com	Houston	Texas	3158563146489648972	191626f0f436b591dc18de2f0dbb715d	Diners Club / Carte Blanche	29.6995573164042099	-95.3119018195211964
43956	2020-08-10 23:45:03	2020-08-10	Zechariah Jakubowski	zechariah.jakubowski@geemail.com	Garland	Texas	4685925846402	20c59995b3e196054b6caf06596e6f08	VISA 13 digit	32.8858543187614529	-96.6480934272680514
43957	2020-08-10 23:45:31	2020-08-10	Mrs. Erykah Considine	mrs.erykah.considine@geemail.com	Orlando	Florida	4006394165568990	85ddab55eaf63de9017c986cd6702d88	Mastercard	28.3845225626867261	-81.2931654122158847
43958	2020-08-10 23:52:48	2020-08-10	Katelin Schultz	katelin.schultz@warmmail.com	McKinney	Texas	3096382766540142621	0856ba03f0e4c784cce2805a266d0f2f	Voyager	33.2381872544195502	-96.7248686387036116
43959	2020-08-10 23:53:22	2020-08-10	Mr. Patric McLaughlin	mr.patric.mclaughlin@geemail.com	El Paso	Texas	3528701857833390193	47d07398e544fed19b8a3d6df11131b9	JCB 16 digit	31.9316547274418205	-106.511614420356238
43960	2020-08-10 23:55:17	2020-08-10	Levi Sipes	levi.sipes@warmmail.com	Phoenix	Arizona	53605276947432519	0c5b2a9872ccc810c69ec1e50d896287	Voyager	33.5141347366318101	-112.029378776105503
43961	2020-08-10 23:56:35	2020-08-10	Dempsey Koelpin	dempsey.koelpin@woohoo.com	New York	New York	3706086738692493	79333cb4c6682eabf9fd4c60942e4805	VISA 16 digit	40.6754060118216998	-74.0228629164759013
43962	2020-08-11 00:11:56	2020-08-11	Arba Smith Sr.	arba.smith.sr.@warmmail.com	Detroit	Michigan	503869064256543	da185c6b14d2033ae329a150077fc3eb	VISA 13 digit	42.4109455364681835	-83.0237587232261802
43963	2020-08-11 00:14:07	2020-08-11	Yasmeen Dach	yasmeen.dach@warmmail.com	Milwaukee	Wisconsin	3492840292283361	c0c0b8c9fe58ce795448839d722c0d4c	Discover	43.1604129652578337	-87.9863988097857685
43964	2020-08-11 00:27:53	2020-08-11	Deric Grant	deric.grant@warmmail.com	New York	New York	3096398227360325517	7507f9a8546340617c2826180209ccea	Voyager	40.7068917397633214	-73.9296538981504767
43965	2020-08-11 00:29:48	2020-08-11	Antwan Gusikowski-Bruen	antwan.gusikowski.bruen@woohoo.com	Los Angeles	California	3088320799269346714	b6a22a20895423a53b011f6cdd4da395	VISA 13 digit	34.0693296394176741	-118.323083554626621
43966	2020-08-11 00:34:21	2020-08-11	Billy Hegmann-Hettinger	billy.hegmann.hettinger@woohoo.com	New York	New York	210056446687737914	e076a25ccdc8d25dfeda3d12df12d19f	Maestro	40.6029889493938541	-73.990832835099468
43967	2020-08-11 00:36:11	2020-08-11	Jaxton Dare	jaxton.dare@geemail.com	Jacksonville	Florida	3337153711081887603	6424dc3ebe4f5b780d147d1f25930a54	VISA 16 digit	30.3244232878606752	-81.575415601496033
43968	2020-08-11 00:45:42	2020-08-11	Mckinley Osinski-Padberg	mckinley.osinski.padberg@geemail.com	Oakland	California	3769076926687656	34d4d9e446ac42da5fedc598c15e8429	VISA 13 digit	37.7879810295831788	-122.267806906247088
43969	2020-08-11 01:09:10	2020-08-11	Mr. Giles Strosin	mr.giles.strosin@warmmail.com	Kenosha	Wisconsin	4346736749031334	0922e2950a93e2bc9fec1969a8835bfc	VISA 16 digit	42.5153192604731771	-87.8243540191318885
43970	2020-08-11 01:14:26	2020-08-11	Dalton Schiller PhD	dalton.schiller.phd@geemail.com	Centennial	Colorado	210021945155905996	4ac1db0b5fcde12f7be67749138031cd	Maestro	39.6249916759826277	-104.895722326206425
43971	2020-08-11 01:24:11	2020-08-11	Maceo Bernier	maceo.bernier@geemail.com	Newport News	Virginia	4239178924280123	8b8d8494d61ee37ba778878a3f59a4f9	Diners Club / Carte Blanche	37.1303918345261366	-76.5628167648594911
43972	2020-08-11 01:33:18	2020-08-11	Yosef Larson	yosef.larson@geemail.com	Ontario	California	676195696244979	713a941ad5776dcfcd0c08fc65df6896	Maestro	34.0581197359278818	-117.515532893790677
43973	2020-08-11 01:41:12	2020-08-11	Mr. Tyrek Daniel DDS	mr.tyrek.daniel.dds@woohoo.com	Des Moines	Iowa	3158998516897406467	a1ec009a0acd016cfbbe68900653b4ff	JCB 16 digit	41.4840291699137538	-93.5985026209194331
43974	2020-08-11 01:44:02	2020-08-11	Velda Lubowitz	velda.lubowitz@geemail.com	Indianapolis	Indiana	6011402419784965259	5a9d1c66a89a3c02c286fa5a8c24a200	American Express	39.8346333295579953	-86.1250965093463634
43975	2020-08-11 01:47:14	2020-08-11	Everet Brakus	everet.brakus@geemail.com	New York	New York	3051306004042784	fac098e74a20b91b60d91db0a4e2da9a	VISA 13 digit	40.6130072191581135	-73.9463685026288005
43976	2020-08-11 02:03:34	2020-08-11	Miss Lisha Koelpin MD	miss.lisha.koelpin.md@geemail.com	Vacaville	California	4287714209353	ab59174056e61c39c2465ec866d78c3b	JCB 16 digit	38.3552712678104655	-121.874054513999454
43977	2020-08-11 02:25:15	2020-08-11	Miss Georgiana Treutel	miss.georgiana.treutel@geemail.com	Saint Paul	Minnesota	4698363497873801	883615ed1637b3ed7504d89c69019e3a	VISA 16 digit	45.0269029301997321	-93.0065133183993424
43978	2020-08-11 02:28:17	2020-08-11	Alanzo Dickinson	alanzo.dickinson@geemail.com	Norman	Oklahoma	869969107517799780	d53488ca30cbdcb4570f98bd10e52986	VISA 16 digit	35.3333673404570661	-97.4432721579700711
43979	2020-08-11 02:28:38	2020-08-11	Dr. Tonda Heathcote PhD	dr.tonda.heathcote.phd@geemail.com	Cedar Rapids	Iowa	52199794866462103	c5abdc98a2202920c9de7290224717e8	VISA 13 digit	42.0163315839674283	-91.6853718948151908
43980	2020-08-11 02:30:55	2020-08-11	Mr. Mason Koch DVM	mr.mason.koch.dvm@warmmail.com	Ann Arbor	Michigan	6011327528144568074	10c43f6c67acb301db911086e5b18305	Maestro	42.2881917103718976	-83.6352541986961029
43981	2020-08-11 02:40:53	2020-08-11	Odalys Waelchi	odalys.waelchi@geemail.com	San Francisco	California	54634037594120186	b8cb97d1dfc2a54d7c912ab892f41d9b	Mastercard	37.7624536852175225	-122.421046958830772
43982	2020-08-11 02:52:29	2020-08-11	Denny Stoltenberg	denny.stoltenberg@warmmail.com	Clovis	California	869905591310925717	c95dc5e3ab8b1b6f4d57a49a59e868d9	VISA 13 digit	36.922470948786291	-119.602586111573132
43983	2020-08-11 02:59:16	2020-08-11	Shyla Harvey	shyla.harvey@woohoo.com	Clearwater	Florida	3096564276387582764	d23c50f61505d030c227206ea18ff833	Mastercard	27.9581927043978133	-82.8201793871153171
43984	2020-08-11 03:04:09	2020-08-11	Beadie Frami	beadie.frami@geemail.com	Oakland	California	3477517886591099	bac9deb5cd18a53c3bc0ba4d9ac10257	VISA 13 digit	37.782545812341489	-122.247673914891038
43985	2020-08-11 03:08:18	2020-08-11	Saniyah Koch-Metz	saniyah.koch.metz@woohoo.com	Raleigh	North Carolina	4635250205161809	b57099c45a4abcc113354ade22a89997	JCB 16 digit	35.8353026582062242	-78.7376444108255242
43986	2020-08-11 03:14:36	2020-08-11	Mrs. Gabriela Littel MD	mrs.gabriela.littel.md@woohoo.com	Glendale	Arizona	3158530066114668916	ea11ecbaa20b0ba97a39308b4e0917d2	Voyager	33.5152521265432242	-112.191687348231298
43987	2020-08-11 03:17:23	2020-08-11	Larkin Windler	larkin.windler@geemail.com	San Francisco	California	180047413554876607	8482484c7592c733cf5b62ea809ccd92	VISA 16 digit	37.7904433544883602	-122.419940022601082
43988	2020-08-11 03:21:22	2020-08-11	Freddie Greenholt	freddie.greenholt@warmmail.com	Escondido	California	180094131262655293	07204d2e485871ebdeb67fd0fc47901d	American Express	33.1843603933922964	-117.013243716886265
43989	2020-08-11 03:22:08	2020-08-11	Bennett Keebler	bennett.keebler@geemail.com	San Francisco	California	869980549527774912	9f869aa5d46c40b72e423d2a8c3d6d32	Voyager	37.781669848122668	-122.45167863383989
43990	2020-08-11 03:26:12	2020-08-11	Dr. Bernhard Parker DDS	dr.bernhard.parker.dds@geemail.com	Hayward	California	3088441494939081552	c659c9b69947141204799bfef2536565	Discover	37.550844492575898	-122.149571517973769
43991	2020-08-11 03:28:11	2020-08-11	Love Lynch	love.lynch@geemail.com	Oklahoma City	Oklahoma	4259061777025859	7bb4b08dd957aa7f76a23ca27bad228a	Discover	35.3695942332413082	-97.5527435880981386
43992	2020-08-11 03:36:42	2020-08-11	Mrs. Ethyle Shanahan PhD	mrs.ethyle.shanahan.phd@geemail.com	Columbus	Ohio	55495086270033591	38655a53e376f1ca37d77e1039d6dbbb	VISA 13 digit	39.9980618110436907	-82.9948548697169883
43993	2020-08-11 03:38:06	2020-08-11	Lura Goldner	lura.goldner@geemail.com	Oakland	California	869960550963427019	9ab0940ad00a95458d3c271d5665984c	American Express	37.8340990782860302	-122.266205794340223
43994	2020-08-11 03:48:51	2020-08-11	Dariana Kulas	dariana.kulas@geemail.com	Philadelphia	Pennsylvania	3528672602227393238	6da1419d47852c2319c3b91c1f7159fc	Discover	40.0298083110671499	-75.1904554380934798
43995	2020-08-11 03:50:50	2020-08-11	Mertie Connelly	mertie.connelly@warmmail.com	Cedar Rapids	Iowa	4448323179168337	c35ac6601389a428afa83f367912e3a4	Discover	41.9198216552454994	-91.7015746706698138
43996	2020-08-11 03:52:15	2020-08-11	Leanna Steuber DDS	leanna.steuber.dds@geemail.com	Los Angeles	California	210016786586528453	f1458d4fc068340f7bf2f3ccb23fae4b	JCB 16 digit	33.9979246168263245	-118.3689629901193
43997	2020-08-11 03:59:17	2020-08-11	Ray Hirthe	ray.hirthe@geemail.com	Irving	Texas	4670148709246868	5cc83ed3b3e9f088fc6ea34024cfac31	VISA 16 digit	32.918334336387737	-97.0596648448426293
43998	2020-08-11 04:01:01	2020-08-11	Ricki VonRueden	ricki.vonrueden@geemail.com	Murrieta	California	6011821306010220323	654b71a7c357e3e42b9eb65cef1922f5	Diners Club / Carte Blanche	33.4924666456975046	-117.14633940713442
43999	2020-08-11 04:03:45	2020-08-11	Clemence Leuschke	clemence.leuschke@warmmail.com	Corpus Christi	Texas	4156631314885835	1f2dde5275418b72ea9f44cfb150f1fa	Diners Club / Carte Blanche	27.7495607143204666	-97.1798569605514473
44000	2020-08-11 04:14:32	2020-08-11	Ms. Kaylin Veum	ms.kaylin.veum@geemail.com	Chicago	Illinois	52969799250085467	fd4a667d12712eda0bf30485cb06acb7	VISA 13 digit	41.7494424572516252	-87.5909133867390466
44001	2020-08-11 04:31:03	2020-08-11	Miss Toya Baumbach DDS	miss.toya.baumbach.dds@geemail.com	Montgomery	Alabama	676248613733095	b151949e6e243dcf0414d6b93f4c702e	Mastercard	32.3342208603795598	-86.2926998618677175
44002	2020-08-11 04:36:48	2020-08-11	Miss Melinda Bruen	miss.melinda.bruen@geemail.com	Stockton	California	4380262068037486	0a6a32dbf5f79bf74179a1d51cba0daf	VISA 16 digit	37.9402049265068015	-121.271015011108659
44003	2020-08-11 04:49:02	2020-08-11	Miss Verne Bednar	miss.verne.bednar@geemail.com	Denver	Colorado	869996050480468024	588676d385484d89cb2c10571ad4e1a5	American Express	39.7399735340435001	-104.820766041312737
44004	2020-08-11 04:49:23	2020-08-11	Obie Mayer-Carroll	obie.mayer.carroll@geemail.com	Oakland	California	52037327624011874	9a62524332db01d223caa79ceca41dec	Diners Club / Carte Blanche	37.8170899399208551	-122.268199135717936
44005	2020-08-11 04:52:24	2020-08-11	Mrs. Ayana Hartmann PhD	mrs.ayana.hartmann.phd@geemail.com	Chicago	Illinois	4788573496819818	a794560ebf9778ca6e973f4b3c950a33	Discover	41.7411276278387788	-87.7171053781203938
44006	2020-08-11 04:59:49	2020-08-11	Henderson Willms-Halvorson	henderson.willms.halvorson@geemail.com	Phoenix	Arizona	52850045779607825	f119773f51d13fea9198ec995e90b64b	Mastercard	33.6531947017114632	-112.1800547519628
44007	2020-08-11 05:00:24	2020-08-11	Philip Schowalter	philip.schowalter@geemail.com	Dallas	Texas	3088315470025423257	dd347e57f6dcc3778ce22d0f73ab387f	VISA 16 digit	32.7862173379205188	-96.7699151200670684
44008	2020-08-11 05:05:22	2020-08-11	Lary Kiehn	lary.kiehn@warmmail.com	Tacoma	Washington	561292379316158	6a8daee9e3a5291fe76dd8025d742d77	JCB 16 digit	47.2041400123041157	-122.456174044101687
44009	2020-08-11 05:11:07	2020-08-11	Lexie Greenfelder Sr.	lexie.greenfelder.sr.@geemail.com	Memphis	Tennessee	4044529397738267	46dc337e124fb9d43b462eed21c39cfb	VISA 16 digit	35.162584896019851	-89.9488819081593363
44010	2020-08-11 05:18:03	2020-08-11	Georgeann Hauck	georgeann.hauck@geemail.com	Riverside	California	3158782634060333440	4e1d5557bf4fbcb99266ee17a5b81bab	JCB 15 digit	33.841025790846345	-117.317871550421032
44011	2020-08-11 05:26:44	2020-08-11	Jannette Harber-Walker	jannette.harber.walker@geemail.com	San Francisco	California	3528323063210969141	3c07053bf5bd4dfdfed6e999258dfcb2	JCB 15 digit	37.7611813410507295	-122.412648206032657
44012	2020-08-11 05:27:53	2020-08-11	Myla Koelpin-Kohler	myla.koelpin.kohler@warmmail.com	New York	New York	3528650209836124339	f390f4628512ef0aed56347a1615c175	Voyager	40.5932136019915362	-73.848360250507298
44013	2020-08-11 05:28:27	2020-08-11	Mr. Zackery Bernier	mr.zackery.bernier@geemail.com	Colorado Springs	Colorado	3704039887667511	ced926f3a7e88fab516b77e0a829514f	Diners Club / Carte Blanche	38.7721628966789709	-104.814238271645081
44014	2020-08-11 05:30:57	2020-08-11	Kaycee Senger	kaycee.senger@warmmail.com	New York	New York	6011051717893965134	55bd9126ffe93aaffeacf8f0e0578e02	JCB 16 digit	40.724847050871702	-73.8643066463422002
44015	2020-08-11 05:31:45	2020-08-11	Merton Hansen	merton.hansen@geemail.com	New Haven	Connecticut	3088080210362926261	b33d1160c7328203be358cebeb852fb3	Diners Club / Carte Blanche	41.2488854601506176	-72.838172665797174
44016	2020-08-11 05:39:25	2020-08-11	Dr. Kraig Green II	dr.kraig.green.ii@geemail.com	Salt Lake City	Utah	210003893506094890	c872c06ed295d83c11d58046dfde3bd5	JCB 16 digit	40.8458690834842599	-111.959663480700925
44017	2020-08-11 05:48:19	2020-08-11	Milo Grady	milo.grady@geemail.com	Omaha	Nebraska	3447391357467552	51005d2c7dad7460a0601e5f59bc25ba	JCB 16 digit	41.3201548385113497	-95.9904321461100238
44018	2020-08-11 05:54:13	2020-08-11	Mr. Devon Brekke	mr.devon.brekke@geemail.com	San Francisco	California	3158036966444290878	64960f7839e1b75c8db3bd75f6106c58	Voyager	37.7724837332732193	-122.419699757289351
44019	2020-08-11 05:57:21	2020-08-11	Mr. Krish Oberbrunner II	mr.krish.oberbrunner.ii@geemail.com	Charlotte	North Carolina	54309296437026836	5db2a044b12eb301cbafe6b53b2c16f6	American Express	35.2901436207137991	-80.8181946495957675
44020	2020-08-11 06:06:33	2020-08-11	Delmas Bruen	delmas.bruen@geemail.com	Fort Worth	Texas	639028635786750	cecc7591487b88b1ffd1f2e331956af1	American Express	32.8130501238685142	-97.2837058373548018
44021	2020-08-11 06:08:11	2020-08-11	Maren Balistreri-Klein	maren.balistreri.klein@geemail.com	Berkeley	California	3112646641314131583	273c69c68d3922581be10091313383d6	Maestro	37.8853515141461301	-122.272514810941615
44022	2020-08-11 06:25:55	2020-08-11	Dani Predovic	dani.predovic@geemail.com	New York	New York	3112290391547294035	d5a122c889c689113c523eba9441f467	Maestro	40.6128576879147403	-74.0324797356396829
44023	2020-08-11 06:30:22	2020-08-11	Fed Quitzon-Dickinson	fed.quitzon.dickinson@geemail.com	Burbank	California	3112597536689967182	0a48f6d2e8183e5a0bdcc6f7b5c9f48a	JCB 16 digit	34.1128978244423848	-118.38872214733027
44024	2020-08-11 06:34:45	2020-08-11	Yazmin Aufderhar	yazmin.aufderhar@woohoo.com	Pearland	Texas	589358477722936	be2bc4de395982dde4a19a898b460062	Maestro	29.6196626174069948	-95.3932297244522687
44025	2020-08-11 06:38:54	2020-08-11	Dr. Roby Auer	dr.roby.auer@geemail.com	Houston	Texas	3088659414422859360	7a8d75285d295cbcdb86de0197bad05b	Voyager	29.780828977756574	-95.3678761912059088
44026	2020-08-11 06:44:41	2020-08-11	Gabe Gibson	gabe.gibson@woohoo.com	Nashville	Tennessee	4579873995791192	b95b7abcbf59e639473ce894e12d2e02	VISA 16 digit	36.2531641846645627	-86.771265231296411
44027	2020-08-11 06:55:00	2020-08-11	Fred Thompson	fred.thompson@geemail.com	Warren	Michigan	4621459807452	c1269d640a2b971ee80c53bad3fc7a3b	JCB 16 digit	42.5754666997116047	-83.1073903731536205
44028	2020-08-11 07:02:58	2020-08-11	Susanne Wilkinson	susanne.wilkinson@warmmail.com	Los Angeles	California	180057361894308491	29982efc0a602cc1a089c4059f8a1662	VISA 16 digit	34.078661507494374	-118.441273531968889
44029	2020-08-11 07:06:44	2020-08-11	Artis O'Connell-Lubowitz	artis.o'connell.lubowitz@warmmail.com	San Francisco	California	6011285069425190270	9e0438a9ef62a3183adf3386e42c6b6c	Diners Club / Carte Blanche	37.776619789117639	-122.408777745350847
44030	2020-08-11 07:08:52	2020-08-11	Dr. Arvel Lehner	dr.arvel.lehner@geemail.com	Atlanta	Georgia	6011575365289487292	a1fd12d194e30d391ef6e94d89213171	Diners Club / Carte Blanche	33.843681890731304	-84.3524051829285924
44031	2020-08-11 07:14:29	2020-08-11	Savana Rowe MD	savana.rowe.md@woohoo.com	Los Angeles	California	3528935858129093820	0f18f4460129686a7aff42f13abb2793	VISA 16 digit	33.9412981649260956	-118.408029894390324
44032	2020-08-11 07:15:06	2020-08-11	Mikal Walsh	mikal.walsh@warmmail.com	Baltimore	Maryland	869983124923699852	ec08c0a13f62ea60db31f5568681109a	Maestro	39.2665356336627127	-76.5276370683703533
44033	2020-08-11 07:15:58	2020-08-11	Dr. Miriah Rolfson	dr.miriah.rolfson@geemail.com	Sparks	Nevada	210027501308088588	e5d13bd60b8f1da29db93160d306aed1	VISA 16 digit	39.4761959712725172	-119.753933391379576
44034	2020-08-11 07:20:25	2020-08-11	Dr. Edmund Rau III	dr.edmund.rau.iii@warmmail.com	Omaha	Nebraska	4777394633195	6313d25b330d068c01663fdd18442b3f	Voyager	41.3341088382672552	-96.1202605302561182
44035	2020-08-11 07:22:21	2020-08-11	Robley Ledner	robley.ledner@warmmail.com	Dallas	Texas	869979126259941267	ea47ea613ef7717e93e72ad5878add19	American Express	32.8562899734165512	-96.8067653485070849
44036	2020-08-11 07:23:06	2020-08-11	Germaine Hudson I	germaine.hudson.i@warmmail.com	Oxnard	California	54608999219380077	47f92dfa0afa53ba70809a9a990e6f64	JCB 16 digit	34.1272992487952109	-119.223324073190241
44037	2020-08-11 07:29:49	2020-08-11	Miss Augusta Kulas	miss.augusta.kulas@geemail.com	San Jose	California	3448846196771588	3c335bf6bd33779b1284df6eb5749c3f	Discover	37.2150477939572184	-121.792080048493673
44038	2020-08-11 07:38:27	2020-08-11	Marchello Olson-Connelly	marchello.olson.connelly@warmmail.com	Memphis	Tennessee	4007242011332476	9d9aefb1758045fbe9543573abb9c882	JCB 16 digit	35.147496687674149	-90.0057642494119676
44039	2020-08-11 07:44:02	2020-08-11	Genoveva Waters	genoveva.waters@geemail.com	Columbus	Ohio	4218315397727	747bcd8d8911cfdd2a01e8077d7db235	JCB 16 digit	40.0323728958189449	-82.9086005681429157
44040	2020-08-11 08:01:43	2020-08-11	Miss Margarette Becker MD	miss.margarette.becker.md@geemail.com	New York	New York	501856601061445	f668245bd89b35930889cce02adc2ad4	Voyager	40.7002445908486834	-73.8970586825057865
44041	2020-08-11 08:04:47	2020-08-11	Miss Lorrie Quitzon DVM	miss.lorrie.quitzon.dvm@warmmail.com	Palmdale	California	4036306268925	aacfb86b4bc183fe83f5b33c4eb07865	Mastercard	34.6346343907844272	-118.012521662423012
44042	2020-08-11 08:06:15	2020-08-11	Clem Goyette	clem.goyette@warmmail.com	Colorado Springs	Colorado	4388455971388275	85f98693e2325598dc5fcef0d5b9e388	JCB 16 digit	38.8116036600016088	-104.745513608834514
44043	2020-08-11 08:06:24	2020-08-11	Loriann Casper	loriann.casper@geemail.com	West Palm Beach	Florida	6011775057605673717	ee0a178e188f81b999c215d0e6e73f51	Discover	26.7284885740220552	-80.2016723735094104
44044	2020-08-11 08:06:36	2020-08-11	Jordyn Konopelski	jordyn.konopelski@woohoo.com	New York	New York	6011703088623223596	412586890841a06b46cf4e4c93f08772	Mastercard	40.6562195199765242	-73.9233471655182512
44045	2020-08-11 08:16:47	2020-08-11	Asia Hirthe	asia.hirthe@geemail.com	San Antonio	Texas	639062108149105	14697e4a01305db29425e9f2023cb455	JCB 16 digit	29.5360375896167007	-98.454936821416382
44046	2020-08-11 08:19:19	2020-08-11	Carl Prosacco	carl.prosacco@geemail.com	Irving	Texas	6011824296746509221	b51f61d73476d561b5ac0c3cc073e809	Diners Club / Carte Blanche	32.7991977753069293	-96.9657888898439637
44047	2020-08-11 08:20:04	2020-08-11	Jeanmarie Waelchi	jeanmarie.waelchi@geemail.com	Vancouver	Washington	4166564056728	282568173842111e49c432881a0a8038	VISA 16 digit	45.5896238226048638	-122.688087523222705
44048	2020-08-11 08:23:29	2020-08-11	Kinsey Stark	kinsey.stark@geemail.com	Garden Grove	California	3774449465512432	e8c4325a6c5fe7f1a2a97bf1b6f710b3	JCB 15 digit	33.7963009361933899	-117.982918801067399
44049	2020-08-11 08:33:36	2020-08-11	Miss Elana Mann MD	miss.elana.mann.md@geemail.com	League City	Texas	869988254680633748	85a50319634f1821d81f8a354c63e11e	JCB 16 digit	29.4786636438149969	-95.0836245597325274
44050	2020-08-11 08:39:42	2020-08-11	Cinnamon Yost	cinnamon.yost@geemail.com	Indianapolis	Indiana	180039226201521107	c3e9270e0f054cf0984ddb076501b702	Maestro	39.7956996590372185	-86.1922679800741349
44051	2020-08-11 08:50:31	2020-08-11	Mr. Merrill Jacobi	mr.merrill.jacobi@geemail.com	Chicago	Illinois	4357681097279323	704ba593b7c8976d84e96d07626925db	Voyager	41.7656192504171315	-87.6349177963130188
44052	2020-08-11 08:51:47	2020-08-11	Melanie Kemmer	melanie.kemmer@geemail.com	Arvada	Colorado	6011294064629080699	0ebcf2484f7667a77e6e24a0e9557b77	VISA 16 digit	39.740928368008511	-105.173791532448675
44053	2020-08-11 08:53:07	2020-08-11	Ernest Hauck	ernest.hauck@woohoo.com	High Point	North Carolina	6011738849246644297	33d755cc974f15df50c17389b5f592a4	JCB 15 digit	35.960119744446132	-80.0559464924707953
44054	2020-08-11 08:54:36	2020-08-11	Erling Stanton	erling.stanton@geemail.com	Midland	Texas	210078698810258101	b7d1a0ca9df77768019b49d9f98f7be2	Voyager	32.1090227678608144	-102.10370857280121
44055	2020-08-11 08:59:46	2020-08-11	Zander Robel	zander.robel@warmmail.com	Memphis	Tennessee	3528286953563959134	2f0c2c640370b0c03b8318ada90ae726	VISA 16 digit	35.0071257681652952	-90.0496459088545294
44056	2020-08-11 09:07:06	2020-08-11	Luka Bogisich	luka.bogisich@geemail.com	Las Vegas	Nevada	4975434674344272	238a75b528e845baf3ad1bdb60b5bdee	JCB 16 digit	36.1446814585112008	-115.263258125560725
44057	2020-08-11 09:07:29	2020-08-11	Jaylon Lockman	jaylon.lockman@geemail.com	New York	New York	4685575886112	93826d5df6e04fa05353665775b5edb3	VISA 16 digit	40.7370908379312624	-73.964432774613428
44058	2020-08-11 09:23:26	2020-08-11	Itzel Marks	itzel.marks@geemail.com	Aurora	Illinois	3088133157298496926	ae9caed750644d1e04086854769fb49a	American Express	41.6773023484498282	-88.2404158704377721
44059	2020-08-11 09:26:10	2020-08-11	Luciano Parker	luciano.parker@geemail.com	San Francisco	California	630447180126956	4cfa4cc1d964b6dcae62b7ffa510ea01	JCB 16 digit	37.8012880593743645	-122.388797883588964
44060	2020-08-11 09:28:14	2020-08-11	Latonia Schimmel	latonia.schimmel@geemail.com	Kansas City	Missouri	3528590062629144136	c478e281d33d81167d8dbdcf6507465c	American Express	39.1922699107624624	-94.4617213848736128
44061	2020-08-11 09:28:29	2020-08-11	Permelia Wolff	permelia.wolff@woohoo.com	Santa Maria	California	180050341682228710	d35e7804ca9ae8ab65e3ab0ea302bf1b	VISA 16 digit	34.8783947560533889	-120.499172228799381
44062	2020-08-11 09:42:20	2020-08-11	Mrs. Kami Dare DVM	mrs.kami.dare.dvm@warmmail.com	Las Cruces	New Mexico	3088472485640155398	cca81f5f3da3dfad288805f302747752	Discover	32.2489443271454448	-106.697078445845094
44063	2020-08-11 09:52:21	2020-08-11	Lyman Hackett II	lyman.hackett.ii@geemail.com	Oakland	California	3528845666910324596	ee4023b1afdc80a6250663d5c99788c3	VISA 16 digit	37.8070066703575449	-122.248787398391983
44064	2020-08-11 09:52:36	2020-08-11	Mr. Kimberly Ritchie IV	mr.kimberly.ritchie.iv@geemail.com	West Palm Beach	Florida	3054363756303838	cf6aff6469cb12ede6b298971c2311ed	Mastercard	26.8007805709574392	-80.0549498218413476
44065	2020-08-11 10:09:07	2020-08-11	Ingrid Boehm	ingrid.boehm@geemail.com	Rochester	Minnesota	3088301201130790009	300828e4b65caa37d1255a7a0911f2a0	Discover	44.0942081353995974	-92.4847990498531516
44066	2020-08-11 10:25:58	2020-08-11	Carmen Ferry	carmen.ferry@geemail.com	Cleveland	Ohio	6011913544324168528	3485515a61f76462e1be4338ddbcc51c	JCB 15 digit	41.4588298921324281	-81.7237539323285205
44067	2020-08-11 10:36:18	2020-08-11	Juelz Pagac	juelz.pagac@geemail.com	Fresno	California	3528208908917892972	862a6fb3048051a8b6fcd8fc486fee2b	VISA 16 digit	36.7728708435188949	-119.826414287753039
44068	2020-08-11 10:38:21	2020-08-11	Xander Bartell	xander.bartell@geemail.com	Los Angeles	California	4691753264064	b4babbe6ab0b7a49f654a82f5b85122f	Voyager	33.9763978932850037	-118.373971887118358
44069	2020-08-11 10:45:25	2020-08-11	Arden Fadel MD	arden.fadel.md@geemail.com	Spokane	Washington	501844723992317	aacfe65eb20c4a94764013dcdaf68662	JCB 15 digit	47.7222753215819608	-117.460527463154122
44070	2020-08-11 10:52:03	2020-08-11	Keesha Brakus PhD	keesha.brakus.phd@geemail.com	Las Cruces	New Mexico	3096274852126514697	7b0dba3a3d9a38f6e436c51c8e1ec6a6	JCB 16 digit	32.2711256870102119	-106.705463613115995
44071	2020-08-11 11:02:00	2020-08-11	Ambers Bergnaum-Simonis	ambers.bergnaum.simonis@warmmail.com	Louisville	Kentucky	869950795388506754	00b2f26b2c24343233d5031e14e61bd2	Maestro	38.1136396948616962	-85.6415635570954521
44072	2020-08-11 11:09:52	2020-08-11	Juelz Little	juelz.little@geemail.com	Chicago	Illinois	4474675509679078	ad9390fb1f0eed9775e4a9bb05976370	Discover	41.844117985370012	-87.5898058837309463
44073	2020-08-11 11:13:52	2020-08-11	Verl Stiedemann	verl.stiedemann@geemail.com	Seattle	Washington	3479404589739259	462c55eb022be229b7113ee64bc7dbac	JCB 15 digit	47.6702896399349001	-122.33909994563237
44074	2020-08-11 11:21:53	2020-08-11	Deidra Ondricka	deidra.ondricka@warmmail.com	Norfolk	Virginia	4868382580025	b9998a5699bd09b377761dead264e551	VISA 13 digit	36.9367325783260156	-76.2706065860115103
44075	2020-08-11 11:27:30	2020-08-11	Veva Baumbach	veva.baumbach@woohoo.com	Tallahassee	Florida	4940206231787017	85780ae21e0a81199ff628d0edf6d59c	Discover	30.482299725434185	-84.1742603419829152
44076	2020-08-11 11:27:43	2020-08-11	Furman Fisher V	furman.fisher.v@geemail.com	Durham	North Carolina	4753370672930308	1d838624c584c025be94f6ebbb478015	JCB 15 digit	36.038899035077911	-78.9743727239217606
44077	2020-08-11 11:33:03	2020-08-11	Quinn Bechtelar	quinn.bechtelar@warmmail.com	San Diego	California	589351265596117	828c33db3d7894c5266d74f57fced905	Voyager	32.8611168920129515	-117.052344782873988
44078	2020-08-11 11:35:48	2020-08-11	Odalys Jones	odalys.jones@geemail.com	Jacksonville	Florida	3788056354747757	fdcbdae49225e7b3f8f5ff00b94a9ed3	JCB 15 digit	30.2497625704441226	-81.6507707791481181
44079	2020-08-11 11:37:14	2020-08-11	Babyboy Smith	babyboy.smith@geemail.com	Reno	Nevada	4482493993679	320c780ceeb34663072a1ea19347995f	American Express	39.6368157379407435	-119.810597901342064
44080	2020-08-11 11:43:09	2020-08-11	Christi Halvorson	christi.halvorson@warmmail.com	Athens	Georgia	3337097297291235410	83dd53f7aaa49960b202dbc08c7effd0	Voyager	34.035493280152231	-83.4532357328221082
44081	2020-08-11 11:44:13	2020-08-11	Mr. Parrish Marvin DDS	mr.parrish.marvin.dds@geemail.com	Phoenix	Arizona	501853918556795	0ae4d37aad7b913df3867ba728ce13b0	JCB 16 digit	33.5038316470969519	-112.119344122514505
44082	2020-08-11 11:44:22	2020-08-11	Mr. Anibal Larkin II	mr.anibal.larkin.ii@geemail.com	San Francisco	California	676204130771712	47f9a6909de3439c168ca9c988a6bf89	VISA 16 digit	37.789355026550929	-122.41388774396313
44083	2020-08-11 11:48:23	2020-08-11	Kurtis Marks-Cremin	kurtis.marks.cremin@geemail.com	Fremont	California	4532689576630542	483e99c4eb79d1de7b5e703e239d2632	Voyager	37.4172328523062205	-121.942025465423981
44084	2020-08-11 11:49:57	2020-08-11	Johnathan Kunze	johnathan.kunze@geemail.com	San Jose	California	561215062994239	096817ad323e3699f4c3fb8848940841	Mastercard	37.2640598301596953	-121.826590652646118
44085	2020-08-11 12:01:54	2020-08-11	Larissa Heller	larissa.heller@woohoo.com	Little Rock	Arkansas	3337215200220010174	71499bceaa5153f4fae42c8a750f5b0d	VISA 16 digit	34.6791419907283043	-92.4472293448507685
44086	2020-08-11 12:16:28	2020-08-11	Braedon Kemmer-Kovacek	braedon.kemmer.kovacek@geemail.com	Miami Gardens	Florida	3499975861358559	33d19c7670804f498ee85e7b68303d6f	VISA 16 digit	25.8740439451239972	-80.1930276864454186
44087	2020-08-11 12:19:50	2020-08-11	Mikayla Terry	mikayla.terry@geemail.com	Berkeley	California	51730518875004663	3660b6e0d21127cdef14210b1d8cca59	JCB 16 digit	37.8661580830144331	-122.280152238705625
44088	2020-08-11 12:25:50	2020-08-11	Addyson Hudson MD	addyson.hudson.md@geemail.com	Oklahoma City	Oklahoma	180079996983216826	7d11c2d1a8f5ae6543d088f4268c306a	VISA 16 digit	35.5325550806153601	-97.4709007725480916
44089	2020-08-11 12:27:47	2020-08-11	Elinore Fay	elinore.fay@geemail.com	San Francisco	California	3088234622313336728	6f8253245bec37a5c5a93d2346b314dc	JCB 16 digit	37.8066450181203138	-122.474616687702451
44090	2020-08-11 12:50:20	2020-08-11	Ulysses Stamm IV	ulysses.stamm.iv@woohoo.com	Antioch	California	675935586193027	0be42f6523e1afd769ddf068a7da1939	Diners Club / Carte Blanche	37.9095245426319565	-121.870512381353223
44091	2020-08-11 12:52:57	2020-08-11	Joslyn Mraz	joslyn.mraz@woohoo.com	New York	New York	55598495432407393	1665911504d8060a1fb39f681bd6a69b	Voyager	40.7218007529843575	-73.9267965528543982
44092	2020-08-11 12:55:08	2020-08-11	Royce Nicolas	royce.nicolas@geemail.com	Los Angeles	California	210035694877111871	c4eb095ecbaee2443655224376f8c50c	VISA 13 digit	33.9654508191026707	-118.468920782626782
44093	2020-08-11 13:02:37	2020-08-11	Parlee Pacocha	parlee.pacocha@geemail.com	Berkeley	California	6011021254174072346	bc80d8d0c99bcab0dfcd400eeb1c04e8	Diners Club / Carte Blanche	37.8734599668325416	-122.273892692051618
44094	2020-08-11 13:15:08	2020-08-11	Valeria Gutkowski	valeria.gutkowski@geemail.com	Corpus Christi	Texas	4382606620515538	a7c090381adc81f938499344d5e9ec71	JCB 16 digit	27.6622209942836328	-97.1431460635099597
44095	2020-08-11 13:16:15	2020-08-11	Kenyatta Kovacek	kenyatta.kovacek@geemail.com	San Francisco	California	630447485982269	2512190fe7a97fb99c0199caa02162bc	JCB 16 digit	37.7656308618303456	-122.437960649459598
44096	2020-08-11 13:28:28	2020-08-11	Gail Volkman	gail.volkman@woohoo.com	Minneapolis	Minnesota	4275771558853	cb3005dbb784b43b1332516b755287e4	JCB 16 digit	44.9909793840341266	-93.2798850702859426
44097	2020-08-11 13:28:51	2020-08-11	Ean Walter	ean.walter@woohoo.com	Woodbridge	New Jersey	180042255171766314	5e829c2b17df82dcb41b0e6460a11617	Mastercard	40.5130487321101072	-74.1962904237069125
44098	2020-08-11 13:30:08	2020-08-11	Tonia Gutmann	tonia.gutmann@warmmail.com	Everett	Washington	3484804273542492	fe3bf8a95cfcbdb4455ff6b83ef73291	JCB 16 digit	47.8855263345301196	-122.101974800567703
44099	2020-08-11 13:34:15	2020-08-11	Giovanny Larson	giovanny.larson@geemail.com	Chicago	Illinois	210098185436729240	93e09178412706c8abc052f9ce2545f1	Diners Club / Carte Blanche	41.792038854614276	-87.6588005698781387
44100	2020-08-11 13:35:20	2020-08-11	Killian Nicolas	killian.nicolas@geemail.com	Jacksonville	Florida	869928916973272078	22d8cec8c077c56bd20e1aac02c32477	VISA 16 digit	30.3199786892678596	-81.7356975486580382
44101	2020-08-11 13:50:13	2020-08-11	Mahlon Considine	mahlon.considine@geemail.com	Newark	New Jersey	6011393995519919514	e9f094e5e6cf29151ed5482cc804dcb5	JCB 16 digit	40.7807479141660068	-74.2714801758736343
44102	2020-08-11 14:00:55	2020-08-11	Dr. Diamond Fisher PhD	dr.diamond.fisher.phd@woohoo.com	Killeen	Texas	3096467087124511588	64488d3324a7024328788099a4eaade8	Voyager	31.0633709028128528	-97.739473147194829
44103	2020-08-11 14:03:48	2020-08-11	Delphia Hessel	delphia.hessel@geemail.com	Garden Grove	California	3088469116764000731	35a9e789a3c7ab43fcfdb7716064b50f	VISA 16 digit	33.8765893427014291	-117.99918219000287
44104	2020-08-11 14:09:23	2020-08-11	Imogene Roberts	imogene.roberts@warmmail.com	San Francisco	California	869904898346560355	c526fffb86b61d9aa50ac2c950ea7e3f	VISA 13 digit	37.7971067278806672	-122.420926147486341
44105	2020-08-11 14:20:21	2020-08-11	Millard Bernier PhD	millard.bernier.phd@warmmail.com	Cleveland	Ohio	54843148776046227	e5cbafbba25ecdce80061ed22cd172d0	Diners Club / Carte Blanche	41.4552824860755322	-81.7757460344355565
44106	2020-08-11 14:20:35	2020-08-11	Mrs. Latonia Considine DDS	mrs.latonia.considine.dds@warmmail.com	Tucson	Arizona	3112665837141832700	b9b4f92dcbcebe13b6fae6b1f26f4ded	American Express	32.1950762121513492	-110.869306523282447
44107	2020-08-11 14:49:54	2020-08-11	Carol Hartmann	carol.hartmann@geemail.com	Denver	Colorado	3528939602000455781	31480b5e6a039864e00ef20f14b749c0	VISA 16 digit	39.6828271128755006	-104.923701892631499
44108	2020-08-11 14:52:12	2020-08-11	Miss Gabriella Deckow PhD	miss.gabriella.deckow.phd@geemail.com	Palmdale	California	869943167397878345	de253abb3175cb545deaa7cb5cca1be4	VISA 13 digit	34.6285228262972069	-118.1043740096964
44109	2020-08-11 15:00:26	2020-08-11	Sebrina Stamm	sebrina.stamm@woohoo.com	Los Angeles	California	3337854929948892481	d9ba8e918df8b09638784877adae24c7	American Express	34.0039841655041997	-118.484881023177124
44110	2020-08-11 15:02:21	2020-08-11	Mr. Dewey Luettgen I	mr.dewey.luettgen.i@geemail.com	Modesto	California	53488409267653644	679cd19d67af66f8a12820a9dd44166f	Maestro	37.6005155250895768	-121.058341313360259
44111	2020-08-11 15:07:31	2020-08-11	Greyson Witting	greyson.witting@geemail.com	Indianapolis	Indiana	3528526764159957220	3b0b490f79a52969cfd97415e1bb9b6c	Diners Club / Carte Blanche	39.7614522634547214	-86.0879354978181368
44112	2020-08-11 15:16:56	2020-08-11	Dr. Rick Berge	dr.rick.berge@geemail.com	Oakland	California	3760750975464352	71886004e5c0d5cf6d36b517a0cb004a	Voyager	37.8210309658823647	-122.246430028154592
44113	2020-08-11 15:26:14	2020-08-11	Davante Lowe MD	davante.lowe.md@geemail.com	San Francisco	California	52843109633135991	88b6e4cc47e04cc6d966a26a195996a7	American Express	37.7690995331841393	-122.422126393763435
44114	2020-08-11 15:26:55	2020-08-11	Mr. Terrence Quigley I	mr.terrence.quigley.i@geemail.com	Oakland	California	4433671710300711	75a415193d18af7965ab437964463190	Voyager	37.8291776834501903	-122.253667782355663
44115	2020-08-11 15:27:10	2020-08-11	Mr. Nevin Bartoletti	mr.nevin.bartoletti@geemail.com	North Las Vegas	Nevada	3088133675423477099	6621c57d55a03e53ea492197617ce387	JCB 16 digit	36.2228000957675249	-115.078280128281193
44116	2020-08-11 15:40:48	2020-08-11	Shanell Kunde	shanell.kunde@geemail.com	Frisco	Texas	4893931447085172	c22961e2f04d213d7a723ba81bfe4215	Maestro	33.1783619092773634	-96.7783540392968717
44117	2020-08-11 15:42:13	2020-08-11	Marjory Lubowitz PhD	marjory.lubowitz.phd@geemail.com	San Francisco	California	3756277564436399	d01d15cc7fc05e08f3505494b446c6f1	VISA 16 digit	37.773150342985339	-122.436636884554403
44118	2020-08-11 15:46:45	2020-08-11	Candido Moore	candido.moore@geemail.com	Hialeah	Florida	4577580076602717	41a243baae55e86dc27036b1dbfc3b29	JCB 16 digit	25.8442133781477814	-80.3917326101470735
44119	2020-08-11 15:47:18	2020-08-11	Keila Dietrich-Franecki	keila.dietrich.franecki@geemail.com	Denver	Colorado	4254076350571	5965df728c747a72e82fedf4e358c815	Discover	39.7404874876193688	-104.970874045860398
44120	2020-08-11 15:55:17	2020-08-11	Emmons Sanford	emmons.sanford@geemail.com	Boston	Massachusetts	3054078301050482	626e34945b38f7e21d88451c8212cd46	American Express	42.3074663282539731	-71.000506749884039
44121	2020-08-11 15:58:25	2020-08-11	Verlie Bednar	verlie.bednar@warmmail.com	Saint Paul	Minnesota	869947293220408450	2b2f7182ac8afd0e8562703a5396585a	Diners Club / Carte Blanche	44.8870488753017085	-93.0708855387553626
44122	2020-08-11 15:58:48	2020-08-11	Shepherd Schmitt	shepherd.schmitt@geemail.com	Tempe	Arizona	3766036230114501	d90bed576bcbea87e0d0a4ac8a29c4f5	VISA 13 digit	33.340313785468787	-111.870595096240933
44123	2020-08-11 15:59:01	2020-08-11	Derwin Durgan	derwin.durgan@woohoo.com	Milwaukee	Wisconsin	639009146138830	c922853ee72d1de694c5282dd86d70f8	Diners Club / Carte Blanche	43.1626247980251918	-87.9784285553365919
44124	2020-08-11 16:05:07	2020-08-11	Dr. Lonny Powlowski	dr.lonny.powlowski@warmmail.com	New York	New York	3017885010282017	c5ebe777ad6a8dae78af2109b3b774cf	American Express	40.6799773847907744	-73.9017373095627903
44125	2020-08-11 16:06:38	2020-08-11	Michale Sipes PhD	michale.sipes.phd@warmmail.com	Chicago	Illinois	3088321055949527291	60586dee04fe32acfa460c6ed1b73427	Diners Club / Carte Blanche	41.8288041556555825	-87.6306163150846942
44126	2020-08-11 16:20:31	2020-08-11	Lisha Fritsch	lisha.fritsch@geemail.com	San Francisco	California	3528093393893155629	475580c325240d0700a4b9e264209728	Diners Club / Carte Blanche	37.7803137277267069	-122.437677048319372
44127	2020-08-11 16:30:03	2020-08-11	Garth Dare	garth.dare@warmmail.com	San Francisco	California	3770163806858396	0c97af9a94740060ac3427fb3d9959f7	JCB 16 digit	37.7943782790868426	-122.421133421982717
44128	2020-08-11 16:39:43	2020-08-11	Alverta Murphy	alverta.murphy@geemail.com	Sterling Heights	Michigan	869927066708347109	edb503638f6886478cd4fbcdd375445d	Mastercard	42.582186052025115	-83.1187851875714898
44129	2020-08-11 16:44:47	2020-08-11	Dr. Uriel Dietrich IV	dr.uriel.dietrich.iv@geemail.com	Philadelphia	Pennsylvania	3739011942493737	532b9cc101eede6e5b6e6383e867e8e7	JCB 15 digit	39.9306053199764364	-75.2238872871167956
44130	2020-08-11 16:48:00	2020-08-11	Jazlynn Bergstrom	jazlynn.bergstrom@geemail.com	Washington	District of Columbia	3012950952149833	1e90cfd680d1a738245928d30b9af59c	JCB 16 digit	38.9308352715600279	-76.9865190180696572
44131	2020-08-11 16:49:24	2020-08-11	Miss Sanai Hickle DVM	miss.sanai.hickle.dvm@geemail.com	Los Angeles	California	3112473050969211435	26efd8bd125114844e34b61376440818	JCB 15 digit	34.0714202628336835	-118.343301188991589
44132	2020-08-11 17:05:15	2020-08-11	Toriano Schaefer-Oberbrunner	toriano.schaefer.oberbrunner@geemail.com	New York	New York	210075231898132593	1924e05ea6fe3703864026ddae370994	VISA 13 digit	40.6924216760080313	-73.8875627491053137
44133	2020-08-11 17:06:11	2020-08-11	Brandi Kuhic	brandi.kuhic@geemail.com	New York	New York	4450117941036	ca2e6310568fe08b4c1231994d8cee87	Discover	40.740108096668493	-73.9662061813648819
44134	2020-08-11 17:08:16	2020-08-11	Alexis Hegmann	alexis.hegmann@geemail.com	Richardson	Texas	53178504523841325	996e131b4982dbcfa96c377700ff0524	VISA 13 digit	32.9430287941593676	-96.7059897958062606
44135	2020-08-11 17:12:17	2020-08-11	Isadore Jast	isadore.jast@geemail.com	San Antonio	Texas	6011477064096751581	426362d958dbc699f5370b30aca51b99	VISA 13 digit	29.5452839105460789	-98.5798920457087462
44136	2020-08-11 17:20:46	2020-08-11	Benita Zieme	benita.zieme@geemail.com	Henderson	Nevada	54517246410839786	caa0181b4736585e227708384d056468	JCB 16 digit	36.0402475661065438	-114.955715921443712
44137	2020-08-11 17:25:46	2020-08-11	Odus Funk I	odus.funk.i@geemail.com	Phoenix	Arizona	3158896160582824693	aac12942231cbad2cb25c3f0d79e9c38	VISA 16 digit	33.6202635077692591	-112.152198359735692
44138	2020-08-11 17:31:16	2020-08-11	Fleet Lockman	fleet.lockman@geemail.com	St. Petersburg	Florida	6011692682704560240	f304f2edadf16ca946b85f7b4406c854	American Express	27.8224064653161918	-82.6629285291660523
44139	2020-08-11 17:54:06	2020-08-11	Dr. Marchello Carter	dr.marchello.carter@geemail.com	Lansing	Michigan	4678141599640	aa63cec83c3571da152e1a188f7e6459	Diners Club / Carte Blanche	42.7469020805630819	-84.5600087665144287
44140	2020-08-11 17:56:34	2020-08-11	Madelene Cronin DDS	madelene.cronin.dds@warmmail.com	Chesapeake	Virginia	4000957232862335	fa6ee679d4d8235b553053904ab33ddc	Discover	36.6022172617498782	-76.2991848783411086
44141	2020-08-11 18:05:21	2020-08-11	Noretta Wehner	noretta.wehner@geemail.com	Berkeley	California	3112938954082499141	3c385ebe1b565ff4e7567ad2772d7dad	Discover	37.8660513897522648	-122.257765692500698
44142	2020-08-11 18:10:37	2020-08-11	Jayvion Streich	jayvion.streich@woohoo.com	New York	New York	54459937722653804	5052e84ec06ce0375656bd80ed23b118	JCB 15 digit	40.6724879458304471	-73.915879201273242
44143	2020-08-11 18:12:23	2020-08-11	Lillard Turner	lillard.turner@warmmail.com	Aurora	Illinois	6011562103059182693	283508b91df8384ddc9dd7c7ca98fc3b	Mastercard	41.8201305234096949	-88.3041663442201923
44144	2020-08-11 18:16:48	2020-08-11	Hugo Hettinger	hugo.hettinger@woohoo.com	San Francisco	California	53852392449181429	74080a4c565da458bdb84173cee1d80b	Diners Club / Carte Blanche	37.7908513213493578	-122.431142272569971
44145	2020-08-11 18:16:50	2020-08-11	Cappie Dooley	cappie.dooley@geemail.com	Las Vegas	Nevada	4367785084604118	e4ec7da28e8e66e529daf93ae734e92a	JCB 16 digit	36.2898370616238566	-115.171364209309587
44146	2020-08-11 18:19:28	2020-08-11	Migdalia Olson	migdalia.olson@woohoo.com	Fort Collins	Colorado	869942175022287429	475d44bb98bde2b49b6526ab9ff8cb82	VISA 16 digit	40.5397062475483878	-104.965694972076648
44147	2020-08-11 18:26:57	2020-08-11	Montrell Brakus	montrell.brakus@woohoo.com	Mesa	Arizona	4304697697805295	ff1906fe097f01bd7dc756e34538ec44	Discover	33.4634071398206032	-111.779234587994964
44148	2020-08-11 18:31:20	2020-08-11	Ingram Collins	ingram.collins@geemail.com	Corona	California	3337473294324755740	c9f4a145fd113191d8efcf60617dd5d8	Mastercard	33.9008164551462983	-117.477251555325466
44149	2020-08-11 18:36:25	2020-08-11	Lala Hintz MD	lala.hintz.md@geemail.com	Houston	Texas	3047347897621924	aa506280cbe91c7416298f54ae339cab	VISA 16 digit	29.7610272577576325	-95.3327355378322352
44150	2020-08-11 18:44:49	2020-08-11	Anaya Thompson	anaya.thompson@warmmail.com	Orange	California	4862449629538592	9a0bc5631068d11485abe9aa76c447dd	JCB 15 digit	33.8605382976941769	-117.836988993325463
44151	2020-08-11 18:51:47	2020-08-11	Adelard Fisher	adelard.fisher@woohoo.com	Houston	Texas	4775592846803517	c7b121b801182e5b767d1810f1db9c65	Maestro	29.827474954778701	-95.3190992759555655
44152	2020-08-11 19:06:29	2020-08-11	Dr. Mauro Stokes PhD	dr.mauro.stokes.phd@warmmail.com	New York	New York	3434695562554276	8b2b2c3692f695c86e2faf5d3a172155	VISA 16 digit	40.6484720407743012	-73.9479331172898355
44153	2020-08-11 19:14:51	2020-08-11	Ridge Schiller	ridge.schiller@geemail.com	Santa Ana	California	4754652822831646	b432f6026b7ae52eb5e04e755cd3653f	VISA 13 digit	33.8321833049051435	-117.811017976135005
44154	2020-08-11 19:34:38	2020-08-11	Evette Gleichner-Macejkovic	evette.gleichner.macejkovic@geemail.com	Sacramento	California	6011637990510728036	6dfcec1e7b321a167884413711b214ff	VISA 16 digit	38.5765704519379895	-121.556811117126045
44155	2020-08-11 19:44:17	2020-08-11	Miss Zilpha Ziemann DVM	miss.zilpha.ziemann.dvm@geemail.com	Seattle	Washington	3402885524475540	b466baf247b3e1956944e93962dcae48	Mastercard	47.6667167821358859	-122.393051451529928
44156	2020-08-11 20:07:51	2020-08-11	Adelard Conroy	adelard.conroy@woohoo.com	Chicago	Illinois	4225753607027284	72d636832983e9dfd85bb19a657de22b	VISA 16 digit	41.8458707210443919	-87.6016161021806283
44157	2020-08-11 20:08:25	2020-08-11	Haley Morar	haley.morar@geemail.com	Philadelphia	Pennsylvania	869905956984787653	4aa4c515fd02d0907cc8a0ab838c9147	Voyager	40.0315533390693332	-75.0935728255558814
44158	2020-08-11 20:15:04	2020-08-11	Naima Ondricka	naima.ondricka@geemail.com	San Francisco	California	51034859111553318	b82b3c2d91c1fe42e9e1b3bc541e01d1	JCB 16 digit	37.7696295631114012	-122.446619822644948
44159	2020-08-11 20:17:56	2020-08-11	Celina Upton	celina.upton@warmmail.com	Bridgeport	Connecticut	6011425591762194533	f63ff160651143ebae91fc78b323f640	American Express	41.2157866407349687	-73.1918778053384358
44160	2020-08-11 20:25:20	2020-08-11	Brylee Stanton	brylee.stanton@geemail.com	Killeen	Texas	869926337406025151	844e6b9fefddc13f798a69a0efd287d2	Mastercard	31.1347082130376265	-97.7222645458467269
44161	2020-08-11 20:30:01	2020-08-11	Nadine Romaguera	nadine.romaguera@warmmail.com	Pittsburgh	Pennsylvania	55656554585787370	d6190c4a1baf97a88688e1aab6cb76e5	JCB 16 digit	40.3770974867932466	-79.9556317114442692
44162	2020-08-11 20:30:06	2020-08-11	Tonja Goldner	tonja.goldner@geemail.com	Miami	Florida	869908302521503179	fd4ee1c93edea2cf1613eae25fd8151a	JCB 15 digit	25.8615109938800352	-80.2088584350295406
44163	2020-08-11 20:30:40	2020-08-11	Miss Tamela Pacocha	miss.tamela.pacocha@geemail.com	San Diego	California	3158589227175804655	502c9a99a0bbb7adbbe647565abe51b6	JCB 15 digit	32.7891206839188953	-117.132607364645239
44164	2020-08-11 20:35:12	2020-08-11	Unique Ernser	unique.ernser@geemail.com	Fort Worth	Texas	3337765253502336852	e575338d87fa1b66c31dbca3f98a8a40	VISA 13 digit	32.8616273279823403	-97.3456334507845327
44165	2020-08-11 20:43:19	2020-08-11	Corean Hills-Cummerata	corean.hills.cummerata@woohoo.com	Austin	Texas	3337286690806232974	38387c23c1a0131dbafb906dbeb6772c	Diners Club / Carte Blanche	30.3814488606188426	-97.8018247382953803
44166	2020-08-11 20:50:44	2020-08-11	Arlington Nienow	arlington.nienow@geemail.com	Columbus	Ohio	3158371796650648771	c53e7de0451f72518833d7933d25251d	JCB 16 digit	39.9037088963247797	-82.97933098950908
44167	2020-08-11 21:08:27	2020-08-11	Phoenix Waters	phoenix.waters@geemail.com	San Francisco	California	3759480170036549	e2d9aeed7011d0bc51bf6a0a5c91c9ac	Discover	37.7904160311093733	-122.41872657965888
44168	2020-08-11 21:14:08	2020-08-11	Dolphus Lang	dolphus.lang@geemail.com	Oakland	California	4627526332788	0ef7fa87075ab6dec785ffdc55fb74c4	Maestro	37.7552400515614792	-122.248889311952681
44169	2020-08-11 21:18:31	2020-08-11	Roberta Rowe	roberta.rowe@geemail.com	Oklahoma City	Oklahoma	3158260782121082497	9e64d13ad6b2e30b882c76c8d508b65c	Voyager	35.502960849590977	-97.457856470755118
44170	2020-08-11 21:26:57	2020-08-11	Nolan Heathcote	nolan.heathcote@geemail.com	San Mateo	California	53880780927198715	6a82488145a8e88b29c528f5b147075e	VISA 13 digit	37.5031587810602005	-122.244503426956385
44171	2020-08-11 21:28:18	2020-08-11	Cinthia Paucek-Dibbert	cinthia.paucek.dibbert@geemail.com	Durham	North Carolina	3158363212186566032	b8a48c871b5b6b1cda7f31f7cea1010e	American Express	36.0288662060409735	-78.8672386746291068
44172	2020-08-11 21:30:50	2020-08-11	Kendell Turcotte IV	kendell.turcotte.iv@geemail.com	West Jordan	Utah	869992887066373977	65928e390e9f1f7ef145ce3424e14d20	Mastercard	40.6749066498387606	-112.003444995879377
44173	2020-08-11 21:35:24	2020-08-11	Dr. Unknown Koch	dr.unknown.koch@warmmail.com	San Diego	California	55302674545718535	df1e4864d464cf151ec522e447bd8c5b	Discover	32.7339044936068362	-117.094047215757897
44174	2020-08-11 21:43:19	2020-08-11	Davina Powlowski-Huels	davina.powlowski.huels@woohoo.com	Albuquerque	New Mexico	4658389141024	c3cd329fc68f6904372e635d4d89393a	Maestro	35.1428552785556789	-106.596091209219395
44175	2020-08-11 21:58:41	2020-08-11	Mervyn DuBuque	mervyn.dubuque@woohoo.com	El Cajon	California	3528804698883944109	6f01cdb17fc435fce8238a4950c821a9	Maestro	32.7514336073312862	-117.044878814620532
44176	2020-08-11 22:23:57	2020-08-11	Mr. Gustavo O'Connell	mr.gustavo.o'connell@geemail.com	Frisco	Texas	676308545378765	649e1349dc8d286a66ec9ee69de5d87d	JCB 15 digit	33.2407750973474236	-96.8472545245870862
44177	2020-08-11 22:24:06	2020-08-11	Edgar Durgan-Lemke	edgar.durgan.lemke@geemail.com	San Francisco	California	180005793668240265	2c59e9de43b03d5b03a0e5bb9ad30fc2	JCB 15 digit	37.7606564258300565	-122.417075482321835
44178	2020-08-11 22:31:53	2020-08-11	Mr. Ricci Reichel II	mr.ricci.reichel.ii@geemail.com	San Francisco	California	4289100452260599	d637fcffb188d166eb0db959598f7c97	Diners Club / Carte Blanche	37.7714620675873718	-122.446914446912302
44179	2020-08-11 22:33:23	2020-08-11	Tracie Friesen	tracie.friesen@warmmail.com	Wichita Falls	Texas	3032770899423251	2054d91e4fa783cf1996a7393cbfc966	VISA 16 digit	33.8567324420630911	-98.5346809680495284
44180	2020-08-11 22:42:52	2020-08-11	Lucian Friesen	lucian.friesen@geemail.com	Jackson	Mississippi	3018018317070583	983cbd128897d408685e59629ac7dd02	Mastercard	32.3664284167058796	-90.1616333811052186
44181	2020-08-11 22:45:28	2020-08-11	Abelardo Fadel-Beahan	abelardo.fadel.beahan@woohoo.com	New York	New York	869926734002010951	e4ed756c5d151c652d03e5aed375ae51	Discover	40.5861721698418236	-73.9519310931105167
44182	2020-08-11 22:53:23	2020-08-11	Stacie Kertzmann	stacie.kertzmann@geemail.com	Indianapolis	Indiana	4293158551117304	f107fcadee1602c038f9574b17899814	Maestro	39.8160938572145966	-86.1646247767113067
44183	2020-08-11 22:57:56	2020-08-11	Mr. Konnor Herzog	mr.konnor.herzog@geemail.com	Tulsa	Oklahoma	4667099143548275	c913092d6c56ace3e220c5b8588bed1f	Maestro	36.1647119882885306	-95.9599920127030401
44184	2020-08-11 23:01:44	2020-08-11	Eloisa Zulauf-Nikolaus	eloisa.zulauf.nikolaus@geemail.com	Torrance	California	180087759710684991	30d96560a8e2184134b155352a6bf869	Maestro	33.7457962563633913	-118.387963934721043
44185	2020-08-11 23:03:55	2020-08-11	Dr. Kasie Strosin PhD	dr.kasie.strosin.phd@warmmail.com	San Francisco	California	3418622992390782	a745f391aa3d9f5747d6d3c008b393ed	JCB 16 digit	37.7595664933929243	-122.432297257934565
44186	2020-08-11 23:04:10	2020-08-11	Carolynn Fay	carolynn.fay@geemail.com	Pomona	California	52964930086253152	fbd569e4e5cd428caad98d738787a0da	JCB 16 digit	34.0718410957641922	-117.779977574335788
44187	2020-08-11 23:05:25	2020-08-11	Dr. Loreen Block	dr.loreen.block@woohoo.com	Chicago	Illinois	501822752577548	2770cfc635a4773835f77acfc8be06e1	Mastercard	41.8306272965691974	-87.7672575383476925
44188	2020-08-11 23:19:42	2020-08-11	Laila Berge	laila.berge@geemail.com	Clovis	California	3022231724343115	92e2b66b41ef07f34ef48f961632a613	VISA 16 digit	36.84804142381698	-119.636766692630573
44189	2020-08-11 23:26:11	2020-08-11	Manley Becker	manley.becker@geemail.com	Los Angeles	California	6011360525128060779	6f97fe308022771a72783a8c96193940	Maestro	33.9604701506771107	-118.329387968731297
44190	2020-08-11 23:27:22	2020-08-11	Auston Walker-Beier	auston.walker.beier@warmmail.com	Oakland	California	4075615443647	7c3091040848dfd90c175d82bc527ca7	Voyager	37.8038167473443352	-122.257486140968524
44191	2020-08-11 23:29:00	2020-08-11	Mario Labadie	mario.labadie@geemail.com	Phoenix	Arizona	3096876260552331515	26f0809b4a4701327a8cd0dec83b7972	Mastercard	33.5677419444479099	-112.088524328118567
44192	2020-08-11 23:53:12	2020-08-11	Emiliano Corkery	emiliano.corkery@woohoo.com	Seattle	Washington	4661047524525566	fd4966d4a51f6e164b4adbdc0b5d36a8	VISA 16 digit	47.6136059579364925	-122.427797329231723
44193	2020-08-12 00:09:23	2020-08-12	Margurite Rice	margurite.rice@geemail.com	Portland	Oregon	4030374557999532	536405980babd251ca4182307bef019a	Mastercard	45.4569091611430025	-122.643294444354254
44194	2020-08-12 00:11:31	2020-08-12	Curtiss Kertzmann-Shields	curtiss.kertzmann.shields@geemail.com	New York	New York	4362666893456236	91242bb0f4ef9ad7a649ee05e495a73e	JCB 16 digit	40.7550028406307092	-73.9113432228926541
44195	2020-08-12 00:11:34	2020-08-12	Bill Jacobson	bill.jacobson@geemail.com	Little Rock	Arkansas	4539254058990	7617d79f4102d9e912ad46c761f1dd53	Voyager	34.6365736696213489	-92.263325792212413
44196	2020-08-12 00:27:38	2020-08-12	Mr. Huy Moore DVM	mr.huy.moore.dvm@woohoo.com	San Francisco	California	589382826562538	99b52465d6c0f55e222fb3f9c437f344	VISA 16 digit	37.7491755180500874	-122.428256739847271
44197	2020-08-12 00:40:14	2020-08-12	Boris Hegmann	boris.hegmann@geemail.com	Los Angeles	California	869904709449381229	4611dffc44da37f517eb261c0bd8c580	VISA 16 digit	33.9670309641264367	-118.427083789882431
44198	2020-08-12 00:43:05	2020-08-12	Teri Kilback	teri.kilback@geemail.com	Gainesville	Florida	3032185565337117	d8b7a767feeeb221996257de93575aa4	VISA 16 digit	29.743124702788144	-82.3289203618526528
44199	2020-08-12 00:48:44	2020-08-12	May Berge	may.berge@warmmail.com	New York	New York	210046731726983329	0d9c750fada8c7c6a9ec1f405a398900	Maestro	40.6526811978071905	-73.9453412668675156
44200	2020-08-12 00:53:41	2020-08-12	Dr. Deric Carroll	dr.deric.carroll@woohoo.com	San Antonio	Texas	4494294965962790	9c66cf669c15061ceda8dbdade0fb2e7	JCB 16 digit	29.3967966689798992	-98.5074350613936787
44201	2020-08-12 00:55:17	2020-08-12	Dr. Joy Heller	dr.joy.heller@geemail.com	Berkeley	California	3528053610253974903	fd8b2cd9ca2de47a0cee63d550291059	VISA 13 digit	37.8812897111799955	-122.262812419418935
44202	2020-08-12 00:56:08	2020-08-12	Delwin Conn	delwin.conn@warmmail.com	San Francisco	California	6011304666931232228	13c02d84cd118fee576023440a17379c	VISA 13 digit	37.7633711153134399	-122.432695053300691
44203	2020-08-12 00:58:32	2020-08-12	Lavon Walter	lavon.walter@geemail.com	Fort Wayne	Indiana	3025524962318063	b1a3780bcc2bbcf29da08f9fc0a68b10	JCB 16 digit	41.0920579740095917	-85.1899966445505612
44204	2020-08-12 00:59:29	2020-08-12	Blane Gutkowski	blane.gutkowski@geemail.com	Dallas	Texas	4624013680709952	f92235a77006ef720a00c25ce5a2aa57	JCB 15 digit	32.824533164994051	-96.8039590035527908
44205	2020-08-12 01:08:59	2020-08-12	Danelle Corwin	danelle.corwin@geemail.com	Yonkers	New York	3033190405409604	207df3bab17d43732e8b7f413d14333a	Voyager	40.8759885613076435	-73.9330491687987035
44206	2020-08-12 01:20:29	2020-08-12	Carter Lockman-Cormier	carter.lockman.cormier@warmmail.com	Austin	Texas	4493988679733360	bf4f98866ae076639e895ab34c69f0fc	JCB 15 digit	30.378358370031787	-97.7874264925956709
44207	2020-08-12 01:28:02	2020-08-12	Estelle Crist DDS	estelle.crist.dds@geemail.com	San Francisco	California	6011555217101435195	bb2a5078997cc9db17f78e125abb354a	JCB 16 digit	37.780103926296114	-122.434002942315757
44208	2020-08-12 01:31:30	2020-08-12	Jace Marvin	jace.marvin@geemail.com	Chicago	Illinois	3528850609365809846	e177ece37bdc90d4e062f1e846c34c84	American Express	41.9066999430604312	-87.7474563225202218
44209	2020-08-12 01:35:18	2020-08-12	Oland McLaughlin-Runolfsdottir	oland.mclaughlin.runolfsdottir@woohoo.com	Atlanta	Georgia	6011488832265318490	add4299c4f5253de22a251f2db39bcf2	Voyager	33.8609871208477813	-84.4031006266873334
44210	2020-08-12 01:36:44	2020-08-12	Mr. Waverly Herzog DVM	mr.waverly.herzog.dvm@geemail.com	Oakland	California	675989438614359	3c2cfde7ab86a09799103ff411799262	Mastercard	37.788199126884578	-122.260851389285307
44211	2020-08-12 01:39:20	2020-08-12	Severt Green	severt.green@geemail.com	McAllen	Texas	869931787980870195	934af324577ce580e69142f2513bd895	JCB 15 digit	26.2833081701144557	-98.2410592925116362
44212	2020-08-12 01:40:11	2020-08-12	Oren Stiedemann-Bins	oren.stiedemann.bins@geemail.com	Seattle	Washington	4525945027309261	e5ad2ac1add4a74edc56831beb4a8b2a	JCB 16 digit	47.7089779910091281	-122.257667322355871
44213	2020-08-12 01:47:23	2020-08-12	Amir Abbott	amir.abbott@warmmail.com	Aurora	Colorado	180064494134257490	302d1f52f0f4791e1437d333f0aec137	Mastercard	39.7664034764394216	-104.753382642672207
44214	2020-08-12 02:00:35	2020-08-12	Kadijah Price	kadijah.price@geemail.com	San Francisco	California	3023669334716536	92913ae569a9d1029ac973a072406bcc	VISA 16 digit	37.7631923109755689	-122.429996194276754
44215	2020-08-12 02:02:29	2020-08-12	Haiden Kirlin	haiden.kirlin@geemail.com	New York	New York	210010951258208562	be77e6ac7a896e65b116c9a5be934d3c	Voyager	40.6009340446665874	-73.9866169229511144
44216	2020-08-12 02:12:20	2020-08-12	Maddux Bode-Gorczany	maddux.bode.gorczany@warmmail.com	Baltimore	Maryland	4068833911337205	b3e7ebf822f18663938acb067df5a429	Voyager	39.3198786121793091	-76.7049412325974629
44217	2020-08-12 02:19:04	2020-08-12	Dr. Hailie Lakin	dr.hailie.lakin@geemail.com	New York	New York	3528484389412227003	beda42d4f0d2358b43339cfc765a70ce	JCB 15 digit	40.7219622994996584	-73.8693426858063731
44218	2020-08-12 02:26:03	2020-08-12	Miss Gwyneth Okuneva	miss.gwyneth.okuneva@geemail.com	Houston	Texas	4072850364129529	a976a76c8c4746f9faf1c35f768f2b78	VISA 13 digit	29.7426491426847868	-95.4319511531401474
44219	2020-08-12 02:31:08	2020-08-12	Mr. Gregg Schuppe	mr.gregg.schuppe@geemail.com	Baton Rouge	Louisiana	676214929389451	ad7f2177a46d156d1d2df534d41b29f2	JCB 16 digit	30.3997739223975678	-91.1396827460840342
44220	2020-08-12 02:38:46	2020-08-12	Joelle Dibbert	joelle.dibbert@geemail.com	San Francisco	California	3046062399739386	f3893bb72d32b7d39cb066fde7ba0610	JCB 15 digit	37.773549788005127	-122.460225476148366
44221	2020-08-12 02:40:10	2020-08-12	Dr. Buford O'Keefe	dr.buford.o'keefe@woohoo.com	Cedar Rapids	Iowa	3528854733705429135	f549d45e301ed279be294b2b37a82a92	Voyager	41.9494093346484007	-91.7191561060559053
44222	2020-08-12 02:50:54	2020-08-12	Dr. Ottis Abbott	dr.ottis.abbott@geemail.com	Portland	Oregon	6011438853359549601	20eea973eb80d84ced21ddb5e40d0702	Voyager	45.5281988901440045	-122.65287286820822
44223	2020-08-12 02:53:04	2020-08-12	Jimmie Bergstrom	jimmie.bergstrom@geemail.com	San Francisco	California	561202060237324	bc4086b9773350c9f6325c83030c6f68	JCB 16 digit	37.7683272753934105	-122.412195698013306
44224	2020-08-12 02:54:00	2020-08-12	Auston Bartoletti-Homenick	auston.bartoletti.homenick@geemail.com	Las Vegas	Nevada	3042945512168778	1d15f6d889ca1138f433c8f91115f41c	JCB 16 digit	36.1684373849637808	-115.186604398835811
44225	2020-08-12 02:59:49	2020-08-12	Madilynn Parker	madilynn.parker@geemail.com	Winston–Salem	North Carolina	180052527634176357	91cefe79149d2591297e128dce393437	Voyager	36.0136745645895573	-80.3536618378609404
44226	2020-08-12 03:00:59	2020-08-12	Delmus Deckow-Feil	delmus.deckow.feil@geemail.com	Jacksonville	Florida	4431115252598177	079ebae68c8b7f50e2937eac6b0e4561	VISA 13 digit	30.4034547503624104	-81.6161821070205491
44227	2020-08-12 03:09:50	2020-08-12	Marybelle Jones	marybelle.jones@geemail.com	San Jose	California	6011942209070296460	c272e12ec6e22a2ecebe1ac8be077664	Discover	37.310833414765824	-121.909821671735116
44228	2020-08-12 03:14:01	2020-08-12	Keisha Rosenbaum	keisha.rosenbaum@geemail.com	San Francisco	California	4689780573505109	63740d256b152cf5f7922a9bfbb740f7	VISA 13 digit	37.7589576872242958	-122.425045693864703
44229	2020-08-12 03:16:46	2020-08-12	Ean Shanahan	ean.shanahan@geemail.com	Phoenix	Arizona	210059746294978851	d07cd616210aaac5db5a0c4a9e5d314d	VISA 16 digit	33.5069315825521983	-112.15519968037718
44230	2020-08-12 03:21:42	2020-08-12	Ah Stanton	ah.stanton@woohoo.com	St. Petersburg	Florida	4992003525295287	c7de0dca87f0f8257be85fe1bf5f83ec	Maestro	27.705684279033914	-82.5801338161233787
44231	2020-08-12 03:37:10	2020-08-12	Cierra Pfeffer-Halvorson	cierra.pfeffer.halvorson@geemail.com	Santa Rosa	California	6011843497589245488	c1a87b57186a4b85fc03cc1ded450442	Diners Club / Carte Blanche	38.3907655657392013	-122.723764999002597
44232	2020-08-12 03:40:23	2020-08-12	Mrs. Yoshiko Bernhard	mrs.yoshiko.bernhard@geemail.com	Baton Rouge	Louisiana	3731487877626012	bfae456457d93e435099c3c8f8760031	VISA 16 digit	30.538983932670952	-91.2021831661570843
44233	2020-08-12 03:40:27	2020-08-12	Leontine Dickens	leontine.dickens@geemail.com	Glendale	California	3337232388514629632	9656952c61b84c53f7a2a1f67341024d	JCB 16 digit	34.2574181578807497	-118.315358267481628
44234	2020-08-12 03:55:51	2020-08-12	Winfield Roberts	winfield.roberts@geemail.com	San Francisco	California	3711113063556698	1a98133c03688ea0d2c3cf57a8b96650	VISA 13 digit	37.7712254648859798	-122.445526612322695
44235	2020-08-12 04:00:16	2020-08-12	Mrs. Ora Koepp DVM	mrs.ora.koepp.dvm@geemail.com	Houston	Texas	869977555492634234	f0ca2f2f6e567a209def4bdd510eaa8a	Discover	29.879244610535352	-95.4413111723508649
44236	2020-08-12 04:03:47	2020-08-12	Gene Nicolas	gene.nicolas@geemail.com	St. Petersburg	Florida	4780896635904219	80d2f3d8b9ae0596e3c6032cc7f5a0d3	Discover	27.701451745664702	-82.5554264666404549
44237	2020-08-12 04:16:53	2020-08-12	Kameron Hickle-Batz	kameron.hickle.batz@geemail.com	Provo	Utah	180038787553500933	6a408a82e3b3dc288d9970579417e7f5	Discover	40.2039328505538407	-111.624107560203598
44238	2020-08-12 04:16:59	2020-08-12	Kathrine Koch	kathrine.koch@woohoo.com	Vacaville	California	6011076782468482023	f2e181fe27394eaff6555f6690ab588d	Discover	38.2864915384572058	-121.991581127920384
44239	2020-08-12 04:30:24	2020-08-12	Lonnie Schamberger	lonnie.schamberger@geemail.com	Philadelphia	Pennsylvania	589398636428280	401f2f832329be5181629b723d2c9d88	Discover	40.0352782121818507	-75.0698765353664754
44240	2020-08-12 04:32:22	2020-08-12	Leo Gusikowski PhD	leo.gusikowski.phd@geemail.com	Tucson	Arizona	3026104078267980	e7f6fe4ae5dad4a37b38a2b5d30caab4	Mastercard	32.0621123791713316	-110.912476755002885
44241	2020-08-12 04:33:56	2020-08-12	Billy Sawayn DVM	billy.sawayn.dvm@geemail.com	Torrance	California	3096156861296721316	668319f354c3ff83a3f9d9e899ff1132	Discover	33.8016076523717501	-118.272503342585253
44242	2020-08-12 04:36:20	2020-08-12	Mr. Kristen Wiegand	mr.kristen.wiegand@woohoo.com	New York	New York	180033526921378092	ac6ed79168fd0aa8400ab27745ad24fe	JCB 16 digit	40.6504962746277414	-73.9592436577089103
44243	2020-08-12 04:37:45	2020-08-12	Emmit Luettgen	emmit.luettgen@warmmail.com	Dallas	Texas	3425946923498054	b85c934a332305a9687e4413bc919ac0	JCB 16 digit	32.8884334532350309	-96.7690242723990224
44244	2020-08-12 04:44:39	2020-08-12	Tasha Weissnat-Schmidt	tasha.weissnat.schmidt@woohoo.com	Louisville	Kentucky	52891306657703529	e1c18b15d2f1fd4a749efd5f3ad734f6	JCB 15 digit	38.1383865967296032	-85.6162846413046168
44245	2020-08-12 04:45:42	2020-08-12	Missy Beatty	missy.beatty@geemail.com	Indianapolis	Indiana	180027964394312306	34872b9694f120fd69859c1cdb03de99	American Express	39.85139048965722	-86.0951802308406684
44246	2020-08-12 04:53:22	2020-08-12	Ronda Moore	ronda.moore@warmmail.com	Newark	New Jersey	3158106862061572398	7a52b50458b9987febb830cb57533556	Discover	40.6661412509072591	-74.0791647643525124
44247	2020-08-12 04:56:12	2020-08-12	Kiarra Price-Buckridge	kiarra.price.buckridge@woohoo.com	Lewisville	Texas	3158640090200290630	e4ed1dedcf84a4be2ae19fc88a6a3679	Discover	32.9624203724306071	-97.067558221289147
44248	2020-08-12 04:58:34	2020-08-12	Heidi Cassin	heidi.cassin@woohoo.com	Overland Park	Kansas	4972609195730	a461b1653730a6b691d1d13ff0b29563	Diners Club / Carte Blanche	38.8706733627114502	-94.6590659629128908
44249	2020-08-12 05:10:32	2020-08-12	Garner Stark	garner.stark@geemail.com	Henderson	Nevada	3009217438726276	2b9b26af48a73dc1c3a35414eaf32d25	Maestro	36.0807580006707482	-115.094363053670904
44250	2020-08-12 05:11:13	2020-08-12	Miss Vella Anderson	miss.vella.anderson@geemail.com	San Francisco	California	3337266086058319961	ebdfeb0a296063d858d991dbe72b7d3d	Voyager	37.747922466983475	-122.417435660730746
44251	2020-08-12 05:30:37	2020-08-12	Golda Davis	golda.davis@geemail.com	New York	New York	3743468867514661	3b7bdccf46fb765e35439da38e31d145	VISA 13 digit	40.6213492392320177	-73.9905920194357662
44252	2020-08-12 05:31:18	2020-08-12	Bird Senger-Powlowski	bird.senger.powlowski@geemail.com	San Jose	California	4502579453320	5bf5d53da0ab12e373c5e58f6d221572	Discover	37.359634560934083	-121.791216310135653
44253	2020-08-12 05:37:25	2020-08-12	Americo Kling DVM	americo.kling.dvm@geemail.com	Modesto	California	3050023555533696	aaf8bc7ca2581f750a06aaee3ccdc906	JCB 16 digit	37.6506130626890823	-120.941923834497103
44254	2020-08-12 05:42:48	2020-08-12	Zaiden Hilll	zaiden.hilll@woohoo.com	Fort Wayne	Indiana	52828660956570585	ba86ec84b9228aee4fb4e86ea520f3d8	VISA 16 digit	41.0217135105997315	-85.0579249674208455
44255	2020-08-12 05:42:56	2020-08-12	Joey Rodriguez	joey.rodriguez@geemail.com	Oxnard	California	869954464106007225	f93bb47eb949519c631b14b3c66d8161	Discover	34.1273678347889344	-119.298490281626954
44256	2020-08-12 05:47:40	2020-08-12	Almedia Kerluke	almedia.kerluke@geemail.com	Arlington	Texas	54456199912155230	4feb7586824feb2d2ad6869995d31081	JCB 15 digit	32.6213319343764283	-97.0520557313252255
44257	2020-08-12 05:51:16	2020-08-12	Annice Kautzer	annice.kautzer@geemail.com	Kansas City	Missouri	3528053881833071516	ae4ddc8f6b18eabdd00b724566cbfaf7	Voyager	39.1248986694332217	-94.5492693149242598
44258	2020-08-12 05:51:30	2020-08-12	Dr. Amos Monahan Jr.	dr.amos.monahan.jr.@geemail.com	Eugene	Oregon	3112976111927601430	e79d35976afa713303020f97354fddd1	American Express	44.0281437386952348	-123.084966997056085
44259	2020-08-12 05:52:28	2020-08-12	Lucretia Braun-Kub	lucretia.braun.kub@geemail.com	Charlotte	North Carolina	210050118116694455	0b4794cc75e73e4c7c9b6c0dc5f78360	Maestro	35.3029503565534952	-80.9169595964662705
44260	2020-08-12 06:04:49	2020-08-12	General Kovacek	general.kovacek@warmmail.com	Austin	Texas	3470096149410824	392dea330b6179dcad940a1a6f678a3f	VISA 16 digit	30.2248648032207043	-97.7861635836079728
44261	2020-08-12 06:05:33	2020-08-12	Fidencio Walsh I	fidencio.walsh.i@geemail.com	Pompano Beach	Florida	3700754957334388	9362c2826d379c700309db0bff0e8c2e	Mastercard	26.1475598117601109	-80.2290543079223397
44262	2020-08-12 06:07:39	2020-08-12	Dr. Holland Cole Jr.	dr.holland.cole.jr.@geemail.com	Jacksonville	Florida	55909500467386737	ef6f092cb91dd41c36d20642bb64ca49	JCB 15 digit	30.2609308760199696	-81.741883263931058
44263	2020-08-12 06:08:00	2020-08-12	Brown Wiza	brown.wiza@woohoo.com	Mobile	Alabama	3480947505030796	cfe746274d02a0644b2f627c318d323b	Maestro	30.5866426565326748	-88.1099554912324976
44264	2020-08-12 06:09:19	2020-08-12	Yoselin Senger	yoselin.senger@geemail.com	Fresno	California	4533706030505364	67247c9a4160afaa86d84031a5aae482	Mastercard	36.8399917683437437	-119.860736704675119
44265	2020-08-12 06:10:25	2020-08-12	Ivanna Lemke-Mueller	ivanna.lemke.mueller@geemail.com	Los Angeles	California	4653369856371876	570a0bd8ecf09e30362c96e044a15ad0	VISA 16 digit	33.940133198383819	-118.318724772752446
44266	2020-08-12 06:28:04	2020-08-12	Maribel Heller	maribel.heller@geemail.com	Huntsville	Alabama	210059624669080084	0f1de3ce9dcfbf5ec5384c3d5c787c33	Voyager	34.600356730191038	-86.7070922594070481
44267	2020-08-12 06:29:40	2020-08-12	Marcella Lockman	marcella.lockman@geemail.com	Huntington Beach	California	3158222076219444116	353ae7912254bf37b53b05c28f446a6c	VISA 16 digit	33.7485782105982324	-117.91380821062549
44268	2020-08-12 06:33:47	2020-08-12	Joaquin Deckow	joaquin.deckow@geemail.com	Tampa	Florida	4248704027513828	fab9ac8b814d40c86130adb5a56190ba	Maestro	28.0012648896429681	-82.4407657413490114
44269	2020-08-12 06:37:50	2020-08-12	Mckayla Gleason	mckayla.gleason@geemail.com	Tempe	Arizona	869935663840925618	b70d73bdb0bb4ac054c97782cd7634ca	Diners Club / Carte Blanche	33.3268515196084962	-111.840491785810514
44270	2020-08-12 06:44:38	2020-08-12	Jabari Torp Sr.	jabari.torp.sr.@woohoo.com	Chicago	Illinois	4177337012664440	c39b44b9f5b54c71a60ec0b34172075b	Voyager	41.8704093658201444	-87.6588792854949759
44271	2020-08-12 06:47:26	2020-08-12	Orren Bayer	orren.bayer@woohoo.com	Los Angeles	California	4801836089087	2d12e2e77f97c1bcef264f95e46b2016	JCB 16 digit	34.0077519276510927	-118.502214878098286
44272	2020-08-12 06:56:09	2020-08-12	Nila Bogisich-Ebert	nila.bogisich.ebert@woohoo.com	Hayward	California	6011471852599744400	6b1d03b015dfd5c5e78f5a55e09c7686	Voyager	37.6113325345318756	-122.116575102720034
44273	2020-08-12 06:57:00	2020-08-12	Dr. Terance Lang	dr.terance.lang@woohoo.com	Fort Wayne	Indiana	6011857245769927562	843acd05e0239ab68e086d94f30a8280	JCB 16 digit	41.0755836585320537	-85.1044139996856472
44274	2020-08-12 07:12:19	2020-08-12	Marnita Keeling	marnita.keeling@geemail.com	Boston	Massachusetts	4901891028751941	9057f1b8930199288f73bb7fc600b47a	Mastercard	42.3497678404841551	-70.9944621646262704
44275	2020-08-12 07:18:51	2020-08-12	Ms. Kassie McGlynn	ms.kassie.mcglynn@geemail.com	Lansing	Michigan	180057774680589738	4f7376693c4612f0254514563c220d14	JCB 16 digit	42.769612421033159	-84.6518413993652814
44276	2020-08-12 07:21:19	2020-08-12	Jabbar Tromp	jabbar.tromp@geemail.com	Brownsville	Texas	869966096214618174	66a20dde5e1809bb154f8dc475746ad2	Voyager	26.0005330559410126	-97.5299990243464663
44277	2020-08-12 07:30:58	2020-08-12	Lige Weber	lige.weber@geemail.com	Boston	Massachusetts	3026106620804327	cf720f5c367bcec18618cb3f3ad95e09	American Express	42.4232268841173479	-70.9991327930659111
44278	2020-08-12 07:34:47	2020-08-12	Lark Lowe III	lark.lowe.iii@geemail.com	Seattle	Washington	561286889718952	2fc0febec31bb30f399ea7383869047a	VISA 13 digit	47.5404642596300704	-122.365195427780591
44279	2020-08-12 07:35:41	2020-08-12	Flonnie Morar-Wiza	flonnie.morar.wiza@geemail.com	San Francisco	California	6011018887423306737	d63e4352e7958d69fe57b69e0533042c	JCB 15 digit	37.7759804392391487	-122.467159210434914
44280	2020-08-12 07:44:32	2020-08-12	Brandie Pouros	brandie.pouros@geemail.com	Detroit	Michigan	3112652755842909962	b90facddde0a1c30dc3b9b0bfb01b4b7	VISA 13 digit	42.3288761500660371	-83.0655971642702724
44281	2020-08-12 07:46:36	2020-08-12	Clarnce Wilderman	clarnce.wilderman@woohoo.com	Oakland	California	3088491587972291712	74ebdc3a58628afaa58ffa6a695c6244	VISA 16 digit	37.806756774029509	-122.273570799296309
44282	2020-08-12 07:58:21	2020-08-12	Lottie Lindgren	lottie.lindgren@geemail.com	Albuquerque	New Mexico	3042450760848973	78750e2e19fbe37abd31218f64ac2746	VISA 16 digit	35.1877901611983788	-106.593330518303077
44283	2020-08-12 08:18:00	2020-08-12	Curley Lesch	curley.lesch@geemail.com	Chicago	Illinois	3005161698017709	ca23b749b3ff46ceece4cd400b029002	Discover	41.789180554526304	-87.654432557339959
44284	2020-08-12 08:19:19	2020-08-12	Less Fritsch	less.fritsch@geemail.com	Denver	Colorado	180032249595103743	1d6a2ac66333ea5f1f9c1330e98681c4	Diners Club / Carte Blanche	39.852299472275746	-104.924730720954386
44285	2020-08-12 08:25:36	2020-08-12	Normand Howe-Sanford	normand.howe.sanford@geemail.com	Washington	District of Columbia	3041362031505285	f7fed812bebe40be05a4c2131bd518e9	Discover	38.8274577793464033	-76.9296970638658877
44286	2020-08-12 08:28:52	2020-08-12	Franz Leannon	franz.leannon@warmmail.com	Antioch	California	3337876964173992577	2a141836e2471dd5081bc5b83abff858	Discover	37.9470850416257974	-121.802019099536167
44287	2020-08-12 08:43:57	2020-08-12	Letty Bergnaum-Stroman	letty.bergnaum.stroman@geemail.com	Fargo	North Dakota	4594017705050587	ad93462e0b59a0894a3c700991dc7670	JCB 16 digit	46.7900292556032582	-96.7838510225489728
44288	2020-08-12 08:49:37	2020-08-12	Aiyana Rohan-Conn	aiyana.rohan.conn@geemail.com	Hollywood	Florida	561265930203958	7441f37a512c36946db6d44f07b7754d	Mastercard	26.1289813079349678	-80.1406627645533405
44289	2020-08-12 09:08:06	2020-08-12	Hilary Tromp-Goyette	hilary.tromp.goyette@woohoo.com	Tallahassee	Florida	6011539328922447870	57379cb4346ca3d71759ff0b6cf32bea	JCB 16 digit	30.3988572111375639	-84.1692028953708729
44290	2020-08-12 09:13:12	2020-08-12	Newton Fisher	newton.fisher@geemail.com	Cape Coral	Florida	3112242857991244295	3d0adb5032ee6936d1b512d394ad480b	Diners Club / Carte Blanche	26.6504166767902682	-82.0805259042024602
44291	2020-08-12 09:14:34	2020-08-12	Mr. Ezra Schumm DDS	mr.ezra.schumm.dds@geemail.com	Lakeland	Florida	6011971712563187017	3a5bd59b51313d4f50e06b6df4f8baf7	VISA 16 digit	28.1112889497373253	-81.934544525190816
44292	2020-08-12 09:14:54	2020-08-12	Mr. Stanton Marquardt Sr.	mr.stanton.marquardt.sr.@geemail.com	Houston	Texas	6011176100466673908	8e77abec114b5309bae56587c0ae3768	Diners Club / Carte Blanche	29.8493972344402216	-95.474706953299787
44293	2020-08-12 09:18:25	2020-08-12	Lukas Dicki-Herman	lukas.dicki.herman@geemail.com	Kent	Washington	52616460420313290	dbdadd56a2d77eb0baa14eb2b3b717fb	American Express	47.3594289742056276	-122.274318357710541
44294	2020-08-12 09:27:06	2020-08-12	Serenity Keeling	serenity.keeling@geemail.com	Dallas	Texas	869954026360720395	54f274db16369b2ff713452021619740	JCB 16 digit	32.8280238349262632	-96.8526424594186182
44295	2020-08-12 09:31:11	2020-08-12	Taina Yundt	taina.yundt@geemail.com	Wilmington	North Carolina	869926525030720417	a9d981c94be673eacd17c6f3b945186c	Diners Club / Carte Blanche	34.1860518681637942	-77.8384875014882596
44296	2020-08-12 09:32:36	2020-08-12	Alton Keeling	alton.keeling@geemail.com	Waco	Texas	180053575448865797	9dd82ffb3c35d8e6ff2cd31d09a2fa1c	Discover	31.5076740872789145	-97.1920404447373016
44297	2020-08-12 09:34:13	2020-08-12	Korey Haag	korey.haag@geemail.com	Toledo	Ohio	3765643853047388	890b6ae8a5dec196771887345c7bf324	VISA 16 digit	41.7461204029325401	-83.6403124929737345
44298	2020-08-12 09:34:46	2020-08-12	Adolphus Wyman	adolphus.wyman@geemail.com	McAllen	Texas	4163951119235	4522c3e71bd1e7d91c207fb93e3bc339	Discover	26.2243636046841715	-98.3122698415383667
44299	2020-08-12 09:39:38	2020-08-12	Arlie Greenfelder	arlie.greenfelder@geemail.com	North Las Vegas	Nevada	3021038573799763	cb1188eddbde619dfec6d9742dfd055e	Discover	36.3496436539262504	-115.068634865175568
44300	2020-08-12 09:49:59	2020-08-12	Dr. Hoyt Graham V	dr.hoyt.graham.v@geemail.com	Albuquerque	New Mexico	3004594480328507	7195d24ca3201fea0033c4420a7921c1	Diners Club / Carte Blanche	35.0993999097630436	-106.573484502553569
44301	2020-08-12 09:52:07	2020-08-12	Sanjuanita Johnston	sanjuanita.johnston@woohoo.com	Colorado Springs	Colorado	4229310102699	dc95e7cd809206f2d860ea80e76db7f7	Mastercard	38.8181419614750922	-104.825127638472992
44302	2020-08-12 09:53:33	2020-08-12	Orla Zieme	orla.zieme@geemail.com	New York	New York	4500713702628	3d77e18d36793dd6f5f0d5e9cc00b94d	JCB 15 digit	40.7413357777744523	-73.9141173148423434
44303	2020-08-12 09:56:09	2020-08-12	Alayna Anderson MD	alayna.anderson.md@geemail.com	San Francisco	California	3059153462264126	f70815936cdaba03bc21587d8f43021b	Diners Club / Carte Blanche	37.7694245752415085	-122.412580822374593
44304	2020-08-12 10:06:32	2020-08-12	Dr. Brigette Kreiger	dr.brigette.kreiger@geemail.com	El Paso	Texas	869958800508941212	2d6b711a351feaf7ee565748ebbab138	Mastercard	31.8997502596411877	-106.479124518156056
44305	2020-08-12 10:06:43	2020-08-12	Carmel Sporer	carmel.sporer@geemail.com	Orange	California	4445696589305	879ae7186cf58d7b9f3fbe31c8950ca5	American Express	33.7241178739238521	-117.92689718423523
44306	2020-08-12 10:07:10	2020-08-12	Berdie Boyle MD	berdie.boyle.md@geemail.com	San Francisco	California	180026288244121456	4aff8af95feb11cc73b9ca139a93d823	VISA 13 digit	37.7662476689610855	-122.432732582045048
44307	2020-08-12 10:10:25	2020-08-12	Foster Muller	foster.muller@warmmail.com	Los Angeles	California	3088279526842829119	205041b2c79e5136bd4c52bbca3a3c7a	Maestro	33.9476164917327452	-118.342033863532535
44308	2020-08-12 10:19:04	2020-08-12	Dr. Kenley Kuhlman	dr.kenley.kuhlman@woohoo.com	Lexington	Kentucky	3337140706853107855	0ac4b12ed13916bf2de2869b5cf1bcfd	Diners Club / Carte Blanche	38.0281294259585465	-84.4690211477123114
44309	2020-08-12 10:24:21	2020-08-12	Dr. Schuyler Davis	dr.schuyler.davis@geemail.com	Jurupa Valley	California	6011125461200422024	50b4d9fc2903f1c087497793b3451591	Voyager	34.0918714536283147	-117.481230277523778
44310	2020-08-12 10:26:49	2020-08-12	Francisquita Volkman	francisquita.volkman@geemail.com	Charlotte	North Carolina	3481004519622934	e94d2c749b426a9c6de9b1c5962ffa46	American Express	35.3033068693961951	-80.7476660757269684
44311	2020-08-12 10:29:27	2020-08-12	Phyllis Brown	phyllis.brown@geemail.com	Oakland	California	210074853355418966	2a003063e5ca1b60f057d5dbcda6592e	Mastercard	37.8114405841602945	-122.277836367490622
44312	2020-08-12 10:29:33	2020-08-12	Faustino Brown	faustino.brown@geemail.com	Reno	Nevada	3426159073836557	89e88471230230081ce946e758ef9bfc	VISA 16 digit	39.5294413240704685	-119.783180518557884
44313	2020-08-12 10:31:13	2020-08-12	Kian Lakin IV	kian.lakin.iv@geemail.com	San Francisco	California	3028387885852551	f852be00e27714f98674d648486724c4	VISA 16 digit	37.7838170811582472	-122.400581303059653
44314	2020-08-12 10:44:45	2020-08-12	Dr. Linn Blanda DVM	dr.linn.blanda.dvm@geemail.com	Elgin	Illinois	869991004080917067	57744b1155c5e61fee01e49d7cb2b751	Diners Club / Carte Blanche	42.0572180823706105	-88.2785630675319624
44315	2020-08-12 10:47:03	2020-08-12	Karissa Rempel	karissa.rempel@warmmail.com	Las Vegas	Nevada	3042899193031880	b3c7a8095480691191d25c13896f45a9	VISA 13 digit	36.1916780669342728	-115.208301824445272
44316	2020-08-12 10:52:15	2020-08-12	Johnathon Trantow	johnathon.trantow@geemail.com	San Diego	California	4481395055710	82454184be8a0ef400e21af37b6a07f1	JCB 15 digit	32.9130233590558205	-117.131487563941633
44317	2020-08-12 11:13:28	2020-08-12	Laurel Weimann Sr.	laurel.weimann.sr.@woohoo.com	Austin	Texas	869930449677918610	7ed68ee0421673006a6d624172425169	Discover	30.2501505240458997	-97.6922628593869575
44318	2020-08-12 11:16:26	2020-08-12	Durrell Ankunding	durrell.ankunding@geemail.com	Fort Wayne	Indiana	630425103578305	be9108d772fb796e6ee1a65addd4f953	Mastercard	41.1433248279865822	-85.0568804091993798
44319	2020-08-12 11:31:01	2020-08-12	Mitch Legros	mitch.legros@geemail.com	Overland Park	Kansas	180001200468680603	56649d2f307d1d7ba5978b386b869f30	VISA 16 digit	38.8397110368926093	-94.5930714072234906
44320	2020-08-12 11:31:51	2020-08-12	Saniyah Kuhn DDS	saniyah.kuhn.dds@woohoo.com	San Antonio	Texas	3088070155499796347	36ebfb4facf62a2f3484ccafca653747	American Express	29.4096503854800027	-98.4963026176974097
44321	2020-08-12 11:34:40	2020-08-12	Ms. Ever Medhurst	ms.ever.medhurst@geemail.com	Rochester	New York	180050346050493937	6adaa0ea1b55741a2fefaa87e5688ee2	VISA 13 digit	43.1389676045138373	-77.5442443492595146
44322	2020-08-12 11:49:44	2020-08-12	Mrs. Etna Macejkovic PhD	mrs.etna.macejkovic.phd@geemail.com	San Francisco	California	3702952803544212	64f37a601cd83fed5743c812dff01e6c	VISA 16 digit	37.7696590755433235	-122.42158619095926
44323	2020-08-12 12:12:40	2020-08-12	Shelvie Ferry	shelvie.ferry@geemail.com	Wilmington	North Carolina	869989399236277125	cb08fc19edaf888808fa1a8253a8a5e7	Mastercard	34.1134119018267867	-77.9661743020631377
44324	2020-08-12 12:19:51	2020-08-12	Toma Douglas PhD	toma.douglas.phd@geemail.com	Shreveport	Louisiana	53929499773165529	7910f99943a840100662e53ede8686d6	JCB 15 digit	32.5335541715618248	-93.8004552005536851
44325	2020-08-12 12:20:29	2020-08-12	Laila Hansen	laila.hansen@geemail.com	Boston	Massachusetts	869999450142062107	f89a598ed40b8b1005cbcaa88d1aa1c1	Diners Club / Carte Blanche	42.2386247723065296	-71.091157600930714
44326	2020-08-12 12:26:16	2020-08-12	Abraham Mohr III	abraham.mohr.iii@warmmail.com	Chesapeake	Virginia	180019708952186218	84d9dc0572e009c31cbc51d74c1e1c07	Diners Club / Carte Blanche	36.7084590646211097	-76.3491420043010294
44327	2020-08-12 12:36:24	2020-08-12	Fidel Schuppe III	fidel.schuppe.iii@warmmail.com	Milwaukee	Wisconsin	3043177373144131	c7daa33602ceb4822fd8bb914a836e3f	JCB 16 digit	42.9711694412019085	-87.8775681773301187
44328	2020-08-12 12:38:14	2020-08-12	Yajaira Abbott-Reichert	yajaira.abbott.reichert@warmmail.com	Fort Worth	Texas	3528271020050950740	1de43c81026e048884bbc81fcb0770bd	VISA 16 digit	32.7705151787549269	-97.2927535927209988
44329	2020-08-12 13:13:22	2020-08-12	Latrell Homenick	latrell.homenick@woohoo.com	Lewisville	Texas	4500642221453594	523b73d535f9b04ff9530838de6063dd	JCB 16 digit	33.0578625026609743	-97.0644978316996259
44330	2020-08-12 13:14:51	2020-08-12	Mr. Trent Harris	mr.trent.harris@geemail.com	Berkeley	California	54505373111769544	dc6f666c2d8159debb266b04b5203cc5	Diners Club / Carte Blanche	37.8783724682431995	-122.29011476372996
44331	2020-08-12 13:15:44	2020-08-12	Mr. Elwood Yost	mr.elwood.yost@geemail.com	Mesa	Arizona	4577495312298644	84cc1b1f50a3a265db48a5a1517548c9	VISA 16 digit	33.3737061899766303	-111.759508706803985
44332	2020-08-12 13:17:05	2020-08-12	Jaidyn Stiedemann	jaidyn.stiedemann@woohoo.com	San Angelo	Texas	6011423307018158707	679e04dc40355b8b36b63f2fe3d38727	JCB 16 digit	31.5326110286325196	-100.43443484852277
44333	2020-08-12 13:20:09	2020-08-12	Raegan Herzog	raegan.herzog@geemail.com	New York	New York	3528520142558693595	1afbb6d124606b00479b45d15c992fec	Voyager	40.6259289256054927	-74.0196006245806757
44334	2020-08-12 13:26:40	2020-08-12	Miss Winnie Renner DDS	miss.winnie.renner.dds@geemail.com	Miami	Florida	6011066931759452458	b77f278167893c441a0e041149f795ae	JCB 15 digit	25.6868525149438547	-80.287218283709521
44335	2020-08-12 13:29:08	2020-08-12	Devin Breitenberg	devin.breitenberg@geemail.com	Austin	Texas	3410352995697359	e019975288e5f5522b3f57e511ba355b	American Express	30.2513691666662687	-97.7077683895599165
44336	2020-08-12 13:35:42	2020-08-12	Brain Homenick	brain.homenick@geemail.com	San Francisco	California	3096644728881009326	0e3fbd4cbde75e436199fea57991422b	American Express	37.759410411375832	-122.427358451803784
44337	2020-08-12 13:37:38	2020-08-12	Jon Jones	jon.jones@warmmail.com	Portland	Oregon	3158451630458104542	dd7028405b8a10fcfd90bdd1d86da16e	JCB 16 digit	45.5727096800114921	-122.565396428573877
44338	2020-08-12 13:41:02	2020-08-12	Ebony Hermiston	ebony.hermiston@woohoo.com	Seattle	Washington	4243619082647227	abc1f1a8b86eecfdbafdd3776ea45795	VISA 16 digit	47.6948565501645234	-122.294918075987695
44339	2020-08-12 13:41:26	2020-08-12	Dr. Christy D'Amore PhD	dr.christy.d'amore.phd@geemail.com	Fort Worth	Texas	55260256624625813	102884cb2993cd59e65050e341046419	Maestro	32.8715703880935948	-97.444959224463247
44340	2020-08-12 13:42:10	2020-08-12	Dimple Hoppe	dimple.hoppe@geemail.com	Kent	Washington	55765236372482609	00bc56c78a53afb7540a91e58e66affc	JCB 16 digit	47.4777858233191026	-122.206421464928241
44341	2020-08-12 13:42:12	2020-08-12	Arbie Herzog	arbie.herzog@woohoo.com	Everett	Washington	6011795305862760511	0bbac227792bb4517984f38ae7b854ed	VISA 16 digit	47.9383280291579652	-122.191040438891946
44342	2020-08-12 13:42:27	2020-08-12	Oliva Metz-Pouros	oliva.metz.pouros@geemail.com	San Francisco	California	4565578874108022	7fbadbb1587f44e87a54f76810feeddf	Diners Club / Carte Blanche	37.7634627356530999	-122.418353179586759
44343	2020-08-12 13:48:39	2020-08-12	Arlie Botsford	arlie.botsford@geemail.com	Cleveland	Ohio	6011523465987489948	c111c734c1e3c6d6530e2c04e72e24d0	JCB 16 digit	41.4192095157541331	-81.6631898770812938
44344	2020-08-12 13:49:01	2020-08-12	Braxton Ferry-Beahan	braxton.ferry.beahan@woohoo.com	Richmond	Virginia	4947525421194780	c10d74ed7ed911f03f111c85e0eb0674	Voyager	37.5654936142019906	-77.3923584532681872
44345	2020-08-12 13:52:08	2020-08-12	Wirt Cassin	wirt.cassin@warmmail.com	St. Petersburg	Florida	210082705779739577	5febd7afce80c9080b3af9f850fd93fc	American Express	27.6914780631083985	-82.5774906397223418
44346	2020-08-12 13:57:17	2020-08-12	Lurline Heidenreich-Quitzon	lurline.heidenreich.quitzon@geemail.com	West Valley City	Utah	3741347599754062	9a7fc0ccc591abf192ab622764a275ef	American Express	40.6298791664410359	-112.044164128855982
44347	2020-08-12 13:57:39	2020-08-12	Kelan Turcotte	kelan.turcotte@warmmail.com	New York	New York	6011522484709914845	2a16b9f7584e1bdc3cdbc52b2dd88b70	Discover	40.5777913978081202	-73.8532191624760657
44348	2020-08-12 13:58:48	2020-08-12	Miss Amma Sanford	miss.amma.sanford@geemail.com	Fort Worth	Texas	210024592857501199	86f366e9f0c573d3f8b9d6db2f13d5ef	Maestro	32.7673096441719665	-97.2564659028135168
44349	2020-08-12 13:59:24	2020-08-12	Amit Marquardt	amit.marquardt@geemail.com	Charleston	South Carolina	4094237219798	96ca96dbdfa87b75019f8dc55ed6bf02	JCB 16 digit	32.8205672465726721	-79.900312786843628
44350	2020-08-12 14:02:52	2020-08-12	Chasity Pacocha	chasity.pacocha@geemail.com	Philadelphia	Pennsylvania	3418961392731413	2efd3199369065c6dcc3e8265366a539	JCB 16 digit	39.996472681775316	-75.0444772992182578
44351	2020-08-12 14:05:43	2020-08-12	Jameson Effertz	jameson.effertz@geemail.com	New York	New York	561218923640884	61e93dc42c110db3c685fcba3a457fcb	American Express	40.7435529372412688	-73.9035198406677694
44352	2020-08-12 14:15:52	2020-08-12	Irl Stehr	irl.stehr@warmmail.com	Sacramento	California	6011399300713162165	e8a062e7f2f4d6b215f9f6e573e26f7f	VISA 16 digit	38.5271610829778055	-121.556973943651087
44353	2020-08-12 14:30:36	2020-08-12	Felton West	felton.west@geemail.com	San Francisco	California	4635056168159	37d6e17b2415bac4e9bda882efb12abd	JCB 15 digit	37.7508816446923277	-122.43512032785948
44354	2020-08-12 14:32:01	2020-08-12	Ms. Marget Schmidt	ms.marget.schmidt@geemail.com	Orlando	Florida	3013395637844714	4f5a46e0c90beef7afbfc0882b00b688	Diners Club / Carte Blanche	28.4528446535378698	-81.2308047107853071
44355	2020-08-12 14:41:31	2020-08-12	Leann Harris MD	leann.harris.md@geemail.com	San Francisco	California	3158561409789658485	29e4aaf89b3ea8a00e1371976ab466f1	VISA 13 digit	37.7796524643387244	-122.428985334996597
44356	2020-08-12 14:48:42	2020-08-12	Rondal Padberg-West	rondal.padberg.west@geemail.com	Oakland	California	4947978826784	7c7dfc4e70346062fe19f83cb95231ad	Voyager	37.8262196481334669	-122.298181558341255
44357	2020-08-12 15:11:45	2020-08-12	Zula Jacobson PhD	zula.jacobson.phd@geemail.com	Macon	Georgia	180003630506316455	d067177cb1c2e8c0bfa0fa8fdab2a972	Mastercard	32.8850505205348114	-83.654268702092395
44358	2020-08-12 15:12:33	2020-08-12	Yolanda Hansen	yolanda.hansen@geemail.com	Vacaville	California	869991054242035704	00dc2ad7fb6739173726ff7c74762cd7	Discover	38.2790833693124384	-121.889224437100069
44359	2020-08-12 15:19:58	2020-08-12	Argie Huel	argie.huel@geemail.com	Corpus Christi	Texas	3053748375689321	408fbdad5eabc8bd78c3d2285ccb8cfb	JCB 15 digit	27.7183782707836492	-97.1410320647355121
44360	2020-08-12 15:23:32	2020-08-12	Lilianna Mueller-Cartwright	lilianna.mueller.cartwright@warmmail.com	Charlotte	North Carolina	3112017277921600883	c743e926ec75e25d2643264d8985e688	JCB 16 digit	35.1666282887358221	-80.9266323259044498
44361	2020-08-12 15:24:36	2020-08-12	Ms. Ember Medhurst	ms.ember.medhurst@warmmail.com	Yonkers	New York	3088251278058759273	7253869f53838651a7f2b67200330c44	JCB 15 digit	40.9333536720104547	-73.9366411205731424
44362	2020-08-12 15:31:18	2020-08-12	Miss Drema Hahn DVM	miss.drema.hahn.dvm@geemail.com	Sacramento	California	3088820797426975487	5860d626ca09830a60a19f03368eefe7	Discover	38.6230762255642546	-121.550250122767309
44363	2020-08-12 15:32:40	2020-08-12	Shirlie Kilback PhD	shirlie.kilback.phd@geemail.com	Chicago	Illinois	630479147101699	922f2f3f0bda5d29ac1ba66a26087285	Maestro	41.7434041218202552	-87.7312865989312485
44364	2020-08-12 15:36:10	2020-08-12	Chalmer Cole	chalmer.cole@geemail.com	Phoenix	Arizona	3458630575943969	8847120df7ce131cc6957dec7b176249	Mastercard	33.5305512547891595	-112.151330203136808
44365	2020-08-12 15:54:05	2020-08-12	Lemmie Lehner	lemmie.lehner@geemail.com	San Francisco	California	4873706262154483	f5da06db28598c41a4fe7d897405d807	Diners Club / Carte Blanche	37.7476109707040024	-122.432192616217122
44366	2020-08-12 15:55:05	2020-08-12	Prosper Schumm	prosper.schumm@geemail.com	Lakewood	New Jersey	210082530758598244	4abd1de86ebe1584edb621cf66b3a4c5	JCB 15 digit	39.9914123457208319	-74.1646746245954205
44367	2020-08-12 16:04:09	2020-08-12	Creola Larson	creola.larson@woohoo.com	Dallas	Texas	6011536198555891022	4a09d0af0398301631bd3b8a2ce489bd	VISA 13 digit	32.8645173801846795	-96.8090218226853665
44368	2020-08-12 16:10:27	2020-08-12	Luverne Ryan	luverne.ryan@warmmail.com	Philadelphia	Pennsylvania	55536418194208176	15962a695aae3da874ae206667c66d81	Discover	39.9135314390022273	-75.0364288896221723
44369	2020-08-12 16:11:56	2020-08-12	Jewell Leuschke	jewell.leuschke@geemail.com	Memphis	Tennessee	4853721559856	1c97234c0b7af00c7e13ea9e6e84b909	JCB 16 digit	35.0178902683846687	-89.8826897199988366
44370	2020-08-12 16:15:34	2020-08-12	Dr. Sandie Borer DDS	dr.sandie.borer.dds@geemail.com	Philadelphia	Pennsylvania	3457907550890485	e4312d517f2cff4d3df70105acf95ba4	Discover	39.9485856730915572	-75.0608231131352568
44371	2020-08-12 16:21:48	2020-08-12	Jerimiah Jerde	jerimiah.jerde@geemail.com	Vacaville	California	210013031464043587	26503fab184d8be02bc1c1091d93e901	American Express	38.4424709766298562	-122.01524913724252
44372	2020-08-12 16:23:06	2020-08-12	Dr. Makhi Schimmel	dr.makhi.schimmel@warmmail.com	Los Angeles	California	3402957678524439	52c3ca71c2c5fe8a32ec9db67781732b	JCB 16 digit	33.9568570579268041	-118.325050722480938
44373	2020-08-12 16:27:19	2020-08-12	Miss Isabela Shanahan	miss.isabela.shanahan@geemail.com	Miami	Florida	6011353024651369780	e77d435ffc22038db24908dd4155c438	JCB 15 digit	25.7596945402815969	-80.1634282169271302
44374	2020-08-12 16:30:30	2020-08-12	Asia Haag	asia.haag@geemail.com	Tucson	Arizona	4572958052061923	8ea1745cb4419ed1de0b25b83d2783fe	JCB 15 digit	32.0872469398234088	-110.866570112318172
44375	2020-08-12 16:40:38	2020-08-12	Mr. Stoney Moen	mr.stoney.moen@geemail.com	New York	New York	561291339680976	ac2618b3b369223249407d751fc75851	VISA 13 digit	40.7513797901328658	-73.8561422326963424
44376	2020-08-12 16:47:01	2020-08-12	Grafton O'Keefe Jr.	grafton.o'keefe.jr.@geemail.com	Birmingham	Alabama	4364816741979	06cfc25167ce4e628ab0e033f0937684	Diners Club / Carte Blanche	33.472030430499089	-86.7902483312655306
44377	2020-08-12 17:02:13	2020-08-12	Mariyah Sporer	mariyah.sporer@geemail.com	Corpus Christi	Texas	589395773739867	2798ad57bb2aafd86710d7821a707624	American Express	27.7911501033168307	-97.1395801095120675
44378	2020-08-12 17:09:16	2020-08-12	Lannie Wuckert	lannie.wuckert@woohoo.com	Tucson	Arizona	3403213797021413	0633a9e596ec9db9651dd20ec45cf045	Discover	32.1078266589012031	-110.924671694426237
44379	2020-08-12 17:18:12	2020-08-12	Maceo Littel V	maceo.littel.v@geemail.com	New York	New York	6011503135032213908	a65f70fc9aa89c837d98ea7f88bf856f	Discover	40.7351467831283784	-73.897695574060819
44380	2020-08-12 17:28:26	2020-08-12	Merrilee Mayer	merrilee.mayer@geemail.com	Lubbock	Texas	3337392490042291939	d2a92eb17618566fc38b8a9ce2a42c7a	American Express	33.4800092075526763	-101.866315798406305
44381	2020-08-12 17:32:59	2020-08-12	Campbell Huel	campbell.huel@woohoo.com	Springfield	Massachusetts	3096389536030815470	f69fb4529c40de678fc784b979c5e1e0	VISA 16 digit	42.0386293215882034	-72.5033645560126843
44382	2020-08-12 17:38:10	2020-08-12	Mr. Sean Spencer IV	mr.sean.spencer.iv@geemail.com	New York	New York	3033062079232606	e087445a0d829b5949c0cb062e0b9248	Mastercard	40.7409543178733458	-73.9885875858727786
44383	2020-08-12 17:43:22	2020-08-12	Arlene Herman DVM	arlene.herman.dvm@geemail.com	McKinney	Texas	4384084724697	450e415e9527db53945f062267c06e15	VISA 13 digit	33.1231759946923745	-96.6476582966577382
44384	2020-08-12 17:49:23	2020-08-12	Zakary Pfeffer	zakary.pfeffer@geemail.com	Riverside	California	4847166927821567	835fca7dbd3fdbf86d0c3e2cd7d1c50e	JCB 16 digit	33.8474571382109062	-117.295570332647102
44385	2020-08-12 18:01:33	2020-08-12	Carli Volkman	carli.volkman@geemail.com	Overland Park	Kansas	3055133740568005	439294b5ffee0ed7141915084b55b7a7	Voyager	38.9020786891095369	-94.6297628340818022
44386	2020-08-12 18:03:23	2020-08-12	Hershel Tillman	hershel.tillman@geemail.com	Oakland	California	501896361930538	bebe9309c16eacd77ebe39f472f1ad30	Voyager	37.81035590388435	-122.300287802758419
44387	2020-08-12 18:18:20	2020-08-12	Brinda Steuber	brinda.steuber@woohoo.com	Jacksonville	Florida	869913858444839456	042b725258eaed3385d76ffea425e857	VISA 16 digit	30.2975599248945713	-81.7182892917268049
44388	2020-08-12 18:25:03	2020-08-12	Jayden Kerluke	jayden.kerluke@warmmail.com	New York	New York	180069122915992598	a49e7e2cab82afd60f4369b6ffc4c7e2	VISA 13 digit	40.665504761947318	-73.9742600366834466
44389	2020-08-12 18:26:38	2020-08-12	Chana O'Connell	chana.o'connell@geemail.com	Berkeley	California	3461226485477399	7039fd27b75cebf946b11e4b095b02b8	VISA 16 digit	37.863908868975507	-122.231720187144433
44390	2020-08-12 18:28:22	2020-08-12	Dr. Guido Krajcik Sr.	dr.guido.krajcik.sr.@warmmail.com	Abilene	Texas	3158817167451405211	c650e4197d1c1cf62e28433be95211cf	Mastercard	32.3588165021576017	-99.8234743953630357
44391	2020-08-12 18:31:47	2020-08-12	Mr. Alanzo McLaughlin	mr.alanzo.mclaughlin@geemail.com	El Paso	Texas	4899081853272	e1b0a2ad5e146a121615d13baabeca47	VISA 13 digit	31.8660806683186451	-106.457084521928806
44392	2020-08-12 18:40:58	2020-08-12	Mr. Montel Upton	mr.montel.upton@geemail.com	Thornton	Colorado	52103022882590359	febb4e58a514e8c3ed02febd83865ec6	Voyager	39.9744599226262451	-104.919024185246982
44393	2020-08-12 19:30:10	2020-08-12	Sherri Torphy	sherri.torphy@woohoo.com	Oakland	California	4276850036198179	ae73ae2138eb51b2d2f3f4f999d56a09	American Express	37.8351908963541845	-122.289149025688431
44394	2020-08-12 19:35:32	2020-08-12	Ota McKenzie	ota.mckenzie@geemail.com	Port St. Lucie	Florida	3528349913456629249	609ecaf21e117ed62fe76cebe1e3411b	VISA 16 digit	27.3084307540342195	-80.3617879315830805
44395	2020-08-12 19:36:17	2020-08-12	Marolyn Hirthe	marolyn.hirthe@geemail.com	Anaheim	California	4342605847611	1fa3065eecd528d54cc77d100ec6be14	VISA 16 digit	33.8359747284855672	-117.712826450795305
44396	2020-08-12 19:41:48	2020-08-12	Caroline Weimann	caroline.weimann@geemail.com	Virginia Beach	Virginia	3001163136424871	af1ae1911ef7214105fe684b6eec30c3	Diners Club / Carte Blanche	36.8427834317740093	-75.9774414206992788
44397	2020-08-12 20:03:25	2020-08-12	Fidelia Thiel-Reichert	fidelia.thiel.reichert@warmmail.com	Nashville	Tennessee	210045119375988768	2c161c52534e98dac729c5dad2c86fea	Diners Club / Carte Blanche	36.2362790675491055	-86.7833852028846735
44398	2020-08-12 20:03:28	2020-08-12	Hernan Padberg IV	hernan.padberg.iv@geemail.com	Moreno Valley	California	210095738955934162	47ef7383491c591289a56070eb2d4e7d	JCB 15 digit	33.9384663065422316	-117.199166727342444
44399	2020-08-12 20:10:59	2020-08-12	Pratt Steuber	pratt.steuber@warmmail.com	Murrieta	California	180076177535992346	56ed26dd67edd6b8ae5550d87bb38a9e	VISA 16 digit	33.6451354584287827	-117.144372425311801
44400	2020-08-12 20:11:32	2020-08-12	Beda Hahn	beda.hahn@geemail.com	San Francisco	California	869954470279529788	6e3458aa7fdebee6e3fbc25a0139e072	VISA 16 digit	37.7346877386892032	-122.451841532526558
44401	2020-08-12 20:16:13	2020-08-12	Franc Ullrich DVM	franc.ullrich.dvm@geemail.com	San Jose	California	3012505050409032	9199105fb3b31ad30cbbba19000b5830	Voyager	37.2126140659961848	-121.851072445347526
44402	2020-08-12 20:38:15	2020-08-12	Mr. Donavan Ritchie	mr.donavan.ritchie@geemail.com	Louisville	Kentucky	4868644777122058	4123430b03e627e32249637ccd23093b	JCB 15 digit	38.1240475647520256	-85.5827322050068631
44403	2020-08-12 20:41:45	2020-08-12	Lorie Lebsack	lorie.lebsack@geemail.com	Simi Valley	California	869976304082731477	d4cb735555da1113efeb3f5d72093f41	Discover	34.2100994489394097	-118.666887938803072
44404	2020-08-12 20:51:33	2020-08-12	Cordell Gerhold	cordell.gerhold@geemail.com	New York	New York	6011260562747113979	bba25d4f0b8c60b3fe7c39c87917d6ff	Maestro	40.7361506946608429	-74.0163951632462442
44405	2020-08-12 20:53:38	2020-08-12	Albertine Lowe PhD	albertine.lowe.phd@geemail.com	San Francisco	California	4866325583533975	433c29cbee77b62d6826b2570e08f2d6	Mastercard	37.7639006129681221	-122.434277637510164
44406	2020-08-12 20:59:39	2020-08-12	Rene Lang DVM	rene.lang.dvm@woohoo.com	Chicago	Illinois	3029958443922000	c5ba4642f23a3efd52fc66fec20da1ec	JCB 16 digit	41.8473298818174797	-87.5948555883049949
44407	2020-08-12 21:05:50	2020-08-12	Eligah Walsh	eligah.walsh@woohoo.com	Berkeley	California	51703033293936564	18a70d3fa6eb06dc5f0c80d6457b20e9	Mastercard	37.8984140470693234	-122.293461873775641
44408	2020-08-12 21:06:16	2020-08-12	Delfina Ebert PhD	delfina.ebert.phd@woohoo.com	Indianapolis	Indiana	4136809670445189	3a44fd71b4a840c8be3564aceea692ac	VISA 16 digit	39.7348357686780389	-86.2130844726894026
44409	2020-08-12 21:10:11	2020-08-12	Eula Torp	eula.torp@warmmail.com	Lexington	Kentucky	180091859563823797	805eff6d7c116ee1f394e6340c28567e	JCB 16 digit	38.018110807926206	-84.4366577857073395
44410	2020-08-12 21:10:31	2020-08-12	Miss Sharyn Kris PhD	miss.sharyn.kris.phd@geemail.com	Wichita	Kansas	675996762502050	0c518a2bf87acb758f732f33b1fcb7ce	VISA 16 digit	37.7258911263074737	-97.3469155168827598
44411	2020-08-12 21:12:04	2020-08-12	Billy Feeney	billy.feeney@geemail.com	McAllen	Texas	3432577129196670	4319ce13340d53319b38c92e3801af0b	American Express	26.1817092936791482	-98.2372726068679185
44412	2020-08-12 21:12:26	2020-08-12	Sonji Collins MD	sonji.collins.md@geemail.com	Washington	District of Columbia	53943861704407845	dfd791b8007b96cf7c7d12764a2af68a	Mastercard	38.9923773166056691	-76.9771457025993584
44413	2020-08-12 21:31:20	2020-08-12	Anthony Gulgowski-Hackett	anthony.gulgowski.hackett@geemail.com	San Francisco	California	180080478806329505	da32873f0ac43a039c5cbb0b4984680e	VISA 13 digit	37.756951457248519	-122.445942724360677
44414	2020-08-12 21:31:23	2020-08-12	Jarad Hyatt	jarad.hyatt@geemail.com	Cary	North Carolina	4213604004134	f0f2459b010a764cd508fed527b7dccc	Mastercard	35.846640344906227	-78.7410781136799613
44415	2020-08-12 21:35:12	2020-08-12	Karon Heathcote	karon.heathcote@geemail.com	Roseville	California	4932893162937	21e0cf77f7ab75f0fc11cd23cb2a9cf3	Diners Club / Carte Blanche	38.7451557174846499	-121.292171997412666
44416	2020-08-12 21:36:50	2020-08-12	Shyann Kemmer DDS	shyann.kemmer.dds@geemail.com	Honolulu	Hawaii	4103573108901	b007f3a240caffafd7f1655adc5cc54c	American Express	21.3014415781695412	-157.841735804614046
44417	2020-08-12 21:37:23	2020-08-12	Lisle Kertzmann Sr.	lisle.kertzmann.sr.@geemail.com	Baltimore	Maryland	4872144317848787	2ad1389fef44fd3e0ac12291a97da8fe	JCB 16 digit	39.2405095061752931	-76.6956244985126006
44418	2020-08-12 21:42:22	2020-08-12	Ellamae Schultz	ellamae.schultz@geemail.com	Kansas City	Missouri	4751860247590	0f5ba839550412152c344afe2bbd0681	JCB 16 digit	39.028972850909831	-94.614169538881626
44419	2020-08-12 21:43:31	2020-08-12	Lloyd Daniel	lloyd.daniel@geemail.com	New York	New York	6011371549085099551	5ff6683b4a6fa2ef10ea06980550356f	Maestro	40.6549348666090538	-74.0001751679357085
44420	2020-08-12 21:55:04	2020-08-12	Jinnie Stokes PhD	jinnie.stokes.phd@geemail.com	San Francisco	California	4263396151148	affe9cb187ae504d29c19e9ce3b3e961	JCB 16 digit	37.7799057231488931	-122.419487298967056
44421	2020-08-12 21:59:50	2020-08-12	Luc Toy	luc.toy@geemail.com	Milwaukee	Wisconsin	4517421459548057	b30eb894439a35cbd32ef2b0b4213bf5	VISA 13 digit	43.1538801463872161	-87.9478490437947187
44422	2020-08-12 22:01:55	2020-08-12	Clevie Collier	clevie.collier@woohoo.com	San Francisco	California	6011812413221367314	8ab9c4a72513c0f2195c50c5acce1ebd	Discover	37.7436567896040671	-122.428308896894819
44423	2020-08-12 22:03:47	2020-08-12	Gayle Kovacek	gayle.kovacek@geemail.com	Dallas	Texas	180093243723201244	f282aa32df7f58665952fdc8d3450396	VISA 16 digit	32.7877069120101652	-96.7065757124181715
44424	2020-08-12 22:16:59	2020-08-12	Hildegarde Towne-Ullrich	hildegarde.towne.ullrich@geemail.com	Houston	Texas	3052017941089155	5991e9ad42c7f003291c5e2968894668	Voyager	29.7358931142915033	-95.4675942185815387
44425	2020-08-12 22:24:51	2020-08-12	Mr. Iver Kiehn Jr.	mr.iver.kiehn.jr.@warmmail.com	San Francisco	California	53027770352462201	b078479dd2659261f5799df8d6a1ede0	VISA 16 digit	37.7921014199349443	-122.408567816279756
44426	2020-08-12 22:26:05	2020-08-12	Watson Schuster	watson.schuster@geemail.com	North Las Vegas	Nevada	3088333661485478819	f23c0de1302fe693efcf946e0bf0987a	VISA 13 digit	36.3461356726165832	-114.997312781981762
44427	2020-08-12 22:42:38	2020-08-12	Vollie Baumbach MD	vollie.baumbach.md@geemail.com	Vista	California	4065738783714	df126d65e624bd56af40a49805f0e7c4	JCB 16 digit	33.2417764938417832	-117.25996017889716
44428	2020-08-12 22:51:15	2020-08-12	Ms. Tinnie Connelly	ms.tinnie.connelly@woohoo.com	New York	New York	3528256252649683016	feeca482bebf5de002cb470182f3f2d5	VISA 16 digit	40.5861437512319512	-74.0233113495063009
44429	2020-08-12 22:58:50	2020-08-12	Delvin Gottlieb	delvin.gottlieb@geemail.com	Lakewood	New Jersey	3158183158876219523	69cfc94ec05edf44a16681f58253e09b	Mastercard	39.9964010999821156	-74.1608969420936006
44430	2020-08-12 23:00:00	2020-08-12	Pamela Bergnaum DDS	pamela.bergnaum.dds@geemail.com	Milwaukee	Wisconsin	4468026139096	30ec4586efa1c30b71b19b9f560d54bb	JCB 16 digit	42.9885514339517769	-88.0302197457391742
44431	2020-08-12 23:23:57	2020-08-12	Mireya Feil	mireya.feil@geemail.com	Tucson	Arizona	4720377050246116	f8fa0704143ce0de5295bbb72db1f110	VISA 16 digit	32.0633840717416305	-110.950723961344352
44432	2020-08-12 23:36:09	2020-08-12	Dr. Easter Ullrich DDS	dr.easter.ullrich.dds@geemail.com	Norfolk	Virginia	869967901373508190	e643e1a9421dfe0268985bc8d2152e68	JCB 16 digit	36.9653422148451227	-76.2892497187949772
44433	2020-08-12 23:41:48	2020-08-12	Omarion Hills	omarion.hills@warmmail.com	Sparks	Nevada	53505896343597911	be668dd3ea224d57acb198928411222b	Discover	39.5464962866861356	-119.655216790954029
44434	2020-08-12 23:47:49	2020-08-12	Esco Ziemann-Rohan	esco.ziemann.rohan@warmmail.com	West Covina	California	869958137399312777	cd1dbdf3918b9e77e2479353e2867b33	Mastercard	34.0783304783623677	-117.929560930475219
44435	2020-08-12 23:54:26	2020-08-12	Cain Marquardt	cain.marquardt@geemail.com	Richardson	Texas	4825964132873951	ff3e502c4a7da9b724f06043971d2792	Mastercard	32.9908862518846959	-96.7639689023833682
44436	2020-08-12 23:55:33	2020-08-12	Claude King-Braun	claude.king.braun@geemail.com	Broken Arrow	Oklahoma	3528414122668868880	156e7a55ff4b7b4be3092a96996171c6	JCB 16 digit	36.0119476873669768	-95.7614866841994257
44437	2020-08-12 23:56:14	2020-08-12	Racquel Blick	racquel.blick@geemail.com	Seattle	Washington	676162156164246	d6d90a0a6aeb54cc381f64965f8899c4	American Express	47.5880757722929104	-122.386104784432419
44438	2020-08-12 23:58:18	2020-08-12	Nayely Willms	nayely.willms@geemail.com	Riverside	California	3096458961180672347	c8bbe9462c0a39f5c6456f7c4168e50f	Voyager	34.0022777000389951	-117.377796892911931
44439	2020-08-13 00:00:25	2020-08-13	Dr. Alfie Hilpert Sr.	dr.alfie.hilpert.sr.@geemail.com	Colorado Springs	Colorado	4491122676399	fa093f8acdf46a78b63ff32f72b18bcc	JCB 16 digit	38.9462108946453753	-104.685862602821359
44440	2020-08-13 00:04:03	2020-08-13	Dr. Gavin Brakus	dr.gavin.brakus@warmmail.com	Grand Rapids	Michigan	3005683980553307	ee7ac3abd5e4e4b0cdf9c73f84347a4c	VISA 16 digit	43.0007454922225278	-85.6246189603716203
44441	2020-08-13 00:04:23	2020-08-13	Bryon Armstrong	bryon.armstrong@geemail.com	Buffalo	New York	676208141906829	c5bf3785701fbfbfc8d3606c300704f2	Maestro	42.9702867722324982	-78.8978874078884758
44442	2020-08-13 00:05:17	2020-08-13	Alois Cormier I	alois.cormier.i@geemail.com	San Francisco	California	3737133790200055	80c778b99c79fc2d731e6bd35823c372	American Express	37.7940220606547896	-122.44720739497437
44443	2020-08-13 00:10:56	2020-08-13	Myrtie Nader	myrtie.nader@geemail.com	Irvine	California	3337360918881095381	d8f9195ae43af4b52287116d306129ad	Discover	33.7407178711161038	-117.672273400380462
44444	2020-08-13 00:23:18	2020-08-13	Clemence Dicki	clemence.dicki@warmmail.com	San Francisco	California	6011123247224368877	24d8729b53c0b98ef8e70408e4c98448	VISA 16 digit	37.759394928637839	-122.450181619420135
44445	2020-08-13 00:26:32	2020-08-13	Crista Daniel	crista.daniel@woohoo.com	San Francisco	California	3088129954870446097	67c593271071c33a219ef9c013acb1f3	VISA 13 digit	37.7634813923903891	-122.423002241876574
44446	2020-08-13 00:30:21	2020-08-13	Brodie Rice	brodie.rice@geemail.com	Garland	Texas	4802030514034179	ca08183444e40f3edcf24b500bcafee3	JCB 16 digit	32.998520761053264	-96.6351807193990879
44447	2020-08-13 00:31:56	2020-08-13	Teddy Kerluke	teddy.kerluke@geemail.com	Port St. Lucie	Florida	3008759550355062	6759c8c24b5d2e3998899514da3b9bae	JCB 16 digit	27.3545316773135205	-80.4326565450608797
44448	2020-08-13 00:32:48	2020-08-13	Alberto Beahan	alberto.beahan@geemail.com	Glendale	Arizona	3019559316076419	dd6b7b054c3f138cec0ab55cb86e7931	Mastercard	33.6233822186704714	-112.254174526154614
44449	2020-08-13 00:46:25	2020-08-13	Emerson Rath	emerson.rath@geemail.com	Tulsa	Oklahoma	3402621141887407	44c5e20f713909f1b6b05f7a55292c6e	American Express	36.1807018347918969	-95.9035480402365295
44450	2020-08-13 00:50:02	2020-08-13	Sherry Stracke	sherry.stracke@warmmail.com	Newark	New Jersey	3700025034920717	4cbd733465eab73fc1807a7de53e5d43	Discover	40.7075902304992141	-74.112173625056073
44451	2020-08-13 00:51:00	2020-08-13	Floretta Dietrich	floretta.dietrich@geemail.com	Los Angeles	California	869931382137616160	a281c57c3e6f7361afa605018b52971b	VISA 13 digit	34.0779289278998974	-118.383679134258244
44452	2020-08-13 00:55:43	2020-08-13	Miss Lesta Dach PhD	miss.lesta.dach.phd@geemail.com	Fort Wayne	Indiana	210006807860628017	827e2f225376a781ddc6dd1d9a4f0ebf	JCB 16 digit	41.0696886365085874	-85.0483739830773402
44453	2020-08-13 01:01:39	2020-08-13	Dewey Hirthe	dewey.hirthe@warmmail.com	Chicago	Illinois	6011364327336255309	9946febe0ef637f6c1aed8c04dee0d26	VISA 16 digit	41.8864485116045913	-87.695541222210224
44454	2020-08-13 01:05:57	2020-08-13	Kiana Runte	kiana.runte@geemail.com	Jackson	Mississippi	3016343671003992	2f4332402deecb266b396c02ed9c231a	JCB 16 digit	32.3424655595507531	-90.1873034405030296
44455	2020-08-13 01:14:37	2020-08-13	Valinda Morissette-Nolan	valinda.morissette.nolan@geemail.com	Phoenix	Arizona	4123803043629	17363081c913f477b3ba0b271c3d4dc2	VISA 13 digit	33.6279830975856626	-111.996185312087093
44456	2020-08-13 01:15:49	2020-08-13	Lovell Williamson-Blanda	lovell.williamson.blanda@woohoo.com	Rochester	New York	6011739456090441215	fb74227bbe9dcccfef79d12c8949c57d	Voyager	43.1622193251248447	-77.6842540397081507
44457	2020-08-13 01:27:06	2020-08-13	Lindell Bins-Vandervort	lindell.bins.vandervort@geemail.com	Denver	Colorado	4997580267561732	bc0e2338ce40b87c81f34f7fe95ad3cf	Voyager	39.8154346564371124	-104.862991539832578
44458	2020-08-13 01:28:26	2020-08-13	Toriano Schimmel	toriano.schimmel@geemail.com	Phoenix	Arizona	3446855348754568	d3e21879973b8e917bd7b008669fc852	American Express	33.6522336117856256	-112.047505208144344
44459	2020-08-13 01:33:40	2020-08-13	Dr. Dennis Morissette V	dr.dennis.morissette.v@geemail.com	Akron	Ohio	3007547607229104	9a32416c60524845ac15c93f7563606c	JCB 16 digit	41.144269071549175	-81.5705885075811352
44460	2020-08-13 01:34:02	2020-08-13	Armin Leannon III	armin.leannon.iii@geemail.com	New York	New York	3337507737270270601	ad42c4e30eda06451ecdcc4acc77a38e	Mastercard	40.7031730673033749	-74.0181878019019877
44461	2020-08-13 01:34:55	2020-08-13	Ms. Connie Will DVM	ms.connie.will.dvm@warmmail.com	Pueblo	Colorado	54017647618951395	4ea2645a07f27de336141f0225d5dd13	Diners Club / Carte Blanche	38.3474741149205727	-104.668307122294976
44462	2020-08-13 01:45:51	2020-08-13	Mrs. Muriel Rippin DDS	mrs.muriel.rippin.dds@geemail.com	Columbus	Ohio	4594498610498832	35402b42c5371ff59b02772f19da9f4f	Diners Club / Carte Blanche	40.0320883473426079	-83.0507531041048566
44463	2020-08-13 01:46:32	2020-08-13	Charls Schmidt	charls.schmidt@geemail.com	Portland	Oregon	869971607321511574	0086303722ddbd64833a77b5265c3db8	JCB 15 digit	45.4472892424445618	-122.622672533430162
44464	2020-08-13 01:46:35	2020-08-13	Ms. Rory Collier DVM	ms.rory.collier.dvm@woohoo.com	Anaheim	California	3528065139051043725	01d03542d210baf4d32df7e6102ea5be	Diners Club / Carte Blanche	33.8675142966508886	-117.765542962748924
44465	2020-08-13 01:57:48	2020-08-13	Christine Beier	christine.beier@geemail.com	Berkeley	California	869916584458070088	aa78447eea6b426ad29d2872ad8a4d6b	Voyager	37.8464162924105239	-122.275004807625123
44466	2020-08-13 01:59:50	2020-08-13	Berniece Weissnat-Schultz	berniece.weissnat.schultz@woohoo.com	San Francisco	California	51897284944712757	681b25909ee8ec3fe594fc27407f5afb	Mastercard	37.7998186654630786	-122.437757425074423
44467	2020-08-13 02:06:00	2020-08-13	Alexys Von DDS	alexys.von.dds@geemail.com	Fort Lauderdale	Florida	3337547491321442908	06f0e42df6d1effb1564b4c54670d2d4	American Express	26.1999723037227987	-80.2109345924861685
44468	2020-08-13 02:14:16	2020-08-13	Karrie Thiel	karrie.thiel@geemail.com	Escondido	California	54965642384224442	21574ceb980f3053d6cdf3a1098d7ca3	JCB 16 digit	33.076513937045263	-117.089466733183713
44469	2020-08-13 02:17:45	2020-08-13	Joanna Farrell MD	joanna.farrell.md@warmmail.com	Mobile	Alabama	6011303227012277375	73d8136e140f29a2440aaa29abcf439b	JCB 16 digit	30.6098079381618646	-88.1896356788136018
44470	2020-08-13 02:28:19	2020-08-13	Dr. Aric Davis	dr.aric.davis@warmmail.com	Denver	Colorado	3733122275096439	7f3d5b31cc8440122363d152bfb943e9	Voyager	39.806633969820659	-104.793206568692256
44471	2020-08-13 02:30:50	2020-08-13	Demetria Gutkowski	demetria.gutkowski@geemail.com	Santa Rosa	California	52424576505838042	6a32df67d2683963033a9f93331074b4	American Express	38.413226930762832	-122.729144449603197
44472	2020-08-13 02:36:33	2020-08-13	Alcie Bradtke	alcie.bradtke@geemail.com	Jersey City	New Jersey	3158408949147142786	0a6d1ec675b9e38b2b68a6cb2499533f	Voyager	40.7651488393019861	-74.0538642203390651
44473	2020-08-13 02:51:10	2020-08-13	Shandra Barrows	shandra.barrows@geemail.com	Woodbridge	New Jersey	4057588397464583	bf5d640e2309044d818960724df8f9c1	American Express	40.584901680300753	-74.3596587103649966
44474	2020-08-13 02:53:02	2020-08-13	Ms. Viridiana Heidenreich	ms.viridiana.heidenreich@woohoo.com	Anchorage	Alaska	869920789324841836	7671baeaee79ba921d962f0d7a9516fc	JCB 15 digit	61.209892807689684	-149.189076449687775
44475	2020-08-13 03:00:12	2020-08-13	Kris Tromp	kris.tromp@geemail.com	Coral Springs	Florida	4727414746459903	34d1d338bfbeda01c8d772973b5599d3	American Express	26.1966393017273411	-80.2432894765522349
44476	2020-08-13 03:07:49	2020-08-13	Ms. Karrie Parker DVM	ms.karrie.parker.dvm@woohoo.com	Saint Paul	Minnesota	3096212183544651548	57497ce4468af6cebc18b5a9f4e621f8	VISA 16 digit	44.9736640636283909	-93.0284092516437227
44477	2020-08-13 03:22:07	2020-08-13	Dr. Brandt Howell MD	dr.brandt.howell.md@warmmail.com	West Valley City	Utah	3439947129673684	f69fda71bed9e89ae0b1cf9e42eac3c5	American Express	40.6342746931351684	-111.999978749196231
44478	2020-08-13 03:25:19	2020-08-13	Jessica Kassulke	jessica.kassulke@warmmail.com	Naperville	Illinois	3729709235421081	b47da0acb44fe8f59031400e6d781e25	Mastercard	41.7269577989734728	-88.1571382169965716
44479	2020-08-13 03:26:44	2020-08-13	Miss Odile McKenzie DVM	miss.odile.mckenzie.dvm@geemail.com	Greensboro	North Carolina	4875568030003048	90ac66aa424a7dd7912d3a2c3dd25277	Maestro	36.0072664465405055	-79.8079493711683909
44480	2020-08-13 03:29:33	2020-08-13	Angelina Hyatt DVM	angelina.hyatt.dvm@warmmail.com	Nashville	Tennessee	180063634782231872	dee1e30fb67dced3cad18e6d99ec9353	VISA 13 digit	36.2022806620813853	-86.8376829865295434
44481	2020-08-13 03:33:20	2020-08-13	Ashlee Spinka-Leffler	ashlee.spinka.leffler@warmmail.com	Nashville	Tennessee	4566870219624832	2389b7e707d10e90f9d86c930645442f	Maestro	36.2508956870652739	-86.8543833108059999
44482	2020-08-13 03:35:47	2020-08-13	Lisha Monahan	lisha.monahan@geemail.com	Garland	Texas	4940453147309326	64bffd780b5a6174b6870a8d8469a64c	VISA 16 digit	32.9999395175605983	-96.5494814793273832
44483	2020-08-13 03:41:02	2020-08-13	Alijah Quitzon-Fisher	alijah.quitzon.fisher@geemail.com	Fort Worth	Texas	4882879922194	6a8f3bf14e0a11c87200c62dff6ee6fc	Discover	32.6992545846905571	-97.383517514896397
44484	2020-08-13 03:47:29	2020-08-13	Lamont Gutkowski	lamont.gutkowski@geemail.com	San Francisco	California	6011425820676666652	ebb34823de3c2de5151ea5d7dad5ac24	Mastercard	37.7834685777081134	-122.399797032766287
44485	2020-08-13 03:51:13	2020-08-13	Dr. Ernest Labadie	dr.ernest.labadie@geemail.com	Lexington	Kentucky	4568303517692796	841dddcfaef2e821a5bbca1456ecfa2a	VISA 13 digit	38.1237026728101114	-84.3782595239479036
44486	2020-08-13 03:55:04	2020-08-13	Mrs. Ladonna Barton	mrs.ladonna.barton@geemail.com	Omaha	Nebraska	4454688588556905	60f39ee1f0fa6eca1ea3139bce612d00	Mastercard	41.173740244019406	-95.9541597954578691
44487	2020-08-13 04:01:50	2020-08-13	Cleo Weissnat	cleo.weissnat@geemail.com	Kansas City	Missouri	4488745978582	7281933cc3e1f52a07868ac36ec8f7f5	JCB 16 digit	39.034323135048524	-94.5192208796497511
44488	2020-08-13 04:02:25	2020-08-13	Dr. Stanislaus Russel II	dr.stanislaus.russel.ii@geemail.com	Fargo	North Dakota	4295575953901233	4619853642c914057d33881f2b2a11b7	VISA 16 digit	46.8545751073163004	-96.9275234403051371
44489	2020-08-13 04:05:28	2020-08-13	Jazmin Kub-Wunsch	jazmin.kub.wunsch@geemail.com	Fayetteville	North Carolina	3779062535448555	888c9e2903a375457f952b41a7af56ed	VISA 16 digit	35.0496653916101906	-78.8770729916300581
44490	2020-08-13 04:06:17	2020-08-13	Katherin Sipes	katherin.sipes@geemail.com	Chula Vista	California	3412609192293524	0df6d0ae73950e5ff65be537c5c613f4	JCB 16 digit	32.6981119893256533	-116.990246091573312
44491	2020-08-13 04:11:42	2020-08-13	Marius Reichel-Simonis	marius.reichel.simonis@warmmail.com	Fremont	California	4003479052487504	db5cb344d1802462ef4a5b2d4911bebc	VISA 13 digit	37.4639263710640407	-121.859616231870646
44492	2020-08-13 04:17:16	2020-08-13	Dr. Ruthie Kozey	dr.ruthie.kozey@geemail.com	El Paso	Texas	3051677963054857	4fdc9a87bf7c7210e4f8f3d0c8632209	VISA 16 digit	31.9037449677769125	-106.347885343570269
44493	2020-08-13 04:18:04	2020-08-13	Metha Stehr	metha.stehr@geemail.com	Fargo	North Dakota	3096423740966381261	ae18c96eb9a6b7d2ed97b82db6712532	VISA 16 digit	46.766298959613593	-96.9143557730559166
44494	2020-08-13 04:21:34	2020-08-13	Laci Gerhold MD	laci.gerhold.md@geemail.com	Charlotte	North Carolina	630470960259813	b86d72b149974727cb18cc77c750f400	American Express	35.2611815891947558	-80.7650524001047074
44495	2020-08-13 04:25:45	2020-08-13	Dr. Cas Moore PhD	dr.cas.moore.phd@geemail.com	Oxnard	California	3158201876178727079	0a0f27b25112546769eb64d673b46799	Mastercard	34.1951518301341721	-119.110905089918901
44496	2020-08-13 04:26:24	2020-08-13	Kamora Crooks	kamora.crooks@geemail.com	Houston	Texas	3528094846923484565	e0261deb2e8f93a7c2d42ac097350caf	Discover	29.750388564549759	-95.3562007013257613
44497	2020-08-13 04:27:10	2020-08-13	Dr. Garrett Nienow	dr.garrett.nienow@geemail.com	Irving	Texas	52789280572142888	b84e4a52303f13446a3731d3c0eec1b1	Mastercard	32.8828869649626299	-96.932317686667659
44498	2020-08-13 04:27:24	2020-08-13	Dosia Padberg	dosia.padberg@warmmail.com	Glendale	Arizona	501842985556465	edafa3d6aaa13245ed0113d1b17ca94d	VISA 16 digit	33.5735239058960175	-112.1200533228252
44499	2020-08-13 04:39:17	2020-08-13	Miss Jalynn Turcotte	miss.jalynn.turcotte@geemail.com	Winston–Salem	North Carolina	3023557200134738	98e28f341fa69a3e3863968f8e921c2a	JCB 16 digit	36.1964621287070187	-80.2639895438346969
44500	2020-08-13 04:47:56	2020-08-13	Kimberley Emard	kimberley.emard@geemail.com	Wichita Falls	Texas	3158192994211459393	629a41d72cc7a3adef75e00ea5b0dfc1	Voyager	33.9626680223464987	-98.493467503359156
44501	2020-08-13 04:53:55	2020-08-13	Miss Makaila Fay MD	miss.makaila.fay.md@geemail.com	San Francisco	California	4106665387885521	994a906fbab9d826a3182e09daafde7c	American Express	37.7703964631493676	-122.450299340235503
44502	2020-08-13 04:58:10	2020-08-13	Kathyrn Gutkowski	kathyrn.gutkowski@geemail.com	El Paso	Texas	4189443735056	3adc734b94f2ad158cfc9c2e6769e262	JCB 16 digit	31.808582379325852	-106.350073546681557
44503	2020-08-13 05:00:14	2020-08-13	Emmet Little I	emmet.little.i@woohoo.com	Chicago	Illinois	4556717352566969	77aad939a0f225a5fdd4424968cc4d93	Voyager	41.840513119597361	-87.6959178671270507
44504	2020-08-13 05:00:21	2020-08-13	Ibrahim Willms	ibrahim.willms@geemail.com	Des Moines	Iowa	869966466097796118	75bbae3568016772382caa81080fdf46	JCB 15 digit	41.5466190434269649	-93.6099477540746392
44505	2020-08-13 05:15:49	2020-08-13	Deonte Bogisich	deonte.bogisich@geemail.com	Los Angeles	California	869920788455678272	8233508b3e4b2b48fd9059b6f478b0c6	American Express	34.0152579649683062	-118.359757581678394
44506	2020-08-13 05:16:22	2020-08-13	Brain Stoltenberg-Lehner	brain.stoltenberg.lehner@geemail.com	Anchorage	Alaska	4487436496998913	09916685bc57d256851c47b45d74fffe	JCB 16 digit	61.0802419114142694	-149.257489504351469
44507	2020-08-13 05:21:18	2020-08-13	Electa Schroeder	electa.schroeder@woohoo.com	Mobile	Alabama	4107675207545	81f830b241fab921869ed097f12c025d	Diners Club / Carte Blanche	30.7537029900230436	-88.1003077939756167
44508	2020-08-13 05:22:28	2020-08-13	Mrs. Cristen Howell MD	mrs.cristen.howell.md@warmmail.com	Arvada	Colorado	180034919903125954	ff42ecd97dd54fb662c005c05e8104f8	Mastercard	39.9185189397249403	-105.126996422602986
44509	2020-08-13 05:29:23	2020-08-13	Georgie Douglas	georgie.douglas@geemail.com	Colorado Springs	Colorado	869980910369181535	c4b4f1380cf5e90b76bd6a23e672ec0b	Mastercard	38.85951811699681	-104.682195109982786
44510	2020-08-13 05:30:29	2020-08-13	Renard Stamm	renard.stamm@geemail.com	San Jose	California	4676759204690253	99db0b3c9552298ce7ccd9dfdf8db98d	Maestro	37.3616621940217897	-121.901055900588261
44511	2020-08-13 05:35:24	2020-08-13	Benjamine Johnston V	benjamine.johnston.v@geemail.com	Glendale	California	52234373838372513	bb2424f823684581e1d96b6d1968f631	American Express	34.2218156596399794	-118.246472581233093
44512	2020-08-13 05:36:17	2020-08-13	Sharleen Nader	sharleen.nader@geemail.com	Charlotte	North Carolina	180054725209863056	a2beeea746bad12535733df346171ced	Discover	35.2828718587543833	-80.7856247256454054
44513	2020-08-13 05:37:29	2020-08-13	Collis Ratke	collis.ratke@warmmail.com	New York	New York	869990569788230147	9dae9a381bd01db92c1a0f505a54083b	Mastercard	40.7155401866175239	-73.9991684083722561
44514	2020-08-13 05:49:43	2020-08-13	Rayshawn Reilly MD	rayshawn.reilly.md@geemail.com	Wilmington	North Carolina	6011702550436222355	a24ed1f7bf6f98b83600f5ec37c9f560	Voyager	34.3023264572311248	-77.8598866085980177
44515	2020-08-13 05:51:05	2020-08-13	Mr. Ras Thompson	mr.ras.thompson@geemail.com	Springfield	Missouri	630477949966988	2544c6a43ee7087913dc581536bc07bc	JCB 16 digit	37.1385324503023213	-93.2235975161485442
44516	2020-08-13 05:55:52	2020-08-13	Gregg Treutel	gregg.treutel@warmmail.com	Tacoma	Washington	180080955688489572	94d15b7b9382daea53e0a6ec506c52b5	American Express	47.1752041119270018	-122.453848086088158
44517	2020-08-13 05:58:32	2020-08-13	Adalynn Kovacek	adalynn.kovacek@geemail.com	Mesa	Arizona	3744473310564486	7217aae40f2fd158bb3623f63716de47	Voyager	33.4029989166330523	-111.768427732156212
44518	2020-08-13 06:01:32	2020-08-13	Keion Torp-Walsh	keion.torp.walsh@geemail.com	New York	New York	561293927822531	ccec0cd4ec3c65003af5fb9b813ea15b	Discover	40.6803779477477079	-73.9473909547913735
44519	2020-08-13 06:03:26	2020-08-13	Mrs. Kallie Reichert	mrs.kallie.reichert@geemail.com	Fullerton	California	6011969086064637547	ece5c5940b3e8cf870c2720e0bcafd98	Discover	33.918434835287556	-117.911274113200605
44520	2020-08-13 06:08:48	2020-08-13	Ms. Sharla Waters	ms.sharla.waters@warmmail.com	Phoenix	Arizona	676212100926489	b64f34abf2cddd2f2a6a9048303f2b36	Mastercard	33.5951712920263432	-111.992141838364688
44521	2020-08-13 06:08:56	2020-08-13	Fidencio Pouros II	fidencio.pouros.ii@geemail.com	Albuquerque	New Mexico	3798750288950325	d443f5e45e1f662f3c6bcfbd4708b438	JCB 15 digit	35.0962420466955791	-106.685258064332984
44522	2020-08-13 06:14:24	2020-08-13	Laurel Muller	laurel.muller@warmmail.com	San Francisco	California	3158468246304973088	7afa75ec47b5853ce85e4a352c7a5fd4	JCB 16 digit	37.7882350580261104	-122.394384045802141
44523	2020-08-13 06:14:37	2020-08-13	Myron Spencer	myron.spencer@geemail.com	Houston	Texas	3710816000513868	1b3963895d1afd007b5f197f07f8fe1e	VISA 16 digit	29.811551850250364	-95.3610438335701787
44524	2020-08-13 06:21:47	2020-08-13	Mr. Dow Schinner	mr.dow.schinner@woohoo.com	San Antonio	Texas	6011950767228551531	7034956e01a15396f6668a79ce6faed4	VISA 13 digit	29.3727237991593775	-98.5170776182155947
44525	2020-08-13 06:28:20	2020-08-13	Weston Mills-Goyette	weston.mills.goyette@geemail.com	Houston	Texas	180042199873464010	12aa379e1541a1132b192ed415c9cb34	VISA 13 digit	29.8526584811121225	-95.3207039365559865
44526	2020-08-13 06:32:14	2020-08-13	Bose Hirthe PhD	bose.hirthe.phd@geemail.com	Dayton	Ohio	3700120097327486	a6b3fdd8cadef3a2d8b8a2dd3f183331	JCB 15 digit	39.8284594951454523	-84.1665707933906475
44527	2020-08-13 06:34:16	2020-08-13	Miss Mireya Kunde	miss.mireya.kunde@geemail.com	Akron	Ohio	3337974477671767301	1384cc7a6fd422c92576dc639712842e	Mastercard	41.0945761876013123	-81.4331611310444714
44528	2020-08-13 06:35:42	2020-08-13	Dr. Bonny Gleichner	dr.bonny.gleichner@geemail.com	Phoenix	Arizona	501899911771204	d62efca62bea3207fdf22fe8db5a2001	VISA 13 digit	33.5152975963827231	-112.03604388115221
44529	2020-08-13 06:46:12	2020-08-13	Casimer Runolfsson	casimer.runolfsson@geemail.com	New York	New York	4921200907761	84d3e2b71a30a50737acce27fda02b66	JCB 15 digit	40.6665086709652073	-73.9916911363497292
44530	2020-08-13 06:53:28	2020-08-13	Flint Sporer	flint.sporer@geemail.com	Anaheim	California	4467762382746	2e945ae37b558338dc4dfcae91120161	Discover	33.9418983068149558	-117.826680613702536
44531	2020-08-13 07:00:19	2020-08-13	Janeen Considine	janeen.considine@geemail.com	Richmond	Virginia	4687726300636339	bb99d6d8c19847e7074ff5e6f13b8155	VISA 13 digit	37.4906861497774671	-77.4273576252851683
44532	2020-08-13 07:05:51	2020-08-13	Elder O'Conner	elder.o'conner@geemail.com	New York	New York	3088964483505336372	ba4d54a441668daaa3a6a7053897964a	VISA 16 digit	40.744855149159207	-73.9127959726273929
44533	2020-08-13 07:12:07	2020-08-13	Ms. Gwyneth Emard	ms.gwyneth.emard@geemail.com	Miami	Florida	210090007383191745	47f9dbe4a3b2f25cc6ebc92dfdd7b886	Diners Club / Carte Blanche	25.7130191410563889	-80.1271309761669528
44534	2020-08-13 07:16:49	2020-08-13	Kayleigh Goldner DVM	kayleigh.goldner.dvm@geemail.com	Phoenix	Arizona	4306213711965947	cf45ca81863348785c510e3081c7d163	JCB 16 digit	33.6125920042328588	-111.998924687264861
44535	2020-08-13 07:24:18	2020-08-13	Mills Stracke-Towne	mills.stracke.towne@warmmail.com	San Francisco	California	4182362200164436	b3c45c75d232b86cf93e16cfe92a6607	JCB 16 digit	37.7731193303251018	-122.428328358325459
44536	2020-08-13 07:25:59	2020-08-13	Burnice Hahn-Mohr	burnice.hahn.mohr@geemail.com	Nashville	Tennessee	3050104080548282	7b47c23cfadb52ab0df6294d030ed379	American Express	36.0951978861942848	-86.7111737911496334
44537	2020-08-13 07:38:09	2020-08-13	Miss Juanita Davis	miss.juanita.davis@geemail.com	Lubbock	Texas	3450017995059709	da6e893faca6fb4fe68ee5cebb5ee1e2	VISA 16 digit	33.6132699965074693	-101.947406445900725
44538	2020-08-13 07:45:04	2020-08-13	Miss Vada O'Reilly DVM	miss.vada.o'reilly.dvm@geemail.com	San Francisco	California	4782439157374	ed7571f3246f6ab2a88de6282385c006	VISA 16 digit	37.7786105893628203	-122.460540976419168
44539	2020-08-13 07:53:27	2020-08-13	Hayes Lynch-Crooks	hayes.lynch.crooks@warmmail.com	Meridian	Idaho	6011501793235377029	470cd2618f6b58fe06419490fb92c9f7	Voyager	43.7006600238390206	-116.394357089506087
44540	2020-08-13 07:55:05	2020-08-13	Ples Gutkowski	ples.gutkowski@geemail.com	Houston	Texas	4467140110899101	21c883a01063f1785b3a97185ac75fbd	JCB 16 digit	29.8736095965452506	-95.4032104194179169
44541	2020-08-13 07:56:06	2020-08-13	Dr. Darron Sawayn V	dr.darron.sawayn.v@geemail.com	Miami	Florida	3112733440869099202	f654f9cfc3b3528b1c653eebe3d49f62	Voyager	25.7899481791209446	-80.1896295110102812
44542	2020-08-13 07:58:28	2020-08-13	Annika Jones	annika.jones@geemail.com	New York	New York	3460917466889054	4a754d1cd0018f4ef0d8b31f8e0930eb	Mastercard	40.5659858967866711	-73.8696584875125382
44543	2020-08-13 08:09:08	2020-08-13	Rome Torp I	rome.torp.i@warmmail.com	Plano	Texas	4306951854155657	173991efe155fda457dd6070e6a838b4	JCB 16 digit	33.0754085994411255	-96.8389772130824582
44544	2020-08-13 08:20:39	2020-08-13	Sydnee Wiegand	sydnee.wiegand@woohoo.com	Chattanooga	Tennessee	4088026907953368	189c83670f84d8fa5c71fd55c99f1e33	Diners Club / Carte Blanche	34.9711176453009287	-85.1979762892998735
44545	2020-08-13 08:26:24	2020-08-13	Gale West	gale.west@geemail.com	Daly City	California	3158800444624435386	7ee29e02614776eb28ea110f07eed9fa	JCB 16 digit	37.6560157745066988	-122.450993846086789
44546	2020-08-13 08:33:09	2020-08-13	Rosie Towne	rosie.towne@geemail.com	Oakland	California	6011155235686904181	e83d527f28757b03f8a4f7e1b6e1ee07	VISA 13 digit	37.8083555053552516	-122.304069691736458
44547	2020-08-13 08:44:34	2020-08-13	Allyn Sawayn	allyn.sawayn@warmmail.com	Lancaster	California	210086230830568697	72cd6a19752aac13cab97a2e52ed3ddd	Mastercard	34.6779689596746152	-118.120144811689102
44548	2020-08-13 08:49:27	2020-08-13	Marylou Hahn	marylou.hahn@geemail.com	San Antonio	Texas	3528139312574378637	abf7e7f5d0736d88fe41b784109fae19	Maestro	29.3831348373159784	-98.4912118536721835
44549	2020-08-13 08:53:51	2020-08-13	Adriana Christiansen	adriana.christiansen@geemail.com	San Francisco	California	3058718421279877	318174702177fc59ccc5ba75f4ece1c8	JCB 15 digit	37.7952532408496467	-122.439165314179391
44550	2020-08-13 08:58:09	2020-08-13	Kathryn Schamberger	kathryn.schamberger@geemail.com	Dayton	Ohio	3491502581396509	13efc970379cab424869f287280a68a5	Voyager	39.8707634264860289	-84.259021156020836
44551	2020-08-13 09:04:27	2020-08-13	Zackary Gottlieb	zackary.gottlieb@geemail.com	Hartford	Connecticut	180011112508873379	45944a5eef424be1865bef8dcd6bbbd1	American Express	41.6738537909012337	-72.7063058509849043
44552	2020-08-13 09:09:17	2020-08-13	Dr. Edmonia Rowe DVM	dr.edmonia.rowe.dvm@geemail.com	Las Vegas	Nevada	3096794491739401389	69f2714d653f8b7522a7427280fe6e0f	Voyager	36.2184433819361047	-115.215457188591728
44553	2020-08-13 09:27:43	2020-08-13	Jules Larson	jules.larson@geemail.com	Irving	Texas	3740812711941757	7ec0f7b039905397a001e120c6eb787c	JCB 16 digit	32.8823356838382779	-96.941830982342367
44554	2020-08-13 09:43:31	2020-08-13	Mr. Rosevelt Bradtke	mr.rosevelt.bradtke@geemail.com	Colorado Springs	Colorado	6011201808315837685	fade1e4d117f3818c44af6e06aec96b8	Discover	38.9409049370840208	-104.757979247455296
44555	2020-08-13 09:52:27	2020-08-13	Hermann Denesik	hermann.denesik@geemail.com	New York	New York	180068295656237075	e7a2b00894c2dd254f04482db3ae3e3f	Discover	40.618212555743753	-73.9811922358244658
44556	2020-08-13 09:57:03	2020-08-13	Mohamed Reichert	mohamed.reichert@geemail.com	San Francisco	California	4580989226478511	2efa1dea690307cac31c7bfc5766056f	VISA 13 digit	37.7560211858153849	-122.423936988867169
44557	2020-08-13 10:01:58	2020-08-13	Maxim Hoeger Jr.	maxim.hoeger.jr.@woohoo.com	Denver	Colorado	4641416224376122	4b7543c6d888baa6b14b4ebebf22dc4d	Maestro	39.6817595098219797	-104.95209745799788
44558	2020-08-13 10:05:16	2020-08-13	Lance Jacobs	lance.jacobs@geemail.com	Peoria	Arizona	55951929522018398	88761a5142897981c822cfd647a1f498	JCB 15 digit	33.8211690318107614	-112.242290942456577
44559	2020-08-13 10:06:50	2020-08-13	Andre Ferry-Marquardt	andre.ferry.marquardt@woohoo.com	Lakeland	Florida	180002484712768849	50a7fabea71f9a2038ceedb04a52a19d	Voyager	28.1433152518533163	-82.0165002663038649
44560	2020-08-13 10:07:29	2020-08-13	Chase Kiehn-Larkin	chase.kiehn.larkin@geemail.com	Berkeley	California	3096038081523367528	ca9cb6a216c82c4de39a64e867c85636	VISA 13 digit	37.8900669789988811	-122.236741031967455
44561	2020-08-13 10:09:11	2020-08-13	Isaias Effertz	isaias.effertz@geemail.com	St. Petersburg	Florida	4917475987280	0f555cb9335a7ddb7b13ee8a426da694	Mastercard	27.8606376131419111	-82.7357570100001993
44562	2020-08-13 10:12:02	2020-08-13	Thomas Gorczany-Crona	thomas.gorczany.crona@geemail.com	San Diego	California	4742764162605	db5d32bcf380ec1ebe9d308ffad36e60	VISA 16 digit	32.8462118975419557	-117.220065948078414
44563	2020-08-13 10:15:09	2020-08-13	Chaney Dibbert	chaney.dibbert@geemail.com	Jacksonville	Florida	4676996735311161	2eae67f06423984fe15207d96f7b3087	JCB 16 digit	30.2538938982464387	-81.6481995101165126
44564	2020-08-13 10:18:53	2020-08-13	Gayle Smith	gayle.smith@warmmail.com	San Francisco	California	4154934866538329	b8cadabe5c14f536d4827d09f8f87e14	Maestro	37.7688326218010104	-122.3902480079973
44565	2020-08-13 10:26:51	2020-08-13	Analia Jaskolski	analia.jaskolski@geemail.com	New York	New York	3015290685535652	bc5123a361e8b456c1f179a63f239038	VISA 16 digit	40.7075329656470544	-73.8492974723119318
44566	2020-08-13 10:31:03	2020-08-13	Brea Bailey-Fritsch	brea.bailey.fritsch@geemail.com	Riverside	California	3044685382098303	734478be944b5f3e106ac1fe886eab30	JCB 15 digit	33.8734364821057738	-117.318372457937144
44567	2020-08-13 10:31:57	2020-08-13	Ashely Hamill	ashely.hamill@geemail.com	Riverside	California	869971560133877305	1c67d42c345aa9cfe87c9fcdb4f7f4d2	Maestro	33.9359155308403047	-117.335147381664058
44568	2020-08-13 10:48:54	2020-08-13	Angelita Frami-Schmidt	angelita.frami.schmidt@woohoo.com	Mobile	Alabama	210026368529236037	f43a6a771dc051580aa0202f933f7ce1	JCB 16 digit	30.5962446964453889	-88.1074185504715928
44569	2020-08-13 10:54:36	2020-08-13	Lennie Davis	lennie.davis@woohoo.com	Sacramento	California	3006233594290943	deb02dabe543e1fca05f9af83f58fdcf	Mastercard	38.6450927841741603	-121.526886197204135
44570	2020-08-13 10:54:42	2020-08-13	Gunner Bradtke	gunner.bradtke@warmmail.com	Philadelphia	Pennsylvania	3096021252221465737	fafaea3816bd95a77ecb46cb3170a443	Diners Club / Carte Blanche	39.962284346758949	-75.2101464279361096
44571	2020-08-13 10:56:23	2020-08-13	Ms. Annamae Kemmer	ms.annamae.kemmer@geemail.com	Bakersfield	California	51886517773101326	a03564cd8e3f5c2d2a5c66fce923e3fb	Voyager	35.3214767069730868	-118.998664100355654
44572	2020-08-13 10:57:02	2020-08-13	Porfirio Wisoky	porfirio.wisoky@geemail.com	Stockton	California	4113876407683660	769a27d0c46bfbbd74f200ce8f0d5d41	Mastercard	37.9529675488092053	-121.40149500994869
44573	2020-08-13 11:00:57	2020-08-13	Pricilla Berge	pricilla.berge@geemail.com	New York	New York	4959457306980	0f64ddd4e7816ac3f3511272092fbf29	VISA 13 digit	40.7509858196824766	-74.0340734785318375
44574	2020-08-13 11:04:44	2020-08-13	Clementina Parker-Swift	clementina.parker.swift@geemail.com	Des Moines	Iowa	3770114998685188	ac4bc2ff815fc24bb97e4cf368ff5e93	Mastercard	41.6405603531956672	-93.703181058545411
44575	2020-08-13 11:11:12	2020-08-13	Daisy Beer	daisy.beer@geemail.com	Los Angeles	California	869902288396730763	b930e04a3ab7d0f776ddfe113928e85c	American Express	33.9924474176816602	-118.442906400933111
44576	2020-08-13 11:21:55	2020-08-13	Jeryl Purdy DDS	jeryl.purdy.dds@warmmail.com	Los Angeles	California	3096085187930646297	025095e22804ea515e5310381a6a20ba	American Express	34.0854026873927509	-118.444300745892519
44577	2020-08-13 11:23:29	2020-08-13	Ms. Pairlee Runte	ms.pairlee.runte@geemail.com	New York	New York	4763127566734933	dc9caa9f32a448595caf7f66260177d1	JCB 16 digit	40.5864262572713201	-73.9752869604051142
44578	2020-08-13 11:24:19	2020-08-13	Nelda Green-Graham	nelda.green.graham@geemail.com	San Francisco	California	4815153276198191	4d2b647e927ebc742625b63fd78ce2a3	Mastercard	37.7527845160657805	-122.415680837170711
44579	2020-08-13 11:29:46	2020-08-13	Admiral Stokes	admiral.stokes@warmmail.com	Norfolk	Virginia	4445514139173614	dfe86d05d1c89d655528f4499981ebb5	JCB 16 digit	37.0050124731399137	-76.3405394070785519
44580	2020-08-13 11:37:53	2020-08-13	Cassidy Feest MD	cassidy.feest.md@geemail.com	Atlanta	Georgia	3158992736349349240	a2dd9c87e98ed157ee1f29a7ff2bc480	Diners Club / Carte Blanche	33.6692146426342447	-84.3968868884302736
44581	2020-08-13 11:41:05	2020-08-13	Arvid Christiansen	arvid.christiansen@geemail.com	Wilmington	North Carolina	4335577518196749	973ece448e6b1921a6b79f9554b6376c	JCB 16 digit	34.2971416291602011	-77.8638248828697925
44582	2020-08-13 11:44:23	2020-08-13	Kieran Collins	kieran.collins@geemail.com	North Las Vegas	Nevada	3460638282395213	208ec53e16ad057aa8389f0421c96725	VISA 16 digit	36.3129400624118759	-115.114685681670537
44583	2020-08-13 11:46:06	2020-08-13	Vern Morissette	vern.morissette@geemail.com	New York	New York	869976291549124406	1ea436b556dc5ab052ce8375351d2b2e	JCB 16 digit	40.6182239178791633	-74.0327227821469336
44584	2020-08-13 12:09:46	2020-08-13	Forest Wisoky IV	forest.wisoky.iv@geemail.com	Orlando	Florida	3049033057668990	08e38005590968fde89fafd71365658c	American Express	28.4693631501201523	-81.3722203527543684
44585	2020-08-13 12:10:30	2020-08-13	Thomasina Berge MD	thomasina.berge.md@geemail.com	Fresno	California	4322051952822116	9307bac846b80efba33cccd2aa0fe238	Mastercard	36.7876570422075702	-119.878801075286802
44586	2020-08-13 12:11:02	2020-08-13	Mrs. Celestine Abernathy	mrs.celestine.abernathy@woohoo.com	Berkeley	California	630450131708328	8ac3ff9cd11975de37d7b89ff2a72f83	Mastercard	37.8709143140891626	-122.261735851189229
44587	2020-08-13 12:14:40	2020-08-13	Lacey Rempel DVM	lacey.rempel.dvm@woohoo.com	New York	New York	4485481346669	6ceed9033ce8460d33968ea754e29861	VISA 13 digit	40.6360814468692979	-73.9257732517912984
44588	2020-08-13 12:24:49	2020-08-13	Lovell Runolfsdottir-Lubowitz	lovell.runolfsdottir.lubowitz@geemail.com	Macon	Georgia	51268558142963416	f2deec57a3c58be51bc173658b72b975	Diners Club / Carte Blanche	32.7264298755221077	-83.6357791928302419
44589	2020-08-13 12:29:35	2020-08-13	Emma Runolfsdottir	emma.runolfsdottir@warmmail.com	Montgomery	Alabama	3088743007082630945	b0325426b482ae57dee4d3be191545de	Voyager	32.3398393199246357	-86.1934819683119571
44590	2020-08-13 12:32:12	2020-08-13	Jens Boyle	jens.boyle@geemail.com	San Francisco	California	4017482121542	d3852a1445f445576bcdcd1573dd4413	VISA 13 digit	37.7620572743305942	-122.40237999228134
44591	2020-08-13 12:56:40	2020-08-13	Trinity Pacocha	trinity.pacocha@warmmail.com	Portland	Oregon	869965490836825393	37bc1bc0e2a24b05187d085b3bb7db70	JCB 16 digit	45.6282055513821518	-122.583136130450299
44592	2020-08-13 13:06:08	2020-08-13	Kasey Williamson-Kreiger	kasey.williamson.kreiger@geemail.com	Dallas	Texas	6011568494586027640	be7ca91596447b605dcab9a00e84cf19	JCB 16 digit	32.8697566744677729	-96.831363968268036
44593	2020-08-13 13:13:10	2020-08-13	Dr. Wilber Cummings	dr.wilber.cummings@geemail.com	Midland	Texas	53646006235149025	05e122f8782f8d5c6ebf74658c30086f	JCB 16 digit	31.9984088909070934	-102.082238564662632
44594	2020-08-13 13:15:21	2020-08-13	Chessie Yundt DVM	chessie.yundt.dvm@geemail.com	Phoenix	Arizona	3711062768003284	1e7c5b7a3c942ba295bb77432ea277c2	Mastercard	33.5017633656438463	-112.056792870389671
44595	2020-08-13 13:23:11	2020-08-13	Dr. Derick Langosh IV	dr.derick.langosh.iv@geemail.com	El Paso	Texas	4159676471712261	285e91568c490c99dea7db1a83857034	JCB 16 digit	31.8651142420541511	-106.385958984119824
44596	2020-08-13 13:30:15	2020-08-13	Renada Corkery	renada.corkery@geemail.com	New York	New York	4630215799843141	b3e25b2eb67c7ea9090cb98ab0d29b49	JCB 16 digit	40.7008164380434891	-73.9244794709037905
44597	2020-08-13 13:32:34	2020-08-13	Dr. Clydie Skiles	dr.clydie.skiles@geemail.com	Springfield	Illinois	4516846942582746	1e9590dc88f9755191713ef90101ccb3	Mastercard	39.8264400154970559	-89.697556168586388
44598	2020-08-13 13:40:05	2020-08-13	Arron Kuphal	arron.kuphal@geemail.com	Boise	Idaho	54130270484771680	87550841ababda7b8f27ec6c31d9c2ea	JCB 16 digit	43.528052242672814	-116.198047358888019
44599	2020-08-13 13:41:13	2020-08-13	Britt Lynch-Zboncak	britt.lynch.zboncak@geemail.com	Oakland	California	4466344952089406	0a582ffeb11a700b41c0dc9480c1eddc	JCB 15 digit	37.8322596654373839	-122.269760373824013
44600	2020-08-13 13:47:14	2020-08-13	Carnell Dicki	carnell.dicki@warmmail.com	Pompano Beach	Florida	54291423836491813	551a8473670440d4517bbc0a0f22280a	JCB 16 digit	26.3355596245996644	-80.0776266314867797
44601	2020-08-13 13:47:23	2020-08-13	Beadie Hudson-Schmeler	beadie.hudson.schmeler@geemail.com	Berkeley	California	4913202573612452	e8616ab476667db9f8e62d8639b3d86b	Diners Club / Carte Blanche	37.8470724476285696	-122.321807062615164
44602	2020-08-13 13:47:29	2020-08-13	Trevion Streich	trevion.streich@geemail.com	Charlotte	North Carolina	180056899779097615	958dc782b550214896c1248fbee0759d	Mastercard	35.204459954311325	-80.8706716287359626
44603	2020-08-13 13:48:12	2020-08-13	Miss Frida Ebert DVM	miss.frida.ebert.dvm@warmmail.com	Miami	Florida	55628410303882131	170d336f2a373d5e4b6351f2e1e74f14	VISA 16 digit	25.8654362782973806	-80.1369879730384866
44604	2020-08-13 13:48:29	2020-08-13	Cristine Rowe	cristine.rowe@geemail.com	West Valley City	Utah	3088753489928960321	354eefd9cd9d9e22e3ddad4d84b1750b	JCB 16 digit	40.6492211676891841	-112.031647566634405
44605	2020-08-13 13:55:14	2020-08-13	Marybelle Stokes	marybelle.stokes@geemail.com	Las Vegas	Nevada	6011670431490880008	64a901ffa9ea24a31a39c6846e1f6a2b	Diners Club / Carte Blanche	36.3088515228226782	-115.321342092307646
44606	2020-08-13 13:55:49	2020-08-13	Mrs. Jaylen Zboncak	mrs.jaylen.zboncak@warmmail.com	Oakland	California	3337513606504622337	189ee7adaeaece49a3f151d5a1700964	VISA 16 digit	37.8207573591074535	-122.260645453397842
44607	2020-08-13 14:08:07	2020-08-13	Linnie Keebler	linnie.keebler@geemail.com	Temecula	California	4563775167653548	044c6d6553b70484d6eb8fac35ccb28a	VISA 13 digit	33.5156922485813453	-117.199960099180032
44608	2020-08-13 14:14:22	2020-08-13	Benny Weber-Koepp	benny.weber.koepp@geemail.com	Los Angeles	California	3044345291285455	bf312a68d896d10e3c9b180e2c12fe49	Maestro	33.9318577578622822	-118.372209815447405
44609	2020-08-13 14:23:00	2020-08-13	Jazmin Pouros DVM	jazmin.pouros.dvm@geemail.com	Houston	Texas	210074033017051915	30d6bd2e9f5a960cffd2225dd3d94fbc	American Express	29.8301967531520873	-95.3415541473790995
44610	2020-08-13 14:26:46	2020-08-13	Dr. Davian Ryan MD	dr.davian.ryan.md@geemail.com	Arvada	Colorado	53420274985053977	2b353f2c7892a93d5ade50d1bd68e12c	American Express	39.8966664873238628	-105.074618795138974
44611	2020-08-13 14:32:32	2020-08-13	Jaylan Bernhard	jaylan.bernhard@warmmail.com	Irving	Texas	210069844291153475	553ea4e8a3765a21c55d2d0effe1832a	VISA 16 digit	32.7863666877567752	-96.9803270839434077
44612	2020-08-13 14:44:29	2020-08-13	Rayburn Konopelski	rayburn.konopelski@woohoo.com	Tucson	Arizona	4429890890628	2a19a1e2bbdc12ae160bce2452782720	VISA 13 digit	32.1055038876872558	-110.874947413638608
44613	2020-08-13 14:47:03	2020-08-13	Emma Hahn	emma.hahn@geemail.com	Virginia Beach	Virginia	503803495972733	5e668dae196f75541361f37539c8ba50	JCB 15 digit	36.8118363597616565	-76.1055161496296506
44614	2020-08-13 14:49:20	2020-08-13	Brittney Bartoletti	brittney.bartoletti@geemail.com	Tucson	Arizona	869971687849851934	fa73b5ac4709572a9484d363e6a46074	VISA 16 digit	32.1650104373734465	-110.946400252426415
44615	2020-08-13 14:50:24	2020-08-13	Christel Wisozk	christel.wisozk@warmmail.com	Houston	Texas	3053863807114820	8ce8f77907f54bb873d6095ca4477e14	VISA 13 digit	29.8572054984591908	-95.4749257580392054
44616	2020-08-13 14:56:10	2020-08-13	Elaine Gaylord	elaine.gaylord@geemail.com	Phoenix	Arizona	3088074629119057062	00884397baa9c7785048e458a70302ab	Diners Club / Carte Blanche	33.6381588559065037	-112.053967631088952
44617	2020-08-13 15:05:06	2020-08-13	Dr. Reino Romaguera I	dr.reino.romaguera.i@geemail.com	Madison	Wisconsin	3779638661214489	4593e84be39333f863b036b77e5dfbe5	Diners Club / Carte Blanche	43.1516562303967817	-89.4134057453252353
44618	2020-08-13 15:06:39	2020-08-13	Pete Altenwerth	pete.altenwerth@geemail.com	San Antonio	Texas	6011106471271715712	94e0eb4d85f603273fc25a9eb1d7296c	JCB 15 digit	29.5561201990652833	-98.4317998341586389
44619	2020-08-13 15:08:56	2020-08-13	Jax O'Connell-Muller	jax.o'connell.muller@warmmail.com	Nashville	Tennessee	869948088495036310	3d8133db16cf3ff337235052f2e47d51	Maestro	36.1237261217676107	-86.6945151452347602
44620	2020-08-13 15:13:34	2020-08-13	Mitchel Fahey-Gleason	mitchel.fahey.gleason@geemail.com	Sacramento	California	3158214127285811165	04ead0d261224b419274b821917bc5e3	Maestro	38.4921077765788908	-121.465343912436069
44621	2020-08-13 15:23:43	2020-08-13	Dr. Sunday Leffler MD	dr.sunday.leffler.md@geemail.com	Chesapeake	Virginia	060458607166228	7fce593f22e4536c41f38ffb588769b2	Diners Club / Carte Blanche	36.6188489370286447	-76.3618419189315318
44622	2020-08-13 16:02:31	2020-08-13	Fumiko Luettgen	fumiko.luettgen@geemail.com	Albuquerque	New Mexico	210095561106124461	3624033f2fadb0cbf9275ae0c5d0dbac	JCB 16 digit	35.1747660987678969	-106.661567330414059
44623	2020-08-13 16:10:54	2020-08-13	Afton Harber	afton.harber@warmmail.com	Phoenix	Arizona	52320663380009645	eea2917d10bca59acb0bd625e1cb6b4c	VISA 16 digit	33.6417725259371139	-112.041831000375012
44624	2020-08-13 16:21:18	2020-08-13	Rashida Gutkowski	rashida.gutkowski@geemail.com	Savannah	Georgia	3420018176689949	2386ec834c2ac72e9bd306c0b0fb18c1	VISA 16 digit	32.0867311305459566	-81.1023905754707783
44625	2020-08-13 16:37:52	2020-08-13	Dr. Nunzio Hirthe PhD	dr.nunzio.hirthe.phd@geemail.com	Syracuse	New York	869999436990343467	c9da1ae33efb7b29875916ccf2a0e623	JCB 16 digit	43.0006028496511234	-76.1020164096042606
44626	2020-08-13 16:39:13	2020-08-13	Cephus McGlynn	cephus.mcglynn@geemail.com	Toledo	Ohio	6011900527984076839	48e8908213f3e06b646cc1d14ec6509d	JCB 16 digit	41.6014759698588392	-83.6397700685873673
44627	2020-08-13 16:41:39	2020-08-13	Felix Weissnat DVM	felix.weissnat.dvm@geemail.com	Winston–Salem	North Carolina	4078420284404	f2a9ba268c2885a5bf2bb658e41c3da7	Voyager	36.1522476784184548	-80.3403647916521777
44628	2020-08-13 17:08:19	2020-08-13	Jannette Pollich	jannette.pollich@geemail.com	San Antonio	Texas	4738664157125628	c407e3734f60c2fc3cbad1d08a331d4b	Discover	29.4036579063698653	-98.6058719432283084
44629	2020-08-13 17:08:34	2020-08-13	Dr. Erland Kemmer	dr.erland.kemmer@warmmail.com	Odessa	Texas	55632131315735612	bee7b6c37e89d9e2fe13b709a2724a0c	JCB 15 digit	31.9615707983739696	-102.328540338730804
44630	2020-08-13 17:13:32	2020-08-13	Cristobal Hirthe	cristobal.hirthe@geemail.com	New York	New York	4293378327030645	ce039135d0f5508d2e217d87222f2e31	VISA 16 digit	40.7033073118180013	-73.9988725359912962
44631	2020-08-13 17:16:13	2020-08-13	Adolphus Kulas Sr.	adolphus.kulas.sr.@geemail.com	Richmond	California	4894245394710867	9fc6209abb4fca368a244b4014584574	VISA 16 digit	38.039094422799721	-122.374595682820683
44632	2020-08-13 17:28:15	2020-08-13	Mr. Ballard Hickle V	mr.ballard.hickle.v@geemail.com	Omaha	Nebraska	3414149986492147	aa3aa011708b7a0e6e90be4255e189cb	VISA 13 digit	41.361325689652567	-96.002484291384377
44633	2020-08-13 17:48:27	2020-08-13	Nat Nicolas-Moen	nat.nicolas.moen@geemail.com	St. Petersburg	Florida	4539073198883016	a42fcb1ef2f7bb272590bab25a20f763	VISA 16 digit	27.7039814991764715	-82.7213089292295223
44634	2020-08-13 17:48:43	2020-08-13	Laurene McKenzie	laurene.mckenzie@geemail.com	Boston	Massachusetts	4039498144850006	f0b201ee73f68c4f4bbfca9acf23c4dc	Diners Club / Carte Blanche	42.3992295761760332	-70.9680155539371071
44635	2020-08-13 18:03:45	2020-08-13	Clemens Bogisich	clemens.bogisich@geemail.com	New York	New York	4053558132360	72c850f3915a345255eb3e9c4714d35b	VISA 13 digit	40.7443508526999523	-73.8611373298697202
44677	2020-08-13 21:26:08	2020-08-13	Felipa Gottlieb	felipa.gottlieb@geemail.com	Berkeley	California	3158650235014686229	34a0f3dc5c25354a15244614b4093bb3	Maestro	37.8542804343254318	-122.276526619209264
44636	2020-08-13 18:05:37	2020-08-13	Courtney Wehner	courtney.wehner@woohoo.com	Philadelphia	Pennsylvania	3430681018896143	d30906d7487475dbce0beab3080da681	VISA 16 digit	40.0717200109694147	-75.2035061835676544
44637	2020-08-13 18:05:43	2020-08-13	Carlene Turner-Fisher	carlene.turner.fisher@woohoo.com	Oakland	California	869903160036684107	e6c9db9c8f5de50c4ae31557832ad46a	JCB 16 digit	37.8018808668457709	-122.274566816633012
44638	2020-08-13 18:05:43	2020-08-13	Gloria Schaden	gloria.schaden@geemail.com	Wichita Falls	Texas	3096079903464371187	7ddb45f33b2dde9d56ab57aa7b765e7b	VISA 13 digit	33.8093585299521706	-98.608765014811965
44639	2020-08-13 18:12:03	2020-08-13	Viva Collier	viva.collier@geemail.com	San Francisco	California	676112288286318	dc4d43ae8ed02838fb0dca25f8510b41	VISA 16 digit	37.7362329829151903	-122.45576812317627
44640	2020-08-13 18:12:46	2020-08-13	Delcie Morar	delcie.morar@geemail.com	Phoenix	Arizona	060405301696927	ddbdf5c78e649139bc19c94a926925de	American Express	33.4891499129056953	-112.009059308927888
44641	2020-08-13 18:13:05	2020-08-13	Hanson Homenick-Will	hanson.homenick.will@woohoo.com	Seattle	Washington	676210751492637	8ef1a91fa941601eb1c4b82e5473da38	VISA 16 digit	47.5268255057204527	-122.407830153677239
44642	2020-08-13 18:18:23	2020-08-13	Dr. Jeremey Kovacek	dr.jeremey.kovacek@geemail.com	Worcester	Massachusetts	4524626814959606	d4bf4df9e7ebab27105fc16658c805d5	Voyager	42.1961352445352844	-71.7587320993442148
44643	2020-08-13 18:21:22	2020-08-13	Elza Ledner DDS	elza.ledner.dds@geemail.com	Columbus	Ohio	4053582980170362	3de6ac9fccf73f1fd781e4e5b84c0767	Discover	40.0709010650914124	-82.9086160592038226
44644	2020-08-13 18:22:55	2020-08-13	Ms. Loreen Skiles MD	ms.loreen.skiles.md@geemail.com	New York	New York	3045375830011137	95174e9c1629c0af3cf702eabfb20063	JCB 15 digit	40.7536819064747533	-73.9986918362218802
44645	2020-08-13 18:26:16	2020-08-13	Mrs. Lou Schimmel PhD	mrs.lou.schimmel.phd@geemail.com	Los Angeles	California	210043539166344503	f92ab9260d546fe90d6901a79318d645	Discover	33.9454544966440608	-118.330010370630021
44646	2020-08-13 18:27:54	2020-08-13	Amaris Raynor	amaris.raynor@geemail.com	Pittsburgh	Pennsylvania	4361997845066	cec238a39836153e7e758df8c7a07b15	American Express	40.5025023051958541	-80.053794163156681
44647	2020-08-13 18:31:39	2020-08-13	Katelin Kuhlman DVM	katelin.kuhlman.dvm@geemail.com	San Francisco	California	3725185185079472	b2ec021c91e8eb5da406825e221674ec	VISA 16 digit	37.7779785435467588	-122.435076268802121
44648	2020-08-13 18:41:41	2020-08-13	Foy Fisher	foy.fisher@geemail.com	Raleigh	North Carolina	3462681559143427	0a70750ae7429a021c04971c7bc19a16	VISA 16 digit	35.8537615379918364	-78.5508760213323001
44649	2020-08-13 18:46:04	2020-08-13	Arlyn Wintheiser MD	arlyn.wintheiser.md@geemail.com	Grand Rapids	Michigan	3488214352151353	6822f7a3620bca31aa57710cf67d84a6	JCB 16 digit	42.9045194245211761	-85.725837301988534
44650	2020-08-13 19:01:43	2020-08-13	Una Gislason-Waelchi	una.gislason.waelchi@woohoo.com	New York	New York	180091159245736065	bfe9dec05c542a9d5044d3e8d7640a71	Maestro	40.7030092080812906	-73.8657797188393772
44651	2020-08-13 19:04:38	2020-08-13	Dulce McKenzie	dulce.mckenzie@warmmail.com	Berkeley	California	3096322421168894680	94872f83032d2cd7a5969da9f6d5517a	Discover	37.8719909966027828	-122.243567524070215
44652	2020-08-13 19:07:57	2020-08-13	Dr. Mervin Jenkins	dr.mervin.jenkins@woohoo.com	New York	New York	3528795770239813030	9ab9b9304705f2ac46898322b7338225	JCB 16 digit	40.7339028753563781	-73.98154820277243
44653	2020-08-13 19:12:19	2020-08-13	Reason Klein	reason.klein@geemail.com	Denver	Colorado	52289986993820333	d17d9ffe13397a15c4e8aa9633a4f36e	VISA 16 digit	39.8213293011352363	-104.885125316704062
44654	2020-08-13 19:19:10	2020-08-13	Cletus Jenkins-Rau	cletus.jenkins.rau@warmmail.com	New York	New York	4845745187313415	af11fe43259ad88a5272cd8b9927bab7	JCB 16 digit	40.5737276639547204	-73.8992183585546911
44655	2020-08-13 19:20:51	2020-08-13	Latifah Kautzer	latifah.kautzer@geemail.com	San Francisco	California	3021304602299922	9248142d27a9b0222d49cc9a7698286e	Voyager	37.7912125984258722	-122.431266999020892
44656	2020-08-13 19:21:11	2020-08-13	Shelley Baumbach	shelley.baumbach@woohoo.com	Los Angeles	California	3112126723709021394	48dd827a6fa2dd7866069fed4e089bd2	Diners Club / Carte Blanche	34.0149148566979918	-118.316247766091664
44657	2020-08-13 19:27:43	2020-08-13	Jeremiah Brakus	jeremiah.brakus@geemail.com	Henderson	Nevada	6011596789873416455	927f3fe4470848c0fe0d8ec075a7857e	JCB 16 digit	36.0774980997599712	-114.959638729986551
44658	2020-08-13 19:54:02	2020-08-13	Izayah Christiansen	izayah.christiansen@geemail.com	Columbus	Ohio	4382308232783667	4a18ac45c3de813f91fbc8186c2ab54a	Voyager	39.9900651853576292	-82.9636934915326663
44659	2020-08-13 19:55:34	2020-08-13	Miss Stefani Connelly	miss.stefani.connelly@geemail.com	Olathe	Kansas	4647880054736297	49a34e73201a13d5681daa92fbd1b440	VISA 16 digit	38.9298333097837883	-94.7648517398331336
44660	2020-08-13 19:57:42	2020-08-13	Nobie Mann	nobie.mann@woohoo.com	Denver	Colorado	4918954567940	42180c7c6afa45f3bccf787e7e97c1ae	VISA 13 digit	39.7387010952044264	-104.923309292948247
44661	2020-08-13 20:01:41	2020-08-13	Miss Sydnee Klein	miss.sydnee.klein@geemail.com	Buffalo	New York	180058805742029062	e9512cf4b158bbc875c52a258567f474	VISA 16 digit	42.7975674513448041	-78.8467337903034036
44662	2020-08-13 20:04:30	2020-08-13	Orrie Hermiston	orrie.hermiston@geemail.com	Chicago	Illinois	3096367184586775628	7e9380c28f14a6bd8b91196e6270c272	American Express	41.7922221824828526	-87.7710004892229989
44663	2020-08-13 20:10:12	2020-08-13	Aryan Gutmann	aryan.gutmann@woohoo.com	San Francisco	California	55802817867274844	4e641cba9a18f4ae8f1b3fcce0344ce2	JCB 16 digit	37.7784152805207825	-122.450748583624915
44664	2020-08-13 20:11:41	2020-08-13	Dr. Reagan Towne	dr.reagan.towne@geemail.com	Fort Lauderdale	Florida	4639612273667361	b22ca5a4170276584249a110f9a7c555	Maestro	26.221262231328339	-80.0923985344178959
44665	2020-08-13 20:19:00	2020-08-13	Allison Deckow	allison.deckow@warmmail.com	San Francisco	California	3337562956031432100	7bd670ec98068911bbd09d82eeeac5dd	Diners Club / Carte Blanche	37.7796432627972933	-122.415241316141888
44666	2020-08-13 20:24:32	2020-08-13	Arnav Batz	arnav.batz@geemail.com	Seattle	Washington	210057822475130455	b566b491046cf332a71139ad1223a9a1	JCB 15 digit	47.629008112793791	-122.297966133888437
44667	2020-08-13 20:35:25	2020-08-13	Eleonora Ward MD	eleonora.ward.md@warmmail.com	Syracuse	New York	53369676932037197	77c896b429ca63a65ea498395ae53334	Mastercard	43.1014836415499403	-76.0776414076112246
44668	2020-08-13 20:36:05	2020-08-13	Deonte Pacocha	deonte.pacocha@geemail.com	Chicago	Illinois	3528604274745961079	463a6aeaf0d97ce4f75f079874ffb6cf	VISA 16 digit	41.8117145829204517	-87.6234650122031553
44669	2020-08-13 20:48:50	2020-08-13	Rodney Conn-Kovacek	rodney.conn.kovacek@warmmail.com	Alexandria	Virginia	3059781952852347	4535cdb942b23003ef0212f45fcdbefb	Voyager	38.7951449983403052	-77.0320264905676311
44670	2020-08-13 20:53:18	2020-08-13	Miss Buena Doyle MD	miss.buena.doyle.md@geemail.com	Cedar Rapids	Iowa	3112592962578040979	61c46083ac5e36e70192a71303d245a1	Discover	41.8676861010100652	-91.6497494920223943
44671	2020-08-13 20:57:12	2020-08-13	Dr. Lexis Metz	dr.lexis.metz@woohoo.com	Miami Gardens	Florida	4280764167530	d3d80b4d71adcf1a6f036fc47499e276	Mastercard	25.9488275417067094	-80.2906232119783709
44672	2020-08-13 20:59:18	2020-08-13	Dr. Hiram Davis	dr.hiram.davis@warmmail.com	New York	New York	4725235563815964	2bde415f1b79a4d0e9fb89299bfe5f87	American Express	40.6056893055085055	-74.0359350575029822
44673	2020-08-13 21:04:12	2020-08-13	Cruz Feil	cruz.feil@geemail.com	Nashville	Tennessee	4712662542953530	2dff8a66360e8a4aa9b46869a480f57f	American Express	36.1448459981597949	-86.8613444501440881
44674	2020-08-13 21:09:39	2020-08-13	Donnell Rutherford-Bode	donnell.rutherford.bode@geemail.com	San Francisco	California	6011872340107682242	03007f4d7e65e99a7d565c81f095a82d	Maestro	37.7737441055480971	-122.409205862504933
44675	2020-08-13 21:25:30	2020-08-13	Julious Barton PhD	julious.barton.phd@geemail.com	Houston	Texas	3793792493586333	9cda050aadad364b34f670cf1418f0e1	JCB 16 digit	29.8480729851018651	-95.3577143178801947
44676	2020-08-13 21:25:43	2020-08-13	Wylie Willms II	wylie.willms.ii@geemail.com	Los Angeles	California	51955221009480853	06491b83413d869582c632545c7a222f	Mastercard	34.0119045219715659	-118.510672685410071
44678	2020-08-13 21:30:27	2020-08-13	Ms. Tennie Bradtke	ms.tennie.bradtke@geemail.com	Salem	Oregon	4233974179751123	abb7a7dc049027c54b5442943d7ee62f	VISA 16 digit	44.9721084406867604	-123.106598018451407
44679	2020-08-13 21:35:02	2020-08-13	Ariella Jacobi	ariella.jacobi@geemail.com	Rochester	Minnesota	3732084480535208	05e7b88539e82e92692aae50c958140a	VISA 13 digit	43.9753020542576891	-92.4240100406695149
44680	2020-08-13 21:37:27	2020-08-13	Norberto Mitchell	norberto.mitchell@geemail.com	New York	New York	55087874657764449	160015a9c91f5dd6726a2e24d9ecfb7a	VISA 13 digit	40.6914120451305052	-73.8758126578189405
44681	2020-08-13 21:40:22	2020-08-13	Rahul Morissette	rahul.morissette@geemail.com	New York	New York	3096109291373123533	8581f549202302f43cc09983b574f6d0	JCB 16 digit	40.7517559267804046	-73.9999122382968579
44682	2020-08-13 21:49:09	2020-08-13	Rafael Gaylord	rafael.gaylord@warmmail.com	San Francisco	California	6011017838664151358	1dbd1eac1f19cc80e2e8e0b38d0dc604	American Express	37.7749860853864732	-122.413335825668923
44683	2020-08-13 21:51:28	2020-08-13	Elie Rippin	elie.rippin@geemail.com	Los Angeles	California	6011630094117555277	7980d61b201acb8a83689669031af7b2	JCB 16 digit	33.9752030505664635	-118.465049595338471
44684	2020-08-13 22:00:48	2020-08-13	Reginald Quigley	reginald.quigley@geemail.com	Fort Worth	Texas	180048465147617822	55311fe70b23e2f1fc03b480ed5f9469	JCB 16 digit	32.7969432919342054	-97.3006808985777241
44685	2020-08-13 22:06:43	2020-08-13	Phillis Waters	phillis.waters@geemail.com	Boulder	Colorado	3096805554056090213	6cfd8f2f406192ec29dea24ee36c4e68	JCB 16 digit	40.0661553664114365	-105.349937002887586
44686	2020-08-13 22:09:59	2020-08-13	Dr. Ariane Macejkovic	dr.ariane.macejkovic@geemail.com	Rockford	Illinois	180092140777335095	660e48bd351a3c36ab0fb53f54e19dbf	VISA 16 digit	42.2266563348483288	-89.0301568125657781
44687	2020-08-13 22:13:32	2020-08-13	Mrs. Effa Cartwright	mrs.effa.cartwright@geemail.com	New York	New York	4508821714856	bb0ec4bfe42d8b303dfb4dd40e1e4345	Discover	40.6364090314824153	-73.9861134000018268
44688	2020-08-13 22:15:58	2020-08-13	Dr. Dorothea Pacocha MD	dr.dorothea.pacocha.md@geemail.com	New York	New York	869995096075080865	93e6a92476730bdd57a08aacef203f6a	VISA 16 digit	40.6592003687508381	-73.9139520347479646
44689	2020-08-13 22:17:56	2020-08-13	Dr. Tatsuo Hauck Jr.	dr.tatsuo.hauck.jr.@geemail.com	Henderson	Nevada	4188037714360	30c6c1822b9fd711328bda3d2d7e1aee	Maestro	36.1032608873143843	-115.050252268944689
44690	2020-08-13 22:38:10	2020-08-13	Dr. Treyton Raynor	dr.treyton.raynor@geemail.com	Richmond	California	675942231591647	70c42ef30a68a4aa6befeda85db9a836	JCB 16 digit	38.0105898351363862	-122.321992667843034
44691	2020-08-13 22:46:24	2020-08-13	Adrian Leffler PhD	adrian.leffler.phd@warmmail.com	Portland	Oregon	180042996674563134	a252abe51c20fb63461e772796e485a6	JCB 16 digit	45.5089283044338231	-122.670401819003757
44692	2020-08-13 22:58:29	2020-08-13	Ellamae Steuber DVM	ellamae.steuber.dvm@geemail.com	Albuquerque	New Mexico	180035872574439619	34c380a849be3233e2cbb3dc569c347f	Voyager	35.1687124374456701	-106.593836177426951
44693	2020-08-13 23:00:21	2020-08-13	Che Zboncak	che.zboncak@geemail.com	Charlotte	North Carolina	210091140957689775	ac57f25d39352e84deeeb59c5fc1dfd8	Voyager	35.1994463227942589	-80.8171261971294967
44694	2020-08-13 23:03:01	2020-08-13	Joleen Berge	joleen.berge@woohoo.com	Jacksonville	Florida	3041476106565774	f140a537c11786bde9c193f51add01b0	VISA 13 digit	30.4277930105157211	-81.5819321222216018
44695	2020-08-13 23:06:07	2020-08-13	Chanel Kiehn	chanel.kiehn@woohoo.com	New York	New York	3528703466665362474	421a67c1c4802b127953a0395ce3e0b6	VISA 16 digit	40.583626575464379	-73.9847421487223329
44696	2020-08-13 23:09:44	2020-08-13	Mackenzie Corwin-Turcotte	mackenzie.corwin.turcotte@woohoo.com	Los Angeles	California	6011681308530222309	7abe0fc17264c1f3e0016fd29f7e25c4	Voyager	33.9495846444141094	-118.427809582603345
44697	2020-08-13 23:17:13	2020-08-13	Wash Romaguera	wash.romaguera@woohoo.com	Los Angeles	California	3047542502702495	f32aa2a18648c4832102e8d8de9e230d	JCB 16 digit	34.0380770904343564	-118.319832164840022
44698	2020-08-13 23:18:58	2020-08-13	Devin Klocko	devin.klocko@geemail.com	San Francisco	California	4547569548305634	fd8f94956ca2e8828928e7b507f5686c	Voyager	37.7357929573229143	-122.41967692510589
44699	2020-08-13 23:24:10	2020-08-13	Shirlie Torp	shirlie.torp@geemail.com	Seattle	Washington	4635557673018802	7770c5e9a376de58ce24c4998034c2e4	JCB 16 digit	47.5363163883257656	-122.319239371914037
44700	2020-08-13 23:29:19	2020-08-13	Delmus Blick	delmus.blick@geemail.com	San Francisco	California	4268221580817	2386faa771fcc98f0f5b28d6b5eaa150	VISA 13 digit	37.7633203471019385	-122.438033925875104
44701	2020-08-13 23:30:08	2020-08-13	Dink Hahn I	dink.hahn.i@woohoo.com	Chula Vista	California	6011096723214590806	4be7dd7c3428b2834d89ba31c7451721	VISA 16 digit	32.5750756868392202	-116.972038233722373
44702	2020-08-13 23:36:00	2020-08-13	Inez Schoen	inez.schoen@geemail.com	Long Beach	California	869951296203485000	de84c13c43e27772fcd0a430eb326e8f	VISA 16 digit	33.7170733260277657	-118.242921042598041
44703	2020-08-13 23:41:03	2020-08-13	Orlando Watsica	orlando.watsica@geemail.com	Dallas	Texas	6011925349774459807	03a0d26087ba7049a8b5073076fbe3d1	Voyager	32.8816602611254893	-96.7806226724255794
44704	2020-08-13 23:45:56	2020-08-13	Denver Homenick	denver.homenick@geemail.com	Coral Springs	Florida	4817512027076691	58b3619160cee3c927dc543724abdc67	Voyager	26.3391534369967886	-80.2393704570021384
44705	2020-08-13 23:53:15	2020-08-13	Dr. Thorwald DuBuque II	dr.thorwald.dubuque.ii@geemail.com	Cambridge	Massachusetts	4467074094589729	f314cab5a91bbcea5ce10482b9dd4b50	JCB 15 digit	42.4391717246957114	-71.0562646517146419
44706	2020-08-13 23:54:17	2020-08-13	Ewart Herman	ewart.herman@woohoo.com	San Diego	California	3528127869175952916	4ad9a5d96e97aeebc7f5233fd1630ac9	JCB 16 digit	32.7558680938158204	-117.163813552344223
44707	2020-08-13 23:59:21	2020-08-13	Agnes Goyette DDS	agnes.goyette.dds@geemail.com	San Francisco	California	3337603648737527611	6323d27f305cb9ba39ad69b949ec93ff	VISA 13 digit	37.770259470102765	-122.452214245169145
44708	2020-08-14 00:02:14	2020-08-14	Glenn Nader	glenn.nader@geemail.com	Washington	District of Columbia	4246773606447429	81500ffdc1eee884b7fff40e18cb2c4d	Diners Club / Carte Blanche	38.8045628098569821	-77.0424986514009618
44709	2020-08-14 00:02:24	2020-08-14	Akira Zulauf MD	akira.zulauf.md@woohoo.com	San Francisco	California	561286833028110	105843d391248e1c4cd2e62ea17e12cc	Maestro	37.7534761427216523	-122.406417909615456
44710	2020-08-14 00:02:51	2020-08-14	Ples Ankunding	ples.ankunding@woohoo.com	Oceanside	California	180072631810627229	5596d5e306cb78c6631c8824263a7262	American Express	33.2672185140550098	-117.320685392346988
44711	2020-08-14 00:22:37	2020-08-14	Korey Boyle	korey.boyle@geemail.com	New York	New York	3051945618287101	39287be2f821893e0f4f69485d1be2cf	American Express	40.6783440301418295	-73.8390345109988004
44712	2020-08-14 00:27:45	2020-08-14	Ms. Missy Nikolaus	ms.missy.nikolaus@geemail.com	Hillsboro	Oregon	3112701304820955969	c9a16e49e89cef9866ce1e64c2a74241	JCB 16 digit	45.5888737406320885	-122.968619557439155
44713	2020-08-14 00:29:09	2020-08-14	Katelynn Smith	katelynn.smith@geemail.com	San Francisco	California	4156170702682140	3308f04a4e5a4787144dea41e7fe260b	American Express	37.7761217095003374	-122.453034374801391
44714	2020-08-14 00:34:04	2020-08-14	Vera Reynolds-Morissette	vera.reynolds.morissette@geemail.com	New York	New York	4632604667540061	f94d6696aa558b5a2a6765804758b41f	Maestro	40.756075943283733	-73.9285116982541979
44715	2020-08-14 00:40:49	2020-08-14	Krish O'Hara II	krish.o'hara.ii@warmmail.com	Los Angeles	California	869930363200727622	b95ef3bd803f3af35f24c75defb36f9d	Mastercard	34.0645702559832486	-118.338165280129004
44716	2020-08-14 00:42:20	2020-08-14	Stuart Strosin	stuart.strosin@geemail.com	Atlanta	Georgia	4200394286765	9e1087cfe4c6d6a391ddd299cc597c54	JCB 15 digit	33.8573490181282182	-84.3835426408376605
44717	2020-08-14 00:49:54	2020-08-14	Lillis Balistreri	lillis.balistreri@geemail.com	Denver	Colorado	869999189641918902	293917909c32bd8bec42b0623df6a99d	JCB 16 digit	39.7848614918585852	-104.810436229758338
44718	2020-08-14 00:51:53	2020-08-14	Mrs. Stacie Hessel DDS	mrs.stacie.hessel.dds@geemail.com	League City	Texas	3010883920600540	3d9c84eecd2016532694baab906dea67	VISA 16 digit	29.4486173906758459	-95.0238074027918316
44719	2020-08-14 01:01:40	2020-08-14	Darren Herzog	darren.herzog@woohoo.com	Albuquerque	New Mexico	52518710211919344	71037a61524725fa368508d42482bb8f	JCB 16 digit	35.1938935528643455	-106.607744985779377
44720	2020-08-14 01:07:46	2020-08-14	Thyra Corkery	thyra.corkery@warmmail.com	Palm Bay	Florida	4915598575040	894d878420852cd58ed304b4f4c584f3	JCB 16 digit	27.909849667441474	-80.7326787287671124
44721	2020-08-14 01:09:45	2020-08-14	Xiomara Ward DVM	xiomara.ward.dvm@geemail.com	St. Louis	Missouri	4516717320142	0bf47ca7648e7393c635751ba5ae0780	American Express	38.6110023520112051	-90.1966058425143444
44722	2020-08-14 01:13:43	2020-08-14	Dr. Lise Deckow	dr.lise.deckow@woohoo.com	Virginia Beach	Virginia	3049888557475778	86cd8b1a683f0cd03c6ff45bf7a4d452	Mastercard	36.7314075293205704	-76.0009501690182816
44723	2020-08-14 01:17:50	2020-08-14	Cas Becker	cas.becker@geemail.com	Elk Grove	California	4236757484484887	11b53ae1e12ea5704cff6cacd1b2e057	Maestro	38.4150045751877158	-121.324232086995622
44724	2020-08-14 01:35:05	2020-08-14	Joann Denesik	joann.denesik@geemail.com	New York	New York	3036594180000313	42530128da5a0d99795d0c2f028eb69b	American Express	40.6315913978256305	-73.8904507486045361
44725	2020-08-14 01:45:17	2020-08-14	Phil Collier	phil.collier@geemail.com	Cambridge	Massachusetts	6011572540254168902	88429838172d0102635212f8f73cc81f	Mastercard	42.3936417394541181	-71.0999242800369871
44726	2020-08-14 01:46:19	2020-08-14	Tawnya Bernier-Koepp	tawnya.bernier.koepp@geemail.com	New York	New York	3528467213947204744	038c364eb69d5a8d8d7ca6b9fc2b9bd2	VISA 13 digit	40.7107034595906754	-73.9777588242560569
44727	2020-08-14 01:52:45	2020-08-14	Jeb Dickens	jeb.dickens@geemail.com	Richmond	California	4988550469973	cd30d57c17ad082123aa72d96a342ac8	JCB 16 digit	38.0333093444306414	-122.275051692998417
44728	2020-08-14 01:53:49	2020-08-14	Drucilla Lueilwitz MD	drucilla.lueilwitz.md@geemail.com	Lincoln	Nebraska	4885708839208	d332686b4eb08f2b76c8ee4cb0aa75b7	American Express	40.7895266683325133	-96.7437382992517172
44729	2020-08-14 02:02:26	2020-08-14	Juelz Bechtelar	juelz.bechtelar@geemail.com	San Francisco	California	3031437034111693	14e67073202394b6487cf4e746e8b6fb	Mastercard	37.768793963824649	-122.409296266032612
44730	2020-08-14 02:11:28	2020-08-14	Lita Dibbert	lita.dibbert@geemail.com	Los Angeles	California	630425408590369	459e01f7e0a0afddc2387698ae1eb491	Voyager	33.9461800066620114	-118.342945308004687
44731	2020-08-14 02:15:11	2020-08-14	Consuela Olson	consuela.olson@woohoo.com	Lansing	Michigan	3337712328329588382	1e5de1d57f80fd04f325095feffde750	JCB 15 digit	42.7016372539412217	-84.4915529163211545
44732	2020-08-14 02:17:57	2020-08-14	Reinaldo Parisian	reinaldo.parisian@geemail.com	San Francisco	California	3337055909190204012	7ab234c78cfe5c082918c351d1f46191	JCB 15 digit	37.7650516840461918	-122.412035395402242
44733	2020-08-14 02:22:05	2020-08-14	Trudie Carroll	trudie.carroll@geemail.com	Honolulu	Hawaii	3431674428649961	57db6efde67f71d1ca0c14d8e76790cc	Discover	21.2348852406471984	-157.945828552425269
44734	2020-08-14 02:41:01	2020-08-14	Alleen Schumm	alleen.schumm@woohoo.com	Fargo	North Dakota	4470983024679043	883d387360a0229cdea2848424eed8f2	JCB 15 digit	46.9471819430355026	-96.8728724611885781
44735	2020-08-14 02:51:20	2020-08-14	Amina Hilll	amina.hilll@geemail.com	San Francisco	California	6011922105700491980	8e533c6b16a00079bb54add063c02ef3	Maestro	37.7937915734019469	-122.425577214107321
44736	2020-08-14 02:57:44	2020-08-14	Deasia Lowe PhD	deasia.lowe.phd@geemail.com	Los Angeles	California	502016366499370	b3eb15b83e0d82b9d9188e41e81d40b9	Mastercard	33.9802163570519511	-118.466602961625156
44737	2020-08-14 02:58:28	2020-08-14	Nanna Williamson	nanna.williamson@geemail.com	Norfolk	Virginia	3011003634090263	79987aa335a6980fef5dc4882e636f28	VISA 16 digit	36.9674345073774475	-76.1759116116449349
44738	2020-08-14 03:03:16	2020-08-14	Kalel Kulas II	kalel.kulas.ii@warmmail.com	San Francisco	California	3528379389154487839	d8c2473ef05ee7e2d2501a9c3afe2a92	JCB 16 digit	37.7932011473875775	-122.425965997168475
44739	2020-08-14 03:13:50	2020-08-14	Mr. Gregory Johnson III	mr.gregory.johnson.iii@geemail.com	Naperville	Illinois	869986455520751176	67c3941bf8f7ef230a7d1f1a79a36840	VISA 16 digit	41.8309895374726537	-88.2599578320868403
44740	2020-08-14 03:15:22	2020-08-14	Mr. Erie Jerde	mr.erie.jerde@geemail.com	San Francisco	California	180034085654453951	d577e7ab84e6b9a67f83a1935e19db79	JCB 15 digit	37.7348520644311947	-122.415236892950091
44741	2020-08-14 03:44:02	2020-08-14	Hiram Witting	hiram.witting@geemail.com	Albuquerque	New Mexico	3158131617929710336	049e38b38209514017c8d0c766ca2f1b	JCB 16 digit	35.1878536093182888	-106.602613405610995
44742	2020-08-14 03:51:08	2020-08-14	Liana Tromp	liana.tromp@woohoo.com	Chicago	Illinois	4004929315168	09043d18d3ed875025b93c47fe2aed5e	JCB 15 digit	41.7769557534087497	-87.6207670854900016
44743	2020-08-14 03:58:56	2020-08-14	Vinton Zulauf	vinton.zulauf@geemail.com	San Antonio	Texas	3088810754936101452	431075cbfd9f4a4167ec5426a4bfd04f	JCB 16 digit	29.5007114795107412	-98.4703136630657951
44744	2020-08-14 04:04:41	2020-08-14	Dr. Penny Anderson MD	dr.penny.anderson.md@woohoo.com	Gresham	Oregon	4648805566441	bf37ec7de696be7dbdcc96646dbc529f	VISA 16 digit	45.4635606098875371	-122.462258114925021
44745	2020-08-14 04:09:54	2020-08-14	Mrs. Glynis White DVM	mrs.glynis.white.dvm@geemail.com	New York	New York	3780145072824242	571d854d39f4d14e4d0db58b5f92c0d2	American Express	40.6815226050317307	-73.9539441509067927
44746	2020-08-14 04:18:00	2020-08-14	Lynn Beahan	lynn.beahan@geemail.com	Charlotte	North Carolina	4731091920350951	ace17c75930f22b7b4a48ac8cce7e7f6	VISA 16 digit	35.2408637008883048	-80.7394862734656868
44747	2020-08-14 04:18:18	2020-08-14	Makena Grant DVM	makena.grant.dvm@geemail.com	New York	New York	3112034853917052401	163cdace588bb7e278e0243402ae8285	JCB 16 digit	40.7511445281319311	-73.9100659319095286
44748	2020-08-14 04:18:35	2020-08-14	Winfield Greenfelder	winfield.greenfelder@geemail.com	Killeen	Texas	6011006280588284242	5ce1bf256e9fe5333743e771a7e0e0f6	American Express	31.1302671490468086	-97.7165398480072582
44749	2020-08-14 04:18:53	2020-08-14	Benji Treutel	benji.treutel@geemail.com	Louisville	Kentucky	3337645689660978611	df7431ce162c0b619a97026c8e4944c0	Voyager	38.2567255935069142	-85.6175491449959623
44750	2020-08-14 04:19:30	2020-08-14	Andra Treutel	andra.treutel@geemail.com	Colorado Springs	Colorado	210044145453188063	38c754035dc523a9c3acb5df751a5534	JCB 15 digit	38.7785211923580633	-104.744338184890154
44751	2020-08-14 04:20:55	2020-08-14	Jewell Sipes DVM	jewell.sipes.dvm@woohoo.com	Chicago	Illinois	869983660081784978	02feb678e72d9a334137c3064ec6e696	Maestro	41.8931423330515642	-87.6097121571686017
44752	2020-08-14 04:20:58	2020-08-14	Miss Maralyn Homenick	miss.maralyn.homenick@warmmail.com	San Francisco	California	869907422878660579	50a1500c236382784930dc740c97eafa	VISA 13 digit	37.7918998984594623	-122.397303777307897
44753	2020-08-14 04:23:04	2020-08-14	Lukas Bogisich	lukas.bogisich@geemail.com	Fremont	California	180084386978548107	11786b949026eef10ab714e16d007167	VISA 16 digit	37.4247196389064243	-122.039152333884303
44754	2020-08-14 04:49:39	2020-08-14	Kamryn Gerlach	kamryn.gerlach@geemail.com	Oklahoma City	Oklahoma	3050165174196866	56945bdae75fda43e9afa0018c0876de	Maestro	35.4315205657299614	-97.5537247413665085
44755	2020-08-14 04:52:09	2020-08-14	Katy Schamberger-Marquardt	katy.schamberger.marquardt@woohoo.com	Sacramento	California	675956522805680	6fd5d60aaa822e68ee9b704fae1fcbe2	Maestro	38.5597894032284643	-121.384300112050397
44756	2020-08-14 05:01:33	2020-08-14	Verlin Kunde	verlin.kunde@geemail.com	Clarksville	Tennessee	4224794083889236	c11432b5134caf7415ee2ad3cc33863a	Mastercard	36.4672622274268434	-87.3186934797510617
44757	2020-08-14 05:04:16	2020-08-14	Santa Kris-Labadie	santa.kris.labadie@woohoo.com	San Francisco	California	51976210994860646	63863cea2e2fb16e14201ac5c8c647ff	JCB 16 digit	37.7697424710083496	-122.451355797135491
44758	2020-08-14 05:07:32	2020-08-14	Algie Terry Jr.	algie.terry.jr.@geemail.com	Tucson	Arizona	51226855654719827	17b428158c1e726d99366abeb3c289a1	JCB 15 digit	32.1198244859505451	-110.947170777548479
44759	2020-08-14 05:08:56	2020-08-14	Mrs. Tenisha Runolfsdottir	mrs.tenisha.runolfsdottir@geemail.com	Chicago	Illinois	869912576415226146	2c53430fa84dc747edebc1fb9e83aa03	VISA 13 digit	41.8153870391961178	-87.6951540411945416
44760	2020-08-14 05:09:03	2020-08-14	Cornel Stark	cornel.stark@warmmail.com	Los Angeles	California	869902890861109652	3bd450a710cea3b963a7d846b3416283	VISA 16 digit	33.9623682303685683	-118.457043734797452
44761	2020-08-14 05:19:23	2020-08-14	Dr. Charisse Pagac	dr.charisse.pagac@geemail.com	San Antonio	Texas	4911056253113	4e40d6d2498a540432b092cbd5a8116f	Voyager	29.4718463789276797	-98.4471975254196678
44762	2020-08-14 05:35:03	2020-08-14	Mr. Sherrill Strosin	mr.sherrill.strosin@geemail.com	Jacksonville	Florida	210042314721319247	9461a3d8f84a8d627ba8dca1567434e7	Discover	30.3968093850236372	-81.7179685338012973
44763	2020-08-14 05:36:59	2020-08-14	Maricela Lebsack MD	maricela.lebsack.md@geemail.com	Oakland	California	53547291742380509	ad55e1c0290872d293f5f119fcc1e7f1	Maestro	37.789900250126756	-122.266750693201416
44764	2020-08-14 05:37:38	2020-08-14	Julie Kirlin	julie.kirlin@warmmail.com	San Francisco	California	53946838364488890	f23daa9bd3b8234cf5a95ab27f971100	JCB 16 digit	37.756390524836803	-122.441291867742464
44765	2020-08-14 05:39:38	2020-08-14	Junie Leannon	junie.leannon@geemail.com	Berkeley	California	3088283324266093964	8c50506974b1d1e1c2cf8f54abd98ad1	Mastercard	37.8537005173400729	-122.271108207378688
44766	2020-08-14 05:48:46	2020-08-14	Eugenio Watsica	eugenio.watsica@warmmail.com	Boston	Massachusetts	52524042614404894	1a22710251ca3b0142953a10cff6e114	Discover	42.2908515089824775	-70.9591365417417137
44767	2020-08-14 05:52:26	2020-08-14	Dr. Kassandra Kohler	dr.kassandra.kohler@geemail.com	Phoenix	Arizona	4554228821068	4c58c3a8ba8da59abe1c4e249eae2769	VISA 16 digit	33.5006735659137362	-112.121577244291458
44768	2020-08-14 06:00:47	2020-08-14	Dr. Jewell Halvorson	dr.jewell.halvorson@woohoo.com	Fort Worth	Texas	3496870561975161	914d96bd3585559958f87d66ca3e3fe9	Diners Club / Carte Blanche	32.7877191119417546	-97.4121418399557513
44769	2020-08-14 06:01:26	2020-08-14	Anastacia Schmidt	anastacia.schmidt@geemail.com	Berkeley	California	4602189350167188	543a686d276fafe2daa52ca5a9a4bd7f	Maestro	37.8689269988431576	-122.305252669598559
44770	2020-08-14 06:03:11	2020-08-14	Miss Ara Altenwerth	miss.ara.altenwerth@geemail.com	Elizabeth	New Jersey	502013502602918	adde697c832030f0017383d14da4c49e	VISA 16 digit	40.607221093553683	-74.2220032292827909
44771	2020-08-14 06:03:24	2020-08-14	Mr. Gideon Hilpert DDS	mr.gideon.hilpert.dds@geemail.com	Chandler	Arizona	3464477340692493	c4ad5e0f6fe9b90c826d6cabcea7e799	Diners Club / Carte Blanche	33.2748834884349236	-111.834376106166843
44772	2020-08-14 06:09:04	2020-08-14	Myron Ratke-Howell	myron.ratke.howell@geemail.com	Arlington	Texas	6011893847070507789	2bc348349ec8f927c0d0ecad8b239315	JCB 16 digit	32.7809315461914963	-97.1752535476841075
44773	2020-08-14 06:26:37	2020-08-14	Mrs. Beatriz Wiegand	mrs.beatriz.wiegand@geemail.com	Toledo	Ohio	4838596619497	884adb742ba30b90bd85a4f1d923b8bf	American Express	41.6783138873692565	-83.6004782107524562
44774	2020-08-14 06:26:48	2020-08-14	Tara Corwin	tara.corwin@woohoo.com	Oakland	California	3112318488543161149	7f07f65edc84676e11535e20eabf9e29	Voyager	37.8380523635918209	-122.271923113489322
44775	2020-08-14 06:27:22	2020-08-14	Jenny Schumm-Bogisich	jenny.schumm.bogisich@geemail.com	Aurora	Colorado	4556824736707	cefaf5cdb1f7f977e418b6ef56a36352	Voyager	39.6873081487249593	-104.733388660021873
44776	2020-08-14 06:27:30	2020-08-14	Campbell Weber-Aufderhar	campbell.weber.aufderhar@woohoo.com	Boston	Massachusetts	3711506377017689	6fa73a70677c6822d0a9814f81f58a01	JCB 16 digit	42.316079593420028	-71.0820569931946693
44777	2020-08-14 06:27:59	2020-08-14	Maren Heller	maren.heller@warmmail.com	Wichita	Kansas	3088221014720597966	f3f5c2b9ec65b34d8aef2752b13e948c	JCB 15 digit	37.6348315788775665	-97.2718823050349926
44778	2020-08-14 06:39:19	2020-08-14	Chloie Dach	chloie.dach@woohoo.com	Huntington Beach	California	4231136849079895	74c48c7471efc71a084f96e393515ed9	Voyager	33.6457141457166529	-117.950346600556003
44779	2020-08-14 06:47:17	2020-08-14	Dewayne Blanda	dewayne.blanda@woohoo.com	Sacramento	California	180026088764792037	008511403f3c4ea6e1993daf1ea4c5b8	Discover	38.5390362467881289	-121.413216212556136
44780	2020-08-14 06:50:58	2020-08-14	Berlin Ankunding	berlin.ankunding@geemail.com	Vacaville	California	4889645017464965	30053a32e43b8c3cb552467a8f9b77b5	JCB 16 digit	38.2910137673500941	-122.011445912939692
44781	2020-08-14 07:00:22	2020-08-14	Amasa Jaskolski III	amasa.jaskolski.iii@geemail.com	Glendale	California	501820647258811	cc97ab0b705b22eb0d468389f854b698	VISA 16 digit	34.2634995042100527	-118.197386824934938
44782	2020-08-14 07:00:31	2020-08-14	Richmond Rowe	richmond.rowe@geemail.com	Chicago	Illinois	3049494478139435	4c6a2287de34df1064f7d6f40359b153	Discover	41.7525076770991106	-87.6259055632196322
44783	2020-08-14 07:08:12	2020-08-14	Lovett Keebler	lovett.keebler@warmmail.com	Dallas	Texas	52316308536992809	df59c48ac236beda7b1a7b8e0f786be0	Voyager	32.7854494171489037	-96.7659382348377193
44784	2020-08-14 07:17:31	2020-08-14	Madison Toy	madison.toy@woohoo.com	San Francisco	California	3039290541037378	935aff354c3664a7393602444b7d6f5d	Discover	37.7664477859884755	-122.402094143845801
44785	2020-08-14 07:19:52	2020-08-14	Gayle Walker PhD	gayle.walker.phd@geemail.com	Cleveland	Ohio	869930643277003084	352e5665fd629757a3e6c241ffc5ec23	JCB 16 digit	41.509687913427129	-81.6345098665688198
44786	2020-08-14 07:21:05	2020-08-14	Bettye Hilpert	bettye.hilpert@woohoo.com	New York	New York	3158044621930705570	ec3cd1ec999002571458c7f025c8d599	Diners Club / Carte Blanche	40.6903581499811224	-73.9663076612062724
44787	2020-08-14 07:24:00	2020-08-14	Dr. Macey Weber DDS	dr.macey.weber.dds@geemail.com	San Francisco	California	4673039744911	d4dcbd9fbf1a625a42f4a1522a20fb46	VISA 16 digit	37.7681001708136463	-122.428672702200998
44788	2020-08-14 07:28:14	2020-08-14	Izabella Kautzer	izabella.kautzer@geemail.com	San Francisco	California	6011034058115723353	e30cc3543fd76ef43e116d5ee44a9ed8	Mastercard	37.8209814457850797	-122.400499510651926
44789	2020-08-14 07:31:56	2020-08-14	Laken Koelpin	laken.koelpin@geemail.com	Elizabeth	New Jersey	210013899625608500	b7e1c9b5d2ac5b3b85f0a89464131845	Voyager	40.6523544142615094	-74.138808876503262
44790	2020-08-14 07:39:56	2020-08-14	Konner Cassin	konner.cassin@geemail.com	Ventura	California	3112626494807492896	1f2ae3cf833db7b0036f35d77dcd553d	Maestro	34.239384001509471	-119.290523390621686
44791	2020-08-14 07:49:36	2020-08-14	Miss Ruthe Rippin DVM	miss.ruthe.rippin.dvm@warmmail.com	Corpus Christi	Texas	502061358882555	dd9442bc0126b312627f190eec933900	Discover	27.8410036063689752	-97.1772333282340384
44792	2020-08-14 07:52:16	2020-08-14	Ottie Swaniawski	ottie.swaniawski@warmmail.com	San Francisco	California	3057463382209297	3676f78d45ac4cb18a12a2533fef4b0f	JCB 16 digit	37.7777675575962135	-122.438660856540807
44793	2020-08-14 08:00:46	2020-08-14	Natalee Padberg	natalee.padberg@woohoo.com	Orlando	Florida	3049077069583960	3e93980e6d062da3782a8cc765e2a5bc	JCB 16 digit	28.4972197576224779	-81.3630328003749241
44794	2020-08-14 08:07:54	2020-08-14	Dr. Herman Sporer	dr.herman.sporer@geemail.com	San Francisco	California	3112616069761981555	1a20acdd250e925b7a86016264e05cdd	Diners Club / Carte Blanche	37.7585822287107931	-122.444843729581237
44795	2020-08-14 08:18:51	2020-08-14	Murdock Orn	murdock.orn@warmmail.com	San Jose	California	4801040164467562	1b570308c61c66d782cde0c91d448463	Voyager	37.2328736187711371	-121.840599174446979
44796	2020-08-14 08:19:05	2020-08-14	Tyrik Mante	tyrik.mante@geemail.com	Richmond	California	3096575310833006255	3470242294252b119793a70f7dc41059	JCB 16 digit	37.9325118767984222	-122.423259906409683
44797	2020-08-14 08:33:58	2020-08-14	Liston Reilly	liston.reilly@woohoo.com	Pittsburgh	Pennsylvania	210088447865179020	ac5667e0cf97b8c577fad0f3e5065b57	VISA 16 digit	40.5184761539988187	-79.9497708836741765
44798	2020-08-14 08:40:35	2020-08-14	Dr. Jovanny Williamson	dr.jovanny.williamson@geemail.com	South Bend	Indiana	869914906490817899	bf4006084c562a693210774f921cb420	JCB 16 digit	41.7531831679079701	-86.2790216551218236
44799	2020-08-14 08:41:27	2020-08-14	Yetta Parker	yetta.parker@woohoo.com	Greeley	Colorado	3112776152382081819	da437978084ec7d4c4e738180c978df1	VISA 16 digit	40.4660997364737085	-104.695101045056063
44800	2020-08-14 08:51:10	2020-08-14	Hermon Hagenes	hermon.hagenes@woohoo.com	Mesa	Arizona	869947900859065977	eeb478884350f4f2799ec2dbc5a31718	Mastercard	33.4628714272897696	-111.811951326148204
44801	2020-08-14 09:01:24	2020-08-14	Loyd Reilly	loyd.reilly@geemail.com	Milwaukee	Wisconsin	869907506965198301	efeb6d2e67d5b37f4021270bc555307f	Discover	42.9688462941061715	-87.9103196071561399
44802	2020-08-14 09:06:04	2020-08-14	Dori Harvey	dori.harvey@geemail.com	Salem	Oregon	676398945380206	145fcb634e8c8c643eb6b4a3075774bb	American Express	44.9446766805637594	-122.998726616629213
44803	2020-08-14 09:07:17	2020-08-14	Thursa Mosciski-Wilderman	thursa.mosciski.wilderman@geemail.com	New York	New York	3450178015165924	117f02127dc68e01699f8a74335b9e09	VISA 16 digit	40.645570851325985	-73.9339094438020084
44804	2020-08-14 09:08:39	2020-08-14	Lance Padberg	lance.padberg@geemail.com	Fontana	California	4154633339210900	c3473cd858e5b3ae94b04951bcdc94d0	VISA 16 digit	34.1800182448849128	-117.433438719976323
44805	2020-08-14 09:12:07	2020-08-14	Mr. Blain Lang MD	mr.blain.lang.md@geemail.com	San Francisco	California	3779804295866967	ff8543d5f2df9ed374f88920806c6afa	JCB 16 digit	37.7644570430715021	-122.414437938378597
44806	2020-08-14 09:15:46	2020-08-14	Montgomery O'Hara-Rau	montgomery.o'hara.rau@geemail.com	Boston	Massachusetts	4495201892206992	5359e8a8ea8d4709f461ae61aea5e8d0	Voyager	42.3367023311723045	-71.0204667892724331
44807	2020-08-14 09:21:11	2020-08-14	Alesha Miller	alesha.miller@geemail.com	Corpus Christi	Texas	869974279869493313	82532588df05388339fab54aacaefbf9	Mastercard	27.7408372927393785	-97.1341885764446147
44808	2020-08-14 09:21:50	2020-08-14	Levar Abbott	levar.abbott@warmmail.com	Torrance	California	4774886440735369	286bf883738f9b2878a9435eb7e00192	Diners Club / Carte Blanche	33.751623615799474	-118.377638581920039
44809	2020-08-14 09:39:40	2020-08-14	Franz Kerluke	franz.kerluke@woohoo.com	San Francisco	California	3088539976636810195	72a85da8ecb656d624b1911bcc116f19	Diners Club / Carte Blanche	37.7722545050103662	-122.422504516026336
44810	2020-08-14 09:41:36	2020-08-14	Aydan Hartmann	aydan.hartmann@geemail.com	New Haven	Connecticut	4450832026146978	9cdb593b6e801707effcc6802c974aca	Maestro	41.3291175171259795	-72.9583726278971909
44811	2020-08-14 09:44:20	2020-08-14	Ana Hirthe-Hamill	ana.hirthe.hamill@woohoo.com	Philadelphia	Pennsylvania	502019323946780	1c96002a303087a3edd21deaf61f74ee	Mastercard	40.0125168783549228	-75.1758311360508316
44812	2020-08-14 09:46:18	2020-08-14	Attilio Durgan	attilio.durgan@warmmail.com	Indianapolis	Indiana	3005681847914019	075f07529aab0475268b3471b524534c	VISA 16 digit	39.6851752511698734	-86.0954935446116991
44813	2020-08-14 09:49:15	2020-08-14	Mercedes Crist	mercedes.crist@warmmail.com	Columbus	Ohio	3472439748092148	77ab3a6acb037f8e5ccb35240855a57d	VISA 16 digit	39.9965508634269256	-82.9099702858135146
44814	2020-08-14 09:51:14	2020-08-14	Martina Eichmann-Rath	martina.eichmann.rath@geemail.com	St. Petersburg	Florida	4787057782220940	e0f86aef4d65c8514907bb139769b765	Diners Club / Carte Blanche	27.8059007830806095	-82.5639892175685617
44815	2020-08-14 09:52:45	2020-08-14	Ciarra Ullrich	ciarra.ullrich@geemail.com	League City	Texas	210094118418605124	de5f9b796b23016efaf2cbdd300abeae	VISA 13 digit	29.4270064129889022	-95.1963693571262013
44816	2020-08-14 09:57:15	2020-08-14	Manson Spinka	manson.spinka@geemail.com	Jackson	Mississippi	869935586232309960	ecf49c10497df5ce5dc674f20d5d6fbc	VISA 13 digit	32.2288347446538523	-90.2630129517030042
44817	2020-08-14 09:59:14	2020-08-14	Dr. Karissa Cartwright MD	dr.karissa.cartwright.md@geemail.com	Grand Prairie	Texas	4650263558183	e1b475aa4535d9a044a8caf537cd133d	JCB 15 digit	32.6081996379006682	-97.0750727877359907
44818	2020-08-14 09:59:57	2020-08-14	Bryce Bechtelar	bryce.bechtelar@warmmail.com	San Diego	California	3158213470897094544	b28d6277585d4ff3d2a73e74629ab98a	Mastercard	32.7310823349349178	-117.202924815975138
44819	2020-08-14 10:15:02	2020-08-14	Roll Block	roll.block@geemail.com	St. Louis	Missouri	3016442736631837	c4eecb427d9663eb0765958101c3cd0b	Discover	38.7230318023979692	-90.2766810705423381
44820	2020-08-14 10:20:14	2020-08-14	Lynn Kling	lynn.kling@geemail.com	Raleigh	North Carolina	210006534362112676	9f982d00c30bfc4e7dcdbbfe5470a834	Maestro	35.788896473976223	-78.5426134391624515
44821	2020-08-14 10:21:31	2020-08-14	Lessie Murray Sr.	lessie.murray.sr.@woohoo.com	Chicago	Illinois	6011188396980800573	08d1c4246ce169f0a253480d5d0ec892	Voyager	41.8972531684510443	-87.6093076191406652
44822	2020-08-14 10:31:16	2020-08-14	Nova Trantow DVM	nova.trantow.dvm@geemail.com	Inglewood	California	869919121551149001	13b7078afa2cc4821f2d787ce03b1822	VISA 16 digit	34.00639033580795	-118.330973862626777
44823	2020-08-14 10:34:36	2020-08-14	Spenser Ullrich	spenser.ullrich@woohoo.com	San Francisco	California	869919706998049051	e8b03428eee17edde6613536e0689fed	Mastercard	37.7591791395786487	-122.385823011764259
44824	2020-08-14 10:50:41	2020-08-14	Miss Marilee Ritchie PhD	miss.marilee.ritchie.phd@woohoo.com	Dallas	Texas	630498348901822	0002708c0deb5d3fbd042daee4d90f9d	American Express	32.7499555270459553	-96.7491434232294552
44825	2020-08-14 10:51:53	2020-08-14	Anner Casper	anner.casper@geemail.com	New York	New York	210075354593529341	c8b7864916e1fdf64ecb335ab4fcb1dd	VISA 16 digit	40.6892724910508861	-74.0087765432324289
44826	2020-08-14 11:17:39	2020-08-14	Ms. Jayme Maggio	ms.jayme.maggio@warmmail.com	Denver	Colorado	4204659364176419	c33100e79bd12e6c96fb3783a854052a	Discover	39.7682497599679934	-104.892084670976175
44827	2020-08-14 11:19:53	2020-08-14	Cassie Koelpin	cassie.koelpin@geemail.com	Clinton	Michigan	869905379291990631	b403683e70112609acb0fb69ca0e43a7	JCB 15 digit	42.6333206118617198	-82.8186637258231713
44828	2020-08-14 11:22:04	2020-08-14	Friend Mann-Monahan	friend.mann.monahan@warmmail.com	Jacksonville	Florida	4539166922320451	d6ef2535c06e809467e85b06a772a264	Diners Club / Carte Blanche	30.313703024765104	-81.6227814504023712
44829	2020-08-14 11:22:26	2020-08-14	Dr. Crawford Gleichner	dr.crawford.gleichner@geemail.com	Columbus	Georgia	3436299317067771	f4755e73b14ee0a5b3f0a4a55bc53f29	Voyager	32.5619967034596911	-84.9149801581330621
44830	2020-08-14 11:28:40	2020-08-14	Nevin Harvey III	nevin.harvey.iii@geemail.com	San Francisco	California	54582458916157551	896fb2fb208bd4ed180dee81775dc2c6	JCB 16 digit	37.7464938503489762	-122.402718506624183
44831	2020-08-14 11:29:49	2020-08-14	Rolland Gerhold	rolland.gerhold@geemail.com	New York	New York	3044715444063621	d2c9cf9c38da1a97ce4de2aa14b85b18	VISA 16 digit	40.6407655300796051	-73.9314627797704134
44832	2020-08-14 11:43:22	2020-08-14	Benson Schuster	benson.schuster@geemail.com	Bakersfield	California	210020674454639319	00412da59c619c16b3625b184e2230b7	Voyager	35.3586221961945242	-119.0101140519876
44833	2020-08-14 12:03:59	2020-08-14	Johnnie Larson-Rodriguez	johnnie.larson.rodriguez@warmmail.com	Milwaukee	Wisconsin	4575571156415437	f678665f82a9476c238ac50d268f4e87	VISA 16 digit	43.118134048729388	-88.0270477868251504
44834	2020-08-14 12:16:40	2020-08-14	Michial Lynch	michial.lynch@geemail.com	Springfield	Missouri	6011384211298032565	e11af96f1cfe2f1e30491be222a2a3c3	American Express	37.2495741862997463	-93.2749747978348296
44835	2020-08-14 12:19:11	2020-08-14	Dr. Buster O'Connell PhD	dr.buster.o'connell.phd@geemail.com	Berkeley	California	3158857012696486538	f383433a9bb864659fc2ed79778a2837	Discover	37.8694780225441292	-122.286366245480664
44836	2020-08-14 12:25:38	2020-08-14	Orie Erdman III	orie.erdman.iii@woohoo.com	St. Louis	Missouri	4218565081456261	cd94e77891729bab72e02848cd0d683a	Discover	38.7112303888116003	-90.2005259355533866
44837	2020-08-14 12:27:03	2020-08-14	Yair Rempel	yair.rempel@woohoo.com	Los Angeles	California	4481185647601357	2072fd620ecf73b3ba0e54c081d52029	American Express	34.0457614089228215	-118.387271941405899
44838	2020-08-14 12:41:53	2020-08-14	Mr. Wm Bruen	mr.wm.bruen@geemail.com	Indianapolis	Indiana	210022107617479339	28d169b2c63a35b4879a2f748b7ab3b3	VISA 16 digit	39.6840635757435081	-86.0588660720005549
44839	2020-08-14 12:44:58	2020-08-14	Soloman Armstrong	soloman.armstrong@geemail.com	New York	New York	210033563719383901	3b45e90fc43be6541d1fa5e744104415	VISA 16 digit	40.6232361406311355	-73.8833605070028483
44840	2020-08-14 12:56:05	2020-08-14	Mackenzie Veum-Gorczany	mackenzie.veum.gorczany@geemail.com	San Francisco	California	4446220204858	d928f4bca8c41bbaff66df03df1d2a6a	Diners Club / Carte Blanche	37.7544752160429979	-122.446436077747222
44841	2020-08-14 13:07:05	2020-08-14	Monna Dooley DDS	monna.dooley.dds@geemail.com	San Diego	California	6011097636904527160	851e791dc39f0b81b663b8a90dd864bf	VISA 16 digit	32.7418495375730103	-117.171394019704323
44842	2020-08-14 13:07:11	2020-08-14	Lorrie Cormier	lorrie.cormier@geemail.com	Corona	California	3059124560961285	482b089ff120a56056397ca2c607d4b0	American Express	33.8157717518396694	-117.567360901294279
44843	2020-08-14 13:09:30	2020-08-14	Dr. Darion Torp III	dr.darion.torp.iii@geemail.com	New York	New York	6011632997478961249	82f5d8d6e08ffd271b6f08baafe2a61e	VISA 13 digit	40.7009439756851634	-73.9089774415723895
44844	2020-08-14 13:15:17	2020-08-14	Dane Morar	dane.morar@geemail.com	Phoenix	Arizona	3041212960605327	512ebfd6ac0fdf1a1ae3a3599e80536b	Discover	33.5327453856289424	-112.03331060567163
44845	2020-08-14 13:37:42	2020-08-14	Leland Rohan	leland.rohan@geemail.com	San Francisco	California	210063097138799598	96c07c45877c963691c1ff428e58fc74	Voyager	37.7634761709673867	-122.416769776210018
44846	2020-08-14 13:37:52	2020-08-14	Abram Wolff	abram.wolff@warmmail.com	Minneapolis	Minnesota	4699140896960069	25f3a552cb841ce8ff2424ac4e3d2d3f	American Express	45.0547915201254128	-93.2290822421938117
44847	2020-08-14 13:39:20	2020-08-14	Dr. Esta Quitzon MD	dr.esta.quitzon.md@woohoo.com	Oklahoma City	Oklahoma	869945754509795067	ab3961542601f18c82a991289a6864b3	VISA 13 digit	35.5201415322165985	-97.539306325874108
44848	2020-08-14 13:40:04	2020-08-14	Love Bahringer	love.bahringer@geemail.com	Minneapolis	Minnesota	3758193046223925	d99482482a6181fcf6a034335fea6b86	JCB 16 digit	44.8828913733914447	-93.2406170408979023
44849	2020-08-14 13:41:50	2020-08-14	Wash Willms	wash.willms@warmmail.com	Laredo	Texas	3158070058233155202	314faf7914707c4dfc28be5b9c4a6ba0	Diners Club / Carte Blanche	27.5201383108455708	-99.4396036367405145
44850	2020-08-14 13:49:14	2020-08-14	Sammy Anderson-Zboncak	sammy.anderson.zboncak@geemail.com	Madison	Wisconsin	4926806480313270	7ed0c970309701e45843574d5ba9e218	Mastercard	43.1489033965833499	-89.5218778042938652
44851	2020-08-14 13:54:43	2020-08-14	Ivan Jenkins-Effertz	ivan.jenkins.effertz@woohoo.com	Houston	Texas	3337124623228563052	f488411ffda65818898b32592b108f0e	JCB 15 digit	29.7971969955679015	-95.321948566848036
44852	2020-08-14 13:57:16	2020-08-14	Mr. Ennis Heidenreich	mr.ennis.heidenreich@warmmail.com	Aurora	Colorado	869953392066177160	1331c12a085a228659ad2f1dc7ec1ad1	VISA 16 digit	39.7096181763447831	-104.638146230450644
44853	2020-08-14 14:02:40	2020-08-14	Sedrick Kuhlman-Mante	sedrick.kuhlman.mante@woohoo.com	Fort Wayne	Indiana	3016094228017908	62d8ad99434ad06d6b436c602140d152	Diners Club / Carte Blanche	41.1829636628989135	-85.1221384815625868
44854	2020-08-14 14:04:20	2020-08-14	Vela Weber	vela.weber@geemail.com	Lakewood	New Jersey	210023423650597310	14796921cbfd9b4bb99c3eba19134a60	Voyager	40.0531015224106639	-74.2719533607639448
44855	2020-08-14 14:06:01	2020-08-14	Dr. Edd Gerhold IV	dr.edd.gerhold.iv@geemail.com	Raleigh	North Carolina	55232880445194819	44ec78e71865762b7e780f23c751ad07	JCB 16 digit	35.8253493467014223	-78.6390272834274953
44856	2020-08-14 14:08:59	2020-08-14	Julius Schoen MD	julius.schoen.md@warmmail.com	Baton Rouge	Louisiana	210045050172513295	eba987aeef63d0a13c332ad2fc7b8707	JCB 15 digit	30.3970806277569388	-91.2304578452944668
44857	2020-08-14 14:15:30	2020-08-14	Oliver Dickens	oliver.dickens@woohoo.com	New York	New York	53664153854951401	d6e4cf1b12c0c0142690e231b4f2b913	Mastercard	40.7463617816325296	-73.8829315640859221
44858	2020-08-14 14:19:33	2020-08-14	Mozell Crona	mozell.crona@geemail.com	Mesa	Arizona	3441288527283362	84ba56f04bae1a727d9c3b0ef89b272a	Voyager	33.3352839618135235	-111.771403440262745
44859	2020-08-14 14:24:48	2020-08-14	Lloyd Kemmer	lloyd.kemmer@geemail.com	Columbus	Ohio	3464285412027567	2d2d53186688d835988a407c98a07dae	VISA 16 digit	40.0742297333709914	-82.9124845003943989
44860	2020-08-14 14:29:58	2020-08-14	Shardae Kulas	shardae.kulas@geemail.com	Chula Vista	California	4148657350358	ae5320b22fd33b70e91ca0a0cc4ac2e4	VISA 16 digit	32.6548339902654234	-117.095201872451966
44861	2020-08-14 14:32:18	2020-08-14	Mr. Emile Schmeler	mr.emile.schmeler@geemail.com	Ann Arbor	Michigan	210046346311256971	70ef3690eb15d6f59e34ef90bc45bdea	VISA 13 digit	42.3630108837563526	-83.8302026837240959
44862	2020-08-14 14:39:38	2020-08-14	Garrick Bogan	garrick.bogan@geemail.com	Indianapolis	Indiana	3158815748513639350	ecc917af37e41fb849295c619b49f4aa	JCB 16 digit	39.7606503954164694	-86.0920954743601357
44863	2020-08-14 14:41:51	2020-08-14	Lora Schowalter	lora.schowalter@geemail.com	Fort Worth	Texas	4113543317439209	85cada2d6742490ac5053cc7d59821ef	Mastercard	32.7572687828037914	-97.2690966042511178
44864	2020-08-14 15:04:01	2020-08-14	Joyce Hettinger	joyce.hettinger@warmmail.com	Irvine	California	3007541762367379	756c81f2ae4e6ca4ab3fa2d9020bc0a7	Voyager	33.7597868164084858	-117.75201780698373
44865	2020-08-14 15:24:45	2020-08-14	Alwin Kris	alwin.kris@warmmail.com	Colorado Springs	Colorado	4502788764134758	23efe682ec0fe49737901d455d265908	JCB 16 digit	38.914674108526853	-104.751951313313839
44866	2020-08-14 15:25:12	2020-08-14	Dwain Parker	dwain.parker@geemail.com	New York	New York	3096372225311210796	1a680ec226d8c522fcecc2484e7d66cf	American Express	40.5742501522637866	-74.0316910457693069
44867	2020-08-14 15:26:15	2020-08-14	Audie Hegmann	audie.hegmann@geemail.com	Berkeley	California	210085163607833823	8e3df953bcbdc965699c5efc1e4d8fbb	JCB 15 digit	37.8841449093266363	-122.282387937836091
44868	2020-08-14 15:32:18	2020-08-14	Erick Goodwin-Hauck	erick.goodwin.hauck@geemail.com	Simi Valley	California	639068284416028	f9cf51e80573f8fba49824e5f2028baf	Discover	34.3447399033471967	-118.739394557395954
44869	2020-08-14 15:38:09	2020-08-14	Delilah Wolf	delilah.wolf@warmmail.com	San Francisco	California	6011228823791912943	1649062604aae483f0eee66d29f57508	American Express	37.7609387170861908	-122.434391894462749
44870	2020-08-14 15:40:07	2020-08-14	Dr. Darryle Johnson DDS	dr.darryle.johnson.dds@woohoo.com	Portland	Oregon	4793057840960315	cff81a6476e3128e0a28b94c3085b37d	VISA 13 digit	45.4841745175309455	-122.582831898005679
44871	2020-08-14 15:41:28	2020-08-14	Dr. Allyson Waters DDS	dr.allyson.waters.dds@geemail.com	Los Angeles	California	869953536597884567	593e9cedfb48ad675079852d44e3b63e	JCB 16 digit	34.1138427043665189	-118.377177465380356
44872	2020-08-14 15:56:39	2020-08-14	Alana Marquardt	alana.marquardt@geemail.com	New York	New York	3019617301842193	21b787557c086c07bb9580cac3274935	VISA 13 digit	40.6224659941848358	-74.0299143163382922
44873	2020-08-14 15:59:34	2020-08-14	Mr. Moses Pfannerstill	mr.moses.pfannerstill@geemail.com	Orlando	Florida	4055705833774	29c2eea0c3e2afe6c1771680bca98c66	JCB 16 digit	28.3529804962951673	-81.330303921407463
44874	2020-08-14 16:02:41	2020-08-14	Amari Ryan II	amari.ryan.ii@geemail.com	High Point	North Carolina	3055784963250950	8841b750f393a45df90d23cc5f5379a3	Voyager	36.07511795005761	-79.9960209985002848
44875	2020-08-14 16:03:35	2020-08-14	Dr. Kem Zieme PhD	dr.kem.zieme.phd@geemail.com	Hialeah	Florida	3112795954192825328	9a67337efc6348223807491fd1ff5dde	Mastercard	25.8982272181637612	-80.2918431876130398
44876	2020-08-14 16:04:14	2020-08-14	Beckie Runte	beckie.runte@warmmail.com	San Francisco	California	4646332963851040	ac65abb09ed94cf88b142cd43a66f7c4	VISA 16 digit	37.7848772284241576	-122.426338420815455
44877	2020-08-14 16:05:16	2020-08-14	Kevon Bartell	kevon.bartell@geemail.com	Los Angeles	California	4066661308024	5bc27fdfd49526910edb0b1c008270e4	Mastercard	33.9651037408370513	-118.373735940595338
44878	2020-08-14 16:08:41	2020-08-14	Bertram Stiedemann PhD	bertram.stiedemann.phd@geemail.com	New York	New York	55619705367173587	90a2c79a676a5f9b06fb9c1b572a54c0	American Express	40.6466089078448718	-74.0293434786971574
44879	2020-08-14 16:13:03	2020-08-14	Andre Lowe II	andre.lowe.ii@woohoo.com	Virginia Beach	Virginia	3741922032609568	4d61b86b3795e76860cc4bf86d24b0c4	VISA 16 digit	36.8074862337857525	-76.1077444857589853
44880	2020-08-14 16:15:20	2020-08-14	Jarett Mraz	jarett.mraz@geemail.com	Cincinnati	Ohio	4147527722222193	f4cd43b313670c6673941416cc3ab80e	Maestro	39.2391994423929589	-84.5057348848592369
44881	2020-08-14 16:28:14	2020-08-14	Lindsey Watsica-Konopelski	lindsey.watsica.konopelski@woohoo.com	Cincinnati	Ohio	4081084414034195	9e18f2802a9cae90cddc15ba604ec225	American Express	39.1905237082622975	-84.4904477854531137
44882	2020-08-14 16:38:03	2020-08-14	Dr. Pratt Huel III	dr.pratt.huel.iii@geemail.com	Houston	Texas	676371383217883	ed48732d554f87e7f064f7dc3d6720d7	JCB 16 digit	29.8449641030825674	-95.488651320572572
44883	2020-08-14 16:44:07	2020-08-14	Julien Hand	julien.hand@geemail.com	Worcester	Massachusetts	3736578564999681	7aa8d84c9bee324399d278289506942f	JCB 16 digit	42.1892194288950435	-71.8120633761186156
44884	2020-08-14 16:45:47	2020-08-14	Niles Greenholt	niles.greenholt@geemail.com	Waco	Texas	3042748099609135	c2e07a61b90e0fda3c0733d90ba343ed	JCB 15 digit	31.4756096753966048	-97.0944341024048754
44885	2020-08-14 16:46:33	2020-08-14	Dora Kozey	dora.kozey@warmmail.com	San Diego	California	6011067551226410993	797a49a5ca7cf203c8c4ef3d9121786a	JCB 16 digit	32.8044726034227736	-117.229408328318968
44886	2020-08-14 16:50:45	2020-08-14	Lolla Schultz-Herman	lolla.schultz.herman@woohoo.com	Chicago	Illinois	3337611568349167624	a5db9afe4eabaaafa71499f7684f6f60	Voyager	41.8611535057261577	-87.7663797001384154
44887	2020-08-14 16:54:04	2020-08-14	Mr. Cole Price	mr.cole.price@geemail.com	Salinas	California	210020621007950123	78b1e83ca1733fc568ca44eed2246811	Voyager	36.745977908861633	-121.579180629382662
44888	2020-08-14 17:07:45	2020-08-14	Dema Rowe	dema.rowe@geemail.com	Columbus	Ohio	869906639788680030	b13f3b3dd42ad549c57dce69df4ef546	VISA 16 digit	39.9198863974351426	-83.0327037348646684
44889	2020-08-14 17:12:06	2020-08-14	Dr. Jaxson Durgan Jr.	dr.jaxson.durgan.jr.@geemail.com	Joliet	Illinois	180027170557857737	8bd9e32627f9fb9678f677238d34519e	VISA 13 digit	41.549409920382125	-88.2166166837897094
44890	2020-08-14 17:17:43	2020-08-14	Greggory Abshire	greggory.abshire@woohoo.com	Kent	Washington	869920767193984192	60c858413c7bb619e8b4f21d39ee833b	Diners Club / Carte Blanche	47.3269350532554043	-122.227560172988845
44891	2020-08-14 17:21:25	2020-08-14	Dr. Mont Huel MD	dr.mont.huel.md@geemail.com	Austin	Texas	3043481197790255	6bf102f47ba635e53d6691a28bb0f820	Maestro	30.321114444465934	-97.7955934123840223
44892	2020-08-14 17:33:59	2020-08-14	Wayland Reinger	wayland.reinger@woohoo.com	San Francisco	California	4937040660717	a4ce4acbef5e19fb93990a8d8b716384	Diners Club / Carte Blanche	37.7907897554710246	-122.466222212236048
44893	2020-08-14 17:36:04	2020-08-14	Mr. Kieran Wintheiser	mr.kieran.wintheiser@geemail.com	Lowell	Massachusetts	6011527802810773310	34ff714c157cc7e3426bc513b5e923bd	Voyager	42.6278412252999885	-71.4037456261798695
44894	2020-08-14 17:38:29	2020-08-14	Ciarra Mayer-McKenzie	ciarra.mayer.mckenzie@warmmail.com	Stockton	California	3028308637590760	3df2436ad10440a5ba7fd0c06dd5e1f8	Mastercard	38.0200259590718943	-121.228776962132372
44895	2020-08-14 17:51:08	2020-08-14	Chaney Gaylord	chaney.gaylord@geemail.com	Sioux Falls	South Dakota	3018738658922213	766672cfc7e8f2584da3b4b08d1941c1	VISA 13 digit	43.4412728458728665	-96.7153832192700378
44896	2020-08-14 18:04:27	2020-08-14	Adolfo Goodwin	adolfo.goodwin@warmmail.com	Irving	Texas	869990152427924444	cb89e2faa7e8ee15d2373091d61aedbf	VISA 16 digit	32.8977540994480293	-96.9541488822828939
44897	2020-08-14 18:06:07	2020-08-14	Carnell Koss	carnell.koss@geemail.com	Oakland	California	3010541009038111	469a7ed98bd7148e8e8b0178c80372b7	Voyager	37.7958390746861923	-122.278486370936605
44898	2020-08-14 18:06:47	2020-08-14	Geraldine Renner-Heaney	geraldine.renner.heaney@geemail.com	Dallas	Texas	3422701218426853	8dc190c4206c7f74d54588e69b44b244	Mastercard	32.7990816842105275	-96.6961160005032951
44899	2020-08-14 18:30:54	2020-08-14	Alison Gusikowski	alison.gusikowski@geemail.com	Philadelphia	Pennsylvania	869962378833383594	7688ae7ed4512ae439ad5b424030caef	VISA 16 digit	40.0005443911027143	-75.174481826405227
44900	2020-08-14 18:31:05	2020-08-14	Miss Danyelle Tremblay	miss.danyelle.tremblay@geemail.com	San Francisco	California	589316985692553	2f6a9d9e5ee8a8c767f6addfda22ed1c	Diners Club / Carte Blanche	37.7540932097164443	-122.456845635151538
44901	2020-08-14 18:34:35	2020-08-14	Edie McKenzie	edie.mckenzie@geemail.com	Charlotte	North Carolina	3439102164563263	a159e2b85758705bdde5e64457281f60	JCB 16 digit	35.1483630861408969	-80.8571739574372828
44902	2020-08-14 18:35:47	2020-08-14	King Leannon DVM	king.leannon.dvm@woohoo.com	Ann Arbor	Michigan	210015689237568251	61449dc246ca778f9dbd71195140cca1	VISA 16 digit	42.3015680093843471	-83.6421454261165138
44903	2020-08-14 18:36:16	2020-08-14	Roscoe Johnson	roscoe.johnson@geemail.com	Philadelphia	Pennsylvania	53616726073707768	bd9327155d0872881f6014711ad8c468	Voyager	39.974367171754686	-75.2228883988589132
44904	2020-08-14 18:36:31	2020-08-14	Edwin Kuhlman-Schultz	edwin.kuhlman.schultz@warmmail.com	Waterbury	Connecticut	3337851546319878932	10158c436cca5a053559fee9657cb49a	VISA 13 digit	41.5378479443527766	-72.9808175225656441
44905	2020-08-14 18:45:39	2020-08-14	Alesia Mueller	alesia.mueller@geemail.com	Tyler	Texas	869984612208758244	eee4439d71fb75ff7f0f8c00571b0f96	VISA 16 digit	32.320161145650971	-95.3721666270043613
44906	2020-08-14 18:50:02	2020-08-14	Miss Louella Russel	miss.louella.russel@geemail.com	Wilmington	North Carolina	3037313174115527	443fb276fb63343b082f594db3ab1059	American Express	34.18758143948466	-77.9790619879487963
44907	2020-08-14 18:52:02	2020-08-14	Fuller Lind Sr.	fuller.lind.sr.@geemail.com	San Francisco	California	4846695812897	28d5af80ef5fd66f9c84a0bef8893785	American Express	37.7771091271459198	-122.420670808999091
44908	2020-08-14 18:54:39	2020-08-14	Wilhelm Hermiston	wilhelm.hermiston@geemail.com	Fullerton	California	6011508728937246539	1a3deb23a7e48abd1abc6d54180d3a81	Voyager	33.9005831722792266	-117.912163468284533
44909	2020-08-14 18:54:40	2020-08-14	Miss Valery Rutherford	miss.valery.rutherford@warmmail.com	Savannah	Georgia	54918820260334265	e2032eb69890a8d19b7e43080dc488eb	JCB 16 digit	32.0696258125919798	-81.1268487843837534
44910	2020-08-14 18:59:53	2020-08-14	Lucy Von	lucy.von@geemail.com	Rialto	California	676318362787923	8e2b14b4c4e6e18abda87562d1f39028	Discover	34.1150772646285603	-117.476828974493969
44911	2020-08-14 19:01:38	2020-08-14	Rex Von-Fadel	rex.von.fadel@geemail.com	Chicago	Illinois	4617721568302	500bd23ea86e3abd30ed1087f570bf08	Discover	41.8049963014036408	-87.6686314365856276
44912	2020-08-14 19:03:24	2020-08-14	Oda Schneider	oda.schneider@geemail.com	Nashville	Tennessee	3499576032702681	c1d20bbc624f065e54dd151802ecd3aa	VISA 16 digit	36.0928445450153177	-86.8732283269893344
44913	2020-08-14 19:08:13	2020-08-14	Hebert Kuhic	hebert.kuhic@geemail.com	Berkeley	California	3096478378371558845	03dcd6758c6ad6c828890a6c84130651	VISA 13 digit	37.8292822460570619	-122.266812491509526
44914	2020-08-14 19:13:18	2020-08-14	Grant Roob	grant.roob@geemail.com	Albuquerque	New Mexico	3053185949456806	fa5bd91a948cc6b33129c209f343e1fb	Discover	35.169508144785091	-106.709935210000353
44915	2020-08-14 19:16:17	2020-08-14	Mr. Lim Bailey	mr.lim.bailey@geemail.com	Irvine	California	6011384355736964069	b9c157782d3e157d7ac8f50d179efb5e	VISA 13 digit	33.612038844871897	-117.857831866993749
44916	2020-08-14 19:20:49	2020-08-14	Tess Kilback-Kovacek	tess.kilback.kovacek@geemail.com	Provo	Utah	4756768502250408	23108562ce2e1c6cc0b8b7f75e394882	American Express	40.2408834601540093	-111.636534353033824
44917	2020-08-14 19:23:35	2020-08-14	Mont Schinner	mont.schinner@geemail.com	San Francisco	California	4194976744635902	a60e22b1c585abe9bf74eb2ed485c3d7	Voyager	37.7862002029480664	-122.384134642790428
44918	2020-08-14 19:24:42	2020-08-14	Chelsie Kunde	chelsie.kunde@woohoo.com	San Francisco	California	589393669225554	39e8936a318241ba23d2e0bc22f385e8	JCB 16 digit	37.7602641163466615	-122.427368003858106
44919	2020-08-14 19:27:32	2020-08-14	Gael Pfeffer	gael.pfeffer@woohoo.com	Westminster	Colorado	6011681683624947924	c34f46c41fc4d8e35a8f020fbc5b0879	JCB 16 digit	39.8652064305104261	-105.03390304103084
44920	2020-08-14 19:32:57	2020-08-14	Miss Verena Franecki	miss.verena.franecki@warmmail.com	San Francisco	California	210036701399624148	72352d4f3df193f0b5841b6bdd834c7c	American Express	37.8063732891938429	-122.449777703052902
44921	2020-08-14 19:40:54	2020-08-14	Kortney Pfannerstill	kortney.pfannerstill@geemail.com	Birmingham	Alabama	3005101854063931	7a989f486d2afbea28b826aee9db5a57	Diners Club / Carte Blanche	33.5742919470440597	-86.8673938560541785
44922	2020-08-14 19:45:30	2020-08-14	Miss Phebe Huel DVM	miss.phebe.huel.dvm@geemail.com	Raleigh	North Carolina	51452275244404860	2b5fee292627aa3e7ed35be55bfb3092	VISA 16 digit	35.9122210040822623	-78.6957803206454969
44923	2020-08-14 19:54:46	2020-08-14	Ruben Kerluke	ruben.kerluke@geemail.com	Sterling Heights	Michigan	869955259928046040	716b98e370178966070805918d440006	JCB 16 digit	42.6589604142203953	-83.096062573201209
44924	2020-08-14 19:57:29	2020-08-14	Damion Denesik	damion.denesik@geemail.com	Chicago	Illinois	4274583663457541	7a414b4c926db045b84900f37527d732	Mastercard	41.7727755884010392	-87.6041598961252674
44925	2020-08-14 20:10:25	2020-08-14	Sing Dickinson II	sing.dickinson.ii@geemail.com	San Francisco	California	3112029493565827239	9d3ae791e5d6aedcccff45afce290240	Mastercard	37.7508065168150182	-122.443691955308751
44926	2020-08-14 20:26:58	2020-08-14	Price Botsford	price.botsford@geemail.com	San Francisco	California	4092937223319684	8839144446fa013b08099d0988b99bab	JCB 15 digit	37.7892898955134839	-122.403788802979747
44927	2020-08-14 20:33:41	2020-08-14	Charlene Towne-Schimmel	charlene.towne.schimmel@geemail.com	Tulsa	Oklahoma	3088236373714368054	be9a5b6df5f20b08eef77eee46f9686a	Diners Club / Carte Blanche	36.2235769468262774	-95.8818637844130421
44928	2020-08-14 20:39:26	2020-08-14	Beckham Kreiger	beckham.kreiger@geemail.com	San Francisco	California	53818935506644623	0f2ba2efe5622b46d01bc7d06c87b35b	JCB 15 digit	37.7682329304892122	-122.430271183094533
44929	2020-08-14 20:50:01	2020-08-14	Mariam Rempel-Lakin	mariam.rempel.lakin@woohoo.com	Columbus	Ohio	55474432743667612	7cb2f749d9050eb6f69ed4a739ee84a2	JCB 15 digit	39.9111917465038601	-82.9080827228494002
44930	2020-08-14 20:52:33	2020-08-14	Paris Baumbach-Medhurst	paris.baumbach.medhurst@geemail.com	Chula Vista	California	3088440706537153769	9a55bdb7c88c6fcdb7384746a1cfaa7c	Voyager	32.5988066550575155	-117.107682681944965
44931	2020-08-14 20:59:14	2020-08-14	Rhys Oberbrunner-Batz	rhys.oberbrunner.batz@geemail.com	Grand Prairie	Texas	4061522003153	9a095100044d95ba85aa7b6ea2ed95a3	American Express	32.774841587856038	-96.9841205289926478
44932	2020-08-14 21:07:13	2020-08-14	Dr. Willie Kirlin DDS	dr.willie.kirlin.dds@geemail.com	San Antonio	Texas	4992955403764520	31b5e7030ef00f6a83027665b1a485f3	VISA 13 digit	29.5167066562525946	-98.5358889577280621
44933	2020-08-14 21:10:28	2020-08-14	Nolen Wuckert	nolen.wuckert@geemail.com	San Diego	California	4911209467452665	003c7d5924a539efe830df19a61362cb	JCB 15 digit	32.7795117055133005	-117.191844094023111
44934	2020-08-14 21:17:34	2020-08-14	Mustafa Weimann	mustafa.weimann@geemail.com	Denver	Colorado	210040909727687471	2babecf4691b2540881170fa6f0c024b	JCB 16 digit	39.674676423338795	-104.804655741645405
44935	2020-08-14 21:19:04	2020-08-14	Vonetta Blanda	vonetta.blanda@geemail.com	Lincoln	Nebraska	4808026388327297	4c60fdb86ca525dafda53913117af490	VISA 16 digit	40.8945764044783999	-96.6282491966776576
44936	2020-08-14 21:19:37	2020-08-14	Madison Hartmann	madison.hartmann@geemail.com	Philadelphia	Pennsylvania	3005151613403456	cb2c3efdf312f3984220900330a5985e	Voyager	39.9288856942631298	-75.1057975453224032
44937	2020-08-14 21:21:01	2020-08-14	Carlisle Lowe	carlisle.lowe@woohoo.com	New York	New York	3096884250467270791	c40a9675466b6b69fd6e917f22c7fb67	JCB 15 digit	40.6810449203234157	-73.9831057815708135
44938	2020-08-14 21:24:06	2020-08-14	Ms. Icey Hagenes DVM	ms.icey.hagenes.dvm@geemail.com	Warren	Michigan	869951376469272829	9739f583becc35f448171223de1f2085	Maestro	42.5878332583229948	-82.9322959446348307
44939	2020-08-14 21:27:17	2020-08-14	Thyra Heller	thyra.heller@geemail.com	New York	New York	3007632045357806	21ffde356ef0a4e0f7f060190d8ac856	Voyager	40.5693969928417317	-74.0008052757836907
44940	2020-08-14 21:35:22	2020-08-14	Miss Bristol Fay	miss.bristol.fay@geemail.com	Los Angeles	California	3456532521136270	09e1c6010577498962d0a312b5adf867	Voyager	34.0153441802464371	-118.415335428201772
44941	2020-08-14 21:44:46	2020-08-14	Leamon Mosciski	leamon.mosciski@geemail.com	Springfield	Missouri	4412685053154886	46627433ecf22eeb53bfdd68695c3077	JCB 16 digit	37.1137974729955218	-93.2140572425734319
44942	2020-08-14 21:49:30	2020-08-14	Lemon Sipes	lemon.sipes@geemail.com	Brownsville	Texas	3158756456684320435	5ed210f8ca6bc2abdf5c0dbbef3928fd	JCB 16 digit	26.0211819973386795	-97.425771420141686
44943	2020-08-14 22:00:01	2020-08-14	Harden Pfannerstill	harden.pfannerstill@woohoo.com	San Antonio	Texas	869987941162307988	6a9e581869a860cd5777261d7d237206	JCB 16 digit	29.4047889451101412	-98.4749959828168073
44944	2020-08-14 22:12:18	2020-08-14	Knute Smitham	knute.smitham@geemail.com	Green Bay	Wisconsin	060406809536789	523676b9e4ccea9590037d7d89e034f8	JCB 15 digit	44.5896710265956813	-87.8992043161585883
44945	2020-08-14 22:21:11	2020-08-14	Mr. Donovan Gibson	mr.donovan.gibson@geemail.com	Saint Paul	Minnesota	3528972518183539282	d68967803b7c633516851d89b6eb6aae	JCB 16 digit	44.8532447338044662	-93.0370692913219415
44946	2020-08-14 22:32:49	2020-08-14	Steve Grady	steve.grady@woohoo.com	Long Beach	California	4796839765785349	b06f0d8f6bba35f9c42bc925c30fe007	American Express	33.842897338355705	-118.08422247675918
44947	2020-08-14 22:33:36	2020-08-14	Mahala Robel	mahala.robel@warmmail.com	Escondido	California	54449549963092692	4ef6d5ef7576b925c6d26e59c0ddded4	VISA 16 digit	33.0887058584246745	-117.141325029801578
44948	2020-08-14 22:49:16	2020-08-14	Dr. Kahlil Konopelski	dr.kahlil.konopelski@geemail.com	Los Angeles	California	4601593494645374	b981988a10a52bf2852965a32e7e44bd	American Express	33.9705089700274172	-118.506874350038544
44949	2020-08-14 22:51:52	2020-08-14	Aubrey Witting	aubrey.witting@geemail.com	Louisville	Kentucky	869925342222214089	84cc1a6c88c7c35dc61b7bac6245bfbc	VISA 13 digit	38.254665690091997	-85.6589363118238794
44950	2020-08-14 22:55:37	2020-08-14	Chrissy Casper	chrissy.casper@woohoo.com	Los Angeles	California	54310207431511894	a91c18dec9d3bbd6639a656522237238	Mastercard	33.9555581935081605	-118.506269132950521
44951	2020-08-14 23:03:02	2020-08-14	Lidie Hirthe	lidie.hirthe@woohoo.com	Provo	Utah	3027613203174241	2d2722a3165b48a2d688bd93be6a8148	Mastercard	40.2989394299007984	-111.640885159713406
44952	2020-08-14 23:07:00	2020-08-14	Dr. Rebeca Barrows MD	dr.rebeca.barrows.md@geemail.com	Chicago	Illinois	3337157029610644940	f7dff30a8dfed70d42795da65dffe2ff	American Express	41.8128323515713234	-87.6575918140385255
44953	2020-08-14 23:10:29	2020-08-14	Orvis Torp-Parker	orvis.torp.parker@woohoo.com	Fargo	North Dakota	676168306820728	c1c479b5b04eadba76ed24c4633a6c05	Maestro	46.9644283864412486	-96.7674253912605309
44954	2020-08-14 23:16:19	2020-08-14	Karlie Mills	karlie.mills@woohoo.com	San Francisco	California	4876181860790400	bb25812b504c20beda5a4340c1c122ff	JCB 15 digit	37.7478314376290243	-122.457029816598251
44955	2020-08-14 23:16:28	2020-08-14	Willard Trantow	willard.trantow@geemail.com	San Francisco	California	210009029383380011	92adfdffe5e415bbc73fcc438462c5a4	JCB 16 digit	37.7843343301873844	-122.481989101621309
44956	2020-08-14 23:26:04	2020-08-14	Dr. Gerry O'Connell	dr.gerry.o'connell@geemail.com	Cleveland	Ohio	3088454570594478219	4a605e57fc14c082eda0245aa87c5167	VISA 16 digit	41.4012086865343107	-81.6381618567515233
44957	2020-08-14 23:29:45	2020-08-14	Dusty Weimann-O'Connell	dusty.weimann.o'connell@geemail.com	San Francisco	California	4207990179686228	85cd00274e2f515bea323d71df1dd168	Diners Club / Carte Blanche	37.7612637029051683	-122.431262319508477
44958	2020-08-14 23:36:42	2020-08-14	Miss June Smitham	miss.june.smitham@warmmail.com	Detroit	Michigan	4414842152809062	2c5efaeaff017427517ac0f919439914	JCB 16 digit	42.3295111097320955	-83.0700572759963478
44959	2020-08-14 23:38:58	2020-08-14	Dr. Buel Lehner	dr.buel.lehner@woohoo.com	Manchester	New Hampshire	4507658790377678	fa9fe1e1981a9e52d4db0b47e9807e3d	American Express	42.941318322958054	-71.4109811135925412
44960	2020-08-14 23:41:59	2020-08-14	Ms. Vikki Hoeger DVM	ms.vikki.hoeger.dvm@warmmail.com	Houston	Texas	630496727569061	2eeb290107e4c69566121c6ec0c7ad84	VISA 13 digit	29.7413410406637944	-95.4700191171389037
44961	2020-08-15 00:01:37	2020-08-15	Lavern Emmerich DVM	lavern.emmerich.dvm@woohoo.com	New York	New York	4530067042898765	d82ae561f5f5d53fa12d45cdd054eed1	JCB 16 digit	40.6645717857163405	-73.9625478337880224
44962	2020-08-15 00:02:47	2020-08-15	Robin Rowe II	robin.rowe.ii@woohoo.com	Detroit	Michigan	630451847092585	7e4b432ea53d851e60379c41d76fb581	JCB 15 digit	42.2991405730992582	-83.0038079356893803
44963	2020-08-15 00:08:48	2020-08-15	Darrell Romaguera	darrell.romaguera@woohoo.com	Indianapolis	Indiana	869966403478944629	880c927d11bdb113f49e29fb9687133f	VISA 13 digit	39.7710049951922144	-86.14094592260345
44964	2020-08-15 00:15:24	2020-08-15	Denzell Marks	denzell.marks@geemail.com	Albuquerque	New Mexico	6011070388928355654	5046cc6652e8dc52d0e05d7cdba8d22d	JCB 16 digit	35.1454514076136064	-106.557455292909964
44965	2020-08-15 00:19:29	2020-08-15	Doll McClure Jr.	doll.mcclure.jr.@geemail.com	Virginia Beach	Virginia	52899217118736192	21dd4d1ed190e49a0140745635a4542e	Maestro	36.7163171163015107	-75.9416684846997185
44966	2020-08-15 00:20:36	2020-08-15	Holly Spinka	holly.spinka@geemail.com	San Francisco	California	869985432182966252	3167032e7b8ad297fa3fc3e19eb4ae73	JCB 16 digit	37.7742826010147255	-122.445573417584413
44967	2020-08-15 00:21:28	2020-08-15	Ogden Homenick	ogden.homenick@geemail.com	Salem	Oregon	3759931376883217	df036c59b5d295495946f67bfcbecc45	Voyager	44.8753001908108544	-123.111590540424743
44968	2020-08-15 00:29:07	2020-08-15	Dr. Humberto Trantow	dr.humberto.trantow@warmmail.com	Dallas	Texas	210060319011210003	0948309d98bb6a26de960fdbd572ac46	Maestro	32.6940265709806255	-96.8023910331036888
44969	2020-08-15 00:32:12	2020-08-15	Jeffery Aufderhar	jeffery.aufderhar@geemail.com	Inglewood	California	3528681459852104821	4b996454e5bb7f163961e206c52d0609	JCB 15 digit	33.9664202214464552	-118.338429706965769
44970	2020-08-15 00:36:44	2020-08-15	Rosalee Grant	rosalee.grant@geemail.com	Peoria	Arizona	3053964597416738	beaea91a9ed7a8addcbefe0727e48d97	JCB 16 digit	33.8206445525668542	-112.288457544978712
44971	2020-08-15 00:38:57	2020-08-15	Shanna Adams	shanna.adams@woohoo.com	New York	New York	3158246682841671208	77d2e470a8b37e47e832dac7a9133bfb	VISA 16 digit	40.6687582100965059	-73.9679193118482772
44972	2020-08-15 00:40:28	2020-08-15	Jami Lang	jami.lang@geemail.com	Tallahassee	Florida	3096959240421734925	2a44b894bb68073aafcaf04812bf799c	JCB 15 digit	30.4012825358681411	-84.3510700769271722
44973	2020-08-15 00:41:02	2020-08-15	Lillian Davis	lillian.davis@warmmail.com	Fontana	California	180009524753506930	297c7e119a1d8240b69f178f86ac8054	Maestro	34.2058470607418599	-117.501551715684684
44974	2020-08-15 00:44:55	2020-08-15	Alyvia Pacocha-Bashirian	alyvia.pacocha.bashirian@woohoo.com	Newark	New Jersey	6011418965724645841	06c0a0198f7a9ece002ad499b078c9cc	VISA 16 digit	40.684393075658754	-74.1286950511135245
44975	2020-08-15 00:52:02	2020-08-15	Litha Medhurst	litha.medhurst@geemail.com	Fort Worth	Texas	4747235908221	befb3169548a6097ba9ce3af8921a55a	JCB 16 digit	32.7409354607630547	-97.2726314198046964
44976	2020-08-15 01:01:39	2020-08-15	Bobbye Kuhn	bobbye.kuhn@warmmail.com	McAllen	Texas	639069397726295	43873d63f47d246315b379e7282b0cdd	JCB 15 digit	26.2859043138872828	-98.3219620222538708
44977	2020-08-15 01:06:07	2020-08-15	Mr. Erland Bogan	mr.erland.bogan@geemail.com	San Francisco	California	4718966894599492	38e1b51e38e0cdf78f6e5227399b7304	VISA 16 digit	37.8084298759563779	-122.442097673568384
44978	2020-08-15 01:10:36	2020-08-15	Jenifer Sipes	jenifer.sipes@geemail.com	Concord	California	501801418586275	5dc01d3a4a6bbbda8ab8301e86a210c0	VISA 16 digit	38.0079850028201918	-121.904073098179325
44979	2020-08-15 01:19:36	2020-08-15	Ishaan Dooley-Olson	ishaan.dooley.olson@geemail.com	Arvada	Colorado	4561728151706	32624ad942e670bffed72f26050399d0	Maestro	39.8881479798991236	-105.138738768265767
44980	2020-08-15 01:24:41	2020-08-15	Dr. Demetria Wunsch DVM	dr.demetria.wunsch.dvm@geemail.com	Joliet	Illinois	180022809648882114	cea19554919d92da2911d29ba4828693	American Express	41.591043495791773	-88.2334570424269771
44981	2020-08-15 01:37:04	2020-08-15	Luciana Abshire	luciana.abshire@warmmail.com	Austin	Texas	3158107131678975678	9c7427ea08856aa67473204759a6d796	JCB 16 digit	30.3280331444121884	-97.8115907414123456
44982	2020-08-15 01:37:17	2020-08-15	Frona Leffler	frona.leffler@geemail.com	Gilbert	Arizona	3031684571819960	cb209b9f6e3b2517ed39ca24052e92fc	VISA 16 digit	33.3429683667488348	-111.764664929047598
44983	2020-08-15 01:39:46	2020-08-15	Raymond Bruen	raymond.bruen@geemail.com	Berkeley	California	630456452177597	82f3a6be015d52642f741e7c8ab8a31d	Diners Club / Carte Blanche	37.8924281743499378	-122.280747811842801
44984	2020-08-15 01:44:43	2020-08-15	Makenna Conn	makenna.conn@geemail.com	New York	New York	4793999954079418	09f218b9a9934f63eb57de58daefd921	JCB 16 digit	40.7384408809468113	-73.8758749257668796
44985	2020-08-15 01:50:44	2020-08-15	Michaele Bode	michaele.bode@geemail.com	Houston	Texas	3112364959643832782	1c9c68e8db044c5b8657c6fa267373dc	Voyager	29.8851521388240151	-95.4174927691478274
44986	2020-08-15 01:52:07	2020-08-15	Dellia Funk	dellia.funk@geemail.com	Modesto	California	630442581909977	095370eb59c266789130a22ba52ad870	JCB 15 digit	37.6370764645747897	-121.086908102009446
44987	2020-08-15 01:52:14	2020-08-15	Ezekiel Hessel	ezekiel.hessel@geemail.com	New York	New York	3337333995034659507	c727f72d806d64384ebe8431dd6dde04	Diners Club / Carte Blanche	40.6285627406779639	-73.9937657700747167
44988	2020-08-15 02:15:32	2020-08-15	Alleen Bernhard	alleen.bernhard@warmmail.com	Riverside	California	4731815722187793	6aae0ccf103a1c3fb1559375e652f183	VISA 16 digit	33.8486689232237623	-117.455018499490606
44989	2020-08-15 02:15:51	2020-08-15	Marina O'Conner	marina.o'conner@warmmail.com	New York	New York	3486210293590503	7e66eb2d3d8832d541d6aaed1d7b0e18	JCB 15 digit	40.6703591885268665	-73.9171038211684674
44990	2020-08-15 02:28:34	2020-08-15	Jerel Mueller	jerel.mueller@geemail.com	Peoria	Arizona	3088054304347655319	16f9d2c09fc0176c7b2e81d064df6e55	JCB 15 digit	33.8631132455345281	-112.344437666462738
44991	2020-08-15 02:32:35	2020-08-15	Neoma Quitzon	neoma.quitzon@geemail.com	Las Vegas	Nevada	3790776730119530	99bc98908bbf93395a7fb618f33b2cab	Maestro	36.1537103972498315	-115.235811574312294
44992	2020-08-15 02:32:51	2020-08-15	Mr. Montrell Wiza DVM	mr.montrell.wiza.dvm@geemail.com	Columbus	Ohio	630406482656433	f0f7af37f42d56b23ae96b429a64e581	Maestro	40.0094867392022167	-83.0680147242501477
44993	2020-08-15 02:42:23	2020-08-15	Melodie Hauck DVM	melodie.hauck.dvm@warmmail.com	San Francisco	California	210068283772180791	07ee12b5cc9e9279b02461d3aa7ca743	VISA 16 digit	37.7747875013039689	-122.416796470151667
44994	2020-08-15 02:45:40	2020-08-15	Sherrie Baumbach	sherrie.baumbach@geemail.com	El Cajon	California	3158018917448068994	dda86bc3493202e99ef18f122b8bc40b	JCB 16 digit	32.8371955359827723	-116.961617938214545
44995	2020-08-15 02:48:50	2020-08-15	Dr. Francis Pouros PhD	dr.francis.pouros.phd@geemail.com	San Francisco	California	3112870825017421337	d2c959b0e1ef1c5fc4041fed65547e00	Diners Club / Carte Blanche	37.779024040336914	-122.445593392262538
44996	2020-08-15 02:55:53	2020-08-15	Paisley Ledner	paisley.ledner@geemail.com	Pearland	Texas	3528847946514218842	05f26fd3545b97946dfd2c48acbc0d93	JCB 16 digit	29.6533905260071187	-95.3525058801140659
44997	2020-08-15 02:56:06	2020-08-15	Celine Dickens	celine.dickens@geemail.com	Glendale	Arizona	3112802493411739821	e198194fcafd26ff732ec413ec0cdf46	Maestro	33.602897442108393	-112.124446404983843
44998	2020-08-15 03:02:59	2020-08-15	Alonzo Ernser	alonzo.ernser@geemail.com	Billings	Montana	4406603182420480	f7dcb20fa4a3debc784fd5e133f66ad8	Discover	45.8648855923898537	-108.641552322979635
44999	2020-08-15 03:03:29	2020-08-15	Namon Morar	namon.morar@geemail.com	Memphis	Tennessee	3772612136315509	5006460e54c4863cad6cb15db6157dd2	VISA 16 digit	35.1738832356009681	-90.0380355811003597
45000	2020-08-15 03:07:06	2020-08-15	Shelba Konopelski-Graham	shelba.konopelski.graham@geemail.com	Rockford	Illinois	210087039355405196	dba7399a180f73c1f03fe5419497a220	VISA 16 digit	42.2938568658206648	-89.002966015721114
45001	2020-08-15 03:07:33	2020-08-15	Mr. Deron Larson	mr.deron.larson@geemail.com	Fort Worth	Texas	3112154599960126584	98957afacadd35f558ee30d01deae379	Diners Club / Carte Blanche	32.6886317330002782	-97.3481700210653287
45002	2020-08-15 03:10:52	2020-08-15	Mr. Elwyn Bechtelar DDS	mr.elwyn.bechtelar.dds@woohoo.com	Indianapolis	Indiana	3088769590548890509	77822e936ed5d6734ab2e5175030f262	JCB 16 digit	39.7514289814054962	-86.1343575286880139
45003	2020-08-15 03:14:35	2020-08-15	Mr. Maceo Mills	mr.maceo.mills@geemail.com	Greensboro	North Carolina	869999142585340096	61152a9c58f6c24ac835199799c59f02	VISA 16 digit	36.0908726045977346	-79.8592370489127887
45004	2020-08-15 03:19:20	2020-08-15	Nelson Schultz	nelson.schultz@geemail.com	New York	New York	3003522487657025	217dde27f72739004ddc5fd77535ee79	JCB 15 digit	40.7375478663239647	-74.035606539704645
45005	2020-08-15 03:33:34	2020-08-15	Dr. Patric Jones	dr.patric.jones@geemail.com	St. Louis	Missouri	4617629227302115	e453f96e1331ced3b7100f8b558a7c76	Diners Club / Carte Blanche	38.7200012141995131	-90.2568971617616711
45006	2020-08-15 03:34:11	2020-08-15	Nestor Fadel-Schuppe	nestor.fadel.schuppe@woohoo.com	Shreveport	Louisiana	4688419810256	19cb0ff49a8cd7e79b64ec0af959fb01	Discover	32.3924368878133606	-93.8134013053242057
45007	2020-08-15 03:34:36	2020-08-15	Ms. Merrilee Bashirian	ms.merrilee.bashirian@geemail.com	New York	New York	4491434293446	d1d43010c81bc6c60635ffb42446d24b	Voyager	40.6090802111420786	-73.9641286062438041
45008	2020-08-15 03:36:11	2020-08-15	Taj Rohan	taj.rohan@geemail.com	Charlotte	North Carolina	54057097962081814	af106d0c92beb33ded4f0dc0326a58c4	Voyager	35.2641013951759774	-80.8889918366391214
45009	2020-08-15 03:47:10	2020-08-15	Mr. Uriel Heathcote	mr.uriel.heathcote@geemail.com	Reno	Nevada	4960839115941	6005ced06527988c7746587f5ca08a19	VISA 16 digit	39.6346072563048466	-119.76376342584156
45010	2020-08-15 03:48:29	2020-08-15	Dr. Rigoberto Renner PhD	dr.rigoberto.renner.phd@geemail.com	Tallahassee	Florida	4186141116989730	d7af7cdcbeb53b1d1de581e62ba11d2f	JCB 16 digit	30.4067969882417479	-84.3149192222874575
45011	2020-08-15 03:49:59	2020-08-15	Kenyatta Quitzon	kenyatta.quitzon@geemail.com	Philadelphia	Pennsylvania	4521704986589734	ac21d47ca23e9e669c3b870a83c7b8cb	VISA 16 digit	39.9160051332280048	-75.0725653788440042
45012	2020-08-15 03:52:06	2020-08-15	Judi Bergnaum	judi.bergnaum@woohoo.com	Oakland	California	4920839967261	dbf3643144176ed566eb697f3a9d5057	JCB 16 digit	37.8237117690364784	-122.285410217812242
45013	2020-08-15 03:54:34	2020-08-15	Geno Lakin-Heller	geno.lakin.heller@woohoo.com	Aurora	Colorado	6011018499384058735	52b49784c8e44086b165afff47caaf24	JCB 16 digit	39.7700572446566127	-104.776053816883646
45014	2020-08-15 03:54:46	2020-08-15	Robin Feeney	robin.feeney@geemail.com	New York	New York	4450074011110962	9a35ebaa3d46f5a57ccdbd266ff78aa3	JCB 15 digit	40.691761572727934	-73.9951092223998188
45015	2020-08-15 04:14:01	2020-08-15	Cornell Padberg DDS	cornell.padberg.dds@geemail.com	Fresno	California	3158367174780576872	170224851a6af4e087ee0c19f984c7bf	VISA 13 digit	36.6919633153233704	-119.887651910224562
45016	2020-08-15 04:25:09	2020-08-15	Tyrell Botsford	tyrell.botsford@geemail.com	Riverside	California	210053719654604447	0b092a2aa8158992be7bfaadcf904fec	Maestro	33.885670034815	-117.311902235352235
45017	2020-08-15 04:26:53	2020-08-15	Domenic Wilkinson	domenic.wilkinson@geemail.com	Santa Clarita	California	3404334275179058	70e0303e5b11b8e439e875e3672dcfd5	JCB 16 digit	34.3318797690067399	-118.541084709866709
45018	2020-08-15 04:27:24	2020-08-15	Deana Kuvalis	deana.kuvalis@geemail.com	San Francisco	California	4739807464457403	860d09d5d45deb5b2cf736a196114fd5	Diners Club / Carte Blanche	37.7452314932510973	-122.437495971548998
45019	2020-08-15 04:29:18	2020-08-15	Willis Friesen	willis.friesen@geemail.com	Houston	Texas	3158591472777180130	2f2ca066dbacde2014909a3e7a9b1f07	VISA 13 digit	29.7645825204052024	-95.4902083700072097
45020	2020-08-15 04:39:01	2020-08-15	Chasity Nicolas MD	chasity.nicolas.md@geemail.com	Philadelphia	Pennsylvania	3528536911763153542	08b5f04dc324cdf825145ff682a38bdd	Voyager	40.0002323016483317	-75.1259976751070582
45021	2020-08-15 04:42:33	2020-08-15	Vic Conn	vic.conn@geemail.com	Austin	Texas	3735036622924226	84e7faee6e5d5e670ae3dd9da07df195	JCB 16 digit	30.333997536742686	-97.7740957330685205
45022	2020-08-15 05:02:20	2020-08-15	Brett Turner	brett.turner@geemail.com	El Cajon	California	3701995888527843	6145ba64e1de45acf8d79c000426801e	VISA 13 digit	32.8296447629582104	-116.899761981069673
45023	2020-08-15 05:11:39	2020-08-15	Dr. Kimball Mohr II	dr.kimball.mohr.ii@warmmail.com	Boston	Massachusetts	3742456305753828	2baa0b319f231d2c08fbdec88ce17038	JCB 15 digit	42.2882749698758147	-71.1112248423926587
45024	2020-08-15 05:12:34	2020-08-15	Colt Rodriguez	colt.rodriguez@geemail.com	Oakland	California	6011660518659034344	6e5adeb1192b0de81b7f3f04ebbaba9b	VISA 13 digit	37.7735948421702687	-122.302947579256497
45025	2020-08-15 05:19:37	2020-08-15	Marius Murray	marius.murray@geemail.com	Norman	Oklahoma	869989672741618573	9481afc47ccaecbd4aba3184e2d56679	VISA 16 digit	35.2928701337467885	-97.3579189756672747
45026	2020-08-15 05:27:28	2020-08-15	Tabatha Schiller	tabatha.schiller@geemail.com	Ontario	California	3528717451874411589	2eee514bd12090df1f943feabf175bb7	VISA 13 digit	34.1107145778048775	-117.633986695120868
45027	2020-08-15 05:29:29	2020-08-15	Margueritte Hyatt	margueritte.hyatt@geemail.com	Colorado Springs	Colorado	3733233219435482	38277204fa4d7583d275221262503b9f	JCB 16 digit	38.8669077630203219	-104.839792721827322
45028	2020-08-15 05:29:40	2020-08-15	Keisha Bogisich	keisha.bogisich@woohoo.com	San Francisco	California	869947264428598509	87ad559645d7537e4a294841e0f2094d	American Express	37.7563340538382946	-122.447083840308693
45029	2020-08-15 05:34:14	2020-08-15	Reggie Keebler	reggie.keebler@geemail.com	Chicago	Illinois	4636320085222523	d796b0bb5cd96539cebd0e72dfc78675	VISA 13 digit	41.8819221814930458	-87.6383431477967605
45030	2020-08-15 05:44:12	2020-08-15	Jermain Beier-Hayes	jermain.beier.hayes@warmmail.com	Philadelphia	Pennsylvania	210052434316388873	1454e1fb08aaf7dfca0d5484e9609f87	VISA 13 digit	39.9479931837372462	-75.1013093354545589
45031	2020-08-15 05:46:14	2020-08-15	Kenzie Pfannerstill	kenzie.pfannerstill@geemail.com	Pearland	Texas	3026488945968478	eae2e179215d20a42c6823e6acb134b7	VISA 16 digit	29.4737990656673929	-95.2704385368008104
45032	2020-08-15 05:52:09	2020-08-15	Kennard Mertz V	kennard.mertz.v@geemail.com	New York	New York	4314653556048	9281e1e486a08514b9914d6f1c58e01c	JCB 16 digit	40.6110756366737178	-73.951838455478466
45033	2020-08-15 05:54:51	2020-08-15	Ace Schulist	ace.schulist@geemail.com	Cleveland	Ohio	4935003733265	ac44ee52078e23f927d0971deceb7391	JCB 16 digit	41.396052486481139	-81.7077170418813807
45034	2020-08-15 06:01:46	2020-08-15	Frona Bernier	frona.bernier@woohoo.com	Louisville	Kentucky	869949125091022739	be6f9e06405c6d3a8ffc0458bcb2d929	JCB 15 digit	38.2168055035077003	-85.682944098727404
45035	2020-08-15 06:07:33	2020-08-15	Colten White	colten.white@geemail.com	New York	New York	4444394753024	0fe9b8cee006a21c53f4758ec2ef52a8	JCB 16 digit	40.5929677865691474	-74.0266402845166596
45036	2020-08-15 06:18:16	2020-08-15	Dr. Hernan Gottlieb Sr.	dr.hernan.gottlieb.sr.@geemail.com	San Francisco	California	3112199837450307653	2ba901973c4372cf01369475f24dd911	Voyager	37.7548358095567878	-122.435683885477971
45037	2020-08-15 06:21:55	2020-08-15	Mr. Hubbard Littel	mr.hubbard.littel@woohoo.com	Visalia	California	4196338805702782	094c69bcba74c0911cf33496188f56f6	Maestro	36.3622172196350988	-119.391370739986755
45038	2020-08-15 06:29:09	2020-08-15	Shaniece Gulgowski	shaniece.gulgowski@geemail.com	McKinney	Texas	3158569717843175599	08e24789d8334317d4a73f073bd66f8b	American Express	33.1554206857122509	-96.6293922670018048
45039	2020-08-15 06:36:37	2020-08-15	Ms. Reva Halvorson DVM	ms.reva.halvorson.dvm@woohoo.com	Antioch	California	210074446963002627	5ae8131d0fd202877de8345a4f153da2	Discover	37.9028692367751177	-121.716054839518662
45040	2020-08-15 06:38:09	2020-08-15	Haiden Smith	haiden.smith@geemail.com	Indianapolis	Indiana	501826280352332	4a8b0f9b24a096fffacb39d4afe505f6	Maestro	39.8589238345164816	-86.2011624949254127
45041	2020-08-15 06:43:31	2020-08-15	Dr. Arnoldo Spinka	dr.arnoldo.spinka@geemail.com	Anchorage	Alaska	4166450861032230	02864bca34b4a473e2cdccd76d8f18c1	Maestro	61.0970042164653577	-149.36672134461179
45042	2020-08-15 06:44:24	2020-08-15	Dillon Ortiz Sr.	dillon.ortiz.sr.@warmmail.com	Grand Prairie	Texas	4187462172649	c433c02c21690a1144d427fe06f63014	VISA 16 digit	32.7202137184847146	-96.9834216815292933
45043	2020-08-15 06:46:31	2020-08-15	Vesta Hane	vesta.hane@geemail.com	Richmond	California	4743383780739076	76e4e12b0de0747ae796ea22adce840d	VISA 16 digit	38.0517725031312537	-122.278935131602367
45044	2020-08-15 06:47:32	2020-08-15	Miss Noreen Ward DVM	miss.noreen.ward.dvm@geemail.com	Pembroke Pines	Florida	52931246111049501	782a726e0d6220315b730560be2759dc	JCB 15 digit	25.9855623636432007	-80.3305668987236885
45045	2020-08-15 06:50:38	2020-08-15	Arlena Schaefer	arlena.schaefer@geemail.com	Birmingham	Alabama	3042131131036981	c96074c34315c5793879bc9a75bd020b	Voyager	33.43506580742784	-86.799920959888027
45046	2020-08-15 06:51:10	2020-08-15	Winfred Stanton	winfred.stanton@woohoo.com	Tyler	Texas	4786770760434033	61ac5e50527f0cd7a294a961deb8bade	Voyager	32.2796021936509803	-95.3955427311003206
45047	2020-08-15 06:51:34	2020-08-15	Mrs. Trilby Langworth PhD	mrs.trilby.langworth.phd@woohoo.com	New York	New York	4482459027783807	c2c538a077267aa0f3f350b7f8b59404	VISA 13 digit	40.6949966058358541	-73.9951793768338888
45048	2020-08-15 06:52:30	2020-08-15	Adrien Parker	adrien.parker@geemail.com	San Francisco	California	676193755314510	fd23060a3a156bd6f15645380b799cb3	Voyager	37.764223354797295	-122.450320317688337
45049	2020-08-15 06:56:28	2020-08-15	Dr. Kiara Johnson PhD	dr.kiara.johnson.phd@geemail.com	Little Rock	Arkansas	3022727142905195	4537c778a6652da3cd476e4560133ecc	Mastercard	34.653831599400938	-92.2790072141088444
45050	2020-08-15 07:06:54	2020-08-15	Ms. Laci Von PhD	ms.laci.von.phd@geemail.com	Richardson	Texas	3158821417167261315	9d26bf9a5c8f639dbc0e8e4eef05fa2a	Discover	32.9737862006064475	-96.6659373015392589
45051	2020-08-15 07:09:10	2020-08-15	Christ Pacocha	christ.pacocha@geemail.com	Anaheim	California	4498401988759	9cd382bbff474998e8aa171cd60a6bf2	VISA 16 digit	33.7741383641324902	-117.697074478373295
45052	2020-08-15 07:17:31	2020-08-15	Dereon Paucek-Medhurst	dereon.paucek.medhurst@woohoo.com	San Francisco	California	3429661329667907	893c72d1a1e0c38ce2f79b067072d142	VISA 13 digit	37.7766028013350521	-122.436302285875087
45053	2020-08-15 07:25:21	2020-08-15	Mrs. Lenora Murazik	mrs.lenora.murazik@geemail.com	Glendale	California	3058181908739659	23ca1735c016acc91e838df48ac2898e	VISA 16 digit	34.0855509706992592	-118.184526022699856
45054	2020-08-15 07:26:53	2020-08-15	Ms. Yasmine Olson	ms.yasmine.olson@geemail.com	Stockton	California	3528468842596610980	06aa429f95665330a600aa15543fb994	Voyager	37.9465254774048972	-121.213319675819207
45055	2020-08-15 07:28:40	2020-08-15	Zula Corwin-Adams	zula.corwin.adams@geemail.com	Bellevue	Washington	51468663801430877	0e6309e6ee1c72bdfccfeb074129e29a	JCB 16 digit	47.5521895107995718	-122.193637233186507
45056	2020-08-15 07:30:15	2020-08-15	Maryellen Hyatt	maryellen.hyatt@geemail.com	Fargo	North Dakota	4613667327560434	f100201b8eb46072ed152785380460b4	American Express	46.8573142719220357	-96.8867780413906985
45057	2020-08-15 07:37:44	2020-08-15	Simone Hansen-Rice	simone.hansen.rice@geemail.com	San Jose	California	589381296498108	b34c7678ee72a7bea5efb7e91a7fcd95	JCB 16 digit	37.3783953870933487	-121.855981751553344
45058	2020-08-15 07:44:44	2020-08-15	Elzy Rogahn	elzy.rogahn@geemail.com	Long Beach	California	676158334591094	b1d4e099de4443ef2a9a51a18eaa3ac1	Voyager	33.7938960278227896	-118.145245387654001
45059	2020-08-15 07:53:37	2020-08-15	Ms. Shari Brown	ms.shari.brown@geemail.com	Chicago	Illinois	3038538467389525	200564daae787228d39296936a7f8e0e	VISA 13 digit	41.7941196563955444	-87.6498305296089484
45060	2020-08-15 07:53:39	2020-08-15	Vollie Hauck	vollie.hauck@geemail.com	San Jose	California	4472223609927	9a28dcfb70bbc92a8d20bafd8925fc40	VISA 13 digit	37.2137706992037636	-121.762024174466362
45061	2020-08-15 08:02:22	2020-08-15	Lee Considine	lee.considine@warmmail.com	San Francisco	California	3528436240702846847	13ae971d37ae67b2b8f1b29734faf629	JCB 16 digit	37.7933348344960223	-122.420644803120368
45062	2020-08-15 08:03:56	2020-08-15	Chadd Murray MD	chadd.murray.md@warmmail.com	San Francisco	California	3096803670622182755	6d3fd8c23d85cab066baa730c284f600	VISA 16 digit	37.7946467541111204	-122.443981871552836
45063	2020-08-15 08:04:04	2020-08-15	Curtiss Walker	curtiss.walker@geemail.com	San Antonio	Texas	869947008935976959	8ce5f95f36428b221b75b8a227cd6c05	VISA 16 digit	29.4601012040466088	-98.5903498387731503
45064	2020-08-15 08:09:42	2020-08-15	Jaylene Pagac-Moore	jaylene.pagac.moore@geemail.com	Hillsboro	Oregon	6011019058458180582	bc93055b2a11d21f533912b8ebd2c3e6	American Express	45.562230259805915	-122.91068127701692
45065	2020-08-15 08:14:02	2020-08-15	Sandie Zboncak	sandie.zboncak@geemail.com	Dallas	Texas	4910994484024529	880ac77a682d41b481fcd7795ece23b5	Discover	32.764388252775376	-96.7444786900617117
45066	2020-08-15 08:15:34	2020-08-15	Mr. Darrin Davis	mr.darrin.davis@geemail.com	Portland	Oregon	501834046739438	d27fbde5fb4f0a528945d96b0aad5dc2	VISA 13 digit	45.5139221237860596	-122.55871553542093
45067	2020-08-15 08:18:44	2020-08-15	Mrs. Makena Eichmann MD	mrs.makena.eichmann.md@geemail.com	San Mateo	California	3431885454839868	9f7defbf8df0701e70ecf3aa6633ca0f	JCB 16 digit	37.6551304999154013	-122.21283402385599
45068	2020-08-15 08:21:51	2020-08-15	Dr. Charity Greenholt	dr.charity.greenholt@warmmail.com	Tampa	Florida	869947625189261786	72f37f240249260f95c8b827dea613f1	Mastercard	28.05307685952857	-82.3962164123289256
45069	2020-08-15 08:44:00	2020-08-15	Conner Lakin	conner.lakin@geemail.com	Tucson	Arizona	869917993724011538	1b1bfcd32b222cdf75530d0f3a47804e	JCB 15 digit	32.1982246847864246	-110.858660247618701
45070	2020-08-15 08:45:05	2020-08-15	Mrs. Peggie Jacobs	mrs.peggie.jacobs@woohoo.com	Miami	Florida	869917572685595828	2a44001cb73e4d74d63329ced92c2099	VISA 16 digit	25.8369403528653088	-80.1279367579486319
45071	2020-08-15 08:51:37	2020-08-15	Forest Kuvalis-Spinka	forest.kuvalis.spinka@geemail.com	Elk Grove	California	6011428910375235425	314e222da33d230edfec2bbcd1c398e3	VISA 16 digit	38.4737731426771745	-121.349444069890311
45072	2020-08-15 08:51:49	2020-08-15	Essex Witting	essex.witting@woohoo.com	Palmdale	California	3047342046112271	4007951f730dd27c4ef108cbf1209cd8	American Express	34.5315859044287379	-118.186359024047476
45073	2020-08-15 08:57:43	2020-08-15	Timmothy White	timmothy.white@geemail.com	Portland	Oregon	676246569497244	a3f55bec96cd738b1fd2c6ad2f124155	VISA 16 digit	45.47937637082115	-122.712732101697483
45074	2020-08-15 09:00:42	2020-08-15	Eddie Mosciski	eddie.mosciski@woohoo.com	Long Beach	California	501895739479640	e76e9d8e0eaa1fac3bc99f5e8d500c88	VISA 16 digit	33.8621627778101697	-118.124295726527649
45075	2020-08-15 09:11:16	2020-08-15	Zed Medhurst	zed.medhurst@geemail.com	Oakland	California	4882735731703934	dee67a1d549b665a75958b03afed9231	Voyager	37.8552123741195956	-122.248070358513317
45076	2020-08-15 09:21:26	2020-08-15	Tisa Metz	tisa.metz@geemail.com	New York	New York	4511691018048791	4da8f4897965f3b5685f87d8fbc3f3eb	American Express	40.7326282621119162	-73.9580124043289544
45077	2020-08-15 09:39:30	2020-08-15	Geri Rogahn	geri.rogahn@geemail.com	Aurora	Illinois	3472080898544031	fbf0a34f577c336930ea516e50b9e91d	JCB 16 digit	41.8144105218108777	-88.2729835250809742
45078	2020-08-15 09:56:56	2020-08-15	Dr. Nathen Jenkins IV	dr.nathen.jenkins.iv@geemail.com	Fort Lauderdale	Florida	3096008431949520646	56f66ee6cb53ed8693d8eb7d55bacbb2	JCB 15 digit	26.1455476504273712	-80.1635978217989162
45079	2020-08-15 10:20:19	2020-08-15	Dr. Bertrand Heller	dr.bertrand.heller@geemail.com	San Francisco	California	54749977501601020	d17e9bd6c6610b9049e4a57510ce1e3d	Maestro	37.7763158611755046	-122.445722979390297
45080	2020-08-15 10:20:38	2020-08-15	Redden Erdman III	redden.erdman.iii@woohoo.com	New York	New York	54638032666113553	c6860516fec5e7f9cee5ecad9264911e	JCB 15 digit	40.7529930489826953	-73.963716063265494
45081	2020-08-15 10:22:50	2020-08-15	Shelby Labadie	shelby.labadie@geemail.com	Toledo	Ohio	3158424738647019986	cfdd1f6b266e9168741a90b2dcab48a8	Maestro	41.6538345732431807	-83.493868002701177
45082	2020-08-15 10:37:08	2020-08-15	Hassan Rau	hassan.rau@geemail.com	Houston	Texas	51260599508283013	c04f55d903c76807e240e921d6f98009	VISA 16 digit	29.7605290626719601	-95.4645683514900583
45083	2020-08-15 10:38:35	2020-08-15	Aryanna Borer	aryanna.borer@woohoo.com	San Francisco	California	51078209885955678	0bed345fa6101d24b9faa414e1a64840	Maestro	37.7779826490054376	-122.414892002624384
45084	2020-08-15 10:47:41	2020-08-15	Mr. Bronson Lockman	mr.bronson.lockman@geemail.com	Los Angeles	California	4224425406064674	e98e2a2304b945a2a0d8bbadd3d55b3a	Maestro	34.0215961264777889	-118.405711032216615
45085	2020-08-15 10:52:48	2020-08-15	Joleen Koch MD	joleen.koch.md@geemail.com	Eugene	Oregon	4288459036336551	b9dd980e191c2820d026850028523bae	American Express	44.1089899006493411	-123.0513110468153
45086	2020-08-15 10:53:55	2020-08-15	Deonta Effertz	deonta.effertz@geemail.com	Palm Bay	Florida	869970212644450997	27121db5bf807540f4f5fccf5faaacbe	VISA 13 digit	27.8912371939834216	-80.6847582451369618
45087	2020-08-15 11:01:09	2020-08-15	Norris Koch	norris.koch@geemail.com	Lowell	Massachusetts	4798722841292	ce6ccda6d1676f3a15bbabb4a9ad2ec3	Maestro	42.5725343701764984	-71.3270171577449901
45088	2020-08-15 11:03:06	2020-08-15	Stephenie Aufderhar	stephenie.aufderhar@woohoo.com	Salt Lake City	Utah	3158446378071082251	cc64c96c35ac7ae08f5ea45ec4085e4d	VISA 16 digit	40.7816023339662692	-111.909534664958713
45089	2020-08-15 11:09:01	2020-08-15	Brett Durgan	brett.durgan@woohoo.com	San Francisco	California	3728002452056827	b55c2141074d2ad606a39d72fa537740	Voyager	37.7719929873552331	-122.488728593479948
45090	2020-08-15 11:10:23	2020-08-15	Hermine Stoltenberg	hermine.stoltenberg@geemail.com	McKinney	Texas	6011445749193940926	c7da019eb9b8df7eb62373ac356358c9	JCB 16 digit	33.2896884271074143	-96.6083082657605416
45091	2020-08-15 11:10:41	2020-08-15	Dr. Brain Harber	dr.brain.harber@geemail.com	Alexandria	Virginia	869926113731040284	69af902254701ae1335f21cdcaf7556d	Voyager	38.7492358988266403	-77.0047265843939073
45092	2020-08-15 11:22:24	2020-08-15	Jammie Borer	jammie.borer@geemail.com	Greeley	Colorado	4344254996889356	013e33b01c5e40c7f0530f900cfd37d9	VISA 16 digit	40.3674229028236127	-104.753733079259092
45093	2020-08-15 11:27:49	2020-08-15	Mr. Dino Tromp V	mr.dino.tromp.v@warmmail.com	Houston	Texas	210042239687585236	3017a136de4f03360ef3cdbafdb1955b	Discover	29.8820840776510543	-95.4533082338064958
45094	2020-08-15 11:27:50	2020-08-15	Suzette Reichel	suzette.reichel@geemail.com	Winston–Salem	North Carolina	4150297801566449	32eb9be7b52274ba3a444de987bb21c3	VISA 13 digit	36.125835967273261	-80.2056127645671353
45095	2020-08-15 11:36:04	2020-08-15	Lovisa Funk	lovisa.funk@warmmail.com	San Francisco	California	3727435589605200	53fb47f12e8e06098300feceb1317701	VISA 16 digit	37.7917019046007425	-122.447381223815995
45096	2020-08-15 11:37:04	2020-08-15	Hope Douglas Jr.	hope.douglas.jr.@geemail.com	Norfolk	Virginia	3528040168499026034	ea77ac9d4e9f13724d4de9f45bb6213c	JCB 15 digit	36.9442190120946634	-76.3203741821464234
45097	2020-08-15 11:44:37	2020-08-15	Ott Rohan	ott.rohan@geemail.com	Glendale	Arizona	6011418244536392574	f55785092ff2c6d09614179c208a4275	Mastercard	33.515332456188645	-112.21295687936022
45098	2020-08-15 11:46:11	2020-08-15	Waldemar Fisher	waldemar.fisher@woohoo.com	Lubbock	Texas	4659599063444025	2bc6a1309ed0792f7db373271347ec6c	Diners Club / Carte Blanche	33.521334267923983	-101.97908135642372
45099	2020-08-15 11:47:55	2020-08-15	Zander Nikolaus	zander.nikolaus@warmmail.com	Colorado Springs	Colorado	4936888213811	76d1575dd3d9b1cae1e96f61b1e72633	Discover	38.8860048667576166	-104.716869424811378
45100	2020-08-15 11:49:27	2020-08-15	Lela Satterfield	lela.satterfield@geemail.com	San Francisco	California	3751803021425991	fab4c83dcda1b59b492ea0036467d02b	VISA 13 digit	37.7399345243796986	-122.411267538554071
45101	2020-08-15 11:50:50	2020-08-15	Lourdes Schaden PhD	lourdes.schaden.phd@geemail.com	Indianapolis	Indiana	3158504227551785272	f87244c87837177a43f519765e1afcb0	VISA 13 digit	39.6835282370455573	-86.1863866468161319
45102	2020-08-15 11:54:11	2020-08-15	Karl Macejkovic	karl.macejkovic@woohoo.com	Memphis	Tennessee	55842149838444005	e2b74e5bc588557633aa517368e72a51	VISA 16 digit	35.1873025470946033	-89.90489822316691
45103	2020-08-15 12:04:57	2020-08-15	Mr. Silas Macejkovic PhD	mr.silas.macejkovic.phd@geemail.com	New York	New York	3472746227942878	4f27c84a909a2487a7ef7140e6aacb2d	Voyager	40.6510589310657195	-74.0046736506175193
45104	2020-08-15 12:16:47	2020-08-15	Chastity Rosenbaum-Bosco	chastity.rosenbaum.bosco@woohoo.com	Reno	Nevada	869983949304071093	31031ed70f2b4f9ec5b4ecd57137ce67	Diners Club / Carte Blanche	39.5384473359290567	-119.885312276070565
45105	2020-08-15 12:27:59	2020-08-15	Jaheim Torp I	jaheim.torp.i@warmmail.com	Chicago	Illinois	3753583388647910	232d98aa45c4d79d2142e7be332715ad	VISA 13 digit	41.8218715292237704	-87.773547109685083
45106	2020-08-15 12:39:07	2020-08-15	Valentin Greenholt DVM	valentin.greenholt.dvm@geemail.com	Long Beach	California	869952882622080768	5ebed279243f8ec6e17110ca1be5e914	Diners Club / Carte Blanche	33.7449297901064114	-118.11153632594943
45107	2020-08-15 12:43:45	2020-08-15	Mr. Antwon Okuneva	mr.antwon.okuneva@geemail.com	Portland	Oregon	4949394549045160	04cb9eeb0e6abfc8c5bae9f230561621	Diners Club / Carte Blanche	45.5723404301684312	-122.637539443187421
45108	2020-08-15 12:49:12	2020-08-15	Marlena Lesch	marlena.lesch@warmmail.com	Denver	Colorado	4145095728955	6f1ef7de9c006fa8e858e59d170ee6de	VISA 13 digit	39.8258535451307836	-104.78932928501294
45109	2020-08-15 12:54:56	2020-08-15	Jerrilyn Blick DVM	jerrilyn.blick.dvm@geemail.com	Torrance	California	3112554449577318610	4bceb6bec89790f5f472dd84df04c42b	American Express	33.8824116830620952	-118.373331529333811
45110	2020-08-15 13:00:22	2020-08-15	Dr. Cornel Cassin II	dr.cornel.cassin.ii@geemail.com	Broken Arrow	Oklahoma	4765855856753969	b4d01d8bd502d055574d5e9981d91a7e	American Express	35.9514535359814715	-95.6982008013352754
45111	2020-08-15 13:00:26	2020-08-15	Granville Spencer IV	granville.spencer.iv@woohoo.com	Indianapolis	Indiana	869932457054914753	1514db273ccd9b6774edcc621c991783	VISA 16 digit	39.8658011489555193	-86.0930799838356648
45112	2020-08-15 13:03:32	2020-08-15	Delwin Medhurst-Heathcote	delwin.medhurst.heathcote@geemail.com	Columbus	Ohio	4905585096414103	114b61ce49e432d79e46769eae86b602	VISA 16 digit	39.9517214654989559	-83.0310568736635162
45113	2020-08-15 13:06:49	2020-08-15	Jaden Schneider	jaden.schneider@geemail.com	Fontana	California	869932863447146153	e7f854b14c191071c066cae1df68fcc2	Voyager	34.0215619438476864	-117.387511540883779
45114	2020-08-15 13:07:05	2020-08-15	Lauren Schowalter PhD	lauren.schowalter.phd@geemail.com	San Antonio	Texas	3731630376318801	23a94d963ceb16f3c72c71e7a8fbed1f	JCB 16 digit	29.3819689132809643	-98.5059072993531828
45115	2020-08-15 13:10:45	2020-08-15	Chantel Cummerata	chantel.cummerata@warmmail.com	Milwaukee	Wisconsin	52323660805863264	aad3e5c83855c803aad3e96c4b22f4a3	VISA 16 digit	43.0797579214062552	-87.8915460579663517
45116	2020-08-15 13:18:58	2020-08-15	Harvy Schuster	harvy.schuster@geemail.com	Irvine	California	3009918838376014	ac2f1acedbe22dae82fb205cd010904e	VISA 16 digit	33.691353062029556	-117.736740775500607
45117	2020-08-15 13:19:32	2020-08-15	Dr. Lucien Skiles III	dr.lucien.skiles.iii@warmmail.com	Lowell	Massachusetts	3112920147767507680	9a278ee6c7e3c78598a1c932cd5a0534	JCB 16 digit	42.714554219866173	-71.2938597724646286
45118	2020-08-15 13:24:58	2020-08-15	Bena Haag-Balistreri	bena.haag.balistreri@geemail.com	San Francisco	California	3782946807927863	48607744aaa1c1541eda0046c4a4c4b3	Mastercard	37.7732710972184904	-122.445623138375126
45119	2020-08-15 13:30:36	2020-08-15	Lavonia Von	lavonia.von@geemail.com	Charlotte	North Carolina	3337439496748012011	84f6ff2dbd4e7b2e2b4e773e26e36029	Mastercard	35.2150887782938753	-80.9122987456563862
45120	2020-08-15 13:40:36	2020-08-15	Danica Paucek	danica.paucek@geemail.com	Vancouver	Washington	6011152058921733766	6fa274de45f6eb27e4128a3c19d5db32	VISA 16 digit	45.6752297425713394	-122.500983544771373
45121	2020-08-15 13:50:10	2020-08-15	Thalia Hermann	thalia.hermann@geemail.com	Orlando	Florida	869955606824963993	c964b2a108d9ceaf6b32d1e478f2cfbc	VISA 16 digit	28.3538515356633809	-81.3042143159046731
45122	2020-08-15 13:51:52	2020-08-15	Simmie Bahringer	simmie.bahringer@warmmail.com	Fresno	California	869979398304421583	e9b14879de3ebe627a497581feed3769	VISA 13 digit	36.8761738464575259	-119.861634319519254
45123	2020-08-15 14:08:11	2020-08-15	Mrs. Erlinda Gibson PhD	mrs.erlinda.gibson.phd@warmmail.com	Seattle	Washington	4981213450464	0344462b53c6240f1b3a37034fa2c899	JCB 16 digit	47.6189695945866376	-122.445836749944462
45124	2020-08-15 14:08:23	2020-08-15	Siddie Tillman	siddie.tillman@geemail.com	Hollywood	Florida	4799025521212698	9a05b488bee23d31b4a76c6efa4da44a	JCB 16 digit	25.9515681965220715	-80.1264493936024564
45125	2020-08-15 14:24:42	2020-08-15	Crete Sauer	crete.sauer@warmmail.com	Chicago	Illinois	3528055227740658961	dc81d9da86adfc0a6abc15c481bb5238	Diners Club / Carte Blanche	41.8336713560692957	-87.7596901294805036
45126	2020-08-15 14:31:57	2020-08-15	True Stoltenberg	true.stoltenberg@warmmail.com	Los Angeles	California	4009303263446170	5804de7d87078cc5eac989cb683d5a65	VISA 16 digit	34.0187768272455742	-118.4598782179404
45127	2020-08-15 14:40:27	2020-08-15	Dakota Gleichner	dakota.gleichner@geemail.com	Birmingham	Alabama	869978294784094589	931c53f1a4cd3a75d82f67f61d4080e3	VISA 16 digit	33.4316688388377443	-86.7983473818991342
45128	2020-08-15 14:49:51	2020-08-15	Olof Ward	olof.ward@warmmail.com	Boise	Idaho	4005872136180160	541e259205cfc206f744acf54d8919a9	VISA 16 digit	43.5762786760132741	-116.165366107291362
45252	2020-08-16 03:42:05	2020-08-16	Marty Gutmann V	marty.gutmann.v@geemail.com	Reno	Nevada	210072924032245528	407a8c1f9a46a061766a2e9c2ac31f5d	VISA 16 digit	39.5050725587256295	-119.808188524998357
45129	2020-08-15 14:52:33	2020-08-15	Delvin Hamill	delvin.hamill@geemail.com	Riverside	California	51503016612952547	f462b51a92d5bd99695dc70dff093205	Diners Club / Carte Blanche	34.0117500391270937	-117.353422602216526
45130	2020-08-15 15:00:59	2020-08-15	Mr. Pablo Mohr Sr.	mr.pablo.mohr.sr.@geemail.com	Corona	California	4071513771650	48268eb0a9c276395450b3ddd96e6298	JCB 15 digit	33.8808966854941147	-117.664477261316037
45131	2020-08-15 15:05:35	2020-08-15	Pat Pouros	pat.pouros@woohoo.com	Tulsa	Oklahoma	4945869371056215	930dec636867f20f095e25b9df65ad6a	JCB 16 digit	36.0995150129679558	-95.9392105688761916
45132	2020-08-15 15:09:40	2020-08-15	Candi Runolfsdottir	candi.runolfsdottir@geemail.com	San Francisco	California	53298257059527207	42d0fd4847d34ef3da60f06ac316ff46	American Express	37.784303692284773	-122.455535093534081
45133	2020-08-15 15:10:23	2020-08-15	Lea Keebler	lea.keebler@geemail.com	Long Beach	California	52036782124411555	724a3c9675e536b0bd4dae35b046e7df	Discover	33.75874016101546	-118.074852372209719
45134	2020-08-15 15:13:34	2020-08-15	Dr. Anderson Grady PhD	dr.anderson.grady.phd@warmmail.com	San Francisco	California	52605601609906346	48161b531e58c966716c0ea0b7aa5749	Voyager	37.7444341717203216	-122.410208972879985
45135	2020-08-15 15:16:15	2020-08-15	Allen Welch	allen.welch@geemail.com	Colorado Springs	Colorado	502046432344326	a32f4c2399bd1d04b2f9b7e2df9654fc	Mastercard	38.8496404069989936	-104.788875766533238
45136	2020-08-15 15:20:22	2020-08-15	Zion Predovic	zion.predovic@geemail.com	Houston	Texas	3733322278100499	5c08c052a9c30f12e9d2b1534592008b	VISA 16 digit	29.8378306489981711	-95.3681603122051769
45137	2020-08-15 15:20:39	2020-08-15	Ancel Reichel	ancel.reichel@geemail.com	Mesa	Arizona	180020537737660271	a7f7a9285a116164ee7bd4672f09ccee	JCB 16 digit	33.3658386016409807	-111.801608921622488
45138	2020-08-15 15:23:23	2020-08-15	Mrs. Leta McDermott	mrs.leta.mcdermott@geemail.com	New York	New York	53434228786537533	abad93e867d5d05b044e3b08b64450ec	JCB 16 digit	40.7483926233593365	-73.9294242141664029
45139	2020-08-15 15:28:15	2020-08-15	Rhonda DuBuque	rhonda.dubuque@geemail.com	Pittsburgh	Pennsylvania	3528158940512422764	3ccfd1b0270b0664aff1bbd48a0c9206	Discover	40.489346735128386	-80.0668346918359504
45140	2020-08-15 15:31:40	2020-08-15	Woody Hoeger	woody.hoeger@geemail.com	Boise	Idaho	180034234693104460	b141bdebea0f29c6aa60ca3b8e722b47	JCB 16 digit	43.6144762504518013	-116.229868508848185
45141	2020-08-15 15:37:30	2020-08-15	Vernice Eichmann	vernice.eichmann@geemail.com	Rochester	New York	3454831703402175	bca1e90f6f8f014e0347b9e086877d49	Mastercard	43.2424620335433616	-77.5630694003082795
45142	2020-08-15 15:45:47	2020-08-15	Jayson Cartwright-Predovic	jayson.cartwright.predovic@geemail.com	Ventura	California	4441984011647973	441974c587f4af569716c3b2cf206417	VISA 16 digit	34.3021719779513816	-119.283361360813302
45143	2020-08-15 15:48:15	2020-08-15	Alida Zemlak	alida.zemlak@geemail.com	San Francisco	California	3497743219508305	1c920b9c16c004f6c9042a8b8459c758	Voyager	37.7949356020099216	-122.429735922577251
45144	2020-08-15 15:51:41	2020-08-15	Orval Braun-Schiller	orval.braun.schiller@geemail.com	Houston	Texas	3036930688768391	421b5d6d2c2f4aad176b95dae1464184	Mastercard	29.8711327304676182	-95.3516831446453921
45145	2020-08-15 16:03:38	2020-08-15	Dr. Edgar Simonis	dr.edgar.simonis@geemail.com	Green Bay	Wisconsin	3488882054992710	5b518e4b95525c83dca7abe26307ca11	Maestro	44.5613656520906787	-88.0389545371111524
45146	2020-08-15 16:08:15	2020-08-15	Todd Funk	todd.funk@woohoo.com	Berkeley	California	3112609832957043053	fee5c7b919fb9dffc4ef1028cd8d6c0a	Diners Club / Carte Blanche	37.9003877867216161	-122.307697863350299
45147	2020-08-15 16:20:10	2020-08-15	Enriqueta Roob-Schumm	enriqueta.roob.schumm@geemail.com	San Francisco	California	869941986880831855	dcee936ec59e30de88b7fa04c7164794	VISA 16 digit	37.8225616550700536	-122.44234649869675
45148	2020-08-15 16:20:26	2020-08-15	Donaciano Kuhn III	donaciano.kuhn.iii@geemail.com	Philadelphia	Pennsylvania	3158960754428276836	5dd7cc9a5d3328815ac652cef0ab8ce2	JCB 16 digit	40.0728663436096184	-75.1485388996910331
45149	2020-08-15 16:23:11	2020-08-15	Mossie Bosco	mossie.bosco@geemail.com	Las Vegas	Nevada	3737300200079920	c245516a46d415f044a698f1ae2b86d0	Discover	36.2757282955672551	-115.28111081442087
45150	2020-08-15 16:24:01	2020-08-15	Isadora Marks DVM	isadora.marks.dvm@geemail.com	New York	New York	3088942624458231261	bcd74749809b49c244b6ead02324e349	VISA 13 digit	40.5680111585874101	-73.850777250843862
45151	2020-08-15 16:31:11	2020-08-15	Hulda Sawayn	hulda.sawayn@geemail.com	San Francisco	California	4207410386707279	142300e08ec23c310601fbf026ac11cf	JCB 16 digit	37.7894575433098368	-122.4653404573898
45152	2020-08-15 16:31:12	2020-08-15	Latosha Hackett	latosha.hackett@warmmail.com	Reno	Nevada	3031147913798714	0d1c3c2f1d688d914e525e7aba487a58	JCB 16 digit	39.4544252340294435	-119.909785468985888
45153	2020-08-15 16:35:34	2020-08-15	Hjalmar Willms	hjalmar.willms@geemail.com	Fargo	North Dakota	6011482405280869916	2fe58cfebc207bb6cf7c8f6ad60940f5	JCB 16 digit	46.9610705528639301	-96.766190080992871
45154	2020-08-15 16:36:13	2020-08-15	Dr. Harrell Feest IV	dr.harrell.feest.iv@geemail.com	Houston	Texas	4564184878102391	09331b5fc7e51f07b266000351b3aed3	American Express	29.8594751036804169	-95.3107650088626883
45155	2020-08-15 16:38:22	2020-08-15	Dr. Jodi Osinski	dr.jodi.osinski@woohoo.com	Atlanta	Georgia	52170014540375073	9be812a9837cd19adc7b0588393c438d	Voyager	33.7180042159087989	-84.382117111519733
45156	2020-08-15 16:55:49	2020-08-15	Altha Osinski	altha.osinski@geemail.com	San Jose	California	503874527194299	547eda798766ffe90a581c31cb1c830d	JCB 16 digit	37.330925444728507	-121.792903230361262
45157	2020-08-15 17:02:32	2020-08-15	Bella Kunde-Jakubowski	bella.kunde.jakubowski@geemail.com	Thousand Oaks	California	3451015759875715	d34ec68a5cab9c1f845e5632214eb76b	JCB 16 digit	34.2628509179495282	-118.863963186639182
45158	2020-08-15 17:31:32	2020-08-15	Jeffie Mosciski	jeffie.mosciski@geemail.com	Houston	Texas	4617373634550	cd1b9cc154e40bce5ebf14b834a2ec2f	JCB 15 digit	29.8646736392363898	-95.3824239507332408
45159	2020-08-15 17:34:26	2020-08-15	Felix Ullrich-O'Hara	felix.ullrich.o'hara@geemail.com	Shreveport	Louisiana	3096915446207492694	bc99f4824f82e53a1b0c1f45ec368bbb	VISA 16 digit	32.4142476844839749	-93.7671512119218704
45160	2020-08-15 17:46:39	2020-08-15	Arch Leannon	arch.leannon@geemail.com	League City	Texas	180028686429314036	7c5f34b9b13874b7cb70f45abf162337	Voyager	29.4560937128424669	-95.1249930218778559
45161	2020-08-15 17:48:56	2020-08-15	Neppie Waters-Daugherty	neppie.waters.daugherty@woohoo.com	New York	New York	3005596652224868	9677b92f09f521f49622d99ed4192491	Voyager	40.6545051142331175	-74.0214637881971811
45162	2020-08-15 17:49:17	2020-08-15	Argie King	argie.king@warmmail.com	San Francisco	California	3158124069498747761	f9468f3b848cfffe9173e0cbdda8b3eb	VISA 13 digit	37.7814327319292715	-122.417664079848208
45163	2020-08-15 17:51:44	2020-08-15	Denzel Nikolaus	denzel.nikolaus@warmmail.com	Los Angeles	California	55699253846621119	f0ea71bf45fd30f8a4108a548c2c4755	Voyager	34.0926807998079795	-118.49313688329346
45164	2020-08-15 17:58:59	2020-08-15	Raekwon Hessel	raekwon.hessel@woohoo.com	Colorado Springs	Colorado	3337989182339750631	20ec7aef564c2ffe84f69ddd6a02d882	American Express	38.8860895794399113	-104.755837176476419
45165	2020-08-15 17:59:45	2020-08-15	Shatara Altenwerth	shatara.altenwerth@geemail.com	Plano	Texas	3337366782904930782	d9bde1638690476321ecfbc734e8f6de	JCB 15 digit	33.01080248906203	-96.6835670277658892
45166	2020-08-15 18:05:13	2020-08-15	Skye Torp	skye.torp@geemail.com	Jacksonville	Florida	4796245894878411	28654520eda79bcc58f368fe32d142ff	Diners Club / Carte Blanche	30.3083008682873114	-81.5679962753396524
45167	2020-08-15 18:06:40	2020-08-15	Herminia Blick	herminia.blick@geemail.com	Waterbury	Connecticut	4138711373229779	ce3a8fbdf43de9404557eea2ebb5d367	Maestro	41.5736242887135603	-73.1350433648478173
45168	2020-08-15 18:06:52	2020-08-15	Nataly Rogahn	nataly.rogahn@geemail.com	Hartford	Connecticut	4693547786537615	0853adb359fedac8d80fd64f0c64fe0f	Maestro	41.6801130995169302	-72.6807009367629888
45169	2020-08-15 18:08:48	2020-08-15	Demarco Gulgowski	demarco.gulgowski@geemail.com	Peoria	Illinois	6011705421180770360	f427c338cef027caf5463204e68ac1c0	American Express	40.7427529566325219	-89.5692623678945097
45170	2020-08-15 18:25:38	2020-08-15	Jammie Hilll	jammie.hilll@geemail.com	Burbank	California	869914557349552060	cc85fad9bc21716cfbdf8fb2280793fc	Diners Club / Carte Blanche	34.147146503946189	-118.29398487070911
45171	2020-08-15 18:30:22	2020-08-15	Amin Kling	amin.kling@geemail.com	San Francisco	California	4308776427707	b46fa2c01929967d1f6b993b976752b2	JCB 16 digit	37.7749949315136249	-122.426891078012119
45172	2020-08-15 18:33:50	2020-08-15	Vashti Schuster-Bergnaum	vashti.schuster.bergnaum@geemail.com	Richmond	Virginia	3005740860996483	48d65f363694617bb53ed69291ce4caa	Discover	37.5320822169292683	-77.4088054232057203
45173	2020-08-15 18:35:15	2020-08-15	Xzavier Rice	xzavier.rice@geemail.com	Oakland	California	4651664632025065	153626018a1f2214e2ea469877cb1bb3	Mastercard	37.8033406735174822	-122.266235191581828
45174	2020-08-15 18:36:35	2020-08-15	Ebb Abshire	ebb.abshire@geemail.com	New York	New York	52455808547430120	28ebc8bb3ff012ca59830cac69426bba	JCB 16 digit	40.7046528038792275	-73.9957449157617901
45175	2020-08-15 18:59:50	2020-08-15	Cleda Jones	cleda.jones@geemail.com	Madison	Wisconsin	3096734757065312116	54a908c36e7007059401a939b46f6fd0	JCB 15 digit	43.115172392034161	-89.4403031616821949
45176	2020-08-15 19:05:39	2020-08-15	Jaquan Cassin V	jaquan.cassin.v@geemail.com	San Francisco	California	3096122371270968819	0a806919eff1e1a9d6f5a3723dd8e240	VISA 16 digit	37.7844245215341203	-122.454771265786732
45177	2020-08-15 19:23:20	2020-08-15	Aniya Emmerich-Purdy	aniya.emmerich.purdy@geemail.com	Seattle	Washington	869923598177942030	e37c2ce833d3a67e700b25f6a1e16505	JCB 15 digit	47.6402576812468439	-122.411457781765236
45178	2020-08-15 19:30:10	2020-08-15	Queen Erdman	queen.erdman@geemail.com	Los Angeles	California	4412629207306	4397e2fff48c72b4dece8e6ba900e1c6	VISA 16 digit	33.993097723820803	-118.391159378037969
45179	2020-08-15 19:41:16	2020-08-15	Miss Matie Quigley	miss.matie.quigley@geemail.com	Wichita	Kansas	4750843016450525	01af5488ba33bd0a113f2bbc9da503fe	JCB 15 digit	37.6068228701937954	-97.4391347354013533
45180	2020-08-15 19:48:00	2020-08-15	Letitia Simonis	letitia.simonis@woohoo.com	Minneapolis	Minnesota	3158839498263941406	d92070eb6551ed135692bf5bdde4fe23	Maestro	44.9695406483571958	-93.3012927834216441
45181	2020-08-15 19:50:25	2020-08-15	Willa Dibbert	willa.dibbert@woohoo.com	Cary	North Carolina	3038038017374721	c08e44d0f9cdf4d284e287597abcbb77	VISA 16 digit	35.7158295158870516	-78.8731046209197473
45182	2020-08-15 19:56:33	2020-08-15	Micheal Russel I	micheal.russel.i@geemail.com	Oakland	California	3528436468348935928	0dd7bc850946e9f78137ca57ab9f32db	Voyager	37.8141611442952978	-122.26694092121231
45183	2020-08-15 20:06:29	2020-08-15	Sherita Parisian DDS	sherita.parisian.dds@geemail.com	Dallas	Texas	675946748738351	554e9e579f85f132bfee9d82d47ce9c1	VISA 16 digit	32.8617654904529459	-96.8213293645493565
45184	2020-08-15 20:07:36	2020-08-15	Mardell Hand	mardell.hand@geemail.com	Richmond	Virginia	3112114925425146439	17189fcc9a6e63273313e74093ef06f7	JCB 16 digit	37.5393930150415756	-77.3919420711919628
45185	2020-08-15 20:07:48	2020-08-15	Rhianna Klocko-Walsh	rhianna.klocko.walsh@geemail.com	Berkeley	California	4430858784309446	00f338fe9975893ffec9e6a7c3210e8d	Discover	37.8486889675739135	-122.280250901034591
45186	2020-08-15 20:14:15	2020-08-15	Paisley Stracke	paisley.stracke@geemail.com	Oakland	California	210016485118427462	a53f9b881f83ed1627d944e711201c8d	JCB 16 digit	37.8175539002279777	-122.237304417104369
45187	2020-08-15 20:20:42	2020-08-15	Eric Blick	eric.blick@geemail.com	Long Beach	California	210071157370336523	9b9721d636fbafb119ead818e8ed1036	American Express	33.7309023272067279	-118.103590782747787
45188	2020-08-15 20:22:13	2020-08-15	Alaya Kassulke DVM	alaya.kassulke.dvm@geemail.com	Lexington	Kentucky	6011948861335330833	192f2285e591ecc891e6471e321e6eb4	Maestro	38.0396540523849467	-84.4816814761042565
45189	2020-08-15 20:32:19	2020-08-15	Shawn Friesen MD	shawn.friesen.md@geemail.com	Lancaster	California	4296690620474115	4e15cd3307d0cd467192f3fdcdab065b	VISA 16 digit	34.683450773988298	-118.17517924969755
45190	2020-08-15 20:35:28	2020-08-15	Miss Natalee Hirthe DDS	miss.natalee.hirthe.dds@geemail.com	Fayetteville	North Carolina	54410321657803296	c5d9af6fa1ea61e13706a4de5c81d117	VISA 16 digit	35.0594306436154994	-78.9903286459986163
45191	2020-08-15 20:40:20	2020-08-15	Taryn Smith	taryn.smith@geemail.com	San Antonio	Texas	6011968721605360255	f0fe72ef42fa7db65d76fe1e1d2a2cff	VISA 16 digit	29.3979821745377023	-98.5484005963265872
45192	2020-08-15 20:41:39	2020-08-15	Harrison Jakubowski	harrison.jakubowski@geemail.com	New York	New York	502072368485834	1dd7c5bf8f054788376fc8c8760e5837	Diners Club / Carte Blanche	40.6972115278001851	-73.8410315481841479
45193	2020-08-15 20:54:25	2020-08-15	Thresa Rolfson	thresa.rolfson@geemail.com	Pompano Beach	Florida	3158049525763279204	052dda3afd83834bbc3c7aed98362f2e	JCB 15 digit	26.1993545706182687	-80.0452803680986165
45194	2020-08-15 20:58:36	2020-08-15	Dr. Margarita Crist	dr.margarita.crist@geemail.com	Oceanside	California	3088576521742353336	7e71f99e5ff5fd90fced3f891b044c8d	Mastercard	33.3087515522148436	-117.327737383040414
45195	2020-08-15 21:14:13	2020-08-15	Dustyn Boyer-Gutmann	dustyn.boyer.gutmann@geemail.com	Berkeley	California	4560069863200	bfdc6b20d7988082929a3026955d63f5	Voyager	37.8389681945358021	-122.28402159436547
45196	2020-08-15 21:20:26	2020-08-15	Angel Friesen	angel.friesen@geemail.com	Virginia Beach	Virginia	502078499729255	6dfa136d334f2ef408ecd9c5bb33dd1b	JCB 16 digit	36.7122826105169935	-76.0280934840112934
45197	2020-08-15 21:29:53	2020-08-15	Jazmin Walsh MD	jazmin.walsh.md@geemail.com	Irving	Texas	4884202260839	c5d15c0836b97a8b7a3dc3469da0c24f	JCB 16 digit	32.7995087984900948	-96.9965972373541376
45198	2020-08-15 21:31:35	2020-08-15	Eola Orn	eola.orn@geemail.com	San Jose	California	3050101031972322	cf3cbedbcaefe7c211fa4f2c009a9ca0	Voyager	37.319638063740733	-121.848420526388665
45199	2020-08-15 21:36:09	2020-08-15	Trevor Marvin IV	trevor.marvin.iv@geemail.com	New York	New York	869922060270572488	521df9f0b06d6fd8064061b0bdfb46ab	Voyager	40.6289284237418329	-74.0179625423986494
45200	2020-08-15 21:36:28	2020-08-15	Nanette Stiedemann	nanette.stiedemann@geemail.com	El Paso	Texas	3471993018950121	07283fb5458f64655064c7bf1d912844	Mastercard	31.8227894896935695	-106.52619463568368
45201	2020-08-15 21:38:02	2020-08-15	Miss Pat Deckow	miss.pat.deckow@geemail.com	San Francisco	California	3456241599955724	f69140f44fc0510cd65eb81b8d89dfdb	JCB 16 digit	37.7860361965764895	-122.419739298845229
45202	2020-08-15 21:38:15	2020-08-15	Evonne Murazik	evonne.murazik@geemail.com	Los Angeles	California	3528426240127579892	afc971e03139acba6ba55ec0fce32705	Discover	34.0031812174111607	-118.366655298601088
45203	2020-08-15 21:44:50	2020-08-15	Mr. Hosteen Stroman	mr.hosteen.stroman@geemail.com	Oakland	California	6011608936362011414	c1a50ba0c71160582bdcda09652adeb0	JCB 16 digit	37.7972140371398737	-122.271549081192191
45204	2020-08-15 21:52:26	2020-08-15	Laverne Wilkinson	laverne.wilkinson@geemail.com	Omaha	Nebraska	210045679549675021	ce929dba5ada14a24489cb4e96eada39	JCB 16 digit	41.2023669189918778	-95.9617905859951037
45205	2020-08-15 22:00:23	2020-08-15	Arbie Funk	arbie.funk@woohoo.com	San Francisco	California	676235892741485	1233b5fa49d0ea43925e6166b935b16b	Maestro	37.7584147613668009	-122.440949464334565
45206	2020-08-15 22:04:10	2020-08-15	Jaliyah Farrell-Langosh	jaliyah.farrell.langosh@geemail.com	Paterson	New Jersey	3088184269186779350	5b29e9d9d2c605fda173103d25625143	American Express	41.0016962532374976	-74.122098153454445
45207	2020-08-15 22:06:03	2020-08-15	Shelley Schimmel	shelley.schimmel@geemail.com	Houston	Texas	4421134252473242	82a2da9fd962baa82765a632f0f3acfd	Maestro	29.8006412752050913	-95.4593981324244254
45208	2020-08-15 22:23:53	2020-08-15	Erla Kshlerin	erla.kshlerin@woohoo.com	Lexington	Kentucky	6011956257777242983	72ff84cae48e8e6d36b17e9c644c51b9	VISA 13 digit	38.0908085286028708	-84.4073798783022795
45209	2020-08-15 22:35:58	2020-08-15	Dr. Murdock Watsica	dr.murdock.watsica@warmmail.com	Evansville	Indiana	4501772224684694	9bd5df7226588bc97064216915fb77b1	Diners Club / Carte Blanche	37.9371617790915039	-87.6343172077488219
45210	2020-08-15 22:45:46	2020-08-15	Darell Stoltenberg	darell.stoltenberg@geemail.com	San Francisco	California	4923177374637	578acc8d4075ee0854fd59e50dbe4e39	Mastercard	37.7967684811148601	-122.402871523259975
45211	2020-08-15 22:57:17	2020-08-15	Dr. Carissa Dooley	dr.carissa.dooley@geemail.com	San Francisco	California	4238501478479	43be7312e7468bc066ec02cca0e1ea9f	American Express	37.7762697600585398	-122.40500692642658
45212	2020-08-15 23:05:18	2020-08-15	Leamon Connelly	leamon.connelly@geemail.com	Hartford	Connecticut	869935559264747688	43931cba94b2f1485f44b617d13ae7af	Discover	41.8312271793387822	-72.6265336668476493
45213	2020-08-15 23:17:29	2020-08-15	Zillah Effertz	zillah.effertz@geemail.com	Little Rock	Arkansas	4663758674598819	8ec52a9f97cd47f7c6874b8b406f55cc	American Express	34.783390045612677	-92.4002203908156616
45214	2020-08-15 23:29:48	2020-08-15	Teena Tremblay	teena.tremblay@geemail.com	Aurora	Colorado	180021569582726153	b17bbce449bb395b4774c6aec2acd979	Diners Club / Carte Blanche	39.6496360833402761	-104.694631930080064
45215	2020-08-15 23:48:17	2020-08-15	Dr. Heather Ortiz	dr.heather.ortiz@geemail.com	Oklahoma City	Oklahoma	3337086245672413257	9181092feb8c187b2c6b807c0e8205cc	Mastercard	35.4008238464038811	-97.4628970641538501
45216	2020-08-15 23:57:21	2020-08-15	Tandy Rosenbaum	tandy.rosenbaum@geemail.com	Little Rock	Arkansas	3337326536355454109	8d85366714eaff8c8d7f6dcc35614c31	Diners Club / Carte Blanche	34.7028817107711021	-92.4042484999507678
45217	2020-08-16 00:08:37	2020-08-16	Olga Wilderman	olga.wilderman@geemail.com	Wichita	Kansas	4766487802213	2506ec69a5236989915af6bffee8ae3d	VISA 13 digit	37.6910814970608783	-97.2670259972769742
45218	2020-08-16 00:09:05	2020-08-16	Ms. Leonie Okuneva	ms.leonie.okuneva@geemail.com	Laredo	Texas	3003914822495254	1403735f43f5f608d37322787cae0f28	VISA 16 digit	27.5315044809315381	-99.5882007426124005
45219	2020-08-16 00:09:59	2020-08-16	Mr. Buford Zieme	mr.buford.zieme@geemail.com	San Francisco	California	3528802468499555562	d95501eec92da0addefec3c0b44b471f	VISA 16 digit	37.7627753533148081	-122.431911907557023
45220	2020-08-16 00:28:58	2020-08-16	Lorne Little	lorne.little@geemail.com	San Francisco	California	55112410582227266	a595e0744f13a200dfebe92297d99930	Diners Club / Carte Blanche	37.7988394120326703	-122.44583924663732
45221	2020-08-16 00:36:35	2020-08-16	Dr. Arnulfo Tromp I	dr.arnulfo.tromp.i@geemail.com	San Francisco	California	4630678339807746	729e7a716c8010097be248d61d42f635	JCB 15 digit	37.7942552730717054	-122.470190909827764
45222	2020-08-16 00:38:56	2020-08-16	Jewell Pouros V	jewell.pouros.v@geemail.com	Memphis	Tennessee	3337991507228156043	81ebab2d0b01188ed565db1ac13d2543	Maestro	35.1856470506239702	-90.049663006865984
45223	2020-08-16 00:45:01	2020-08-16	Floy Johnson	floy.johnson@geemail.com	Sioux Falls	South Dakota	3790232040881955	0fd34eeddcd20cd81772c405416264e1	VISA 16 digit	43.6319972777824816	-96.8125427987128546
45224	2020-08-16 00:50:59	2020-08-16	Mr. Presley McGlynn I	mr.presley.mcglynn.i@geemail.com	Los Angeles	California	4858985709063	82b79507fb2e5995794b3ec55daa256b	JCB 15 digit	34.0113325832743172	-118.46088958359249
45225	2020-08-16 00:58:11	2020-08-16	Vena Schowalter PhD	vena.schowalter.phd@geemail.com	New York	New York	3700465402995562	f404b480132b3aaed86430073358a20c	VISA 13 digit	40.5644684801567337	-73.9597704677738221
45226	2020-08-16 01:01:59	2020-08-16	Oda Jones	oda.jones@woohoo.com	Daly City	California	53788553856326901	80450b90703787828a1ce9a6224c755e	VISA 13 digit	37.7718476040210547	-122.379664517436183
45227	2020-08-16 01:06:57	2020-08-16	Malia Morissette-Macejkovic	malia.morissette.macejkovic@geemail.com	Oklahoma City	Oklahoma	4688653177365108	a36de22b6329a097e7d43f8712191cc2	VISA 16 digit	35.4451537496786599	-97.5028088725067619
45228	2020-08-16 01:11:39	2020-08-16	Kurt Heidenreich	kurt.heidenreich@geemail.com	Nashville	Tennessee	869975968849261530	3bd52b54bc416e1e251f508356c117ad	Voyager	36.072327224317192	-86.710194177636879
45229	2020-08-16 01:13:48	2020-08-16	Darwyn Koss DDS	darwyn.koss.dds@woohoo.com	Bakersfield	California	3454012114681588	ecc2aefc8ab42401d2e442b5bb6e17ca	JCB 16 digit	35.2701256064873192	-119.086113877481964
45230	2020-08-16 01:18:04	2020-08-16	Annabelle Huel	annabelle.huel@geemail.com	Atlanta	Georgia	676309742669246	18193f7e1c3f065664a8cbb255f98822	JCB 16 digit	33.8094352694503968	-84.4964114373594555
45231	2020-08-16 01:21:26	2020-08-16	Elon Hartmann	elon.hartmann@geemail.com	Chicago	Illinois	210040324862853393	fcbc4da622a3d9ec7645206b710d586f	JCB 15 digit	41.8019566558137541	-87.7615134383581506
45232	2020-08-16 01:32:18	2020-08-16	Mrs. Attie Schiller	mrs.attie.schiller@woohoo.com	Arvada	Colorado	55514267439810395	0f5f699f843feaffedd3611ac9a73ff7	VISA 13 digit	39.8382754347927843	-105.156840688779212
45233	2020-08-16 01:37:51	2020-08-16	Redmond Flatley-Rolfson	redmond.flatley.rolfson@geemail.com	Portland	Oregon	53393795750157273	6586e7b255bceeef27e5e3a753cad83f	Diners Club / Carte Blanche	45.5822803604770428	-122.67550139548257
45234	2020-08-16 01:40:44	2020-08-16	Ethan Cremin	ethan.cremin@geemail.com	San Antonio	Texas	4573098017796450	e870a19f36f4cb2fe3a22081073589ee	Voyager	29.490643211740629	-98.5617551687940932
45235	2020-08-16 01:40:48	2020-08-16	Mr. Kadyn Lebsack	mr.kadyn.lebsack@geemail.com	Beaumont	Texas	3528486359387996377	cb50a5c8e473655dbff818d9b7c329d4	JCB 16 digit	30.0028867872968341	-94.063808892972034
45236	2020-08-16 02:02:40	2020-08-16	Tamika Cormier	tamika.cormier@geemail.com	Chicago	Illinois	53098939517539906	8db43935b7c10c0b96163785f68c08a5	Diners Club / Carte Blanche	41.9167264939121935	-87.7808318936295819
45237	2020-08-16 02:16:34	2020-08-16	Laurel Wisozk	laurel.wisozk@woohoo.com	San Jose	California	3158155535309752325	a8907b698c151859fbf5fa9a9a641af8	JCB 15 digit	37.3772249579716487	-121.852431622402364
45238	2020-08-16 02:25:46	2020-08-16	Dallas Simonis	dallas.simonis@woohoo.com	Los Angeles	California	3703094476825757	44d845b213db5f516f2d863d9340f42d	VISA 13 digit	34.0051061926741127	-118.36125417463407
45239	2020-08-16 02:28:39	2020-08-16	Mr. Hugo Fritsch	mr.hugo.fritsch@geemail.com	Oklahoma City	Oklahoma	4800735753421	7ecd30be1c603dbb212a17bed9acd2b1	JCB 15 digit	35.5005102980326868	-97.4928807939764113
45240	2020-08-16 02:37:08	2020-08-16	Latonia Collins	latonia.collins@woohoo.com	Lincoln	Nebraska	3337482643978422743	ff38765981a0b7330736269a4737d013	Voyager	40.9085175730772264	-96.7503603708624809
45241	2020-08-16 02:48:21	2020-08-16	Robby Wehner	robby.wehner@geemail.com	New York	New York	4174484467892010	f50d030ec82cedda6a2d58031ac395ad	American Express	40.7048676764350361	-73.849251581066099
45242	2020-08-16 03:07:09	2020-08-16	Veta Anderson	veta.anderson@geemail.com	High Point	North Carolina	3096124874411657561	5e7871a10e6da08e702c1f4b4c5586db	JCB 16 digit	35.9302909950818901	-79.9834439205676233
45243	2020-08-16 03:07:37	2020-08-16	Lorne Klocko	lorne.klocko@geemail.com	Berkeley	California	54209628972903121	f8a2ec53fece6f8e2e0cdba9547ff116	VISA 16 digit	37.8734452822697421	-122.297863954232483
45244	2020-08-16 03:08:38	2020-08-16	Makena Strosin	makena.strosin@warmmail.com	North Las Vegas	Nevada	4374682096692903	97aaad558d02a806ee9e65d8d3de3580	JCB 15 digit	36.2821450750965582	-115.145755598762634
45245	2020-08-16 03:13:41	2020-08-16	Hildegard Gaylord DVM	hildegard.gaylord.dvm@geemail.com	San Diego	California	675923961908763	7d6f7e5eebf49bc862c24c7852f439cb	JCB 16 digit	32.759101974039524	-117.14975085024723
45246	2020-08-16 03:14:00	2020-08-16	Miriah Nitzsche	miriah.nitzsche@geemail.com	Lakeland	Florida	869981881252463935	18a01d9df447b2531a09f6ab18c48d91	JCB 16 digit	28.0224249820522964	-81.8993710331037619
45247	2020-08-16 03:17:16	2020-08-16	Araminta Schultz-Price	araminta.schultz.price@warmmail.com	Irving	Texas	4808201536493	220fbe7cc33532574f2d18f57a2c4ecc	Discover	32.935124047142267	-96.9896242971811375
45248	2020-08-16 03:25:44	2020-08-16	Joanna Walsh PhD	joanna.walsh.phd@geemail.com	Kansas City	Missouri	4921598218896	9cfae0cb44b43e05c7f3717f39e4db7e	Mastercard	39.2232225554831331	-94.5112353518828741
45249	2020-08-16 03:34:00	2020-08-16	Emily Walker	emily.walker@geemail.com	Phoenix	Arizona	4548062706211	35f2d57dd33af4dd07fc31617eb125cc	JCB 16 digit	33.6315388386536398	-112.113473639537034
45250	2020-08-16 03:36:30	2020-08-16	Jadyn Ernser	jadyn.ernser@geemail.com	Chicago	Illinois	502098305293122	481259f53d656096418e671957c5dc54	VISA 13 digit	41.8992626931820098	-87.6770063042204839
45251	2020-08-16 03:39:43	2020-08-16	Thurman Hodkiewicz	thurman.hodkiewicz@geemail.com	Naperville	Illinois	3475135526758887	10a6a1fa68e3e377671c7c6fcbff618f	Diners Club / Carte Blanche	41.7634153132241224	-88.1278471632748932
45253	2020-08-16 03:52:56	2020-08-16	Caitlyn Huel	caitlyn.huel@geemail.com	Saint Paul	Minnesota	54081739618652163	ab00cffc65e0c57ca851470112d3df17	VISA 16 digit	44.8595311748269978	-93.1776958349891089
45254	2020-08-16 03:54:44	2020-08-16	Mr. Othel Ritchie	mr.othel.ritchie@geemail.com	Springfield	Illinois	210094994217050054	64c0928f9b83e55dd8166b2adc035f28	Mastercard	39.8152206884384157	-89.6467004118490962
45255	2020-08-16 03:56:20	2020-08-16	Derald Lueilwitz II	derald.lueilwitz.ii@geemail.com	Los Angeles	California	6011541446434021813	c190208e9c7bb96940ee449ea6c99f77	Discover	34.007386796535549	-118.397261187154044
45256	2020-08-16 04:00:22	2020-08-16	Effie Hermiston-Shields	effie.hermiston.shields@geemail.com	Garland	Texas	3112402758065894112	79efb35d790202f912e0a3bbd54b0f1f	JCB 15 digit	32.8935665685452463	-96.5794920030210164
45257	2020-08-16 04:05:51	2020-08-16	Mrs. Tanja Crist PhD	mrs.tanja.crist.phd@geemail.com	Chicago	Illinois	869938233242162579	6a8a3ab6341bf33fdf59e5c8df8767ea	American Express	41.8464981750421217	-87.6341641698993641
45258	2020-08-16 04:25:26	2020-08-16	Lupe Gusikowski V	lupe.gusikowski.v@geemail.com	Chicago	Illinois	180091891433746049	f87d201f6dc80bba21125f0e68ca746c	Maestro	41.7787686799488966	-87.6841046535905377
45259	2020-08-16 04:28:26	2020-08-16	Clemon Wisoky	clemon.wisoky@geemail.com	Yonkers	New York	3158811397714362695	18019017bc3bcdc402ccea8803d96cad	VISA 16 digit	40.8742060752786713	-73.847397960757462
45260	2020-08-16 04:29:59	2020-08-16	Dr. Avis Cormier PhD	dr.avis.cormier.phd@warmmail.com	Phoenix	Arizona	3158479107478748515	be426bd05214bb834f7a1d3d13ca42dc	Mastercard	33.4846389963224524	-112.155239751322569
45261	2020-08-16 04:33:48	2020-08-16	Dr. Alana Emmerich	dr.alana.emmerich@geemail.com	Dallas	Texas	4779347157956545	92bdf532398cc40203d36c4087d5290d	Mastercard	32.807577820196002	-96.7593253562655207
45262	2020-08-16 04:42:03	2020-08-16	Wing Schamberger	wing.schamberger@geemail.com	San Francisco	California	4847547820682935	83fdca9c4fdd18b7410e1bd8a2cc53fd	VISA 13 digit	37.7571091615670511	-122.433846511932458
45263	2020-08-16 04:51:25	2020-08-16	Mrs. Rhoda Daniel	mrs.rhoda.daniel@geemail.com	Jacksonville	Florida	210015003609835522	545b2d6f2d3ad888b3eb20d279b3882e	VISA 16 digit	30.3332583175558597	-81.6763829041350675
45264	2020-08-16 05:08:47	2020-08-16	Lular Lemke DDS	lular.lemke.dds@geemail.com	Kansas City	Missouri	3096305393884008815	125c5c7e71c239dd033bd70808744e09	Maestro	39.0697678387932541	-94.5308652148805635
45265	2020-08-16 05:09:59	2020-08-16	Moe Keebler	moe.keebler@geemail.com	Oakland	California	55521416001444494	aa3130103b40e91282092929e3c8133c	Voyager	37.7702881642304504	-122.250088758238007
45266	2020-08-16 05:11:21	2020-08-16	Pearlie Cummerata	pearlie.cummerata@geemail.com	Oakland	California	630455697633059	178006cb4371dacb447f4c59848cbce7	Maestro	37.7960927983085568	-122.287701061595328
45267	2020-08-16 05:15:04	2020-08-16	Alfonse Reichert	alfonse.reichert@geemail.com	Dallas	Texas	3023902638033088	eb262ca1f3747f55f2110ab63f5737d2	JCB 15 digit	32.8392976310841789	-96.7408866853881619
45268	2020-08-16 05:18:32	2020-08-16	Burleigh Bartoletti	burleigh.bartoletti@geemail.com	San Jose	California	180060491030839623	df9048f31cc0c7ea790df029c956a82b	Discover	37.3392576646346583	-121.874984256712352
45269	2020-08-16 05:21:44	2020-08-16	Jerrold Lueilwitz	jerrold.lueilwitz@geemail.com	Saint Paul	Minnesota	869987901894970537	3da87759b791d458f23e03f6bd67056c	JCB 16 digit	45.0317751323744702	-93.0731508017316429
45270	2020-08-16 05:22:40	2020-08-16	Miss Caitlynn Rempel DVM	miss.caitlynn.rempel.dvm@geemail.com	Boulder	Colorado	4503236984287005	ef6f2f8aa71c226b7489dfa96e9e99e2	VISA 13 digit	40.0478344895858314	-105.302906733998668
45271	2020-08-16 05:35:04	2020-08-16	Mr. Brittany Bruen Jr.	mr.brittany.bruen.jr.@geemail.com	New York	New York	869943251140405604	d005d280512d2ff39bd638ce3d2eeefe	JCB 15 digit	40.5670158033017074	-73.9288424713432732
45272	2020-08-16 05:38:37	2020-08-16	Sinda Ruecker-Mraz	sinda.ruecker.mraz@geemail.com	High Point	North Carolina	675908725836277	560044344afaed2af0513224ba7121c1	JCB 16 digit	35.9803105336241416	-80.0327572519630195
45273	2020-08-16 05:38:50	2020-08-16	Rueben Kautzer	rueben.kautzer@geemail.com	Los Angeles	California	51681571830058539	f63bde79d33ae089607cdfbd6d3279c2	VISA 16 digit	33.9559738101303523	-118.350021160439766
45274	2020-08-16 05:43:41	2020-08-16	Ryley Abernathy	ryley.abernathy@warmmail.com	Orlando	Florida	3039987849403257	5e2d2e24e281517ab00e853330c18d3c	VISA 16 digit	28.3676761227924352	-81.3477779424250116
45275	2020-08-16 05:45:52	2020-08-16	Dr. Leatha Raynor	dr.leatha.raynor@woohoo.com	Tucson	Arizona	3400398530790755	27718b44aee084a84c7491a05ae59160	Maestro	32.2321541416499784	-110.860703575354435
45276	2020-08-16 05:48:13	2020-08-16	Justina Bode	justina.bode@warmmail.com	San Antonio	Texas	4666664941525485	47d06108992353766848580696fe043a	JCB 16 digit	29.4773561391118903	-98.5166081990416984
45277	2020-08-16 05:48:46	2020-08-16	Lailah Kemmer	lailah.kemmer@woohoo.com	Escondido	California	4500773728844	094097f70d01977410bfccb60eeef78d	VISA 13 digit	33.0836337624810639	-117.104347917554904
45278	2020-08-16 05:51:19	2020-08-16	Halbert Baumbach	halbert.baumbach@warmmail.com	Baton Rouge	Louisiana	3035977859844734	811ba38d66e5099e3e85ce86c069f5cc	Diners Club / Carte Blanche	30.3827746126081806	-91.1645614688392669
45279	2020-08-16 05:53:50	2020-08-16	Yurem Harvey	yurem.harvey@geemail.com	Sacramento	California	3785005047055212	6fbda73d642321e03d6b85b13fc23294	American Express	38.4825597528632741	-121.541354537221039
45280	2020-08-16 06:08:18	2020-08-16	Welton Davis	welton.davis@geemail.com	Henderson	Nevada	4219638727301	86454e7003044d9e3ecf3b6730b222eb	VISA 16 digit	35.9253660741660781	-115.061157929819828
45281	2020-08-16 06:08:31	2020-08-16	Shelbi Blick	shelbi.blick@warmmail.com	Anaheim	California	4558016835115	1cd563aabf676cc10811c3d36424f720	JCB 15 digit	33.8038512534759903	-117.835243996812395
45282	2020-08-16 06:19:37	2020-08-16	Mrs. Rae Bernhard	mrs.rae.bernhard@warmmail.com	Henderson	Nevada	630432623965095	62dfa85305a3ca7d9e6ca700f66c724a	VISA 16 digit	36.0426653200693465	-114.940084345980367
45283	2020-08-16 06:22:49	2020-08-16	Ariel Kovacek-Frami	ariel.kovacek.frami@woohoo.com	Austin	Texas	53620360940664988	72e323622ee003b6cf0c931e3d993f8e	VISA 16 digit	30.3454986713487642	-97.6564411459729058
45284	2020-08-16 06:30:16	2020-08-16	Ottie Conroy Sr.	ottie.conroy.sr.@geemail.com	San Francisco	California	3008762344489627	9c88a3695e6fb054bcc9530745933e06	VISA 16 digit	37.7291353688530506	-122.41720911689626
45285	2020-08-16 06:31:49	2020-08-16	Acie Weber-Bogan	acie.weber.bogan@woohoo.com	Lubbock	Texas	4182454091865	0d9a012bb07d5b808b95633f291f4f21	Mastercard	33.5207477999426473	-101.872603233941646
45286	2020-08-16 07:02:47	2020-08-16	Angel Kris-Willms	angel.kris.willms@geemail.com	Stamford	Connecticut	4964675805459214	317fa3dd3b559031988fb34b1e0983bd	VISA 13 digit	41.0517379119876793	-73.4921659283842956
45287	2020-08-16 07:08:05	2020-08-16	Refugio Kling I	refugio.kling.i@geemail.com	Colorado Springs	Colorado	4539733951102058	9b4f2555b6f1c0e7be113840eeb71380	Voyager	38.9166591212201851	-104.860296543051305
45288	2020-08-16 07:11:42	2020-08-16	Mr. Zaire Cruickshank	mr.zaire.cruickshank@geemail.com	Orange	California	180095458435464629	f2c270d9ab98cda67a11b7a50a0f46fb	Maestro	33.8781809770856057	-117.839708303251484
45289	2020-08-16 07:11:59	2020-08-16	Tiarra Bogisich	tiarra.bogisich@geemail.com	Clovis	California	210017131856906353	9ffd74a0877eb57d9ab76b06c32697f5	Mastercard	36.7813628700904545	-119.747834554228561
45290	2020-08-16 07:17:29	2020-08-16	Jaxson Dietrich	jaxson.dietrich@geemail.com	Columbus	Ohio	3528343043590602542	9da37266ede2b21007d459daf2e8d7a1	Discover	39.9251823639541854	-82.9128810947995731
45291	2020-08-16 07:19:02	2020-08-16	Aedan Okuneva	aedan.okuneva@geemail.com	San Francisco	California	54976495052797554	cb7b7449add5f3e9669df21b5ccea7fc	Maestro	37.7586122558037474	-122.415384687745586
45292	2020-08-16 07:22:07	2020-08-16	Rowena Ullrich	rowena.ullrich@geemail.com	Davie	Florida	4056210251690838	f570c865803a9a0091cb913edad73f2d	VISA 16 digit	26.0911990303810697	-80.3657985338382446
45293	2020-08-16 07:25:07	2020-08-16	Tracy Gutkowski	tracy.gutkowski@warmmail.com	Berkeley	California	3009570998834223	3a1fd661f90052d98d0d1084f7c581b8	Voyager	37.8986897002736498	-122.289691695095698
45294	2020-08-16 07:25:50	2020-08-16	Carl Huels	carl.huels@geemail.com	Honolulu	Hawaii	3050877871335288	202acf0e3758e0cbca2d9968fc9ca1ea	JCB 16 digit	21.2980488909158865	-157.847429352041701
45295	2020-08-16 07:29:11	2020-08-16	Iris Mraz-Runolfsson	iris.mraz.runolfsson@geemail.com	Berkeley	California	3055059663059054	bccf1e12ddbc32bcba7bf47465c7a0cf	Maestro	37.871862498564397	-122.278190636424682
45296	2020-08-16 07:43:31	2020-08-16	Rinda Senger	rinda.senger@geemail.com	Pomona	California	060407045835779	cbd96d82b603e10a12e32dbd6f006952	Discover	34.0942403681147894	-117.832385187825565
45297	2020-08-16 07:44:38	2020-08-16	Kathryn Miller	kathryn.miller@warmmail.com	Virginia Beach	Virginia	3018027285619339	95fcc52b076a8a148f31d45b58c8a348	VISA 13 digit	36.8350065290182869	-75.9293697065811557
45298	2020-08-16 07:50:15	2020-08-16	Mr. Torrey Hammes III	mr.torrey.hammes.iii@geemail.com	Jacksonville	Florida	54521592020309775	19c7b9db61ea3559ad71917353145b1c	VISA 16 digit	30.2964162183512009	-81.7453224844377502
45299	2020-08-16 07:59:10	2020-08-16	Johnnie Veum Sr.	johnnie.veum.sr.@geemail.com	Berkeley	California	180060906503548047	86837e1c82476fc35e54b615f732da77	JCB 16 digit	37.8780702882950138	-122.244811889432384
45300	2020-08-16 08:04:08	2020-08-16	Miss Jaidyn Greenfelder	miss.jaidyn.greenfelder@geemail.com	Oakland	California	3797026788741519	c340e35c4c591dcd9abe37498a2c2975	JCB 15 digit	37.8097208612574178	-122.282683591499776
45301	2020-08-16 08:04:15	2020-08-16	Dr. Boone Lang	dr.boone.lang@geemail.com	Murfreesboro	Tennessee	3528170977574147438	9176a07dab95bb3062c990c4bf02b652	Diners Club / Carte Blanche	35.9481766630549018	-86.3834019532278177
45302	2020-08-16 08:04:20	2020-08-16	Hosie Kreiger	hosie.kreiger@warmmail.com	Nashville	Tennessee	6011466008303994784	a26fe92ed3bacaf2b05e0a12da15ab15	VISA 16 digit	36.0942793744273445	-86.710456638401368
45303	2020-08-16 08:05:14	2020-08-16	Nova Lebsack	nova.lebsack@woohoo.com	Louisville	Kentucky	4956252122640437	c58ead7df371b1a5f3caf8205d5a3ebb	Diners Club / Carte Blanche	38.1036113814819615	-85.55845525172316
45304	2020-08-16 08:20:46	2020-08-16	Kenton Kuphal	kenton.kuphal@geemail.com	Surprise	Arizona	4403517138671249	6e838b668912c63aaafeaae7620be162	American Express	33.7161038680695029	-112.353906530071782
45305	2020-08-16 08:25:12	2020-08-16	Eldon Kessler	eldon.kessler@geemail.com	New York	New York	869902061637082330	b9d8bb54a7f318a1692e00bcadc205b2	VISA 13 digit	40.7062786884829393	-74.0309180729452549
45306	2020-08-16 08:25:21	2020-08-16	Lyn Waelchi MD	lyn.waelchi.md@geemail.com	San Angelo	Texas	180064272980315830	d37afc6c46e4a10951c40d7d86e0642c	American Express	31.4168598994765418	-100.515993916114795
45307	2020-08-16 08:39:53	2020-08-16	Jeffrey Casper	jeffrey.casper@geemail.com	Oakland	California	3005267107944522	ae26eb885b82764e7018c0e4cac5a687	JCB 15 digit	37.8390735013251955	-122.288681400360474
45308	2020-08-16 08:43:37	2020-08-16	Elna Legros MD	elna.legros.md@woohoo.com	Tucson	Arizona	4822143941737763	0230af13e12a0921378f011d60735d67	JCB 16 digit	32.2463978010270793	-110.782753621856116
45309	2020-08-16 08:48:49	2020-08-16	Marylyn Jacobs-Wehner	marylyn.jacobs.wehner@geemail.com	Columbia	South Carolina	676113595770804	4b26940bb6ff735320d1e4ae54c557a6	JCB 15 digit	34.0011178934745502	-80.9371390796285084
45310	2020-08-16 08:51:30	2020-08-16	Torry Gislason MD	torry.gislason.md@geemail.com	San Francisco	California	180086146349954162	b8d3073ce061a6ed1cc967fcc584b880	Discover	37.7366929749783679	-122.47524688510974
45311	2020-08-16 08:52:11	2020-08-16	Berenice Padberg	berenice.padberg@geemail.com	Little Rock	Arkansas	3528986413239849063	a297f61cff84709e00b414067656d702	Mastercard	34.7788975034184773	-92.4047246082559184
45312	2020-08-16 08:53:10	2020-08-16	Ian Aufderhar	ian.aufderhar@geemail.com	Lubbock	Texas	630473444246554	a54db8bcb4e9929083371c75ea478dc3	Mastercard	33.575130681045728	-101.869456897527726
45313	2020-08-16 08:54:30	2020-08-16	Shira Bode	shira.bode@geemail.com	Columbia	South Carolina	630470628399415	16ffea9bec8d92a1c35b94fd14657f87	American Express	33.9417076120417534	-80.9297713209427911
45314	2020-08-16 08:55:01	2020-08-16	Tab Stark	tab.stark@geemail.com	Inglewood	California	4207249019576960	99d982fcc237fc23d896d2ac0747c9de	Diners Club / Carte Blanche	34.0189532784059665	-118.297756251835452
45315	2020-08-16 08:55:19	2020-08-16	Weaver Klocko	weaver.klocko@geemail.com	Richmond	Virginia	53769668044303506	5a5a57946c24f4ab46e7ac934878e31c	JCB 15 digit	37.6204241338871412	-77.4704849098101249
45316	2020-08-16 08:59:06	2020-08-16	Dr. Zachary Ratke DVM	dr.zachary.ratke.dvm@geemail.com	San Francisco	California	4379281565989646	fd0c022250ff51617ee75b4ae976d6b9	JCB 16 digit	37.7784223284755356	-122.463650703548467
45317	2020-08-16 09:06:01	2020-08-16	Jensen Smitham	jensen.smitham@geemail.com	Vancouver	Washington	210029590566526221	a028a3120d5333f6c337a147d63ec6d8	Diners Club / Carte Blanche	45.6462740669563445	-122.650978614070254
45318	2020-08-16 09:07:00	2020-08-16	Dr. Dalton Mertz	dr.dalton.mertz@geemail.com	Phoenix	Arizona	676349431947040	e55478fe60f46df2a2f92f03ca070707	Maestro	33.5006625240135989	-112.075311569955574
45319	2020-08-16 09:19:10	2020-08-16	Erica Ledner	erica.ledner@geemail.com	New Haven	Connecticut	6011640871410848352	9a84cbfffe9fc1a074ee787f22b608e1	JCB 16 digit	41.3331342789337057	-72.8711519707459985
45320	2020-08-16 09:19:20	2020-08-16	Dr. Pershing Haag Sr.	dr.pershing.haag.sr.@geemail.com	San Francisco	California	4527040311031868	72053ea2470bc9f729c89038e8827bf4	Maestro	37.7779149794961384	-122.424287317504906
45321	2020-08-16 09:19:31	2020-08-16	Kadence Barrows	kadence.barrows@geemail.com	Port St. Lucie	Florida	3096514282250140400	85147df591d28223455548681a743e37	VISA 13 digit	27.2155133233074089	-80.3234955231744863
45322	2020-08-16 09:24:28	2020-08-16	Thomas Tromp	thomas.tromp@geemail.com	Scottsdale	Arizona	3705006459415628	e9f0e3ca9d0b81315f727b73692d4ce3	JCB 16 digit	33.7479710107326483	-111.771190236878013
45323	2020-08-16 09:27:29	2020-08-16	Carolina Ankunding	carolina.ankunding@warmmail.com	Brownsville	Texas	6011881343196757445	414f753b75b993fdc169d582f69f87cc	Diners Club / Carte Blanche	26.0658675190605216	-97.5075870496872739
45324	2020-08-16 09:35:08	2020-08-16	Ari Franecki	ari.franecki@geemail.com	Aurora	Colorado	4841274753075	f0c1705cf2c6403b7808c264a7cae898	Voyager	39.6642442091945568	-104.664605182793736
45325	2020-08-16 09:36:56	2020-08-16	Ms. Tiarra Nikolaus	ms.tiarra.nikolaus@warmmail.com	Phoenix	Arizona	6011990329278062646	d2775ce174cee9edca2e11121fff4615	VISA 16 digit	33.584793597220262	-112.145135977019009
45326	2020-08-16 09:47:34	2020-08-16	Sherlyn Schmeler	sherlyn.schmeler@geemail.com	Arlington	Texas	3783986029939162	ffd1ca80ca4b955b9f899aec98809e67	Voyager	32.6230051280248858	-97.2202514549743455
45327	2020-08-16 09:57:57	2020-08-16	Dr. Nelle Maggio	dr.nelle.maggio@woohoo.com	New York	New York	6011844240517766418	99ba9734818b37b7e7216f1b80b44e8e	JCB 16 digit	40.6552983544990383	-73.8878787661798242
45328	2020-08-16 10:03:19	2020-08-16	Dr. Laken Hammes MD	dr.laken.hammes.md@warmmail.com	Raleigh	North Carolina	4863941611932964	6716d0318ecb22fee2f78a2f3407e228	Mastercard	35.8837443329993633	-78.6973127851199337
45329	2020-08-16 10:03:28	2020-08-16	Dr. Wes Bode Sr.	dr.wes.bode.sr.@geemail.com	Anaheim	California	4704088018699763	30836f2c10cbeb8469f75ae174cb78fb	VISA 13 digit	33.8171984712425626	-117.723283401338747
45330	2020-08-16 10:08:31	2020-08-16	Nataly Senger	nataly.senger@warmmail.com	Columbus	Ohio	3528692767538349587	527b794d57b0e36eefc66edc03419b0d	VISA 13 digit	39.8852335301738208	-82.9714804898716523
45331	2020-08-16 10:12:03	2020-08-16	Rayshawn Erdman	rayshawn.erdman@geemail.com	Oakland	California	3759042797112481	5da7c3ffd93316c66dc3c84a4e63c79e	Discover	37.7961691908641271	-122.258805022744582
45332	2020-08-16 10:12:19	2020-08-16	Miss Shannen VonRueden DDS	miss.shannen.vonrueden.dds@geemail.com	New York	New York	3337533023692683830	d26bce30930e0b2bb61d244eb0d16e53	JCB 15 digit	40.5782519049234693	-73.862009908481312
45333	2020-08-16 10:12:40	2020-08-16	Kolton Koch	kolton.koch@warmmail.com	Phoenix	Arizona	4449871192778	5e82430c38d7aeea63cb8036867272cf	VISA 16 digit	33.5681454703610385	-112.031816341488067
45334	2020-08-16 10:13:39	2020-08-16	Lorenza Runte	lorenza.runte@warmmail.com	San Antonio	Texas	869954388109786453	e6a45eb235ec3c299935f0a98176ef74	Voyager	29.5554383687745776	-98.527053871734438
45335	2020-08-16 10:14:34	2020-08-16	Toni Johnson	toni.johnson@warmmail.com	San Jose	California	3088993030960416978	b69fad070f4951f9e88c4e80239eba95	JCB 15 digit	37.2413277572307777	-121.825733644583821
45336	2020-08-16 10:16:00	2020-08-16	Fritz Bins	fritz.bins@geemail.com	St. Louis	Missouri	4958694738559	626580ed0b6b32703ba813081ec35529	Diners Club / Carte Blanche	38.7109818682696698	-90.1561755158010953
45337	2020-08-16 10:19:58	2020-08-16	Mr. Kimberly Rogahn IV	mr.kimberly.rogahn.iv@geemail.com	Los Angeles	California	060437190260192	4e051ffa0b0849cb83f35d5be1b86b5f	Discover	34.1157941947557006	-118.389302062754695
45338	2020-08-16 10:22:11	2020-08-16	Mrs. Sheri Zulauf DDS	mrs.sheri.zulauf.dds@warmmail.com	Tallahassee	Florida	4805556588976157	41dbfbf307b72fd451a82c2f1bc3e6fa	Diners Club / Carte Blanche	30.4356145019199715	-84.2436653817087375
45339	2020-08-16 10:24:41	2020-08-16	Ora Bechtelar-Mayert	ora.bechtelar.mayert@geemail.com	Little Rock	Arkansas	630463403201450	e9e5f1fb7aacbd45dbe8d8c4900a5424	VISA 16 digit	34.8059140638258313	-92.3940059926699746
45340	2020-08-16 10:37:00	2020-08-16	Clement Fisher IV	clement.fisher.iv@geemail.com	Los Angeles	California	3528445652969642694	1a2ec85c76557f36c8ab14735675ea6d	Discover	34.0496347475662802	-118.39031654433272
45341	2020-08-16 10:40:47	2020-08-16	Shellie Ferry I	shellie.ferry.i@woohoo.com	San Francisco	California	4021567636918206	58f12d79874fde3df2bc2ee1c3dd5daa	Mastercard	37.7593882615770156	-122.410552339560198
45342	2020-08-16 11:09:24	2020-08-16	Danae Kozey	danae.kozey@woohoo.com	Indianapolis	Indiana	3036262619368970	f9bbd067b5d9245fd40428c160d42ef6	JCB 16 digit	39.7901953345172075	-86.2325878692060712
45343	2020-08-16 11:11:50	2020-08-16	Kailey Heller	kailey.heller@warmmail.com	Mesa	Arizona	6011880019696347835	05c8f986bb4819cd87edeb200dcf2179	American Express	33.3262448379449552	-111.725051558518402
45344	2020-08-16 11:16:48	2020-08-16	Aracely Collier	aracely.collier@woohoo.com	Houston	Texas	3055793998660455	ad40224c7c8c82f3429d9e093b7626d8	Voyager	29.7869266392741352	-95.3360823426410633
45345	2020-08-16 11:30:51	2020-08-16	Mr. Rome Schmitt I	mr.rome.schmitt.i@warmmail.com	Naperville	Illinois	4937628467717282	aa3409999032b0b56b77f4cc7c37fa1a	Diners Club / Carte Blanche	41.7054025620136457	-88.1126199100054919
45346	2020-08-16 11:35:33	2020-08-16	Levin Halvorson	levin.halvorson@geemail.com	Chicago	Illinois	3003057579910776	c147974325e5629d53a58e6a5511fc59	JCB 15 digit	41.900723795529828	-87.7625168106082754
45347	2020-08-16 11:40:58	2020-08-16	Mrs. Jacey Schmeler	mrs.jacey.schmeler@warmmail.com	Stamford	Connecticut	4808378260906759	5eb6ba87b7561352e12fe2505f028f58	JCB 15 digit	41.0633812481887688	-73.5849814803842577
45348	2020-08-16 11:50:06	2020-08-16	Dr. Angelique Runolfsson PhD	dr.angelique.runolfsson.phd@woohoo.com	Nashville	Tennessee	6011550568916390495	4130df6a51d7f776dfc3466b1b891988	VISA 13 digit	36.1033642429981327	-86.8751859376113771
45349	2020-08-16 11:53:14	2020-08-16	Michael McKenzie	michael.mckenzie@geemail.com	Berkeley	California	210058459373767465	947a61263942549ff46bfa40cb03f51a	Mastercard	37.8473090935043928	-122.264866716328655
45350	2020-08-16 11:55:56	2020-08-16	Woodroe Ryan	woodroe.ryan@geemail.com	Dallas	Texas	6011873427810932169	f428ea332bcfd0808a011f54e431eddf	Voyager	32.7593074383020451	-96.6933295860383595
45351	2020-08-16 11:57:14	2020-08-16	Violeta Bins	violeta.bins@geemail.com	New York	New York	676338577785488	1a943477ac3cd7ae26613d89ae56bdd1	Maestro	40.7387452228218336	-73.9199101999763428
45352	2020-08-16 12:00:14	2020-08-16	Krystin Smitham	krystin.smitham@geemail.com	Baltimore	Maryland	869940338444844217	b3946878e84891767c652b16702b54e4	Mastercard	39.2217899869661721	-76.6833690535295744
45353	2020-08-16 12:04:41	2020-08-16	Freeman Bernhard	freeman.bernhard@geemail.com	Houston	Texas	3007772791096826	170b1347b2c34f3fd59b8befbe686a2e	American Express	29.7009763099797084	-95.3731863062843672
45354	2020-08-16 12:18:28	2020-08-16	Kiya Ritchie MD	kiya.ritchie.md@woohoo.com	Baltimore	Maryland	52814037857422636	e4279321771b8687c821e4a214ccefec	VISA 16 digit	39.3702311747241751	-76.5914665214270372
45355	2020-08-16 12:27:19	2020-08-16	Alesia Johns	alesia.johns@geemail.com	Frisco	Texas	3158974027708011460	4e095b9fb11b0fbf3424ae6102cdad58	JCB 16 digit	33.2232079007659138	-96.9090946478977742
45356	2020-08-16 12:30:18	2020-08-16	Miss Christal Botsford	miss.christal.botsford@geemail.com	Dallas	Texas	3436932332085796	4573f9d0cc670753ce6335ff5fa45374	American Express	32.7264988274585491	-96.6945156004242534
45357	2020-08-16 12:38:38	2020-08-16	Dr. Zaniyah Wiegand	dr.zaniyah.wiegand@woohoo.com	Saint Paul	Minnesota	3026262166202135	7f8d902488786f6d613afb9cab8c1aa3	VISA 13 digit	44.9476587631680076	-93.038194912419101
45358	2020-08-16 12:39:44	2020-08-16	Loyal Swaniawski-Harber	loyal.swaniawski.harber@geemail.com	New York	New York	869937373842900308	7e3ce1963c66fc59a85cfc50ab15ab27	American Express	40.7325127578563979	-73.8684279175836593
45359	2020-08-16 12:40:27	2020-08-16	Eddy Langworth	eddy.langworth@geemail.com	Vancouver	Washington	869910159969073818	47056fecc58d2abe10504727ce822a21	VISA 16 digit	45.5842941683787899	-122.604161721055206
45360	2020-08-16 12:44:52	2020-08-16	Harrell Armstrong-McCullough	harrell.armstrong.mccullough@geemail.com	Paterson	New Jersey	3112594616221564425	7055059539d5574340d7c9dfd19e176b	Mastercard	40.8309737519316371	-74.0837641494788244
45361	2020-08-16 12:56:27	2020-08-16	Irma Schulist DDS	irma.schulist.dds@warmmail.com	Allentown	Pennsylvania	210060072186162463	9af23cf8d735cde400fd747003322c3c	JCB 16 digit	40.5757596113964922	-75.430067054975396
45362	2020-08-16 13:02:38	2020-08-16	Dagmar Welch	dagmar.welch@geemail.com	St. Petersburg	Florida	180074956980713543	ed6fff597871277b97f8d82be775b6fd	VISA 16 digit	27.7664617995154117	-82.5643273648697829
45363	2020-08-16 13:03:10	2020-08-16	Alejandro Lindgren	alejandro.lindgren@geemail.com	Pittsburgh	Pennsylvania	675936370387502	cebc7e414ee0e83ab391dcfb91490e99	JCB 15 digit	40.3520838065493805	-79.9692814537961141
45364	2020-08-16 13:16:44	2020-08-16	Rosario Rowe	rosario.rowe@geemail.com	Broken Arrow	Oklahoma	3528166262262173905	ab547b76e9a2a87e568093139fe6ede7	Maestro	36.119851184893399	-95.7658233485128818
45365	2020-08-16 13:18:28	2020-08-16	Cordella Muller	cordella.muller@geemail.com	New York	New York	180009058909047762	63c78b5d2733efa81b8f3747ef8e6d84	VISA 13 digit	40.6887571024000607	-73.8613296330336482
45366	2020-08-16 13:23:00	2020-08-16	Mrs. Logan Waters DVM	mrs.logan.waters.dvm@warmmail.com	Oakland	California	3096799318018980103	01eac0e82fa3b9c7be3a65d2f18944f8	JCB 16 digit	37.7856223555730679	-122.284200304150914
45367	2020-08-16 13:30:29	2020-08-16	Dr. Giuseppe Schroeder IV	dr.giuseppe.schroeder.iv@geemail.com	Glendale	Arizona	4236272892290	b85347f4ed8c5a532b6572e9ccc6a108	Mastercard	33.4484472065925544	-112.246754939972973
45368	2020-08-16 13:38:39	2020-08-16	Horacio Harvey	horacio.harvey@woohoo.com	San Antonio	Texas	210091624547635554	7e2133ffea5f8db7c67a3afb086020c6	American Express	29.522033110919967	-98.4966535898227136
45369	2020-08-16 13:43:08	2020-08-16	Reese Macejkovic	reese.macejkovic@woohoo.com	Rialto	California	3528072060756427487	aebe82c35a7402e992b411da56dc8bf2	JCB 16 digit	34.1866028832487814	-117.467321086776636
45370	2020-08-16 13:43:25	2020-08-16	Oliver Lemke V	oliver.lemke.v@geemail.com	Stockton	California	3015258628594136	4eeed6ef70eb7a5793ee369f185da2f9	Diners Club / Carte Blanche	38.0371671220485155	-121.39072302636616
45371	2020-08-16 13:44:51	2020-08-16	Spring Grant	spring.grant@warmmail.com	Grand Prairie	Texas	4234789206991784	a84b9746d9abe1e073c6e622ba8fcfda	VISA 13 digit	32.5898942954424768	-97.0349272541109542
45372	2020-08-16 13:46:31	2020-08-16	Caitlin Wilderman PhD	caitlin.wilderman.phd@geemail.com	Wichita	Kansas	4524874258340236	1ae4a2571e610ee46621e795a5897718	Mastercard	37.7830715109005553	-97.2990229245476428
45373	2020-08-16 13:49:21	2020-08-16	Icey Heidenreich	icey.heidenreich@geemail.com	Sacramento	California	4827652821464285	21d5a3613821f390f82152c235d7a52b	JCB 16 digit	38.5116314729474496	-121.458909724584217
45374	2020-08-16 13:50:42	2020-08-16	Mr. Jordon Brown MD	mr.jordon.brown.md@geemail.com	Cape Coral	Florida	3055584742816216	c5babf5812b26ff610bad7fe779b431a	Diners Club / Carte Blanche	26.5518857619229713	-82.0592731153663237
45375	2020-08-16 13:53:35	2020-08-16	Mrs. Leanne Flatley	mrs.leanne.flatley@woohoo.com	North Las Vegas	Nevada	3447400569786731	6fe86eca05f61ebcfed62f889c41a6f4	JCB 15 digit	36.3843328963655992	-115.044100167763986
45376	2020-08-16 14:02:20	2020-08-16	Evelina Feil	evelina.feil@warmmail.com	Philadelphia	Pennsylvania	180007556020073593	d124e079351de36f1c8d731eb1f63e93	Voyager	39.9586091807536761	-75.1311285076562427
45377	2020-08-16 14:02:33	2020-08-16	Jerrica Walsh	jerrica.walsh@geemail.com	Oklahoma City	Oklahoma	180051824838869874	879bd34dd90324e833a40354ed00a6b6	JCB 16 digit	35.5261640752576326	-97.4954372015211703
45378	2020-08-16 14:04:22	2020-08-16	Kasey Grant-Treutel	kasey.grant.treutel@woohoo.com	Wichita	Kansas	6011222576648019967	1506cbee934fc9afb0656d4e7b51f5da	VISA 16 digit	37.7568386240739358	-97.3957022144194724
45379	2020-08-16 14:05:13	2020-08-16	Sherwin Mosciski DDS	sherwin.mosciski.dds@geemail.com	San Antonio	Texas	3017196670027381	2c3e481bc63f0ab172e3bbfde2bf6496	Discover	29.5220860148385178	-98.4546908571220882
45380	2020-08-16 14:09:59	2020-08-16	Dana Gleichner-Gerhold	dana.gleichner.gerhold@geemail.com	New York	New York	676178256807583	cc281271adf0299932a0d15a13939658	JCB 16 digit	40.5799541154168537	-73.9060970002681046
45381	2020-08-16 14:23:24	2020-08-16	Champ Dare	champ.dare@geemail.com	Jacksonville	Florida	6011678422636194141	d4ada896fded72d21c641f73189309fe	Voyager	30.240082374779135	-81.6274951658289893
45382	2020-08-16 14:25:16	2020-08-16	Mr. Verl Schmeler Sr.	mr.verl.schmeler.sr.@geemail.com	Cleveland	Ohio	3112402452091291135	1d3cff28a1269e991bfa734df925a188	VISA 16 digit	41.4568934159204332	-81.6318188208859397
45383	2020-08-16 14:27:49	2020-08-16	Urijah Cole	urijah.cole@woohoo.com	San Francisco	California	4383660618620	c0eaa06824258e0bb93485e762b07ee3	JCB 16 digit	37.7935357554350517	-122.425868362143419
45384	2020-08-16 14:31:06	2020-08-16	Brenden Bernier	brenden.bernier@geemail.com	Indianapolis	Indiana	4798174278096697	f328971878523ab5c329dc52eb123574	Diners Club / Carte Blanche	39.6928234722007076	-86.1594387170128471
45385	2020-08-16 14:32:53	2020-08-16	Loree Jerde	loree.jerde@geemail.com	New York	New York	4055755348405609	34bfaf2b71ba4b974670c34eb9a043c2	VISA 16 digit	40.6858105385433859	-73.8801345893543129
45386	2020-08-16 14:33:33	2020-08-16	Celestine Bergstrom	celestine.bergstrom@geemail.com	Dallas	Texas	3442215558224238	566e53b7ae91192af3d378508b3ca5a7	JCB 15 digit	32.8135025304548478	-96.7851393030919098
45387	2020-08-16 14:53:10	2020-08-16	Raphael Morar	raphael.morar@geemail.com	Sacramento	California	55258599011237310	25d2c3bed0a0701947fccb677c81ba25	Diners Club / Carte Blanche	38.5103584478408081	-121.50013377720154
45388	2020-08-16 14:57:54	2020-08-16	Lilian Sanford	lilian.sanford@warmmail.com	Los Angeles	California	3088921041121276885	a2a0e327c6d2470698d3f75bbbae3c1a	JCB 16 digit	33.9800269561219963	-118.41133356443531
45389	2020-08-16 15:01:22	2020-08-16	Rhea Watsica PhD	rhea.watsica.phd@geemail.com	Anaheim	California	060439261768160	b88ee861a902de8527eb5a73646e253f	JCB 15 digit	33.8644007057249539	-117.847548172690338
45390	2020-08-16 15:06:17	2020-08-16	Randall Schulist	randall.schulist@warmmail.com	Fresno	California	4514298548991	c6f6e11a374bf0d7d937c134775f9c18	VISA 16 digit	36.833233141653615	-119.709446960791581
45391	2020-08-16 15:07:33	2020-08-16	Arland Murray MD	arland.murray.md@geemail.com	New York	New York	869942799702920478	061b440459296b92eb9795a07f7f5a16	JCB 15 digit	40.6557863825224359	-74.0363300159934852
45392	2020-08-16 15:11:45	2020-08-16	Kadeem Hackett	kadeem.hackett@geemail.com	Washington	District of Columbia	4436910586318465	351c9ed373ccdf0342300c4f3b28baba	JCB 16 digit	38.8445278765432533	-77.0663295380983584
45393	2020-08-16 15:14:10	2020-08-16	Aubra Flatley	aubra.flatley@warmmail.com	Renton	Washington	210026575668911028	bd292826b349abb76253dd0c306ba7d7	JCB 16 digit	47.4796553256981113	-122.095049730183547
45394	2020-08-16 15:15:33	2020-08-16	Sofia Runolfsson MD	sofia.runolfsson.md@geemail.com	Santa Rosa	California	869938444872481458	b57ca5da22f26463aa2fa61cc7a9c1d0	Diners Club / Carte Blanche	38.5130543956190365	-122.736965798145533
45395	2020-08-16 15:24:55	2020-08-16	Caitlin Moen DDS	caitlin.moen.dds@geemail.com	Jackson	Mississippi	503804319981546	b5ed5f5d9705980d1a82526613a260d6	Discover	32.3435011417318137	-90.262812840749703
45396	2020-08-16 15:25:31	2020-08-16	Ardella Hermann-Cremin	ardella.hermann.cremin@geemail.com	Surprise	Arizona	6011753119080278978	7dd849e8714e0eafcd298f4544480916	JCB 16 digit	33.719930096133055	-112.441457456792506
45397	2020-08-16 15:26:39	2020-08-16	Talon Zboncak	talon.zboncak@warmmail.com	Omaha	Nebraska	4551873499661	ab027542c7c36bc59a7a4c6027eae4c7	JCB 15 digit	41.3603092747885768	-96.0923668441943875
45398	2020-08-16 15:30:36	2020-08-16	Raleigh Grant	raleigh.grant@geemail.com	Mesa	Arizona	3528528782833211762	0043133af341ef96a53531d0bec77e1c	American Express	33.3809297838393562	-111.632333286514125
45399	2020-08-16 15:34:29	2020-08-16	Hazen Kuvalis DVM	hazen.kuvalis.dvm@geemail.com	Houston	Texas	4863007625289	022cf2a3290356e2826b39fcec8e7295	JCB 16 digit	29.7028539655808359	-95.3776297989781909
45400	2020-08-16 15:34:56	2020-08-16	Tawanna Green	tawanna.green@geemail.com	San Francisco	California	4221045401546	2f962a457f88fa3942d207aff898426a	Voyager	37.7857031618645749	-122.421288650436907
45401	2020-08-16 15:39:26	2020-08-16	Rutha Bednar	rutha.bednar@geemail.com	Syracuse	New York	3088258584537751002	df4b6639a3e6d5d2ea7f20b99613c508	JCB 16 digit	43.1247290700525028	-76.2222161035299308
45402	2020-08-16 15:39:55	2020-08-16	Annice Rutherford	annice.rutherford@geemail.com	San Antonio	Texas	3425346434140958	308746fc73aff73260f0d3024b0e2557	Mastercard	29.4274842142663893	-98.5847704666968383
45403	2020-08-16 15:39:59	2020-08-16	Justice Hirthe	justice.hirthe@geemail.com	Fresno	California	3022746430427993	9426d97527dd94aebb9e025a9cabddac	Diners Club / Carte Blanche	36.8181791891682906	-119.717397465660795
45404	2020-08-16 15:44:12	2020-08-16	Dock Walker	dock.walker@geemail.com	Sacramento	California	503819370017865	7dacbfe681cef627ac39c4830fc6038c	American Express	38.6241411893893059	-121.49473973626867
45405	2020-08-16 15:48:43	2020-08-16	Chimere Nikolaus	chimere.nikolaus@warmmail.com	Anaheim	California	503818882522594	f387c7f95ef425d7c31652006ee67323	Voyager	33.8484700371809311	-117.788613497253877
45406	2020-08-16 15:53:46	2020-08-16	Lexie Crist	lexie.crist@geemail.com	Berkeley	California	4249596127791752	44eb95b6ff72cd5c9be641308d845ef0	VISA 16 digit	37.8929744128038308	-122.269479529117675
45407	2020-08-16 15:57:11	2020-08-16	Tollie Fadel	tollie.fadel@geemail.com	Cape Coral	Florida	3761893833120987	2a419afad3e77c08795d9c28804f79a2	Diners Club / Carte Blanche	26.6443947728693473	-81.9944431173685899
45408	2020-08-16 15:57:13	2020-08-16	Hope Dare	hope.dare@woohoo.com	Los Angeles	California	210059917150137128	229e1181d8d1d89a0f90fbe612767951	JCB 16 digit	34.0218374605622103	-118.431193895590667
45409	2020-08-16 15:58:04	2020-08-16	Danniel Wyman	danniel.wyman@warmmail.com	Baltimore	Maryland	4658867731356868	ab60906cdd1a0f43cb7b7e4c5d2e15a0	Maestro	39.2282111654523717	-76.6416506363097625
45410	2020-08-16 16:01:51	2020-08-16	Kiyoshi Morissette	kiyoshi.morissette@woohoo.com	Oakland	California	3096456350577906140	2571842a6259702b46bc6114a10b407c	Diners Club / Carte Blanche	37.8104349788238139	-122.308255057076039
45411	2020-08-16 16:04:00	2020-08-16	Florine Friesen	florine.friesen@geemail.com	Salt Lake City	Utah	4242653748107533	c9c6c71573fdb4a0d2959b4997c1176d	American Express	40.8363644484575801	-111.908096057636655
45412	2020-08-16 16:05:23	2020-08-16	Webb Heidenreich-Feest	webb.heidenreich.feest@geemail.com	Houston	Texas	869994607769185454	9877c091fff1de68aa99e3e80f40e538	American Express	29.8736271374005824	-95.3450542228776925
45413	2020-08-16 16:08:57	2020-08-16	Kyleigh Lemke	kyleigh.lemke@geemail.com	Salt Lake City	Utah	3112025792238320900	771b244a039d9d6523189b1992b0fe09	Voyager	40.7254427269246406	-111.95002087870985
45414	2020-08-16 16:14:00	2020-08-16	Gray Klein	gray.klein@geemail.com	San Francisco	California	55466258306851032	a1246e148aae4b282625d819fd3bb5df	VISA 16 digit	37.7710002459579144	-122.434436020271491
45415	2020-08-16 16:15:45	2020-08-16	Jamie Murray	jamie.murray@geemail.com	Boston	Massachusetts	6011706463380065182	3de7d3607bf9cf7663ae3b64479ca479	JCB 16 digit	42.3714922759849557	-71.0670532686587393
45416	2020-08-16 16:25:21	2020-08-16	Levern O'Hara	levern.o'hara@geemail.com	Columbia	Missouri	4834455064370	ae8b780f2874ac497c73100fce18b97c	VISA 16 digit	39.0500475504316995	-92.3509175422654636
45417	2020-08-16 16:25:40	2020-08-16	Kayden Stoltenberg	kayden.stoltenberg@warmmail.com	Louisville	Kentucky	869933235125429905	f07e755c501ea69f47f9c589f430d293	American Express	38.2304139614008349	-85.6191579981777835
45418	2020-08-16 16:26:56	2020-08-16	Remy O'Connell	remy.o'connell@geemail.com	Phoenix	Arizona	4788483916235	7a95355eabdd7e328ad90fd0f416f61c	Mastercard	33.5599665151841933	-112.119652343953405
45419	2020-08-16 16:27:52	2020-08-16	Dr. Kadeem Powlowski MD	dr.kadeem.powlowski.md@geemail.com	Thornton	Colorado	4771411634040485	2209beb4b806c70e8518a7403084b88f	VISA 16 digit	39.909555699849129	-104.962540571221339
45420	2020-08-16 16:31:39	2020-08-16	Bryce Reilly	bryce.reilly@geemail.com	New York	New York	54089780083800673	7fa002e6635bdb3db21c2a5b1aee893e	JCB 15 digit	40.6691305947713531	-73.8934116628382327
45421	2020-08-16 16:51:00	2020-08-16	Mrs. Lasonya Medhurst MD	mrs.lasonya.medhurst.md@geemail.com	Kansas City	Missouri	4557033587691	1f029edfea96edc68fbc7ab78dcf15f8	VISA 16 digit	39.2042055289097178	-94.4526885383520352
45422	2020-08-16 16:52:45	2020-08-16	Miss Colette Hoeger	miss.colette.hoeger@geemail.com	Mobile	Alabama	502084830583294	8600429e06c7a195636d7d4e1a4e3ef1	Diners Club / Carte Blanche	30.6711950149495145	-88.167504539773617
45423	2020-08-16 17:10:52	2020-08-16	Della Buckridge	della.buckridge@woohoo.com	San Francisco	California	3158037691407022444	515c18ef985a7cfbf07ad3a23f3f5a86	VISA 16 digit	37.7230485955447961	-122.457155170123286
45424	2020-08-16 17:19:57	2020-08-16	Orvin Prosacco	orvin.prosacco@geemail.com	Philadelphia	Pennsylvania	4667847266364	c5af315911916445d96f132953222eb6	VISA 13 digit	40.0972020485863112	-75.1673692129917441
45425	2020-08-16 17:31:29	2020-08-16	Payton Gusikowski	payton.gusikowski@geemail.com	Phoenix	Arizona	6011625587769642480	fb53558776a5aef2621e0ba3a0f2ee34	Mastercard	33.5361847910497346	-112.091395128138743
45426	2020-08-16 17:42:59	2020-08-16	Mrs. Laisha Walter	mrs.laisha.walter@geemail.com	Garden Grove	California	180060468831802422	09046d5944bc29709bb2054d168ccf32	American Express	33.8339171991508394	-117.975962412871411
45427	2020-08-16 17:49:59	2020-08-16	Chiquita Schneider DDS	chiquita.schneider.dds@warmmail.com	Milwaukee	Wisconsin	869912375694216054	5798f64fbfd711aa779b25193c7df672	VISA 13 digit	43.1036484967071516	-87.9925158714044926
45428	2020-08-16 17:59:20	2020-08-16	Kolten Kling	kolten.kling@geemail.com	Chicago	Illinois	4093622512021055	63e33d117da57dd4e76fe8d9dbc84374	JCB 15 digit	41.8325690349400077	-87.6778844019893455
45429	2020-08-16 18:18:37	2020-08-16	Vergil Ratke	vergil.ratke@geemail.com	Phoenix	Arizona	3337355793386329131	9aa27251f09b9e9e3da8e7bc05f245a3	VISA 16 digit	33.5923491695363126	-112.142551977832255
45430	2020-08-16 18:21:23	2020-08-16	Miss Danette Hintz DVM	miss.danette.hintz.dvm@woohoo.com	Oceanside	California	180028141599172806	75665a38d442fe81b227c72bcbe1de25	JCB 16 digit	33.2665734709594361	-117.345641658323629
45431	2020-08-16 18:21:54	2020-08-16	Dr. Arvil Lesch	dr.arvil.lesch@woohoo.com	Philadelphia	Pennsylvania	54950932044691438	cfe838dab9a5bb9844269e0677e1ee5f	Mastercard	40.0637504887260505	-75.2012886020254427
45432	2020-08-16 18:22:54	2020-08-16	Bradly Rogahn Sr.	bradly.rogahn.sr.@geemail.com	Dallas	Texas	4258026104607662	02b096fa2bd450e05cc2c91b86f8047f	Voyager	32.8489610475294285	-96.6885876496285164
45433	2020-08-16 18:30:43	2020-08-16	Ms. Aileen Morar DDS	ms.aileen.morar.dds@geemail.com	Lexington	Kentucky	630415043911187	d93b6c400a42b9eb66f5ee8d1f82fc6f	JCB 15 digit	38.0113150592770452	-84.5044830820422561
45434	2020-08-16 18:37:35	2020-08-16	Delora Beer	delora.beer@warmmail.com	San Antonio	Texas	3088938421013446591	75efe5f5b497749ec6590a0c5d11c55f	American Express	29.406409804204106	-98.4544762952089201
45435	2020-08-16 19:03:16	2020-08-16	Lemuel Trantow-Larson	lemuel.trantow.larson@geemail.com	New York	New York	3427938839692431	4c91c2bc9b2641f2522330a9c49858b9	Voyager	40.7612801382075958	-73.8664217791415751
45436	2020-08-16 19:10:18	2020-08-16	Buck Oberbrunner	buck.oberbrunner@geemail.com	Irvine	California	3743085595123423	a93b47766a480da804e6c0e3c271a3a7	Diners Club / Carte Blanche	33.7491559666596359	-117.81681261425949
45437	2020-08-16 19:18:06	2020-08-16	Norman Becker-Rempel	norman.becker.rempel@geemail.com	Nashville	Tennessee	3158131690103491270	4502503a0d7be7f7f3ed8c996c9f4caf	Discover	36.1104726884171328	-86.8373529648315099
45438	2020-08-16 19:23:33	2020-08-16	Britt Sipes	britt.sipes@geemail.com	Waterbury	Connecticut	503895811642966	8784b75eef122700bb663b2d0a4f3176	JCB 15 digit	41.5219402629919401	-72.9501953261353009
45439	2020-08-16 19:27:20	2020-08-16	Shanice Orn DDS	shanice.orn.dds@geemail.com	Long Beach	California	4589088859089	ea6afa70d0cdde007ea2eaa64356a48f	Discover	33.8579575334496781	-118.20294900002628
45440	2020-08-16 19:27:40	2020-08-16	Houston Wilderman IV	houston.wilderman.iv@geemail.com	Anaheim	California	4292224934868343	8ed5208d4646929c57ac610f55dbe25d	JCB 15 digit	33.7663038801234237	-117.731063860303152
45441	2020-08-16 19:28:18	2020-08-16	Marinda Schaden	marinda.schaden@geemail.com	Fullerton	California	180084523621772912	476596f507e643cf681ea2c934b071b3	VISA 16 digit	33.9315140336442767	-118.010914596842596
45442	2020-08-16 19:28:59	2020-08-16	Simone Schaden	simone.schaden@geemail.com	Mesa	Arizona	4805905145969	29087a78d41f9e6be644e0befd1d59ca	Maestro	33.4226923735026276	-111.695248638826982
45443	2020-08-16 19:34:15	2020-08-16	Carmel Fadel	carmel.fadel@geemail.com	New York	New York	210058523340520313	1805a7fa309860ecd6be95d2b0414f2f	Maestro	40.6385713841523994	-73.88751277033127
45444	2020-08-16 19:37:16	2020-08-16	Glendon Boyer	glendon.boyer@geemail.com	Augusta	Georgia	3088709633238970745	963bd1af35fce01a5d7c1adce3c5b6b9	JCB 16 digit	33.3552831280250075	-82.0880734876092646
45445	2020-08-16 19:37:44	2020-08-16	Ivey McDermott	ivey.mcdermott@geemail.com	Los Angeles	California	52644722342933851	f9e404887d40706a975676cfa6e98d68	Mastercard	33.9651049442455175	-118.330546599439529
45446	2020-08-16 19:39:08	2020-08-16	Howard Denesik	howard.denesik@woohoo.com	South Bend	Indiana	4511110574957	1ea2c5b6fb6f9aa353957f9c75ec3a89	Maestro	41.6695015570759821	-86.1978868428673621
45447	2020-08-16 19:45:17	2020-08-16	Ms. Lilyana VonRueden	ms.lilyana.vonrueden@geemail.com	Salinas	California	869912014631343107	8e994f5217bf45f1b34c887987335b31	VISA 16 digit	36.7866685638435129	-121.654424620390685
45448	2020-08-16 19:49:20	2020-08-16	Ms. Kaitlynn Anderson	ms.kaitlynn.anderson@warmmail.com	Oklahoma City	Oklahoma	4021201225647717	804fa971b6bb3c8cd141493930169597	Voyager	35.4948996956836424	-97.5182366587117286
45449	2020-08-16 19:54:56	2020-08-16	Dereck Rosenbaum I	dereck.rosenbaum.i@geemail.com	Oakland	California	4499005091350824	be9e9f01cf0380eb62dc8018da9bb211	Maestro	37.7780862706268721	-122.258795525469196
45450	2020-08-16 19:56:06	2020-08-16	Ellison Ruecker	ellison.ruecker@geemail.com	Detroit	Michigan	4874649303688631	3bd3df69f21b292cf59bd959babe7b51	Maestro	42.4621885465849189	-83.0271515213537867
45451	2020-08-16 20:00:45	2020-08-16	Burley Rowe-Fay	burley.rowe.fay@warmmail.com	Killeen	Texas	3030664216935992	e5da85fce7e468db61a82cc40cb59f26	Mastercard	31.0323181133482606	-97.7768421465698623
45452	2020-08-16 20:00:54	2020-08-16	Del Keeling	del.keeling@warmmail.com	Aurora	Colorado	3112428542123670965	c9f38d20e3233276734505b4957ed491	Diners Club / Carte Blanche	39.6742910922616758	-104.77970202254393
45453	2020-08-16 20:01:56	2020-08-16	Darwin Schimmel	darwin.schimmel@geemail.com	Little Rock	Arkansas	4126572159252	265877efcf01321a04319204df124852	Diners Club / Carte Blanche	34.6333368185717632	-92.4247113752983438
45454	2020-08-16 20:01:56	2020-08-16	Colette O'Kon	colette.o'kon@geemail.com	Houston	Texas	4285942801436915	5147a8a93315a079c8baf7d9e48eecdb	American Express	29.8704278510607786	-95.2930003910806107
45455	2020-08-16 20:02:32	2020-08-16	Melissia Stiedemann-Marquardt	melissia.stiedemann.marquardt@geemail.com	San Diego	California	3112531990287289367	5034e6df695624570e6ac14051c67dc2	VISA 13 digit	32.9149126325335359	-117.215689560994505
45456	2020-08-16 20:08:40	2020-08-16	Kindra Adams-Barrows	kindra.adams.barrows@geemail.com	Columbus	Ohio	4494751361297071	8df3f6c32148f655f01fda53f56eae20	Discover	39.8928896442566057	-83.0377820437543193
45457	2020-08-16 20:12:31	2020-08-16	Mr. Deon Stiedemann II	mr.deon.stiedemann.ii@geemail.com	Raleigh	North Carolina	4577175857391505	c7512733238ce72f1b4f6d9237d7a556	JCB 16 digit	35.804052781140804	-78.5571221148066314
45458	2020-08-16 20:20:02	2020-08-16	Delton Lindgren-Will	delton.lindgren.will@woohoo.com	Houston	Texas	3158218890734248794	de75fef8dcd38f833fee1c1c4b2f5b3a	Discover	29.6964076479043797	-95.3327659845832756
45459	2020-08-16 20:21:29	2020-08-16	Orvin Hansen-Ankunding	orvin.hansen.ankunding@geemail.com	Tampa	Florida	3008946881486670	0e7a088099de118be177cbfcae0a00e3	Diners Club / Carte Blanche	27.9944817060720155	-82.4918195476967782
45460	2020-08-16 20:22:01	2020-08-16	Mrs. Laylah Jast MD	mrs.laylah.jast.md@geemail.com	Fort Wayne	Indiana	52805661792987576	9047ba65b5141448f6a074a5d817efab	JCB 16 digit	41.0643067767161867	-85.2270071279942982
45461	2020-08-16 20:33:02	2020-08-16	Kristin Dach	kristin.dach@geemail.com	New York	New York	4342729150358258	fc5da851ab225287691e8935e778948b	VISA 16 digit	40.6269877817705236	-73.9943628757156375
45462	2020-08-16 20:33:33	2020-08-16	Emmaline Bode	emmaline.bode@geemail.com	San Antonio	Texas	869994236499252721	ce867b96765e9287dc131a1001be1ecb	Diners Club / Carte Blanche	29.5067661756720412	-98.449127847778044
45463	2020-08-16 20:38:33	2020-08-16	Paula Green-Gleason	paula.green.gleason@geemail.com	Newark	New Jersey	6011912619985983026	800b0d9f50afe3e8bab228e33b744e97	VISA 16 digit	40.7996484478384289	-74.1603174177672742
45464	2020-08-16 20:38:42	2020-08-16	Tatiana Gaylord	tatiana.gaylord@geemail.com	League City	Texas	4820087798741	a81041b8d94c60af6931646888082d58	Maestro	29.5574850287217679	-95.1667611074153257
45465	2020-08-16 20:41:26	2020-08-16	Mrs. Karla Kilback DDS	mrs.karla.kilback.dds@geemail.com	San Francisco	California	180058316125871583	bc320199d20b2444a6fc4db8f748517d	VISA 16 digit	37.7945463458463564	-122.410306872803417
45466	2020-08-16 20:44:18	2020-08-16	Ottilia Spencer	ottilia.spencer@geemail.com	Albuquerque	New Mexico	4395943993208	f9b844c4fe7044769737f6f32645c1da	VISA 16 digit	35.0268527730502228	-106.604460069730507
45467	2020-08-16 20:49:04	2020-08-16	Augustina Jast	augustina.jast@geemail.com	San Francisco	California	869951923494452817	6b13287a3a5db2563bfa9009fee0ab7f	VISA 16 digit	37.7663155478704198	-122.439154063869253
45468	2020-08-16 20:57:37	2020-08-16	Noreen Roberts-Sporer	noreen.roberts.sporer@geemail.com	Peoria	Illinois	55106143137872165	a93bfe0666f59cd24802ed05dedc2c77	American Express	40.7085811338257031	-89.5712028016686475
45469	2020-08-16 21:01:09	2020-08-16	Roena Ullrich	roena.ullrich@geemail.com	Berkeley	California	4587683139808	cf21d3f46201f7805abf76e9b2deec0f	VISA 16 digit	37.8395434827181347	-122.299052646671569
45470	2020-08-16 21:08:24	2020-08-16	Francisco O'Connell	francisco.o'connell@geemail.com	Wichita	Kansas	3337138271430560096	460f3ca86ad37d03631ad6d8771ce84d	JCB 16 digit	37.7186704275541018	-97.3428049215782494
45471	2020-08-16 21:15:11	2020-08-16	Mikhail Kovacek	mikhail.kovacek@woohoo.com	Hartford	Connecticut	4912988165607	8db2730a40731c84d358e3b5289ffd2c	Discover	41.7462918838966672	-72.6787585768740598
45472	2020-08-16 21:16:40	2020-08-16	Arturo Pfeffer I	arturo.pfeffer.i@geemail.com	El Paso	Texas	55142464548014288	703a482c1c9a7f81bb027f10efbfde5c	Diners Club / Carte Blanche	31.7816587038632505	-106.397549678942198
45473	2020-08-16 21:20:32	2020-08-16	Dr. Jalen Stroman Sr.	dr.jalen.stroman.sr.@warmmail.com	Los Angeles	California	3528863899792850183	f9aa366347665c1dd884fe1f9ef9c2b8	Voyager	34.1096100977487851	-118.410308551647887
45474	2020-08-16 21:24:12	2020-08-16	Micah Muller-Hermiston	micah.muller.hermiston@geemail.com	New York	New York	3096473921776119013	1efeaf22fb5fc11b69ef70dcd0dd66df	Voyager	40.7483496230784823	-73.8697131384059702
45475	2020-08-16 21:49:31	2020-08-16	Reggie Mertz	reggie.mertz@geemail.com	Memphis	Tennessee	4713540295209	0357776eef78b2978f3678dbf91bff08	JCB 16 digit	35.1024408929582705	-90.0149360553152889
45476	2020-08-16 21:56:09	2020-08-16	Dr. Adalberto Bruen IV	dr.adalberto.bruen.iv@warmmail.com	Hayward	California	4937912427740331	8a1c82f27fd7a2849f99a467eac2ca77	Voyager	37.7050202948495752	-122.177911474302036
45477	2020-08-16 22:00:28	2020-08-16	Elige Schuster	elige.schuster@geemail.com	New York	New York	502079134908452	01427760db45f519e763d6c3c4581ce9	VISA 16 digit	40.7165060548800994	-73.8387603346154009
45478	2020-08-16 22:03:13	2020-08-16	Dr. Ednah Hand	dr.ednah.hand@geemail.com	San Francisco	California	869909941833247527	80cec8bae5da35db3302baf5bd7bc6e1	Mastercard	37.7816014277915144	-122.445496819567836
45479	2020-08-16 22:08:03	2020-08-16	Ward Hagenes	ward.hagenes@warmmail.com	Grand Rapids	Michigan	3732365889742804	eb3d8d3789e46e55c7f73e9e600ae219	JCB 16 digit	43.0248488426476712	-85.6871784662962028
45480	2020-08-16 22:09:51	2020-08-16	Mrs. Agnes Medhurst	mrs.agnes.medhurst@geemail.com	Jacksonville	Florida	3096096170881535872	af18236127729135de016e2c3496dde7	VISA 16 digit	30.2787969793710872	-81.704135703908662
45481	2020-08-16 22:17:05	2020-08-16	Ms. Florida Collier	ms.florida.collier@geemail.com	Fresno	California	869990314257169900	3f1589bf03c78ee0a5744f0999710822	Mastercard	36.6965150744993238	-119.874059954203304
45482	2020-08-16 22:17:10	2020-08-16	Leola Bayer	leola.bayer@warmmail.com	San Francisco	California	3741893886216349	3320267996aa211242730ad08032f80e	American Express	37.7608154442449973	-122.407107804702548
45483	2020-08-16 22:20:15	2020-08-16	Ms. Trinity Hickle	ms.trinity.hickle@geemail.com	New York	New York	561284325230781	c43f18b8be133594bcb8ffe1f695561c	Mastercard	40.6707956614661938	-73.9967255978740752
45484	2020-08-16 22:24:49	2020-08-16	Stephon Prohaska MD	stephon.prohaska.md@geemail.com	Murrieta	California	210007263352795519	6de42ea42e17bb3cce79c195c2aeb620	American Express	33.5964646966293472	-117.202136345244568
45485	2020-08-16 22:37:24	2020-08-16	Kira Tromp	kira.tromp@woohoo.com	Reno	Nevada	3112194130410297247	b5389744848101ca63b848257d6ecdf0	Voyager	39.5189871406260878	-119.883636405381935
45486	2020-08-16 22:50:35	2020-08-16	Germaine Tillman DDS	germaine.tillman.dds@geemail.com	Pasadena	California	675916002161079	529d4bcf8556fdea197cffa5a447b454	VISA 16 digit	34.1761081426259139	-118.126960289087521
45487	2020-08-16 22:54:33	2020-08-16	Miss Alexandrea Schowalter DVM	miss.alexandrea.schowalter.dvm@geemail.com	Los Angeles	California	54327696522149484	387a153a5b4f52d6bd47fe8a7962f19f	VISA 13 digit	34.1022026953618962	-118.496298258424915
45488	2020-08-16 23:09:10	2020-08-16	Dr. Noah Buckridge	dr.noah.buckridge@geemail.com	Chicago	Illinois	3777978757622688	2815767488d53514e70c015d954cf1e2	Voyager	41.8308302732486297	-87.7221478690423027
45489	2020-08-16 23:11:41	2020-08-16	Lanny Spencer DDS	lanny.spencer.dds@geemail.com	Las Vegas	Nevada	3528504438322380703	8530a1cd4816c04c3a1d306919b4a943	VISA 16 digit	36.2361373851176367	-115.216774623116848
45490	2020-08-16 23:19:25	2020-08-16	Channing Eichmann II	channing.eichmann.ii@geemail.com	Oakland	California	4095373451114224	362c04cb9a40b5e957f6d2f8ba1750a1	American Express	37.8136431727202336	-122.25297689050096
45491	2020-08-16 23:20:50	2020-08-16	Dr. Martell Fisher	dr.martell.fisher@warmmail.com	Gainesville	Florida	3477429546948877	36ddd62f2fe138205ee242ac47c1e60d	Mastercard	29.6620560040522356	-82.2839594544250588
45492	2020-08-16 23:32:07	2020-08-16	Faith Kuhn	faith.kuhn@geemail.com	Boston	Massachusetts	6011789595551696111	55099b604cd3aab6c0d4822c6bb33b38	Discover	42.3347513015549666	-70.9927960306357591
45493	2020-08-16 23:33:42	2020-08-16	Sherron Sawayn DDS	sherron.sawayn.dds@geemail.com	McAllen	Texas	501875175759754	fdf8a11714a4b8cc0e1af3a43227a540	American Express	26.1547508568808418	-98.1609747160073312
45494	2020-08-16 23:35:52	2020-08-16	Lucero Kreiger	lucero.kreiger@geemail.com	San Jose	California	639035950811261	7da7ee80b228303c084ab63ad2aa1b59	JCB 16 digit	37.2757494612883775	-121.857646283948426
45495	2020-08-16 23:37:03	2020-08-16	Dr. Merritt Cummings	dr.merritt.cummings@geemail.com	Dallas	Texas	4281059829166723	a39ac227bd18178a7f809e9f5803e611	Maestro	32.7832711392819931	-96.7319818049166287
45496	2020-08-16 23:39:09	2020-08-16	Alwin Schuppe DVM	alwin.schuppe.dvm@geemail.com	Tampa	Florida	4554435940909714	78b1be9275967312b4d988fb8856ddbf	VISA 16 digit	27.9355952805954963	-82.5331829673357191
45497	2020-08-16 23:48:30	2020-08-16	Emilia Anderson	emilia.anderson@geemail.com	Cincinnati	Ohio	180068410800440331	83afee07df4e992cf3a625c9c4cbb7ad	JCB 16 digit	39.0766356152713286	-84.4192679042268423
45498	2020-08-16 23:51:23	2020-08-16	Alysa Stokes-Glover	alysa.stokes.glover@geemail.com	West Palm Beach	Florida	4485614231983646	83f2c2d774d212585085e2f2a1ad510a	VISA 16 digit	26.6698591456130174	-80.0868688027210567
45499	2020-08-17 00:01:52	2020-08-17	Alden Grady	alden.grady@geemail.com	Lubbock	Texas	3721369122999737	4ff6777ea01a49cfdc33c065bc334f0e	Diners Club / Carte Blanche	33.5089770110365066	-101.920794248106702
45500	2020-08-17 00:04:26	2020-08-17	Fay O'Keefe-Rosenbaum	fay.o'keefe.rosenbaum@warmmail.com	San Jose	California	180002745796553764	db68bcf8c7e6bd4c504d4255bacfd015	VISA 13 digit	37.3765143828753423	-121.748219353261959
45501	2020-08-17 00:04:33	2020-08-17	Haley Jacobi	haley.jacobi@warmmail.com	Nashville	Tennessee	180048478457692723	70c6643a65a2d2fba7673f2feb983a79	Voyager	36.2156476348761416	-86.8470192351285277
45502	2020-08-17 00:05:22	2020-08-17	Dr. Adolph Schmeler	dr.adolph.schmeler@geemail.com	New York	New York	3475988914299983	c6c995587db419dd7a10b830c5ad418f	Maestro	40.6106007650718084	-73.9857471636857866
45503	2020-08-17 00:13:44	2020-08-17	Audie Parisian-Lang	audie.parisian.lang@geemail.com	Savannah	Georgia	3096527629538168626	42f842ceff8c0220d6376492694e75b7	JCB 16 digit	31.9339145341049857	-81.1922668740306079
45504	2020-08-17 00:16:05	2020-08-17	Aisha Haley	aisha.haley@geemail.com	Portland	Oregon	869975700220578756	058d5456b1136abdd0784bc6a3536526	Diners Club / Carte Blanche	45.5143091380484393	-122.567235105624434
45505	2020-08-17 00:20:19	2020-08-17	Ronny Daniel	ronny.daniel@geemail.com	Waco	Texas	869990774777253189	ecfbd948e5129f78fddce196f7770616	Voyager	31.5939938892818972	-97.1158766042571528
45506	2020-08-17 00:20:23	2020-08-17	Lawerence Cremin-Stokes	lawerence.cremin.stokes@geemail.com	Toledo	Ohio	52849581266395841	1ebbbd0df9f9b0631b2e5194c4d23c0e	Discover	41.5833551674786932	-83.5586292583826946
45507	2020-08-17 00:21:59	2020-08-17	Stetson Kub	stetson.kub@geemail.com	Rancho Cucamonga	California	3006021980826838	281baefc000173bf56b5c96fcdde2447	Maestro	34.0605737315949071	-117.492409022898229
45508	2020-08-17 00:23:34	2020-08-17	Rosanna Lindgren-Hansen	rosanna.lindgren.hansen@geemail.com	Baltimore	Maryland	4016567598970	aab64ab72011124265021a3e16503276	American Express	39.3946462249383274	-76.6117853791471646
45509	2020-08-17 00:24:13	2020-08-17	Tina Luettgen	tina.luettgen@geemail.com	Henderson	Nevada	503828161226361	68805452ec38f5cbe1089cd07060c488	JCB 16 digit	36.0688948878020099	-115.024666121291745
45510	2020-08-17 00:24:37	2020-08-17	Karel Abbott	karel.abbott@geemail.com	Thornton	Colorado	4435957723764565	9ad5e6d64a2ed58e511d623dca81f955	Discover	39.863707204987854	-105.036698697104313
45511	2020-08-17 00:43:15	2020-08-17	Djuna Quitzon	djuna.quitzon@woohoo.com	San Diego	California	869950921095975138	cc49379087cd36d35d0029de8da95436	VISA 16 digit	32.7351580168653271	-117.143878179034218
45512	2020-08-17 00:43:38	2020-08-17	Cass Cronin	cass.cronin@geemail.com	New York	New York	501894252528347	86984a616b860cc806643cc4ab417798	JCB 15 digit	40.5779326609093687	-73.9784338895127149
45513	2020-08-17 00:44:38	2020-08-17	Miss Nelie Douglas	miss.nelie.douglas@geemail.com	Louisville	Kentucky	3449830180533542	2ef3732c6cba3752600747e032651218	Maestro	38.1182082632925372	-85.7303840610269532
45514	2020-08-17 00:47:52	2020-08-17	Chrystal Hickle	chrystal.hickle@geemail.com	San Diego	California	3034971856005283	05999ef50b84a20de24b2eec568dce5e	JCB 15 digit	32.7758057850480071	-117.195424359515314
45515	2020-08-17 00:49:56	2020-08-17	Artis Borer	artis.borer@geemail.com	Riverside	California	4850983970758155	ffcc3ae44bc223703df73636651aa8e8	VISA 16 digit	33.9607661100052312	-117.418094595099603
45516	2020-08-17 00:50:39	2020-08-17	Diane Skiles	diane.skiles@geemail.com	San Jose	California	3096443054190368771	589ef6beaed9270081f244f2b9196090	Mastercard	37.2998341391149921	-121.800957348685344
45517	2020-08-17 00:52:24	2020-08-17	Mikhail Roberts	mikhail.roberts@woohoo.com	Los Angeles	California	869910735291383205	c404601156d8ab18ca93af81cbff84ea	Diners Club / Carte Blanche	33.9458388487208609	-118.347488179196787
45518	2020-08-17 00:55:51	2020-08-17	Peggy Funk	peggy.funk@woohoo.com	Houston	Texas	6011033054150546156	c0adbb8401cdb86ad36e37012c8ac5e7	VISA 16 digit	29.6906051548276082	-95.3551571757547549
45519	2020-08-17 00:57:14	2020-08-17	Dr. Melony Harber PhD	dr.melony.harber.phd@woohoo.com	Lancaster	California	869972134229985684	3e75b0782fae3a12044ad62acc9902f7	Voyager	34.734627724044401	-118.150627148521309
45520	2020-08-17 01:03:25	2020-08-17	Merrily Shields	merrily.shields@geemail.com	Chicago	Illinois	4666088578632986	e65a93076c948983ef9fd719790ec1bb	Voyager	41.7546565587002831	-87.7206986749574469
45521	2020-08-17 01:03:34	2020-08-17	Sergio Greenholt	sergio.greenholt@geemail.com	Wichita	Kansas	4978792784305	440fc88651c12334bf92d8ac0fb7be25	Maestro	37.6460007157985146	-97.418407144464183
45522	2020-08-17 01:05:58	2020-08-17	Vincent Runte	vincent.runte@geemail.com	Los Angeles	California	4535989323422285	aa1f4a4b2cf3159f2684e1f36b8ce510	VISA 16 digit	33.9389422966964531	-118.480533836269004
45523	2020-08-17 01:06:34	2020-08-17	Mr. Alonza Erdman	mr.alonza.erdman@woohoo.com	Chicago	Illinois	3088403512202217193	f00ed82328adc257b96f5aad15403b9c	Maestro	41.9130490255378234	-87.6345403690852152
45524	2020-08-17 01:13:57	2020-08-17	Carmelita Leffler	carmelita.leffler@woohoo.com	Plano	Texas	3047247619294572	4ceb49f3bb122c8d8602e12059844c23	JCB 15 digit	33.0777469482358555	-96.6480350486651076
45525	2020-08-17 01:31:30	2020-08-17	Mariana Schultz-Von	mariana.schultz.von@geemail.com	Carrollton	Texas	060449804088570	c3ba5e2a3c215d29c973c8a84f8283bc	Maestro	33.0071912452965961	-96.8682451334178438
45526	2020-08-17 01:36:43	2020-08-17	Dr. Gilmore Smitham V	dr.gilmore.smitham.v@geemail.com	Columbia	Missouri	4625496156855046	76db5d625fa87ce87c5f26c06b46cede	JCB 15 digit	38.9260740821131179	-92.3784847972502092
45527	2020-08-17 01:48:19	2020-08-17	Dr. Buddy Toy	dr.buddy.toy@warmmail.com	Frisco	Texas	3437629408351784	1d933794b9649e925135c7e242f39d23	VISA 16 digit	33.1080054321788282	-96.7569266316689465
45528	2020-08-17 01:49:46	2020-08-17	Socorro Ritchie	socorro.ritchie@geemail.com	New York	New York	180065748338591213	645a1acb1d3130571eb4c0fd1c5aa2c3	Diners Club / Carte Blanche	40.6120437874682239	-73.9114414915338074
45529	2020-08-17 01:51:19	2020-08-17	Dr. Arlis Bailey	dr.arlis.bailey@geemail.com	San Francisco	California	4294910875643277	8752d3aa037b824cbfb959170c9dbc3a	Diners Club / Carte Blanche	37.7933040238219604	-122.390244650050136
45530	2020-08-17 01:51:36	2020-08-17	Mac Reichel	mac.reichel@warmmail.com	Los Angeles	California	6011450995385454224	e7bf89a313c541c6fffe454edfd6d689	Discover	33.9245213441416595	-118.464058381085465
45531	2020-08-17 01:53:10	2020-08-17	Gidget Lebsack-Quigley	gidget.lebsack.quigley@geemail.com	Amarillo	Texas	3112788625609094935	d24cefe2c8c4ac2903131c2138244dc2	VISA 13 digit	35.1879945348180811	-101.75691106113122
45532	2020-08-17 02:01:48	2020-08-17	Keifer Lakin	keifer.lakin@warmmail.com	Fresno	California	210090898548982485	3c83eaad33610c8e7b7fa15614e0567c	JCB 16 digit	36.7508105676494523	-119.83535343037137
45533	2020-08-17 02:03:55	2020-08-17	Mrs. Merri Hyatt	mrs.merri.hyatt@geemail.com	Columbia	South Carolina	675912865659523	c6f77256b6ae24fb7c83265851c64504	Maestro	33.945317107372361	-80.8974607031810962
45534	2020-08-17 02:09:23	2020-08-17	Garold Macejkovic	garold.macejkovic@geemail.com	Columbus	Ohio	869996767420762980	87ffd2489877275c21610180818c3f34	JCB 16 digit	40.0381189678374696	-82.8896916543368292
45535	2020-08-17 02:13:41	2020-08-17	Oney Monahan-Reynolds	oney.monahan.reynolds@geemail.com	New York	New York	3000094062829331	40803efeb3dde3bf9519fef76f375737	Mastercard	40.6094959680214487	-73.879405504361543
45536	2020-08-17 02:18:15	2020-08-17	Brande Daniel PhD	brande.daniel.phd@geemail.com	Scottsdale	Arizona	4703537792517279	d04d04b498785cd8af63cfac4dfaf5ba	Voyager	33.7616563181050111	-111.817848763658105
45537	2020-08-17 02:22:50	2020-08-17	Cathy Block DVM	cathy.block.dvm@geemail.com	Hollywood	Florida	3096471846145204968	312e5ef3f380b384070bcc64a8f14447	American Express	26.0666091616675253	-80.2022122316345474
45538	2020-08-17 02:24:20	2020-08-17	Bob Witting	bob.witting@geemail.com	Los Angeles	California	4982242398450	3a047f417a3c7da1450628da11fe3726	Voyager	33.9766619000915426	-118.386357165499774
45539	2020-08-17 02:29:55	2020-08-17	Tenika Lehner	tenika.lehner@geemail.com	San Diego	California	180065932290818836	76f04fe59bc82b6112bdf42d493b7f1f	JCB 16 digit	32.7264170576885363	-117.183880199762072
45581	2020-08-17 06:20:56	2020-08-17	Kizzie Bahringer	kizzie.bahringer@geemail.com	Indianapolis	Indiana	4119924258255339	43b82f5ce5f1cec696e7ce4a96f55cd8	Discover	39.8493524508558181	-86.2198541076589322
45540	2020-08-17 02:34:48	2020-08-17	Mrs. Christeen Bogisich MD	mrs.christeen.bogisich.md@woohoo.com	Plano	Texas	4515853416791226	4067843602cd493805fc7a67808ba065	VISA 16 digit	33.0150627069726639	-96.7978574372544927
45541	2020-08-17 02:35:19	2020-08-17	Maynard Grady	maynard.grady@geemail.com	Eugene	Oregon	3112293603544801779	c7c420743445c37457dc718e3d92821e	JCB 16 digit	44.0052524842981256	-123.056123403924332
45542	2020-08-17 02:40:10	2020-08-17	Megan Welch DDS	megan.welch.dds@geemail.com	Eugene	Oregon	180076702758962948	74bf6e4dfb5afd0b8be1073486302366	VISA 16 digit	43.9694238037064693	-123.185694926510379
45543	2020-08-17 02:48:08	2020-08-17	Isidore Hegmann-Funk	isidore.hegmann.funk@warmmail.com	Davenport	Iowa	869915428200228688	b0634854241e19adb63d46750d58fb0b	American Express	41.5174212607353894	-90.5798865066803955
45544	2020-08-17 02:50:10	2020-08-17	Eppie Williamson	eppie.williamson@geemail.com	Chicago	Illinois	3050602908388336	516439087c2ec24771ccea310e36168d	Maestro	41.8902746477931771	-87.6174662847101615
45545	2020-08-17 03:03:46	2020-08-17	Eldora Kautzer	eldora.kautzer@geemail.com	Indianapolis	Indiana	54981923387881820	3b0c5d7750f17bdd623c799e0d8ff3b9	Maestro	39.8311407827779647	-86.1333736633617377
45546	2020-08-17 03:03:53	2020-08-17	Nella Altenwerth	nella.altenwerth@geemail.com	San Francisco	California	4696262594505	3c72c5f5428a8255532d346b0ade8ff1	VISA 16 digit	37.7328349519617703	-122.3960891894491
45547	2020-08-17 03:10:29	2020-08-17	Miranda Treutel DVM	miranda.treutel.dvm@geemail.com	El Paso	Texas	3337157106035768338	421727fbd65ef452cc4f7b951b7ed92f	Diners Club / Carte Blanche	31.7960197284646355	-106.491638126082719
45548	2020-08-17 03:25:18	2020-08-17	Mr. Doss Paucek	mr.doss.paucek@geemail.com	San Francisco	California	180033852704067979	9ff104bf0ac1e1a2d161f65c273e647b	VISA 16 digit	37.7514440223080356	-122.451648663810985
45549	2020-08-17 03:25:34	2020-08-17	Charlize Gerlach PhD	charlize.gerlach.phd@geemail.com	San Francisco	California	51481907544865896	b758606f70b9bb7a720450aab359125b	Maestro	37.758519914255757	-122.423014730173421
45550	2020-08-17 03:27:09	2020-08-17	Elizah Leffler	elizah.leffler@woohoo.com	Mesa	Arizona	3096102651623074652	f4a7bf5af644778ff97985da2cddd1b1	VISA 16 digit	33.4442066307324879	-111.671861944010104
45551	2020-08-17 03:30:09	2020-08-17	Albertus Schimmel	albertus.schimmel@geemail.com	Los Angeles	California	210053538168930472	a7342e0398f78cbb256b15628e211a5b	Maestro	34.0236494117282291	-118.421828517456717
45552	2020-08-17 03:30:42	2020-08-17	Orange Torphy	orange.torphy@geemail.com	Chattanooga	Tennessee	4424110777883831	31843d0af1726a0a20e0d88a61aa2f82	JCB 16 digit	34.9887590588387098	-85.2128454692490465
45553	2020-08-17 03:43:03	2020-08-17	Florentino Mills	florentino.mills@warmmail.com	Philadelphia	Pennsylvania	6011667038057809281	9c34a481845e8b46c0cc610cb6814e2f	VISA 13 digit	40.0890180095523618	-75.1320710951827522
45554	2020-08-17 03:51:38	2020-08-17	Cristin Considine-Fisher	cristin.considine.fisher@geemail.com	Phoenix	Arizona	210003659720349596	8a2875992ca04003f4c9bb6a2def5c5d	Mastercard	33.5799601331751845	-112.100153458716733
45555	2020-08-17 04:00:49	2020-08-17	Ms. Rosanne Balistreri	ms.rosanne.balistreri@geemail.com	Los Angeles	California	54516699328742792	2c2099e4a875a9552b140d34dd27abaa	Voyager	33.9689618524495458	-118.47357471538632
45556	2020-08-17 04:06:16	2020-08-17	Mrs. Shante D'Amore PhD	mrs.shante.d'amore.phd@woohoo.com	Detroit	Michigan	3449581143213074	71f14f034286f8e3845698ccb5d684ad	Voyager	42.3430978971459027	-83.0064084951884951
45557	2020-08-17 04:12:35	2020-08-17	Jarett Effertz	jarett.effertz@geemail.com	Long Beach	California	060494056993713	ff7261e163c9f409bbf8bea4c8284552	American Express	33.8763639500185789	-118.173516792168087
45558	2020-08-17 04:26:41	2020-08-17	Chase Jones	chase.jones@geemail.com	Arvada	Colorado	4282677586869871	4fbe2ce6bd3738490403fc7420f2048c	JCB 16 digit	39.8096132188744818	-105.073796741009872
45559	2020-08-17 04:29:29	2020-08-17	Estelle Prohaska	estelle.prohaska@geemail.com	Chandler	Arizona	630409934017253	d786c3068c1a4c7acc5edc466a52b963	VISA 13 digit	33.2664704511962839	-111.771817256219308
45560	2020-08-17 04:32:20	2020-08-17	Stephen Homenick	stephen.homenick@geemail.com	Toledo	Ohio	4477330682848705	a050b3006c311b82d2d7ff4e8d7a7853	Voyager	41.5779720995746516	-83.6230772953812078
45561	2020-08-17 04:32:28	2020-08-17	Mai Jones	mai.jones@geemail.com	Rochester	New York	3000121977146616	a2d99f2bc8e5ff106f1a0b75542b2f24	Maestro	43.1237504017982616	-77.5777566147740885
45562	2020-08-17 04:44:44	2020-08-17	Kamya Wunsch	kamya.wunsch@woohoo.com	Los Angeles	California	3088350704566737998	5b4cabd0ed67a04c70e22b0272c5d853	VISA 16 digit	33.9402389716222856	-118.399081742483375
45563	2020-08-17 04:47:55	2020-08-17	Frazier Hand	frazier.hand@geemail.com	Portland	Oregon	180014589500167974	df437bdaa96ceb4d541fa986f465deb5	Discover	45.4826695740111191	-122.701651682565
45564	2020-08-17 05:02:51	2020-08-17	Iesha Medhurst	iesha.medhurst@geemail.com	Colorado Springs	Colorado	676102140114469	5f94643ab41aa64588352f452897d824	Voyager	38.9232039723128054	-104.826157819541919
45565	2020-08-17 05:03:49	2020-08-17	Dr. Forrest Goyette DVM	dr.forrest.goyette.dvm@geemail.com	Bakersfield	California	676250215614343	a861506f20be699a0d390807724420ab	JCB 16 digit	35.3529065417300856	-118.952704196357345
45566	2020-08-17 05:10:06	2020-08-17	Mrs. Elianna Schinner	mrs.elianna.schinner@geemail.com	Oklahoma City	Oklahoma	3337743187882585380	b488ec76edb363aeb1f1049f92d954c5	Mastercard	35.3944235929664259	-97.5999159290350917
45567	2020-08-17 05:17:47	2020-08-17	Elenore Huels	elenore.huels@geemail.com	San Jose	California	503897024042026	f5e5b640c473806346a7b93201e3d935	VISA 13 digit	37.3842111530069303	-121.776318223377316
45568	2020-08-17 05:26:06	2020-08-17	Sybil Pfeffer	sybil.pfeffer@geemail.com	Seattle	Washington	639080024731657	4890e8c6fdf610a0d6763634b4ff58e4	Voyager	47.5475723351277395	-122.325029245709629
45569	2020-08-17 05:29:17	2020-08-17	Damond Greenfelder	damond.greenfelder@geemail.com	Glendale	Arizona	6011084567809549295	c67c70f802ea1d0338e0477cdc0c9a68	Diners Club / Carte Blanche	33.6202292272582639	-112.265805300350848
45570	2020-08-17 05:36:20	2020-08-17	Buddy Carter	buddy.carter@geemail.com	Hayward	California	4912297366781077	64c2b12996db876e091d3176262cb123	VISA 16 digit	37.7189015359140924	-122.162516952937096
45571	2020-08-17 05:38:31	2020-08-17	Talon Kozey	talon.kozey@warmmail.com	San Antonio	Texas	4103595218873730	3b9d626472cc7b45234f5d379376b685	JCB 16 digit	29.4633300523344417	-98.5588426139972995
45572	2020-08-17 05:40:21	2020-08-17	Shandra Hansen	shandra.hansen@warmmail.com	Seattle	Washington	502026446836038	c75cafdd656c2acd402a543353970dcc	JCB 16 digit	47.5966904376093325	-122.255077022725345
45573	2020-08-17 05:47:35	2020-08-17	Allyssa Romaguera	allyssa.romaguera@woohoo.com	San Francisco	California	51568756338525596	52d371854ca6fe85325632da02d9cde0	JCB 16 digit	37.7565889558088585	-122.403925227466345
45574	2020-08-17 05:49:56	2020-08-17	Ota Jacobs DVM	ota.jacobs.dvm@geemail.com	Portland	Oregon	3451372770254226	13f2e95802f2f2212e9d1d818d21cb43	Discover	45.495492579218002	-122.658686260273683
45575	2020-08-17 05:52:24	2020-08-17	Glinda Ebert MD	glinda.ebert.md@geemail.com	New York	New York	3337842669876256409	0db2caed1d1d1c523278f7668c6ddc83	Mastercard	40.6073981965184174	-73.943013839226964
45576	2020-08-17 05:54:01	2020-08-17	Ceil Gaylord	ceil.gaylord@woohoo.com	Pembroke Pines	Florida	3096872124096416964	34933d26530dc99bd46b5e1d4f19b32e	JCB 16 digit	26.0458985439073309	-80.3440272411700391
45577	2020-08-17 06:07:26	2020-08-17	Case Greenholt-Bauch	case.greenholt.bauch@woohoo.com	Washington	District of Columbia	4846336279795	a211cc8080fcd48a81fe489208c2f274	VISA 16 digit	38.8291341055449095	-77.0115329857662374
45578	2020-08-17 06:07:30	2020-08-17	Ruel Howe	ruel.howe@woohoo.com	Phoenix	Arizona	869983513482953041	3a5007bef7b22a38ed41af9a9c75bd48	Mastercard	33.6010250992540307	-112.173106262220443
45579	2020-08-17 06:09:11	2020-08-17	Mahalia Kuhic	mahalia.kuhic@woohoo.com	Huntsville	Alabama	3088412247841913170	2f8fe6874188c10dc18f18f400df3a11	JCB 16 digit	34.7110356746483575	-86.6466647836398352
45580	2020-08-17 06:19:20	2020-08-17	Dr. Emerson Bogan V	dr.emerson.bogan.v@warmmail.com	Albuquerque	New Mexico	3158208210610880200	d8a48ffcfe18e8cdebe5e02951647eb7	Maestro	35.0810757508169857	-106.678479810112719
45582	2020-08-17 06:21:47	2020-08-17	Harry Kris	harry.kris@geemail.com	Oklahoma City	Oklahoma	54280513310708246	01e2166415261fb75d8990c00630e6aa	Voyager	35.5366691727101838	-97.5680385046999845
45583	2020-08-17 06:23:13	2020-08-17	Chiquita Kuhn PhD	chiquita.kuhn.phd@geemail.com	Clearwater	Florida	676122341353948	6073767fdb65cd26c6befc4a745597a1	American Express	27.9358144584238524	-82.7182916569322373
45584	2020-08-17 06:24:42	2020-08-17	Lashawn Collins	lashawn.collins@geemail.com	Hartford	Connecticut	4353473050212	cf652622ba5552dcdbcc82b0fe755ab8	VISA 16 digit	41.7859178413186214	-72.588927723922211
45585	2020-08-17 06:29:54	2020-08-17	Amanda Greenholt MD	amanda.greenholt.md@geemail.com	Los Angeles	California	3731303934638603	57b0e37922c1da29bd70bfa7c64566e8	Voyager	33.9272238710761016	-118.399595809494329
45586	2020-08-17 06:31:45	2020-08-17	Mrs. Alesha Nienow	mrs.alesha.nienow@geemail.com	Charleston	South Carolina	6011339542098241576	559f5c3dbf6c0842c056ead8aaab70f5	American Express	32.73584116324745	-79.904406188815841
45587	2020-08-17 06:40:44	2020-08-17	Dr. Claudette Murray	dr.claudette.murray@geemail.com	Henderson	Nevada	210012822384236389	97a4ec9532c72e11b14eb4cf3980e9e5	Maestro	35.9104684457581484	-114.979306711085897
45588	2020-08-17 06:46:30	2020-08-17	Alida Rau	alida.rau@geemail.com	Baltimore	Maryland	869965641032724166	d59e0566b577a934ba1298511008d5a9	Mastercard	39.3253078822512165	-76.5181535055879465
45589	2020-08-17 06:47:50	2020-08-17	Assunta Bogisich	assunta.bogisich@woohoo.com	Nashville	Tennessee	869934236375957792	2f2f63d87708a806c307a9daf995d0bb	Voyager	36.1486620568793242	-86.8705144361965296
45590	2020-08-17 06:51:00	2020-08-17	Willard Waelchi	willard.waelchi@warmmail.com	Los Angeles	California	3727715006595344	7ce9eb0952ca6de79294a8019e9c6a5e	VISA 16 digit	33.9869414217635963	-118.361514688375593
45591	2020-08-17 06:52:11	2020-08-17	Diamond Rolfson	diamond.rolfson@warmmail.com	San Jose	California	55695215400310177	cf9f37dcfe4bf12a330380d3395c6b79	Discover	37.3026213790576904	-121.788671652529018
45592	2020-08-17 07:09:58	2020-08-17	Natalia Leffler-Wisoky	natalia.leffler.wisoky@woohoo.com	Port St. Lucie	Florida	3043901543636522	b8ac85f7291fa57c83df852a8147e353	Mastercard	27.3170089034497749	-80.4527287224859009
45593	2020-08-17 07:13:50	2020-08-17	Miss Rowena Crooks	miss.rowena.crooks@geemail.com	Philadelphia	Pennsylvania	4083413319126	aac8b91777cd4cd32b592e628ed4b174	VISA 13 digit	40.023752740626783	-75.0666725666627315
45594	2020-08-17 07:17:16	2020-08-17	Dr. Elwin Kilback V	dr.elwin.kilback.v@warmmail.com	San Francisco	California	4109740266673939	b6ec75fd27f0f3a78e88c1edc67574db	Maestro	37.7546589087937718	-122.441425535056638
45595	2020-08-17 07:19:09	2020-08-17	Bulah Howe	bulah.howe@geemail.com	Houston	Texas	6011782430875247192	f0807447c4c7c8e567a0ce4b81e158a2	VISA 16 digit	29.7658737479787305	-95.3626395927757073
45596	2020-08-17 07:27:19	2020-08-17	Lawerence Rippin	lawerence.rippin@geemail.com	Palm Bay	Florida	3778994622269430	e9a58eba955e591c61bd4cfce28a1069	Discover	27.954301165867971	-80.731870648621026
45597	2020-08-17 07:32:10	2020-08-17	Dean Parker	dean.parker@geemail.com	San Francisco	California	3158538738341258743	b819323fb003da79d74201a30497bc7b	American Express	37.7576368632045529	-122.430054802971085
45598	2020-08-17 07:39:06	2020-08-17	Dr. Gee Langworth Sr.	dr.gee.langworth.sr.@woohoo.com	Akron	Ohio	501894042032816	287fc62e326ec1f809f5121b86622220	VISA 16 digit	41.0242805891036966	-81.5842776814788522
45599	2020-08-17 07:50:28	2020-08-17	Latrice Will-Hermiston	latrice.will.hermiston@geemail.com	Columbus	Ohio	4082512618708270	d301b65828282fa05b090f2bf846f853	Discover	39.9741936587773239	-82.9051950975090364
45600	2020-08-17 07:56:38	2020-08-17	Orla Boyle-Douglas	orla.boyle.douglas@geemail.com	Houston	Texas	6011711826884474980	d353e51facc94ce57afca9c5112eb8a0	Diners Club / Carte Blanche	29.8708339332681163	-95.4273939047489392
45601	2020-08-17 08:01:45	2020-08-17	Cathern Harris	cathern.harris@geemail.com	West Valley City	Utah	210008939061925096	e288010a6911382948b9b59ae6d7affe	Diners Club / Carte Blanche	40.7438095897193975	-112.111330731234688
45602	2020-08-17 08:06:40	2020-08-17	Wyatt Doyle	wyatt.doyle@woohoo.com	San Francisco	California	6011604772956408334	1c7fcadd9b289886b6e8a0a32094c219	VISA 16 digit	37.7849153528236243	-122.424361297207483
45603	2020-08-17 08:10:51	2020-08-17	Sable Rosenbaum	sable.rosenbaum@warmmail.com	Los Angeles	California	4427368325816102	15799f25f1c99b4c9f08388f79104ab8	JCB 15 digit	34.1109452470537278	-118.464043710240347
45604	2020-08-17 08:18:46	2020-08-17	Devan Bode	devan.bode@geemail.com	Orange	California	6011842812309065928	ca5227f1e138923188bf934cac37b443	American Express	33.7637112128902217	-117.83525053319633
45605	2020-08-17 08:22:19	2020-08-17	Orlando Heathcote	orlando.heathcote@geemail.com	San Francisco	California	54790769568031052	c03a59fe93835c301a5d283219b27bfd	Diners Club / Carte Blanche	37.8076548442530296	-122.466893825509374
45606	2020-08-17 08:23:30	2020-08-17	Ocie Haag	ocie.haag@warmmail.com	San Francisco	California	676314164855026	b29ee467eb807cec35cb143a70607cb0	Mastercard	37.7561562266170512	-122.41960061664544
45607	2020-08-17 08:23:47	2020-08-17	Maurice Gerhold	maurice.gerhold@warmmail.com	Denver	Colorado	6011477571197806742	3d8bdf0ec9cc9cb613c24e1b1d13bc1a	American Express	39.7922369567729532	-104.862057826087252
45608	2020-08-17 08:27:30	2020-08-17	Miss Lilian Haag MD	miss.lilian.haag.md@geemail.com	Roseville	California	51236603512267904	81d9c954009ca956dcd9754e4786aa80	JCB 16 digit	38.7394116753302526	-121.33492420918644
45609	2020-08-17 08:29:47	2020-08-17	Yesenia Kemmer	yesenia.kemmer@geemail.com	Los Angeles	California	3475373785297632	02764a038bcc045cc6eb87d4ee63b27f	JCB 16 digit	34.0807184685818854	-118.360706096560875
45610	2020-08-17 08:33:02	2020-08-17	Gail Mitchell	gail.mitchell@warmmail.com	Chandler	Arizona	3158713637625927899	be81eab75b6593e79b38ff2fc9eac326	VISA 16 digit	33.3670633749194394	-111.930908619181807
45611	2020-08-17 08:42:17	2020-08-17	Adrain Lemke	adrain.lemke@warmmail.com	Santa Rosa	California	4952845964727	35159a57d1e21c7b3bd3ae43b6626c15	JCB 15 digit	38.4633309713687765	-122.798900405668107
45612	2020-08-17 08:48:12	2020-08-17	Akeelah Jerde	akeelah.jerde@woohoo.com	Tampa	Florida	869952780734817061	1bc29ca8745a823a84a707c3442c9258	American Express	27.8755016746114919	-82.4659881185952486
45613	2020-08-17 08:55:48	2020-08-17	Russell Lubowitz	russell.lubowitz@warmmail.com	Tallahassee	Florida	3528129066147935602	3206e5c2507ad77498c5dca801344e26	Voyager	30.4190241733122626	-84.2838889790713779
45614	2020-08-17 09:03:21	2020-08-17	Sage Lesch	sage.lesch@warmmail.com	Berkeley	California	3096786591700687856	7be6a651ed5201b8514105ed24244a47	Maestro	37.8850937259447562	-122.268649675559487
45615	2020-08-17 09:10:48	2020-08-17	Mrs. Cristal Gulgowski	mrs.cristal.gulgowski@woohoo.com	Savannah	Georgia	3096443991219196701	eeb1ecfc890265d7454cfa5d7a611dc5	Voyager	32.0779931921604984	-81.1785575254507279
45616	2020-08-17 09:27:10	2020-08-17	Micayla Dach	micayla.dach@geemail.com	New York	New York	4182546536552765	869a0a68d5af6b6e67c0b35b7ec59886	JCB 15 digit	40.6603974738847427	-73.9911069146718745
45617	2020-08-17 09:39:08	2020-08-17	Ms. Trish White PhD	ms.trish.white.phd@geemail.com	New York	New York	6011643028939513630	eeb9270d9564d7891d62cd4e64b8d8e0	JCB 16 digit	40.7545027811769387	-73.9804448794934899
45618	2020-08-17 09:42:03	2020-08-17	Ila Satterfield	ila.satterfield@geemail.com	Colorado Springs	Colorado	561260754194094	ec22006a6c330f3b96ce00aebf27181c	VISA 13 digit	38.897265803166853	-104.72012510212771
45619	2020-08-17 09:43:42	2020-08-17	Shawanda Braun	shawanda.braun@geemail.com	San Jose	California	53235202207322776	277799484b54a40ddf0a3fd90c071a7b	Mastercard	37.2732284200198976	-121.7629402818378
45620	2020-08-17 09:53:03	2020-08-17	Dr. Sadye Bartell	dr.sadye.bartell@geemail.com	Baltimore	Maryland	4270583528657	78654f6b9accb983dde3aebefe52120d	VISA 16 digit	39.2849995408207135	-76.5636942537054495
45621	2020-08-17 09:54:07	2020-08-17	Annabel Renner	annabel.renner@geemail.com	Winston–Salem	North Carolina	4393374118589252	3e453343a6cbc652be016cfcae8ad0c6	Discover	36.1851076322838665	-80.3505966745913014
45622	2020-08-17 10:04:14	2020-08-17	Dinah Hudson	dinah.hudson@geemail.com	San Jose	California	3528171025472046572	2352afa11915c91e831fbd3763ad2d08	Mastercard	37.3762280680526047	-121.805153541940825
45623	2020-08-17 10:07:09	2020-08-17	Lou Von	lou.von@geemail.com	San Francisco	California	3023717315632634	b999576f133d37cd6a3408e5b4659fa2	VISA 16 digit	37.779568746579649	-122.395497436734402
45624	2020-08-17 10:11:08	2020-08-17	Arra Gutmann MD	arra.gutmann.md@geemail.com	Yonkers	New York	210074803109620037	49b275c8e7372be4de6ad3c3cd163ea7	JCB 16 digit	41.0338128419328498	-73.8890728974133708
45625	2020-08-17 10:12:10	2020-08-17	Marianne Grant	marianne.grant@geemail.com	Fort Wayne	Indiana	3088820152073982958	e2b9b3b10dc2202af52978ef6a737ad2	JCB 15 digit	41.0583532039325689	-85.1031468275222949
45626	2020-08-17 10:12:14	2020-08-17	Jewel Kovacek	jewel.kovacek@geemail.com	Oklahoma City	Oklahoma	4911648199311	a4c348a2d93d230ba860446aad2287a1	Mastercard	35.3769268548026687	-97.5659484219167439
45627	2020-08-17 10:18:55	2020-08-17	Loriann Hartmann	loriann.hartmann@woohoo.com	Joliet	Illinois	4362033612133127	1ff99f02dcdab0df0b442cd4f8ea0dd7	Voyager	41.5002675645377437	-88.0996325047325257
45628	2020-08-17 10:20:42	2020-08-17	Gale Considine	gale.considine@geemail.com	Norman	Oklahoma	3039363109979958	7dbe8af0ea7054cf8cb57b80d60b740b	American Express	35.17418516627923	-97.3756265981376146
45629	2020-08-17 10:40:05	2020-08-17	Jesenia Cremin	jesenia.cremin@warmmail.com	Dallas	Texas	3463184646238093	cd6a78e7d48a54b97ebeeecdac939732	JCB 15 digit	32.7582807237554334	-96.7439469927418969
45630	2020-08-17 10:41:43	2020-08-17	April Jakubowski	april.jakubowski@woohoo.com	Chicago	Illinois	210000153193675292	b0f107a6606c5a1b117e354464664866	American Express	41.8100665291607427	-87.7305208203412548
45631	2020-08-17 10:43:18	2020-08-17	Asha Collins	asha.collins@geemail.com	Lexington	Kentucky	3337480580570187922	99d2f6eabd98d1d8e9f7c1844d8c06a9	Diners Club / Carte Blanche	37.943819186777624	-84.3888080953519761
45632	2020-08-17 10:45:35	2020-08-17	Lee White-Rippin	lee.white.rippin@geemail.com	Dallas	Texas	503841710818398	fddba990f1df5941380770c28f80906b	JCB 15 digit	32.8843338093060993	-96.7322958393450705
45633	2020-08-17 10:46:44	2020-08-17	Kegan Thompson-Mills	kegan.thompson.mills@geemail.com	Scottsdale	Arizona	4186339394631319	a44e623285a195a0a9b011e5f9ab5c27	VISA 16 digit	33.742800109286982	-111.947703105207893
45634	2020-08-17 10:55:18	2020-08-17	Ms. Katharyn Macejkovic DDS	ms.katharyn.macejkovic.dds@warmmail.com	Norfolk	Virginia	4777192682642	1d777f9e8abfe3b44de4c1db750410ee	JCB 15 digit	36.9684113663174259	-76.3212833391506251
45635	2020-08-17 10:57:37	2020-08-17	Jaidyn Hills	jaidyn.hills@geemail.com	Raleigh	North Carolina	3528985075460866974	372dfec6960d9854a50ada501231f7a8	Maestro	35.8838407861668571	-78.6676514077868347
45636	2020-08-17 10:58:52	2020-08-17	Dr. Morton Jakubowski III	dr.morton.jakubowski.iii@warmmail.com	Green Bay	Wisconsin	54447771758227331	fddd32d066fc6178cfffb5fb69135fb0	American Express	44.4536595192801158	-87.9785138096481631
45637	2020-08-17 11:03:34	2020-08-17	Lesley Goodwin	lesley.goodwin@warmmail.com	Aurora	Colorado	3112955847662322568	9af63448601ad06be12863728bee6213	Discover	39.7320458178520255	-104.694552717649188
45638	2020-08-17 11:03:55	2020-08-17	Cornelious Lueilwitz IV	cornelious.lueilwitz.iv@geemail.com	Pasadena	Texas	53528011652671447	ed328a3e9245e8bc5a34098f903ab59d	VISA 13 digit	29.7036443221256121	-95.0989278755564271
45639	2020-08-17 11:07:24	2020-08-17	Jessie Hane	jessie.hane@geemail.com	Wichita	Kansas	869993398465242838	0e2b1f84c2a3c7ef5209088bf596f964	VISA 13 digit	37.7394555491738046	-97.3043248400293237
45640	2020-08-17 11:07:52	2020-08-17	Dr. Arthor Turner V	dr.arthor.turner.v@warmmail.com	San Francisco	California	6011089278934875523	8689dbbe6c15a5dfefbdc0d4cf4f9de0	Diners Club / Carte Blanche	37.7540961240928468	-122.457965558659382
45641	2020-08-17 11:08:43	2020-08-17	Ms. Stacia Boehm	ms.stacia.boehm@geemail.com	Kansas City	Missouri	869904192249241366	e07a8ef85480fcd40b33847a48640567	VISA 16 digit	39.161017830653492	-94.5340810504034152
45642	2020-08-17 11:08:47	2020-08-17	Dr. Tyreke Stamm V	dr.tyreke.stamm.v@warmmail.com	San Francisco	California	180000353341661398	045b9374d47bfc796c7a336671f7a9eb	VISA 16 digit	37.7381135774731362	-122.449251323655744
45643	2020-08-17 11:09:10	2020-08-17	Wilbur Sanford	wilbur.sanford@geemail.com	San Francisco	California	869922527729555256	6d3c2aa9b9a8d7e494c90e626b46fa84	Maestro	37.7912839264316602	-122.401835549089412
45644	2020-08-17 11:19:35	2020-08-17	Shanita Quitzon	shanita.quitzon@geemail.com	Houston	Texas	4029331722008154	17528d4fcecad19a84b5c0500d5399f4	VISA 13 digit	29.7279053596857921	-95.4347706160057356
45645	2020-08-17 11:31:56	2020-08-17	Rosalia Goldner	rosalia.goldner@geemail.com	Fort Wayne	Indiana	55136263839731339	3402ec4e85be561c8fc5eb550252c8bd	Voyager	41.0251775057304684	-85.1904586838778073
45646	2020-08-17 11:34:11	2020-08-17	Dominque Howe	dominque.howe@geemail.com	Tampa	Florida	4893214190777	e05b2900aeb27bdf10b081f29e16ce04	JCB 16 digit	28.0455210367798777	-82.5280206144999653
45647	2020-08-17 11:35:45	2020-08-17	Zoey Farrell DVM	zoey.farrell.dvm@geemail.com	Gresham	Oregon	3731663313639666	03737444c88e126b113501776eba3e5e	VISA 16 digit	45.4556650805242342	-122.416983557425809
45648	2020-08-17 11:36:09	2020-08-17	Dr. Mercy Block DDS	dr.mercy.block.dds@geemail.com	Phoenix	Arizona	676148703001197	6400aed772d369a5262f6d3b8c27c2dc	VISA 16 digit	33.6315440529424734	-111.994243427126122
45649	2020-08-17 11:44:02	2020-08-17	Minnie Okuneva-Christiansen	minnie.okuneva.christiansen@warmmail.com	Edison	New Jersey	4901431255271	821908c943bd2482739d39e7b31f4757	Maestro	40.5223253379072972	-74.4368900147784558
45650	2020-08-17 11:44:32	2020-08-17	Wayde Rempel	wayde.rempel@geemail.com	Phoenix	Arizona	676257895253490	d9ca2c83bd5d7e4ddbf3e2bcf9e79408	JCB 15 digit	33.5880642470371029	-112.19002748806254
45651	2020-08-17 11:45:59	2020-08-17	Dr. Jamel Larkin	dr.jamel.larkin@woohoo.com	Berkeley	California	3718254523158304	be73f5a78de970bf7db6e528eefb0d11	American Express	37.8872116561606873	-122.258641831191369
45652	2020-08-17 11:55:30	2020-08-17	Emett Reilly	emett.reilly@geemail.com	San Jose	California	3497540494716169	e4fc5e8300aaa990d532e418cdeb1351	VISA 13 digit	37.3770534963633878	-121.837343780299278
45653	2020-08-17 12:03:53	2020-08-17	Christeen Treutel	christeen.treutel@geemail.com	Oceanside	California	3112134490862679273	c92ad00cb82ed37982d08656dedabfd2	VISA 16 digit	33.2897056113816774	-117.301185395483671
45654	2020-08-17 12:09:41	2020-08-17	Mr. Van Morissette	mr.van.morissette@geemail.com	Joliet	Illinois	4693190692755334	b9e9d69651c476d920d4df37d52d1a63	Voyager	41.4265852108456158	-88.0902295932743584
45655	2020-08-17 12:09:45	2020-08-17	Edrie Howell	edrie.howell@geemail.com	Tallahassee	Florida	53374295533263624	44bb620ad486c56241453ec632ac6058	American Express	30.3910373554121733	-84.3405473986655494
45656	2020-08-17 12:11:37	2020-08-17	Claudie Goldner	claudie.goldner@geemail.com	Santa Ana	California	869952571029922538	d5997deb1d7108680d30aa576d47a547	VISA 13 digit	33.7610931696474523	-117.924906362306317
45657	2020-08-17 12:26:13	2020-08-17	Delton Orn II	delton.orn.ii@warmmail.com	San Francisco	California	869995697018307206	15c95976d14137296a26dff853c38760	Discover	37.7949628598352021	-122.43197421387778
45658	2020-08-17 12:30:16	2020-08-17	Ava Altenwerth	ava.altenwerth@geemail.com	Dallas	Texas	3088113079027454865	de5eec83aed4707003b5cd98236f05f0	Maestro	32.7543740639269387	-96.6892748171892009
45659	2020-08-17 12:42:22	2020-08-17	Josephus Daugherty	josephus.daugherty@geemail.com	San Jose	California	4040058762517159	0b774f73664cae9d2ce51e0366839f9a	JCB 15 digit	37.219124770053476	-121.726866704340651
45660	2020-08-17 12:44:30	2020-08-17	Sanjuanita Balistreri	sanjuanita.balistreri@geemail.com	Charlotte	North Carolina	3030456979428517	2ab32b87c72a874b62d8499f670bab86	Maestro	35.2890578368931997	-80.9183258199542763
45661	2020-08-17 12:59:37	2020-08-17	Jones Macejkovic	jones.macejkovic@warmmail.com	Clarksville	Tennessee	675969957308583	3f15e2de76e23d712d1b3cbd6373532b	VISA 16 digit	36.5210577238943443	-87.4321677654467635
45662	2020-08-17 13:01:56	2020-08-17	Miss Kattie Satterfield MD	miss.kattie.satterfield.md@geemail.com	Los Angeles	California	4406776256966438	abcf643adcdbdcc34dd60db768f79a27	Voyager	34.1129907531063949	-118.491378625574697
45663	2020-08-17 13:04:46	2020-08-17	Zaida Larson	zaida.larson@woohoo.com	Indianapolis	Indiana	3158137768451038358	98358c7c6963d52d30cba641ca954f36	VISA 13 digit	39.7943928146742252	-86.0527920221645388
45664	2020-08-17 13:05:56	2020-08-17	Kyree Marks II	kyree.marks.ii@geemail.com	Dallas	Texas	6011625583454512617	920b050aa60b6c5dc41826b42d704a91	JCB 16 digit	32.8714563622411333	-96.7529724340848531
45665	2020-08-17 13:07:22	2020-08-17	Miss Suzie Bode	miss.suzie.bode@geemail.com	Atlanta	Georgia	3791732476899271	d66fd58d19383aa99913361814fc2b7a	JCB 16 digit	33.8572869371432859	-84.5067358199086129
45666	2020-08-17 13:17:31	2020-08-17	Jade Moore DVM	jade.moore.dvm@geemail.com	Burbank	California	869938240718024092	c9a7f9cedae66d688ab0d3a04897ad20	JCB 16 digit	34.2294997929524669	-118.417469535398865
45667	2020-08-17 13:18:51	2020-08-17	Mr. Merlin Oberbrunner Sr.	mr.merlin.oberbrunner.sr.@woohoo.com	San Diego	California	53447879021775836	5ccb0945af84527c412c7e2cb487f98b	Maestro	32.7334720684748177	-117.145891713202005
45668	2020-08-17 13:27:54	2020-08-17	Joel Bashirian	joel.bashirian@warmmail.com	New York	New York	503820335116651	527ff37c8fc703dcc4bb2fe36a88a1a8	JCB 16 digit	40.7272690089642992	-73.9603591950506001
45669	2020-08-17 13:32:56	2020-08-17	Ariella Auer	ariella.auer@woohoo.com	Los Angeles	California	4647807926791648	21885c193d3d511333f706f1985effee	VISA 16 digit	34.1099269098933746	-118.480072273126979
45670	2020-08-17 13:33:49	2020-08-17	Dr. Cornelious Schuster IV	dr.cornelious.schuster.iv@geemail.com	Waco	Texas	3027826114500284	a1f059b4b259159da31098fb4a071207	Discover	31.4693514863237738	-97.0860415958464245
45671	2020-08-17 13:39:15	2020-08-17	Rudolf Huel	rudolf.huel@warmmail.com	Akron	Ohio	4912856794587	42dacf013b92dbe1f4de76483f49176a	Maestro	41.1397064621858277	-81.6045134005449739
45672	2020-08-17 13:39:46	2020-08-17	Sibyl Bernier	sibyl.bernier@woohoo.com	San Francisco	California	3112271773934568415	886c2964072a124a49ef8eb12c017c39	VISA 16 digit	37.7666809746166905	-122.433671393664227
45673	2020-08-17 13:44:14	2020-08-17	Miss Sherie Rolfson	miss.sherie.rolfson@geemail.com	New York	New York	4216370492094	f7952c7c764b7f44ba302ebb4d5a115c	American Express	40.7406604746580143	-73.8501638880360787
45674	2020-08-17 13:50:54	2020-08-17	Dr. Hezekiah Tromp	dr.hezekiah.tromp@woohoo.com	Berkeley	California	676258558837777	89ed5f8a122a5edc7af5079bef9b78fa	Maestro	37.8805703434268963	-122.271578772579389
45675	2020-08-17 13:51:42	2020-08-17	Sylvester Mayer V	sylvester.mayer.v@geemail.com	Louisville	Kentucky	52190606297987574	e008f4e2bc94757824d7a8d7388e6d87	Diners Club / Carte Blanche	38.1446831900529517	-85.6975594494562642
45676	2020-08-17 13:54:03	2020-08-17	Ozell Rodriguez	ozell.rodriguez@geemail.com	San Antonio	Texas	52678211868823711	59c278c34b66ae2d3fa27d5e186c59a7	American Express	29.3836514273729179	-98.5837318757384935
45677	2020-08-17 13:54:25	2020-08-17	Carlton Littel	carlton.littel@warmmail.com	Wichita	Kansas	6011598803091288196	3e9a4efad1302a63e89bae890ec591d6	VISA 13 digit	37.6195354617543529	-97.3507694683238896
45678	2020-08-17 13:55:19	2020-08-17	Brock Berge-Schamberger	brock.berge.schamberger@geemail.com	New York	New York	51123853479433082	7094df520963a460b6f09ae485e69c88	Voyager	40.6920781133919931	-73.9375878728821903
45679	2020-08-17 14:06:40	2020-08-17	Tim Kirlin	tim.kirlin@warmmail.com	Portland	Oregon	4091610584889	98cc39ac41a92255d6556492eb0ca6ff	JCB 16 digit	45.5727217424549167	-122.653859554464006
45680	2020-08-17 14:10:22	2020-08-17	Leslie Will	leslie.will@geemail.com	Corona	California	3443720686907686	8923e77ce3de335ee6a87b4cdacb0a27	American Express	33.7775979256611336	-117.596547832826147
45681	2020-08-17 14:22:25	2020-08-17	Lily Brekke	lily.brekke@geemail.com	San Francisco	California	4461886702517	0498ed9aa1a3fe75f54768d73bb3c85b	VISA 16 digit	37.7897250051931834	-122.419945139809272
45682	2020-08-17 14:24:25	2020-08-17	Gisselle Barrows	gisselle.barrows@warmmail.com	San Jose	California	180044905019543600	bdaa0ebf9c2db115c9f534417df871a5	American Express	37.3487577479619546	-121.895791296915704
45683	2020-08-17 14:29:07	2020-08-17	Ms. Ivonne Murray MD	ms.ivonne.murray.md@woohoo.com	Austin	Texas	561274790096601	4d631dad0ae0713dd6fdc50f4c5e1f9c	VISA 13 digit	30.3488426578823471	-97.6647671786375327
45684	2020-08-17 14:29:58	2020-08-17	Mr. Edmond D'Amore I	mr.edmond.d'amore.i@geemail.com	Austin	Texas	210006067213607065	010fce5d5ab15dbd64cd454ce0357796	JCB 15 digit	30.3175112723965192	-97.6575307255383649
45685	2020-08-17 14:33:21	2020-08-17	Darlene Carter MD	darlene.carter.md@geemail.com	Everett	Washington	6011084270224013571	6c6204ed4e0428c13f84b7ab15475f9f	Diners Club / Carte Blanche	48.0469522197157133	-122.147634604772179
45686	2020-08-17 14:47:21	2020-08-17	Floy Haley	floy.haley@woohoo.com	Rochester	New York	3447429963005786	3d6b6d4e5ce9d31e09cc7787e2530d48	Diners Club / Carte Blanche	43.2606160782720863	-77.5464310248155186
45687	2020-08-17 14:49:04	2020-08-17	Stacy Lakin	stacy.lakin@geemail.com	Philadelphia	Pennsylvania	3042989484303146	e96b9f9ea2e21c0d305003c5511a0c11	Maestro	39.9143509635195102	-75.2322117920398767
45688	2020-08-17 14:50:19	2020-08-17	Essence Smith	essence.smith@geemail.com	Chicago	Illinois	52147242027746405	dff3d8163231188772a403eb728b5b68	American Express	41.7495030619040151	-87.7271375715296671
45689	2020-08-17 14:51:54	2020-08-17	Mrs. Gwyn Vandervort MD	mrs.gwyn.vandervort.md@woohoo.com	St. Petersburg	Florida	52753716317636108	271d9daa642c675e461a246cf17b1590	JCB 16 digit	27.6710182192157959	-82.5530115104172353
45690	2020-08-17 14:55:54	2020-08-17	Mr. Dewey Prohaska PhD	mr.dewey.prohaska.phd@geemail.com	San Diego	California	4070565844159	a343ea00a34fce9d6f86d16fd40c8979	VISA 16 digit	32.8172309296738334	-117.202025838233538
45691	2020-08-17 14:58:05	2020-08-17	Dr. Holden Swaniawski IV	dr.holden.swaniawski.iv@geemail.com	Orange	California	3088000199050857291	3d3b50546af20b8e210e374f1037eaf5	VISA 16 digit	33.8639450789317493	-117.84177347115353
45692	2020-08-17 15:05:53	2020-08-17	Ronan Mraz	ronan.mraz@geemail.com	Chattanooga	Tennessee	4081754971570	8aa2cc96932c67db1be886826e4b98cb	American Express	35.1147073664553488	-85.3226992034647651
45693	2020-08-17 15:10:36	2020-08-17	Darian Stehr-Maggio	darian.stehr.maggio@warmmail.com	Fairfield	California	6011867042584285435	24b3b5f35686c256646be90615a1b371	Voyager	38.3405526527792233	-122.100365276402229
45694	2020-08-17 15:16:19	2020-08-17	Cena Ernser MD	cena.ernser.md@geemail.com	Austin	Texas	4769519299510750	bac9e8a3eb25628f2e3454de10d51c96	Voyager	30.2045455849390478	-97.655638776044924
45695	2020-08-17 15:16:42	2020-08-17	Mignon Wintheiser	mignon.wintheiser@warmmail.com	San Francisco	California	4071875261142	c9a8261103cc8f11b3593eedad80281b	VISA 16 digit	37.7856532386212436	-122.431911445577413
45696	2020-08-17 15:16:48	2020-08-17	Brittni Herman PhD	brittni.herman.phd@geemail.com	Yonkers	New York	53898454799005024	66d964235c46a2a9efd02dfc04ea0f18	Mastercard	41.0083841805081803	-73.9583805663861398
45697	2020-08-17 15:21:29	2020-08-17	Mendy O'Reilly	mendy.o'reilly@geemail.com	Los Angeles	California	4381187039854025	90092d4414cc878e3f9256fe51f9f854	American Express	33.996429675245281	-118.484746809396142
45698	2020-08-17 15:21:40	2020-08-17	Nena Cronin	nena.cronin@geemail.com	Memphis	Tennessee	180014222718767464	8e82fc7453930b7a83476bf44c148925	VISA 16 digit	35.0894563208866899	-89.9467841248285112
45699	2020-08-17 15:23:38	2020-08-17	Martell Kassulke-Runte	martell.kassulke.runte@geemail.com	Corona	California	4919637741960396	5408a21a0c86e7dd3fb936584e753db5	Mastercard	33.9099041416663667	-117.627834361392999
45700	2020-08-17 15:24:10	2020-08-17	Jazlyn Stracke-Auer	jazlyn.stracke.auer@geemail.com	Berkeley	California	180008934006645156	c89cdc2b25381db29bdd28b06628c17b	Diners Club / Carte Blanche	37.9122497363436182	-122.259587902789704
45701	2020-08-17 15:30:46	2020-08-17	Mr. Blane Fritsch I	mr.blane.fritsch.i@geemail.com	Charlotte	North Carolina	3096055751185506419	57f4a9264f853fc4c7b3b59cd0333b20	Voyager	35.2885221736293246	-80.8382890525218158
45702	2020-08-17 15:32:01	2020-08-17	Acie Flatley-Reichel	acie.flatley.reichel@warmmail.com	Nashville	Tennessee	3017748449128153	d9bdf6065eec15e753d6660d44381f31	VISA 16 digit	36.2159147170960907	-86.7727771188039299
45703	2020-08-17 15:41:33	2020-08-17	Dr. Colvin Dietrich PhD	dr.colvin.dietrich.phd@geemail.com	Phoenix	Arizona	676203715121939	7583bf2dc7151aac7cb89134cc0136f8	Voyager	33.593534349224349	-112.077936006842563
45704	2020-08-17 15:43:45	2020-08-17	Milly Stiedemann-Kiehn	milly.stiedemann.kiehn@geemail.com	Colorado Springs	Colorado	3768168671831927	2d2acf1bdc22fc9df24352e50f185f0a	JCB 15 digit	38.9454410335563139	-104.789186303100365
45705	2020-08-17 15:48:53	2020-08-17	Marjorie Windler	marjorie.windler@geemail.com	Tulsa	Oklahoma	869908740213479697	7af0fc29dfb47f63852c4e4c187cb00a	JCB 15 digit	36.0705209690049244	-95.9883963979735881
45706	2020-08-17 15:57:35	2020-08-17	Mr. Verlon Ledner	mr.verlon.ledner@geemail.com	Burbank	California	210037412198606281	11b261e47e1ed0dd5040f2dfdfa4be8a	Discover	34.2557230117660012	-118.309044412945966
45707	2020-08-17 16:02:32	2020-08-17	Baldwin Kemmer	baldwin.kemmer@geemail.com	Atlanta	Georgia	4039137571380943	ee0acab3d16282eda35030b406bfedc9	Maestro	33.79354658534713	-84.5137658949054895
45708	2020-08-17 16:08:40	2020-08-17	Yolanda Kihn	yolanda.kihn@geemail.com	St. Louis	Missouri	3051842494784766	72af392c28c158eb54b7b28f60ee1c22	American Express	38.6955086236976058	-90.2477374884303742
45709	2020-08-17 16:11:03	2020-08-17	Farrell Carter	farrell.carter@geemail.com	Fairfield	California	869957016919700763	e9fc5f471b15c0f6a3b6dbb3b91f62e0	Discover	38.2158648476593257	-122.042780669452995
45710	2020-08-17 16:12:02	2020-08-17	Cecile Tremblay	cecile.tremblay@geemail.com	Berkeley	California	4950293324573287	dacda87dc5f48fa514e85125a7870e0f	Voyager	37.8865694433234665	-122.248763519191883
45711	2020-08-17 16:14:54	2020-08-17	Trinidad Crona-Goldner	trinidad.crona.goldner@geemail.com	Chicago	Illinois	4795093648591620	5933d635aeb0c6ba355b0f0b52fa0411	JCB 16 digit	41.9080176518600425	-87.7018046275742336
45712	2020-08-17 16:25:08	2020-08-17	Sincere Gorczany	sincere.gorczany@geemail.com	Houston	Texas	3797874982813752	5d16e530f591d1981922fb8ded71dec6	JCB 15 digit	29.836428354967758	-95.3540497676018646
45713	2020-08-17 16:28:01	2020-08-17	Koen Turner-Aufderhar	koen.turner.aufderhar@geemail.com	San Francisco	California	3088211748587272989	45617ee0cabc3ba5f17c5a3f459bf894	Discover	37.7447334940159607	-122.422017361183109
45714	2020-08-17 16:28:58	2020-08-17	Fitzhugh Howell	fitzhugh.howell@warmmail.com	Kent	Washington	3096662776796262834	47ade3fa4295c0173447c05842e1ef84	Diners Club / Carte Blanche	47.4309027604404818	-122.142577233877773
45715	2020-08-17 16:33:02	2020-08-17	Dion Waelchi	dion.waelchi@woohoo.com	Jacksonville	Florida	4316399604440524	38a084394a27880fa0ae6e26ee3f8e71	Voyager	30.3554357274021953	-81.7560084241986402
45716	2020-08-17 16:34:36	2020-08-17	Alto Kiehn	alto.kiehn@geemail.com	Houston	Texas	3023571261618620	e30c087c1e9aab8e6c0c608dba2855a2	JCB 15 digit	29.8423929894886903	-95.4462784854244433
45717	2020-08-17 16:37:43	2020-08-17	Ms. Celina Powlowski DVM	ms.celina.powlowski.dvm@geemail.com	Kansas City	Missouri	4406748439581533	8f5e863a7147f9dabf424cabc5630b27	VISA 16 digit	39.0932300797034102	-94.5281181917283675
45718	2020-08-17 16:39:06	2020-08-17	Summer Schimmel	summer.schimmel@geemail.com	New Orleans	Louisiana	3025546553944866	554ab8ae9e05413bb22aec82506aff32	Diners Club / Carte Blanche	29.9965408399716011	-89.9669339616112467
45719	2020-08-17 16:40:38	2020-08-17	Melvyn Little	melvyn.little@geemail.com	Dayton	Ohio	3414143213387816	05c4dd646730435931a2d9ea8122792b	Maestro	39.8757567280694829	-84.2043429424710581
45720	2020-08-17 16:41:53	2020-08-17	Georganna Schaden	georganna.schaden@geemail.com	New York	New York	869902699792402171	39f0b989c8ff522686c8dd1bbfc7fdc6	VISA 16 digit	40.6877504002992083	-73.9034847798187258
45721	2020-08-17 16:52:36	2020-08-17	Dr. Hampton Franecki	dr.hampton.franecki@geemail.com	San Jose	California	4565037746810489	8ef995bbca91116e1e0ca77b24e83ffe	JCB 15 digit	37.2546530021175784	-121.895412292819103
45722	2020-08-17 16:54:35	2020-08-17	Harrell Dooley	harrell.dooley@geemail.com	Cleveland	Ohio	3528259825881357824	5d92156d1aabbeba5277756ad0a1f801	Discover	41.4249486668817681	-81.6191700923495063
45723	2020-08-17 16:54:54	2020-08-17	Boysie Schroeder	boysie.schroeder@geemail.com	Lubbock	Texas	4261119411229	8d80c0b83ecb17dd941ca9339c07e779	VISA 16 digit	33.5758986793499474	-101.854124885090442
45724	2020-08-17 17:04:51	2020-08-17	Talmadge Price	talmadge.price@warmmail.com	North Las Vegas	Nevada	3474416147188469	374ff0784a41990c8808926c8428dbe0	VISA 16 digit	36.2506269625544562	-115.059787806518003
45725	2020-08-17 17:08:13	2020-08-17	Mrs. Arizona Feest DDS	mrs.arizona.feest.dds@geemail.com	Inglewood	California	3010478458443080	b3dd571713adf07e6efc36b10c4bfbb3	JCB 15 digit	33.9884600413743385	-118.315071651947875
45726	2020-08-17 17:12:09	2020-08-17	Tawanda Hahn	tawanda.hahn@geemail.com	Pompano Beach	Florida	6011617586737537947	7d8fad6b70c4fa50f19f3a702be6f255	Mastercard	26.2515343898706135	-80.2264655155442625
45727	2020-08-17 17:21:08	2020-08-17	Torie Pouros	torie.pouros@warmmail.com	Houston	Texas	180066583607244379	901760650a4fb672b874d5f0124ef375	Discover	29.7898581989187754	-95.465907799314337
45728	2020-08-17 17:27:11	2020-08-17	Jaclyn Sauer DVM	jaclyn.sauer.dvm@woohoo.com	Arlington	Texas	3158956755123900311	309838b81bc38fca74b363305e9364fb	Mastercard	32.7920745811674692	-97.1193185851935397
45729	2020-08-17 17:30:23	2020-08-17	Cain Hessel	cain.hessel@geemail.com	San Francisco	California	060472425418000	05a428e47f4cba8cc0fb777ef48ee91c	Maestro	37.8164666235462761	-122.418468011768155
45730	2020-08-17 17:37:21	2020-08-17	Mame Bernhard	mame.bernhard@geemail.com	Memphis	Tennessee	3047760499720730	9fd899c163674dfd30bf3f5197a3b04c	VISA 13 digit	35.0618219839476097	-89.9719868403185217
45731	2020-08-17 17:38:49	2020-08-17	Emit Breitenberg	emit.breitenberg@warmmail.com	San Francisco	California	4536161730353615	8ef499f7a144f3cb740b55245a882e04	Maestro	37.7816772919648116	-122.465813385551442
45732	2020-08-17 17:43:42	2020-08-17	Mrs. Shani Steuber	mrs.shani.steuber@geemail.com	Scottsdale	Arizona	6011872137004030685	1e193a85bc7a4f9d156ab2dc4dfc714e	VISA 16 digit	33.7081321546465134	-111.779901923468699
45733	2020-08-17 17:46:45	2020-08-17	Delila Trantow MD	delila.trantow.md@geemail.com	San Diego	California	6011536679112068279	8f63c9cf17b452952fa295b1facfc07e	JCB 16 digit	32.825100905454903	-117.107525316989054
45734	2020-08-17 17:47:36	2020-08-17	Everett Kris	everett.kris@geemail.com	West Palm Beach	Florida	4006366734785	bb45ffb1e59d630938ff14e0fbfaae56	JCB 15 digit	26.833662962246315	-80.0309918823953694
45735	2020-08-17 17:48:59	2020-08-17	Van Conn-Prohaska	van.conn.prohaska@woohoo.com	Costa Mesa	California	3528309367766409073	cdab3d2a820de0c5f0fbd67e90dc4eca	VISA 16 digit	33.6702332533445201	-117.993636154462777
45736	2020-08-17 17:49:01	2020-08-17	Dr. Chynna Hackett DDS	dr.chynna.hackett.dds@woohoo.com	Surprise	Arizona	4180311277850783	fce25475e492ca53e4fd5cdb7315bba7	Maestro	33.661963071464001	-112.373639478371288
45737	2020-08-17 17:52:34	2020-08-17	Ether Huel PhD	ether.huel.phd@geemail.com	Fairfield	California	3042419111208898	5a9495edbbe858f784e7ca1cf86d9adb	JCB 15 digit	38.3434295187361585	-121.994840744370961
45738	2020-08-17 17:57:25	2020-08-17	Khalilah Stroman	khalilah.stroman@geemail.com	New York	New York	4987038042003977	3a1d7f5fd72fa03714a12d24ee92a492	Maestro	40.7520312062688177	-73.8996249120112481
45739	2020-08-17 18:02:54	2020-08-17	Mrs. Paisley Hansen DVM	mrs.paisley.hansen.dvm@geemail.com	Chicago	Illinois	869977401168303343	f01e92c9fa4cd5035a17cb3f9c0da21c	JCB 16 digit	41.8969025750946287	-87.6454650183703734
45740	2020-08-17 18:03:35	2020-08-17	Mr. Stanley Kunde	mr.stanley.kunde@geemail.com	Costa Mesa	California	6011926015212325764	1dc60a361f036acb3b1f607c33522d94	JCB 16 digit	33.6764227212421616	-117.875863191937285
45741	2020-08-17 18:07:46	2020-08-17	Austyn Green	austyn.green@geemail.com	Chicago	Illinois	869926389044222609	a281ec51aeeabe3b33d41dfa8279e485	Mastercard	41.9295724000617867	-87.7694128234434885
45742	2020-08-17 18:07:58	2020-08-17	Jailyn Abshire	jailyn.abshire@geemail.com	Richmond	California	3734962729101825	081a0ef72a7744c79d5c569546e80b3c	Mastercard	37.8660420782353739	-122.329211452030023
45743	2020-08-17 18:19:15	2020-08-17	Tahj Treutel-Kuhic	tahj.treutel.kuhic@warmmail.com	Springfield	Illinois	6011257503403922688	d9638bc36d0037e89a3b9d25f2c6bd4c	Mastercard	39.7234641907889383	-89.5826594814661803
45744	2020-08-17 18:20:02	2020-08-17	Minda Lebsack	minda.lebsack@warmmail.com	Lakeland	Florida	3756171771012442	9326774b084a3cce7a2ac3c706d729b9	JCB 16 digit	27.9760674104858182	-81.8632798641338866
45745	2020-08-17 18:32:58	2020-08-17	Deanne Eichmann	deanne.eichmann@geemail.com	Manchester	New Hampshire	3158062442547022268	e2179455fc29fd705cb406bd2915d501	American Express	42.9200746473461408	-71.4810836703408512
45746	2020-08-17 18:38:04	2020-08-17	Chante Powlowski	chante.powlowski@geemail.com	Overland Park	Kansas	3011534160499718	18f358fb1ab8757339d6047a6fbb70c5	Diners Club / Carte Blanche	38.7923714570570795	-94.7885674562346168
45747	2020-08-17 18:46:57	2020-08-17	Carrol Lesch	carrol.lesch@woohoo.com	New York	New York	180020039314254941	0fbca9838d246fba5fe465af2c1ba050	American Express	40.7145395580902658	-74.0197278500895948
45748	2020-08-17 18:49:01	2020-08-17	Oswald Keebler	oswald.keebler@warmmail.com	Chicago	Illinois	3466610601563874	892c6b11b34f6737f4b03139861c8dd7	Discover	41.7781088429339249	-87.6376059384114967
45749	2020-08-17 19:17:35	2020-08-17	Titus Balistreri	titus.balistreri@woohoo.com	Jersey City	New Jersey	676349781555120	591c01f0c61fed083799524a946a2e78	VISA 13 digit	40.695260923582687	-74.0908700017213846
45750	2020-08-17 19:26:47	2020-08-17	Morton Pfannerstill	morton.pfannerstill@warmmail.com	Chicago	Illinois	503883469745265	29080cff95729bc76f7ad110f4c59b18	JCB 15 digit	41.9309599035255616	-87.6312980151299286
45751	2020-08-17 19:28:53	2020-08-17	Myrl Adams	myrl.adams@geemail.com	Colorado Springs	Colorado	3459688463979940	9654fb96e1ae8dd951da736dbe20bd18	Discover	38.8355033658958959	-104.703868289633462
45752	2020-08-17 19:53:21	2020-08-17	Kimberli Conroy DDS	kimberli.conroy.dds@woohoo.com	Long Beach	California	6011044073613981799	1f66c9b90a4a2f1a6441567ac849490b	VISA 16 digit	33.8201628222882746	-118.197550876221797
45753	2020-08-17 19:53:56	2020-08-17	Emily Fritsch-Langworth	emily.fritsch.langworth@geemail.com	El Paso	Texas	4982996098074058	44894e4c0884d51c1c06a3e470ebba9c	JCB 16 digit	31.8516619439996802	-106.396720632722605
45754	2020-08-17 20:08:28	2020-08-17	Camren Prosacco	camren.prosacco@geemail.com	El Paso	Texas	3411723238484624	81aed806e596b44e016c74e3b9897d09	JCB 16 digit	31.9268909447189451	-106.472265591703362
45755	2020-08-17 20:08:44	2020-08-17	Tera Kihn	tera.kihn@geemail.com	Scottsdale	Arizona	3096269111354615610	c4173808f7bafe365c333114e61fe153	Discover	33.679614774755386	-111.76118663162589
45756	2020-08-17 20:11:51	2020-08-17	Mr. Webster Upton	mr.webster.upton@geemail.com	San Francisco	California	502002569933266	26a178a975afe27e652a7887f3887156	JCB 16 digit	37.8108765196554515	-122.429034388190061
45757	2020-08-17 20:32:52	2020-08-17	Dr. Antonetta Jakubowski PhD	dr.antonetta.jakubowski.phd@geemail.com	Shreveport	Louisiana	3337358974122984911	afa91e5e602a379801935978d71e893f	JCB 16 digit	32.3692687104694556	-93.7613585770808129
45758	2020-08-17 20:49:15	2020-08-17	Ada Stamm-Heidenreich	ada.stamm.heidenreich@warmmail.com	Indianapolis	Indiana	630402558591935	d6ca13717a3eff6262699001c169c10b	Voyager	39.7675002790529248	-86.0869730968229447
45759	2020-08-17 21:08:37	2020-08-17	Ms. Nikita Buckridge DVM	ms.nikita.buckridge.dvm@geemail.com	Seattle	Washington	4317878126451480	aa706ef6e6f0eb29c605ccc49885a545	VISA 16 digit	47.6849377391319749	-122.394351884016388
45760	2020-08-17 21:15:58	2020-08-17	Dr. Keenan Mann	dr.keenan.mann@geemail.com	New York	New York	3043685535280742	ead6c3124ba6859e52639da4a5cffc15	JCB 15 digit	40.6085051974505191	-74.0286986713193329
45761	2020-08-17 21:18:33	2020-08-17	Robbin Ziemann	robbin.ziemann@geemail.com	Chesapeake	Virginia	6011260909800932334	a135fb88419e58d1e26c1c960982bb7a	VISA 16 digit	36.6859346508286919	-76.3807891561027645
45762	2020-08-17 21:21:12	2020-08-17	Alecia Metz MD	alecia.metz.md@geemail.com	New York	New York	3786835240602074	9315ad1ef13031a58cbd2b3e0cb99048	JCB 16 digit	40.6569949507471193	-74.0055532038107486
45763	2020-08-17 21:22:08	2020-08-17	Coby Koelpin	coby.koelpin@geemail.com	Dallas	Texas	4161150143905196	7689f2364ad47e377fd3847427a32e99	Diners Club / Carte Blanche	32.72119567848668	-96.7860208353456102
45764	2020-08-17 21:26:21	2020-08-17	Mr. Jesus Eichmann I	mr.jesus.eichmann.i@geemail.com	San Bernardino	California	3088399900634302079	2427066c2149ae7b179c5ecdab92dadb	Maestro	34.1507722656041324	-117.393242977258183
45765	2020-08-17 21:28:43	2020-08-17	Miss Mai Nitzsche	miss.mai.nitzsche@warmmail.com	Providence	Rhode Island	4242160863848529	91e7d4a55e119833ce259e068d9f19db	VISA 16 digit	41.7582283888332526	-71.3991814051207143
45766	2020-08-17 21:35:08	2020-08-17	Gwyneth Denesik DDS	gwyneth.denesik.dds@warmmail.com	Memphis	Tennessee	55568915689682329	2c710c2235379e7cccf76a8778ffe37b	JCB 15 digit	35.0244705411672612	-90.0010060539726169
45767	2020-08-17 21:41:45	2020-08-17	Cherise Schiller	cherise.schiller@warmmail.com	Palmdale	California	869954977891014619	1af0697f077122ac444f0eedbf1ef588	Voyager	34.5088103619720812	-118.027256000414127
45768	2020-08-17 21:42:22	2020-08-17	Dr. Ronan Murazik III	dr.ronan.murazik.iii@warmmail.com	Stockton	California	53775891095888371	fee8ac4a7884d44ca4cf74ce3df7bfc1	Discover	37.9823520039871383	-121.280176282449816
45769	2020-08-17 21:42:35	2020-08-17	Dr. Oda Bailey	dr.oda.bailey@woohoo.com	Omaha	Nebraska	3158383182402218070	a0257a6a84e5d50c1d1f133658b2aac3	VISA 13 digit	41.2313031586963703	-96.0552337971165855
45770	2020-08-17 21:45:20	2020-08-17	Demetria Cronin DVM	demetria.cronin.dvm@woohoo.com	San Francisco	California	6011143622904966768	5149fcea0be231fe85e88b0c700f743c	JCB 16 digit	37.7931167398136836	-122.446444817217582
45771	2020-08-17 21:47:01	2020-08-17	Mr. Emmitt Turner Sr.	mr.emmitt.turner.sr.@geemail.com	Killeen	Texas	6011059492790483118	294be769e2af7f34509300e1f8a20c64	American Express	31.0558750726979227	-97.7332043096125176
45772	2020-08-17 21:50:55	2020-08-17	Maida Koss	maida.koss@geemail.com	Durham	North Carolina	210006413546437905	01a1133bb6d8127ed9bae5fd7d90e84f	Mastercard	35.9072507652699926	-78.9073441953767087
45773	2020-08-17 21:52:50	2020-08-17	Donal Weber	donal.weber@geemail.com	El Paso	Texas	3476739413474158	56c3a9150cb4bd94d74fcba7362dc991	VISA 16 digit	31.833706105669588	-106.346895018730322
45774	2020-08-17 21:53:12	2020-08-17	Adalberto Erdman	adalberto.erdman@geemail.com	Olathe	Kansas	3088168206351815676	015a8e7930129f5cd5b1b68afaccd0c3	JCB 15 digit	38.9467021045398027	-94.904416461678224
45775	2020-08-17 22:00:25	2020-08-17	Hillery Trantow	hillery.trantow@warmmail.com	Fort Wayne	Indiana	3048346494654527	9be008c6a3cf119019a796f37b96a91b	VISA 16 digit	41.1082250010006121	-85.090824914978441
45776	2020-08-17 22:00:27	2020-08-17	Ms. Maggie Keebler	ms.maggie.keebler@geemail.com	New York	New York	3794092519776029	c0f66db095de1dfcc7872cbb69b3d6d4	Mastercard	40.6537623656205795	-73.8742272352229747
45777	2020-08-17 22:01:00	2020-08-17	Haywood Ruecker	haywood.ruecker@geemail.com	Nashville	Tennessee	3337974369508575330	75f44ce476b318f974e5986be34d1b9c	Mastercard	36.1677497435484057	-86.7401591099239795
45778	2020-08-17 22:04:29	2020-08-17	Mrs. Mara Quigley	mrs.mara.quigley@woohoo.com	Anaheim	California	4698535720744988	7212b84ff9eb03e78e65eb39fec4051e	JCB 16 digit	33.8817866103555971	-117.771550234288341
45779	2020-08-17 22:04:46	2020-08-17	Dr. Hubert Feest	dr.hubert.feest@geemail.com	Indianapolis	Indiana	4454621594829206	950fe6f063a5201afa7e085482d2b3ae	JCB 16 digit	39.7144279004547727	-86.2007025829251887
45780	2020-08-17 22:10:45	2020-08-17	Latosha Hagenes	latosha.hagenes@geemail.com	Nashville	Tennessee	55759408751080753	18b9b9a4734b6fe5818534e7403dcabd	VISA 13 digit	36.2061641880899643	-86.84228310244157
45781	2020-08-17 22:14:57	2020-08-17	Bess Predovic	bess.predovic@warmmail.com	Albuquerque	New Mexico	3337348929357219659	383e45c010e9b674cee94c4aa40f6579	Diners Club / Carte Blanche	35.1770139973279115	-106.712339366839828
45782	2020-08-17 22:28:00	2020-08-17	Britt Homenick	britt.homenick@woohoo.com	Albuquerque	New Mexico	869993447632992203	780ac1e15bb49a587f7845f2a4910549	Discover	35.0209236319310975	-106.620523063286768
45783	2020-08-17 22:29:40	2020-08-17	Dr. Paola Bednar	dr.paola.bednar@woohoo.com	Irvine	California	3039367319004952	03f8f6063916d886170c2ef45b7b6fe1	Voyager	33.6514245737358948	-117.832097648830342
45784	2020-08-17 22:30:04	2020-08-17	Tawanna Gusikowski	tawanna.gusikowski@geemail.com	Philadelphia	Pennsylvania	3457004674055342	bb633ced02174ec377a8d978767b8357	JCB 16 digit	40.0184980785898858	-75.0492163932781722
45785	2020-08-17 22:31:43	2020-08-17	Daryn Roob-Hettinger	daryn.roob.hettinger@woohoo.com	San Francisco	California	3337579973534598098	3dac7fa34a9a16b3e81642b3986bfcc2	American Express	37.7775184862894307	-122.436628935404144
45786	2020-08-17 22:37:45	2020-08-17	Jordyn McClure MD	jordyn.mcclure.md@geemail.com	Wilmington	North Carolina	502059486712629	41de5203911d234718d7d2ecb0c1038b	VISA 16 digit	34.2586222559034823	-77.9362473318811482
45787	2020-08-17 22:48:40	2020-08-17	Alverta Lebsack	alverta.lebsack@geemail.com	Long Beach	California	51267776905124114	b7b6f8da9c85977175626c3fc17239b0	Discover	33.8460016693275421	-118.065770149293542
45788	2020-08-17 22:52:48	2020-08-17	Elden Hettinger-Abernathy	elden.hettinger.abernathy@woohoo.com	Seattle	Washington	4449693444183	385672dc7dbbdca86da0531f8c914ed9	Voyager	47.6612390370499313	-122.388519494134556
45789	2020-08-17 22:53:17	2020-08-17	Eddie Dickinson DDS	eddie.dickinson.dds@warmmail.com	San Francisco	California	180052805136307765	d64f2f5f117f9a4c3a971a8fefc4f1af	Discover	37.7465214003849709	-122.393143045154574
45790	2020-08-17 23:05:12	2020-08-17	Otho Gottlieb	otho.gottlieb@geemail.com	Stockton	California	3428424830787115	16ec7e7f7e874cc42196a08792082656	Mastercard	37.8875814546562779	-121.263681296873088
45791	2020-08-17 23:08:28	2020-08-17	Stacy Howe	stacy.howe@geemail.com	Tucson	Arizona	3037200619869869	9e2db40b74fc1819d55efff8e3023594	Diners Club / Carte Blanche	32.1968385823112015	-110.885690977726497
45792	2020-08-17 23:16:16	2020-08-17	Sylas Grant	sylas.grant@woohoo.com	San Francisco	California	4297532698600925	c5e6b6ad7c7ea148665f7cb56f26554e	Maestro	37.793332543926013	-122.446469001427147
45793	2020-08-17 23:16:34	2020-08-17	Barney Kassulke	barney.kassulke@warmmail.com	Indianapolis	Indiana	210026756388519503	fc87690ae36b95d92d39fbfb7779b20f	JCB 15 digit	39.6953785134021189	-86.1589056159570816
45794	2020-08-17 23:19:13	2020-08-17	Angela Schuster	angela.schuster@geemail.com	San Francisco	California	6011387212049672219	98cfd0047893a35ccff8a9cbe881d0ce	Diners Club / Carte Blanche	37.7580765768657329	-122.429180515207378
45795	2020-08-17 23:20:29	2020-08-17	Tierra O'Connell	tierra.o'connell@geemail.com	Philadelphia	Pennsylvania	3337607617275092243	0d0ce9f39a8b11ddf7feef4f3023f07b	JCB 15 digit	40.0191964925691508	-75.1921477890938519
45796	2020-08-17 23:24:38	2020-08-17	Zane Murazik	zane.murazik@geemail.com	Austin	Texas	4790599792075041	493a7861283be54e37b67c6ef476434b	Discover	30.2999736054461444	-97.8079673890728571
45797	2020-08-17 23:36:17	2020-08-17	Jaida Bernhard DDS	jaida.bernhard.dds@geemail.com	New York	New York	55979282675982277	f2651798690eb28cd330b28e44a6fe66	Maestro	40.6333825073428443	-73.8751018324296922
45798	2020-08-17 23:41:45	2020-08-17	Rylee Ward	rylee.ward@geemail.com	Houston	Texas	3000159033286406	7a8162598df05425088f59ef694b1df3	JCB 16 digit	29.8604075845874846	-95.3147617612049061
45799	2020-08-18 00:10:14	2020-08-18	Irvine Kohler	irvine.kohler@warmmail.com	Fremont	California	180042883735352782	c7fd1a1d03ca2776130e8598e3eac44f	VISA 16 digit	37.5057180012743956	-121.924065046849464
45800	2020-08-18 00:27:35	2020-08-18	Ronal Hyatt II	ronal.hyatt.ii@woohoo.com	Raleigh	North Carolina	4130784462421241	0483d746ca8f28a61d13a4beb7c26f71	Mastercard	35.8192822794564023	-78.6741260282166337
45801	2020-08-18 00:32:55	2020-08-18	Nana Hilll	nana.hilll@warmmail.com	Columbus	Ohio	3096682089630057592	14f4d8d8896ba8fbbb15be2080f5560d	JCB 16 digit	39.9710899931423356	-82.9043689955726393
45802	2020-08-18 00:38:16	2020-08-18	Spenser Kunze	spenser.kunze@geemail.com	Austin	Texas	676274950067640	25141d61b3cf576bbf3d3d869709c1ca	Voyager	30.2365768545433866	-97.6570762376073844
45803	2020-08-18 00:41:19	2020-08-18	Dr. Crawford Crooks	dr.crawford.crooks@woohoo.com	Amarillo	Texas	630424799849781	879026aea7331ac3692b0edc525e0c5b	JCB 16 digit	35.1603389357380536	-101.834648295664053
45804	2020-08-18 00:45:53	2020-08-18	Nehemiah Pouros	nehemiah.pouros@geemail.com	Austin	Texas	3033344158799659	076a2b02a4631b972e224aed3271517e	VISA 16 digit	30.3426280619237545	-97.7879074803792037
45805	2020-08-18 00:55:46	2020-08-18	Mr. Blaine Schaden	mr.blaine.schaden@geemail.com	Boulder	Colorado	4034686595363	ae84308d91a63043cc17ad73988dd10f	Maestro	40.0764336819741871	-105.160225090259317
45806	2020-08-18 00:56:00	2020-08-18	Khloe Klein	khloe.klein@geemail.com	Indianapolis	Indiana	639019253568158	0e0b26b253552acf5586514451573e6f	Diners Club / Carte Blanche	39.7136652017019642	-86.0575131553892021
45807	2020-08-18 00:57:33	2020-08-18	Gina Anderson	gina.anderson@geemail.com	Fontana	California	4087951147420814	4895edb8c7af43009e60f614d4640c2b	VISA 13 digit	34.1875855108406412	-117.502751952483877
45808	2020-08-18 00:57:51	2020-08-18	Celestino Rogahn III	celestino.rogahn.iii@geemail.com	San Francisco	California	060406534237653	306150bc797f331fd8c9e82a895b7afa	VISA 13 digit	37.760553358828119	-122.433443929891283
45809	2020-08-18 00:58:25	2020-08-18	Ivie Kautzer	ivie.kautzer@geemail.com	Yonkers	New York	6011019479681217118	cac89d3bed9de287bcd987c4f512390e	JCB 15 digit	40.8607406391032058	-73.8748905911460554
45810	2020-08-18 00:59:16	2020-08-18	Eber Feil	eber.feil@geemail.com	Madison	Wisconsin	3054345070601583	36d7c11b27d5aef7c1c32788c16b600c	Maestro	43.0078103580486015	-89.3902701874613825
45811	2020-08-18 01:04:40	2020-08-18	Contina Treutel	contina.treutel@geemail.com	Fresno	California	869968015638446069	705b51feadb6e9c26f0c4c5f67a9bd11	American Express	36.8655709735456867	-119.856280572630098
45812	2020-08-18 01:05:39	2020-08-18	Lavenia Durgan	lavenia.durgan@geemail.com	Santa Clarita	California	6011638816635900540	0f658d067ee215f2b3b8141344880963	Maestro	34.3885302355252165	-118.604175497415284
45813	2020-08-18 01:17:54	2020-08-18	Dr. Lesa Gutkowski	dr.lesa.gutkowski@warmmail.com	Norwalk	California	6011988208493180504	78e96fa80588f37dfcf7c939e7bc2e40	JCB 16 digit	33.8289141406886316	-118.036879507176579
45814	2020-08-18 01:18:16	2020-08-18	Dr. Ardelle Nienow	dr.ardelle.nienow@warmmail.com	Atlanta	Georgia	4232100778983	ea1029d6d4e946cb69b991e2379616d0	Diners Club / Carte Blanche	33.7935962171103839	-84.4218609644144777
45815	2020-08-18 01:20:23	2020-08-18	Eliana Herman	eliana.herman@geemail.com	San Bernardino	California	4633138175599	6f1ce5da4b566a62fc4bcbfe4468bf3d	VISA 16 digit	34.2310559863023443	-117.248779703189058
45816	2020-08-18 01:20:49	2020-08-18	Hollis Will-Nitzsche	hollis.will.nitzsche@geemail.com	Huntington Beach	California	3410215603309313	913c6ee6ccbbba34ad1f065055031672	VISA 13 digit	33.6231536841061001	-117.998999610788374
45817	2020-08-18 01:24:34	2020-08-18	Rhett Hettinger	rhett.hettinger@geemail.com	San Francisco	California	3528806933659951022	f3ea70c636cb9f3a09101c556d39149e	JCB 16 digit	37.7476576124722669	-122.422278023206829
45818	2020-08-18 01:24:37	2020-08-18	Opal Haag DVM	opal.haag.dvm@geemail.com	Hampton	Virginia	060423562770208	a12efb0d90d7bbaf6e5d5454812a5589	VISA 16 digit	37.0865004684329023	-76.220397755699608
45819	2020-08-18 01:34:08	2020-08-18	Fritz Kutch	fritz.kutch@woohoo.com	New York	New York	869911757077736504	3d9b89aae7611fc6e9695fe3921f9984	Mastercard	40.7103535781837991	-73.9621456648584399
45820	2020-08-18 01:42:30	2020-08-18	Meredith Lemke	meredith.lemke@geemail.com	Kansas City	Missouri	3528978944113461880	fe2375bbb8dc2d339398320acd893cff	Discover	39.1725254250526476	-94.4511475050114058
45821	2020-08-18 01:48:42	2020-08-18	Ms. Mahalie Goodwin	ms.mahalie.goodwin@geemail.com	Dallas	Texas	3706853595438835	6b87594d60be1a1b76845bda46e7d11d	Diners Club / Carte Blanche	32.7471903702050469	-96.7651937925685104
45822	2020-08-18 01:52:04	2020-08-18	Rennie Wolff	rennie.wolff@geemail.com	Phoenix	Arizona	869985970375494962	14ebedfc302c271a10260e2b37a46d87	Voyager	33.619471272633227	-112.153162464445842
45823	2020-08-18 02:04:57	2020-08-18	Rihanna Mueller	rihanna.mueller@geemail.com	Louisville	Kentucky	869934869418952808	eafaf8f0b304767ea5600241faf0f630	Maestro	38.1722121227901425	-85.7091039003409492
45824	2020-08-18 02:15:09	2020-08-18	Edson Waelchi	edson.waelchi@geemail.com	Houston	Texas	501851439740286	1cbea5ad62f541e639d98d8022908267	Mastercard	29.774381432550399	-95.4355783435531038
45825	2020-08-18 02:18:25	2020-08-18	Benjamin Reichel	benjamin.reichel@geemail.com	San Francisco	California	502024076906460	5c63458d6216354a854ab7b6ad4136f1	Maestro	37.7716845098884022	-122.439984566262467
45826	2020-08-18 02:18:47	2020-08-18	Dr. Danielle Fay DVM	dr.danielle.fay.dvm@geemail.com	San Diego	California	3337249217784278088	ed1cd7a038df643a6ccde3e4040ce533	VISA 16 digit	32.7233354737583539	-117.1727910619136
45827	2020-08-18 02:27:42	2020-08-18	Dr. Shaun Funk	dr.shaun.funk@warmmail.com	San Francisco	California	589383873959924	9b10ac5e5acc8c659a8ab1da7a814d1e	Maestro	37.8089277074610308	-122.453589810453337
45828	2020-08-18 02:29:07	2020-08-18	Graves Collins	graves.collins@geemail.com	Anchorage	Alaska	4840735001124	e9b5c3ec3aacbd810a462e88b1773231	Voyager	61.1269085245423014	-149.197298932320621
45829	2020-08-18 02:30:17	2020-08-18	Hanson Kessler	hanson.kessler@geemail.com	Phoenix	Arizona	3528130395062925752	9ee0f83d6dcc1d900f87d1afa6f5b138	Mastercard	33.4917252327714152	-112.029056725923354
45830	2020-08-18 02:33:38	2020-08-18	Montie Waters	montie.waters@geemail.com	New York	New York	676343502778111	e40fcc99c38ffb6acabb44de163b1870	Voyager	40.5952994960583737	-73.8634022911906243
45831	2020-08-18 02:34:26	2020-08-18	Norbert Hintz	norbert.hintz@warmmail.com	San Francisco	California	676199719142053	7778ed8d14cb76fd412944b3de5a220b	Maestro	37.779126705979813	-122.42805930854081
45832	2020-08-18 02:39:06	2020-08-18	Brad Jacobson	brad.jacobson@geemail.com	Concord	California	869986099025239475	4b6b3513876d3e05f2b6b2a41e90025c	VISA 16 digit	37.9840496368173532	-122.00446894743331
45833	2020-08-18 02:39:28	2020-08-18	Everet Marquardt	everet.marquardt@geemail.com	Elizabeth	New Jersey	4220487740730984	315205642e254bdd3924393fee648388	JCB 16 digit	40.5701551082670733	-74.1201180524136873
45834	2020-08-18 02:40:02	2020-08-18	Corey Gerhold-VonRueden	corey.gerhold.vonrueden@geemail.com	San Antonio	Texas	3337067742769972073	f3ebc2297ed7c720c91a1602a36dde5c	JCB 15 digit	29.3892257222510871	-98.4286504126921216
45835	2020-08-18 02:40:34	2020-08-18	Drake Lueilwitz	drake.lueilwitz@woohoo.com	Overland Park	Kansas	180085915516988331	6bd0e2360ac2cdc476ae36d0e18854cb	VISA 16 digit	38.8684094959273949	-94.6674128880765267
45836	2020-08-18 02:50:17	2020-08-18	Miss Ayanna Nienow	miss.ayanna.nienow@geemail.com	New York	New York	6011808511941330599	1da3b6f4ae94db573f81c5e8cbf74c91	American Express	40.6302087674140893	-73.9716116662964254
45837	2020-08-18 02:53:06	2020-08-18	Mrs. Lorena Schaefer	mrs.lorena.schaefer@geemail.com	New York	New York	589344132327618	cb97f350a309c72f94c647dc069de1d6	VISA 13 digit	40.602884191809224	-73.9049495532073024
45838	2020-08-18 02:53:10	2020-08-18	Concha Schulist-Russel	concha.schulist.russel@geemail.com	Irvine	California	180048844372668041	c44cf7b92c91662709395eda5d59da5f	Voyager	33.672567801458392	-117.81980867376663
45839	2020-08-18 02:55:37	2020-08-18	Dr. Marcello Jones DVM	dr.marcello.jones.dvm@geemail.com	Spokane	Washington	3528926760534378500	037cd3a49089e598d18aa8c1aee5c73e	JCB 16 digit	47.6465350526623439	-117.506587015687671
45840	2020-08-18 03:09:05	2020-08-18	Dylan Hintz-Ondricka	dylan.hintz.ondricka@warmmail.com	Glendale	California	6011851853216587156	bf5aa505110d1bdd121d07ad33642290	Discover	34.2317218101803178	-118.339232858353483
45841	2020-08-18 03:25:06	2020-08-18	Mr. Xzavier Grant	mr.xzavier.grant@geemail.com	Bellevue	Washington	3337056322362598808	d740925543fc9d6adbf2a27190bb6356	American Express	47.663924981671947	-122.128984330926087
45842	2020-08-18 03:31:07	2020-08-18	Mace Wehner	mace.wehner@geemail.com	Tulsa	Oklahoma	6011995652582269986	b235f382e5b93748b04c52c8d2704830	JCB 16 digit	36.1932380743227853	-95.9161819406740364
45843	2020-08-18 03:38:28	2020-08-18	Clide Keebler	clide.keebler@woohoo.com	Philadelphia	Pennsylvania	6011981478439660755	a0ab485a78b628e186bd827a046191b2	JCB 15 digit	40.1060593572869877	-75.0669817584000612
45844	2020-08-18 03:38:34	2020-08-18	Herma Hoppe	herma.hoppe@geemail.com	Savannah	Georgia	6011246757962332317	f632cb080596ccb774fc204f13d60366	JCB 16 digit	32.0317506409808956	-81.1266831372085875
45845	2020-08-18 03:52:35	2020-08-18	Una McClure-Price	una.mcclure.price@warmmail.com	Downey	California	53049423626490111	07cbc0ef94bae479ac58ef8c3eaa0a00	VISA 16 digit	34.0331463413562645	-118.063510843610018
45846	2020-08-18 03:57:00	2020-08-18	Faye Heidenreich	faye.heidenreich@geemail.com	Chula Vista	California	4079243004575512	795361f4e45289bb6822d97996520dd4	JCB 15 digit	32.6436035794902537	-117.112858644383763
45847	2020-08-18 03:59:15	2020-08-18	Chaim Ritchie	chaim.ritchie@geemail.com	Oakland	California	54144831223463527	909cd411fa8dbb13fdfa90f226268635	JCB 15 digit	37.7793040919819774	-122.261533502627202
45848	2020-08-18 03:59:40	2020-08-18	Malinda Beahan DDS	malinda.beahan.dds@geemail.com	Garland	Texas	4619510280057	eee00e1e0957a59e4c797ab9d718b96d	JCB 16 digit	32.9393709255151421	-96.6402118624348248
45849	2020-08-18 04:08:24	2020-08-18	Miss Lesa Pacocha	miss.lesa.pacocha@warmmail.com	Huntington Beach	California	639018213725106	d96cdef7dbb098db423bb255ae9d005a	American Express	33.6698441504076129	-118.071561474877598
45850	2020-08-18 04:35:49	2020-08-18	Lela Ziemann-Koepp	lela.ziemann.koepp@geemail.com	Madison	Wisconsin	3088727728767601972	b8e4ef56e0ea439c567c2fb8af2d24f1	VISA 16 digit	43.1388586789809167	-89.3377456590417864
45851	2020-08-18 04:39:25	2020-08-18	Ama Jerde	ama.jerde@geemail.com	Louisville	Kentucky	3088411603086376633	6ac1e1030ac586a60b0e9e3504b6d5d0	VISA 13 digit	38.2564538069438171	-85.6138646890014456
45852	2020-08-18 04:39:42	2020-08-18	Jefferey Upton	jefferey.upton@geemail.com	Akron	Ohio	55331679092915140	d13bed519eafc8ad1ccb4fa6b3a77519	VISA 16 digit	41.1663331304509228	-81.5107722034525182
45853	2020-08-18 04:44:02	2020-08-18	Jaquan Collier	jaquan.collier@geemail.com	Berkeley	California	3412821131727021	77fcff1e9a45768c0fd45ce7898a58bd	Discover	37.8543601006145067	-122.280986965998721
45854	2020-08-18 05:09:53	2020-08-18	Dr. Jayde Bode	dr.jayde.bode@geemail.com	Portland	Oregon	4448080480263690	3f01f20a041580fce6972c4baa2b98e0	Diners Club / Carte Blanche	45.6072925232239044	-122.713275988167155
45855	2020-08-18 05:21:50	2020-08-18	Ephram Konopelski	ephram.konopelski@geemail.com	Jacksonville	Florida	4051785853556383	700363a1e9802f6a8aa5e4276f7339e5	JCB 16 digit	30.4231734973430648	-81.7533417843826129
45856	2020-08-18 05:24:57	2020-08-18	Chin Ruecker	chin.ruecker@warmmail.com	Glendale	Arizona	3789446204808371	824ae4b4ba16286583f9af2ed06d2dc6	JCB 16 digit	33.5524519060965574	-112.140085294868413
45857	2020-08-18 05:39:00	2020-08-18	Sheila Kutch-Walsh	sheila.kutch.walsh@geemail.com	Newport News	Virginia	4869913996219	1911335b6c143b92b562cd58de0903bb	American Express	37.0564819963078946	-76.5560072755236263
45858	2020-08-18 05:40:55	2020-08-18	Cloe Rutherford	cloe.rutherford@geemail.com	San Jose	California	3715833348886091	98eb4f089230ef96ae6a33a2c7ede1eb	Maestro	37.3739890473715946	-121.768917317431047
45859	2020-08-18 05:41:11	2020-08-18	Mrs. Daisey Dach	mrs.daisey.dach@geemail.com	Chicago	Illinois	4026504675179	1a8352769b656002a91fcf382e54a8c5	JCB 16 digit	41.819849541766942	-87.6648411451403007
45860	2020-08-18 05:41:49	2020-08-18	Casey Volkman PhD	casey.volkman.phd@warmmail.com	Boston	Massachusetts	6011130613583200129	54d2e1bc7ba243eb94615ecb3e21556c	VISA 16 digit	42.4172885418571539	-71.0182598043184754
45861	2020-08-18 05:44:49	2020-08-18	Michaele Frami	michaele.frami@geemail.com	Rochester	New York	180047256934108682	acb5cc5493fd34b0689467016efd3359	VISA 13 digit	43.1551796894498167	-77.6575657104380497
45862	2020-08-18 05:45:35	2020-08-18	Arland Mosciski-Rice	arland.mosciski.rice@geemail.com	Cambridge	Massachusetts	3048106191598561	97c83fa0724d89cc64ade070fb58f450	Discover	42.3454683785550259	-71.0250293579034491
45863	2020-08-18 05:45:41	2020-08-18	Bonny Dickinson DVM	bonny.dickinson.dvm@warmmail.com	Montgomery	Alabama	676208745848161	48ba95d4d5ea97c7fcee63aeec28ff52	Voyager	32.2877387462582419	-86.3484449192568633
45864	2020-08-18 05:47:54	2020-08-18	Hillery Jacobs	hillery.jacobs@geemail.com	Berkeley	California	4270562174806580	70cd3656ca54af719d637143a2d89031	JCB 16 digit	37.8954513921940261	-122.287349993030887
45865	2020-08-18 05:59:33	2020-08-18	Gardner Wehner	gardner.wehner@geemail.com	Detroit	Michigan	3014341111554626	5efa981071f2852fa93b543a9d15b3b4	American Express	42.3023229320924727	-83.1533890712659769
45866	2020-08-18 05:59:53	2020-08-18	Arlis Crona V	arlis.crona.v@geemail.com	Glendale	Arizona	6011266909303196399	cbcc733acaaa08c871ee8a31c4600f1a	Mastercard	33.4763540320325603	-112.161083741139237
45867	2020-08-18 06:04:25	2020-08-18	Orilla Welch	orilla.welch@warmmail.com	Chattanooga	Tennessee	210001257866020980	93b13995b8a373ea90c5dcdd51265f37	Mastercard	34.9842719190605038	-85.2066246233709137
45868	2020-08-18 06:06:04	2020-08-18	Rufus Ledner-Thiel	rufus.ledner.thiel@warmmail.com	Oakland	California	4175769590557343	d55199cf063b96fcefa71020585e1475	JCB 16 digit	37.8062288150392405	-122.295483944666486
45869	2020-08-18 06:08:04	2020-08-18	Jaylin Dickens	jaylin.dickens@geemail.com	Los Angeles	California	639000836436790	358949f4af395f9a72d426888b9a57c1	Discover	34.117459866158292	-118.449979434161634
45870	2020-08-18 06:23:16	2020-08-18	Merna Hermiston	merna.hermiston@geemail.com	Allen	Texas	3337688084589043663	e7ad0a75b30708f0857bc512cd1a006d	Mastercard	33.0475787497617262	-96.5871374803543148
45871	2020-08-18 06:25:51	2020-08-18	Dana Hauck V	dana.hauck.v@warmmail.com	Winston–Salem	North Carolina	4173444320050	2bc13037f247153b8f2294d4300984d6	American Express	36.1266039537962484	-80.2738725208342032
45872	2020-08-18 06:45:18	2020-08-18	Thos Berge	thos.berge@woohoo.com	New York	New York	4820362809280185	b9b8cbe70f35ff99981b1fa27b124175	Voyager	40.6963244992531799	-74.0386896659050109
45873	2020-08-18 06:54:15	2020-08-18	Yasmine Ortiz	yasmine.ortiz@woohoo.com	Austin	Texas	3026756564008630	963b9d04aa8a9fc2c1502e54d196652c	Maestro	30.3592630106151091	-97.7940068760659642
45874	2020-08-18 06:56:13	2020-08-18	Kaley Smith	kaley.smith@woohoo.com	San Diego	California	4624253391152	a1e776b263b67d884dde198132fff8d2	JCB 15 digit	32.8966149545341722	-117.127113706516113
45875	2020-08-18 06:57:45	2020-08-18	Mr. Ritchie Tromp DDS	mr.ritchie.tromp.dds@geemail.com	Greensboro	North Carolina	3088815821836057954	51b93f896f94a28a360b2e125a02154a	Diners Club / Carte Blanche	36.0385630325995407	-79.7593724906891595
45876	2020-08-18 07:08:08	2020-08-18	Dominique Reichel	dominique.reichel@geemail.com	Berkeley	California	210037794592045905	6c935a68f3365658afb74c9cd808ac96	JCB 16 digit	37.8812355870416368	-122.253143311546964
45877	2020-08-18 07:09:44	2020-08-18	Jaylyn Spencer	jaylyn.spencer@geemail.com	Virginia Beach	Virginia	3038961108732897	76a323f25cc2b92ba7ae2114e30e3c21	Voyager	36.6858762777131062	-76.0925227645456772
45878	2020-08-18 07:14:02	2020-08-18	Dr. Kylene DuBuque DVM	dr.kylene.dubuque.dvm@geemail.com	Jacksonville	Florida	502066955768875	1a896848413b7017a892103163131b82	VISA 16 digit	30.3483026687573627	-81.7358049332242587
45879	2020-08-18 07:30:12	2020-08-18	Treva Cronin	treva.cronin@geemail.com	Lincoln	Nebraska	3112622321215132604	40c8c78fc65efd07340ea6abce1ba7f1	VISA 16 digit	40.8824520154874733	-96.7153200916640543
45880	2020-08-18 07:39:49	2020-08-18	Concepcion O'Keefe	concepcion.o'keefe@geemail.com	Plano	Texas	869907166600042123	ad7e4770af3929611ade4d45921fd5bb	VISA 16 digit	32.9886087158314893	-96.7521180884629501
45881	2020-08-18 07:52:53	2020-08-18	Devante Schamberger	devante.schamberger@warmmail.com	Arlington	Texas	6011597540594625257	2417cd661325b648a17c8b1f1fd3a863	VISA 16 digit	32.7353534741111076	-97.0756669679217055
45882	2020-08-18 07:56:39	2020-08-18	Guido Stiedemann	guido.stiedemann@geemail.com	San Francisco	California	502028490344091	e314a5f2331a88ee288cbf68dc6b54ab	Maestro	37.763564304830112	-122.44006503061523
45883	2020-08-18 08:01:23	2020-08-18	Dr. Cleo Eichmann DVM	dr.cleo.eichmann.dvm@warmmail.com	Rialto	California	3112916603711553671	95da0a4dd1723123b35f3f25d041fcab	VISA 13 digit	34.0663274256728599	-117.371085216253249
45884	2020-08-18 08:04:36	2020-08-18	Caroline Wolf-Nader	caroline.wolf.nader@warmmail.com	Columbus	Ohio	3088514414875051825	e98f3699a3e8726bf10db2b63e8e47bc	Maestro	40.0041568662550304	-83.0030860872242613
45885	2020-08-18 08:17:25	2020-08-18	Mr. Jessie Dickinson I	mr.jessie.dickinson.i@geemail.com	Nashville	Tennessee	675918336567849	b3b3028a251a1b81d9ad56c843762538	Diners Club / Carte Blanche	36.1721770133480405	-86.7675854883063522
45886	2020-08-18 08:20:19	2020-08-18	Shanon Ortiz	shanon.ortiz@geemail.com	Newport News	Virginia	4616602689500	d1fd492d666ec3f6852b76bf48206f3a	VISA 16 digit	37.0878265919990824	-76.477354522308346
45887	2020-08-18 08:21:55	2020-08-18	Dr. Vicky Zemlak MD	dr.vicky.zemlak.md@warmmail.com	San Francisco	California	4749133361182970	2b2400ac5c86cbcd830806cd61c9e288	VISA 16 digit	37.8042866793457009	-122.425861342479052
45888	2020-08-18 08:22:31	2020-08-18	May Borer	may.borer@geemail.com	Las Vegas	Nevada	3158700157548529750	b617d1ee1b042628777556a36a9de4d0	VISA 16 digit	36.1321792013578076	-115.272009069074315
45889	2020-08-18 08:26:01	2020-08-18	Bobby Armstrong	bobby.armstrong@geemail.com	Austin	Texas	3528064564875706424	0c72d30d401be7d7e518c3f51ce9e18a	VISA 13 digit	30.3232688636180008	-97.7393641768727548
45890	2020-08-18 08:28:28	2020-08-18	Demetric Skiles	demetric.skiles@geemail.com	Seattle	Washington	639023459463339	68f26ce326774874365d68f10a82bf61	JCB 16 digit	47.6768539969734846	-122.450869386961301
45891	2020-08-18 08:31:11	2020-08-18	Ignatius Lynch	ignatius.lynch@geemail.com	Fayetteville	North Carolina	4096510277117704	3bf086f43844a17891179092cf2c9002	VISA 16 digit	35.1133166219826762	-79.0572579272687506
45892	2020-08-18 08:46:01	2020-08-18	Paxton Hauck-Roberts	paxton.hauck.roberts@geemail.com	San Bernardino	California	3024711625583578	4461670de094f0e9c274f7b139b32ebd	Diners Club / Carte Blanche	34.1479789288978992	-117.393276138209174
45893	2020-08-18 08:46:13	2020-08-18	Tre Shields-Witting	tre.shields.witting@warmmail.com	San Francisco	California	3096204101930807060	53af74513c53f22a918facfe82ed71fd	Voyager	37.760756093051576	-122.449345473535431
45894	2020-08-18 08:47:44	2020-08-18	Kirt Funk-Treutel	kirt.funk.treutel@geemail.com	Shreveport	Louisiana	6011359524543701748	4e841da805443936ac5b851344a242d0	JCB 15 digit	32.3854668315738436	-93.8100875368554057
45895	2020-08-18 08:49:29	2020-08-18	Link Erdman	link.erdman@woohoo.com	San Diego	California	4323992080766676	4973d58211dcbd70c9e08d9f9ab0c60c	Discover	32.7321220360763405	-117.062645389130338
45896	2020-08-18 08:50:21	2020-08-18	Dr. Tyron Lynch Jr.	dr.tyron.lynch.jr.@geemail.com	Brownsville	Texas	4831705722012365	8627012b46f25f4bac2963f2b76aa34a	Maestro	26.0608717007640749	-97.4146820266917359
45897	2020-08-18 08:58:13	2020-08-18	Khiry Yundt	khiry.yundt@geemail.com	New York	New York	4765793422856	b5be3729a1f7eeba32e7646966c892bb	American Express	40.5947550990376627	-73.8839701547648673
45898	2020-08-18 09:04:37	2020-08-18	Alexander Grady	alexander.grady@geemail.com	New York	New York	3759408854931917	d9ae98148e6a1870603de596bf8fd5b0	VISA 13 digit	40.6665958342365883	-73.9827373762510661
45899	2020-08-18 09:32:35	2020-08-18	Quiana Hilll	quiana.hilll@woohoo.com	Victorville	California	869983733464080916	a9548d3ace1fef7f1981c877b05002ac	American Express	34.5081796437732891	-117.34796978171579
45900	2020-08-18 09:35:42	2020-08-18	Dr. Florie Abbott PhD	dr.florie.abbott.phd@geemail.com	Los Angeles	California	210049702095756759	9030cce678483f3c8d3ba5ff5028ed4a	VISA 16 digit	33.9835074145212772	-118.421438287197788
45901	2020-08-18 09:53:54	2020-08-18	Lura Hirthe MD	lura.hirthe.md@warmmail.com	Berkeley	California	51807189089357871	3667abe90ea162ccfe33237a2e912ae1	JCB 16 digit	37.8895470383526458	-122.276529690028568
45902	2020-08-18 09:59:43	2020-08-18	Mr. Cayden Doyle II	mr.cayden.doyle.ii@warmmail.com	Oakland	California	3528040700878672952	b0eeabf7ab5d5788d0bd71f879d51cb8	JCB 16 digit	37.81165834109472	-122.26496888700602
45903	2020-08-18 10:14:23	2020-08-18	Dr. Clara Keebler DDS	dr.clara.keebler.dds@woohoo.com	Los Angeles	California	4429821770462564	be7bdf042620746605a2d03b690a7cde	Voyager	34.071244377582893	-118.41746644158772
45904	2020-08-18 10:15:05	2020-08-18	Lenny Hoeger	lenny.hoeger@geemail.com	Fort Wayne	Indiana	4812481178626230	39222f9b4cc02f163e856e2b248b5387	Maestro	41.1737382991023395	-85.2376681653071273
45905	2020-08-18 10:25:33	2020-08-18	Guthrie Jast	guthrie.jast@geemail.com	Los Angeles	California	3036636147255504	42a6e3afdc51ee89659cfde8c6309030	VISA 16 digit	34.0500375740561623	-118.420111101352788
45906	2020-08-18 10:26:22	2020-08-18	Jovani Berge	jovani.berge@geemail.com	Lubbock	Texas	210024619247164436	b5ea79323e0468025c62a6ec4cbb03d2	Discover	33.4703860135790023	-101.887868047823019
45907	2020-08-18 10:27:10	2020-08-18	Armani Ernser	armani.ernser@geemail.com	Manchester	New Hampshire	503805358112356	736d4b5bdd92e4ac738af8962e4976d6	Maestro	43.0151855120040523	-71.5361473996549933
45908	2020-08-18 10:40:30	2020-08-18	Ms. Nonie Quigley	ms.nonie.quigley@geemail.com	Cincinnati	Ohio	6011975391355536669	43b4100ed3787f03740bf2caf47d6f7e	Mastercard	39.1347554423611612	-84.4500790449131244
45909	2020-08-18 10:42:59	2020-08-18	Enrique Kub	enrique.kub@geemail.com	New York	New York	4802842859290368	e15781404381f98e5c33e5dd4ca98368	JCB 16 digit	40.6944579345863318	-73.8632118096005144
45910	2020-08-18 10:45:36	2020-08-18	Deidra Lowe	deidra.lowe@woohoo.com	Clinton	Michigan	4451037938375	50326d9c83c2b361be92b5cf6102e099	Discover	42.579335742590203	-82.9385182994026735
45911	2020-08-18 10:53:23	2020-08-18	Miss Carrie Herman	miss.carrie.herman@geemail.com	Nashville	Tennessee	4169267418336	4380cb4af16deb13fdff188a3690f3bb	VISA 16 digit	36.1019738708279974	-86.8038796284142791
45912	2020-08-18 11:12:07	2020-08-18	Myrle Harvey MD	myrle.harvey.md@geemail.com	Berkeley	California	180086081285043078	ab683d5bf81fc772246235e5691b850b	Discover	37.868981436533339	-122.234260745894559
45913	2020-08-18 11:12:33	2020-08-18	Mrs. Nila Hyatt	mrs.nila.hyatt@warmmail.com	Salt Lake City	Utah	3788936899526222	1d11b5e9cc9b0d1fd21146dc9e8d50e0	Discover	40.8362732757028155	-111.995164292067287
45914	2020-08-18 11:30:43	2020-08-18	Martin Ortiz	martin.ortiz@warmmail.com	Indianapolis	Indiana	4981790950809649	4200811b0515ddda4252995bd7ad4617	JCB 16 digit	39.8237779111608816	-86.2259635223276888
45915	2020-08-18 11:33:56	2020-08-18	Ms. Vernice Bins DDS	ms.vernice.bins.dds@geemail.com	Fort Wayne	Indiana	3528004381864705298	de14ce8fab8465086bd484ddf2a60c65	VISA 16 digit	41.0879671477962276	-85.0846632311340443
45916	2020-08-18 11:35:48	2020-08-18	Geraldo Hansen	geraldo.hansen@geemail.com	Clarksville	Tennessee	51366957934174417	f9fbec7866cdb94aac45fd6d9e282083	Voyager	36.5375239084601446	-87.4254098949905512
45917	2020-08-18 11:44:18	2020-08-18	Taryn Schulist	taryn.schulist@geemail.com	Chula Vista	California	55314666279543853	d0b918312590916b77de39ad2f96f889	VISA 16 digit	32.7036938369039447	-117.056919022719185
45918	2020-08-18 11:50:16	2020-08-18	Jaiden Pouros	jaiden.pouros@geemail.com	Midland	Texas	3528282997353743996	37e2e23a5abf7b9ebae88a08b80a96f8	Voyager	31.9932014852020892	-102.075992370652031
45919	2020-08-18 11:57:59	2020-08-18	Gideon Boyer V	gideon.boyer.v@geemail.com	Dallas	Texas	869987128713503378	14077b9926fdc45e3335ac137b48333c	JCB 16 digit	32.8179590822935126	-96.7913888697475073
45920	2020-08-18 12:03:08	2020-08-18	Flossie Mayer	flossie.mayer@geemail.com	West Covina	California	55470211040147435	e46f73ff21d9f243d5c7b04c5da31ff5	American Express	34.0387474171925319	-117.842957900471603
45921	2020-08-18 12:08:22	2020-08-18	Orren Beer Jr.	orren.beer.jr.@woohoo.com	Downey	California	3528572476027970276	aed09b9b0a4b74796dac24d04041c314	VISA 13 digit	33.8885805714193751	-118.070077925325933
45922	2020-08-18 12:25:23	2020-08-18	Lashonda Spinka	lashonda.spinka@woohoo.com	Los Angeles	California	3112635767107896240	1350d56b55b6bc65651f64e47209d8cd	Voyager	34.0794719052366872	-118.442492402064801
45923	2020-08-18 12:26:59	2020-08-18	Hal Lubowitz	hal.lubowitz@geemail.com	Waco	Texas	3702050530010282	bdabacf5597ba64d83a94d5cca06d6a9	JCB 16 digit	31.5368954665236174	-97.186929631339396
45924	2020-08-18 12:38:06	2020-08-18	Mr. Garnett Ziemann IV	mr.garnett.ziemann.iv@geemail.com	San Francisco	California	3000126944401507	21ba6a935171652b16494d263019be65	JCB 16 digit	37.7160082359042548	-122.43935539143861
45925	2020-08-18 12:46:41	2020-08-18	Janell Lowe	janell.lowe@geemail.com	San Francisco	California	3018998940811620	697724cba392c9ab9f818feb433dcfe4	VISA 16 digit	37.7884163158573045	-122.414980850983184
45926	2020-08-18 12:53:36	2020-08-18	Miss Flora Stroman	miss.flora.stroman@geemail.com	Houston	Texas	54915248071736960	13e41f828c16c4251caf0d6c1245fa71	VISA 16 digit	29.8664312287777669	-95.4325509720031135
45927	2020-08-18 12:53:50	2020-08-18	Unnamed Nicolas	unnamed.nicolas@geemail.com	Evansville	Indiana	4111231311497991	04b33c122c92b2d8cfe8af0c500a4f4e	Discover	37.9537635346081075	-87.6002257978942254
45928	2020-08-18 12:54:47	2020-08-18	Samie Metz	samie.metz@geemail.com	Saint Paul	Minnesota	3158870255443955973	b3970163be799fb2b8f944e82197830c	Mastercard	45.0345314211152541	-93.1180328850433199
45929	2020-08-18 12:55:21	2020-08-18	Nikita Ankunding-Hegmann	nikita.ankunding.hegmann@geemail.com	Des Moines	Iowa	3158690729820118148	d644374fed41e19d6fcad5f71a77d2c1	JCB 15 digit	41.5595771329686059	-93.6940959051296147
45930	2020-08-18 13:00:54	2020-08-18	Hugo Volkman	hugo.volkman@woohoo.com	Denver	Colorado	4325951042291	94d078e32b73e19ef056efcc3052aa5d	JCB 16 digit	39.8264797656849012	-104.787322178135071
45931	2020-08-18 13:03:07	2020-08-18	Glendon Kulas V	glendon.kulas.v@geemail.com	El Paso	Texas	869954038405394854	801e23ba7a947b596848ff90fefd260d	Voyager	31.8688970359802255	-106.423558965463201
45932	2020-08-18 13:03:32	2020-08-18	Rigoberto Powlowski	rigoberto.powlowski@warmmail.com	San Francisco	California	869940503332811681	7aad841dfbd66fafd7b4cfc6170e01c8	VISA 16 digit	37.7793525193897892	-122.435036050710337
45933	2020-08-18 13:06:37	2020-08-18	Katia Kris	katia.kris@geemail.com	Riverside	California	3337639559117546337	048a5697a6224b842b88c7c118e1be32	Diners Club / Carte Blanche	33.9730668513517813	-117.489920943786203
45934	2020-08-18 13:21:02	2020-08-18	Orlin Okuneva	orlin.okuneva@warmmail.com	Sunnyvale	California	180036740568668809	b9171b175bdcd88c0c55ce4ba47eed38	Maestro	37.3069566596757625	-122.086730643102158
45935	2020-08-18 13:21:24	2020-08-18	Keshawn Schowalter	keshawn.schowalter@woohoo.com	St. Petersburg	Florida	3528180327421872929	61aa2ca3698bf27a78b77133394921b4	Discover	27.6734764302503322	-82.7240618888646253
45936	2020-08-18 13:23:45	2020-08-18	Jeane Skiles	jeane.skiles@geemail.com	Carlsbad	California	6011998732484959954	8556f716c57293246af711d5cbdbda12	VISA 13 digit	33.2190205903664193	-117.316780445982886
45937	2020-08-18 13:28:08	2020-08-18	Nicolette Greenholt DVM	nicolette.greenholt.dvm@geemail.com	Austin	Texas	4467866605971142	92bc1e24953cff782d70115904e8df15	VISA 16 digit	30.383430335403979	-97.7165231723111134
45938	2020-08-18 13:30:15	2020-08-18	Joanna Hermann	joanna.hermann@warmmail.com	Atlanta	Georgia	4493719749609664	47b4d77d074b538146781500a4e30207	Voyager	33.7714719089489463	-84.3329682911790997
45939	2020-08-18 13:33:52	2020-08-18	Mr. Jamel Schinner	mr.jamel.schinner@geemail.com	Rialto	California	55836911270070681	33edc7dea872eed9e569697e217eb561	JCB 16 digit	34.0896645229525888	-117.475364834311605
45940	2020-08-18 13:45:01	2020-08-18	Bryton Mertz	bryton.mertz@geemail.com	Gresham	Oregon	3158793356395435677	c6d9b9fcfa2252a5d48cb8741dfb5e25	Maestro	45.4770323932591793	-122.450153903968996
45941	2020-08-18 14:09:49	2020-08-18	Dr. Kenji Conroy IV	dr.kenji.conroy.iv@geemail.com	Downey	California	4091315042134629	ce50f32452c7b40f1969aaa6e77d7874	JCB 15 digit	34.0343798127275008	-118.055711665806911
45942	2020-08-18 14:10:14	2020-08-18	Mrs. Cherryl Collier DVM	mrs.cherryl.collier.dvm@warmmail.com	Santa Ana	California	6011763124254847580	43f4a5fa97d92dd683d61d29e9fd3716	VISA 16 digit	33.6507400510936989	-117.804275836834677
45943	2020-08-18 14:15:01	2020-08-18	Malissie Dare PhD	malissie.dare.phd@geemail.com	San Francisco	California	3096763575026089175	5d007e5e1f29be3008bcfcc32272afc8	American Express	37.7732927675113004	-122.469712990743602
45944	2020-08-18 14:17:42	2020-08-18	Jacky Thompson Jr.	jacky.thompson.jr.@woohoo.com	San Diego	California	869976605877544036	acf8296bf6ab8e81aeb55a82ab1f64cb	VISA 16 digit	32.8790201758567235	-117.048499388145288
45945	2020-08-18 14:30:52	2020-08-18	Dr. Scottie McDermott PhD	dr.scottie.mcdermott.phd@warmmail.com	Baton Rouge	Louisiana	4171562599983204	549e1f5f259d46ef2b24471e4f01bd44	American Express	30.4983872645281267	-91.1367267898391873
45946	2020-08-18 14:34:27	2020-08-18	Mrs. Missouri Nader	mrs.missouri.nader@warmmail.com	Chicago	Illinois	4723736778652425	db90da5a6b45f97d2e8f450c774171f4	VISA 16 digit	41.7724450396209974	-87.7526842992782576
45947	2020-08-18 14:37:48	2020-08-18	Dr. Evalena Mraz	dr.evalena.mraz@geemail.com	Las Vegas	Nevada	4358902244229	277ea5a281617ed307ef368567ebd4ee	VISA 13 digit	36.3164564523015159	-115.221204571353638
45948	2020-08-18 14:39:57	2020-08-18	Ms. Makenzie Cassin	ms.makenzie.cassin@geemail.com	Berkeley	California	6011584825504660311	29d2f3a3fe2cde5da0839e1c8535f325	Voyager	37.8581067500494015	-122.273596014680578
45949	2020-08-18 14:58:52	2020-08-18	Jame Douglas	jame.douglas@geemail.com	Oxnard	California	52166306866268049	9216b7f278f864f35feb5bf0a3166496	VISA 16 digit	34.2921639457300316	-119.185878006359928
45950	2020-08-18 15:08:12	2020-08-18	Concepcion Okuneva	concepcion.okuneva@woohoo.com	Thornton	Colorado	869953050950630880	c3bc37bb9b6f74f9d8ecb9854c043cef	JCB 15 digit	39.9719953711010518	-104.88126637699753
45951	2020-08-18 15:09:38	2020-08-18	Luvenia Kiehn	luvenia.kiehn@geemail.com	Nashville	Tennessee	3409001759669889	18bd5219c5691790165ce59b6c9b1060	VISA 16 digit	36.138634610840306	-86.7434288580343065
45952	2020-08-18 15:15:35	2020-08-18	Harvey Crona	harvey.crona@warmmail.com	Sacramento	California	501891504483750	141482218b8ed7849903ff6b89589481	Discover	38.5285125403463837	-121.474827348512036
45953	2020-08-18 15:18:34	2020-08-18	Ms. Jule Hettinger DDS	ms.jule.hettinger.dds@warmmail.com	Stockton	California	676331816862093	07002263d104cfadb2692ba81ef85fc9	Maestro	38.0740284872904411	-121.36395910425037
45954	2020-08-18 15:29:49	2020-08-18	Baldwin Armstrong	baldwin.armstrong@geemail.com	Aurora	Colorado	51483433230028283	f29a70f3644a5aaeec27ac220d4cbd4b	JCB 15 digit	39.7718208755012625	-104.723860806098955
45955	2020-08-18 15:36:40	2020-08-18	Davonta Rosenbaum	davonta.rosenbaum@geemail.com	Kenosha	Wisconsin	4485424986159	790ceaa2589aaca796e832dfced2203d	Maestro	42.5812793119650337	-87.8213583529688435
45956	2020-08-18 15:45:41	2020-08-18	Mr. Beau Mueller	mr.beau.mueller@woohoo.com	San Francisco	California	4341630003116532	283846b3082bd8f6fdbb1c5a6d6ef566	VISA 16 digit	37.7560824302375693	-122.441450004652125
45957	2020-08-18 15:49:00	2020-08-18	Ms. Jaeda Barrows	ms.jaeda.barrows@warmmail.com	West Jordan	Utah	6011091611704466378	444ea2d43de8ea1216c2ae378d2c1b48	Discover	40.5891692413274257	-111.962972243231903
45958	2020-08-18 15:49:31	2020-08-18	Anibal Cartwright	anibal.cartwright@geemail.com	Chicago	Illinois	6011388636997181121	d898c75f9c729610bc5e34cc9a86051d	JCB 16 digit	41.8514098140247199	-87.6426743917196944
45959	2020-08-18 16:00:11	2020-08-18	Susann Doyle	susann.doyle@geemail.com	El Cajon	California	3088384738297785454	8c4539f050d96d26b8a5a95916d074c0	JCB 16 digit	32.8598766704097329	-116.91312956606933
45960	2020-08-18 16:01:25	2020-08-18	Ayesha Lebsack	ayesha.lebsack@geemail.com	Baltimore	Maryland	869926941881519941	c2b7e90d15e3c97d6d024121f37e8024	Maestro	39.3312275175936463	-76.6179427811428866
45961	2020-08-18 16:12:35	2020-08-18	Shanda Will	shanda.will@geemail.com	Philadelphia	Pennsylvania	4724084506018	8023a2a99fafa6c4d91b374986bdad5f	VISA 16 digit	40.1037335057236248	-75.169651678008222
45962	2020-08-18 16:24:20	2020-08-18	Jeremiah Schmitt	jeremiah.schmitt@geemail.com	Billings	Montana	55874843197607977	1365ee9a7597a89ef7291b2ae6ce10d2	Discover	45.8514781712777904	-108.636972298768896
45963	2020-08-18 16:35:35	2020-08-18	Mr. Toshio Nicolas	mr.toshio.nicolas@warmmail.com	Macon	Georgia	675931035809628	fee8d3fdb9279e45eb0f69f9cd16655f	VISA 16 digit	32.7258429297257223	-83.6419862486150123
45964	2020-08-18 16:36:50	2020-08-18	Timmie Daugherty	timmie.daugherty@warmmail.com	Tucson	Arizona	869921305596057420	c0ad65f94a380dddf507854bfead305e	VISA 13 digit	32.1120812830090543	-110.803449486265322
45965	2020-08-18 16:37:28	2020-08-18	Dr. Daijah Abernathy MD	dr.daijah.abernathy.md@geemail.com	Sioux Falls	South Dakota	4363396841065520	ee09c6aefe6bd05f27668a0a939d3d1b	Diners Club / Carte Blanche	43.5587835575539586	-96.7341032346412533
45966	2020-08-18 16:47:22	2020-08-18	Elbert Gleason	elbert.gleason@geemail.com	Cleveland	Ohio	3158358117802293936	892ab965363adee2537ac18be8cf74f5	JCB 16 digit	41.5372840136140553	-81.6799736436229153
45967	2020-08-18 16:50:17	2020-08-18	Alger Yost	alger.yost@geemail.com	Eugene	Oregon	3528071724117522416	7f055a679a056ae89b2f15e3fc202baf	Mastercard	44.063714257134869	-123.18876963010878
45968	2020-08-18 16:52:05	2020-08-18	Mercedes Rau	mercedes.rau@geemail.com	Houston	Texas	3423684946321365	0ee651ec323c67ad17c92d9cceed8ed8	VISA 16 digit	29.7390961018469184	-95.448770845356961
45969	2020-08-18 16:55:11	2020-08-18	Micah Zieme	micah.zieme@warmmail.com	San Francisco	California	3337622115238764546	36863e62aaf5bb7862114873caca9ebf	Maestro	37.7665100762683394	-122.427242382128398
45970	2020-08-18 16:57:32	2020-08-18	Ole Batz-Schroeder	ole.batz.schroeder@warmmail.com	Houston	Texas	3407846743419490	7cc1f3bb0273178d2bdd7c1b37a87dd5	VISA 16 digit	29.752713892011343	-95.4489972964409787
45971	2020-08-18 17:01:51	2020-08-18	Mr. Otho Braun V	mr.otho.braun.v@geemail.com	San Antonio	Texas	53111834628302265	f914a474ef72c7d29cd170d4e500ab7d	JCB 16 digit	29.4287018323387954	-98.6182272157933539
45972	2020-08-18 17:05:22	2020-08-18	Budd Batz	budd.batz@geemail.com	San Francisco	California	676155851290977	a804dfe0d794f14624d163bfbe5fbb42	JCB 15 digit	37.7679566147432411	-122.41632995923122
45973	2020-08-18 17:15:29	2020-08-18	Achsah Toy	achsah.toy@geemail.com	Oceanside	California	3088688218747680509	100b851e154cf8e6c51e4cbf7c05a5c6	VISA 16 digit	33.2556723444610824	-117.31251711296737
45974	2020-08-18 17:37:18	2020-08-18	Kayli Hane	kayli.hane@geemail.com	Buffalo	New York	6011791488146613740	32751dff86857ab561e5e475a471fca2	Diners Club / Carte Blanche	42.8289079531747845	-78.9448362039800742
45975	2020-08-18 17:49:12	2020-08-18	Juan Schumm	juan.schumm@geemail.com	Oakland	California	55729224544093517	aaa871fa7705ef60d82a3cfb1a8aec1c	VISA 16 digit	37.8131849326264415	-122.267521182292967
45976	2020-08-18 17:56:04	2020-08-18	Kasie Hyatt	kasie.hyatt@woohoo.com	Santa Maria	California	210001852634171378	e62748e5792c09bd6a8799b8bea01e45	Diners Club / Carte Blanche	35.0174974992934622	-120.483791932036354
45977	2020-08-18 17:57:56	2020-08-18	Benson Boyle DVM	benson.boyle.dvm@geemail.com	Los Angeles	California	3112107451201539407	701ad340c5bd2279ee88e11b9749b3a0	Discover	34.0191727363836023	-118.388498267856605
45978	2020-08-18 18:03:51	2020-08-18	Michel Satterfield	michel.satterfield@geemail.com	Richmond	Virginia	3455604896135277	a4ad5aec5c018c12529be0f672692b10	Voyager	37.5934432795491063	-77.4811509754266581
45979	2020-08-18 18:16:45	2020-08-18	Kenyatta Grimes	kenyatta.grimes@woohoo.com	Long Beach	California	3726455105967299	af3b4194a175dffcd443aaaf512313f7	JCB 15 digit	33.8766637613817991	-118.247181650965658
45980	2020-08-18 18:36:52	2020-08-18	Vesta Kirlin	vesta.kirlin@geemail.com	Tucson	Arizona	3528219855491954107	d434bdbde32fc5555b65082fc7691dde	Maestro	32.2345255004748736	-110.94345827789455
45981	2020-08-18 18:45:33	2020-08-18	Dr. Kaydence Brown	dr.kaydence.brown@geemail.com	Garland	Texas	3096845926982190246	3757086d1831078df79d2297ea03cee6	JCB 16 digit	32.8450190863341049	-96.6370977970466072
45982	2020-08-18 18:48:16	2020-08-18	Miss Clotilda Breitenberg MD	miss.clotilda.breitenberg.md@woohoo.com	Berkeley	California	4332025166972949	7cc0814f75d290acecad92ef98c442c7	JCB 16 digit	37.87080226058265	-122.307315366493228
45983	2020-08-18 18:51:55	2020-08-18	Gary Pacocha-Schaden	gary.pacocha.schaden@warmmail.com	Round Rock	Texas	180067029033374884	f3d006c381acde6716f355ed6cc655fd	VISA 16 digit	30.6170989188037836	-97.5785105822458831
45984	2020-08-18 18:53:41	2020-08-18	Buddy Luettgen	buddy.luettgen@warmmail.com	Elk Grove	California	3747625540283008	da13901a344e528f635f5c33330af997	Diners Club / Carte Blanche	38.3767297964360594	-121.38908797897399
45985	2020-08-18 18:59:41	2020-08-18	Grover Heidenreich-Grant	grover.heidenreich.grant@warmmail.com	San Antonio	Texas	3016517562173127	da3db8d952bd294982d58f3f5eeeb1f1	American Express	29.5188459019713108	-98.4964399490807097
45986	2020-08-18 19:01:13	2020-08-18	Dr. Wayde Gulgowski Jr.	dr.wayde.gulgowski.jr.@geemail.com	Plano	Texas	676296303164626	3595be0227ccf25e3463a19f37ae2bee	Mastercard	33.0802016245286907	-96.8012656681422214
45987	2020-08-18 19:02:11	2020-08-18	Kaye Turcotte	kaye.turcotte@warmmail.com	Berkeley	California	869967755513366301	509e7d9c78b0237a942064b9a35366cc	JCB 16 digit	37.8834497547504938	-122.253047355632773
45988	2020-08-18 19:19:56	2020-08-18	Hazle Stroman-Krajcik	hazle.stroman.krajcik@geemail.com	Seattle	Washington	869955602893154549	085cc7d03b4c98b693bbd69ce9deb713	VISA 16 digit	47.6680958418101071	-122.271692592084037
45989	2020-08-18 19:23:21	2020-08-18	Dr. Arvid Grimes PhD	dr.arvid.grimes.phd@geemail.com	Midland	Texas	3765062832345146	e0933dd654a8352fb312279b2ba1ce63	Discover	31.9761337827615435	-102.207246713921435
45990	2020-08-18 19:24:08	2020-08-18	Dr. Keila King	dr.keila.king@geemail.com	Houston	Texas	3088075772563608680	c56bd42e2c8779e6c91f3114f1ef8e9c	Discover	29.6972527152936898	-95.4329352874323718
45991	2020-08-18 19:26:38	2020-08-18	Americo Rowe	americo.rowe@woohoo.com	Chicago	Illinois	3096691331508294801	fc7b0cccdb64f1cdcf976c586c41cf11	Mastercard	41.7801704062450696	-87.686805525425072
45992	2020-08-18 19:27:50	2020-08-18	Ms. Wanda Feeney DDS	ms.wanda.feeney.dds@geemail.com	Sugar Land	Texas	51970253704893156	0817ace3207caf96a0ca19e5306708a7	JCB 16 digit	29.6965191766671843	-95.5241532195366858
45993	2020-08-18 19:32:49	2020-08-18	Vincent Osinski	vincent.osinski@geemail.com	West Palm Beach	Florida	675975787249889	0464741ab090b055d0e89462fe7d0fc4	JCB 15 digit	26.7179698584448566	-80.1088839914485789
45994	2020-08-18 19:44:16	2020-08-18	Mr. Orin Marquardt Jr.	mr.orin.marquardt.jr.@geemail.com	El Paso	Texas	869971611350775530	4c9deab1d6a360f93e003420f599d2b5	JCB 15 digit	31.8135841165497908	-106.382579751962808
45995	2020-08-18 19:49:48	2020-08-18	Mr. Darnell D'Amore DVM	mr.darnell.d'amore.dvm@woohoo.com	San Francisco	California	180008061954302216	5ba4518e6685133ba37b13a677c8cbff	VISA 16 digit	37.7899482011779071	-122.448441226341174
45996	2020-08-18 19:56:23	2020-08-18	Landyn Hirthe	landyn.hirthe@geemail.com	San Diego	California	3032228096792457	3f0295e49812d62eb4b01ed74c49c26d	VISA 13 digit	32.7673195654593385	-117.048929452793672
45997	2020-08-18 20:03:46	2020-08-18	Brigid Braun	brigid.braun@geemail.com	New York	New York	869908934984178014	ca582c10bf9f94a594539cfa4891325b	Maestro	40.7507416554950197	-73.9548835255101267
45998	2020-08-18 20:15:08	2020-08-18	Nathaly Quigley DDS	nathaly.quigley.dds@geemail.com	Oakland	California	3158103865703187320	eaf771f6cffc666866749c094faf532b	Mastercard	37.7708751215913878	-122.26313522693313
45999	2020-08-18 20:20:28	2020-08-18	Miss Pat Conroy DDS	miss.pat.conroy.dds@geemail.com	San Francisco	California	869950061286210431	0292b2e9fe7438955d19ff850d20b6e3	Diners Club / Carte Blanche	37.7736363726907101	-122.449259865269141
46000	2020-08-18 20:21:34	2020-08-18	Venice Legros	venice.legros@geemail.com	St. Louis	Missouri	3112143564773643773	9943fc44878c290db4ac76d71880cdae	JCB 15 digit	38.5365584434632211	-90.3213682096455273
46001	2020-08-18 20:21:42	2020-08-18	Danita Heidenreich	danita.heidenreich@geemail.com	Phoenix	Arizona	180077230718689202	898d1b5c95c53243aeb2df755e75e158	Maestro	33.5422622445438066	-112.05730154383221
46002	2020-08-18 20:24:12	2020-08-18	Raphael Lehner V	raphael.lehner.v@geemail.com	Indianapolis	Indiana	3158382058658391566	cc49c8b23bd9c0be2c0c81728414156f	VISA 13 digit	39.8457846581943329	-86.0771204055953802
46003	2020-08-18 20:25:05	2020-08-18	Mr. Shelly Thompson	mr.shelly.thompson@warmmail.com	Lewisville	Texas	869900680006859739	1a422fc4be9f506f900498a55e702786	JCB 16 digit	33.1115886293336743	-96.9403055733099706
46004	2020-08-18 20:31:40	2020-08-18	Gaige Bins-Koepp	gaige.bins.koepp@geemail.com	Memphis	Tennessee	4881221835595071	e6177266caa412ad404eb2076d9718f7	JCB 15 digit	35.1476251692578217	-89.9809904361866444
46005	2020-08-18 20:45:43	2020-08-18	Essie Heller	essie.heller@geemail.com	Memphis	Tennessee	4096726858732352	9bbf3d5ec5f2d6ffcdd539a5a34dfea7	JCB 16 digit	35.0872863204285537	-89.9028340046085503
46006	2020-08-18 20:52:27	2020-08-18	Marlo Wisozk	marlo.wisozk@geemail.com	Anaheim	California	3112985556349943084	9da05cb5b1e425c17a9b9ffcdd5ca1bc	Voyager	33.8824884261768275	-117.661312711911648
46007	2020-08-18 20:55:34	2020-08-18	Kami Hessel	kami.hessel@geemail.com	New York	New York	4281344600488540	c628e5563033bc99f1bf1075ee7c036f	Diners Club / Carte Blanche	40.7290816275160736	-73.8853028877068283
46008	2020-08-18 20:57:56	2020-08-18	Alysa Hayes	alysa.hayes@warmmail.com	Newark	New Jersey	4808212685348695	203cd47b241b0a258fa2423c215a801c	Mastercard	40.6307377781633292	-74.2646441039372291
46009	2020-08-18 21:04:57	2020-08-18	Natalia Blanda	natalia.blanda@geemail.com	El Paso	Texas	3732970284240088	7e1905beed044a62d9aa928857acb041	Voyager	31.8502802384380281	-106.513215874319897
46010	2020-08-18 21:05:00	2020-08-18	Yee Zulauf IV	yee.zulauf.iv@geemail.com	San Antonio	Texas	4406634211835356	66e3aaba71c35d0a5cb1836b9cc3ed45	Mastercard	29.5270816223301011	-98.5293458073701629
46011	2020-08-18 21:11:19	2020-08-18	Jaylen Kshlerin	jaylen.kshlerin@woohoo.com	Frisco	Texas	210042517559790442	2edafb8429a0d8222a4c06aec27b3fb7	Discover	33.0612836404234187	-96.7994523455131741
46012	2020-08-18 21:21:43	2020-08-18	Javonte Gusikowski-Bednar	javonte.gusikowski.bednar@geemail.com	New York	New York	561251159840530	8873936c344ef1f63d65e11724b51ae5	Discover	40.625158247280865	-73.9441281345568626
46013	2020-08-18 21:24:38	2020-08-18	Syreeta Ullrich	syreeta.ullrich@woohoo.com	Denver	Colorado	3112834644688568820	33ed84b1b0ea5741ee198af135d04396	Diners Club / Carte Blanche	39.7418076023045899	-104.937095702324442
46014	2020-08-18 21:35:57	2020-08-18	Elisabeth Jerde	elisabeth.jerde@geemail.com	Los Angeles	California	52398593847140914	366518d23091c214ce163ba088f4244b	Discover	34.0838328623078723	-118.400039739766342
46015	2020-08-18 21:47:55	2020-08-18	Mrs. Kinsley Predovic MD	mrs.kinsley.predovic.md@geemail.com	Daly City	California	4901339261850	cc9e10898fd3ebc120b0afa8b240d8f8	Maestro	37.7302926530517624	-122.465472136493773
46016	2020-08-18 21:50:09	2020-08-18	Steven Lakin-O'Reilly	steven.lakin.o'reilly@geemail.com	Vacaville	California	6011226254836556150	c154160d02eab5458c544a30e79794c7	Mastercard	38.3769092767160416	-122.011309959774096
46017	2020-08-18 21:51:17	2020-08-18	Augustus Larkin	augustus.larkin@geemail.com	Antioch	California	52086463320246769	fa2f49ecd0dc6b29c5510be4b12a48af	JCB 16 digit	38.0697735010910776	-121.73313644623272
46018	2020-08-18 21:52:54	2020-08-18	Ayaan O'Connell	ayaan.o'connell@geemail.com	New York	New York	6011951328736146998	0034d8ef2d3dd02f5c8ced020ad2eff0	JCB 15 digit	40.7190473583284742	-73.9204708997521465
46019	2020-08-18 21:53:38	2020-08-18	Lucy Hoeger	lucy.hoeger@warmmail.com	Miramar	Florida	869922121575084551	ce60f68e8549a39cadefa50fe902ff2b	American Express	25.9627808984816077	-80.316028926986462
46020	2020-08-18 22:00:25	2020-08-18	Mr. Adlai Adams Jr.	mr.adlai.adams.jr.@woohoo.com	Anchorage	Alaska	869938744782533979	70325b7e02e73015eae726a9d3fc9f07	Voyager	61.138700403480982	-149.335815309605749
46021	2020-08-18 22:03:03	2020-08-18	Ferrell Roob	ferrell.roob@geemail.com	Moreno Valley	California	869992375712267785	d80c441b9b93a38d70628804ac4bbd84	JCB 16 digit	33.8545568777240788	-117.262178260690334
46022	2020-08-18 22:03:35	2020-08-18	Cortney Nienow	cortney.nienow@geemail.com	Columbus	Ohio	6011431669909404239	46680bc0ee8248697a5ab881608d71ad	JCB 15 digit	40.0150710661008944	-83.081995666376514
46023	2020-08-18 22:21:37	2020-08-18	Mrs. Treena Jerde MD	mrs.treena.jerde.md@woohoo.com	San Francisco	California	4578295657618672	7788e679376798292294d6185cd2b7b8	Voyager	37.7874540052318437	-122.387238098225225
46024	2020-08-18 22:28:31	2020-08-18	Margery Marvin	margery.marvin@warmmail.com	Lancaster	California	54044745747952172	fb5f02126398dea1cacd7e5ca19b5ee7	Voyager	34.6663943058591357	-118.254988443755721
46025	2020-08-18 22:56:52	2020-08-18	Lana Bahringer	lana.bahringer@geemail.com	San Francisco	California	54688676896333487	e5f7aee193ba71ab60bc354bc7e60fab	JCB 15 digit	37.7660554265359778	-122.417864685446801
46026	2020-08-18 22:59:37	2020-08-18	Avah Lynch	avah.lynch@geemail.com	Philadelphia	Pennsylvania	3721280496634430	d5079a1997bbfa48e5a75b5a907951a4	Mastercard	39.9352327967487284	-75.1039946217920686
46027	2020-08-18 23:06:04	2020-08-18	Emilee Dare	emilee.dare@warmmail.com	San Francisco	California	676139593125782	79d87c0d458f5b7e2ecae4a8d6ba7e36	JCB 16 digit	37.7471643461207975	-122.425831208268534
46028	2020-08-18 23:11:15	2020-08-18	Dr. Eugenie Bernier	dr.eugenie.bernier@warmmail.com	Columbus	Ohio	4106449227904606	a34eed9453736316ff0cb7fee1fbae9f	JCB 16 digit	39.9042465814899643	-83.0470483129147539
46029	2020-08-18 23:17:33	2020-08-18	Norma Murphy-DuBuque	norma.murphy.dubuque@geemail.com	Boulder	Colorado	4830361515126516	be9c3667f945bffe525ecd3ce220fcba	Maestro	40.0357691817432624	-105.290815758812812
46030	2020-08-18 23:22:13	2020-08-18	Joretta Predovic-Pfannerstill	joretta.predovic.pfannerstill@geemail.com	Pittsburgh	Pennsylvania	3112595681630616512	b92027909acfd4787c6862554c51cbb7	VISA 16 digit	40.3398347682740521	-79.8805298436138855
46031	2020-08-18 23:24:49	2020-08-18	Braelyn Baumbach	braelyn.baumbach@warmmail.com	Richmond	Virginia	6011087537974848746	902296a9391d32f6c39ad925165af97c	Maestro	37.5250931225005502	-77.4819480507392484
46032	2020-08-18 23:35:18	2020-08-18	Tricia Cartwright	tricia.cartwright@geemail.com	Centennial	Colorado	180090412126988524	88fcac39e80582a322cc0fca5a4d7f3d	JCB 16 digit	39.5112386611331274	-104.877625681495672
46033	2020-08-18 23:39:52	2020-08-18	Brittnie Hansen	brittnie.hansen@geemail.com	Grand Prairie	Texas	6011328677508151776	b3c02724f59b19837d276c058baddb62	JCB 15 digit	32.6956844196707053	-96.935376511920623
46034	2020-08-18 23:47:16	2020-08-18	Mr. Jammie Quigley IV	mr.jammie.quigley.iv@geemail.com	Houston	Texas	4072750284308	2e082f185c8c21e6485482bb81218233	VISA 13 digit	29.87091665180251	-95.346980153724175
46035	2020-08-18 23:50:46	2020-08-18	Ogden Balistreri	ogden.balistreri@geemail.com	Jackson	Mississippi	210093013616846607	793a01dbb5e62e869b4476566872df8f	JCB 16 digit	32.2896321807701199	-90.1536299481961834
46036	2020-08-18 23:52:03	2020-08-18	Docia Cummings	docia.cummings@geemail.com	San Francisco	California	3719347198866422	d4b79b1e1b18f0fffb661bad22144126	Voyager	37.7468663759788967	-122.450955971821941
46037	2020-08-18 23:52:10	2020-08-18	Mrs. Alisson Romaguera	mrs.alisson.romaguera@geemail.com	Bakersfield	California	3528829212908170517	f898f5c7a7be550b7c95bc4d1ef85787	VISA 16 digit	35.3168853311043236	-118.952207015947621
46038	2020-08-18 23:55:33	2020-08-18	Lionel Dietrich Sr.	lionel.dietrich.sr.@woohoo.com	Washington	District of Columbia	210059851136038797	558c828659eb12ed1303d3f939517451	JCB 16 digit	38.9189192300461215	-77.0091622993096792
46039	2020-08-19 00:03:57	2020-08-19	Zander Bernhard	zander.bernhard@geemail.com	Indianapolis	Indiana	4494832268283	4bd56416ae6ee4d1d31d5bb3d227a664	Maestro	39.7512957146864352	-86.1224988847240809
46040	2020-08-19 00:11:00	2020-08-19	Miss Marcy Schaden	miss.marcy.schaden@geemail.com	Las Vegas	Nevada	869968358643927610	1f08038cf898da6304e0a7c3cdad2822	VISA 16 digit	36.1835631396722022	-115.233191581789768
46041	2020-08-19 00:14:53	2020-08-19	Alexis Hartmann	alexis.hartmann@geemail.com	Dallas	Texas	6011530811903712510	13c44dfcde05074952fb09b8456f1b64	VISA 13 digit	32.8761637217171483	-96.7810622472278652
46042	2020-08-19 00:18:48	2020-08-19	Brennon Quitzon	brennon.quitzon@geemail.com	San Francisco	California	180082251048538664	8366548169140028f15c441641823cbe	JCB 16 digit	37.7445427636624729	-122.442725191500614
46043	2020-08-19 00:21:36	2020-08-19	Ashlyn Maggio-Robel	ashlyn.maggio.robel@geemail.com	Cape Coral	Florida	4753535236784	01749075e059d8f45fd01301e80dab68	Voyager	26.6161179166723052	-82.0320314926631795
46044	2020-08-19 00:24:19	2020-08-19	Cruz Cremin	cruz.cremin@geemail.com	Philadelphia	Pennsylvania	4283234792242	455ef6a4a619490fdd7a494a693efbc9	JCB 16 digit	40.0250860005576143	-75.1973897700563185
46045	2020-08-19 00:37:52	2020-08-19	Phebe Willms MD	phebe.willms.md@geemail.com	Miami Gardens	Florida	3088349122021420270	9063363d69b71b1822eb0225b8a8100f	VISA 16 digit	25.8779110727772093	-80.3301715746302136
46046	2020-08-19 00:42:23	2020-08-19	Mrs. Alejandra Beier PhD	mrs.alejandra.beier.phd@geemail.com	Little Rock	Arkansas	3051967636069311	a6dbff64ded45eb9744ed675db202f5b	VISA 16 digit	34.7659246681068126	-92.2922823539342687
46047	2020-08-19 00:48:44	2020-08-19	Franz Zboncak	franz.zboncak@geemail.com	Dallas	Texas	3112323563515235189	283b44a669039f4112c42e35e1e59dd8	American Express	32.7073129878185682	-96.8541631019636924
46048	2020-08-19 00:59:02	2020-08-19	River Gulgowski	river.gulgowski@warmmail.com	Seattle	Washington	3096208186984343084	3bdbb69e1babc03a50ff52ea7e3abf8f	JCB 16 digit	47.6823100227788075	-122.371118825014307
46049	2020-08-19 01:02:33	2020-08-19	Amir Kulas	amir.kulas@geemail.com	San Diego	California	6011422777955738805	201d77e60ecaa02d01310b5719558e05	VISA 16 digit	32.8709432601064435	-117.217718996144839
46050	2020-08-19 01:04:07	2020-08-19	Dr. Willa Heaney	dr.willa.heaney@geemail.com	San Diego	California	6011329783070336305	882442d325758384577da6e8f36b2c56	Voyager	32.8163340341366805	-117.233243458615618
46051	2020-08-19 01:04:10	2020-08-19	Marty Ziemann	marty.ziemann@geemail.com	San Francisco	California	3158134165034953810	d30b3ee75b416910d74e03bd19bba46d	JCB 16 digit	37.7957593176624087	-122.435700083429239
46052	2020-08-19 01:20:02	2020-08-19	Penelope Johnson	penelope.johnson@geemail.com	Fort Lauderdale	Florida	3528423774575500946	45df06c3f7339307a6eb9a613df2787b	Discover	26.2151534107968232	-80.1021055392276509
46053	2020-08-19 01:22:04	2020-08-19	Hayden Stiedemann DVM	hayden.stiedemann.dvm@geemail.com	El Paso	Texas	210030490440310354	2648448286622ba1c314ffadb01b66c9	JCB 16 digit	31.8513546066187345	-106.426326555104936
46054	2020-08-19 01:30:18	2020-08-19	Desiree Volkman	desiree.volkman@geemail.com	New York	New York	3724642061317864	1d45e4c0cc9c008a983353ffe79a4b1a	Discover	40.6115993371922528	-73.917522054108602
46055	2020-08-19 01:33:54	2020-08-19	Shanta Gaylord	shanta.gaylord@woohoo.com	Dallas	Texas	675906760333127	b43f614d115409e164a8e02cedfa1406	JCB 15 digit	32.7458848959106987	-96.6848124846313084
46056	2020-08-19 01:34:09	2020-08-19	Miss Minna Denesik DDS	miss.minna.denesik.dds@geemail.com	Minneapolis	Minnesota	3112593918470908621	a845e3406ad99642338c20484eade5bc	Mastercard	44.987167365345357	-93.3600426900006823
46057	2020-08-19 01:39:22	2020-08-19	Paula Marks-Goodwin	paula.marks.goodwin@geemail.com	Aurora	Colorado	3337124096886258267	6bda992edacaa758f87e0288405f5fa2	Voyager	39.6637729389704816	-104.714937572146582
46058	2020-08-19 01:43:54	2020-08-19	Delphine Schmitt	delphine.schmitt@geemail.com	New York	New York	55232030523148960	9dd5d22d32cff18bcdeaa4192c6215e2	VISA 13 digit	40.6331095569990595	-73.9920014801796526
46059	2020-08-19 01:51:04	2020-08-19	Kip Botsford	kip.botsford@geemail.com	Minneapolis	Minnesota	6011417332418121368	46d118c9a7521525e76a500cf1b91316	Diners Club / Carte Blanche	45.0121013250287589	-93.3623612405538523
46060	2020-08-19 01:58:44	2020-08-19	Nery Rosenbaum	nery.rosenbaum@geemail.com	Denton	Texas	3158385681804082321	729de95c2423c114e244f6a26dce5489	JCB 15 digit	33.2159129880167541	-97.0984088009350046
46061	2020-08-19 02:07:27	2020-08-19	Ms. Malissa Christiansen	ms.malissa.christiansen@woohoo.com	Nashville	Tennessee	4603180612843400	a8f325a772883ee4476b54aa4e62dbcc	Maestro	36.2296691489063178	-86.8476831969711895
46062	2020-08-19 02:07:27	2020-08-19	Rosey Dibbert	rosey.dibbert@geemail.com	Los Angeles	California	869980882248574851	5b719c167ff4aef2289169e1555a2497	Discover	34.0475202920246858	-118.383854843721906
46063	2020-08-19 02:16:24	2020-08-19	Olivine Hilll	olivine.hilll@geemail.com	Lubbock	Texas	561207325926025	72fbd225647132e30c921cd0075172f6	VISA 16 digit	33.5990135707002153	-101.923276662352308
46064	2020-08-19 02:18:28	2020-08-19	Vern Dicki I	vern.dicki.i@geemail.com	Chicago	Illinois	4691029114448130	fe9de7bcc23bf9537c79534cf213c73b	American Express	41.7497326721273367	-87.6706770761433916
46065	2020-08-19 02:20:52	2020-08-19	Dr. Carmelo Senger	dr.carmelo.senger@woohoo.com	Oakland	California	4996835710558	9d3cd8490bc27e8a7040416aee12659f	Discover	37.8314538847673418	-122.284819165185681
46066	2020-08-19 02:24:47	2020-08-19	Raymond Zboncak	raymond.zboncak@geemail.com	New Orleans	Louisiana	4779470921414474	dbc582ed513e2f3b399d8b4a3106f613	Mastercard	30.1142593301381929	-89.8915100455079283
46067	2020-08-19 02:37:03	2020-08-19	Barney Adams	barney.adams@geemail.com	Springfield	Missouri	869985146993441707	0c566ea8a56adf6a487572f460fd5165	Diners Club / Carte Blanche	37.1537795430243065	-93.2308711028017143
46068	2020-08-19 02:40:56	2020-08-19	Bree Kessler-Breitenberg	bree.kessler.breitenberg@geemail.com	Pittsburgh	Pennsylvania	675922892341508	a84ac6f0fd7da3c6f1165aad6047d9c1	Diners Club / Carte Blanche	40.4294253962069732	-80.0680638055022911
46069	2020-08-19 02:46:49	2020-08-19	Ms. Lexus Gottlieb MD	ms.lexus.gottlieb.md@warmmail.com	Phoenix	Arizona	3528509444535621540	76ed2ff3da9c75e3ca33101f81029f0c	VISA 16 digit	33.5586107619971088	-112.168530509148169
46070	2020-08-19 02:47:23	2020-08-19	Marie Stanton DVM	marie.stanton.dvm@geemail.com	Roseville	California	3713744835882406	0deb5147fc216df6b343ce4aa968d348	JCB 16 digit	38.8328578332029295	-121.314969132536646
46071	2020-08-19 02:48:23	2020-08-19	Malinda Glover	malinda.glover@geemail.com	Washington	District of Columbia	4551222206500889	7dd2b1551bcaf544949e132aac157bc4	VISA 16 digit	38.9742816868502615	-76.919946429294356
46072	2020-08-19 02:49:49	2020-08-19	Isaiah Streich	isaiah.streich@geemail.com	Fresno	California	3799037866450251	c2405ea9849f7f7068716d0b7a1a65e5	Voyager	36.8369893522340774	-119.723283181024343
46073	2020-08-19 02:57:49	2020-08-19	Roselyn Emmerich	roselyn.emmerich@geemail.com	Tampa	Florida	869995283812576591	65d4e6829e804c1b7d9bc763a108e897	VISA 16 digit	27.9798043804358691	-82.5247511711649508
46074	2020-08-19 03:17:29	2020-08-19	Mrs. Onie Hauck DVM	mrs.onie.hauck.dvm@geemail.com	Modesto	California	869921405692210814	24a884a517ddf56b81ec60294f07ce34	Diners Club / Carte Blanche	37.5881028653588203	-121.044894240444521
46075	2020-08-19 03:45:17	2020-08-19	Dr. Wallace Jaskolski	dr.wallace.jaskolski@geemail.com	Bakersfield	California	6011056873903242454	f5bfe84826d0b2e51a9be19da2001c0d	JCB 15 digit	35.3625155752234122	-118.932866420065238
46076	2020-08-19 03:52:43	2020-08-19	Claudie Schimmel Sr.	claudie.schimmel.sr.@geemail.com	San Antonio	Texas	6011583580598593842	630b962196aa2742446b2a2e8b59e5df	VISA 13 digit	29.4639536272339519	-98.5433249221019452
46077	2020-08-19 03:53:02	2020-08-19	Sabina Gaylord	sabina.gaylord@geemail.com	Evansville	Indiana	4340137382685	7c6eeed2ddacdc184135f2cff5ce544a	VISA 16 digit	37.9337715570952696	-87.4531615273959915
46078	2020-08-19 04:14:38	2020-08-19	Mr. Dexter Conn II	mr.dexter.conn.ii@geemail.com	Phoenix	Arizona	6011729577534865057	0bacc942232bc82bdcc23f3226d2562b	VISA 13 digit	33.6420470496106887	-112.135398450719578
46079	2020-08-19 04:19:25	2020-08-19	Kenji Schneider III	kenji.schneider.iii@warmmail.com	San Diego	California	060403609356344	a2965f1de6ce89212e56b36d8f41a782	American Express	32.8498979363191879	-117.231868655364963
46080	2020-08-19 04:34:38	2020-08-19	Una Deckow DDS	una.deckow.dds@geemail.com	San Francisco	California	4492297464900	4e87520082ab71e39737a171490d172a	Diners Club / Carte Blanche	37.7178867011972017	-122.443105863662851
46081	2020-08-19 04:36:31	2020-08-19	Emma Bahringer-O'Connell	emma.bahringer.o'connell@geemail.com	Fremont	California	6011901080638948242	a61d6a8cc8a452a4b4d3022a08597033	VISA 16 digit	37.486662273591385	-121.921652252971001
46082	2020-08-19 04:48:49	2020-08-19	Joel Gerhold III	joel.gerhold.iii@woohoo.com	Athens	Georgia	55595272328524166	811de4fd83930665e781a7ba496cfebc	Diners Club / Carte Blanche	33.8869397728428225	-83.3712874862480788
46083	2020-08-19 04:55:08	2020-08-19	Samira Zboncak	samira.zboncak@geemail.com	Santa Ana	California	3415087565590155	294fb36713b470ecd425bcb75e86774d	Diners Club / Carte Blanche	33.6457394142273785	-117.915055731117718
46084	2020-08-19 04:55:51	2020-08-19	Oneal Kirlin	oneal.kirlin@geemail.com	Mobile	Alabama	3414495592836767	d42e434625452907e5087bce441cff3c	Discover	30.7337438838664418	-88.1124512854170092
46085	2020-08-19 04:58:55	2020-08-19	Dane Leffler	dane.leffler@geemail.com	Fontana	California	6011998734369320559	78561b5c4cc9b25a5dc1524193a47d20	Diners Club / Carte Blanche	34.1992109971735658	-117.469004201683774
46086	2020-08-19 05:01:15	2020-08-19	Columbus Reynolds	columbus.reynolds@geemail.com	Lakewood	Colorado	3448213210919398	7c7d98cee699696ce30c661ab7359b52	Discover	39.7721735739089581	-105.069332440618794
46087	2020-08-19 05:11:26	2020-08-19	Ms. Dasia Miller MD	ms.dasia.miller.md@geemail.com	Lafayette	Louisiana	4938340386334	787e906da7cc488328480d71a2418af6	Voyager	30.2134786789748802	-92.0178222157843351
46088	2020-08-19 05:17:10	2020-08-19	Adam Vandervort Jr.	adam.vandervort.jr.@geemail.com	Birmingham	Alabama	4822587522977208	53cf119cfca6bd9408558a048fef64eb	Discover	33.6072845030367375	-86.8510004153251742
46089	2020-08-19 05:18:51	2020-08-19	Micayla Gutkowski MD	micayla.gutkowski.md@geemail.com	New York	New York	180012247949064888	b49cbba1d1dee3334385775d16915588	American Express	40.6927386007029526	-73.9551895364548955
46090	2020-08-19 05:22:04	2020-08-19	Willard Greenholt	willard.greenholt@geemail.com	Stamford	Connecticut	6011453726253704482	f0d2943b9cda638aa6f4af4cf272cd6a	Maestro	41.1187342367950848	-73.6055075818244404
46091	2020-08-19 05:25:25	2020-08-19	Ted Armstrong-Rosenbaum	ted.armstrong.rosenbaum@geemail.com	Jersey City	New Jersey	676372373905172	9c71c43599601282193c82944fbe942c	American Express	40.6373506443515424	-74.0600301593031816
46092	2020-08-19 05:31:55	2020-08-19	Mr. Alvis Quigley	mr.alvis.quigley@geemail.com	San Francisco	California	4574494917317	71f4e8c81d18675912af79956a7928d0	Discover	37.7856250514900083	-122.446379225013715
46093	2020-08-19 05:35:54	2020-08-19	Jordyn Bayer DVM	jordyn.bayer.dvm@geemail.com	Oakland	California	51331056685147789	5147f95060804d6b39424c47e12ee023	JCB 15 digit	37.7889921680831051	-122.253047937418046
46094	2020-08-19 05:37:22	2020-08-19	Grant Herman V	grant.herman.v@woohoo.com	Miramar	Florida	6011405533299169921	0c99524e203344af0ebbb2d35ab026bd	VISA 16 digit	25.8863662082217623	-80.4107723079148684
46095	2020-08-19 05:38:51	2020-08-19	Nallely Ortiz DVM	nallely.ortiz.dvm@geemail.com	Inglewood	California	3715967832226057	ec68e0686200c4048ac8bf247d11781a	JCB 15 digit	33.8861834133289719	-118.345845905135576
46096	2020-08-19 05:41:09	2020-08-19	Chester Streich	chester.streich@geemail.com	Thornton	Colorado	3055930275239385	f8fe5cce1b5423c807a1a421ca67bbfc	VISA 16 digit	40.0150414411310109	-104.916579677227148
46097	2020-08-19 05:47:11	2020-08-19	Dr. Michal Dibbert	dr.michal.dibbert@geemail.com	Greeley	Colorado	676389428359692	3a268b8fa9f23235294749e25793ab89	Diners Club / Carte Blanche	40.3303626007001839	-104.694851540292433
46098	2020-08-19 05:52:10	2020-08-19	Thompson Farrell	thompson.farrell@geemail.com	San Francisco	California	3337884321601579387	fac3c80557033069732ae0e45716e391	American Express	37.8032186991472514	-122.405528548293191
46099	2020-08-19 06:03:30	2020-08-19	Mr. Tyrel Runolfsson	mr.tyrel.runolfsson@geemail.com	Houston	Texas	54415320600007216	cc88284a68fea96371f498a225956349	VISA 13 digit	29.7123215028628707	-95.4132782865330569
46100	2020-08-19 06:08:43	2020-08-19	Candy Kris-Howe	candy.kris.howe@geemail.com	Washington	District of Columbia	3112230759495745153	6e68cb23a32bceb25be93075ed3b74f3	JCB 16 digit	38.8971053847841901	-77.0205941106870853
46101	2020-08-19 06:14:09	2020-08-19	Evita Pfannerstill-Gottlieb	evita.pfannerstill.gottlieb@geemail.com	Rancho Cucamonga	California	3744521253107109	04aec20b331428045de30f8331e18dd1	JCB 16 digit	34.148525632218643	-117.500374167972055
46102	2020-08-19 06:25:12	2020-08-19	Mr. Ean Fisher DDS	mr.ean.fisher.dds@geemail.com	San Diego	California	4763082091720917	ca789bca197f7bbd10ec2c5a99fdb068	Mastercard	32.8815245362997075	-117.08428243877367
46103	2020-08-19 06:27:49	2020-08-19	Denise Larkin	denise.larkin@geemail.com	Jacksonville	Florida	53449435749213861	e186d6065244d6b449df4bf4cb53ce05	Discover	30.2976037378475063	-81.6110485068135034
46104	2020-08-19 06:31:02	2020-08-19	Mrs. Milan Dickens	mrs.milan.dickens@geemail.com	New York	New York	869999381710363017	10d2f879b21ca4c6463da873e36ef03b	VISA 16 digit	40.6679486871920517	-73.965481374542037
46105	2020-08-19 06:53:17	2020-08-19	Brianne Krajcik	brianne.krajcik@woohoo.com	Norfolk	Virginia	869959095758437545	e1163c98d630da0293b2933347cfb269	Diners Club / Carte Blanche	36.961733620010321	-76.2934360299728809
46106	2020-08-19 06:56:06	2020-08-19	Yaakov Padberg	yaakov.padberg@geemail.com	San Diego	California	180047330624526550	ec24b14ece6b7d40234d169fe6e44e92	VISA 13 digit	32.8115504080496763	-117.112036907244473
46107	2020-08-19 06:57:19	2020-08-19	Shirl Pfeffer DVM	shirl.pfeffer.dvm@geemail.com	New York	New York	3042747117175129	75067a28dc652b674f9730a1781d3714	VISA 13 digit	40.6618382590115033	-73.9094223451230619
46108	2020-08-19 07:00:10	2020-08-19	Essa Bednar	essa.bednar@woohoo.com	Cape Coral	Florida	3337214000727611065	a2fd14d2390e49587b9f0dd2b6aa57df	Mastercard	26.7424195785045633	-82.0723514534138161
46109	2020-08-19 07:03:30	2020-08-19	Harvy Howe	harvy.howe@geemail.com	Berkeley	California	6011710675812513265	3b911e27d8951669f51872f79743a9a2	VISA 16 digit	37.8521847723956384	-122.248366693899399
46110	2020-08-19 07:13:33	2020-08-19	Dr. Kylene Hahn	dr.kylene.hahn@geemail.com	New York	New York	3528513811892443375	207cfa3d7310d5740d07478a85255ea9	Voyager	40.6125453631151458	-73.8901337921515022
46111	2020-08-19 07:14:34	2020-08-19	Ciera Hessel	ciera.hessel@warmmail.com	Worcester	Massachusetts	210048016364241018	a055f8a7fd9eb73f460b703a938a30b4	VISA 13 digit	42.3403934606052914	-71.811064229837811
46112	2020-08-19 07:19:52	2020-08-19	Elouise Fisher-Frami	elouise.fisher.frami@warmmail.com	Boston	Massachusetts	3001466879237552	5549e6ea9644bb907517c69c1b7a8e56	Diners Club / Carte Blanche	42.3226025586184136	-71.1152592883396863
46113	2020-08-19 07:21:44	2020-08-19	Lenore Nicolas	lenore.nicolas@geemail.com	Berkeley	California	3018447117698667	be72101437f6d55c6f5ffad94f3af796	Discover	37.8910632523667701	-122.274207481511169
46114	2020-08-19 07:24:19	2020-08-19	Leonor Reinger PhD	leonor.reinger.phd@woohoo.com	Phoenix	Arizona	4346577094020468	6501c14a1b069a1ea9f753488e6ebd45	VISA 16 digit	33.5288320305690206	-112.001107986776532
46115	2020-08-19 07:31:12	2020-08-19	Mr. Franklin Windler	mr.franklin.windler@geemail.com	San Francisco	California	4209339489103	3372142aff3057d0beb7bb29005f3e65	VISA 13 digit	37.8041915237236097	-122.421172972613135
46116	2020-08-19 07:32:17	2020-08-19	Buffy Gerlach-McCullough	buffy.gerlach.mccullough@geemail.com	Houston	Texas	53031366782253320	c6d81ce7f57e02b2fb74e54a7ee0823b	Maestro	29.8600987795352921	-95.3861390226535519
46117	2020-08-19 07:33:44	2020-08-19	Ms. Antionette Corkery	ms.antionette.corkery@geemail.com	Gilbert	Arizona	869911972861859301	c408cad2302f592d04b8616da51350a2	VISA 13 digit	33.4051133666068267	-111.842074930681292
46118	2020-08-19 07:34:36	2020-08-19	Landon Ruecker	landon.ruecker@geemail.com	San Jose	California	3438699072589224	3117ac08e24a8f894a21f3b1c7f3fbe0	Voyager	37.3755322040345561	-121.811624819714197
46119	2020-08-19 07:37:47	2020-08-19	Marinda Stracke	marinda.stracke@geemail.com	Baltimore	Maryland	3760015655429319	b0195b71205ada209050d38c685142d6	Discover	39.3866333597339633	-76.557440981550144
46120	2020-08-19 07:46:49	2020-08-19	Caesar Hilll	caesar.hilll@woohoo.com	Indianapolis	Indiana	3528151301891350182	0d98d787f9591a1c23fc71fbacf4ddf6	Voyager	39.801080396353079	-86.1182699703812631
46121	2020-08-19 07:47:07	2020-08-19	Camille Kohler DVM	camille.kohler.dvm@geemail.com	New York	New York	869959245562770157	cc890f9134bd06e842d45051c1795b8a	VISA 13 digit	40.6596110148578873	-74.0233613575238678
46122	2020-08-19 07:48:58	2020-08-19	Clara Durgan	clara.durgan@warmmail.com	Des Moines	Iowa	3528821975807000823	8c70e26724afc2e776bb675649e1f2f2	Discover	41.4955922061786069	-93.6875525618482499
46123	2020-08-19 07:55:33	2020-08-19	Ozzie Sporer	ozzie.sporer@geemail.com	Fresno	California	3038860357192862	c1ab4e0e0a108f7de1cbfb4e954ba16b	Diners Club / Carte Blanche	36.7239017787728486	-119.870230189162868
46124	2020-08-19 08:06:31	2020-08-19	Minor Moen	minor.moen@geemail.com	New York	New York	676133052009264	3a07497f30f23fcb5677c0e3fdba6730	Maestro	40.6692889781426601	-74.0117997306760316
46125	2020-08-19 08:13:01	2020-08-19	Dr. Lowell Maggio	dr.lowell.maggio@geemail.com	Austin	Texas	3528620933299110603	5bd1d4ca3fc686e3be5348e78248cbb3	American Express	30.4025352499108763	-97.6844830472726358
46126	2020-08-19 08:14:11	2020-08-19	Eulalia Sporer-Pacocha	eulalia.sporer.pacocha@geemail.com	Fresno	California	6011689750290447596	8d749defc8b8db410e7c1ad5ddc89a49	JCB 15 digit	36.7176318830683854	-119.746264063996833
46127	2020-08-19 08:15:22	2020-08-19	Regena Bosco	regena.bosco@geemail.com	Minneapolis	Minnesota	3415170061061770	96be4e00c0522064b0bc14752fc5f6ce	Diners Club / Carte Blanche	44.9535775091584711	-93.2523619082562618
46128	2020-08-19 08:22:46	2020-08-19	Howell Hermann	howell.hermann@woohoo.com	Philadelphia	Pennsylvania	51207406425982451	c19e20551ff83fc852917ecea78bf2c5	VISA 16 digit	40.0337298648856574	-75.2160765233814743
46129	2020-08-19 08:31:02	2020-08-19	Dr. Wallace Johnston PhD	dr.wallace.johnston.phd@woohoo.com	New York	New York	55108641065509152	43339b78da520edf316719a1ff99e003	JCB 16 digit	40.647719143306837	-73.9016522448405624
46130	2020-08-19 08:37:43	2020-08-19	Tawny Price DVM	tawny.price.dvm@woohoo.com	Rialto	California	3112540565924259236	1dc8f803bacf746550026bc9d3d2395c	American Express	34.1112566089008027	-117.471861202837161
46131	2020-08-19 08:42:03	2020-08-19	Jaiden Kutch-White	jaiden.kutch.white@geemail.com	Palmdale	California	4304915510986161	27e86f60db2e100a568663c085a1539b	Voyager	34.6493431428298351	-118.13556339330934
46132	2020-08-19 08:42:39	2020-08-19	Kasey Hammes	kasey.hammes@geemail.com	Carlsbad	California	3734817134720074	83f5ec9833a5c06390a92dc4561cc8f1	VISA 13 digit	33.1683295202847575	-117.233464524221787
46133	2020-08-19 08:46:11	2020-08-19	Elba Turcotte	elba.turcotte@geemail.com	Sterling Heights	Michigan	3015505993333585	02867b3403a14eb46f5f437df556b098	VISA 16 digit	42.5028765919234601	-82.9909601143721432
46134	2020-08-19 08:48:52	2020-08-19	Yee Altenwerth	yee.altenwerth@warmmail.com	San Francisco	California	869903747029163618	2f68c91d0630675683e1d7946384c836	Maestro	37.7698399900428043	-122.418202545582844
46135	2020-08-19 09:03:37	2020-08-19	Tab McLaughlin	tab.mclaughlin@geemail.com	Shreveport	Louisiana	3025664661829604	872f1ac020ebfd90156001fcbfe44ffd	American Express	32.4733961160067466	-93.7487424032974985
46136	2020-08-19 09:05:42	2020-08-19	Dr. Arlen Schuster	dr.arlen.schuster@warmmail.com	McAllen	Texas	060482705398434	48ecaddbfe1a28f4f1a7214b79bc5582	Voyager	26.1887153963398163	-98.1875124933045242
46137	2020-08-19 09:06:15	2020-08-19	Alethea Mann MD	alethea.mann.md@warmmail.com	Los Angeles	California	51985414768566368	cff993db85f9dd40d75b590c9c5c1dee	Voyager	33.9564783307123932	-118.361982918949053
46138	2020-08-19 09:12:47	2020-08-19	Leisa Dooley	leisa.dooley@geemail.com	Alexandria	Virginia	4660918443533	313c9951cc060350b0e31121f6ceda67	American Express	38.7798087277565102	-77.1274921928983304
46139	2020-08-19 09:22:14	2020-08-19	Mr. Holland Champlin	mr.holland.champlin@geemail.com	San Bernardino	California	6011765437866641490	c55f676347a7e20a2b6dddfb60b379ef	Diners Club / Carte Blanche	34.1947796094030139	-117.219719140163065
46140	2020-08-19 09:26:21	2020-08-19	Deryl Mann	deryl.mann@geemail.com	Minneapolis	Minnesota	180024386125682653	f52b575ca34462b0c8a5ccf0d40ea7db	JCB 16 digit	44.9591077228162419	-93.2991201195672062
46141	2020-08-19 09:29:54	2020-08-19	Dr. Martez Armstrong Jr.	dr.martez.armstrong.jr.@geemail.com	Tulsa	Oklahoma	6011692271416216810	b5f6fff07eeed8da0bdf6045b6039150	JCB 16 digit	36.1091167937401636	-95.9046799554444789
46142	2020-08-19 09:30:46	2020-08-19	Mr. Duard Greenholt DDS	mr.duard.greenholt.dds@warmmail.com	Palmdale	California	210027314460090982	1b740973738d3e6ac65b8d23fd578265	VISA 13 digit	34.5234308075942096	-118.050934854289153
46143	2020-08-19 09:55:27	2020-08-19	Arturo Rippin-Schultz	arturo.rippin.schultz@geemail.com	Westminster	Colorado	561282107810648	0c18fc7ba97726b37c8b46f617c67aeb	Voyager	39.9052181201361122	-105.121077031377339
46144	2020-08-19 10:04:09	2020-08-19	Joline Batz-Morissette	joline.batz.morissette@geemail.com	Sugar Land	Texas	3088960342075044242	b5020efc06d06e8235e86c9d47d9d9a2	VISA 16 digit	29.6203779606200754	-95.7051412821289063
46145	2020-08-19 10:04:35	2020-08-19	Arlie Dickinson	arlie.dickinson@geemail.com	Boston	Massachusetts	3041729560769336	84c6b59cad55664eda290c0694d74d5d	American Express	42.4291646308433243	-71.0079596965525326
46146	2020-08-19 10:05:02	2020-08-19	Braeden Von	braeden.von@geemail.com	Portland	Oregon	676159358660484	f5b422086639e23593ae1cb1cd2c00de	VISA 16 digit	45.4387080918885786	-122.728984406124809
46147	2020-08-19 10:26:20	2020-08-19	Rex Beatty	rex.beatty@geemail.com	Fort Worth	Texas	869935424741147053	fe35676b1e4b03e954eb426e06ae35f9	Maestro	32.7362447287943255	-97.3883969092097175
46148	2020-08-19 10:26:34	2020-08-19	Tella Rice	tella.rice@warmmail.com	Clarksville	Tennessee	3019794995628400	8321a51a7626038e37b32d2eb66b4e6f	VISA 16 digit	36.6033831943418875	-87.3989469755392605
46149	2020-08-19 10:31:25	2020-08-19	Lavina Leuschke	lavina.leuschke@woohoo.com	New York	New York	4723340812532816	9588530e499727186cb59901925207d1	VISA 13 digit	40.7344749331697784	-73.8943662679649833
46150	2020-08-19 10:35:11	2020-08-19	Bradly Anderson	bradly.anderson@warmmail.com	Scottsdale	Arizona	3528471717766389992	d3d8d5b0c44e77719920123dca657d46	Voyager	33.7416266022372966	-111.841788215605902
46151	2020-08-19 10:44:06	2020-08-19	Lary O'Conner	lary.o'conner@geemail.com	West Palm Beach	Florida	6011652000633390878	b902e549dce32e9d4eae56ba0fa8db02	JCB 16 digit	26.797686752708259	-80.1429710833657509
46152	2020-08-19 10:47:44	2020-08-19	Mr. Javion Larson I	mr.javion.larson.i@warmmail.com	Newport News	Virginia	869965710786999447	9e6b576578e6aa4a2e4381a06768eefe	JCB 16 digit	37.1445813082054244	-76.4822377131581419
46153	2020-08-19 10:50:04	2020-08-19	Donovan Schultz	donovan.schultz@geemail.com	New York	New York	3421510443312197	804ccb35a10118277322e765a3bfeaab	JCB 16 digit	40.5680236437115838	-73.8801405124261947
46154	2020-08-19 10:51:42	2020-08-19	Dellar Feest-Abshire	dellar.feest.abshire@warmmail.com	Oakland	California	3441251645120569	35c73efff107d822ed981064f56d5c33	VISA 16 digit	37.7678488210713255	-122.302262967803301
46155	2020-08-19 10:52:55	2020-08-19	Brook Stokes PhD	brook.stokes.phd@geemail.com	San Jose	California	3051247021851809	09e4ecb3260937112b31552301daa589	VISA 16 digit	37.2835599040433792	-121.906854089511185
46156	2020-08-19 10:57:08	2020-08-19	Kiya Parker PhD	kiya.parker.phd@geemail.com	Coral Springs	Florida	3112524835764477259	037a57a6851d9f35ca5876be3f9bc092	Diners Club / Carte Blanche	26.2841776824153968	-80.2076260230161182
46157	2020-08-19 10:57:35	2020-08-19	Dr. Zela DuBuque	dr.zela.dubuque@geemail.com	San Francisco	California	3528750950463592079	fc76483ccdd6fbe869bebf6691a5acfd	VISA 16 digit	37.7843099063348973	-122.430217306422307
46158	2020-08-19 11:18:31	2020-08-19	Francisca O'Conner	francisca.o'conner@geemail.com	Philadelphia	Pennsylvania	3158038288383860910	154c7cfb0da2b8d037f5becd5ad80763	Maestro	39.9228906895924354	-75.1445501734402086
46159	2020-08-19 11:29:55	2020-08-19	Rylan Stanton	rylan.stanton@geemail.com	Lafayette	Louisiana	501813829629057	4945b5ab1fce3a7192459219295f4aa4	JCB 16 digit	30.2766417792975915	-91.9463416996262879
46160	2020-08-19 11:34:57	2020-08-19	Hasel Kertzmann	hasel.kertzmann@geemail.com	Sacramento	California	4116854971839	dfbb99a0703d07649992c6b0024d9c8f	JCB 16 digit	38.5743516433782858	-121.437842261024187
46161	2020-08-19 11:37:08	2020-08-19	Nichelle McGlynn	nichelle.mcglynn@geemail.com	San Francisco	California	3158351053426457598	a5e41500aab8dd2eef3e46fdb426a456	Diners Club / Carte Blanche	37.7406962326439626	-122.420102842398535
46162	2020-08-19 11:56:04	2020-08-19	Berenice Nicolas	berenice.nicolas@warmmail.com	Henderson	Nevada	180081770832997167	b295189672beb97cae3f2dcd83e37acd	JCB 16 digit	35.9787573057625494	-115.092276815759774
46163	2020-08-19 12:03:47	2020-08-19	Orin Leannon V	orin.leannon.v@geemail.com	Henderson	Nevada	3158711557516109641	0b37a46bb4a1ae1934f0d99ed9a0b9a4	JCB 16 digit	35.9131763185773067	-115.027703457667315
46164	2020-08-19 12:04:32	2020-08-19	Ms. Mozelle Fadel	ms.mozelle.fadel@geemail.com	Akron	Ohio	3019856045236144	2d6de39268cc983f721c92143573b26c	Voyager	41.1390219222120948	-81.5790526863034842
46165	2020-08-19 12:04:54	2020-08-19	Kenyon Weimann-Dare	kenyon.weimann.dare@geemail.com	Austin	Texas	180027380589629554	715d8b81551a655e9a0be617684e69be	Diners Club / Carte Blanche	30.2784567919686438	-97.8264277658663701
46166	2020-08-19 12:07:45	2020-08-19	Dwain Funk	dwain.funk@geemail.com	Irvine	California	3158676326069107102	6ad518ea82eb990533cabcc7ff4c31ae	Diners Club / Carte Blanche	33.675843530615424	-117.721469826904311
46167	2020-08-19 12:08:49	2020-08-19	Robley Runte	robley.runte@geemail.com	Meridian	Idaho	869993051128825545	e190e6f8d4895bb811b32b0fec18227f	Maestro	43.6198354163214503	-116.473005085385964
46168	2020-08-19 12:14:13	2020-08-19	Dion Shields	dion.shields@woohoo.com	Murrieta	California	4168229368011493	42152b30e82cf7180697859d3e798a05	Maestro	33.6703194327749316	-117.218835993334281
46169	2020-08-19 12:16:59	2020-08-19	Dorman Stoltenberg	dorman.stoltenberg@geemail.com	Omaha	Nebraska	676291758633795	f1b6a032eefc404323cd379078eb4881	JCB 16 digit	41.2446714804187451	-96.0295522624276572
46170	2020-08-19 12:18:04	2020-08-19	Guilford Stokes	guilford.stokes@warmmail.com	Orange	California	4211045387712029	b6acee4ca3564e3a594d6c229a9028a8	Voyager	33.7585337838977537	-117.861512879804891
46171	2020-08-19 12:31:13	2020-08-19	Winthrop Wehner	winthrop.wehner@warmmail.com	San Francisco	California	6011104609935924236	82234c9135de5a38ba913d88c1108e1f	VISA 13 digit	37.7592577932280733	-122.450191381826386
46172	2020-08-19 12:36:41	2020-08-19	Paulette King	paulette.king@geemail.com	Chicago	Illinois	675982608642581	e3fa35f99bb7e8db74c0e9dc8878db25	Maestro	41.7938540822196742	-87.7364681480016486
46173	2020-08-19 12:38:55	2020-08-19	Dr. Edsel Armstrong	dr.edsel.armstrong@warmmail.com	Madison	Wisconsin	3043748889873932	4ee32fa12d0deea6b1b95bc5b86d34ec	JCB 16 digit	43.1330094233594821	-89.5296284765821042
46174	2020-08-19 12:41:24	2020-08-19	Williams Kihn-Lueilwitz	williams.kihn.lueilwitz@geemail.com	San Diego	California	6011001061795625897	22a0107f0336d6bc6ec3757f33db7141	American Express	32.8871746748752898	-117.227551548173651
46175	2020-08-19 12:49:32	2020-08-19	Sadie O'Connell	sadie.o'connell@woohoo.com	Phoenix	Arizona	3052709488112727	e1f8d702fcd04cfc63e4c92383413e45	American Express	33.5767574026647964	-112.155604090581093
46176	2020-08-19 12:51:38	2020-08-19	Mr. Raul Rau Jr.	mr.raul.rau.jr.@warmmail.com	Columbus	Ohio	6011250813194677103	90e850cb49fa30774ddb56bb3db57760	VISA 16 digit	40.0631284790158233	-83.0820752770409001
46177	2020-08-19 12:54:24	2020-08-19	Mrs. Kirsten Roob	mrs.kirsten.roob@woohoo.com	San Francisco	California	210024339733732972	533f35dd91c57445e0b220ffad482296	VISA 13 digit	37.7640242940049973	-122.421815319395549
46178	2020-08-19 12:57:21	2020-08-19	Ragna Ward DDS	ragna.ward.dds@geemail.com	Oakland	California	180024990752463533	45b89666080630a08459a80cf7471bd1	Mastercard	37.7944982386371748	-122.291776478159193
46179	2020-08-19 13:01:31	2020-08-19	Shemar Upton Sr.	shemar.upton.sr.@geemail.com	Memphis	Tennessee	3096333270970851934	cfd7b4bb3aac3f2d3c91a1e6e10b232c	Discover	35.1519764570120756	-90.0437879937026651
46180	2020-08-19 13:15:17	2020-08-19	Isabella Mayert	isabella.mayert@geemail.com	San Francisco	California	6011583566670252407	c70d1c1211a443f6a966fe3253616e5e	Diners Club / Carte Blanche	37.767659589938205	-122.422987367010705
46181	2020-08-19 13:19:39	2020-08-19	Kelan Auer DVM	kelan.auer.dvm@woohoo.com	Omaha	Nebraska	55437043447552376	10336d0e566071981fccb1a56622462f	Diners Club / Carte Blanche	41.322351019331812	-96.0582956300698214
46182	2020-08-19 13:23:36	2020-08-19	Jinnie Jenkins	jinnie.jenkins@geemail.com	Tucson	Arizona	6011991617897335511	0a5e918d56728482909a5980d12f72b3	Mastercard	32.2465577499981961	-110.906925669847425
46183	2020-08-19 13:28:29	2020-08-19	Randall White	randall.white@geemail.com	Fullerton	California	4745472410562400	f4df58fd558749916a51bf9e1be114e5	Discover	33.9467758455470232	-117.926935578530646
46184	2020-08-19 13:39:47	2020-08-19	Byrd Kessler	byrd.kessler@warmmail.com	New Haven	Connecticut	676286074903559	7f8b438af79a4951d17245f3daa5b693	VISA 16 digit	41.2251288588617015	-72.8641992348711938
46185	2020-08-19 13:46:01	2020-08-19	Donta Bartoletti-Cummerata	donta.bartoletti.cummerata@geemail.com	Birmingham	Alabama	180071133843915680	64bf6d7ecf3631f99015b6df33858a91	Voyager	33.4462225543592098	-86.7759150385167572
46186	2020-08-19 13:50:15	2020-08-19	Lupe Barton	lupe.barton@warmmail.com	New York	New York	4134979965084910	3fd81d4fd46f3acf1112fa3bd8366226	Diners Club / Carte Blanche	40.7108757606465375	-73.9477517489239489
46187	2020-08-19 14:04:02	2020-08-19	Marquita Kuhic	marquita.kuhic@geemail.com	Minneapolis	Minnesota	3000385647055172	5c1f6302503f6dbf387c6dda62a57d3c	American Express	44.8818524866916206	-93.2643855159908526
46188	2020-08-19 14:08:47	2020-08-19	Lorene Stokes	lorene.stokes@geemail.com	Jacksonville	Florida	4630332624109	481350b4643a9c6279c2c058e41ff755	VISA 16 digit	30.349617275321485	-81.5810846037775406
46189	2020-08-19 14:09:14	2020-08-19	Tristen Satterfield	tristen.satterfield@woohoo.com	Huntsville	Alabama	4544401828301526	368c00754a80bc018b61da63b2c919e6	Maestro	34.7059454000797132	-86.7354896281398879
46190	2020-08-19 14:13:59	2020-08-19	Salvador Spinka	salvador.spinka@geemail.com	Phoenix	Arizona	4031268636001675	3f0f2b9e8b6e0bb172e0da9441dc6e72	VISA 16 digit	33.5162896317828469	-111.992550334141043
46191	2020-08-19 14:23:23	2020-08-19	Dr. Cedric Dibbert DVM	dr.cedric.dibbert.dvm@woohoo.com	Stockton	California	3337242239008078794	c7afe50e0d0075cfa53cc06367d27b81	VISA 13 digit	37.9918712278094191	-121.353975712656222
46192	2020-08-19 14:24:07	2020-08-19	Mina Sawayn	mina.sawayn@warmmail.com	San Francisco	California	210052115460291175	18ba335effe561e8911fd9189744f527	JCB 16 digit	37.8239313415178344	-122.411420980748176
46193	2020-08-19 14:26:14	2020-08-19	Floy Mosciski	floy.mosciski@warmmail.com	Miramar	Florida	3448219497050047	d2f2b1610b61b263355cfc08d1fd8ce1	Voyager	25.9603768367767351	-80.4058734577607481
46194	2020-08-19 14:32:10	2020-08-19	Dann Keebler	dann.keebler@geemail.com	Fort Worth	Texas	4926944601242845	eacba9ff5f04815e1712305511f1a88b	JCB 15 digit	32.822498314414176	-97.3784020065151168
46195	2020-08-19 14:32:27	2020-08-19	Rubie Leuschke DVM	rubie.leuschke.dvm@warmmail.com	Hayward	California	3452238195789303	1b9e92ea46fd53670e6e7cc06c404cd9	VISA 16 digit	37.6163347929704983	-122.108187633545697
46196	2020-08-19 14:50:58	2020-08-19	Ms. Bella Haag	ms.bella.haag@geemail.com	Los Angeles	California	4394254786956091	45c51e93df34651d8334c92282200265	VISA 13 digit	34.0312293760344389	-118.384275280357514
46197	2020-08-19 14:51:50	2020-08-19	Scarlet Hills	scarlet.hills@geemail.com	Overland Park	Kansas	4685313341917	91aacc7ab84d371a4a0b58ce390e9e8b	VISA 16 digit	38.9140661958474681	-94.6977688028052427
46198	2020-08-19 14:53:10	2020-08-19	Rodney Friesen	rodney.friesen@geemail.com	Los Angeles	California	6011154037891418812	b17a71d9a52bc08d1a5368c3ce062068	Diners Club / Carte Blanche	33.9998034221917393	-118.476226605613903
46199	2020-08-19 14:54:53	2020-08-19	Casandra Purdy DVM	casandra.purdy.dvm@geemail.com	Saint Paul	Minnesota	3048341173338047	5be735fc3edbf5aacabedf16a4e21059	Discover	44.9040951960194903	-93.0730661072101526
46200	2020-08-19 15:02:42	2020-08-19	Clytie Koss	clytie.koss@geemail.com	Phoenix	Arizona	51826308396229162	217b6c46bd18ed4cd2800a1876b4c5f0	Discover	33.6125868040535636	-112.121039868045983
46201	2020-08-19 15:26:13	2020-08-19	Adria Schumm	adria.schumm@geemail.com	Vallejo	California	3337793380884377422	477147e607fbe21ee4a9eff21ecce88a	Discover	38.126085948440803	-122.298420473175113
46202	2020-08-19 15:29:48	2020-08-19	Dr. Lynnette Weimann	dr.lynnette.weimann@geemail.com	Denver	Colorado	4475708606765588	0486caa1062c8b057494564bb7bf31f0	JCB 16 digit	39.8442250430170404	-104.897566664522884
46203	2020-08-19 15:32:42	2020-08-19	Regis Hauck IV	regis.hauck.iv@geemail.com	New York	New York	3528629995831683562	350c16e457e2c98ea21e89c6943da3b7	VISA 16 digit	40.6273807535171514	-73.95128762124925
46204	2020-08-19 15:40:34	2020-08-19	Dr. Keyshawn Romaguera DDS	dr.keyshawn.romaguera.dds@geemail.com	Indianapolis	Indiana	3037528125292782	7235ae3f024600715bd480fd7aaaaa36	American Express	39.7358198134236034	-86.2093833295363936
46205	2020-08-19 15:41:39	2020-08-19	Mr. Korey Purdy Jr.	mr.korey.purdy.jr.@geemail.com	Topeka	Kansas	3050129769582013	cd70b84af85ae9731a53c7b625fb9108	American Express	38.9925295157756651	-95.6187828326307283
46206	2020-08-19 15:41:56	2020-08-19	Dr. Guy Smith	dr.guy.smith@woohoo.com	Milwaukee	Wisconsin	210025774797283331	a34159b783d414e05d77125baf59e077	VISA 16 digit	43.0138266735795867	-87.9205995924405812
46207	2020-08-19 16:08:16	2020-08-19	Chessie Zemlak	chessie.zemlak@geemail.com	Corpus Christi	Texas	180006559225938538	d62af3a079c1a603b6565645d952c29b	American Express	27.8523193035677075	-97.2105775495819699
46208	2020-08-19 16:38:44	2020-08-19	Stacy Larkin	stacy.larkin@geemail.com	Glendale	Arizona	4853321220061368	9d3a4db6e37fd6581aae904775cf6e19	Diners Club / Carte Blanche	33.4660191360156958	-112.221530906648923
46209	2020-08-19 16:47:34	2020-08-19	Ms. Kaydence Schowalter	ms.kaydence.schowalter@geemail.com	Mesa	Arizona	869990437092682819	257c2cf745eb79876372016d99d6c31e	JCB 15 digit	33.4689895305462173	-111.680011575657502
46210	2020-08-19 16:51:10	2020-08-19	Jinnie Haag PhD	jinnie.haag.phd@geemail.com	Des Moines	Iowa	4533891857106726	b13415e7cbd309de04bdd9510aa0f0d5	Discover	41.5825705875851241	-93.6685654488436938
46211	2020-08-19 16:56:45	2020-08-19	Dorthea Baumbach	dorthea.baumbach@warmmail.com	Miramar	Florida	4522446276090390	e692c5a3a39fedf8a2f6eeaa4e6e868e	Maestro	25.9167238026373106	-80.2769843027919592
46212	2020-08-19 17:07:56	2020-08-19	Allen Schmitt	allen.schmitt@geemail.com	Anaheim	California	55097870390460756	8d737e19ce2b4f18abe6b3ae46f4edc5	Diners Club / Carte Blanche	33.8248183606490471	-117.730853955515101
46213	2020-08-19 17:12:25	2020-08-19	Dr. Roxanna Veum DVM	dr.roxanna.veum.dvm@geemail.com	New York	New York	3158410261797338599	1a77e82e199482878e49af74a13643ff	Discover	40.6953432807456679	-74.0366364924132796
46214	2020-08-19 17:18:57	2020-08-19	Dr. Wellington Hayes	dr.wellington.hayes@geemail.com	Milwaukee	Wisconsin	3054001060672064	03b318dccd7c07e578e8d10a88cbb743	VISA 13 digit	43.0501925750721242	-88.0458947445832223
46215	2020-08-19 17:20:02	2020-08-19	Felicie Metz DDS	felicie.metz.dds@geemail.com	Everett	Washington	3528729903828966031	5b2ca23764b3bcd2538d67ba38d88dca	Discover	48.0409179758638132	-122.252155305830385
46216	2020-08-19 17:21:34	2020-08-19	Gurney Hickle	gurney.hickle@geemail.com	Irvine	California	52239976896505678	bb745b420764d62fe6a7160f2325ab0a	Maestro	33.7781066524811138	-117.753754842887815
46217	2020-08-19 17:31:06	2020-08-19	Dr. Braiden Mann Jr.	dr.braiden.mann.jr.@geemail.com	Huntsville	Alabama	589306559822603	911bcf13aaa952cbfadd137e017e52e0	JCB 16 digit	34.7738419743496934	-86.6574960865098944
46218	2020-08-19 17:38:36	2020-08-19	Richard Baumbach Jr.	richard.baumbach.jr.@geemail.com	San Francisco	California	4621766325069990	b9b9814761b4f83714303c74848fdaa6	JCB 15 digit	37.7839156109592693	-122.434290792814764
46219	2020-08-19 17:42:47	2020-08-19	Walt Stark-Nicolas	walt.stark.nicolas@geemail.com	New York	New York	869936047623120671	8d26be3964cf788677784868bc44e154	Diners Club / Carte Blanche	40.6223402889203271	-73.9222434737615259
46220	2020-08-19 17:52:46	2020-08-19	Evan Kris	evan.kris@geemail.com	Raleigh	North Carolina	52710168494043207	dad386c34a2d8d06f5c01d033c596971	Mastercard	35.8936065813194958	-78.597834187925983
46221	2020-08-19 17:59:51	2020-08-19	Jeri Bahringer	jeri.bahringer@geemail.com	San Francisco	California	676125236899834	58a6e69659b0fd8e02d96286b7eb2d48	JCB 16 digit	37.7811585124065701	-122.420393082868031
46222	2020-08-19 18:01:45	2020-08-19	Dominique D'Amore	dominique.d'amore@geemail.com	Oakland	California	3528058045874719384	7b4a1789f2437edfae0f0d55f8b596f0	JCB 15 digit	37.8430491225048939	-122.24469045291184
46223	2020-08-19 18:14:26	2020-08-19	Mr. Glenwood Schiller	mr.glenwood.schiller@warmmail.com	Scottsdale	Arizona	53908840985253881	35891fbc5fd278ebc0a72efff7f00614	VISA 16 digit	33.6927025788120957	-111.802466583108895
46224	2020-08-19 18:17:56	2020-08-19	Kerry Dietrich	kerry.dietrich@geemail.com	Lexington	Kentucky	3158908240705640618	9a59fd3bee8287c64039938a018f9bec	Voyager	38.0511397093411574	-84.3738461344867829
46225	2020-08-19 18:19:48	2020-08-19	Rosia Kilback	rosia.kilback@woohoo.com	San Francisco	California	4950531948046	b4d71c405f46d499eb5ff3286c0882c0	VISA 16 digit	37.7976678407586064	-122.430844001093106
46226	2020-08-19 18:21:07	2020-08-19	Pleasant Schumm	pleasant.schumm@geemail.com	Austin	Texas	6011878010908807140	57802b5ccb389475d6d4d01ca13ea289	JCB 16 digit	30.3488407760053853	-97.7555286192573618
46227	2020-08-19 18:24:00	2020-08-19	Leala Schmeler	leala.schmeler@woohoo.com	New York	New York	6011457776484659597	d2c0f72b66912d78ebc62dc3afa1117d	JCB 15 digit	40.732654077442362	-73.9030059936817736
46228	2020-08-19 18:25:32	2020-08-19	Zeke Crist	zeke.crist@geemail.com	Newark	New Jersey	3030428265235351	2973231ef40128b565be32de460ac04c	Mastercard	40.681741313301778	-74.1527531469449457
46229	2020-08-19 18:26:26	2020-08-19	Dr. Doretta Hessel DVM	dr.doretta.hessel.dvm@geemail.com	Grand Rapids	Michigan	3088681362323136986	e0961325fad9715f02eb5ba9ba393ead	Maestro	42.9743361650768634	-85.6202677773911631
46230	2020-08-19 18:26:52	2020-08-19	Merlin Lang	merlin.lang@woohoo.com	Seattle	Washington	51739430050249652	0591c45187e1b0949dfba7ecfccab0b4	VISA 16 digit	47.5460154128652093	-122.309205010013272
46231	2020-08-19 18:35:12	2020-08-19	Kloe Cruickshank	kloe.cruickshank@geemail.com	Los Angeles	California	501800814736559	45645658cc98fdebb44a5ffee5c423d7	VISA 13 digit	33.9433925871603179	-118.317686089313767
46232	2020-08-19 18:38:55	2020-08-19	Dr. Loren Boyle V	dr.loren.boyle.v@woohoo.com	Santa Clarita	California	3337389124202881925	d78c109a0cfd2e94c4f9196779408785	JCB 15 digit	34.3247316338792459	-118.412312405380234
46233	2020-08-19 18:39:19	2020-08-19	Russel Huel	russel.huel@woohoo.com	New York	New York	3088242569087463875	176769bff4aee6e88cc9a5b96c4b0b52	Mastercard	40.7252635439615673	-73.9318004472542469
46234	2020-08-19 18:40:23	2020-08-19	Reva Abbott	reva.abbott@geemail.com	New York	New York	54827005357287499	fc0fd224021aa82dd399c72b8f510b12	VISA 13 digit	40.5814472811054401	-73.9268124982610288
46235	2020-08-19 18:42:47	2020-08-19	Alina King	alina.king@geemail.com	Detroit	Michigan	4601806695706542	d727596aa9bc73a1e70e00387335495a	VISA 13 digit	42.3551381665207458	-83.0315223893269803
46236	2020-08-19 18:43:54	2020-08-19	Jaylin Swaniawski DVM	jaylin.swaniawski.dvm@geemail.com	Port St. Lucie	Florida	6011303096280312184	d98bd3eb98d18411cf6fa5a3c0102825	Diners Club / Carte Blanche	27.1878918047662808	-80.3332902397580426
46237	2020-08-19 18:53:40	2020-08-19	Valentino Turcotte-Turcotte	valentino.turcotte.turcotte@geemail.com	Santa Rosa	California	3337812923049425714	6bd16fd1dc93fb13d26de165b91ba2b0	JCB 15 digit	38.4259807178873629	-122.78337421782912
46238	2020-08-19 18:53:56	2020-08-19	Mckayla Metz-Hahn	mckayla.metz.hahn@geemail.com	Columbus	Ohio	52063496843708441	3f88d32a5cdd7d916e1ebaf6e4b9f772	Mastercard	39.9639406438961586	-83.0712032339304756
46239	2020-08-19 18:54:14	2020-08-19	Golda Dare DDS	golda.dare.dds@geemail.com	Raleigh	North Carolina	676288688169064	f93e82848da841c7b14d6f9edfd275c0	JCB 16 digit	35.903743484024325	-78.5836310804758256
46240	2020-08-19 18:56:53	2020-08-19	Addisyn Labadie	addisyn.labadie@geemail.com	St. Louis	Missouri	3038027241483812	5d6ee224d4394af0240518d714fcb752	Maestro	38.6719091627903282	-90.2337714860685196
46241	2020-08-19 18:59:50	2020-08-19	Jovanni Yundt	jovanni.yundt@geemail.com	Huntsville	Alabama	3088068635710700958	b61a06282075f49e510c12c887f99b54	Maestro	34.7067231445815381	-86.7294515137113677
46242	2020-08-19 19:13:38	2020-08-19	Dr. Rico Powlowski	dr.rico.powlowski@geemail.com	New York	New York	3469803235349482	207e86ebacf96b1468a47fdcb4fe55e8	VISA 16 digit	40.6320291215777374	-73.9225627412449597
46243	2020-08-19 19:17:16	2020-08-19	Romie Simonis Sr.	romie.simonis.sr.@geemail.com	Mobile	Alabama	3789943937248032	55756f4823cf9e4df40193158dcc5d53	JCB 16 digit	30.7144511054843647	-88.163616558410979
46244	2020-08-19 19:19:54	2020-08-19	Ms. Antonia Sporer DVM	ms.antonia.sporer.dvm@geemail.com	Jersey City	New Jersey	54479690298576083	241c1a372ac3088a03e84a68045e51d3	Voyager	40.7188221767019485	-74.0785686161790125
46245	2020-08-19 19:22:12	2020-08-19	Margaretta Roob	margaretta.roob@woohoo.com	San Angelo	Texas	869962768795706214	02b62dd34d3fc7a1bf0dca44b9ba415a	JCB 16 digit	31.3772318116541946	-100.451188391132291
46246	2020-08-19 19:30:27	2020-08-19	Theodis Lang	theodis.lang@geemail.com	Gainesville	Florida	4101574682081197	73a64c0f31c36f019cd0d4a71c8d62a1	Mastercard	29.6429879202798006	-82.4191782358907261
46247	2020-08-19 19:34:57	2020-08-19	Cornelius Kiehn	cornelius.kiehn@geemail.com	New York	New York	55432796896862092	d3cb9833fcfa4f0a2d01bfff1e8b1930	VISA 16 digit	40.6816400095578246	-73.9301153594523583
46248	2020-08-19 19:38:53	2020-08-19	Robley D'Amore I	robley.d'amore.i@warmmail.com	New York	New York	53688778313411605	a71011a9158ee0e0ead0b95b6fbe6979	JCB 15 digit	40.5946925397720193	-73.8520848039433275
46249	2020-08-19 19:39:48	2020-08-19	Delvin Ratke	delvin.ratke@geemail.com	San Antonio	Texas	6011060857526518253	097ef0bf2c442713b4d3d037283249db	Discover	29.4230303201895218	-98.5423194675076672
46250	2020-08-19 19:44:49	2020-08-19	Edgardo Fay	edgardo.fay@geemail.com	Olathe	Kansas	3158928392842701567	ad69d11059e5ffa4faac68cdba4a6e7e	Maestro	38.8506209927734005	-94.8288366163782825
46251	2020-08-19 19:50:44	2020-08-19	Miner Weimann	miner.weimann@geemail.com	Houston	Texas	630412331456827	cde4c27f4addaaab193cc9176b4bda72	American Express	29.8350329914674148	-95.469930291456734
46252	2020-08-19 19:56:36	2020-08-19	Shea Will Sr.	shea.will.sr.@warmmail.com	New York	New York	6011090503060321837	27b6cd7a90b2d73e9d1062eb9c479313	Voyager	40.761080999229101	-73.9339404106967066
46253	2020-08-19 19:57:35	2020-08-19	Mrs. Tiffanie Welch MD	mrs.tiffanie.welch.md@geemail.com	Visalia	California	869906203937159634	3fd6ed3c1507355f625ff2a0c0aac4da	Mastercard	36.390886763432249	-119.341159737867869
46254	2020-08-19 19:57:55	2020-08-19	Micky Crona	micky.crona@geemail.com	San Francisco	California	869915696102101472	91f9a0828c80b81648660ecc54620222	American Express	37.7439826750630161	-122.456460320845196
46255	2020-08-19 19:58:06	2020-08-19	Dr. Payten Gaylord MD	dr.payten.gaylord.md@geemail.com	New York	New York	3112312533976690365	d3f8309df4fb264a1a6686e9f7e9c74f	Maestro	40.6987117097005253	-73.8958448370814267
46256	2020-08-19 20:06:55	2020-08-19	Dr. Halley Legros	dr.halley.legros@geemail.com	Kansas City	Missouri	4510744163397769	cac0104201fb94e5132ba4d6957cc7bf	Diners Club / Carte Blanche	39.0350699512589756	-94.4856520751249036
46257	2020-08-19 20:14:22	2020-08-19	Mrs. Sarrah Harber MD	mrs.sarrah.harber.md@warmmail.com	Oklahoma City	Oklahoma	3088064882745480719	031975a15816d0586fb2eaaf58ca2b81	JCB 15 digit	35.4864600750528325	-97.5825388518057792
46258	2020-08-19 20:18:24	2020-08-19	Teddy Zieme	teddy.zieme@warmmail.com	San Francisco	California	55255726436045076	7154e0ad4599eb841624d9a90f4ea29b	Voyager	37.8093513140781425	-122.421433749237266
46259	2020-08-19 20:31:16	2020-08-19	Teddy Nicolas	teddy.nicolas@woohoo.com	New York	New York	3096726193578370773	9acde332a2b0b14b6d598bc9a3314234	VISA 13 digit	40.5855482298638677	-73.9373448703333764
46260	2020-08-19 20:32:05	2020-08-19	Cristy Hauck	cristy.hauck@warmmail.com	Burbank	California	3013895504284621	a25da4357b0f958a9d0a506b25ce08fa	Diners Club / Carte Blanche	34.145323860871045	-118.241730259548504
46261	2020-08-19 20:32:39	2020-08-19	Margarite Rowe-Jenkins	margarite.rowe.jenkins@geemail.com	Los Angeles	California	869909649688392799	2d199b9bcc4fd72f1182dddac0535441	JCB 15 digit	34.0442499930370559	-118.330441272630537
46262	2020-08-19 20:42:44	2020-08-19	Noreen Boehm	noreen.boehm@woohoo.com	Oakland	California	6011676105246597413	fed9bb98e42bb328b9ff20795e21c6a6	JCB 15 digit	37.8114577910405885	-122.286835083212281
46263	2020-08-19 20:50:05	2020-08-19	Dr. Verlyn Powlowski	dr.verlyn.powlowski@geemail.com	Round Rock	Texas	4904368684052259	f73a2d56269bb6c351f087f08a50a1e5	American Express	30.6051519415013509	-97.6915515619181036
46264	2020-08-19 20:55:49	2020-08-19	Crissy Stracke-Rempel	crissy.stracke.rempel@geemail.com	Allen	Texas	3088064642184205716	908363abb00d1a8d9081be421e2e3132	American Express	33.0357109765548245	-96.7479302531056078
46265	2020-08-19 20:58:50	2020-08-19	Arbie Stroman	arbie.stroman@geemail.com	Killeen	Texas	3447202281910718	305d2162ea31ac05b0b20aa2494d346c	American Express	31.1300611227516093	-97.7560039807744374
46266	2020-08-19 21:09:43	2020-08-19	Mr. Ricci Jakubowski IV	mr.ricci.jakubowski.iv@geemail.com	Buffalo	New York	3528629201766136134	5d045bf2ddbc86b7d1684e7f02c44a13	Discover	42.8437822431977793	-78.8562238705277423
46267	2020-08-19 21:14:48	2020-08-19	Burnie Rath DVM	burnie.rath.dvm@geemail.com	Gresham	Oregon	869948987045804889	931082bd87d7faca98debb2fc501b2aa	JCB 16 digit	45.4955047159411023	-122.397650655012939
46268	2020-08-19 21:17:42	2020-08-19	Lassie Friesen	lassie.friesen@woohoo.com	Palm Bay	Florida	3528961372168621324	0251e60133dc36955079750f5bd038e4	VISA 13 digit	27.8988310165092379	-80.7326539880432108
46269	2020-08-19 21:21:05	2020-08-19	Ms. Vonetta Wuckert	ms.vonetta.wuckert@warmmail.com	Los Angeles	California	4495497186462	b93b221f08da62d55a243a8b6ec24af8	JCB 16 digit	33.9632328709918951	-118.363851497600962
46270	2020-08-19 21:39:42	2020-08-19	Arnie Prosacco Jr.	arnie.prosacco.jr.@warmmail.com	Scottsdale	Arizona	6011789957950235091	d93e5c915e0229dc03c27f012565f9cb	JCB 16 digit	33.6227039287921059	-111.768343583304798
46271	2020-08-19 22:00:38	2020-08-19	Doyle Mertz	doyle.mertz@geemail.com	Santa Clarita	California	3337655638903379282	14c24a1667036c72466cecb7ff4e09d4	Diners Club / Carte Blanche	34.4662639998104439	-118.561194554074476
46272	2020-08-19 22:00:39	2020-08-19	Stacy Brown MD	stacy.brown.md@geemail.com	New York	New York	3007827225536902	e54d1b796f70ae6f3e0dfae219ac1370	Voyager	40.7142130688056341	-73.9007411898940774
46273	2020-08-19 22:01:07	2020-08-19	Mr. Heath Jast DDS	mr.heath.jast.dds@geemail.com	San Diego	California	4478641387535507	e132d7dba7492b80e23bd07ca50b88d0	VISA 16 digit	32.7361525543101166	-117.099507768070325
46274	2020-08-19 22:03:53	2020-08-19	Verena Barton	verena.barton@warmmail.com	Cary	North Carolina	4077141894035138	b991325432459cbf11d8fb742d05db29	Diners Club / Carte Blanche	35.746540064701442	-78.7557602034501656
46275	2020-08-19 22:11:14	2020-08-19	Renae Rice	renae.rice@geemail.com	Downey	California	3158720022182006083	cb01a6c4aa16ff1a6674de298a27959d	VISA 16 digit	33.9054160929068971	-118.181254962237176
46276	2020-08-19 22:13:06	2020-08-19	Shonda Smitham	shonda.smitham@geemail.com	San Francisco	California	3053108763595970	9e1f5dcaa30e7bc40ba0ee4269bff9d5	Discover	37.75758350981517	-122.405902969496807
46277	2020-08-19 22:21:33	2020-08-19	Brooks Kulas	brooks.kulas@geemail.com	St. Louis	Missouri	4386124185228972	ba27eadbcd5e20599a145e7328ce182c	VISA 16 digit	38.6780378874547779	-90.2424511920664543
46278	2020-08-19 22:28:35	2020-08-19	Mrs. Edythe O'Reilly DVM	mrs.edythe.o'reilly.dvm@geemail.com	Honolulu	Hawaii	6011290930166740289	ec526fdc4a5a5dbb0b46cb2dc964d00a	Discover	21.4028204791463921	-157.879670460356778
46279	2020-08-19 22:33:03	2020-08-19	Luberta Sauer	luberta.sauer@warmmail.com	Norfolk	Virginia	3483481531323105	adb8ad300688484aa4cabd325caabba0	VISA 16 digit	36.9240796256363382	-76.2538003581579886
46280	2020-08-19 22:50:31	2020-08-19	Greg McLaughlin-Ullrich	greg.mclaughlin.ullrich@geemail.com	San Francisco	California	210044794547220224	a1694320f56014c115f02999f31ad3fe	VISA 16 digit	37.7865836367579604	-122.432429994363275
46281	2020-08-19 22:57:49	2020-08-19	Toshio Murphy	toshio.murphy@geemail.com	Houston	Texas	4354800608972688	d56f7892d650f755531fcff0c730ff54	VISA 13 digit	29.8165539761617779	-95.3331635793220329
46282	2020-08-19 23:03:26	2020-08-19	Abram Okuneva-Adams	abram.okuneva.adams@geemail.com	Buffalo	New York	53147862742478297	4104c6873da95dce2bff0f003ae2ebf0	Mastercard	42.8742289656959485	-78.7703869966723005
46283	2020-08-19 23:04:48	2020-08-19	Karsyn Terry	karsyn.terry@geemail.com	San Francisco	California	54224887733154108	3a28987068b4fc0cd7d6b34db5875ab1	Maestro	37.8109946481900039	-122.417829000714789
46284	2020-08-19 23:14:04	2020-08-19	Dean Mante	dean.mante@warmmail.com	New Orleans	Louisiana	501875860045923	a062bcd7a67a6381661eb40ff5ca28c3	VISA 13 digit	29.9942721642568699	-89.972654920935625
46285	2020-08-19 23:18:04	2020-08-19	Keyla Cassin	keyla.cassin@geemail.com	Las Cruces	New Mexico	180056125207890789	a69eb99e1ae8b4d5b26297fcbbf9c87e	VISA 13 digit	32.4155038175672274	-106.732772951352217
46286	2020-08-19 23:18:49	2020-08-19	Ms. Myranda Schmeler MD	ms.myranda.schmeler.md@warmmail.com	Houston	Texas	4838424130665961	f5d5a04a1b691ef0285b04cabdf1328c	VISA 16 digit	29.8566737146195038	-95.4177755489960333
46287	2020-08-19 23:18:55	2020-08-19	Dedric Kshlerin	dedric.kshlerin@geemail.com	Rochester	Minnesota	4087654008128191	16bb46b2d337a6716711e12c27d8e7f4	Maestro	44.0809198387335996	-92.4075343404550011
46288	2020-08-19 23:33:24	2020-08-19	Shyann Breitenberg	shyann.breitenberg@warmmail.com	Overland Park	Kansas	3750239408504051	5e8414b8580d5d95b51fc6d98fe209dc	Maestro	38.8521545923184632	-94.6693349755410196
46289	2020-08-19 23:37:30	2020-08-19	Nathanial Hessel	nathanial.hessel@geemail.com	Tulsa	Oklahoma	869904972645229267	4cbb70d236ffa47501d0e88113644a2c	Voyager	36.1611690335344491	-95.9806607126679268
46290	2020-08-19 23:39:19	2020-08-19	Yaakov Flatley	yaakov.flatley@geemail.com	Garland	Texas	869929697834801987	b6c73ff5ed2d9c17e7be2735cbd4c778	Mastercard	32.8369478796377763	-96.5850087658196799
46291	2020-08-19 23:43:06	2020-08-19	Keira Wyman	keira.wyman@geemail.com	Colorado Springs	Colorado	4968586740332	15bcf209c7487789b17f2fcb63a3b1df	JCB 16 digit	38.775407477007434	-104.686342506312585
46292	2020-08-19 23:48:36	2020-08-19	Jackson Nader	jackson.nader@warmmail.com	San Francisco	California	54705945198510145	bbaaa0081ddb4364b51afe0f9b12b202	VISA 16 digit	37.775366655107689	-122.406561982659952
46293	2020-08-19 23:50:50	2020-08-19	Dr. Winford Blanda	dr.winford.blanda@woohoo.com	Sunnyvale	California	180043499359788968	1097da50e0aa74f9d7fc900a44392e53	Maestro	37.3226254987523021	-122.07840522511043
46294	2020-08-19 23:51:08	2020-08-19	Thad Conn	thad.conn@warmmail.com	Spokane	Washington	869992452803836529	3cd547a0bb17e13533cb6ad632155bab	Discover	47.5793902259092789	-117.5036285084106
46295	2020-08-19 23:56:39	2020-08-19	Manda Mitchell	manda.mitchell@warmmail.com	Berkeley	California	869975787904256106	be8214b76824692a02f5c682b29e8988	JCB 16 digit	37.898264588623725	-122.252114691317203
46296	2020-08-19 23:58:36	2020-08-19	Tomika Hartmann	tomika.hartmann@woohoo.com	Pearland	Texas	6011116409255016390	a4a6bf4de13e6fbe8932b60fdde73914	VISA 16 digit	29.5373034498460605	-95.3304097825050292
46297	2020-08-20 00:02:41	2020-08-20	Abigayle Olson	abigayle.olson@geemail.com	Washington	District of Columbia	51164604478824742	9fb7f4e4f6a4dd13964605669324f717	Diners Club / Carte Blanche	38.9812160893607853	-77.0088640057694249
46298	2020-08-20 00:03:39	2020-08-20	Dr. Anjelica Von	dr.anjelica.von@woohoo.com	San Francisco	California	869967325231529141	412a1e514dadf4b50d11ca1aab68d0ff	VISA 16 digit	37.7501602534610328	-122.423420858553484
46299	2020-08-20 00:04:56	2020-08-20	Lindsay Lindgren	lindsay.lindgren@geemail.com	Raleigh	North Carolina	3096894050756838904	3d60f7f5c094e64f8c8274e46d5855c3	Discover	35.8313210622075928	-78.7202077370539399
46300	2020-08-20 00:06:39	2020-08-20	Beau Kunde PhD	beau.kunde.phd@geemail.com	Orlando	Florida	180055892800172029	4bafbfa13896ecc0900ca1a857f6547b	VISA 16 digit	28.3313222697269147	-81.2203155435588258
46301	2020-08-20 00:13:16	2020-08-20	Classie Krajcik	classie.krajcik@warmmail.com	Chattanooga	Tennessee	3013749900843763	6f1fa4b820815bcd482f473d0575f588	Maestro	35.1205752708334487	-85.2520796494852817
46302	2020-08-20 00:21:18	2020-08-20	Camren Toy-Lueilwitz	camren.toy.lueilwitz@geemail.com	Pasadena	California	3112623988112745198	e4ecf2748b6cb46810bbb50896f1fd07	VISA 16 digit	34.1618032129801819	-118.211930374876033
46303	2020-08-20 00:24:09	2020-08-20	Hilma Schultz	hilma.schultz@geemail.com	Seattle	Washington	3043988459656883	f09918930b8dc4b9209fcfb76e96df0e	JCB 16 digit	47.6316845233011961	-122.34159143589585
46304	2020-08-20 00:29:33	2020-08-20	Miss Nyla Flatley PhD	miss.nyla.flatley.phd@geemail.com	Yonkers	New York	4220748701308528	8ff3785f4b8eb6275f08f9525791f642	VISA 16 digit	41.018592653350531	-73.9190045638360118
46305	2020-08-20 00:33:52	2020-08-20	Serena Raynor MD	serena.raynor.md@woohoo.com	Raleigh	North Carolina	869993555893713892	7f068a3263fb544cf451c7efd53f36b5	Maestro	35.8787988441199062	-78.6144940737571574
46306	2020-08-20 00:39:22	2020-08-20	Rory Bins-Ledner	rory.bins.ledner@geemail.com	New York	New York	3413057812383193	10010e4c10737ac0deedeaa80d106076	American Express	40.6012397199626989	-73.9312618463661551
46307	2020-08-20 00:48:56	2020-08-20	Chace Donnelly	chace.donnelly@geemail.com	Hampton	Virginia	4859271588918838	cd93453518609739e5b408958e907e57	Maestro	36.9511352343037771	-76.218748869430641
46308	2020-08-20 00:52:17	2020-08-20	Misti Romaguera	misti.romaguera@warmmail.com	San Francisco	California	6011011246403465780	0e480e69021b7e3d8dc0b5f0cc9b7829	American Express	37.78558753712705	-122.429572233756844
46309	2020-08-20 00:55:36	2020-08-20	Ginny Dickinson	ginny.dickinson@geemail.com	Oceanside	California	4779340281764	da3e726831dd9c5bacf84e42d9990139	JCB 16 digit	33.2225976604390851	-117.212734469127653
46310	2020-08-20 00:57:20	2020-08-20	Beverlee Jast	beverlee.jast@geemail.com	New York	New York	55593487126036740	ef46733aed30e9d0a78240f586b929db	Diners Club / Carte Blanche	40.691711760148408	-73.9136694623053074
46311	2020-08-20 01:05:42	2020-08-20	Declan Hilll	declan.hilll@woohoo.com	Vallejo	California	4101905723420871	27d43ac3ca39cd26c923188a2286d63f	Maestro	38.1167233992457426	-122.297101594308387
46312	2020-08-20 01:07:12	2020-08-20	Mrs. Ottilia Schroeder	mrs.ottilia.schroeder@geemail.com	Tulsa	Oklahoma	180081739451382688	854b5c3e5de6058cbc28a8655ece5dab	Voyager	36.1175967407781613	-95.9029034343503355
46313	2020-08-20 01:09:06	2020-08-20	Melissa Kuvalis DDS	melissa.kuvalis.dds@geemail.com	Oakland	California	3433767447196028	3f2da49e841823a88b6d64cfeaee3e5b	JCB 16 digit	37.7996184704875375	-122.274181890662746
46314	2020-08-20 01:09:08	2020-08-20	Mr. Aron Hammes IV	mr.aron.hammes.iv@geemail.com	Irvine	California	55203747387345565	7ed0049e1fbf247986ad7aad632d8e29	VISA 13 digit	33.6878873959198657	-117.682254763926565
46315	2020-08-20 01:33:49	2020-08-20	Leora Sauer	leora.sauer@geemail.com	Thousand Oaks	California	6011876538250693447	8c9ff62259021a7c377f908f51710c7e	Mastercard	34.1611201893344543	-118.910255965488773
46316	2020-08-20 01:38:34	2020-08-20	Clarke Ankunding	clarke.ankunding@geemail.com	Laredo	Texas	869935243435391987	4cd630a8d87f2f120f2885313477a104	VISA 16 digit	27.557067851740495	-99.5311853902421859
46317	2020-08-20 01:42:32	2020-08-20	Kelan Kuhic-Hudson	kelan.kuhic.hudson@geemail.com	San Antonio	Texas	180015129746649540	0c50635e97e3665350f579293f0b2534	Voyager	29.5185480828002085	-98.4675222738482034
46318	2020-08-20 01:48:50	2020-08-20	Xander Rempel-Runte	xander.rempel.runte@geemail.com	Mesa	Arizona	180085500939553977	677c8dca8c2a98f59046372a3c31b7b8	Voyager	33.4741244856413402	-111.807137543556834
46319	2020-08-20 01:51:04	2020-08-20	Miss Ayana Reinger DDS	miss.ayana.reinger.dds@warmmail.com	Jersey City	New Jersey	3022682239269023	7e77d76dd9f6d7f9644970387fe3be7c	Discover	40.718527706939355	-74.1106745052106675
46320	2020-08-20 01:51:33	2020-08-20	Cale Jakubowski	cale.jakubowski@geemail.com	Jackson	Mississippi	4642145310003857	c7fdf7a01e71b1df9eb42709e827e7e6	Discover	32.2271853083923503	-90.2722767929520415
46321	2020-08-20 01:55:25	2020-08-20	Keira Pagac-Jacobs	keira.pagac.jacobs@warmmail.com	Houston	Texas	52588875366730096	fdaefcc9fc8d2ab1431c1fa83d1f3e5a	Maestro	29.7150559322521097	-95.3909439008697859
46322	2020-08-20 02:08:48	2020-08-20	Fred Deckow	fred.deckow@geemail.com	Philadelphia	Pennsylvania	3026746396646418	fee4801667016bd15361b45519949d78	Maestro	40.0524619111284608	-75.1855543649189286
46323	2020-08-20 02:10:18	2020-08-20	Izola West	izola.west@geemail.com	Houston	Texas	4210554930393675	4355db46b6c548e109b74bed48092ece	JCB 16 digit	29.6992657515298575	-95.4799924638137298
46324	2020-08-20 02:10:54	2020-08-20	Maxim Weissnat	maxim.weissnat@warmmail.com	Mesa	Arizona	3088584426145850229	ded386a5a1515008af8d6530296e210e	American Express	33.4012217927869415	-111.782910990843178
46325	2020-08-20 02:11:00	2020-08-20	Dr. Ivor Williamson II	dr.ivor.williamson.ii@warmmail.com	Port St. Lucie	Florida	4273803204208	a2b81745e711dab97f102c98b7dc454e	JCB 16 digit	27.2677914867777389	-80.3333926862657108
46326	2020-08-20 02:19:26	2020-08-20	Bernardo Stracke-Bergstrom	bernardo.stracke.bergstrom@geemail.com	San Bernardino	California	4495221110275	26f390d6959b996139a8e68b68f4c7f8	VISA 13 digit	34.0933952362541106	-117.366614820506797
46327	2020-08-20 02:32:31	2020-08-20	Mr. Derrick Kunde Jr.	mr.derrick.kunde.jr.@warmmail.com	Pittsburgh	Pennsylvania	4627368766804	3815dc96edf07840eaf80e72343cbdb3	American Express	40.5210241196166692	-80.0614894271068351
46328	2020-08-20 02:34:30	2020-08-20	Dorthea Nikolaus DDS	dorthea.nikolaus.dds@geemail.com	Milwaukee	Wisconsin	6011129037253168353	ba145cad907865ab7056f17cbaab9847	VISA 16 digit	43.0414667166855196	-88.058933300535017
46329	2020-08-20 02:36:05	2020-08-20	Mr. Deonta Morissette	mr.deonta.morissette@woohoo.com	San Francisco	California	3032627612693133	3be55d9cfaa43618418d4a298113ee1e	Discover	37.7694576481966422	-122.418557594858484
46330	2020-08-20 02:36:51	2020-08-20	Bertrand Mohr-Kuhn	bertrand.mohr.kuhn@warmmail.com	Minneapolis	Minnesota	51838701640401494	493fd2bde524b674cf86725e994edba2	VISA 13 digit	44.9398731717925486	-93.2518624110419267
46331	2020-08-20 02:38:13	2020-08-20	Lisette Hickle	lisette.hickle@woohoo.com	Chicago	Illinois	503824685065393	1d66eaa7f4a8d132a0738f4085500a18	VISA 16 digit	41.9165019918069248	-87.5930120083533126
46332	2020-08-20 02:43:12	2020-08-20	Cortney Kozey-McCullough	cortney.kozey.mccullough@warmmail.com	Paterson	New Jersey	53390069170203122	852bedf7ff0c2faa1a8371cb25c7d764	VISA 16 digit	40.9526155902028108	-74.2587091941360455
46333	2020-08-20 02:43:17	2020-08-20	Sherie D'Amore	sherie.d'amore@geemail.com	Columbia	Missouri	4299552740076	b3382d334fee5f8cd4f4ea52fc6923df	Voyager	38.8541840460964139	-92.3248678891041408
46334	2020-08-20 02:51:43	2020-08-20	Donn Haley-Schroeder	donn.haley.schroeder@geemail.com	Oakland	California	6011967515779631124	4700866d79eae9c24bd51b1d9e8fbea1	JCB 15 digit	37.847832246098605	-122.244527285367283
46335	2020-08-20 02:52:42	2020-08-20	Ivonne Torp	ivonne.torp@geemail.com	Dayton	Ohio	3528921662810286230	f2f4581f386f65a96942b1378510e6e8	Discover	39.8214944625064717	-84.1578094490528201
46336	2020-08-20 02:57:09	2020-08-20	Savana Eichmann	savana.eichmann@geemail.com	Everett	Washington	3787444991180312	a35272aedefe8eb9e415c695651a0b78	VISA 16 digit	47.860725649156052	-122.273124440027033
46337	2020-08-20 02:57:36	2020-08-20	Bart Stiedemann	bart.stiedemann@geemail.com	Norfolk	Virginia	51356950735595692	4f31457dc078abba27c19b031ea35932	VISA 16 digit	37.0000815351512315	-76.1937517548915082
46338	2020-08-20 02:59:28	2020-08-20	King Medhurst	king.medhurst@warmmail.com	Savannah	Georgia	3112033440383476073	de26bf27310bd84365aaf62f4e3c1bc3	VISA 16 digit	32.0899470260925597	-81.2137973247714342
46339	2020-08-20 02:59:52	2020-08-20	Kylee Tremblay	kylee.tremblay@geemail.com	Austin	Texas	060414894251421	e1d65ee081d78263dfd0b69ed31be16f	JCB 16 digit	30.3844596453603337	-97.7182546623755286
46340	2020-08-20 03:06:39	2020-08-20	Annette Tromp-Fay	annette.tromp.fay@warmmail.com	Tucson	Arizona	060473071312117	bcde8569e28e075120e956c89dcb3f88	VISA 16 digit	32.2062775070819995	-110.820095450686665
46341	2020-08-20 03:16:24	2020-08-20	Giovanny Dooley-Kilback	giovanny.dooley.kilback@geemail.com	San Antonio	Texas	3088942304707953003	c0437410afd921805324f33ade5ba7e0	Maestro	29.5590228705272082	-98.5718870633583464
46342	2020-08-20 03:22:34	2020-08-20	Anita Schneider-Nolan	anita.schneider.nolan@warmmail.com	Cambridge	Massachusetts	869908924394319365	f148f5020be322faf70512e4d5740756	VISA 16 digit	42.4131464218478627	-71.1822866791941209
46343	2020-08-20 03:29:18	2020-08-20	Jonnie Murray	jonnie.murray@woohoo.com	Lexington	Kentucky	210054154005189113	63b6cd0725462249ed35e11d5c66f93b	JCB 16 digit	38.0533169068273196	-84.4436538502473297
46344	2020-08-20 03:41:08	2020-08-20	Dr. Dwaine Ratke I	dr.dwaine.ratke.i@geemail.com	Clarksville	Tennessee	4531329080835409	dc42335c7eff95cc408a07cc64fd0d1b	VISA 16 digit	36.644280436973645	-87.2944114026565217
46345	2020-08-20 03:44:31	2020-08-20	Sallie Johns	sallie.johns@warmmail.com	San Antonio	Texas	869957548265461376	fcef90cf366460772ed7ff9e8319300b	Diners Club / Carte Blanche	29.4403705300368372	-98.5736438432544446
46346	2020-08-20 03:52:34	2020-08-20	Dr. Aloysius Schumm Sr.	dr.aloysius.schumm.sr.@geemail.com	Chesapeake	Virginia	53347376592728469	fa9401d288f023b73a855121f213c88e	JCB 15 digit	36.7786573238909256	-76.3924877657864272
46347	2020-08-20 03:58:47	2020-08-20	Dr. Mozell Cruickshank	dr.mozell.cruickshank@woohoo.com	Los Angeles	California	3337876518558072270	6dc9b9fd69faf7b960119a99c72a5daf	Diners Club / Carte Blanche	34.0092615216370646	-118.445634942687292
46348	2020-08-20 04:00:39	2020-08-20	Tina Robel-Runolfsson	tina.robel.runolfsson@geemail.com	San Diego	California	55859652157896382	1dd2071070d29957613dac04ff49a96b	Discover	32.8385926271390147	-117.195319619579251
46349	2020-08-20 04:01:47	2020-08-20	Arlington Parisian	arlington.parisian@woohoo.com	San Francisco	California	869936120436769826	479b8c8a4c45d6e0face46c2e9f1aa9c	VISA 16 digit	37.7900319488906575	-122.451639322709269
46350	2020-08-20 04:06:11	2020-08-20	Lovett Green	lovett.green@warmmail.com	Oakland	California	3009932615915647	c2a54f44c824d140bee4416a3a75c3d3	VISA 16 digit	37.8635091753183559	-122.27200166310385
46351	2020-08-20 04:22:54	2020-08-20	Holli Smitham MD	holli.smitham.md@woohoo.com	Jersey City	New Jersey	060497602512952	ffee774c7f6cb85ab64042aa6d331223	VISA 16 digit	40.8097820732217258	-74.0397514975119435
46352	2020-08-20 04:23:04	2020-08-20	Dr. Tosha Sporer	dr.tosha.sporer@geemail.com	Newark	New Jersey	869960650739210549	288357b6ad9268fbac12eb07bcef1639	JCB 15 digit	40.7642184983853255	-74.2058004358526375
46353	2020-08-20 04:33:10	2020-08-20	Samson Quitzon	samson.quitzon@geemail.com	Berkeley	California	4960294627327148	e442be6f924b28e5b5b1b5187b8b68f6	VISA 16 digit	37.9108583746371366	-122.279201786991663
46354	2020-08-20 04:46:20	2020-08-20	Edrie Erdman PhD	edrie.erdman.phd@woohoo.com	San Francisco	California	676320245888803	c773fd13547d363d984686e6a46ab71d	VISA 13 digit	37.7648870798358871	-122.420250017704831
46355	2020-08-20 05:04:06	2020-08-20	Janine Metz	janine.metz@woohoo.com	San Antonio	Texas	52551158775298952	49beefad2fb6bbb5f27e38a0d54784aa	VISA 13 digit	29.4392346127029505	-98.5521644808653718
46356	2020-08-20 05:06:54	2020-08-20	Dr. Ceola Jenkins DDS	dr.ceola.jenkins.dds@geemail.com	Las Vegas	Nevada	869917111789167661	8d6d124489728d4de9a9c7de29ff7aee	VISA 16 digit	36.1712491454191465	-115.349630341979108
46357	2020-08-20 05:11:36	2020-08-20	Mercedes Greenfelder-Wintheiser	mercedes.greenfelder.wintheiser@geemail.com	San Francisco	California	6011646770594915041	572076ddd43cd5429b79d5aac7535f1f	JCB 16 digit	37.7748835182564093	-122.439871061082926
46358	2020-08-20 05:18:27	2020-08-20	Mrs. Addison Lakin	mrs.addison.lakin@geemail.com	New York	New York	4035096657974	53c0c42e4c316b74b9709f951291a6f6	Diners Club / Carte Blanche	40.6992559951022272	-73.8947193562414526
46359	2020-08-20 05:34:50	2020-08-20	Dr. Selene Bode	dr.selene.bode@warmmail.com	New York	New York	4277114895059	cc9b9ddb2c0d50e56c5b3973c36563b3	JCB 16 digit	40.6297374163977807	-73.9297361596848788
46360	2020-08-20 05:38:42	2020-08-20	Urijah Dooley	urijah.dooley@geemail.com	Colorado Springs	Colorado	3096760102861438053	05eb08e08e9f26d2543405501659935c	JCB 16 digit	38.9236589571043865	-104.800864172556246
46361	2020-08-20 05:40:03	2020-08-20	Robin Bernhard	robin.bernhard@geemail.com	Norfolk	Virginia	060486082111328	f3404e6cdc60c2627a120c24ab3c941b	VISA 16 digit	36.9346174029652019	-76.3288170699499631
46362	2020-08-20 05:48:16	2020-08-20	Dr. Boss Schamberger	dr.boss.schamberger@geemail.com	Albuquerque	New Mexico	3700443672697200	576c0bd198dc175ef1eb3cdeef4447c1	Diners Club / Carte Blanche	35.1025076424837152	-106.620948331065108
46363	2020-08-20 05:58:57	2020-08-20	Dr. Bowman Reinger	dr.bowman.reinger@geemail.com	El Paso	Texas	676382572770590	fe48a43002c57ae9d70c4be53fd175df	VISA 13 digit	31.7711066833060265	-106.352206521339724
46364	2020-08-20 05:59:06	2020-08-20	Marietta Greenholt	marietta.greenholt@geemail.com	Ontario	California	3056553537404594	4231251673082c4cb1047e5daf7c3084	JCB 16 digit	34.0248489459190537	-117.536223016037425
46365	2020-08-20 06:00:47	2020-08-20	Clarnce Crona	clarnce.crona@geemail.com	San Jose	California	4499674155746	b14c8b5a9307e0fc6a3a1fb663b9a36d	American Express	37.2317679242517841	-121.835974851272624
46366	2020-08-20 06:16:42	2020-08-20	Andrae Ankunding	andrae.ankunding@geemail.com	New York	New York	676217944452261	9d312401e31ee444366019ecdc1d993e	JCB 15 digit	40.6343532299846402	-73.8405493579700618
46367	2020-08-20 06:16:49	2020-08-20	Mrs. Kaaren Kiehn DDS	mrs.kaaren.kiehn.dds@geemail.com	San Jose	California	4183621397490	6d0f12ef4b2b10f07bac70126096d01e	American Express	37.3834212576325982	-121.813270233686637
46368	2020-08-20 06:24:20	2020-08-20	Lavera Wolff	lavera.wolff@geemail.com	Charlotte	North Carolina	3096246825456240211	f5aa5c4b6b4094fa33ea5a9aff13f45d	Diners Club / Carte Blanche	35.1229970334816741	-80.7782389243543122
46369	2020-08-20 06:25:55	2020-08-20	Mrs. Dora Abernathy MD	mrs.dora.abernathy.md@geemail.com	San Francisco	California	3786298018692258	e9fd45f185231d56bcf35b24e3425da1	Mastercard	37.8013608188304957	-122.412813607996455
46370	2020-08-20 06:33:05	2020-08-20	Tisha Huels	tisha.huels@geemail.com	Pompano Beach	Florida	210038459692823192	f80da7ee221656fb7a253e5ab9171bf2	VISA 13 digit	26.2388937379032363	-80.0953032640587566
46371	2020-08-20 06:36:19	2020-08-20	Mrs. Shawna Erdman DVM	mrs.shawna.erdman.dvm@geemail.com	Cedar Rapids	Iowa	4270009254365236	ab556b312869635452fca6d143865b55	Diners Club / Carte Blanche	41.9525515371542426	-91.6032111512098481
46372	2020-08-20 06:43:48	2020-08-20	Dr. Oren Beer	dr.oren.beer@geemail.com	San Francisco	California	3158485492744242564	ffebb181d1986953c22a0ee8e6f075bc	JCB 16 digit	37.8134343940112672	-122.438369519479437
46373	2020-08-20 06:45:41	2020-08-20	Federico Nader	federico.nader@geemail.com	Seattle	Washington	3088910825573262085	83d187e071939433b4fd4ffcd1d7deb9	Diners Club / Carte Blanche	47.5423382241670041	-122.398718964673208
46374	2020-08-20 06:45:44	2020-08-20	Bode Olson	bode.olson@woohoo.com	Billings	Montana	180003465983029812	286287d9ccbccc6f159f4b019bc8e7ef	JCB 16 digit	45.862182755464687	-108.635253978676715
46375	2020-08-20 06:53:33	2020-08-20	Abby Senger-Bechtelar	abby.senger.bechtelar@geemail.com	Bakersfield	California	6011906123975271128	2c035ec6a1b1815e8a1af4a866c4a8e5	Voyager	35.4128488391347176	-119.106578110139068
46376	2020-08-20 07:12:58	2020-08-20	Jerod Von	jerod.von@warmmail.com	San Francisco	California	869993315507734622	1a599355de240f5b8c8a526f425831e0	JCB 16 digit	37.7792691440957853	-122.443830509233493
46377	2020-08-20 07:13:00	2020-08-20	Dr. Penny Reilly DDS	dr.penny.reilly.dds@geemail.com	Oakland	California	675972969335305	a05535a435723d58daf982fd439e2fcc	Voyager	37.822675059342366	-122.289164176153918
46378	2020-08-20 07:17:56	2020-08-20	Kayla Daniel	kayla.daniel@woohoo.com	Durham	North Carolina	676322101094013	28ba9a2d8449adeac3a987cbccc51bd2	Voyager	35.8863163020241984	-78.9956643549628552
46379	2020-08-20 07:26:54	2020-08-20	Fitzgerald Deckow	fitzgerald.deckow@woohoo.com	Palmdale	California	3004544844162878	0cd8ebef8a84f6747ca466912a1103e3	American Express	34.654117615319791	-118.071333011565358
46380	2020-08-20 07:28:54	2020-08-20	Miss Jaden Witting DVM	miss.jaden.witting.dvm@geemail.com	Riverside	California	180001927535533353	4cb75f8e352ad9c0e788d85cbc916d89	Voyager	33.8556037437118604	-117.380625410700958
46381	2020-08-20 07:31:56	2020-08-20	Mr. Carroll Parker	mr.carroll.parker@geemail.com	Tulsa	Oklahoma	180022913874866989	bab6525a4a9d7a58257b7cb606148c0a	Maestro	36.0870998585965452	-95.9116658915720848
46382	2020-08-20 07:35:16	2020-08-20	Jeanine Beatty	jeanine.beatty@geemail.com	Houston	Texas	3496582005490380	747950b66782c51173b5dd0d3d6e8b2b	Voyager	29.8655945267140872	-95.4448900838863068
46383	2020-08-20 07:44:20	2020-08-20	Ms. Alline Gulgowski DVM	ms.alline.gulgowski.dvm@geemail.com	Springfield	Missouri	3026789745330623	cc97a955f456d55813a027b28db7905a	Mastercard	37.2585257781397559	-93.3354527113784229
46384	2020-08-20 07:45:33	2020-08-20	Mr. Johnson Pollich	mr.johnson.pollich@geemail.com	New York	New York	3112261116577245119	d04d119339f358515d9308450042b3fd	Discover	40.5694213784057638	-73.9939336720749736
46385	2020-08-20 07:46:39	2020-08-20	Kerry Cole-Swift	kerry.cole.swift@geemail.com	San Francisco	California	6011753791857655271	00689b4a12a8e1ab3d52645434687d75	JCB 16 digit	37.7638865126959331	-122.408369802467163
46386	2020-08-20 07:50:32	2020-08-20	Mr. Elvis Ward	mr.elvis.ward@geemail.com	Orlando	Florida	4687679961601	bcdd9de38abac2c9c5dbf7d3681672dc	VISA 16 digit	28.4882917228419323	-81.2031711760874799
46387	2020-08-20 07:53:08	2020-08-20	Issac Batz	issac.batz@warmmail.com	New York	New York	869995506071725743	4c9dd1292fda7135f1b7f256ba0b3510	Maestro	40.7285345822330527	-73.9840837844543131
46388	2020-08-20 07:53:34	2020-08-20	Darian Lindgren	darian.lindgren@geemail.com	Oakland	California	3038843209333249	27fa448c2ece103818a730509a25fd41	VISA 13 digit	37.821615599954697	-122.270944036931027
46389	2020-08-20 08:04:51	2020-08-20	Braiden Halvorson	braiden.halvorson@geemail.com	Irving	Texas	060481174400580	3068098b29783cdb781f84e407f77d7e	Discover	32.9574770623303976	-97.0472904647979817
46390	2020-08-20 08:07:15	2020-08-20	Enzo Jacobson	enzo.jacobson@woohoo.com	Norman	Oklahoma	3337635261841109268	d7ef84d1fc0a55720e8bd348b9537492	American Express	35.2758635246701573	-97.3819783511824824
46391	2020-08-20 08:08:32	2020-08-20	Jasiah Leffler	jasiah.leffler@geemail.com	Hillsboro	Oregon	53369235055545013	9c31a920c4ffe1d23536005feef8d36c	VISA 16 digit	45.5526934968978168	-123.017030944830552
46392	2020-08-20 08:22:49	2020-08-20	Dr. Oma Gaylord	dr.oma.gaylord@geemail.com	San Diego	California	210087264690087679	8ac311cafabd8f9725a7b621ecc2e03f	Diners Club / Carte Blanche	32.7455496521733735	-117.129146384950729
46393	2020-08-20 08:26:42	2020-08-20	Dr. Joeseph Dare PhD	dr.joeseph.dare.phd@geemail.com	Westminster	Colorado	3112870766189554291	3f12f64c11deb3a841cc95d6b8a30d3b	JCB 16 digit	39.9683376762855787	-104.994575309022892
46394	2020-08-20 08:26:46	2020-08-20	Mr. Ham Altenwerth	mr.ham.altenwerth@geemail.com	Henderson	Nevada	4364653664193	9aa3fa290d3f890b6d8d9d84e35d699f	JCB 15 digit	35.9277067395791434	-114.963670347087842
46395	2020-08-20 08:27:36	2020-08-20	Toby Oberbrunner	toby.oberbrunner@geemail.com	Burbank	California	869927576379020801	c7567c91327cea283bdcf770b26981b6	Maestro	34.1658556506432589	-118.39692194173449
46396	2020-08-20 08:29:45	2020-08-20	Devon DuBuque	devon.dubuque@geemail.com	San Francisco	California	060497623017916	13360326fe990df888e1d7415f656e61	VISA 13 digit	37.7745773458564003	-122.411835891960919
46397	2020-08-20 08:33:02	2020-08-20	Dr. Shelvie Kshlerin	dr.shelvie.kshlerin@woohoo.com	Fremont	California	4958077085123	8417a2b42659a893599863fac109d290	Voyager	37.524445930466058	-121.895374129711456
46398	2020-08-20 08:45:20	2020-08-20	Helena Morar	helena.morar@woohoo.com	Winston–Salem	North Carolina	4035316523462850	88e78910cb4e7b16b970cfc58cf05fca	Voyager	36.1165489434495584	-80.2268875035122022
46399	2020-08-20 08:53:39	2020-08-20	Lacey Bosco	lacey.bosco@geemail.com	Ann Arbor	Michigan	869970678693408724	149b534455dc6586786f60af12ccd69e	JCB 15 digit	42.3635314782675323	-83.783720033859467
46400	2020-08-20 08:59:40	2020-08-20	Carey Beatty	carey.beatty@geemail.com	Portland	Oregon	6011241928352936166	cb11db5611980474cc87131948cf2177	Maestro	45.4577471422851076	-122.6433282178361
46401	2020-08-20 09:04:39	2020-08-20	Clemens Beier DVM	clemens.beier.dvm@geemail.com	Tulsa	Oklahoma	210029193858739279	0e14e003baf9259683d10ee8e8f2f530	Discover	36.1370420249082116	-95.9066845690786778
46402	2020-08-20 09:09:10	2020-08-20	Ms. Tana Metz	ms.tana.metz@geemail.com	Brownsville	Texas	3055742356724577	6c4c0bd33fb92fddf8d083c62bc84ace	JCB 16 digit	26.0390353417102247	-97.4418000274989708
46403	2020-08-20 09:10:58	2020-08-20	Gee West	gee.west@geemail.com	Santa Rosa	California	180016525772660963	a2829767f794db1d5882236ccf963d9a	Maestro	38.4688540900714742	-122.609108982632321
46404	2020-08-20 09:25:25	2020-08-20	Vira Turcotte	vira.turcotte@geemail.com	Oklahoma City	Oklahoma	3158444728627621097	10fcebfc1505833a255cd8025ee5e69a	VISA 13 digit	35.457535709198936	-97.6130285860400591
46405	2020-08-20 09:28:24	2020-08-20	Madeline Roberts	madeline.roberts@geemail.com	Joliet	Illinois	3491949915750739	f22926a6e58394d930c3a992f8ed5b6a	Maestro	41.5211378983546027	-88.1726677917979629
46406	2020-08-20 09:32:32	2020-08-20	Dr. Mozella Wisoky	dr.mozella.wisoky@woohoo.com	Carrollton	Texas	3528258660285602355	ea7fa16ed876b232ba808e7837b46cb9	American Express	32.9004551482774303	-96.9249489811111289
46407	2020-08-20 09:48:40	2020-08-20	Paityn Johns-Walker	paityn.johns.walker@woohoo.com	Berkeley	California	4236863945378443	3aa777bec3aa871dbd35cd563b3ff29c	JCB 15 digit	37.8588168083838852	-122.251046795278043
46408	2020-08-20 09:49:47	2020-08-20	Kobe Koelpin II	kobe.koelpin.ii@woohoo.com	Washington	District of Columbia	3528311228547243114	7bb0fb8db6d28e0294ac843db14df7fa	American Express	38.9821356594827009	-76.9367223810151302
46409	2020-08-20 09:53:33	2020-08-20	Rodrick Kulas	rodrick.kulas@geemail.com	New York	New York	3158048065416474911	6d20ce8fd9568bdfadbc7b382c5b77d9	VISA 13 digit	40.6297828559055887	-74.0243374511495205
46410	2020-08-20 09:56:54	2020-08-20	Hector Keeling-Nader	hector.keeling.nader@geemail.com	Salinas	California	3088195269707942351	b4231b7edbf4a74d2f42c5675eac0219	VISA 16 digit	36.7896851992465557	-121.644212669617318
46411	2020-08-20 10:00:20	2020-08-20	Miss Darian Huels	miss.darian.huels@woohoo.com	Louisville	Kentucky	3158979757124904626	aff442caabbdfc0c33e625ef23561c6c	Discover	38.2327647939227475	-85.6651238977514282
46412	2020-08-20 10:09:16	2020-08-20	Clarissa Bradtke	clarissa.bradtke@geemail.com	Detroit	Michigan	4128573153378537	e016b9189c59d517d96ef44aa7c4ca61	VISA 16 digit	42.3831512099523096	-83.0431537532366804
46413	2020-08-20 10:11:10	2020-08-20	Carmine Carter-Durgan	carmine.carter.durgan@geemail.com	North Las Vegas	Nevada	4230636929546573	2650d9338c42a882cd60717b68d120c5	VISA 16 digit	36.2027738217886537	-115.092299881273519
46414	2020-08-20 10:19:07	2020-08-20	Shaina Graham	shaina.graham@geemail.com	Austin	Texas	3096011986661810959	b29c0eb7c31a63dd60c12002f7080d43	VISA 13 digit	30.2832967816047365	-97.7308316469896567
46415	2020-08-20 10:20:00	2020-08-20	Madelene Prosacco PhD	madelene.prosacco.phd@geemail.com	Simi Valley	California	3088169617569558131	40378b4d53e4ac2ce61eb7003e9929a8	American Express	34.3172841823898267	-118.692452979100878
46416	2020-08-20 10:23:05	2020-08-20	Beecher Ledner	beecher.ledner@geemail.com	Glendale	Arizona	869900614105943961	c0a5fb24d06f28489ee88ed8a5dd366d	Discover	33.589083493477105	-112.23998833212778
46417	2020-08-20 10:27:36	2020-08-20	Samson Barrows	samson.barrows@warmmail.com	Odessa	Texas	210028227492662017	dc759205d3e65852eae82285145d24d6	Discover	31.9339633784733721	-102.393078578744451
46418	2020-08-20 10:27:53	2020-08-20	Lou Rutherford	lou.rutherford@warmmail.com	Los Angeles	California	4287466099867696	a8df3a643f67927a884b3f74a6837bb4	JCB 15 digit	33.9650938828341609	-118.481444022803743
46419	2020-08-20 10:28:07	2020-08-20	Verner Larson I	verner.larson.i@warmmail.com	Richmond	Virginia	4469686701380602	7b8ac7218355c046c512f503b2b53b49	Voyager	37.4920605322100187	-77.4535639110244745
46420	2020-08-20 10:31:25	2020-08-20	Fiona Ritchie	fiona.ritchie@geemail.com	New York	New York	4003939178897	73d123126b9bfaa3170186da59056c89	Maestro	40.5947115026637917	-73.888480232599008
46421	2020-08-20 10:38:06	2020-08-20	Shavon Mohr	shavon.mohr@geemail.com	Eugene	Oregon	4931431638796	583cd85c0f064bbfa4f1d60f007ed890	Maestro	44.1525625464234466	-123.125871389963478
46422	2020-08-20 10:47:54	2020-08-20	Donnell Fadel	donnell.fadel@warmmail.com	Oakland	California	501872188264757	a19c49d4bee455c7e1a4f02e9e02fb43	Discover	37.7984079600861023	-122.271365989933258
46423	2020-08-20 11:00:23	2020-08-20	Kamryn Von	kamryn.von@warmmail.com	Pearland	Texas	210051120438496261	d0ffa462bfe8f4353c7372d293999259	American Express	29.6268277077741935	-95.3398397099081336
46424	2020-08-20 11:00:43	2020-08-20	Gottlieb Kerluke	gottlieb.kerluke@geemail.com	Modesto	California	180042663557746760	e788418992dcaaa62ea8a3a45fe91ecf	Diners Club / Carte Blanche	37.7198488278780175	-120.972277698034418
46425	2020-08-20 11:03:04	2020-08-20	Mr. Elzie Rath	mr.elzie.rath@geemail.com	New York	New York	501899745444192	367cd017c4756d6680262713c9c8fc1e	Discover	40.6572197825405723	-73.9684408854588895
46426	2020-08-20 11:10:45	2020-08-20	Judyth Brakus	judyth.brakus@warmmail.com	Winston–Salem	North Carolina	3088314991095815404	c902bbe62e428f7eaf4f73ae56a15710	Discover	36.1141519192371518	-80.2278438517488439
46427	2020-08-20 11:24:38	2020-08-20	Vikki Bahringer	vikki.bahringer@geemail.com	Oakland	California	3096411568214961681	be5e211b9f0c3df185287a375eda630c	VISA 16 digit	37.7787722376199468	-122.270707647582498
46428	2020-08-20 11:31:08	2020-08-20	Adelia Luettgen	adelia.luettgen@geemail.com	Chicago	Illinois	4798301133816544	87cf0cb1ca0c13b27edebaa4345f99d7	VISA 13 digit	41.8880525271244366	-87.7722567862860785
46429	2020-08-20 11:57:01	2020-08-20	Kiara Beatty	kiara.beatty@geemail.com	Riverside	California	6011485992417285949	62fb788820804484e836b3924ac63c22	Mastercard	33.9753875344008165	-117.312645230066764
46430	2020-08-20 12:13:12	2020-08-20	Nova Morissette	nova.morissette@geemail.com	Chicago	Illinois	060407200886179	7d9a3d14c0890e6175cb600a1c690ed9	JCB 15 digit	41.7614187923561815	-87.7624501256767644
46431	2020-08-20 12:15:38	2020-08-20	Evander Towne	evander.towne@geemail.com	Amarillo	Texas	869979068733210994	5852f36e12eeb5d12451a2c4ad9a30d4	Maestro	35.2408583842381802	-101.762907375427716
46432	2020-08-20 12:20:14	2020-08-20	Tamia Mitchell	tamia.mitchell@geemail.com	Winston–Salem	North Carolina	4668729345318	0e6e99fcbf2677d2b778acd64762148d	VISA 13 digit	36.1761877073206009	-80.1657382396645772
46433	2020-08-20 12:22:51	2020-08-20	Georgette Wisoky	georgette.wisoky@geemail.com	El Monte	California	869910073394643220	0244d247fe6bc7921494da681f315b27	JCB 16 digit	34.0119775895219263	-118.000957000095767
46434	2020-08-20 12:28:09	2020-08-20	Jake Mertz	jake.mertz@geemail.com	San Francisco	California	869986724925949887	fd8d35fd0e17c9d6eeb355ce07c33234	Discover	37.8034814752787298	-122.390767362435867
46435	2020-08-20 12:29:43	2020-08-20	Mattye Stamm	mattye.stamm@geemail.com	Macon	Georgia	4277144285474161	579947bf0d875b7e15642921c4e58f9e	Maestro	32.8221981200400705	-83.621722442257024
46436	2020-08-20 12:35:22	2020-08-20	Candida Treutel PhD	candida.treutel.phd@geemail.com	Oxnard	California	4924678317034136	9800431fa4a898f59f1afba388482fb7	JCB 15 digit	34.1638500903688396	-119.228516784441098
46437	2020-08-20 12:36:38	2020-08-20	Jessee Nader	jessee.nader@warmmail.com	Oakland	California	3031280249857779	9394a4a4dd1fe42c944420469b52277a	JCB 16 digit	37.8066407050378785	-122.256605436186916
46438	2020-08-20 12:37:55	2020-08-20	Collette Windler-Lehner	collette.windler.lehner@geemail.com	Pittsburgh	Pennsylvania	676284670308794	1f0b762ec3b7d12d8d0b123eef0e3dbe	VISA 13 digit	40.3481021073602122	-80.0749330868184614
46439	2020-08-20 12:45:33	2020-08-20	Dr. Montana Kuvalis	dr.montana.kuvalis@geemail.com	Fresno	California	3088440460585896420	764d0aac662f0fe8161b21b0e734d613	JCB 15 digit	36.8035535543099073	-119.727333987934145
46440	2020-08-20 12:47:51	2020-08-20	Florence Lindgren DDS	florence.lindgren.dds@geemail.com	Allentown	Pennsylvania	4678870866454884	42b1f0658dac5a5c9ef6ee330e395455	VISA 16 digit	40.5496301959980272	-75.5306129379678453
46441	2020-08-20 12:49:21	2020-08-20	Dr. Raiden Johns	dr.raiden.johns@woohoo.com	Lakewood	New Jersey	54387590220255478	86f388dddf349daf3950fdc3149e3000	Discover	40.0452164762936533	-74.1456886348124584
46442	2020-08-20 13:05:35	2020-08-20	Tennille Abernathy	tennille.abernathy@warmmail.com	Lakeland	Florida	3057832096477921	e53088e3a136d8ae57f8c0b0240ea8df	Mastercard	27.9740125540010602	-82.0394591616351079
46443	2020-08-20 13:16:53	2020-08-20	Enos Leffler	enos.leffler@geemail.com	Sacramento	California	6011776438331507172	683a27999722bf05543e1713c19d80ba	Maestro	38.5803085883878154	-121.402241638467089
46444	2020-08-20 13:20:35	2020-08-20	Corliss Smith	corliss.smith@geemail.com	Chula Vista	California	4655264210619	03f9aabcf1f5b9be5f088f3cfcd3ce4f	VISA 16 digit	32.6925646481335122	-116.939814554690187
46445	2020-08-20 13:22:06	2020-08-20	Valencia Feest	valencia.feest@geemail.com	Chicago	Illinois	4515420431213949	4ac1e1f4030caf7f84b5b386ac40646b	VISA 13 digit	41.9148152038756763	-87.6940295154724225
46446	2020-08-20 13:26:56	2020-08-20	Raymond Rohan PhD	raymond.rohan.phd@geemail.com	Las Vegas	Nevada	55713888509526402	b026873e55de447b558316dfd25e641e	VISA 13 digit	36.1651884618781523	-115.195830119049546
46447	2020-08-20 13:28:50	2020-08-20	Ariane Abshire	ariane.abshire@geemail.com	Sioux Falls	South Dakota	53907055519995706	2e84ec55d67a6f692c7be4db148f959f	JCB 16 digit	43.4462683397896612	-96.6563511688429884
46448	2020-08-20 13:41:47	2020-08-20	Whitney Jerde	whitney.jerde@geemail.com	Vancouver	Washington	54081580575329464	8fd855740900ff72f441dbfb9c34220e	JCB 15 digit	45.5692865966890039	-122.506073183805483
46449	2020-08-20 14:05:48	2020-08-20	Adriane Olson DVM	adriane.olson.dvm@woohoo.com	Allen	Texas	53277657025671937	7af431a7d31f6eeeb2084cd697e923f2	VISA 16 digit	33.1197366563163698	-96.6450053390529007
46450	2020-08-20 14:06:42	2020-08-20	Lura Jacobi	lura.jacobi@geemail.com	Columbus	Georgia	55231122458500975	88a4f71149f19f248d09dfacf8cb3d96	Discover	32.5812154724772967	-84.8798815145321157
46451	2020-08-20 14:10:47	2020-08-20	Leatha Rutherford	leatha.rutherford@woohoo.com	Huntington Beach	California	869979237842997102	6bccef7ba38bed3d660086503aef75ce	JCB 15 digit	33.6855896220117828	-117.911391710548841
46452	2020-08-20 14:15:34	2020-08-20	Sydnee Mayert	sydnee.mayert@woohoo.com	Santa Rosa	California	52672135497450123	62dd1e0774f1b435d8a8ba346f35f4f8	Maestro	38.3901934211265328	-122.672405935336286
46453	2020-08-20 14:18:55	2020-08-20	Demetrius Dickens III	demetrius.dickens.iii@woohoo.com	Los Angeles	California	51899218832052783	da16083b0824f23e44f7c7b6d7f50cd7	VISA 16 digit	33.95036578083932	-118.317948315710936
46454	2020-08-20 14:32:15	2020-08-20	Mrs. Jenni Buckridge DDS	mrs.jenni.buckridge.dds@geemail.com	Louisville	Kentucky	180061773991093624	a74b8e4623696b29e9948734f69c9d3f	JCB 16 digit	38.0735494545098376	-85.6806474110648111
46455	2020-08-20 14:34:17	2020-08-20	Glenna Douglas-Spinka	glenna.douglas.spinka@woohoo.com	New York	New York	3051367031351937	d4372d4bb558b6e7ed0b82c6de12a8ca	Maestro	40.5790461144167907	-73.9892654520820798
46456	2020-08-20 14:46:48	2020-08-20	Dorathy Mraz	dorathy.mraz@woohoo.com	Salt Lake City	Utah	52317124060908379	ed69a8253e1aadf12e6040905945a43f	Maestro	40.7776434954401097	-111.838697410928077
46457	2020-08-20 14:52:51	2020-08-20	Ashley Yost-Pollich	ashley.yost.pollich@woohoo.com	Santa Maria	California	869979810934211234	3c37708085dbe47d78858eec1a8baa93	JCB 16 digit	34.9169108146399267	-120.41508244591877
46458	2020-08-20 15:01:46	2020-08-20	Dr. Zeke Gleason Sr.	dr.zeke.gleason.sr.@geemail.com	Berkeley	California	3055072466157744	1cfc5fe6659aab3b40b291b7787a9d20	American Express	37.8572691046721914	-122.254063162426547
46459	2020-08-20 15:09:05	2020-08-20	Ms. Esther McClure DDS	ms.esther.mcclure.dds@geemail.com	Philadelphia	Pennsylvania	869937215689744705	f06feec22515806aea63ea9035c6d6de	Diners Club / Carte Blanche	39.9573742084164181	-75.2200365195415941
46460	2020-08-20 15:16:16	2020-08-20	Sheldon Watsica	sheldon.watsica@woohoo.com	New York	New York	4277614883989018	e26439be7fb3d15a4ff573a0f9f1efdb	JCB 16 digit	40.6770762592311925	-74.008949133137989
46461	2020-08-20 15:16:34	2020-08-20	Irl Beier	irl.beier@geemail.com	Atlanta	Georgia	3766028340493172	b0336147455d57c2f279241c727ab9eb	JCB 16 digit	33.8146486992757787	-84.5209932407874618
46462	2020-08-20 15:23:01	2020-08-20	Gaylord Greenfelder	gaylord.greenfelder@geemail.com	New York	New York	3041259334852770	0970ec1852546081b2e0091f0bd84ae5	VISA 13 digit	40.5930586623251415	-73.8463385717373342
46463	2020-08-20 15:31:06	2020-08-20	Carleigh Hoppe-Cassin	carleigh.hoppe.cassin@woohoo.com	San Jose	California	180031307379031448	f33e226dc4915facaac5a94a8c86cb1b	VISA 16 digit	37.2965060793615919	-121.726514473719149
46464	2020-08-20 15:31:22	2020-08-20	Dr. Sandy Kulas	dr.sandy.kulas@warmmail.com	Berkeley	California	210056236970208370	a4178844f1b85ffb1382f07cc90a9c12	VISA 16 digit	37.891524771982418	-122.277514883030875
46465	2020-08-20 15:37:19	2020-08-20	Tilda Runte	tilda.runte@geemail.com	Arlington	Texas	3096017089333535767	a9bf05bf3105819f86260d43549935b3	Mastercard	32.6627646680239536	-97.1256200647473378
46466	2020-08-20 15:42:05	2020-08-20	Reid Welch PhD	reid.welch.phd@geemail.com	Fort Worth	Texas	4298307792138158	89c7311a46d4eb65a7bbe397c07401f7	Discover	32.713291339768098	-97.2758676491498875
46467	2020-08-20 15:47:14	2020-08-20	Minor Wunsch	minor.wunsch@geemail.com	Philadelphia	Pennsylvania	3040412492334245	85e3a48d04b463d8b1f7af722f6a1eed	VISA 16 digit	40.0813872064888486	-75.0564934649404165
46468	2020-08-20 16:09:09	2020-08-20	Tal Aufderhar	tal.aufderhar@geemail.com	Kansas City	Missouri	4463349408697101	b47dfaa44d57141ab77691e1ddafacf4	Diners Club / Carte Blanche	39.2237534771975191	-94.6216078168004771
46469	2020-08-20 16:11:20	2020-08-20	Cloe Kshlerin-Robel	cloe.kshlerin.robel@geemail.com	Wichita	Kansas	3112906650139982786	01b9bda47c3c33786202d6a97f8a3e8f	Maestro	37.6687044671613691	-97.2762659044671807
46470	2020-08-20 16:31:29	2020-08-20	Kody Mertz	kody.mertz@geemail.com	Fresno	California	3045352624895876	db6a1b73998637278b275a1499288a62	JCB 16 digit	36.804724097937715	-119.710443169215324
46471	2020-08-20 17:15:41	2020-08-20	Carolina Rau	carolina.rau@geemail.com	Glendale	Arizona	210070925612342736	c543307452ca8811c36811babcf45b06	Discover	33.5055880266003285	-112.235844700390089
46472	2020-08-20 17:20:05	2020-08-20	Piper Baumbach	piper.baumbach@woohoo.com	Philadelphia	Pennsylvania	3798538190261570	0c3a7c478a74fb6f43e321a29e109e4e	VISA 16 digit	40.0682660743553214	-75.0378912916772123
46473	2020-08-20 17:22:32	2020-08-20	Doloris Kemmer DDS	doloris.kemmer.dds@woohoo.com	Nashville	Tennessee	180095988907946620	2fb7c0b9dd73d05e506382f664c7222d	Discover	36.0790024489752952	-86.716531854718923
46474	2020-08-20 17:22:34	2020-08-20	Leilani Larson	leilani.larson@geemail.com	Oklahoma City	Oklahoma	4243261848572	569e5f66caff42e062389adffd60f1bf	VISA 16 digit	35.544174391581123	-97.5508606116648735
46475	2020-08-20 17:33:51	2020-08-20	Mrs. Treena Wiza	mrs.treena.wiza@geemail.com	San Jose	California	675962856655105	3c347393f30491dff369a749ba443513	VISA 16 digit	37.2402838023200644	-121.778256221323829
46476	2020-08-20 17:43:24	2020-08-20	Mrs. Evelynn Braun	mrs.evelynn.braun@woohoo.com	New York	New York	589377655706099	4d892ca78ccc9846ba42532e2019637b	VISA 16 digit	40.6803908266350618	-73.910467006441948
46477	2020-08-20 17:58:17	2020-08-20	Dr. Trey Kunde	dr.trey.kunde@woohoo.com	Little Rock	Arkansas	3088046457494639568	b1f7f3dfc535ac65cfa48dd1027e59c2	VISA 16 digit	34.6980785896345978	-92.2617063623726352
46478	2020-08-20 18:06:03	2020-08-20	Leisha Robel	leisha.robel@geemail.com	Berkeley	California	6011885502921316860	f534a941dbd31704da0da39e190db1aa	Voyager	37.870316552051797	-122.278928275209651
46479	2020-08-20 18:11:46	2020-08-20	Mr. Keagan Hauck	mr.keagan.hauck@geemail.com	Tulsa	Oklahoma	3112460120570241827	5b260d1492e04d361774c63ca7b332c6	VISA 16 digit	36.0980866936869873	-95.9209641554348167
46480	2020-08-20 18:25:37	2020-08-20	Odette Nader	odette.nader@geemail.com	Portland	Oregon	561222086643255	1ef49e0296155e755eea54e5abcf156a	VISA 16 digit	45.6058449855428165	-122.717006158130246
46481	2020-08-20 18:30:24	2020-08-20	Chas Hayes-Weissnat	chas.hayes.weissnat@woohoo.com	Milwaukee	Wisconsin	55995670517121999	eaa9a804d515bb97aca988c80e8e9e3e	Discover	43.0906321421351279	-88.0559182081937877
46482	2020-08-20 18:31:25	2020-08-20	Channie Wilkinson	channie.wilkinson@geemail.com	Billings	Montana	4706944429399922	631f62aac17133be870d73134b9232f3	VISA 16 digit	45.7186437372807433	-108.54117572509459
46483	2020-08-20 18:39:50	2020-08-20	Heidy Keeling	heidy.keeling@woohoo.com	New York	New York	6011531995132914325	7aca33893dca5afe665ee65ce819299b	Voyager	40.7450679343882953	-74.0249480964977238
46484	2020-08-20 18:54:33	2020-08-20	Gaetano Cummings	gaetano.cummings@geemail.com	Kansas City	Missouri	52846179057554651	32cfa671df931bd7cb5ff63ffb0d412c	VISA 16 digit	39.1990469615742612	-94.5586147526502572
46485	2020-08-20 19:00:22	2020-08-20	Santana Satterfield-Rau	santana.satterfield.rau@warmmail.com	Sandy Springs	Georgia	3158207021320121459	4e259912eaa00b867149749cceb678a2	Diners Club / Carte Blanche	34.0100569263156487	-84.3157484576188097
46486	2020-08-20 19:01:02	2020-08-20	Ivanna Hettinger	ivanna.hettinger@geemail.com	Midland	Texas	4037034065781771	bfcf14cca96e08e08fa26d6f3fcf3dfd	VISA 13 digit	32.1039341360986228	-102.195127920316537
46487	2020-08-20 19:11:49	2020-08-20	Duwayne Bogan	duwayne.bogan@geemail.com	Dallas	Texas	3528407911507120514	4629db067685669c124370234bf7afb5	JCB 16 digit	32.8186910034429289	-96.8555555525198457
46488	2020-08-20 19:12:54	2020-08-20	Annabelle Abernathy MD	annabelle.abernathy.md@warmmail.com	San Francisco	California	180039250421796588	f42fdb9743ef79eecf9124f1c07ed14e	American Express	37.7593934333566565	-122.439489315278507
46489	2020-08-20 19:23:42	2020-08-20	Dr. Brooklyn Senger DVM	dr.brooklyn.senger.dvm@warmmail.com	Long Beach	California	3088832474597068395	4bac5d01baa56019c74b0b88db17c8cc	VISA 16 digit	33.8793974412891998	-118.247445900102335
46490	2020-08-20 19:31:51	2020-08-20	Beatrix Purdy-Kertzmann	beatrix.purdy.kertzmann@geemail.com	Cape Coral	Florida	3096216038542447917	397d180ef0d0ea4b005a2de8d0f641ac	Mastercard	26.7359717504091563	-82.0183370280615947
46491	2020-08-20 19:32:20	2020-08-20	Fannye Howell	fannye.howell@geemail.com	Chesapeake	Virginia	3112729520091068889	e34b4750708e9c27b3b1d3695a819726	Voyager	36.6233715595915896	-76.3310301329318435
46492	2020-08-20 19:32:42	2020-08-20	Shameka Beahan MD	shameka.beahan.md@warmmail.com	New York	New York	561254365949194	ed1cc3ff58d497490a0b1ac84be37f01	JCB 16 digit	40.7359311467725789	-73.9673913150455746
46493	2020-08-20 19:36:56	2020-08-20	Garrison Weimann-Dickens	garrison.weimann.dickens@warmmail.com	San Francisco	California	6011523563256341798	7c73d28965baa05ede51c6ff73950c36	Voyager	37.7936678648285707	-122.424292447542257
46494	2020-08-20 19:42:29	2020-08-20	Ms. Clora Monahan	ms.clora.monahan@geemail.com	Atlanta	Georgia	3096222905759210679	566db84d558cedda42645bb8457c4c3a	VISA 16 digit	33.7014844045318682	-84.3570907892704014
46495	2020-08-20 19:49:28	2020-08-20	Jasmine Swift	jasmine.swift@geemail.com	Indianapolis	Indiana	52497789472861580	acf79f23d47b217016f7c440c1b948ff	Voyager	39.8554714511621739	-86.1047649314362502
46496	2020-08-20 19:51:44	2020-08-20	Dr. Jame Lindgren	dr.jame.lindgren@geemail.com	Chicago	Illinois	869907242048793468	fa0de475546c27fbadf8655e3318c1ab	Discover	41.8272270201541474	-87.6805723927944882
46497	2020-08-20 19:55:03	2020-08-20	Loni Kuhlman	loni.kuhlman@geemail.com	San Antonio	Texas	3088299425434677075	c121a6ef55216af01535bc99a41ca6fb	VISA 13 digit	29.4659191240161675	-98.5097326375380078
46498	2020-08-20 19:55:52	2020-08-20	Shirley Beer	shirley.beer@geemail.com	Anaheim	California	210093680637498152	c637a60951e857ee99394e374a0bc50b	VISA 16 digit	33.9369868146087938	-117.664161046708372
46499	2020-08-20 19:59:16	2020-08-20	Mr. Brandyn Casper DVM	mr.brandyn.casper.dvm@geemail.com	San Francisco	California	639032503586722	90441ff9e27b28304a5ba0659c584930	VISA 13 digit	37.791255505109234	-122.427717297280182
46500	2020-08-20 20:00:04	2020-08-20	Dr. Zhane Herzog MD	dr.zhane.herzog.md@geemail.com	Seattle	Washington	869996142369948836	6b4ad834352a612211d29d3f8aa1c844	American Express	47.7084010704345971	-122.422680889248468
46501	2020-08-20 20:03:41	2020-08-20	Aaron Altenwerth-Schaden	aaron.altenwerth.schaden@geemail.com	Houston	Texas	3528621800623352699	b71e1493ec85191a125fc307dd221b84	Voyager	29.814608035058157	-95.4353654985331019
46502	2020-08-20 20:17:23	2020-08-20	Melva Schultz	melva.schultz@geemail.com	West Palm Beach	Florida	210026099177070317	5e7314ae220731362cf762a4db92ff0c	Diners Club / Carte Blanche	26.6799590265691293	-80.1420738475699039
46503	2020-08-20 20:22:45	2020-08-20	Dr. Elzy Ferry Jr.	dr.elzy.ferry.jr.@geemail.com	New York	New York	6011683780982207590	48e2efeaf7f0380ebae35e28d7c305d5	Mastercard	40.6884626332428283	-74.0327793930087239
46504	2020-08-20 20:25:00	2020-08-20	Ms. Sarrah Herzog	ms.sarrah.herzog@woohoo.com	Pompano Beach	Florida	4779749609763	7989b569c35868cff0ccef16ab41c959	JCB 16 digit	26.1784709014728634	-80.0718380180034757
46505	2020-08-20 20:30:09	2020-08-20	Mrs. Permelia Bashirian	mrs.permelia.bashirian@geemail.com	San Francisco	California	3720395557140985	963d661a96d0ddbfb83f6587091da928	Discover	37.7663286826674778	-122.446626587716167
46506	2020-08-20 20:31:35	2020-08-20	Evander Nolan	evander.nolan@geemail.com	Jacksonville	Florida	6011981472354007449	405669e89142b1c7656a50f8fde42cc9	JCB 16 digit	30.4247325243946172	-81.6481056169219386
46507	2020-08-20 20:32:53	2020-08-20	Kael Jaskolski	kael.jaskolski@woohoo.com	Fort Worth	Texas	3158536708100495366	4f716e9c9f088ae9d26e42c0a6c48335	Maestro	32.7456536298673626	-97.2829856691703156
46508	2020-08-20 20:58:41	2020-08-20	Haleigh Heller	haleigh.heller@geemail.com	Long Beach	California	3088716619721581868	a4ba83322e39d1d344b72ed09560f1c4	JCB 15 digit	33.8546080836381762	-118.169316487775362
46509	2020-08-20 21:06:22	2020-08-20	Kloe Stehr	kloe.stehr@geemail.com	Lincoln	Nebraska	4382865358265134	b776b1c5ce32fc5b78c499391dc9cd58	Voyager	40.8384627068433872	-96.6603688776653343
46510	2020-08-20 21:08:11	2020-08-20	Dr. Zara Stracke	dr.zara.stracke@warmmail.com	New York	New York	3415150797641400	d6a6ebe41b6e2f07e3255173aca372e0	Mastercard	40.6060581641960852	-73.9674976058200002
46511	2020-08-20 21:16:05	2020-08-20	Nelson Willms	nelson.willms@geemail.com	Baton Rouge	Louisiana	6011126497678543346	d82e43aeb1b09d788f3a48daa501b96c	VISA 16 digit	30.3700119931928825	-91.0468763331059279
46512	2020-08-20 21:17:22	2020-08-20	Britta Anderson-Fay	britta.anderson.fay@warmmail.com	Los Angeles	California	4733847174493	a9c720f0d77e6989008c4ef838d9bf19	American Express	34.0196400061581272	-118.471153676555673
46513	2020-08-20 21:18:04	2020-08-20	Georgiann Mills	georgiann.mills@geemail.com	Plano	Texas	3158524252441903634	331a9b47a29f7081dd99e03168ae2c7d	VISA 16 digit	33.1253604919269691	-96.8464267996322405
46514	2020-08-20 21:21:46	2020-08-20	Mrs. Crissy Hermann	mrs.crissy.hermann@geemail.com	New York	New York	3008752853206777	7310d00e9cd690b111b1a33dab1391ee	VISA 16 digit	40.6126395997349192	-73.9527650371555154
46515	2020-08-20 21:22:04	2020-08-20	Myron Quigley	myron.quigley@geemail.com	Oakland	California	210088303331913965	4f4898f276d5082ac204c232a75b22a6	Discover	37.8302631399690839	-122.267239975949309
46516	2020-08-20 21:25:28	2020-08-20	Ms. Rosario McKenzie MD	ms.rosario.mckenzie.md@woohoo.com	Houston	Texas	3096409711653491026	39c7a5fb854a29ce58c0e3088783f618	Mastercard	29.8313629153728499	-95.371328675329309
46517	2020-08-20 21:25:51	2020-08-20	Blain Kunze	blain.kunze@geemail.com	New York	New York	55968213201750907	e34430802652a8e0adc34a9ff96f2cc1	JCB 16 digit	40.7049646626915802	-73.9868760494410935
46518	2020-08-20 21:28:10	2020-08-20	Isaak Greenfelder-Goodwin	isaak.greenfelder.goodwin@geemail.com	New York	New York	51599352020847051	bf84acf86b59eb5d2b217268c7c6f8a7	American Express	40.7095441386327153	-73.9553248109657346
46519	2020-08-20 21:28:34	2020-08-20	Deanne Berge-Champlin	deanne.berge.champlin@geemail.com	Washington	District of Columbia	4049946004897903	355b408f2cd906ac808a1d0c2fe83461	JCB 16 digit	38.9739639021720734	-77.076138528317955
46520	2020-08-20 21:33:29	2020-08-20	Keenen Sipes	keenen.sipes@geemail.com	Tempe	Arizona	3446521021777371	faa6c633d840e8a413bad750e64c5c63	VISA 16 digit	33.4106008253447655	-111.935639317243542
46521	2020-08-20 21:34:01	2020-08-20	Reynolds Kuhic	reynolds.kuhic@geemail.com	Oceanside	California	869918038647479005	d57687c2951c03ccbbf4cbb83c505317	VISA 16 digit	33.253062305448573	-117.213701329062516
46522	2020-08-20 21:34:15	2020-08-20	Myrl Steuber	myrl.steuber@geemail.com	New York	New York	3096858952794091012	768ac68755f73c60b60deca0a2cd5c73	Maestro	40.6061846040878436	-74.0285117508739177
46564	2020-08-21 00:42:57	2020-08-21	Dr. Thor Welch	dr.thor.welch@geemail.com	Dallas	Texas	4505820110025930	b5a371fa5907ea3921fdb34f59d21f05	Maestro	32.7594168117076165	-96.8544346016328745
46523	2020-08-20 21:38:50	2020-08-20	Charlotta Cartwright	charlotta.cartwright@woohoo.com	New York	New York	3772146631505355	620396861ba6b3253d506a47a995498d	JCB 15 digit	40.6476457276605032	-73.8999291529308948
46524	2020-08-20 21:40:45	2020-08-20	Mr. Delos Legros Jr.	mr.delos.legros.jr.@geemail.com	New York	New York	4944384291563358	2f9c3e4357c0642bbfe72ac1e90af200	JCB 16 digit	40.7430029800385256	-73.9041057855717867
46525	2020-08-20 21:44:01	2020-08-20	Dr. Jobe Toy V	dr.jobe.toy.v@woohoo.com	Allentown	Pennsylvania	4759661377102	d3af4f80cb88a26ecc0115b5a374e820	JCB 16 digit	40.5813236476633747	-75.5508208198953355
46526	2020-08-20 21:53:43	2020-08-20	Denisha Gutmann DVM	denisha.gutmann.dvm@woohoo.com	Baltimore	Maryland	561200623187093	c2e9a362b4f4da7c11a760088c11b8f8	VISA 13 digit	39.3822153685148777	-76.5657800751756952
46527	2020-08-20 21:57:18	2020-08-20	Lora Kuhic-Runolfsson	lora.kuhic.runolfsson@geemail.com	San Francisco	California	3013031998028528	e84f6535bad708f26f13b457350f8b5c	Discover	37.7710963680995988	-122.44929713415597
46528	2020-08-20 22:00:49	2020-08-20	Ariane Schmidt MD	ariane.schmidt.md@geemail.com	College Station	Texas	210069700876125157	c736e53dc0fd6f9e21382b5af66884ae	Mastercard	30.6344911782115688	-96.2249053820815021
46529	2020-08-20 22:01:43	2020-08-20	Cleone Kautzer	cleone.kautzer@warmmail.com	Philadelphia	Pennsylvania	3096798210388257967	08ebfec21aeaec1ff880e0e6b344c3e4	JCB 15 digit	40.0073312202427545	-75.0831367833905006
46530	2020-08-20 22:03:26	2020-08-20	Lorrie Wintheiser	lorrie.wintheiser@geemail.com	San Francisco	California	4905901690917	b011761bc7622b0b07e7e77474b880fc	Diners Club / Carte Blanche	37.7758364472126971	-122.414958538126612
46531	2020-08-20 22:11:24	2020-08-20	Lotta Little	lotta.little@woohoo.com	Chesapeake	Virginia	6011843014927954943	d7a80fe1b6b8e8fd597f5ed193dee564	VISA 13 digit	36.7414827763807068	-76.3322413923062442
46532	2020-08-20 22:12:27	2020-08-20	Geovanni Klocko	geovanni.klocko@geemail.com	San Francisco	California	3438346852802522	85c583e8a06e9305523204658b816d70	Mastercard	37.7967266852470587	-122.448734935259324
46533	2020-08-20 22:18:18	2020-08-20	Dossie Bode MD	dossie.bode.md@geemail.com	Los Angeles	California	4825720485342378	547fb753e0df8d9bab83aee022e08166	Mastercard	34.0343371636565735	-118.447060594893244
46534	2020-08-20 22:23:10	2020-08-20	Gurney Mraz	gurney.mraz@woohoo.com	Nashville	Tennessee	4510210396629618	f460c8aa573da103461d0d0520fa6c65	VISA 13 digit	36.1842204314313776	-86.8258903295639897
46535	2020-08-20 22:30:17	2020-08-20	Mr. Kody Douglas PhD	mr.kody.douglas.phd@geemail.com	Los Angeles	California	6011207626024502356	8a805b170328bf9f1b995ce2696271af	JCB 15 digit	33.9817859607614565	-118.478259104023863
46536	2020-08-20 22:33:24	2020-08-20	Dr. Antwain Halvorson	dr.antwain.halvorson@geemail.com	New York	New York	3528776540131915529	3435f69b814813f19cd9f983bf738883	Maestro	40.7066136912666252	-73.90905538791678
46537	2020-08-20 22:39:50	2020-08-20	Uriah Harris	uriah.harris@geemail.com	Richmond	California	561287016220672	46eaafff1166d9f8e8fe911a48db111c	Mastercard	37.9548769570842381	-122.317259094896173
46538	2020-08-20 22:41:30	2020-08-20	Mr. Harlon Windler	mr.harlon.windler@geemail.com	Columbus	Ohio	4213854966913884	a12cbc59486a1387180211c7705e78a4	JCB 16 digit	39.9252139008648683	-83.0410334948685147
46539	2020-08-20 22:46:30	2020-08-20	Ransom Schmidt	ransom.schmidt@geemail.com	Dayton	Ohio	6011523590807627193	c0d31cbf7126cf2dc1d699618dbe797d	Diners Club / Carte Blanche	39.809274530063945	-84.1528100088428772
46540	2020-08-20 22:49:30	2020-08-20	Rusty Douglas	rusty.douglas@geemail.com	Austin	Texas	4340320480593	db3e54abb303144ba978320f8a07c2a4	Discover	30.2284322057045998	-97.744033266208703
46541	2020-08-20 22:50:07	2020-08-20	Raoul Heaney	raoul.heaney@warmmail.com	Oakland	California	3528407958937677886	8ed9ee1b3e35e42cb0784d679756ecd3	Mastercard	37.7587394668588487	-122.253698537070591
46542	2020-08-20 22:50:49	2020-08-20	Winnie Legros	winnie.legros@geemail.com	Phoenix	Arizona	4355491161475092	e1a5f273621bfd676b3441115cf700e9	JCB 16 digit	33.6173486376114212	-112.181647104110951
46543	2020-08-20 22:52:25	2020-08-20	Miss Shirleen Auer	miss.shirleen.auer@geemail.com	Fort Collins	Colorado	4276829625587	94b02ed671442671050e31a05fb27b77	VISA 16 digit	40.4740403471205425	-105.004357119179517
46544	2020-08-20 22:54:35	2020-08-20	Mr. Elick Cassin II	mr.elick.cassin.ii@woohoo.com	Las Vegas	Nevada	630487095167125	b8b7c58de292a9f27959db4960aa2573	Mastercard	36.3057569155570121	-115.185288913475716
46545	2020-08-20 23:12:06	2020-08-20	Miss Carlota Gorczany DVM	miss.carlota.gorczany.dvm@geemail.com	Phoenix	Arizona	54040753303134452	462e705564b058dbc87cc4f189968cc2	JCB 15 digit	33.5630415429759807	-112.0786112552438
46546	2020-08-20 23:15:37	2020-08-20	Yadira Hintz	yadira.hintz@warmmail.com	Davie	Florida	3022731822973325	bb7bb4834fcbcdaaa437fb24331635b0	American Express	26.0117037331484262	-80.3189131075888838
46547	2020-08-20 23:19:57	2020-08-20	Breana Hilpert	breana.hilpert@geemail.com	Orlando	Florida	3752466060988607	0fa3265e5873483ec3d21d174281850c	American Express	28.4535626577012231	-81.3232986026875722
46548	2020-08-20 23:21:01	2020-08-20	Jesus Brakus	jesus.brakus@geemail.com	Los Angeles	California	3776227640375158	09b0a2bfd96ea1f42844bace60ff8469	JCB 16 digit	34.016979628368837	-118.382524481182173
46549	2020-08-20 23:22:06	2020-08-20	Tillie Bartoletti-Klein	tillie.bartoletti.klein@woohoo.com	Long Beach	California	502017730108267	dcfa3dcc9f2549337e02bbc6893cf626	Diners Club / Carte Blanche	33.8708121674887792	-118.149730076796558
46550	2020-08-20 23:22:56	2020-08-20	Siddie Tromp	siddie.tromp@woohoo.com	Milwaukee	Wisconsin	6011296039212597653	5b184a803e525efb787bbdd05c02edeb	Diners Club / Carte Blanche	43.0712938929062332	-87.9139769168671279
46551	2020-08-20 23:25:41	2020-08-20	Raquel Runte	raquel.runte@geemail.com	Chicago	Illinois	4255816198105	3ead78cad4f24227d9d27c998097d7c7	American Express	41.9296849076472213	-87.6283811263769792
46552	2020-08-20 23:37:53	2020-08-20	Mr. Oswaldo Murphy	mr.oswaldo.murphy@geemail.com	Greeley	Colorado	3528550319870097506	cf92b6843b9c3f82062a349a25f92378	VISA 16 digit	40.4610478434778784	-104.683900159115723
46553	2020-08-20 23:40:17	2020-08-20	Ms. Delphine Marks	ms.delphine.marks@geemail.com	Orlando	Florida	676386888158341	beed55aa93a74481c1bbb11632e73031	JCB 16 digit	28.4468998179569823	-81.2989547254484108
46554	2020-08-20 23:53:45	2020-08-20	Bethany Prohaska	bethany.prohaska@warmmail.com	Colorado Springs	Colorado	3528533952590358808	9555dda913faf90eff2b75394388c4a2	American Express	38.9260467342149497	-104.748124989556899
46555	2020-08-20 23:55:13	2020-08-20	Dr. Bose Kuvalis	dr.bose.kuvalis@geemail.com	Baton Rouge	Louisiana	869959471981807400	4fbb695050435da6513093589f6b75d6	Voyager	30.4100767043165874	-91.0828924960564734
46556	2020-08-20 23:57:54	2020-08-20	Earle Treutel	earle.treutel@geemail.com	Atlanta	Georgia	4969798643710	785599fdb917805e4fbdf978cfec7acc	American Express	33.688528158263864	-84.5068310832649559
46557	2020-08-21 00:00:29	2020-08-21	Lady Bauch	lady.bauch@geemail.com	Chicago	Illinois	4672184421424	c1fd97213b7d10b55cfe288df7c228c0	VISA 16 digit	41.8236039443243328	-87.658284098890789
46558	2020-08-21 00:19:13	2020-08-21	Dr. Volney Bartell MD	dr.volney.bartell.md@geemail.com	Raleigh	North Carolina	4700583396366	18958352465cc90d619e3d24e60e4075	American Express	35.7671756576880782	-78.5927532566648068
46559	2020-08-21 00:22:15	2020-08-21	Alexus Herzog	alexus.herzog@geemail.com	Huntsville	Alabama	210046962857837618	499567c7f731be3eb261f4ab6dc2caab	Voyager	34.6129612914063003	-86.7194714689180302
46560	2020-08-21 00:23:40	2020-08-21	Americo Mills-Towne	americo.mills.towne@geemail.com	Grand Rapids	Michigan	6011642734787500741	b1e013fa197681727a6776d2f8aa7ccc	Mastercard	42.995533767741918	-85.6183938625868421
46561	2020-08-21 00:37:16	2020-08-21	Tanner Jacobson-Graham	tanner.jacobson.graham@geemail.com	San Francisco	California	869966990592797156	18ea744e913c141ab050531f87f414eb	VISA 16 digit	37.7729537183858284	-122.414956359512658
46562	2020-08-21 00:42:14	2020-08-21	Martez Kirlin	martez.kirlin@geemail.com	New York	New York	210088796706081732	c110202b1ae4fd9cbd5ccd246834a367	Maestro	40.6341915910821427	-73.9162219116825554
46563	2020-08-21 00:42:19	2020-08-21	Dr. Gael Keeling	dr.gael.keeling@warmmail.com	Oakland	California	210050707737776681	800634a9e5109df6abc6f19aa28d1d28	VISA 13 digit	37.7792141854086196	-122.233074160181147
46565	2020-08-21 00:47:48	2020-08-21	Prosper Bruen	prosper.bruen@warmmail.com	Overland Park	Kansas	676359042342911	b54fac48f523e2bd4cb46d26699c0c06	VISA 16 digit	38.8329742435235588	-94.6719241638708837
46566	2020-08-21 00:48:30	2020-08-21	Echo Raynor	echo.raynor@woohoo.com	San Francisco	California	54726156621199770	ff0a00c380a2ffa801ea1c5ec49b5b42	American Express	37.788509036300411	-122.44656430917064
46567	2020-08-21 00:53:49	2020-08-21	Allyson Lynch DVM	allyson.lynch.dvm@woohoo.com	Port St. Lucie	Florida	3057884413788977	038e8567572874903c61ecaba5a8a482	VISA 13 digit	27.3499374382331979	-80.4663437672510753
46568	2020-08-21 00:54:36	2020-08-21	Eduardo Mills-Smith	eduardo.mills.smith@geemail.com	Kansas City	Missouri	3088536967883016498	2540b3c8fa1e25e44af8307b2562102c	VISA 16 digit	39.0872715391520416	-94.5323623240217614
46569	2020-08-21 00:56:38	2020-08-21	Devante Gusikowski	devante.gusikowski@geemail.com	Murfreesboro	Tennessee	3037052140158787	fe0b0f3ed21cdfc82e30e6adb3226dd9	JCB 16 digit	35.9309298314739038	-86.3295110688395795
46570	2020-08-21 00:59:34	2020-08-21	Oris Kuphal	oris.kuphal@geemail.com	Providence	Rhode Island	3781647612525972	4931e4da84f657be957d98a49426a9ec	VISA 16 digit	41.778653401028734	-71.4669764630880309
46571	2020-08-21 01:02:43	2020-08-21	Dr. Hiram Kunde	dr.hiram.kunde@geemail.com	Denver	Colorado	3528228025025523005	a131a2b7007c0d64fd92d2adbf9b28d7	VISA 13 digit	39.7223800262488425	-104.794958249830088
46572	2020-08-21 01:08:52	2020-08-21	Westley Kuhlman	westley.kuhlman@warmmail.com	Detroit	Michigan	501814860908954	dc4b9bc7dc5fa61e39e7a7204acd2be2	JCB 15 digit	42.3368047316484208	-83.0535740739319408
46573	2020-08-21 01:13:35	2020-08-21	Genesis Satterfield	genesis.satterfield@woohoo.com	San Francisco	California	180018192530042196	313b08118beb810c0ab6f00fcd175731	Discover	37.7581723365733524	-122.399976082841107
46574	2020-08-21 01:14:20	2020-08-21	Kasey McGlynn	kasey.mcglynn@geemail.com	Chicago	Illinois	3059246421274994	1f76979af1ab2d447d770c545ee33d97	Maestro	41.806115908345582	-87.5946850006032633
46575	2020-08-21 01:19:17	2020-08-21	Roll Russel	roll.russel@geemail.com	Worcester	Massachusetts	3112935900662143453	ec457ea1f1e96ff2e47e1ce01a82048e	Maestro	42.2449452629014885	-71.7083987076088789
46576	2020-08-21 01:24:08	2020-08-21	Deidra Wisozk MD	deidra.wisozk.md@warmmail.com	Kansas City	Missouri	6011343777550629694	87116eff99af22f0dbb57f9b0d8286f2	Voyager	39.0791736495982889	-94.5262506892196797
46577	2020-08-21 01:34:45	2020-08-21	Mrs. Delina Block PhD	mrs.delina.block.phd@geemail.com	Bakersfield	California	4337146832804244	7df96246b288f5b09b74b35ecfb9c781	Mastercard	35.4148053227167523	-119.036240743733188
46578	2020-08-21 01:34:52	2020-08-21	Johnie Oberbrunner DVM	johnie.oberbrunner.dvm@geemail.com	Simi Valley	California	3337063536717907023	6b504f327549b6a34f798954374729ab	Voyager	34.1860534321289506	-118.755617458572615
46579	2020-08-21 01:38:35	2020-08-21	Nadia Ryan	nadia.ryan@warmmail.com	Gilbert	Arizona	6011746237586755487	ea0dabc82d5efbc7ce11504e7bc0822b	Voyager	33.3645768392711872	-111.725907262334971
46580	2020-08-21 01:40:17	2020-08-21	Dominique Huel	dominique.huel@geemail.com	Austin	Texas	3088691725637940335	caf8a4b8044b16d6a3e0945e1dfc0927	VISA 16 digit	30.2400711552366595	-97.6632381367735576
46581	2020-08-21 01:47:41	2020-08-21	Dorr Schimmel	dorr.schimmel@geemail.com	Portland	Oregon	3047190894085978	72a5bf6af9d92fcc59053803083c846a	JCB 16 digit	45.489504700049757	-122.641030268091711
46582	2020-08-21 01:48:02	2020-08-21	Clarisa Wuckert	clarisa.wuckert@woohoo.com	Roseville	California	6011306284687043894	c55b06ae83a9325e8918622c5602aa81	VISA 16 digit	38.8173149322215423	-121.413600039410966
46583	2020-08-21 01:52:03	2020-08-21	Manuelita Jaskolski-Doyle	manuelita.jaskolski.doyle@woohoo.com	Killeen	Texas	4428962497240627	0d6719d421b0db1a917f2018e4700c7a	JCB 16 digit	31.076897705695405	-97.7356183246877066
46584	2020-08-21 01:56:08	2020-08-21	Mrs. Tressa Leuschke	mrs.tressa.leuschke@geemail.com	Midland	Texas	869974947122893640	7fc82927ee4196c05963e171df40d7f6	VISA 13 digit	32.0418412139829272	-102.19549599878863
46585	2020-08-21 02:21:41	2020-08-21	Earl Lakin	earl.lakin@geemail.com	Moreno Valley	California	4168998054071	60c86fe336e1da053b359f920e14aacd	American Express	33.9421695165328643	-117.212183874702816
46586	2020-08-21 02:34:29	2020-08-21	Tea Casper	tea.casper@geemail.com	Berkeley	California	3405571624230624	c02e9d0e4890e7628b25489d7c6d7c4c	VISA 16 digit	37.8580309123244589	-122.282211152789898
46587	2020-08-21 02:50:30	2020-08-21	Dr. Tomika Wunsch	dr.tomika.wunsch@warmmail.com	Los Angeles	California	6011781194693772481	d6d2a70a0131d9071763b85e4013591f	Diners Club / Carte Blanche	34.0992367775045295	-118.344237152113763
46588	2020-08-21 02:51:02	2020-08-21	Allyssa Ratke	allyssa.ratke@warmmail.com	Cincinnati	Ohio	4781184271447911	c7c29fb603c613044a2cec48ac149d04	JCB 15 digit	39.1064000847980395	-84.5123478611271821
46589	2020-08-21 02:55:11	2020-08-21	Reid McCullough	reid.mccullough@geemail.com	Escondido	California	3096485718664189827	b6c82ea7630b8f7bf63eb8d871ea45b2	Discover	33.2077518001891647	-117.116301422124721
46590	2020-08-21 02:56:42	2020-08-21	Lahoma Fay	lahoma.fay@warmmail.com	San Diego	California	3735088000302418	a2a811df2075d1840df6b178159c515c	Voyager	32.7743742276050156	-117.160873367115855
46591	2020-08-21 03:08:13	2020-08-21	Dr. Cletus Goodwin V	dr.cletus.goodwin.v@geemail.com	Washington	District of Columbia	3744670706008800	7ffe18a9750229899f826271e1fc0e7c	JCB 15 digit	38.8264432080820185	-76.9692373848266982
46592	2020-08-21 03:14:39	2020-08-21	Spurgeon Eichmann	spurgeon.eichmann@woohoo.com	Overland Park	Kansas	51747778332453454	c104897b60ecd7dab44a8f343cfd588a	VISA 16 digit	38.9575383950360177	-94.5971208806190731
46593	2020-08-21 03:27:27	2020-08-21	Pamala Stamm	pamala.stamm@warmmail.com	San Francisco	California	4497382903405977	21bc5521019e0bf6fa02722e1a305a27	VISA 16 digit	37.7371939705877608	-122.447168358728135
46594	2020-08-21 04:00:06	2020-08-21	Antione Morissette	antione.morissette@geemail.com	Tempe	Arizona	55467733022356218	8825b2a996831acdacc800c59d156505	JCB 15 digit	33.4094260242223697	-112.012182787669076
46595	2020-08-21 04:00:37	2020-08-21	Takisha Klocko	takisha.klocko@geemail.com	Los Angeles	California	4982138083042	7fff32448035fd42fd21b0368d0c8067	VISA 16 digit	34.0589849772263307	-118.436977133247254
46596	2020-08-21 04:10:10	2020-08-21	Lawton Lind	lawton.lind@geemail.com	San Francisco	California	180013894701297369	4319e6577b003b4adbba333c4161cb89	VISA 16 digit	37.769146432658701	-122.395877190865974
46597	2020-08-21 04:11:15	2020-08-21	Ms. Clella Kihn	ms.clella.kihn@geemail.com	Greeley	Colorado	869921995612580171	125da21e779495c355f04835fcb91e6f	JCB 16 digit	40.471260463313385	-104.784178359930223
46598	2020-08-21 04:11:39	2020-08-21	Akira Bednar PhD	akira.bednar.phd@geemail.com	San Francisco	California	3096554097655283162	0a5e8dbefa4a998c632f66cb3f3924fd	VISA 13 digit	37.7933064253673194	-122.488641986394356
46599	2020-08-21 04:14:15	2020-08-21	Treva Bergstrom	treva.bergstrom@geemail.com	Berkeley	California	4266887239794232	0683d4685ac135771be0ea6cabb0c1a4	JCB 16 digit	37.8590899462345476	-122.251831142878615
46600	2020-08-21 04:16:09	2020-08-21	Susana Grant	susana.grant@woohoo.com	Shreveport	Louisiana	6011216053436630817	a9dfc4d7770787837b9ddf5ae18ac7b2	VISA 16 digit	32.5458727698080281	-93.8695878784384519
46601	2020-08-21 04:19:21	2020-08-21	Davey Wiza	davey.wiza@warmmail.com	Long Beach	California	210076712208644509	9c305b7a784af04145e86fb308a8e449	Discover	33.788004139560087	-118.102835457648339
46602	2020-08-21 04:21:12	2020-08-21	Dr. Jerry Bergnaum	dr.jerry.bergnaum@geemail.com	Anchorage	Alaska	180087190583552190	b79f684efd2b95827c0828cf9c8765db	JCB 16 digit	61.2714717573236669	-149.237254820450403
46603	2020-08-21 04:24:31	2020-08-21	Everet Feest	everet.feest@warmmail.com	San Francisco	California	869967383977248962	2d6158cf806158bba820e8f84021890e	VISA 16 digit	37.7650277233869787	-122.47103570361044
46604	2020-08-21 04:29:16	2020-08-21	Glenwood Graham	glenwood.graham@geemail.com	Pasadena	Texas	676305017568295	c7fc3580e19adfb980881c3ce11d343f	JCB 16 digit	29.6053183648608638	-95.1001148465037289
46605	2020-08-21 04:34:30	2020-08-21	Ashleigh Rohan	ashleigh.rohan@geemail.com	New York	New York	6011099880429647719	2cf171423c2f1055063b955ad3e14ce9	JCB 16 digit	40.6711879990752792	-73.9981038081355393
46606	2020-08-21 04:42:41	2020-08-21	Abbie O'Kon	abbie.o'kon@geemail.com	Tacoma	Washington	4357989264332	34eebd5f056afb2badf248ebd9ea73f8	VISA 13 digit	47.1790352502491359	-122.483387200976907
46607	2020-08-21 04:48:20	2020-08-21	Gordon Satterfield	gordon.satterfield@woohoo.com	Berkeley	California	869903875850767908	f581e09d9793b42275543e5565109cca	VISA 13 digit	37.8479507551779761	-122.266578308095447
46608	2020-08-21 04:50:30	2020-08-21	Brian Greenholt	brian.greenholt@geemail.com	Dallas	Texas	4977932677608989	dc2eb8cdaf4c1555ca76dde1292720f6	VISA 16 digit	32.7808071919523201	-96.8109159170146967
46609	2020-08-21 04:51:02	2020-08-21	Abigale Dooley	abigale.dooley@warmmail.com	Kansas City	Kansas	3409863960366237	24d4944b986fbb03d18c9e60ac4291b4	Voyager	39.1762137944251307	-94.8065732529789216
46610	2020-08-21 04:52:42	2020-08-21	Dulce Dare	dulce.dare@geemail.com	Chula Vista	California	6011924755715336212	e4e074f2be88fdadeedcd4ce01dd433c	VISA 16 digit	32.6101317709542755	-116.915210681012638
46611	2020-08-21 04:55:35	2020-08-21	Porsha Gerhold	porsha.gerhold@woohoo.com	San Francisco	California	3055196140373862	fe64c0dc94d910153c6c5db7413323f1	American Express	37.775673526691719	-122.411580895862102
46612	2020-08-21 05:04:19	2020-08-21	Harlon Effertz	harlon.effertz@geemail.com	San Angelo	Texas	4361951297734	87e9a41ec324ad7af1fa8dc0a1856397	American Express	31.4108552161291215	-100.44733022499085
46613	2020-08-21 05:07:20	2020-08-21	Rayshawn Ziemann Jr.	rayshawn.ziemann.jr.@geemail.com	Orlando	Florida	3051640756097483	80e13e60ae3d779eb68aac9e9e7f05fc	JCB 16 digit	28.4273607888989126	-81.201770448774468
46614	2020-08-21 05:10:40	2020-08-21	Mr. Zachary Corwin	mr.zachary.corwin@geemail.com	Glendale	Arizona	4153551132258	f9ac182a55fb795153df7732fd50977e	Discover	33.5707446579582935	-112.10206060863807
46615	2020-08-21 05:14:15	2020-08-21	Dr. Jack Thompson Jr.	dr.jack.thompson.jr.@geemail.com	Wichita	Kansas	675907259397128	3abc0aacb89fae51f01f66a2a5086bc4	VISA 13 digit	37.6343895701568556	-97.2799004439000043
46616	2020-08-21 05:16:19	2020-08-21	Arlen Pacocha Sr.	arlen.pacocha.sr.@woohoo.com	Washington	District of Columbia	3446692882040702	ac1c4b6a3e21945cec391477d3da9616	JCB 15 digit	38.9076238777287315	-76.9822564137380567
46617	2020-08-21 05:28:47	2020-08-21	Miss Nya Collins DDS	miss.nya.collins.dds@geemail.com	Kent	Washington	4728567943051	506b9f9932a622d69d8517278618c9f4	American Express	47.4538742110244911	-122.167052247156207
46618	2020-08-21 05:32:16	2020-08-21	Pratt Gorczany	pratt.gorczany@geemail.com	Oakland	California	4588144458341019	c246a7a6b1cc74316d1c3e301793bfa9	Mastercard	37.7885606247874435	-122.263929211422706
46619	2020-08-21 05:32:20	2020-08-21	Deann Lowe	deann.lowe@warmmail.com	Oklahoma City	Oklahoma	3337628297288460342	40308d7437fef8a5e417bf00d881dce4	Discover	35.413513901913916	-97.5776753038063589
46620	2020-08-21 05:33:04	2020-08-21	Hughey Ziemann DDS	hughey.ziemann.dds@geemail.com	New York	New York	4342423288111892	5cfa96b2f86068c46ae253ab6d12d1b5	VISA 13 digit	40.6517644746918236	-73.9543299404334249
46621	2020-08-21 05:35:27	2020-08-21	Alby Stoltenberg	alby.stoltenberg@geemail.com	Meridian	Idaho	180033594906178473	df4557a8f34065d9e9fd4cbe69608605	Discover	43.7060610503897067	-116.362629375740511
46622	2020-08-21 05:37:37	2020-08-21	Ruthe Ryan	ruthe.ryan@geemail.com	Chicago	Illinois	3051520210153322	74499647724558c0c2323a4be144e252	Diners Club / Carte Blanche	41.7933218347210484	-87.769122445120658
46623	2020-08-21 05:39:03	2020-08-21	Kendal Runolfsson-Champlin	kendal.runolfsson.champlin@woohoo.com	Jacksonville	Florida	6011752436816153247	78730b2b3aa93a3502f8fa623432fd59	VISA 13 digit	30.418727347958459	-81.6717870139595163
46624	2020-08-21 05:44:37	2020-08-21	Rhonda Pouros DVM	rhonda.pouros.dvm@geemail.com	Stamford	Connecticut	3041476128505535	20ed89b6714af62d0e713a3c9a1ab241	VISA 16 digit	41.0784888020601144	-73.5539071639105799
46625	2020-08-21 05:48:49	2020-08-21	Jonah Streich	jonah.streich@woohoo.com	San Francisco	California	4134465872056	79864041e9ecb2254ebcb210318ea147	JCB 16 digit	37.7705055368082441	-122.41501193120601
46626	2020-08-21 05:55:18	2020-08-21	Kailyn Cruickshank DDS	kailyn.cruickshank.dds@geemail.com	San Francisco	California	676275339016265	0a9710a635b90bcca2578553274482b3	VISA 13 digit	37.7974619018476119	-122.432526911210886
46627	2020-08-21 05:55:35	2020-08-21	Jovani Jast-Bosco	jovani.jast.bosco@geemail.com	Moreno Valley	California	55012559485924923	10c749b989db3e1813b32bd03258ab4c	VISA 16 digit	33.897968232817199	-117.241605480012296
46628	2020-08-21 06:06:28	2020-08-21	Keon Zboncak	keon.zboncak@woohoo.com	San Francisco	California	3018757064885145	1e6c991c007adccff26e536c4749c276	VISA 13 digit	37.7795066229088974	-122.421806009964527
46629	2020-08-21 06:15:12	2020-08-21	Chanda Johnson	chanda.johnson@geemail.com	New York	New York	3004389955576650	e299f946ff74afde6452d303f5209b87	JCB 16 digit	40.7003379664141676	-73.8403770191490594
46630	2020-08-21 06:35:39	2020-08-21	Kathy Raynor	kathy.raynor@geemail.com	Grand Rapids	Michigan	3740866811840806	7508f79dd2f6b0d07b0be6b51cdf9643	JCB 15 digit	42.9103675248835188	-85.7231115927122573
46631	2020-08-21 06:41:17	2020-08-21	Alvy Hyatt	alvy.hyatt@geemail.com	Colorado Springs	Colorado	4999851498549673	83bd62c5d57ccbc0fa87883d4346fc9f	JCB 16 digit	38.9256988192491207	-104.826634244962406
46632	2020-08-21 06:46:20	2020-08-21	Stefanie Boyle	stefanie.boyle@geemail.com	San Diego	California	4430870338552553	2ba87df0c61b94d9dc99c4052cd497ab	Discover	32.8772322948157765	-117.223875359203674
46633	2020-08-21 06:54:39	2020-08-21	Mr. Roman Ritchie V	mr.roman.ritchie.v@woohoo.com	Glendale	California	4241192556934	d64e6b30591e1cacd2783bd430fa7a7f	American Express	34.2210525495219926	-118.263596386126437
46634	2020-08-21 06:58:52	2020-08-21	Dr. Dontae Fahey PhD	dr.dontae.fahey.phd@warmmail.com	Las Vegas	Nevada	4568208505223852	10d312c87be30a10c281d677e3c76709	Voyager	36.3170084597177762	-115.356122048825398
46635	2020-08-21 06:59:32	2020-08-21	Marcus Lehner	marcus.lehner@woohoo.com	Topeka	Kansas	4883588782648	1cf04ff7644757f265fedeb9c6eb6f43	JCB 15 digit	38.9486252850785846	-95.7858950652822898
46636	2020-08-21 07:22:53	2020-08-21	Dr. Tamisha Rath MD	dr.tamisha.rath.md@woohoo.com	Lubbock	Texas	4943590847545902	38a45913a9663ff37f19f22a02ad5894	Diners Club / Carte Blanche	33.5560653949663106	-101.858576398427417
46637	2020-08-21 07:26:57	2020-08-21	Sydney Denesik	sydney.denesik@woohoo.com	Palmdale	California	3433964938897822	24d31480bc78c9e90ce4774a729bd660	Mastercard	34.6392481332961495	-118.062077040271461
46638	2020-08-21 07:35:55	2020-08-21	Marcelino Prohaska	marcelino.prohaska@geemail.com	Oxnard	California	3096964520274995258	a51953c1f4e4750260ca61d7e1369513	Maestro	34.2190324747890244	-119.218455573488399
46639	2020-08-21 07:42:38	2020-08-21	Julius Hilll	julius.hilll@geemail.com	Chandler	Arizona	3433224705500335	6e8546f8e032a88f9aa67d2b5a6e8582	Mastercard	33.2314773066524367	-111.85316615378261
46640	2020-08-21 07:49:37	2020-08-21	Ms. Isabel Pagac	ms.isabel.pagac@warmmail.com	San Francisco	California	180049763349432456	4ac4fab0286a212658fe7d8701b51c7e	VISA 16 digit	37.7453054141752347	-122.453237446911743
46641	2020-08-21 07:57:15	2020-08-21	Eleanore Wehner	eleanore.wehner@geemail.com	Fresno	California	4718075561662987	a3e309726149e3a38eb62441902d77c9	Voyager	36.8733493947297362	-119.754629404015475
46642	2020-08-21 08:07:49	2020-08-21	Argie Tillman	argie.tillman@geemail.com	San Francisco	California	55407261653331261	44670b051cba3ba89d7bf1bb8b6789c0	American Express	37.779458909395025	-122.433682863273901
46643	2020-08-21 08:12:43	2020-08-21	Reuben Runte	reuben.runte@geemail.com	Phoenix	Arizona	180089596743692312	e66fe9d830c582aeaaecdecc3e70fca3	Diners Club / Carte Blanche	33.5107622759349653	-111.992507401753599
46644	2020-08-21 08:18:11	2020-08-21	Joanne Eichmann DDS	joanne.eichmann.dds@geemail.com	Jersey City	New Jersey	3024076663934335	7ff5ba63981b594edf7460f404a4b1c0	VISA 16 digit	40.7431145294044157	-74.073887745891895
46645	2020-08-21 08:27:53	2020-08-21	Dr. Elmina Mosciski	dr.elmina.mosciski@woohoo.com	Jacksonville	Florida	3043233870855560	504f4873a4e9cfe3e5d739e679d83151	Mastercard	30.2659656070224941	-81.6678228795141052
46646	2020-08-21 08:31:27	2020-08-21	Judah Mills	judah.mills@geemail.com	Fort Wayne	Indiana	4045802599230444	115077f9c06b3df5c2514cbcc0b13556	Voyager	41.0008041613984844	-85.1109783779583893
46647	2020-08-21 08:38:03	2020-08-21	Philo Harris IV	philo.harris.iv@woohoo.com	Colorado Springs	Colorado	3158325500025879898	8de3721c75d645beb844fa82eb024cd0	JCB 16 digit	38.7777561422485846	-104.722224376086885
46648	2020-08-21 08:42:12	2020-08-21	Teddie Dickinson-Batz	teddie.dickinson.batz@woohoo.com	Houston	Texas	502097969863568	a0468cbc1e757eae3f906cfe4477147a	Maestro	29.8287978708822266	-95.4563524393845313
46649	2020-08-21 08:48:02	2020-08-21	Zola Parker	zola.parker@geemail.com	Aurora	Colorado	3158832774572335671	7fb7a05848e7757ba0fa2af1785f5557	Mastercard	39.6435515906307856	-104.764591753122218
46650	2020-08-21 08:54:12	2020-08-21	Ricky Prohaska	ricky.prohaska@geemail.com	New York	New York	52313168969709960	794814a4e96c6a3438681c9ae68ca322	VISA 13 digit	40.6779527351018046	-74.0167547696165684
46651	2020-08-21 09:01:51	2020-08-21	Cathryn Moen	cathryn.moen@geemail.com	Plano	Texas	54011878448939203	1790e0ace241be7e6153f3f0788b468d	American Express	32.9968521301720301	-96.7998249295350206
46652	2020-08-21 09:22:19	2020-08-21	Elvina Mayert	elvina.mayert@geemail.com	Detroit	Michigan	4085505544719	f4c3ee710775a4f3f8edc8e10dcf034d	Diners Club / Carte Blanche	42.4636797443423433	-83.1923488147675982
46653	2020-08-21 09:26:11	2020-08-21	Trevion O'Hara	trevion.o'hara@geemail.com	San Antonio	Texas	4237048974149290	6cdecb38aeb58e9bd0a0e815cb6d4d41	Diners Club / Carte Blanche	29.4390554126888517	-98.4359900964260106
46654	2020-08-21 09:27:11	2020-08-21	Mrs. Wilhelmina McKenzie	mrs.wilhelmina.mckenzie@woohoo.com	San Antonio	Texas	4013919519024000	762b661309aff9fd7d018159f736a3a2	Discover	29.4071998785320687	-98.6030913315549498
46655	2020-08-21 09:27:29	2020-08-21	Makala Nikolaus	makala.nikolaus@geemail.com	Pittsburgh	Pennsylvania	180016694279043568	5d7f67c4a8f4efbd8a74c7804d0b7f00	Discover	40.349357731309901	-79.9706484561026087
46656	2020-08-21 09:45:29	2020-08-21	Orvel Connelly	orvel.connelly@geemail.com	Houston	Texas	3742090718407464	38c9dfe48b7c8c02ee58bfa658161fc0	VISA 13 digit	29.8496490642506629	-95.4767404105994899
46657	2020-08-21 09:46:22	2020-08-21	Vara Rodriguez-Runolfsdottir	vara.rodriguez.runolfsdottir@geemail.com	Aurora	Colorado	869917543703842187	f22e53ae52a41422d51d7a8a4612eb8b	Discover	39.6180737951882236	-104.650256303709753
46658	2020-08-21 09:56:10	2020-08-21	Vergie Gorczany	vergie.gorczany@warmmail.com	San Diego	California	3776509277345376	443be3e995164ae4a7c7bf397c12a086	Voyager	32.8981333794604964	-117.125655394271021
46659	2020-08-21 10:10:22	2020-08-21	Vincenzo Gleason	vincenzo.gleason@geemail.com	Thousand Oaks	California	4158913588509749	15422d4d518ea67259cef1f9df6f90c4	Discover	34.2765551967818283	-118.935548244128753
46660	2020-08-21 10:12:33	2020-08-21	Dorr Carroll	dorr.carroll@geemail.com	New York	New York	3400921796996947	b1f986e5bdcfcde7694d0e8063ad0bc0	Maestro	40.6874320193883037	-73.8507336952619227
46661	2020-08-21 10:16:31	2020-08-21	Cloyd Reynolds	cloyd.reynolds@geemail.com	Riverside	California	6011099853328165125	737761f99688ee384a203a086a04b242	JCB 15 digit	33.9023657205462428	-117.308605111573627
46662	2020-08-21 10:37:23	2020-08-21	Arnulfo Pagac	arnulfo.pagac@geemail.com	Lakeland	Florida	4592720927561	f4409f7ae9c53efc1e46084f8081eb54	JCB 16 digit	28.0848321351055041	-81.8947501820862271
46663	2020-08-21 10:39:21	2020-08-21	Anabella Wiza	anabella.wiza@woohoo.com	Los Angeles	California	6011533520354611751	60a3851a2cb06659027434c77269ebce	Diners Club / Carte Blanche	33.993340024524926	-118.322681700670344
46664	2020-08-21 10:43:49	2020-08-21	Alexandr Ratke DVM	alexandr.ratke.dvm@woohoo.com	San Francisco	California	3337842484031381930	f81333fc323fbc298bdb2f45561ed1b1	Mastercard	37.7472823365114465	-122.439441315790802
46665	2020-08-21 10:47:19	2020-08-21	Dr. Armani Dach	dr.armani.dach@woohoo.com	Chicago	Illinois	3337579218520217166	e2aafc7e20ce66431d4a36f932411d55	JCB 15 digit	41.889786409709977	-87.7666873546812667
46666	2020-08-21 11:06:11	2020-08-21	Amelie Willms	amelie.willms@geemail.com	Columbia	South Carolina	502075178121333	40f131e8e74c931bb8f21328fabbc046	Voyager	33.9553573171406953	-80.8402057776711871
46667	2020-08-21 11:07:40	2020-08-21	Darron Hickle	darron.hickle@geemail.com	Glendale	California	3718055269199018	88e03b51508d74ac8ae140d00ab350bb	American Express	34.2764905618257814	-118.22473613008782
46668	2020-08-21 11:17:41	2020-08-21	Erna Schaefer	erna.schaefer@geemail.com	New Orleans	Louisiana	630417896615154	defbe9dedcf8d9ab096e1d9ffa9a6cf5	Diners Club / Carte Blanche	30.1468733259491621	-90.0187991570476385
46669	2020-08-21 11:21:25	2020-08-21	Demarcus Auer	demarcus.auer@geemail.com	Dallas	Texas	501810490618146	f13e30667f99f36ebaaefdb5c6be3bfd	Voyager	32.7687005192313379	-96.8463597086686576
46670	2020-08-21 11:28:49	2020-08-21	Romaine Kozey-Gutkowski	romaine.kozey.gutkowski@geemail.com	Vacaville	California	3427183414293434	faa4fdd9f1455228c18340235ef8be8e	JCB 16 digit	38.3196852818258122	-121.937832059280211
46671	2020-08-21 11:37:19	2020-08-21	Kamya D'Amore	kamya.d'amore@geemail.com	Oakland	California	4346610039924	e1de5ea8c5655d163ac17f30bcfd0c43	Voyager	37.8151107821825718	-122.279277821031826
46672	2020-08-21 11:43:18	2020-08-21	Mrs. Shellie Thiel MD	mrs.shellie.thiel.md@geemail.com	Bellevue	Washington	52581524181127305	597b289453beae702f528517f0561455	JCB 15 digit	47.6816879130151179	-122.249449857376504
46673	2020-08-21 12:31:20	2020-08-21	Zoa Farrell	zoa.farrell@geemail.com	San Francisco	California	4833445299105916	b51f9b1394848519270419f232a11ffa	Voyager	37.7772871471073728	-122.427997384454315
46674	2020-08-21 12:41:51	2020-08-21	Rhea Harber PhD	rhea.harber.phd@geemail.com	Beaumont	Texas	3096110440890074326	9864c77b564285048fc30cfe839f9ea4	Mastercard	30.1180352609675381	-94.111469582540181
46675	2020-08-21 12:44:03	2020-08-21	Hughie Ritchie	hughie.ritchie@geemail.com	Los Angeles	California	4546505268054	264a7b28db342928e71404cb2b6d1636	JCB 16 digit	33.9461353035509532	-118.432148754270003
46676	2020-08-21 12:58:34	2020-08-21	Verona Buckridge PhD	verona.buckridge.phd@geemail.com	Mobile	Alabama	3337453405216727878	d743300742227ba7ccf1a3a2aa49fea4	VISA 13 digit	30.7041052777428156	-88.0222460711047034
46677	2020-08-21 13:13:51	2020-08-21	Miss Elmira Reilly	miss.elmira.reilly@woohoo.com	Tallahassee	Florida	4691818733180631	8066928d14608e1ae9de988e73a9e229	Mastercard	30.5119939794320629	-84.2648215380512227
46678	2020-08-21 13:23:20	2020-08-21	Moises Gorczany	moises.gorczany@geemail.com	Lakewood	New Jersey	3112162179643727668	276e1841327fa1dccfb2213362beed0a	Voyager	40.1234481975253701	-74.2967508667889973
46679	2020-08-21 13:25:33	2020-08-21	Adelyn Macejkovic-Reynolds	adelyn.macejkovic.reynolds@geemail.com	Frisco	Texas	6011669149752637626	86dc154c515ed22a317f327456816624	Discover	33.2287202115166949	-96.7467850851569295
46680	2020-08-21 13:30:45	2020-08-21	Ramsey Marvin	ramsey.marvin@warmmail.com	Santa Rosa	California	869970868523233638	e7a6bfeb08fc70a5615a238763022046	JCB 16 digit	38.4338471823960575	-122.656224633964158
46681	2020-08-21 13:34:56	2020-08-21	Mrs. Cassandra Rau DDS	mrs.cassandra.rau.dds@woohoo.com	Raleigh	North Carolina	3052051240538893	554d140eb95aeb10e3d09e3948675b07	JCB 15 digit	35.9017903166491479	-78.60934270782694
46682	2020-08-21 13:37:58	2020-08-21	Mrs. Theresia Trantow	mrs.theresia.trantow@geemail.com	Glendale	California	3158095908644637498	269356a57467d069665643e6ef87a9bc	Mastercard	34.2034515251159661	-118.243686195546019
46683	2020-08-21 13:45:34	2020-08-21	Tyesha Crist	tyesha.crist@geemail.com	New York	New York	4929039325968077	f3ee0bfd2296f708c79358317e4318f7	Mastercard	40.7411148950681081	-73.9427301579516296
46684	2020-08-21 13:49:35	2020-08-21	Jett Champlin	jett.champlin@geemail.com	Coral Springs	Florida	210004331177404584	20e36e44eb674640f84b30e834a810de	JCB 16 digit	26.3269704094219961	-80.3275164699770414
46685	2020-08-21 14:00:47	2020-08-21	Rolla Harvey	rolla.harvey@geemail.com	Memphis	Tennessee	3337506571170768591	c6590b57351279447a28705d91b73c2c	JCB 15 digit	35.1088354966670266	-90.0136339512445005
46686	2020-08-21 14:01:33	2020-08-21	Omarion Bernier	omarion.bernier@warmmail.com	Fargo	North Dakota	4729052448226	452f2fc8d8f31da09b3572d113478475	VISA 16 digit	46.8386050030820087	-96.9154417999517079
46687	2020-08-21 14:08:42	2020-08-21	Richmond Satterfield	richmond.satterfield@woohoo.com	Houston	Texas	3054286318107464	04ca74d28eb931448af439e03932e33b	Mastercard	29.6901907804965965	-95.466828230350842
46688	2020-08-21 14:13:34	2020-08-21	Emry Farrell	emry.farrell@woohoo.com	Detroit	Michigan	6011534039047671428	5bff284a1e3baec8614d0d4b6913a26a	JCB 16 digit	42.3627709900420157	-83.1365930418603085
46689	2020-08-21 14:24:15	2020-08-21	Will Carter DVM	will.carter.dvm@geemail.com	Los Angeles	California	4705950389920301	dda110ca8f64ad8a23b727717b5bb03d	JCB 15 digit	34.0759891220234294	-118.33442295310013
46690	2020-08-21 14:31:36	2020-08-21	Tremayne Haag	tremayne.haag@geemail.com	Berkeley	California	4870778208484	ac17a783ad9744f37ec0eed3ce11a6fc	Maestro	37.8559960944389999	-122.22437701758686
46691	2020-08-21 14:44:06	2020-08-21	Samara Gaylord	samara.gaylord@warmmail.com	Des Moines	Iowa	4037034666189598	f5dab33bc59ac68406f2ad408eb6ed9d	Maestro	41.5456917895212783	-93.6057944363493561
46692	2020-08-21 14:53:09	2020-08-21	Dr. Deion Koch	dr.deion.koch@geemail.com	Phoenix	Arizona	869951503173873242	2aa5c9637214cfbc4adecef2f3d1e69e	Maestro	33.6666253811147058	-112.077010870717842
46693	2020-08-21 14:58:08	2020-08-21	Ahmad McDermott	ahmad.mcdermott@geemail.com	Nashville	Tennessee	3731061489559372	e62349b40f8608cd835703f77b3b5526	Diners Club / Carte Blanche	36.1713114177931061	-86.8294567550905043
46694	2020-08-21 14:58:18	2020-08-21	Mrs. Leta Goldner	mrs.leta.goldner@geemail.com	Birmingham	Alabama	3426634343833006	c34af3604d18d8530528f62396cce382	Voyager	33.5096370863053963	-86.8963326074890858
46695	2020-08-21 15:03:43	2020-08-21	Amiya Skiles	amiya.skiles@warmmail.com	Los Angeles	California	4011444965463752	e7ad7c62a1bed2921ff32d5d68bbb5a8	Mastercard	33.9687669361341733	-118.429874948225162
46696	2020-08-21 15:05:34	2020-08-21	Mel Treutel	mel.treutel@geemail.com	San Francisco	California	3728957325091188	dbc28cbeef470611783fcfa3288c7e20	JCB 16 digit	37.7675069268968784	-122.44374205472495
46697	2020-08-21 15:16:37	2020-08-21	Ms. Hildur McClure PhD	ms.hildur.mcclure.phd@geemail.com	Chesapeake	Virginia	180081047576963196	fd5235b8ec9aa536b794d4e04839215b	JCB 16 digit	36.7011757669743162	-76.2685811349499971
46698	2020-08-21 15:18:03	2020-08-21	Elizabet Bartell	elizabet.bartell@geemail.com	Houston	Texas	210077134481656044	95628bf5a0b2d4524170d3028c9b5224	JCB 15 digit	29.8083768350616083	-95.4119691909305772
46699	2020-08-21 15:30:54	2020-08-21	Desean Reilly	desean.reilly@geemail.com	Garland	Texas	52171375464002467	216871ef4a6978bc1cac85a2acdf73af	Voyager	32.8815524309642555	-96.6917461500197675
46700	2020-08-21 15:31:48	2020-08-21	Emile Towne	emile.towne@geemail.com	Grand Prairie	Texas	3528625186261318119	e8ea54bc20bd4f95307b176aa5c31123	Mastercard	32.7189885261055124	-96.9307450439654303
46701	2020-08-21 15:39:31	2020-08-21	Rosena Marvin	rosena.marvin@geemail.com	Chicago	Illinois	3096550890399857455	c15299c16c9ec83140837d302d8eca18	Maestro	41.8458172482740167	-87.7113534722972616
46702	2020-08-21 15:47:21	2020-08-21	Penny Sanford	penny.sanford@geemail.com	Newport News	Virginia	4081864595590	e06f0ce47b517ab46815e9f4637e21a8	VISA 13 digit	37.0067553370621027	-76.4877108246814572
46703	2020-08-21 15:56:13	2020-08-21	Victory Kutch	victory.kutch@geemail.com	Oakland	California	4369254779043	d308740233588209b968103949b08530	Diners Club / Carte Blanche	37.7753238358626078	-122.273110728793498
46704	2020-08-21 16:06:06	2020-08-21	Denzell Graham	denzell.graham@geemail.com	Frisco	Texas	3158830288725825571	6439135c4dfa3605e887f513c37105ac	Diners Club / Carte Blanche	33.1395299856547254	-96.7408723442558198
46705	2020-08-21 16:09:16	2020-08-21	Jamal Morar	jamal.morar@warmmail.com	Philadelphia	Pennsylvania	52348691332565180	bd3f64373b0291a18c1907aa6775b40d	Discover	39.9516673913650209	-75.1940751493342248
46706	2020-08-21 16:13:07	2020-08-21	Caylee Bogisich DDS	caylee.bogisich.dds@geemail.com	Berkeley	California	676309663435858	ca6c164ac24cd524f819c9362bef07ad	VISA 13 digit	37.8722457803947066	-122.303150399284775
46707	2020-08-21 16:15:31	2020-08-21	Myles Wyman	myles.wyman@geemail.com	Grand Rapids	Michigan	3112396891597012503	60fa8a3eaa7620635e1f446be8136d83	Discover	43.0284577060293358	-85.6539324253931653
46708	2020-08-21 16:16:43	2020-08-21	Sawyer Shields	sawyer.shields@woohoo.com	San Francisco	California	6011795182425305914	5a0ce96044ee7d7162db8999af0e8ca2	JCB 15 digit	37.7681338030545106	-122.431007269910467
46709	2020-08-21 16:17:23	2020-08-21	Rene Parisian DVM	rene.parisian.dvm@geemail.com	Los Angeles	California	3528648349844025675	6c9cc65b33e00d8b606c9264154a496d	Maestro	34.0764032841991593	-118.360329905710358
46710	2020-08-21 16:25:48	2020-08-21	Ms. Margarette Romaguera	ms.margarette.romaguera@geemail.com	Laredo	Texas	3088474484061447523	4481e459304d2818d3bb2bbf0357a896	Discover	27.5296617001943318	-99.4186883468188256
46711	2020-08-21 16:26:06	2020-08-21	Adina Hagenes-Hermann	adina.hagenes.hermann@geemail.com	Berkeley	California	869998718295536429	4119680e7ef24ca06e991dede642f099	Voyager	37.8527634926965462	-122.283955588191375
46712	2020-08-21 16:35:12	2020-08-21	Suzann Cartwright	suzann.cartwright@woohoo.com	Colorado Springs	Colorado	52205784222483044	735aae02ce32abc8403dea5e278254e9	JCB 16 digit	38.8756769456949058	-104.840780027785158
46713	2020-08-21 16:37:34	2020-08-21	Loren Kunde	loren.kunde@geemail.com	Lakeland	Florida	4574643662601148	6a9a250e425efa947a2ac9a029b5b321	Discover	28.1212009514980004	-81.9903505463968969
46714	2020-08-21 16:38:27	2020-08-21	Tilman Gusikowski	tilman.gusikowski@warmmail.com	St. Petersburg	Florida	869949831057796964	0de57985fd658ac6b34920a16d640a79	Mastercard	27.8435267455298465	-82.5467493585202732
46715	2020-08-21 16:43:03	2020-08-21	Emile Nicolas	emile.nicolas@geemail.com	Rancho Cucamonga	California	4206311801648612	0a51a452d229c3d565e8352e606e0b59	JCB 16 digit	34.1688759228672865	-117.520812550420686
46716	2020-08-21 16:47:29	2020-08-21	Alvena Emard	alvena.emard@woohoo.com	Chula Vista	California	675900529032021	d947107bb89814a539a862496ab311d1	Voyager	32.5360034323062735	-116.976473325840004
46717	2020-08-21 16:49:10	2020-08-21	Acy Ullrich	acy.ullrich@warmmail.com	Ann Arbor	Michigan	210020842752658659	91b1920ef5e62098a53f071a0fa9102d	Mastercard	42.2382023173909644	-83.8015522076390766
46718	2020-08-21 16:51:21	2020-08-21	Jennie Kunde	jennie.kunde@geemail.com	New York	New York	4661679695587916	3e8bca10466f94f497ce802a49c9d7b0	Discover	40.5876123582702135	-73.9708808607317536
46719	2020-08-21 16:57:56	2020-08-21	Rossie Mante	rossie.mante@warmmail.com	Greeley	Colorado	3443379626147984	e5448e97cc3ee15d180acb6c96941fef	Mastercard	40.5071269432615537	-104.741815242155269
46720	2020-08-21 17:01:17	2020-08-21	Gauge Murray MD	gauge.murray.md@geemail.com	Cincinnati	Ohio	3158426892846209159	ce26432526b12a79a1b6381c2387b7f3	VISA 16 digit	39.0632804351624117	-84.5758085064861831
46721	2020-08-21 17:02:35	2020-08-21	Alpheus Spencer	alpheus.spencer@geemail.com	San Diego	California	55233600476258930	0fda93923b03ea50a1fd8c6bf8953fce	Voyager	32.7176859029635807	-117.042634057058024
46722	2020-08-21 17:05:41	2020-08-21	Gifford Hane Jr.	gifford.hane.jr.@woohoo.com	Moreno Valley	California	869904903715811759	017af6d6c543ac5a35399c5e7c785369	Discover	33.8765315086573366	-117.296485184688862
46723	2020-08-21 17:07:19	2020-08-21	Mr. Jeff Bartoletti II	mr.jeff.bartoletti.ii@geemail.com	Chandler	Arizona	3054908248053225	17e3274184916e463111309d25c1a523	JCB 16 digit	33.3352306712508195	-111.891773814184219
46724	2020-08-21 17:09:33	2020-08-21	Deonta Hills-Collins	deonta.hills.collins@geemail.com	Aurora	Colorado	4118991909911702	88aed57b3bdc0bd4739649b89ac98149	Mastercard	39.7683792099002744	-104.784685026493676
46725	2020-08-21 17:12:35	2020-08-21	Donaciano Upton	donaciano.upton@geemail.com	San Francisco	California	869944558330243200	5d2e670f6aa0b2747ecf5179a7591360	Discover	37.7673224437720521	-122.47740981992051
46726	2020-08-21 17:13:14	2020-08-21	Delsie Fadel	delsie.fadel@geemail.com	Dallas	Texas	210030670408193039	92873df1349a8b08424e5f7865530636	Diners Club / Carte Blanche	32.7507779916554682	-96.854474250642582
46727	2020-08-21 17:20:37	2020-08-21	Dr. Evert Waelchi	dr.evert.waelchi@warmmail.com	New York	New York	4778984043396428	9f92d2ddcbebda5560e12c70992ff46f	JCB 15 digit	40.6733097815178297	-73.8632698149315985
46728	2020-08-21 17:25:48	2020-08-21	Commodore Runte	commodore.runte@geemail.com	Jersey City	New Jersey	3337662366382708778	a647f598a85d91a646626d7357b95d53	JCB 16 digit	40.6558739104248588	-74.0863101958718175
46729	2020-08-21 17:38:14	2020-08-21	Dr. Edie Blick	dr.edie.blick@geemail.com	Springfield	Missouri	589357531772473	dea92596183dd4a633423e2b8dd99033	Discover	37.2394526689507117	-93.2162186096713015
46730	2020-08-21 17:47:13	2020-08-21	Taurean Herman	taurean.herman@warmmail.com	El Paso	Texas	060464906341470	be2061c786266672a4605e021203d9cd	Maestro	31.8697127010967591	-106.506161801980809
46731	2020-08-21 17:47:17	2020-08-21	Denisha Swift	denisha.swift@geemail.com	San Francisco	California	210049691994255809	071b5c9b307fdd16ab01014cc207f0d2	Maestro	37.7827350058859821	-122.404087534137759
46732	2020-08-21 17:47:47	2020-08-21	Mrs. Madonna Miller	mrs.madonna.miller@geemail.com	Atlanta	Georgia	4163899839142	1eccf31a73072af5aa5f2782adf2fdcc	Diners Club / Carte Blanche	33.7096994686681768	-84.3954087537292423
46733	2020-08-21 17:57:02	2020-08-21	Mr. Khiry Kertzmann V	mr.khiry.kertzmann.v@geemail.com	New York	New York	4482081273047	37f61523bb508a94b979d335b2d048a6	Voyager	40.589835353124883	-73.8689353131119191
46734	2020-08-21 17:57:14	2020-08-21	Miss Roslyn Auer DDS	miss.roslyn.auer.dds@geemail.com	Rancho Cucamonga	California	53853614847250848	a405b27c96e02ae8d60cd487c9e58478	JCB 15 digit	34.0490465501781543	-117.522143900721147
46735	2020-08-21 17:57:28	2020-08-21	Miss Lida Dietrich DVM	miss.lida.dietrich.dvm@geemail.com	San Francisco	California	4877025260739	9145a7da128445ef15ed481ef92095bd	JCB 15 digit	37.77041542749852	-122.443459829980952
46736	2020-08-21 18:01:55	2020-08-21	Abigayle Bartoletti	abigayle.bartoletti@geemail.com	Oakland	California	589348596932680	d0914f9cfe31ad1b7a42b0183b297f94	JCB 16 digit	37.7948692465071971	-122.27283136880888
46737	2020-08-21 18:17:10	2020-08-21	Wilda Gorczany	wilda.gorczany@geemail.com	Sugar Land	Texas	3748132599544132	dbc797041fafe00f3c7a2781501f3550	American Express	29.5616233081143349	-95.653594807396459
46738	2020-08-21 18:21:54	2020-08-21	Dr. Rogers Feeney PhD	dr.rogers.feeney.phd@geemail.com	Bridgeport	Connecticut	4067645985794371	8b60a81ea31d2a70a2bcdd6527088374	JCB 16 digit	41.132773163837939	-73.1830390616685236
46739	2020-08-21 18:27:28	2020-08-21	Mrs. Delores Mills MD	mrs.delores.mills.md@geemail.com	Chicago	Illinois	4792917561460210	e9e3fb8994716454bb105a5a9bcf6156	Mastercard	41.7434914863038813	-87.6695538933418703
46740	2020-08-21 18:28:46	2020-08-21	Dr. Daniela Nolan MD	dr.daniela.nolan.md@geemail.com	Virginia Beach	Virginia	3737366542572617	6c082e6528a5b1d1fca3f85cebf7883c	VISA 13 digit	36.7754174953512845	-76.0459821795251258
46741	2020-08-21 18:29:00	2020-08-21	Mrs. Marilla Little PhD	mrs.marilla.little.phd@woohoo.com	Atlanta	Georgia	3337125482306670548	901cc7de7fd2185b16f179c2462becaa	JCB 16 digit	33.7390053670663406	-84.4186504201076957
46742	2020-08-21 18:49:56	2020-08-21	Nim Connelly	nim.connelly@warmmail.com	Fort Collins	Colorado	3726315797790377	767e6344a89ecdaa2c43074c18e6ef5e	Discover	40.60012475547083	-105.00178619706557
46743	2020-08-21 18:56:42	2020-08-21	General Jacobs IV	general.jacobs.iv@geemail.com	Jersey City	New Jersey	4627016239261	46bcef0e7b9f472ad313778ed9982f91	JCB 16 digit	40.6959875441096699	-74.1624795574184503
46744	2020-08-21 19:09:02	2020-08-21	Dr. Admiral Thompson	dr.admiral.thompson@warmmail.com	Tampa	Florida	4160830879981625	3a141efdaa0c22aeb77ef1142ec4693e	VISA 16 digit	27.9976452667381608	-82.5327004944652316
46745	2020-08-21 19:17:23	2020-08-21	Manilla Batz	manilla.batz@geemail.com	Buffalo	New York	3528647501353114339	1b676973e4dc0839564fc14c4a8087e6	Mastercard	42.9006613597460102	-78.8992152571611172
46746	2020-08-21 19:17:47	2020-08-21	Nonie Treutel	nonie.treutel@geemail.com	San Francisco	California	210088166385776749	eda7bfe2a681c8ee65dc09d89431045d	American Express	37.766219054287852	-122.480087764818379
46747	2020-08-21 19:43:55	2020-08-21	Boysie Rolfson	boysie.rolfson@geemail.com	San Francisco	California	4252259448912128	5e5e5454fa4f1b1f3219040a8f64fc37	Voyager	37.8338093988950419	-122.438484947938292
46748	2020-08-21 19:47:19	2020-08-21	Teela Johns	teela.johns@geemail.com	San Francisco	California	4602754916149	463adbe85000ea3a7edbbbd460802315	Voyager	37.7924118157775055	-122.432462490669991
46749	2020-08-21 19:47:28	2020-08-21	Keegan Kub V	keegan.kub.v@geemail.com	Dallas	Texas	3112488935597673068	3789ffccf5fa36934724f2d9445ad450	Diners Club / Carte Blanche	32.8768536521393813	-96.7676171861551637
46750	2020-08-21 19:53:11	2020-08-21	Tai Reilly-Prohaska	tai.reilly.prohaska@woohoo.com	Elk Grove	California	210064861022165144	1a7b3c9b4e49e9d18f954f9792dd5bb7	JCB 16 digit	38.3516179395657062	-121.369903281182062
46751	2020-08-21 20:03:30	2020-08-21	Mr. Thorwald Raynor	mr.thorwald.raynor@geemail.com	Mesa	Arizona	4912845997203240	b5e6fe2e914700d644c28a471b52adc3	Mastercard	33.4412030027393214	-111.677381040051202
46752	2020-08-21 20:18:34	2020-08-21	Kaci Hintz	kaci.hintz@geemail.com	Kansas City	Missouri	4177325788333217	f8a7a575196775ee7b07aed599a22270	Diners Club / Carte Blanche	39.1556788157507825	-94.648025946108632
46753	2020-08-21 20:30:55	2020-08-21	Mathilde Schumm DVM	mathilde.schumm.dvm@warmmail.com	Glendale	Arizona	869926644521561972	e9050e93f91b13343aec6b7c3d8e1dd1	American Express	33.4904263021651616	-112.214216919315604
46754	2020-08-21 20:31:36	2020-08-21	Dr. Bruce Bogan IV	dr.bruce.bogan.iv@geemail.com	San Francisco	California	4869613726007	9436e37c8f522e4dbfb1fdb89d202405	VISA 13 digit	37.7513533569952813	-122.441531962501031
46755	2020-08-21 20:38:24	2020-08-21	Cloyd Christiansen	cloyd.christiansen@geemail.com	San Francisco	California	180081187477329871	775884fce7cfa1f3ff63387a23ba620e	VISA 16 digit	37.7505997250839727	-122.419270981189158
46756	2020-08-21 20:38:45	2020-08-21	Lena Osinski	lena.osinski@geemail.com	Denver	Colorado	6011107606719189173	c2e2f60cd2d8d41080d8373801c33668	American Express	39.8111982453666613	-104.868986511581028
46757	2020-08-21 20:39:58	2020-08-21	Dr. Babyboy Marquardt	dr.babyboy.marquardt@geemail.com	Indianapolis	Indiana	869961044425371147	f718173999bc005af21c828594650742	Maestro	39.7874135859783706	-86.1010372678019138
46758	2020-08-21 20:44:06	2020-08-21	Mrs. Avis Cole	mrs.avis.cole@warmmail.com	Laredo	Texas	6011614977475726383	8326c89d0f2df08fc079d3154431a130	VISA 16 digit	27.5335443251948817	-99.484061891446629
46759	2020-08-21 20:56:58	2020-08-21	Claudia Hegmann	claudia.hegmann@geemail.com	Columbus	Ohio	4111681872598373	7cd8c9b4eafca2d42cfdf946cc98ffd7	JCB 16 digit	39.8864615306302923	-82.9804621858291398
46760	2020-08-21 21:01:52	2020-08-21	Patrick Morar	patrick.morar@geemail.com	Oklahoma City	Oklahoma	4255311949777521	a6a8d50e29776220067231c381719fd6	Mastercard	35.5272490510627676	-97.6081124007131962
46761	2020-08-21 21:03:07	2020-08-21	Karie Blick	karie.blick@geemail.com	Independence	Missouri	210064422959336529	f03dca7de0392190dbde48d5ffef2e93	Mastercard	39.0444553515892494	-94.2812410709731239
46762	2020-08-21 21:05:34	2020-08-21	Eliseo Breitenberg-Doyle	eliseo.breitenberg.doyle@warmmail.com	Renton	Washington	869997012361266090	414afcc9e9f0d960fb545d867b71734c	JCB 16 digit	47.5644433141745679	-122.256006858365609
46763	2020-08-21 21:05:46	2020-08-21	Ms. Santina Pfeffer	ms.santina.pfeffer@geemail.com	Los Angeles	California	52173176565959276	60fabc4cf7c538e06ca857463e16962a	Discover	34.039949663901325	-118.357224272377039
46764	2020-08-21 21:07:48	2020-08-21	Jewel Breitenberg	jewel.breitenberg@geemail.com	San Francisco	California	3015932626275902	6337658ca2adabf8b244f8ca6da5fc3f	JCB 15 digit	37.8073152976817255	-122.426930853425304
46765	2020-08-21 21:12:22	2020-08-21	Kenya Pfeffer	kenya.pfeffer@woohoo.com	San Francisco	California	3088749226332727251	558ed1827bc731d5ab808b5ffab8b0a6	Maestro	37.7725533887925096	-122.474196277641525
46766	2020-08-21 21:20:19	2020-08-21	Erin Reinger-Pollich	erin.reinger.pollich@geemail.com	Columbus	Georgia	3337940323303032063	31108b041c2186855abc86c1f678647e	Diners Club / Carte Blanche	32.434815626828744	-84.7773013510905145
46767	2020-08-21 21:21:08	2020-08-21	Doshia Murphy	doshia.murphy@geemail.com	Oakland	California	639049140939494	bf8eff340918513f97c10e625bcaf5cd	Discover	37.8208819314127211	-122.255790472603806
46768	2020-08-21 21:24:37	2020-08-21	Dr. Ruie Glover	dr.ruie.glover@warmmail.com	Philadelphia	Pennsylvania	3726543370496233	7936b290e1595f2a34699c1e70b3575a	Discover	40.0915086823940285	-75.0802918434508229
46769	2020-08-21 21:26:56	2020-08-21	Geary Glover II	geary.glover.ii@warmmail.com	New York	New York	869941607268974402	69b15a174a41f4676b10b92c608d066c	VISA 16 digit	40.7515427746567838	-74.0133362261008472
46811	2020-08-22 00:42:39	2020-08-22	Jan Terry	jan.terry@geemail.com	Chicago	Illinois	4376923856250	5c8de6f4cf48842e0cb895544dea702b	VISA 16 digit	41.8298322088852572	-87.6293252848118556
46770	2020-08-21 21:29:00	2020-08-21	Elizabet Sauer	elizabet.sauer@geemail.com	Moreno Valley	California	210075661377446124	9d609d5b11a33cb5e1ac3c6999be132b	VISA 13 digit	33.9303400682743614	-117.278558265461399
46771	2020-08-21 21:33:58	2020-08-21	Dr. Nicholas Reinger II	dr.nicholas.reinger.ii@geemail.com	Phoenix	Arizona	630436377856343	680ad6287783e3beb93963c1caf9a7d1	JCB 16 digit	33.576050465593859	-112.16589778642394
46772	2020-08-21 21:34:02	2020-08-21	Randy Jast	randy.jast@geemail.com	San Francisco	California	3434056044031302	0a7ea340661e28fe569bd6e653b4cd5e	VISA 16 digit	37.7558654211782141	-122.424313305171651
46773	2020-08-21 21:34:10	2020-08-21	Dr. Keion Greenholt Jr.	dr.keion.greenholt.jr.@warmmail.com	Springfield	Illinois	502095879813814	a3dbf5f1c6501288385c511dfabdec2f	VISA 16 digit	39.8066378474388287	-89.5768266154456825
46774	2020-08-21 21:42:07	2020-08-21	Vergie Bashirian DVM	vergie.bashirian.dvm@warmmail.com	Louisville	Kentucky	4866726570449093	2c821ebc819b2256cc2ea8505a15a08b	VISA 13 digit	38.2196730280663814	-85.7345421639807626
46775	2020-08-21 21:51:17	2020-08-21	Dorian Klein	dorian.klein@geemail.com	San Francisco	California	3009125300687627	ef4f399dc917fd4d6660274d0737c6ee	VISA 13 digit	37.775152787681165	-122.455480575540406
46776	2020-08-21 21:52:35	2020-08-21	Laurance Jast	laurance.jast@geemail.com	Abilene	Texas	3337179539566438174	9a88da7057675ac25e7dc455104b5efa	JCB 16 digit	32.493374609209603	-99.7444140482176067
46777	2020-08-21 21:58:13	2020-08-21	Rosendo Stanton	rosendo.stanton@woohoo.com	San Francisco	California	3088013849630918709	1f8733d9899af4321cf7621166f69983	Mastercard	37.7829201320313146	-122.415999820817945
46778	2020-08-21 22:10:17	2020-08-21	Gerhard Wisoky-Rutherford	gerhard.wisoky.rutherford@geemail.com	Milwaukee	Wisconsin	639092389932614	a4eeb78d4e15d85dfc04ea5abaa51c0b	JCB 16 digit	43.0794030908580865	-88.0633720088385132
46779	2020-08-21 22:18:12	2020-08-21	Laquan Runolfsson	laquan.runolfsson@warmmail.com	New York	New York	3337273490088474757	f18e328fa0aa254e93928392f586812f	JCB 16 digit	40.7135977946445351	-73.9699493921257556
46780	2020-08-21 22:18:25	2020-08-21	Lela Jerde DVM	lela.jerde.dvm@geemail.com	Visalia	California	869961013103465281	f130a85c0ae134c9b38d5149a72107ad	VISA 13 digit	36.3117525344669829	-119.313910461509238
46781	2020-08-21 22:21:58	2020-08-21	Donal Huels	donal.huels@geemail.com	San Francisco	California	55666199726082733	c397fe80227af469bc3d2222a10b55ae	VISA 13 digit	37.7849571557732418	-122.44253107346411
46782	2020-08-21 22:30:07	2020-08-21	Mr. Monty Heathcote MD	mr.monty.heathcote.md@geemail.com	Phoenix	Arizona	4358355889640179	7cd96322865e29abc8cd0145ca8993ff	Discover	33.5424973378356555	-112.05607479810007
46783	2020-08-21 22:42:20	2020-08-21	Len Ryan PhD	len.ryan.phd@geemail.com	Omaha	Nebraska	3528294581005776608	502ffa61ed32a87297304db440cb8dd5	JCB 16 digit	41.2371041722741012	-96.0000216998741109
46784	2020-08-21 22:42:48	2020-08-21	Dr. Onnie Smitham	dr.onnie.smitham@warmmail.com	Evansville	Indiana	180035615580879207	9b024a105de8b66e0b4a166cc0594734	VISA 13 digit	38.0401996006861296	-87.5980496533148028
46785	2020-08-21 22:48:28	2020-08-21	Ruie Considine-Klocko	ruie.considine.klocko@geemail.com	Detroit	Michigan	4862043687511458	a409451d13eeece38e03764d050cb8b5	JCB 16 digit	42.4037258190959747	-83.0103090724561383
46786	2020-08-21 22:49:11	2020-08-21	Dr. Orra Stracke PhD	dr.orra.stracke.phd@geemail.com	Washington	District of Columbia	4946165512606698	a964f19692070a17e6a7e7d815ad55ce	Mastercard	38.8196559252481919	-76.9967372276101258
46787	2020-08-21 22:52:48	2020-08-21	Edd Hilll	edd.hilll@geemail.com	San Francisco	California	502037150969469	eb02f2e67b7077d54a2208a8aa610e89	Maestro	37.773495698247892	-122.434632815113147
46788	2020-08-21 22:54:32	2020-08-21	Rosanna Kemmer	rosanna.kemmer@geemail.com	Palm Bay	Florida	4716252091575	33123a947b2a3d1d36995ccfbab0e554	Voyager	27.9214156959991904	-80.6912623713560322
46789	2020-08-21 22:58:33	2020-08-21	Miss Lolla Wisoky MD	miss.lolla.wisoky.md@woohoo.com	Berkeley	California	4951144755521	1aed87401136c3b9d4979f73568ed928	JCB 16 digit	37.8837197475292129	-122.263439221267859
46790	2020-08-21 23:05:56	2020-08-21	Jamya Becker	jamya.becker@warmmail.com	Cincinnati	Ohio	3743180217688687	f151cc92be63b29cd896139d6c8b128a	JCB 16 digit	39.1761442499000552	-84.4973725096128874
46791	2020-08-21 23:06:01	2020-08-21	Wilfred Skiles	wilfred.skiles@geemail.com	Oklahoma City	Oklahoma	589304238701504	8f2fe0ec6e320f1f6a65215cdc7f1298	Voyager	35.5012169415973133	-97.5540990363702178
46792	2020-08-21 23:09:07	2020-08-21	Inger Adams	inger.adams@geemail.com	New York	New York	3703832840085743	577b90fe50edb6489fd5d6c7889281c0	JCB 15 digit	40.6945811850242336	-74.0108139961853624
46793	2020-08-21 23:13:10	2020-08-21	Dr. Johnson Roberts II	dr.johnson.roberts.ii@geemail.com	Buffalo	New York	3019507606908965	45a9f7338a6fd55feff0d39a5e766722	VISA 13 digit	42.9534656454995272	-78.8534171410303628
46794	2020-08-21 23:14:46	2020-08-21	Mr. Joaquin Skiles	mr.joaquin.skiles@woohoo.com	Detroit	Michigan	869978144850040620	b0d675200c7c43e574c970340df63920	Diners Club / Carte Blanche	42.3613057733904625	-83.007965795381736
46795	2020-08-21 23:15:59	2020-08-21	Thelma Lesch	thelma.lesch@geemail.com	Baton Rouge	Louisiana	210075675627035222	0087b4d1b9e91a6e48bc7e420691ffeb	VISA 16 digit	30.4676360977094625	-91.2104642888639034
46796	2020-08-21 23:27:37	2020-08-21	Suzan Beatty MD	suzan.beatty.md@geemail.com	Charlotte	North Carolina	53584152306112619	64c63edab06c506f4eb14d8481b4d327	Discover	35.1664635161191228	-80.7844106010105492
46797	2020-08-21 23:33:15	2020-08-21	Jacky Kreiger-Hackett	jacky.kreiger.hackett@woohoo.com	Philadelphia	Pennsylvania	4139787857164	ee7d7d35accb0b79363357a8d5249d60	VISA 16 digit	40.0643917894881199	-75.0643806867200993
46798	2020-08-21 23:49:09	2020-08-21	Meyer Nienow DVM	meyer.nienow.dvm@warmmail.com	Virginia Beach	Virginia	3112055242420353098	60ed55e705d9ebab2f6f587c1887e3cd	JCB 16 digit	36.7321457409486172	-76.1116705996122249
46799	2020-08-21 23:53:35	2020-08-21	Taft Sipes	taft.sipes@geemail.com	Visalia	California	4103930190758	4c1fd96da6955eda8e454dca7910720e	Discover	36.414497700841352	-119.377637823497508
46800	2020-08-21 23:57:13	2020-08-21	Jaylan Littel V	jaylan.littel.v@geemail.com	Los Angeles	California	3112638734024402590	3e4a804da604edf615df487944c4af5b	JCB 15 digit	34.0109591475553756	-118.363305268901584
46801	2020-08-22 00:03:41	2020-08-22	Raina Kilback MD	raina.kilback.md@woohoo.com	Meridian	Idaho	6011888775646654198	61a789396b437a204b0be0ef544cf08a	VISA 16 digit	43.5539055057808753	-116.320794164383415
46802	2020-08-22 00:05:38	2020-08-22	Mr. Ted Price PhD	mr.ted.price.phd@geemail.com	Chattanooga	Tennessee	180042483483911259	553097ac07506da82a5bbe16fe0e0f80	VISA 13 digit	35.1255331625081624	-85.3229381196960901
46803	2020-08-22 00:08:32	2020-08-22	Flem Barrows	flem.barrows@woohoo.com	Arlington	Texas	3528305397831440740	609a168c6d62c01149f45c065b4600c9	Mastercard	32.6982537679623775	-97.03025382138118
46804	2020-08-22 00:11:12	2020-08-22	Hessie Schaden	hessie.schaden@geemail.com	Memphis	Tennessee	869904288563663647	069fa2b49918fc49e6d9df9b981aed78	Discover	35.0652887689948116	-89.9276316854894162
46805	2020-08-22 00:18:23	2020-08-22	Jena Mertz	jena.mertz@warmmail.com	San Francisco	California	3022783434950985	4f84f5540e151359a80511b87d6d08a7	JCB 16 digit	37.7571930871302044	-122.445885661178977
46806	2020-08-22 00:18:33	2020-08-22	Andrea Hagenes	andrea.hagenes@geemail.com	Lincoln	Nebraska	4378512529136804	7d827abfb36ef8968c0c0e429ffdb061	Diners Club / Carte Blanche	40.8661422639638161	-96.7317248652383768
46807	2020-08-22 00:23:26	2020-08-22	Odessa Klein-Hand	odessa.klein.hand@geemail.com	San Francisco	California	4737872882920	9f6642d2c31ee6f000b8e0538729dc1e	VISA 13 digit	37.7948815840219083	-122.454356661404319
46808	2020-08-22 00:25:46	2020-08-22	Celestia Heaney	celestia.heaney@geemail.com	Los Angeles	California	4176334393215166	502fca773a7cef8ada0f6eb4d90c6bf6	VISA 13 digit	34.1145116886455568	-118.50788031546324
46809	2020-08-22 00:25:57	2020-08-22	Miss Lucero Steuber PhD	miss.lucero.steuber.phd@geemail.com	Oakland	California	3438490788571908	60513df9920a8a40dfbb89aa6f846277	Maestro	37.8072266419779623	-122.272786207230297
46810	2020-08-22 00:35:43	2020-08-22	Damond Lockman	damond.lockman@geemail.com	Scottsdale	Arizona	3096111950983495799	d3c9f188cfbd2a8c3cc53c6f25fd9f1d	Diners Club / Carte Blanche	33.7375978408504267	-111.793069903968274
46812	2020-08-22 00:44:01	2020-08-22	Lila Carroll MD	lila.carroll.md@warmmail.com	Vancouver	Washington	869985623950039187	71341fada1a5e40b87b87b2ba1048985	Maestro	45.5647416026867944	-122.675694168831029
46813	2020-08-22 00:44:23	2020-08-22	Dominic Goodwin MD	dominic.goodwin.md@warmmail.com	Portland	Oregon	6011877317610369512	44703bd137d894964859a7e5e2d84a6d	JCB 15 digit	45.4622199030946916	-122.602847619121903
46814	2020-08-22 00:47:24	2020-08-22	Ms. Racquel Kling	ms.racquel.kling@geemail.com	Carlsbad	California	3018240390895658	c37bde1051f42d7dd13651547d405e03	Diners Club / Carte Blanche	33.1295177182588745	-117.313680460562182
46815	2020-08-22 00:53:46	2020-08-22	Bridget Swift	bridget.swift@warmmail.com	Indianapolis	Indiana	3753822377623908	9188a56b0b75376473eaac1f688f9360	VISA 16 digit	39.7523848377641258	-86.181722296189136
46816	2020-08-22 00:57:27	2020-08-22	Russell Lang	russell.lang@geemail.com	San Francisco	California	3052947978004216	5f990cb1e5e9d6d068fb068c0cfff0ae	JCB 16 digit	37.7780917324220766	-122.426965055636614
46817	2020-08-22 00:58:34	2020-08-22	Ms. Edris Bogisich	ms.edris.bogisich@geemail.com	Denton	Texas	3411188166925859	578637c1b3ba53db182be551e7b62eb5	Discover	33.1209739643413599	-97.113104792790125
46818	2020-08-22 01:02:52	2020-08-22	Hunter Murray	hunter.murray@geemail.com	San Francisco	California	6011074882928452988	0e628481c3598e033fda5ec76d5f4dd4	Maestro	37.7890536565324098	-122.42060176740118
46819	2020-08-22 01:06:25	2020-08-22	Brandt Roob	brandt.roob@geemail.com	Laredo	Texas	3409383819789943	1e41e7b7b7515c5ed417bb2229d2bfb8	VISA 16 digit	27.6324518800429999	-99.4434309073265581
46820	2020-08-22 01:15:10	2020-08-22	Ms. Mavis Goyette	ms.mavis.goyette@geemail.com	Irvine	California	3468649911103417	b331cc5b09e5ff97c0b633dc7ffad9f2	JCB 16 digit	33.7153998498819831	-117.698633593321958
46821	2020-08-22 01:19:47	2020-08-22	Mr. Booker Robel DVM	mr.booker.robel.dvm@geemail.com	Oakland	California	4145259228153068	ce2a0ab0ba70243c93ab44a8ab6f5d26	JCB 16 digit	37.8125280075117089	-122.293944446506003
46822	2020-08-22 01:21:39	2020-08-22	Mr. Kayson Prosacco V	mr.kayson.prosacco.v@warmmail.com	Gilbert	Arizona	3158715156858948967	b4307e14861033ca055b1a10bf76cf2b	American Express	33.2862138657711455	-111.755343399163706
46823	2020-08-22 01:24:08	2020-08-22	Carolann Quitzon	carolann.quitzon@geemail.com	Arvada	Colorado	210095081477381897	2f79dbb1d8bbbf17e90675bcc4fd59be	VISA 16 digit	39.8610124145343931	-105.22108555901535
46824	2020-08-22 01:45:35	2020-08-22	Carmen Rowe	carmen.rowe@geemail.com	San Bernardino	California	180073225306410684	7c5ced62604153f4356aa6c5ac66b721	Mastercard	34.1543337201498431	-117.226641813829914
46825	2020-08-22 01:48:26	2020-08-22	Harvey Lindgren	harvey.lindgren@geemail.com	Wichita	Kansas	210002372591074902	b8a51ac9d758c08371bab308387f4840	VISA 16 digit	37.7782923335086522	-97.2870372262053138
46826	2020-08-22 01:53:47	2020-08-22	Miss Olie Tillman	miss.olie.tillman@warmmail.com	Dallas	Texas	4880262835668	c503992154824853c00a96c8bf3a657f	VISA 16 digit	32.8013535759218087	-96.6940148738641199
46827	2020-08-22 02:01:02	2020-08-22	Declan Lockman	declan.lockman@woohoo.com	New York	New York	210066605556897095	676b71591826cca706e328c8638b9326	Maestro	40.650194825999435	-73.8686639560282146
46828	2020-08-22 02:06:16	2020-08-22	Lindsay Connelly	lindsay.connelly@geemail.com	Green Bay	Wisconsin	51582723459525591	a0a123e1f067bcb49099d04c0caa11d0	Diners Club / Carte Blanche	44.4606654355831452	-87.9441962899461345
46829	2020-08-22 02:07:58	2020-08-22	Armond Stoltenberg	armond.stoltenberg@geemail.com	San Francisco	California	3005623098328754	875399ab7758bba6373d125b3676f9ae	VISA 13 digit	37.8046523663030598	-122.453321665352732
46830	2020-08-22 02:14:25	2020-08-22	Dana Jones	dana.jones@geemail.com	Berkeley	California	869932043271734982	51f206171f7136c39612aaa58f49f802	Discover	37.8617513451571526	-122.315579681883989
46831	2020-08-22 02:21:59	2020-08-22	Amaris Ryan	amaris.ryan@woohoo.com	Jackson	Mississippi	869939480856197867	910d5607dcb652595ca46060e6615a75	JCB 15 digit	32.341971418139714	-90.2344371902264726
46832	2020-08-22 02:35:45	2020-08-22	Mrs. Briana Ferry DDS	mrs.briana.ferry.dds@geemail.com	Oceanside	California	3337249986964849377	52630b185cc13c31467133a9230b432d	Maestro	33.2005681923013185	-117.390369078525154
46833	2020-08-22 02:40:30	2020-08-22	Raiden Hackett	raiden.hackett@geemail.com	Milwaukee	Wisconsin	6011788114640532088	5080bc878ad3c34d80a322bf6b9fc2ef	American Express	42.9794908341105995	-87.9955176721427677
46834	2020-08-22 02:42:30	2020-08-22	Alexande Watsica	alexande.watsica@woohoo.com	San Francisco	California	4398576271392887	324c675c0bf2619903e0ae04fbcc50a4	VISA 16 digit	37.7853506186370609	-122.423098737965773
46835	2020-08-22 02:55:29	2020-08-22	Nada Wiza	nada.wiza@geemail.com	Chesapeake	Virginia	180091160121711776	a63c30cedf56b4a277d15560acfad3dd	VISA 13 digit	36.7427763194549826	-76.345216960025212
46836	2020-08-22 02:58:15	2020-08-22	Jazlene Ferry DDS	jazlene.ferry.dds@warmmail.com	Dallas	Texas	180086315309954393	c5e715b1be6679edc5055cb09541d0f3	JCB 15 digit	32.8036867942467367	-96.7274026995487475
46837	2020-08-22 03:09:30	2020-08-22	Dr. Jakayla Goyette	dr.jakayla.goyette@geemail.com	Anchorage	Alaska	3015652650305769	fc43dcaf04fe38806bff31c479a3576d	VISA 13 digit	61.1388674634259246	-149.254908179457487
46838	2020-08-22 03:16:51	2020-08-22	Buford Swift	buford.swift@geemail.com	New York	New York	180086300254329692	75b47c1565cb5a3280d221303c5ef4d6	JCB 16 digit	40.6232092655021688	-74.0101570801705151
46839	2020-08-22 03:18:09	2020-08-22	Miss Kyra McDermott	miss.kyra.mcdermott@geemail.com	Fort Lauderdale	Florida	4580569229963428	d1f0de8c6cf9ce8dfa3abb07776f7992	VISA 16 digit	26.235942648024114	-80.2259008920572683
46840	2020-08-22 03:29:39	2020-08-22	Mr. Jayden Roob MD	mr.jayden.roob.md@geemail.com	New York	New York	210075302653433235	77d5d759abf3fd7c975320e415dae59e	American Express	40.7081566749364114	-73.9070400564361307
46841	2020-08-22 03:32:22	2020-08-22	Taliyah Krajcik	taliyah.krajcik@woohoo.com	Yonkers	New York	4890281359921	1eeb10a7897e726d8d7b4229d81e59ed	JCB 16 digit	41.0367734189812126	-73.9068026312977082
46842	2020-08-22 03:36:48	2020-08-22	Kaitlynn Williamson DDS	kaitlynn.williamson.dds@geemail.com	Gilbert	Arizona	3017240134930762	43882c5d39624b437e5723083d54054c	Diners Club / Carte Blanche	33.2684751926802065	-111.776641434444485
46843	2020-08-22 03:47:21	2020-08-22	Mr. Jaydon Heathcote Sr.	mr.jaydon.heathcote.sr.@woohoo.com	Berkeley	California	4320221640560	bf04cbed566c995cbc4987c86d8c26ca	Mastercard	37.866618496168293	-122.275492670716005
46844	2020-08-22 03:50:43	2020-08-22	Jettie Heller	jettie.heller@woohoo.com	North Las Vegas	Nevada	3712365775115317	5afff85289e9b90a9dcd84a6c5616375	American Express	36.2943420980747788	-115.129376730857047
46845	2020-08-22 04:05:31	2020-08-22	Janeen Kilback	janeen.kilback@geemail.com	Fort Worth	Texas	6011157675552636391	ff5acf386165fb7317bac7ddc87f38df	Mastercard	32.7993281277883781	-97.4342092194881246
46846	2020-08-22 04:06:48	2020-08-22	Jeramie Metz-Heathcote	jeramie.metz.heathcote@geemail.com	Boston	Massachusetts	3528697019505053718	04afa86ed6258f01fab9ccb090be9cb6	Voyager	42.3229987110178953	-71.0935107000123736
46847	2020-08-22 04:14:30	2020-08-22	Dustan Conn	dustan.conn@warmmail.com	Glendale	Arizona	3053246718486661	683a212332dba44f24ace982ce084a5e	Diners Club / Carte Blanche	33.5444479784224185	-112.108475358111406
46848	2020-08-22 04:29:22	2020-08-22	Lute Simonis-O'Kon	lute.simonis.o'kon@geemail.com	Anaheim	California	4485704941528	f4ff80b90053f79e1fcadef93342b4c5	VISA 16 digit	33.8514748193155981	-117.79358610019311
46849	2020-08-22 04:32:59	2020-08-22	Dr. Zander Kris II	dr.zander.kris.ii@warmmail.com	Los Angeles	California	3096604512521539217	5c84767b32f686825ab6470fad3a9fc0	JCB 16 digit	34.0585171863768252	-118.356773370829586
46850	2020-08-22 04:33:00	2020-08-22	Janet Romaguera	janet.romaguera@woohoo.com	Columbus	Ohio	3414806313756664	af891066fa9e12a50fe6b7887e78e245	JCB 16 digit	39.9287204604640564	-83.0538329267643434
46851	2020-08-22 04:37:00	2020-08-22	Diamond Jakubowski	diamond.jakubowski@warmmail.com	Moreno Valley	California	210026807573347141	4c365b33769d685dfbdce795ccb3b592	VISA 16 digit	33.9617612260852013	-117.133904169729718
46852	2020-08-22 04:41:17	2020-08-22	Tex Bayer	tex.bayer@geemail.com	Denton	Texas	3158891136963848167	e44afc5919f0e5fdd0ad3b3c9c9f63e8	Mastercard	33.1599119043707873	-97.085309858586271
46853	2020-08-22 04:41:35	2020-08-22	Sage Upton V	sage.upton.v@geemail.com	Ontario	California	52193428588088088	f1df93f39366715a7ad051b2de99ccd4	Discover	33.9517174835927804	-117.617346962039178
46854	2020-08-22 04:46:14	2020-08-22	Celestino Cremin	celestino.cremin@geemail.com	Los Angeles	California	4331141795859851	8a02e10a1a0eb2a72e3a83e3b43d49bc	Discover	34.0074390236154187	-118.367735242051253
46855	2020-08-22 04:53:34	2020-08-22	Ashley Schmitt	ashley.schmitt@woohoo.com	Chicago	Illinois	3088669073262676496	e97dcb328761a300150d308be054d0fb	Discover	41.7740252900239071	-87.6739185772865994
46856	2020-08-22 04:58:36	2020-08-22	River Price	river.price@woohoo.com	Fort Worth	Texas	6011089885683476103	0831e3f302c4449919c10ed4fe77d00c	American Express	32.7977070704158393	-97.378547631838174
46857	2020-08-22 05:00:46	2020-08-22	Carey Schulist-Ondricka	carey.schulist.ondricka@warmmail.com	San Angelo	Texas	3411789082860458	c9fa8fb578386098a17b2ab3e585d9b3	American Express	31.3573591182161096	-100.360488164668908
46858	2020-08-22 05:01:19	2020-08-22	Mr. Vaughn Hills	mr.vaughn.hills@geemail.com	Memphis	Tennessee	501884626338770	848c37cc3e2b7c4e98a1c7d295880e55	Voyager	35.1277553444795316	-90.053448224791893
46859	2020-08-22 05:06:41	2020-08-22	Dr. Sara Runte	dr.sara.runte@geemail.com	Kansas City	Missouri	4610296372256525	9c7fc72cfed6dbcb573d69570cd2057b	VISA 13 digit	39.1768968548927461	-94.5875522652398786
46860	2020-08-22 05:12:59	2020-08-22	Mindy Ledner	mindy.ledner@geemail.com	Los Angeles	California	180000602857976313	f98bc1551c64ef0c4cd6d06dbf9bf3ac	VISA 16 digit	34.0984025242604289	-118.467668015835059
46861	2020-08-22 05:19:14	2020-08-22	Donavan Macejkovic	donavan.macejkovic@geemail.com	Elgin	Illinois	869970799352216891	9c8f7d7499f3036450eff1269e409d30	JCB 15 digit	42.0419310905322448	-88.2698760902795954
46862	2020-08-22 05:24:21	2020-08-22	Louvenia Toy	louvenia.toy@geemail.com	Dallas	Texas	4068344006327846	16546178b4980536c16881007b7a39ea	JCB 15 digit	32.7620180064152962	-96.6770551226995849
46863	2020-08-22 05:24:39	2020-08-22	Estel Pacocha-Waelchi	estel.pacocha.waelchi@geemail.com	Pasadena	California	3032286704764532	a89d20b475e6b200f6d4ca7a576b0558	VISA 16 digit	34.1043529675662569	-118.066861717198421
46864	2020-08-22 05:25:22	2020-08-22	Clora Spencer	clora.spencer@geemail.com	Tulsa	Oklahoma	3158298353301264739	dab1d8235ecc16c97d573d513c1b39a7	JCB 16 digit	36.0987392943255543	-95.8429472449190882
46865	2020-08-22 05:27:13	2020-08-22	Reggie Kub	reggie.kub@warmmail.com	Akron	Ohio	3337018266027717054	8a5d25c7fc7878ca3f5a99021b7f2ff2	Discover	41.0884703013412675	-81.4910564216166762
46866	2020-08-22 05:33:15	2020-08-22	Johnna Russel	johnna.russel@geemail.com	San Francisco	California	3158276168967036767	44177c577392504df1cad8aacff4d5fa	Maestro	37.7589849662795984	-122.462986767172254
46867	2020-08-22 05:34:54	2020-08-22	Julien Rutherford	julien.rutherford@geemail.com	Los Angeles	California	180023502905449656	f491e041cc406696a95dde962e3c65b6	JCB 15 digit	33.9814967234484797	-118.510767432580877
46868	2020-08-22 05:41:56	2020-08-22	Kalen Haag	kalen.haag@geemail.com	Tacoma	Washington	3027222281959182	5c901240668ae95a871f7afa5fed4d2c	JCB 15 digit	47.3297003541260963	-122.471612966363509
46869	2020-08-22 05:51:51	2020-08-22	Tyron Konopelski	tyron.konopelski@geemail.com	Oakland	California	3112763739526452792	db7e73b36bffea5c59a6724eead99006	Mastercard	37.7995589784089958	-122.26184572401479
46870	2020-08-22 05:56:20	2020-08-22	Odell Ferry	odell.ferry@woohoo.com	New York	New York	3491860622772926	7af575f2415fe7c3bab4e47c254069ac	Maestro	40.5815480572395018	-73.9884999049723149
46871	2020-08-22 06:11:06	2020-08-22	Salvatore Huel	salvatore.huel@geemail.com	Kent	Washington	4490039462145660	6c2d6820affe4e98e8ead6010a59f4b1	Voyager	47.448535397753119	-122.283884518653892
46872	2020-08-22 06:18:01	2020-08-22	Rupert Bernier Sr.	rupert.bernier.sr.@woohoo.com	Omaha	Nebraska	3158269043655189351	29c8e6f18ceae74e0eecae8fabdb5fc0	JCB 16 digit	41.2351544848788549	-96.0240392510894765
46873	2020-08-22 06:19:30	2020-08-22	Lyndia Boyer	lyndia.boyer@warmmail.com	San Antonio	Texas	4213691869906973	a410b8102c4a44ac9162bb34527698f3	JCB 16 digit	29.5440568068135541	-98.6212467576678762
46874	2020-08-22 06:23:00	2020-08-22	Hobert Labadie PhD	hobert.labadie.phd@warmmail.com	Las Vegas	Nevada	210023600838273555	d3c89569321f73e8c7ee61b821506ef2	Mastercard	36.2532868749562667	-115.262269309230518
46875	2020-08-22 06:29:10	2020-08-22	Gideon Maggio	gideon.maggio@geemail.com	Mesa	Arizona	4392300413953	a71149c749c50f60d6930b5750ac4b50	JCB 16 digit	33.3646311055082805	-111.657346089871226
46876	2020-08-22 06:29:19	2020-08-22	Ruffin Cronin	ruffin.cronin@geemail.com	San Antonio	Texas	3158507059335778860	27a9549f3e4e882fac4f5179f188413c	Diners Club / Carte Blanche	29.5338101872313779	-98.5999976905364548
46877	2020-08-22 06:30:07	2020-08-22	Dolly Altenwerth	dolly.altenwerth@geemail.com	Orlando	Florida	4936940829869	b00aaa302b64eaaf81dfc1077ce67faf	Diners Club / Carte Blanche	28.4083778879869726	-81.2221125103034041
46878	2020-08-22 06:33:52	2020-08-22	Delia Hand DDS	delia.hand.dds@woohoo.com	St. Petersburg	Florida	54907091696534018	c7a8a0a58638f608f08a7cf5df46dac2	JCB 15 digit	27.7251118533667196	-82.6752042821500339
46879	2020-08-22 06:34:29	2020-08-22	Brande Streich	brande.streich@woohoo.com	Detroit	Michigan	3033137464950564	3e91c4d1dfb15ae18e400937ff7e1a35	VISA 16 digit	42.3397419936414821	-83.1972277350377283
46880	2020-08-22 06:39:51	2020-08-22	Macarthur Feil	macarthur.feil@geemail.com	Jacksonville	Florida	6011549065885824814	5bc3af73ce98d5919ec360e87d1d5ed8	VISA 13 digit	30.4115956950053565	-81.7063449378203615
46881	2020-08-22 06:46:37	2020-08-22	Felipe Graham-Huels	felipe.graham.huels@geemail.com	Allentown	Pennsylvania	6011645768240639305	57f2afc61cefc8fe6da79c5df4476109	Discover	40.5457466562524473	-75.4744315792355565
46882	2020-08-22 06:47:42	2020-08-22	Rocky Goyette	rocky.goyette@geemail.com	Berkeley	California	3112312096988154093	bd18a1403fcec84d43d0ae54df2c44b3	American Express	37.8341948761113258	-122.340356084262893
46883	2020-08-22 06:49:05	2020-08-22	Caryn Stark	caryn.stark@geemail.com	Albuquerque	New Mexico	4951081471501402	0ae5ca769bb2bc4b1c3362992d03dc07	JCB 16 digit	35.1765752442780908	-106.716597101006286
46884	2020-08-22 06:52:03	2020-08-22	Kenia Frami DDS	kenia.frami.dds@geemail.com	Wichita	Kansas	3112436506736689605	43167056fa76f6584f371b73b0a77fad	VISA 16 digit	37.6451932194985446	-97.3564832567904119
46885	2020-08-22 06:54:02	2020-08-22	Miss Lola Mayer	miss.lola.mayer@woohoo.com	Aurora	Illinois	3088787754153055018	111f7da5e5a24b1abb36f3e77babe0da	Voyager	41.672096741175281	-88.2041972451306862
46886	2020-08-22 07:01:14	2020-08-22	Angelo Stanton	angelo.stanton@geemail.com	Oklahoma City	Oklahoma	3438430959359121	cb71948d60466d32d49c69a64394a482	Diners Club / Carte Blanche	35.3852337752845187	-97.4267944451317192
46887	2020-08-22 07:10:08	2020-08-22	Eliga Auer	eliga.auer@geemail.com	Edison	New Jersey	6011810647437489212	cbe248d32c741089ba6853703a8cbf92	VISA 13 digit	40.5305103262849116	-74.3855310809850749
46888	2020-08-22 07:13:38	2020-08-22	Cherie Bins	cherie.bins@woohoo.com	Richardson	Texas	3158941165063669330	bfeef5d4217dde52ef3b0afdf08f95bc	American Express	32.9047110306333721	-96.7369555026520089
46889	2020-08-22 07:13:57	2020-08-22	Dr. Chadrick Tremblay	dr.chadrick.tremblay@geemail.com	Philadelphia	Pennsylvania	675969159278592	aa655a699bafdcb131e7df3183e61920	VISA 16 digit	39.9211950510699296	-75.2094556986719454
46890	2020-08-22 07:18:14	2020-08-22	Vernetta Zieme	vernetta.zieme@geemail.com	Oxnard	California	53489081290914902	ca805dbac651f40476adc3478452aaa1	Voyager	34.2607171799011567	-119.242910581026592
46891	2020-08-22 07:26:51	2020-08-22	Myrle Gibson	myrle.gibson@geemail.com	Charlotte	North Carolina	869946691465143693	2f5862c0c60a57bb4f4973967c00d71d	VISA 16 digit	35.1294277038212854	-80.8305529602747441
46892	2020-08-22 07:34:55	2020-08-22	Journey Mayert	journey.mayert@woohoo.com	New York	New York	3049048617490149	4d67d2f240bf182ad6aadd42e021244a	VISA 16 digit	40.6812617935463763	-73.9449752832192928
46893	2020-08-22 07:35:01	2020-08-22	Miss Anice Hilpert PhD	miss.anice.hilpert.phd@geemail.com	League City	Texas	210054541806276513	83fe3a985f2b3b27fa24255b03e6f075	American Express	29.5766252777002769	-95.0168584796585094
46894	2020-08-22 07:37:59	2020-08-22	Britany Kutch	britany.kutch@warmmail.com	Berkeley	California	3096459344596757326	d7e58cfc00d06979a8e8e6129ab4b870	Mastercard	37.9002039790283192	-122.266667268954521
46895	2020-08-22 07:45:48	2020-08-22	Maye Blick-Von	maye.blick.von@geemail.com	Austin	Texas	3013851477088531	36a3499558d9c263c133967a4fc851dd	Maestro	30.3667476061858217	-97.8255638614069767
46896	2020-08-22 07:53:01	2020-08-22	Jacques Stiedemann-Paucek	jacques.stiedemann.paucek@woohoo.com	Los Angeles	California	3528031733764429246	db1fe54d72c5e5289b08faed396efd9e	American Express	34.0441239704709488	-118.359287386014302
46897	2020-08-22 07:57:27	2020-08-22	Rosey Kunze	rosey.kunze@geemail.com	Warren	Michigan	3001295740420844	f0d9f7f467cdaa15eabcabb6d4739cdf	Voyager	42.5023713810831296	-83.1120058726053799
46898	2020-08-22 08:10:27	2020-08-22	Schuyler Luettgen	schuyler.luettgen@woohoo.com	Denver	Colorado	869900090683053806	e4dec5262d92711e25bfc885853acd1b	JCB 15 digit	39.7406661255337283	-104.877967304993803
46899	2020-08-22 08:19:12	2020-08-22	Naomi Daniel-Barrows	naomi.daniel.barrows@geemail.com	Dallas	Texas	4728391507403677	647e6de13fe43dc6d9c9e663b9fbc42f	Mastercard	32.7667099707100533	-96.7544287609830462
46900	2020-08-22 08:20:18	2020-08-22	Anya Beier	anya.beier@woohoo.com	West Jordan	Utah	6011654618252960800	0d18b54c1706f9ca6e377a823e947306	JCB 15 digit	40.6585335943173618	-111.996906134634457
46901	2020-08-22 08:21:21	2020-08-22	Perry Bins V	perry.bins.v@woohoo.com	San Francisco	California	6011880855210282002	87f4d108fd3b455980535fb3cece7203	Mastercard	37.769634280945894	-122.431749993697665
46902	2020-08-22 08:26:19	2020-08-22	Mr. Kim Predovic	mr.kim.predovic@warmmail.com	Bakersfield	California	630422115333456	4a91ff29527fe5e66d179f23e78e1efd	JCB 15 digit	35.3174810849770893	-118.934536731735989
46903	2020-08-22 08:29:57	2020-08-22	Dr. Isaak Pacocha	dr.isaak.pacocha@geemail.com	Boston	Massachusetts	060427226903865	7efc8d7e5cca0923b7bdfa070fa03a32	JCB 15 digit	42.3084862709678688	-71.0156854167066598
46904	2020-08-22 08:30:33	2020-08-22	Lovey Langworth	lovey.langworth@woohoo.com	San Francisco	California	4452649863685381	2a1de9d977f2810e3efb0ee3f50ac77b	JCB 16 digit	37.732114260090647	-122.45363795049677
46905	2020-08-22 08:31:17	2020-08-22	Alaina Kerluke-Altenwerth	alaina.kerluke.altenwerth@woohoo.com	New York	New York	869929313687995492	bf6a67911642b01caa3a8e76948043c7	American Express	40.5939315119516095	-73.8444999133132427
46906	2020-08-22 08:32:58	2020-08-22	Esker Witting	esker.witting@geemail.com	Los Angeles	California	4351990172772649	0bff346ea56e3cd5d158a9618f37f4df	JCB 16 digit	34.0234122790262106	-118.355066471220169
46907	2020-08-22 09:05:24	2020-08-22	Dr. Ari Donnelly	dr.ari.donnelly@warmmail.com	Topeka	Kansas	3158622849158621043	60e97eafa7576c26ebab7e3f38a74ca5	VISA 13 digit	39.0501416884295622	-95.7512768442917661
46908	2020-08-22 09:16:01	2020-08-22	Gregoria O'Reilly	gregoria.o'reilly@geemail.com	Garden Grove	California	869969640659416375	88f045c49b8b3188f3f5db129bc7db57	American Express	33.7763091790314718	-117.917283765647554
46909	2020-08-22 09:45:12	2020-08-22	Tawanda O'Keefe	tawanda.o'keefe@geemail.com	San Francisco	California	4218327702413886	8bcb0ea565a1f94ea5bae1f903eb9791	JCB 15 digit	37.7684962128619972	-122.435273219995338
46910	2020-08-22 09:51:53	2020-08-22	Javier Bechtelar	javier.bechtelar@geemail.com	Sacramento	California	180061538444647551	0a2e8afad313ce9830ab33c8aaf06fb1	JCB 16 digit	38.5563363227326406	-121.561772818468881
46911	2020-08-22 09:55:39	2020-08-22	Miss Anice Okuneva	miss.anice.okuneva@geemail.com	Norfolk	Virginia	180099563338731416	577c0eca68aa0f2c7b5c0613117459c4	American Express	36.9421082377918069	-76.3148319737989453
46912	2020-08-22 10:05:37	2020-08-22	Destiny Johnson-Wolf	destiny.johnson.wolf@geemail.com	Portland	Oregon	676160987341942	14983a5f9891c9ccea4153c30c9684ff	Maestro	45.4483712241873121	-122.722391504794359
46913	2020-08-22 10:10:02	2020-08-22	Dariana Kunde PhD	dariana.kunde.phd@warmmail.com	Fort Wayne	Indiana	869915054192961175	b41218c6aad8c46fd8a6aae4d9a319de	JCB 15 digit	41.1323984751261804	-85.1110106466092162
46914	2020-08-22 10:13:11	2020-08-22	Hilary Feest	hilary.feest@geemail.com	High Point	North Carolina	869936339055676522	143e1803371c3a52b95217ecc0e2eedf	Mastercard	35.9472368844877934	-80.0208497398737819
46915	2020-08-22 10:13:33	2020-08-22	Maddison Ortiz	maddison.ortiz@geemail.com	Cary	North Carolina	6011951364282523926	8975bf2326282a53f494fe65456324e2	American Express	35.7038516836814637	-78.7631562565538985
46916	2020-08-22 10:22:41	2020-08-22	Daja Stark	daja.stark@woohoo.com	Oakland	California	4733798633134336	a68629a820dd929299dca4c57356b2f7	VISA 13 digit	37.8314728158690414	-122.270601040734221
46917	2020-08-22 10:24:30	2020-08-22	Alejandro Runolfsdottir	alejandro.runolfsdottir@warmmail.com	Portland	Oregon	3045235118959235	d826f0ddadd6d435250f4a2ca53ad6ae	Mastercard	45.5716229997463529	-122.566688814619567
46918	2020-08-22 10:27:30	2020-08-22	Dr. Darrell Jenkins	dr.darrell.jenkins@geemail.com	Louisville	Kentucky	4969488048786434	c88361aa3ec383d75f741b737b826568	VISA 16 digit	38.1758433592408863	-85.6744306049846216
46919	2020-08-22 10:32:11	2020-08-22	Trudie Stehr	trudie.stehr@geemail.com	Phoenix	Arizona	4680121412262546	bcf526d07d5fb2edd85391f303272222	JCB 16 digit	33.511737062030285	-111.998365866898013
46920	2020-08-22 10:32:27	2020-08-22	Corbin Bradtke-Blick	corbin.bradtke.blick@geemail.com	Tampa	Florida	501806174980281	cf80cec2642751de01dbe8b078b281db	VISA 13 digit	27.8901537492986762	-82.4395388113081395
46921	2020-08-22 10:46:46	2020-08-22	Ms. Jayda Bode	ms.jayda.bode@geemail.com	Jacksonville	Florida	3088421065269548560	2d2a47ac2e019fbf65cfc57b11c08758	Voyager	30.3436844762466862	-81.7060611233659131
46922	2020-08-22 10:50:22	2020-08-22	Dr. Oswaldo Schultz	dr.oswaldo.schultz@warmmail.com	Meridian	Idaho	6011097024578832499	cf76375ee0d25345403bd2191ed0d1f1	VISA 16 digit	43.6017603002496017	-116.369723460957033
46923	2020-08-22 10:56:10	2020-08-22	Dr. Nyasia Mitchell	dr.nyasia.mitchell@geemail.com	Los Angeles	California	3096320919712181399	1de1edabf3d59fc1a3e884e9664b326a	VISA 16 digit	34.0292621749319082	-118.341836368058992
46924	2020-08-22 11:04:16	2020-08-22	Maia Rosenbaum	maia.rosenbaum@geemail.com	Minneapolis	Minnesota	3490808086388821	a8a6180615ab8eb259b5d9e3f4628c93	American Express	44.9684840274594677	-93.3382152231216367
46925	2020-08-22 11:05:51	2020-08-22	Rilla Ziemann-Parisian	rilla.ziemann.parisian@geemail.com	New York	New York	3048504595940159	3669e417de274cfd8e3f1519a7079b5f	VISA 16 digit	40.6852140073422319	-74.0260562367632957
46926	2020-08-22 11:21:37	2020-08-22	Gerardo Blanda	gerardo.blanda@warmmail.com	Oakland	California	3727599686121310	7790749fcf19482e763652599edeffdb	Mastercard	37.7523683476062217	-122.238796816238235
46927	2020-08-22 11:44:37	2020-08-22	Dr. Isreal Yost Jr.	dr.isreal.yost.jr.@geemail.com	Dallas	Texas	675929945600319	97d391ae334a8d6c0b3c53722ee616d6	American Express	32.7301101677391699	-96.7414716672114992
46928	2020-08-22 12:00:56	2020-08-22	Melbourne Runolfsson	melbourne.runolfsson@geemail.com	Phoenix	Arizona	3439786814487129	4a9fbf036752efdd72bab4c9925ab64b	Maestro	33.5683929649580293	-112.124933494387577
46929	2020-08-22 12:06:57	2020-08-22	Joline Ruecker	joline.ruecker@geemail.com	San Diego	California	3471314841174708	6ef8781db28b2d6e302ec2f1bbf65a34	Maestro	32.747159222007916	-117.064475853312771
46930	2020-08-22 12:08:42	2020-08-22	Natalie Wilkinson	natalie.wilkinson@woohoo.com	San Francisco	California	52064030268254893	d81d141dd5155718fb290fca8d922eae	American Express	37.7917267236999166	-122.452178944892808
46931	2020-08-22 12:13:43	2020-08-22	Kris Gaylord	kris.gaylord@geemail.com	Santa Rosa	California	3023535031396338	f05f380631e0244fd0ce54a6b16add5f	Voyager	38.4982077199157331	-122.700699454803399
46932	2020-08-22 12:16:42	2020-08-22	Axel Nienow	axel.nienow@geemail.com	Irvine	California	3484558863280513	a73a686cc4350f2aa052c796366e186a	JCB 15 digit	33.724075804559142	-117.711978387042137
46933	2020-08-22 12:16:44	2020-08-22	Gale Waelchi DDS	gale.waelchi.dds@geemail.com	Stamford	Connecticut	210032344375360496	be37f770e3fb6ee60c73833487826dc2	Maestro	41.0621252449113925	-73.5857162164561487
46934	2020-08-22 12:22:22	2020-08-22	Albion Sanford	albion.sanford@woohoo.com	Anaheim	California	3037087983588112	af784db458579fea523b6bd09c7d8812	Diners Club / Carte Blanche	33.9175276877656557	-117.731318836586922
46935	2020-08-22 12:23:10	2020-08-22	Crockett Brown	crockett.brown@geemail.com	Hialeah	Florida	3088023595436819330	1a5e1f7efb15795616d9e843c80ecf39	Maestro	25.8796745113074778	-80.3194788165759235
46936	2020-08-22 12:34:06	2020-08-22	Jaxen Weissnat	jaxen.weissnat@geemail.com	Denver	Colorado	53965767956508995	3ceb84da065ce51540179f522fd24600	VISA 16 digit	39.7305245908029363	-104.8145232241381
46937	2020-08-22 12:35:18	2020-08-22	Giancarlo Brakus	giancarlo.brakus@geemail.com	Phoenix	Arizona	51607045779725862	b1f70f43ef44fdaba2d607954d5fc3dc	JCB 16 digit	33.6236552897308059	-112.090998479623721
46938	2020-08-22 12:38:06	2020-08-22	Dr. Edd Stracke	dr.edd.stracke@geemail.com	Los Angeles	California	210059486409171767	e90f57a9df67bd4a6301b583ba59a264	VISA 16 digit	33.9742917808104252	-118.504218896803621
46939	2020-08-22 12:39:47	2020-08-22	Katheryn Gulgowski	katheryn.gulgowski@geemail.com	Laredo	Texas	6011935550176622532	0c5d356878dff8bd39455fc4c73d2e49	JCB 15 digit	27.5870105602495386	-99.5726297393914308
46940	2020-08-22 12:41:03	2020-08-22	Russ Schimmel	russ.schimmel@geemail.com	Kansas City	Missouri	210021768231127009	0f8b0f249a246b5a80adfb2f010aadd1	Discover	39.0785998164512236	-94.4759512685462823
46941	2020-08-22 12:42:51	2020-08-22	Breann Boyer MD	breann.boyer.md@geemail.com	Albuquerque	New Mexico	630469845552749	8fa0a49fec52114ce8c464335937af2a	JCB 16 digit	35.0377132170036489	-106.682711789624392
46942	2020-08-22 12:45:19	2020-08-22	Emmy Schiller	emmy.schiller@geemail.com	Seattle	Washington	3742546604869810	ca9cc8c22a3d9519e7fbdd5354494531	JCB 15 digit	47.6815322948545202	-122.431310267179825
46943	2020-08-22 13:01:53	2020-08-22	Ilda Goldner-Cruickshank	ilda.goldner.cruickshank@geemail.com	Kansas City	Missouri	52694457715979350	5ab46338af35a76b93be28e9d8258e25	Maestro	39.1363270683981526	-94.6311576722413292
46944	2020-08-22 13:06:38	2020-08-22	Hadley Crist	hadley.crist@geemail.com	Phoenix	Arizona	3088403925964680228	76f44efc57ac2e1860916a7683a4d7fa	JCB 16 digit	33.6287850047860317	-112.121758292701472
46945	2020-08-22 13:06:39	2020-08-22	Wallace Purdy DVM	wallace.purdy.dvm@geemail.com	Philadelphia	Pennsylvania	6011428082548558206	1df3fc4c78df512f5ed3d7aabd7daa8d	Mastercard	40.0253043863415741	-75.1856611750453823
46946	2020-08-22 13:07:11	2020-08-22	Valentine Rosenbaum	valentine.rosenbaum@woohoo.com	New York	New York	6011046039383573825	cc0d43b4d9351be72b862ac3ebcb0ec7	Mastercard	40.6873314494490614	-74.0099326726876114
46947	2020-08-22 13:17:48	2020-08-22	Villa Christiansen-Rosenbaum	villa.christiansen.rosenbaum@woohoo.com	Toledo	Ohio	4394351384987245	b9a6d3a08340f4961aacbef55e5e7c7c	Voyager	41.6182908633429562	-83.5107035818841297
46948	2020-08-22 13:32:23	2020-08-22	Jamie Gusikowski	jamie.gusikowski@geemail.com	Austin	Texas	869902618952214044	44699e9a677ec390f5d99670f477019b	Diners Club / Carte Blanche	30.2867134839888656	-97.852892585262282
46949	2020-08-22 13:35:31	2020-08-22	Toivo Gleason	toivo.gleason@geemail.com	Durham	North Carolina	6011896028408887584	2c93ca8b32625b9134ed2e3bbd171beb	Discover	35.9656285404007861	-78.8103281801935367
46950	2020-08-22 13:53:35	2020-08-22	Judi Weissnat	judi.weissnat@geemail.com	San Francisco	California	3757562131569825	3bb8ca136a9c3dcc605861b7d9759c65	VISA 16 digit	37.7795782410392817	-122.436707501944127
46951	2020-08-22 13:58:06	2020-08-22	Mrs. Violet Stoltenberg MD	mrs.violet.stoltenberg.md@geemail.com	San Diego	California	180005381916601916	222334abc6cda4129b82113ea41361fb	JCB 16 digit	32.7614061098147218	-117.187699228096761
46952	2020-08-22 14:04:43	2020-08-22	Lew Reinger Sr.	lew.reinger.sr.@geemail.com	Detroit	Michigan	4028736649915441	2642fa9da8cae331cde1e58e974da514	Mastercard	42.4049804115127813	-83.1871485788960001
46953	2020-08-22 14:10:22	2020-08-22	Edd Weimann	edd.weimann@woohoo.com	Vallejo	California	869998321753667800	bf1bcb933fd2aa26f21af0a38d5f8f86	VISA 16 digit	38.0234756479129175	-122.240657860353579
46954	2020-08-22 14:11:03	2020-08-22	Mr. Reginald Kuhic	mr.reginald.kuhic@warmmail.com	Cleveland	Ohio	3088601389039307749	9367189704e4249d515c07762225b73c	VISA 13 digit	41.4798013942167145	-81.6626657534163485
46955	2020-08-22 14:29:28	2020-08-22	Olof Dooley-Hackett	olof.dooley.hackett@woohoo.com	Orange	California	3796452693337766	2e91b8a29a0c7bba201384d9a62f1385	JCB 15 digit	33.7025526332557206	-117.829860593947771
46956	2020-08-22 14:33:04	2020-08-22	Jamal Kuhn	jamal.kuhn@geemail.com	Houston	Texas	180055896992773858	82c82210f67337773475e7fe7f376c8f	VISA 16 digit	29.8459017510604099	-95.4601033377010424
46957	2020-08-22 14:41:49	2020-08-22	Ms. Caldonia Koss DDS	ms.caldonia.koss.dds@geemail.com	San Jose	California	51339259314932652	9e96b35e50f025fc598bae321b9970ff	JCB 16 digit	37.3755333186879781	-121.889045006803798
46958	2020-08-22 14:43:30	2020-08-22	Garrison Grant	garrison.grant@warmmail.com	New York	New York	210092928385244968	1345a011505b801e85ad92335de53191	VISA 13 digit	40.7336417300850115	-73.9635202115762951
46959	2020-08-22 15:00:11	2020-08-22	Arvil Heidenreich	arvil.heidenreich@warmmail.com	Santa Clarita	California	3337297254982490984	8085831b117c8dc01b391d27813d6497	JCB 16 digit	34.3149240076281146	-118.591541932067642
46960	2020-08-22 15:03:52	2020-08-22	Miss Lona Cole	miss.lona.cole@geemail.com	Tempe	Arizona	210091398802758134	5b995b9f9112d20b4f5e59bf4ddd73da	VISA 13 digit	33.3415212500296505	-111.898846683793877
46961	2020-08-22 15:04:56	2020-08-22	Brittanie Johns	brittanie.johns@woohoo.com	San Francisco	California	3769864011192983	8d31202dffe0191f753e147f83e84150	Diners Club / Carte Blanche	37.7512586419795468	-122.451878460108716
46962	2020-08-22 15:07:57	2020-08-22	Miss Rachael Franecki DDS	miss.rachael.franecki.dds@geemail.com	Buffalo	New York	210064594942803458	9d8ad863377dbfc3d37fcca9c2ea5685	Voyager	42.8300081162899744	-78.9268483310870863
46963	2020-08-22 15:08:05	2020-08-22	Elenore Hilll	elenore.hilll@geemail.com	Sacramento	California	3158527294498235731	3df1f18ec0436a8f6b3461b6c65b9f05	VISA 16 digit	38.6292658976078016	-121.548830659525834
46964	2020-08-22 15:21:37	2020-08-22	Lovey Halvorson	lovey.halvorson@warmmail.com	Phoenix	Arizona	4796601962502	8df46e5427058881db8699f9182e9b67	VISA 13 digit	33.6275375333081925	-111.992669276141015
46965	2020-08-22 15:23:23	2020-08-22	Dr. Jeanetta Jones PhD	dr.jeanetta.jones.phd@geemail.com	New York	New York	869922154710351007	6477ef918c3be6e44ec993e016c5f490	Diners Club / Carte Blanche	40.6610424073170833	-73.8929346051428411
46966	2020-08-22 15:33:38	2020-08-22	Cleola Hessel	cleola.hessel@geemail.com	Houston	Texas	210051497390922868	4bcfe438e0e78f59237b62dfd7257dfc	VISA 16 digit	29.8816431572273373	-95.3561478031814147
46967	2020-08-22 15:34:37	2020-08-22	Miss Alisson Koelpin PhD	miss.alisson.koelpin.phd@geemail.com	Columbus	Ohio	4187020679052632	544004175784c74236351ddea4bf2c1d	VISA 16 digit	40.0516847168605779	-82.9059891872808379
46968	2020-08-22 15:37:37	2020-08-22	Buddy Ledner	buddy.ledner@geemail.com	Raleigh	North Carolina	4106216754055767	2fdfb9d223d07241d13279bc07953236	American Express	35.8246745906438662	-78.6049363543681778
46969	2020-08-22 15:49:36	2020-08-22	Barnie Lowe	barnie.lowe@woohoo.com	San Diego	California	3337822682914593414	2ccdcbea8bae5a41044fe5f450e639ac	Diners Club / Carte Blanche	32.8968945809241404	-117.047203989224514
46970	2020-08-22 15:49:55	2020-08-22	Dr. Willa Torp	dr.willa.torp@geemail.com	Alexandria	Virginia	4181549096989642	9d6b237b995479c357d3bd215a4d50a3	Voyager	38.7312305872909661	-77.1432524306219136
46971	2020-08-22 15:52:17	2020-08-22	Halsey Larkin-Upton	halsey.larkin.upton@woohoo.com	Honolulu	Hawaii	3528859397977001009	dfd2e9f11ba4f7f61be9784f7225386b	VISA 16 digit	21.4033188989136391	-157.802117551884066
46972	2020-08-22 15:56:07	2020-08-22	Karina Mayer	karina.mayer@geemail.com	Raleigh	North Carolina	4331642213416	5fa49aecafc29bbf5a30abbb376298a0	Discover	35.9279565647378547	-78.6303665753390675
46973	2020-08-22 16:11:13	2020-08-22	Konner Bergnaum	konner.bergnaum@geemail.com	San Antonio	Texas	3014929452175835	54fd7577ed0d1f512716e23d872c0b1d	Mastercard	29.4861994069140394	-98.563628381800271
46974	2020-08-22 16:11:43	2020-08-22	Miss Hellen Orn	miss.hellen.orn@geemail.com	San Francisco	California	869965443996425066	d4d46a6ff256a094f2921c43d1899829	Mastercard	37.7535708317315368	-122.437074066646247
46975	2020-08-22 16:14:52	2020-08-22	Lars Bode	lars.bode@geemail.com	Arlington	Texas	3026110307558982	631d6f901c887b34cd5675a0696fe48e	VISA 13 digit	32.7473967805754356	-97.1489546716239403
46976	2020-08-22 16:16:07	2020-08-22	Fate Sanford-Schulist	fate.sanford.schulist@geemail.com	Arvada	Colorado	4583300246559545	edfd52e874e1af0298bde8f94c3a6134	VISA 16 digit	39.7512336113665228	-105.150230239748211
46977	2020-08-22 16:23:04	2020-08-22	Claudie Macejkovic	claudie.macejkovic@geemail.com	Memphis	Tennessee	869988847386586852	83d544caf5c3fe257e8e1bd30626306e	JCB 16 digit	35.1839827455181648	-90.0502880818001898
46978	2020-08-22 16:26:41	2020-08-22	Mr. Ernie Conn	mr.ernie.conn@woohoo.com	Fairfield	California	6011209980791617816	a9dac9c56002feb6ceb85522bf9c96b5	Mastercard	38.2354205754708545	-122.089008966554331
46979	2020-08-22 16:30:51	2020-08-22	Minoru Blick Sr.	minoru.blick.sr.@woohoo.com	Fort Worth	Texas	561205880633192	42610eb5f1484d5c3d570693418bc439	VISA 16 digit	32.7658115577008573	-97.3544908709179566
46980	2020-08-22 16:34:42	2020-08-22	Francis Flatley-Collier	francis.flatley.collier@warmmail.com	New York	New York	4947579794449	9038bce5ce8f8d642b04606e8c264813	Voyager	40.6072077441718449	-73.8400288639951441
46981	2020-08-22 16:38:39	2020-08-22	Dr. Vickey Kessler	dr.vickey.kessler@geemail.com	Antioch	California	630483115648749	f2286ba0701dcd0140b748f5e4ce74fd	American Express	38.0523379423920076	-121.705501629941907
46982	2020-08-22 16:47:10	2020-08-22	Wava Gorczany PhD	wava.gorczany.phd@warmmail.com	Irving	Texas	869916934731505675	eb34d7b2a01f9ddccefcfdbb6f9a8b9c	Discover	32.8993171396151212	-96.9250630068406451
46983	2020-08-22 16:52:32	2020-08-22	Ms. Amalia Carter MD	ms.amalia.carter.md@geemail.com	Berkeley	California	3005059427320586	0375867eaebe1ed80b116fad8bdff6f4	VISA 16 digit	37.8638600587351846	-122.284382074360053
46984	2020-08-22 16:52:49	2020-08-22	Callie Walter	callie.walter@woohoo.com	Boston	Massachusetts	4620218212713976	c712ba96777e1600648972ca34d065ee	Diners Club / Carte Blanche	42.3520738096144029	-70.9259607494294642
46985	2020-08-22 16:58:45	2020-08-22	Denver Little	denver.little@warmmail.com	Austin	Texas	55720332959512662	b89b384f59d4c0284b7cd0b9d74c79d9	JCB 16 digit	30.2593020151030245	-97.6740035535540443
46986	2020-08-22 17:02:41	2020-08-22	Dameon Gusikowski-Satterfield	dameon.gusikowski.satterfield@geemail.com	Houston	Texas	3158016875524290621	4537b1aa2556946c607e8b21e83d2f3c	American Express	29.8439510454036281	-95.4181630144376385
46987	2020-08-22 17:08:14	2020-08-22	Landan Stokes	landan.stokes@geemail.com	Kent	Washington	589338513068742	4b0f17eff15a0f8e66bb0f4a63f044e8	VISA 16 digit	47.3437443439029124	-122.263279795194791
46988	2020-08-22 17:10:08	2020-08-22	Harmony Bergstrom	harmony.bergstrom@geemail.com	Savannah	Georgia	6011964310297274935	d123469738995a6242cea110fdae4353	American Express	31.954792924234642	-81.1488809191774578
46989	2020-08-22 17:23:14	2020-08-22	Elfreda Glover	elfreda.glover@woohoo.com	New York	New York	4569287956639369	7113c3a2902564a33ef03d8012290412	Maestro	40.6251886882111393	-73.9347408438462708
46990	2020-08-22 17:26:56	2020-08-22	Fronnie Stoltenberg DVM	fronnie.stoltenberg.dvm@geemail.com	Chicago	Illinois	4451841316881318	c904525cf4ce310b39add1edbadcbdee	JCB 16 digit	41.7532066843308556	-87.6438276750531031
46991	2020-08-22 17:27:16	2020-08-22	Dr. Burke Ziemann	dr.burke.ziemann@geemail.com	Little Rock	Arkansas	3158522084854563528	dc58958cf87a7b6669abfed0724c7a8d	JCB 16 digit	34.7254957910437128	-92.2777655709408151
46992	2020-08-22 17:29:52	2020-08-22	Luciano Frami I	luciano.frami.i@geemail.com	San Francisco	California	3059478153678155	bad6ee21b760c6c1272b1f2859a89a1b	VISA 16 digit	37.7721103163217435	-122.39342990625542
46993	2020-08-22 17:52:41	2020-08-22	Sharon Conroy	sharon.conroy@geemail.com	San Francisco	California	54422001968007722	c6640583a92675604ca8c317f92cef70	VISA 16 digit	37.7382025635420959	-122.463063040209207
46994	2020-08-22 17:54:07	2020-08-22	Alexia Schultz-Anderson	alexia.schultz.anderson@geemail.com	Baltimore	Maryland	675911238086448	72e10be9e4e2bcc85d7839a4d048fcc5	JCB 16 digit	39.3701370687689618	-76.6208769801557139
46995	2020-08-22 18:09:36	2020-08-22	Wyatt Tremblay	wyatt.tremblay@warmmail.com	Memphis	Tennessee	54289148244141080	6cb88959d9a195bc0d1e61e1eb4b3806	Voyager	35.1039195786297356	-90.0472354118969349
46996	2020-08-22 18:14:32	2020-08-22	Aurelio Ziemann	aurelio.ziemann@geemail.com	Knoxville	Tennessee	3158358783354099375	462b7607b77e4e23060ce0e066416c0d	JCB 16 digit	35.8772066535025829	-83.9431469403423307
46997	2020-08-22 18:16:43	2020-08-22	Megan O'Kon	megan.o'kon@geemail.com	Boise	Idaho	53195226056069145	f5e3c22e79d6d9980c310e9a93b1046c	Diners Club / Carte Blanche	43.6184603627443295	-116.247985459743816
46998	2020-08-22 18:23:23	2020-08-22	Tanesha Ziemann	tanesha.ziemann@geemail.com	New York	New York	53826779225518449	8826f6a92f4a9c7b52a4d2121a19338f	JCB 15 digit	40.7234246932659261	-73.9721307780489354
46999	2020-08-22 18:35:59	2020-08-22	Keenen Wehner	keenen.wehner@geemail.com	San Francisco	California	210008548159503317	2371e73352ab9053b075642aff34d4a8	VISA 16 digit	37.7769786888072687	-122.42456649518823
47000	2020-08-22 18:37:12	2020-08-22	Taylor Lowe	taylor.lowe@woohoo.com	Fontana	California	6011255507726394717	db9c1bbe72b0a602ff07644dc1c1ffff	JCB 15 digit	34.1240934328790786	-117.431160307144381
47001	2020-08-22 18:41:38	2020-08-22	Ola Cruickshank	ola.cruickshank@woohoo.com	San Francisco	California	3402964802336524	2ddeb88939d3e5a41a3b78f4dc45b54a	VISA 16 digit	37.7656340334456857	-122.424944921538412
47002	2020-08-22 18:45:55	2020-08-22	Danielle Sporer MD	danielle.sporer.md@geemail.com	Midland	Texas	4585808122741	a03c296c75c896b4e481730854ba60d0	JCB 15 digit	31.9896707227177899	-102.064459167815741
47003	2020-08-22 18:51:39	2020-08-22	Miss Marni Hilll PhD	miss.marni.hilll.phd@geemail.com	Ann Arbor	Michigan	501845500674218	dc2d48d36ae35431c116153ddb8fe4b0	JCB 15 digit	42.3666372620560239	-83.795704178383204
47004	2020-08-22 18:56:34	2020-08-22	Miss Taja Effertz DVM	miss.taja.effertz.dvm@woohoo.com	San Francisco	California	210030032469546904	4ef41e657bb34143cafa50f3a6e445cb	JCB 16 digit	37.7943179991351528	-122.427139854881773
47005	2020-08-22 19:02:25	2020-08-22	Dr. Nathalie Bins	dr.nathalie.bins@geemail.com	New York	New York	4442744858252918	e7b53bbb56483b4b39cfcdfc121001f2	JCB 15 digit	40.7621989392898953	-73.8487812709424674
47006	2020-08-22 19:05:35	2020-08-22	Mr. Semaj Dickinson	mr.semaj.dickinson@geemail.com	Columbus	Georgia	3034965866006331	c5d5650ff4bdfe75c90b9630ff1f3ced	Voyager	32.4657766766425198	-84.8321171782609014
47007	2020-08-22 19:08:13	2020-08-22	Ms. Kristina Mueller MD	ms.kristina.mueller.md@geemail.com	Boston	Massachusetts	3112001863556906402	de00b54182568b04526860a3e478e9af	JCB 16 digit	42.4071115793827929	-71.0993784679982781
47008	2020-08-22 19:08:38	2020-08-22	Tyreek Feest	tyreek.feest@geemail.com	Seattle	Washington	502079605587454	08af109355373689bf752c4a61497625	JCB 16 digit	47.6057679420262545	-122.339845160806178
47009	2020-08-22 19:09:22	2020-08-22	Jerrold Jast	jerrold.jast@warmmail.com	San Francisco	California	3054666012480657	b6720006a537c70514d2652cd6e24520	Voyager	37.7980926534265578	-122.456156720587884
47010	2020-08-22 19:13:48	2020-08-22	Izola Lehner PhD	izola.lehner.phd@geemail.com	Provo	Utah	4111410522846317	7f38689d83f863a8a78a22304720d918	Diners Club / Carte Blanche	40.2138523977968845	-111.558927927273515
47011	2020-08-22 19:19:59	2020-08-22	Garrett Dickinson	garrett.dickinson@geemail.com	Houston	Texas	3096260764419479445	d638231982ee9b7fb8b0011a805dfb3b	JCB 16 digit	29.7222869542505599	-95.406416518056389
47012	2020-08-22 19:22:42	2020-08-22	Harlow Howe	harlow.howe@geemail.com	Philadelphia	Pennsylvania	4404301104771781	e93fb44180f80539c4f71b3d976c5481	JCB 15 digit	39.9132455942179973	-75.1650231355700669
47013	2020-08-22 19:25:38	2020-08-22	Mr. Orlando Muller PhD	mr.orlando.muller.phd@woohoo.com	Oakland	California	3096598586166816500	7d1035bb1ed8b3c8f38c6d4faa3ccff2	JCB 16 digit	37.8178509383736525	-122.273478106197842
47014	2020-08-22 19:25:54	2020-08-22	Miss Denise Huel	miss.denise.huel@woohoo.com	Aurora	Colorado	869933582163710773	26c4ed21920a1895ac40f3f5785977cf	VISA 16 digit	39.6724921637326489	-104.608183965517952
47015	2020-08-22 19:30:28	2020-08-22	Darrien DuBuque	darrien.dubuque@woohoo.com	Kansas City	Missouri	4253556530710	f4ae22d76a8c7f70be6c131ff81638c9	JCB 16 digit	39.0786250305663856	-94.6092326259464045
47016	2020-08-22 19:30:33	2020-08-22	Sarina Rippin	sarina.rippin@geemail.com	San Francisco	California	4296352730642855	afe4a5fcc949b8a22558da3448128369	Mastercard	37.7796628086734287	-122.438466773364198
47017	2020-08-22 19:41:45	2020-08-22	River Pagac DDS	river.pagac.dds@warmmail.com	Visalia	California	3491123547153452	b8a08314149a990978a3c3d2454babda	Diners Club / Carte Blanche	36.2483106330923732	-119.317864092265822
47018	2020-08-22 19:48:24	2020-08-22	Mr. Leigh Moore Sr.	mr.leigh.moore.sr.@geemail.com	Oakland	California	6011272284657242963	50363a97a06c20a8b5d7e3b39d0a0e2f	JCB 16 digit	37.8083142378200989	-122.249304718331061
47019	2020-08-22 19:55:56	2020-08-22	Earl Hickle	earl.hickle@woohoo.com	Shreveport	Louisiana	3096017518771068717	d1354db90f40e6b93a7bd0d08f268cb5	Diners Club / Carte Blanche	32.3759241727419251	-93.7345153379000635
47020	2020-08-22 19:56:41	2020-08-22	Amaris Spinka DVM	amaris.spinka.dvm@geemail.com	Baltimore	Maryland	210026330403982037	4f39e371e8f28700fa41605216a0c15a	American Express	39.2025775283109397	-76.6408333930205572
47021	2020-08-22 19:57:42	2020-08-22	Paityn Wolff	paityn.wolff@geemail.com	Philadelphia	Pennsylvania	4897516336795803	d31c3454be6d8e993a96820de111ef04	VISA 13 digit	40.0160376806236826	-75.1257642320256736
47022	2020-08-22 20:04:00	2020-08-22	Chin Mann	chin.mann@geemail.com	Memphis	Tennessee	3015431115015507	ddc8bb96c1185551fd6b38327204901b	Voyager	35.051505783905462	-89.9235541153956177
47023	2020-08-22 20:05:03	2020-08-22	Alexande Nolan-Terry	alexande.nolan.terry@geemail.com	Springfield	Massachusetts	180015016849842090	23dc8fdaf238d3411adfc8038f1784be	American Express	42.132363999981429	-72.5293742655403975
47024	2020-08-22 20:15:17	2020-08-22	Dr. Viney Mraz	dr.viney.mraz@geemail.com	Philadelphia	Pennsylvania	3112589428653629156	ba0535dc44c1517dced621a3482fa0dd	JCB 16 digit	40.0501741226255916	-75.057411796403315
47025	2020-08-22 20:17:02	2020-08-22	Mrs. Paris Raynor DDS	mrs.paris.raynor.dds@geemail.com	Phoenix	Arizona	676381065501025	e1d332af7e2bbec6638600a4f420148c	JCB 15 digit	33.4940311806209436	-112.110956757974265
47026	2020-08-22 20:19:11	2020-08-22	Karson Buckridge	karson.buckridge@geemail.com	Philadelphia	Pennsylvania	4398449876325241	f6a10d9f56b1e78f4507d6f56a525737	VISA 16 digit	39.9126410862389918	-75.1704872756630209
47027	2020-08-22 20:33:19	2020-08-22	Bryson Feeney	bryson.feeney@geemail.com	Mobile	Alabama	6011304958296965546	f70202fd911a4953004657c58f834321	Diners Club / Carte Blanche	30.7508874946381887	-88.1039539261393259
47028	2020-08-22 20:33:23	2020-08-22	Jaleel Cummings	jaleel.cummings@geemail.com	New York	New York	3112845305360114732	f9e885afbc757aa80b8ec6124d9b11e4	JCB 16 digit	40.7185289906095704	-73.8995039959333866
47029	2020-08-22 20:37:28	2020-08-22	Tylor Goodwin	tylor.goodwin@woohoo.com	Saint Paul	Minnesota	4476580414685624	de263e84f6a27bd81113fbe0e59ce8c3	VISA 13 digit	44.9598743043314713	-93.0527086657736504
47030	2020-08-22 20:38:59	2020-08-22	Junius Nikolaus-Schmidt	junius.nikolaus.schmidt@geemail.com	Las Vegas	Nevada	6011341087904342123	8fb7ffcdb0146e2e5042a3b0514feb4d	American Express	36.1508501176357271	-115.281966806363684
47031	2020-08-22 20:40:56	2020-08-22	Colon Treutel	colon.treutel@warmmail.com	Oakland	California	210084368965333172	70a1e614b37ef0d5567d6e6be0746b61	American Express	37.8126326989675192	-122.242940474017075
47032	2020-08-22 21:10:15	2020-08-22	Karsyn McGlynn-Greenholt	karsyn.mcglynn.greenholt@warmmail.com	Arlington	Texas	210016971826949947	178eee8341e4802c18b0a88ccd0ea942	JCB 15 digit	32.7506802334699785	-97.0723388721261244
47033	2020-08-22 21:12:05	2020-08-22	Arleth Zboncak	arleth.zboncak@geemail.com	Worcester	Massachusetts	6011549854445026600	b4283023ea28890e3ffaa6bd1bfa0fae	Diners Club / Carte Blanche	42.1936196812130504	-71.8992556710515203
47034	2020-08-22 21:24:25	2020-08-22	Carra Tillman	carra.tillman@geemail.com	San Francisco	California	3096481640689819838	1b622d545a777dad9a4a705f9821d197	Maestro	37.7617578404690875	-122.422652587027017
47035	2020-08-22 21:24:48	2020-08-22	Debera Bradtke-Rempel	debera.bradtke.rempel@geemail.com	Philadelphia	Pennsylvania	54781756546946486	84ebc2f0c2217ea2f41407a06fde2e40	VISA 13 digit	39.9987979911692406	-75.0711613261040327
47036	2020-08-22 21:39:51	2020-08-22	Orla Hoeger IV	orla.hoeger.iv@geemail.com	Durham	North Carolina	6011237809232331917	0e04139d869367d4bbba01019a700775	American Express	35.9728805832344989	-78.868179792295777
47037	2020-08-22 22:12:29	2020-08-22	Mr. Albert Franecki PhD	mr.albert.franecki.phd@geemail.com	Rancho Cucamonga	California	4572634682256643	a0d2b401a54808ecfb15b5218028bc34	VISA 16 digit	34.1804496205870052	-117.487490229775005
47038	2020-08-22 22:25:46	2020-08-22	Effie Keebler-Padberg	effie.keebler.padberg@geemail.com	Philadelphia	Pennsylvania	3773530132382985	a3dd48be9b4b5a4c66a41c9e5eb70e2a	Maestro	40.009057793994991	-75.2328184004306877
47039	2020-08-22 22:30:25	2020-08-22	Carmine Cronin	carmine.cronin@geemail.com	San Francisco	California	3158557380048071495	dfaacfcb24a225e1f6b93f48148cd4b6	Discover	37.7787753226533525	-122.458144477752271
47040	2020-08-22 22:41:24	2020-08-22	Mr. Syed Williamson DVM	mr.syed.williamson.dvm@geemail.com	Richmond	California	3158640753711349357	12d1d0ac9c95c49724f73047bb038a75	Maestro	37.8800773714158723	-122.342484499965238
47041	2020-08-22 22:45:38	2020-08-22	Russel Hayes II	russel.hayes.ii@geemail.com	Denver	Colorado	3414159335733299	ac371c99840a56a419aeb40c32d094f2	Discover	39.674052100447561	-104.792133874284474
47042	2020-08-22 22:49:47	2020-08-22	Cristian Johnston-Aufderhar	cristian.johnston.aufderhar@geemail.com	Bridgeport	Connecticut	869943935983780152	4225201b52907b8af7bedc782022120b	Maestro	41.1425713807042683	-73.1703456086937365
47043	2020-08-22 22:52:17	2020-08-22	Dr. Cyndi Lebsack	dr.cyndi.lebsack@geemail.com	San Francisco	California	210054160572087184	4491ae7f228cdd833756967edd2795c6	Diners Club / Carte Blanche	37.7794192773671895	-122.422639547742108
47044	2020-08-22 22:56:58	2020-08-22	Dr. Bella Spencer	dr.bella.spencer@geemail.com	Waco	Texas	55726522630841746	b775daae04788f84dd6e1211e6825c0c	American Express	31.4969406947702169	-97.1280682458207139
47045	2020-08-22 22:57:20	2020-08-22	Clarance McGlynn V	clarance.mcglynn.v@geemail.com	San Francisco	California	4528738236332357	72d8d8b39896fa9dd0d8c766a822b2c4	Mastercard	37.7665657657859484	-122.413846014899505
47046	2020-08-22 22:57:43	2020-08-22	Channing Parker DDS	channing.parker.dds@geemail.com	Fort Collins	Colorado	55102741278153024	19aaa583d9f0915f3af347956eb49810	Mastercard	40.5611428762011244	-105.064671197063475
47047	2020-08-22 23:05:01	2020-08-22	Liz Koelpin-Haag	liz.koelpin.haag@geemail.com	Tulsa	Oklahoma	502065065303946	370b97a4fab38942ba0a0b29a00b5133	JCB 16 digit	36.0410214764434826	-95.9665194065730986
47048	2020-08-22 23:09:17	2020-08-22	Karie Hilll	karie.hilll@geemail.com	San Francisco	California	3096760074338398089	8dce8f8ee4ab4b9e72e112a130300f3e	Maestro	37.770767304212697	-122.463959733797054
47049	2020-08-22 23:10:01	2020-08-22	Ezra Ebert	ezra.ebert@geemail.com	Lincoln	Nebraska	210021112639894953	73b2315becc20e800912ababe6fa7ffd	JCB 16 digit	40.7731236007083169	-96.6466412962574566
47050	2020-08-22 23:10:25	2020-08-22	Casey Hermiston	casey.hermiston@geemail.com	Victorville	California	210029203425245450	b2f80c46d222196b847fffe4f285cda5	Voyager	34.6038478758417085	-117.323106910070777
47051	2020-08-22 23:10:26	2020-08-22	Williams Zboncak	williams.zboncak@geemail.com	Henderson	Nevada	180081344408563579	070d2eacb919549448c7268081b38533	VISA 16 digit	36.0377681387055659	-115.080075586370015
47052	2020-08-22 23:13:34	2020-08-22	Lindsey Quitzon III	lindsey.quitzon.iii@geemail.com	Colorado Springs	Colorado	6011932747962378047	d262de73c871b05ad1e65c8b222ae1a9	VISA 16 digit	38.8243968710817384	-104.786439181879913
47053	2020-08-22 23:17:02	2020-08-22	Ms. Carina Kozey DVM	ms.carina.kozey.dvm@woohoo.com	Phoenix	Arizona	55990904802305826	98acdcebdc51721b1cd9068656f8024a	JCB 16 digit	33.6378036198139228	-112.010798408084
47054	2020-08-22 23:24:50	2020-08-22	Albertha Moore-Klein	albertha.moore.klein@woohoo.com	Phoenix	Arizona	210080233104187182	cb97ea33a523fdc62150a0358e22ffaa	Voyager	33.5039494436632879	-112.058118210306773
47055	2020-08-22 23:30:01	2020-08-22	Dr. Ansel Beer DVM	dr.ansel.beer.dvm@geemail.com	Denver	Colorado	869998544713732204	66821b03a6f515eb24c9f3ef1d5744fb	VISA 16 digit	39.7521509289327994	-104.854418738443783
47056	2020-08-22 23:35:29	2020-08-22	Elton Nitzsche	elton.nitzsche@geemail.com	San Francisco	California	6011532830767881268	46d4ced112fa72aefe428ad136975265	JCB 16 digit	37.7768959623424578	-122.450106716168733
47057	2020-08-22 23:51:18	2020-08-22	Wright Bartoletti	wright.bartoletti@geemail.com	Riverside	California	4020730307031755	50e023da502f56c0de220a27a90a42a9	Diners Club / Carte Blanche	33.9717888770572856	-117.340287572468441
47058	2020-08-23 00:09:43	2020-08-23	Gustav Moore	gustav.moore@geemail.com	Houston	Texas	210074781062810672	f9d9513cbec040e7b73b5e3560ff889c	American Express	29.8607871704813093	-95.4733391544330914
47059	2020-08-23 00:13:06	2020-08-23	Dr. Kenney Baumbach	dr.kenney.baumbach@geemail.com	Houston	Texas	3445466510365083	9a7c65d5c5f59084b92b4b79bc918303	VISA 16 digit	29.838353664435818	-95.4164665851756979
47060	2020-08-23 00:19:10	2020-08-23	Reilly Breitenberg	reilly.breitenberg@geemail.com	Santa Ana	California	4879188730032720	d6bcf6cd2f93ac7eb2f5bc91186a1cb5	Voyager	33.7778292462799712	-117.831519907146685
47061	2020-08-23 00:19:57	2020-08-23	Lennie Goodwin	lennie.goodwin@geemail.com	Fargo	North Dakota	6011430099099906523	834f98ee1d5723a1af734ce2115a5c76	JCB 16 digit	46.9305117049951122	-96.7494372308216981
47062	2020-08-23 00:31:50	2020-08-23	Darby Thompson	darby.thompson@geemail.com	Clarksville	Tennessee	3096168310731502820	4af1bef84aedd3959cbd43fc00fc9eae	Diners Club / Carte Blanche	36.4821047554384918	-87.4193776710841917
47063	2020-08-23 00:33:25	2020-08-23	Griffith Bode	griffith.bode@woohoo.com	Boston	Massachusetts	3096050264300230563	199eaa3b9d5504b4acab6a90ffd0653d	Maestro	42.3205884192306527	-71.0941439488388625
47064	2020-08-23 00:51:33	2020-08-23	Louisa Ondricka PhD	louisa.ondricka.phd@warmmail.com	Boston	Massachusetts	3016754998196444	ef3802190f6994be053eec92dde8a9b2	JCB 15 digit	42.421429204864431	-71.0275654359206641
47065	2020-08-23 00:52:21	2020-08-23	Jaeden Kuvalis	jaeden.kuvalis@geemail.com	Garland	Texas	6011180621752056635	fb971fa5a12e60c1c08ed8b31ba377b8	VISA 16 digit	32.8304157158128902	-96.6740759228516424
47066	2020-08-23 01:05:03	2020-08-23	Mr. Dylon Waelchi	mr.dylon.waelchi@geemail.com	Springfield	Massachusetts	4752769033922592	a346c076d8d8ba4f7605bc8c3716dc73	VISA 16 digit	42.149636994974685	-72.6095405026897822
47067	2020-08-23 01:12:06	2020-08-23	Dr. Armstead Sawayn	dr.armstead.sawayn@woohoo.com	Waco	Texas	4316634263503	1d9ce9444457f8d9c9a1e352fbd31cd3	Voyager	31.4859758011739679	-97.1913409954067333
47068	2020-08-23 01:16:56	2020-08-23	Donia McLaughlin	donia.mclaughlin@warmmail.com	Omaha	Nebraska	4582393758146448	6ed4c829eb22ebe52e2b09ec0b00e403	Discover	41.3006845322582876	-96.0730856072738817
47069	2020-08-23 01:17:35	2020-08-23	Dr. Ryder Hyatt MD	dr.ryder.hyatt.md@geemail.com	McKinney	Texas	53218402112712589	c550cacf44bb10d8aa5cf7b6b13534f7	American Express	33.148214064132425	-96.762340915652004
47070	2020-08-23 01:30:05	2020-08-23	Corbin Wehner	corbin.wehner@geemail.com	San Bernardino	California	4767505198550	806bda63f90a79af61c70ec96d379d6d	Diners Club / Carte Blanche	34.142086901821564	-117.269111560682205
47071	2020-08-23 01:37:03	2020-08-23	Dr. Hasel Gleichner DVM	dr.hasel.gleichner.dvm@woohoo.com	Reno	Nevada	3005371919314096	d70f0aca23f1995aba6728d4159ad37a	VISA 16 digit	39.62909788806774	-119.852383773278078
47072	2020-08-23 01:41:24	2020-08-23	Branden Howell	branden.howell@warmmail.com	San Francisco	California	3112572686898326388	6386e12484c801df69454c4a550595bf	JCB 15 digit	37.7553090796979447	-122.432262522057698
47073	2020-08-23 01:49:18	2020-08-23	Maliyah Parisian-Hettinger	maliyah.parisian.hettinger@geemail.com	Houston	Texas	53267048606288154	a18a5c588ce2523dd00bd845610cf7a2	JCB 16 digit	29.7120018384031965	-95.4861920767478694
47074	2020-08-23 02:15:34	2020-08-23	Dr. Salomon Yundt	dr.salomon.yundt@geemail.com	Indianapolis	Indiana	869987099973950957	00462961b17f79dcc51e1bdcae686045	VISA 16 digit	39.8084418536171327	-86.098310274744037
47075	2020-08-23 02:22:45	2020-08-23	Ayanna Lang DDS	ayanna.lang.dds@geemail.com	Atlanta	Georgia	3158448265633481949	d7bb28b3bf7cfdd38a305020365d5088	VISA 13 digit	33.7006682877704549	-84.4149025871928842
47076	2020-08-23 02:26:48	2020-08-23	Mr. Colten Will	mr.colten.will@geemail.com	Los Angeles	California	3020160780626620	d8d942f660ce777adbee8bf4dcd496da	Voyager	34.0100405933666963	-118.444947711005057
47077	2020-08-23 02:32:37	2020-08-23	Tomie Gaylord	tomie.gaylord@geemail.com	Las Vegas	Nevada	675944183436987	3512584f347c0dff29fa2136920a2fe3	American Express	36.3234014124244453	-115.16198763565383
47078	2020-08-23 02:40:38	2020-08-23	Dr. Hillary Bergnaum Jr.	dr.hillary.bergnaum.jr.@geemail.com	Philadelphia	Pennsylvania	589384652358296	af4b59b06f122cd71aedec146105480d	JCB 16 digit	39.9846230387181052	-75.1142320805128776
47079	2020-08-23 02:47:05	2020-08-23	Karen Hansen	karen.hansen@geemail.com	Phoenix	Arizona	3015549117873019	e9cbe72fbd4f3fd330a6989b393bb8ad	Maestro	33.6571380705971279	-112.186617963521186
47080	2020-08-23 02:47:16	2020-08-23	Iza Weber	iza.weber@warmmail.com	Boston	Massachusetts	4031426955010079	ee5b32249ad93d86027d38a25a3162dc	JCB 16 digit	42.3733004436064533	-71.0056607460088998
47081	2020-08-23 02:49:24	2020-08-23	Adell Herzog-Bashirian	adell.herzog.bashirian@geemail.com	Omaha	Nebraska	4231810514672263	78f4b8e1dcace9eae9fb16f13c4cf3af	JCB 16 digit	41.2578704425744718	-96.0003791709546022
47082	2020-08-23 02:54:13	2020-08-23	Cleon Fisher	cleon.fisher@geemail.com	Memphis	Tennessee	3158118976700697907	85797b195e2f19a0e6f8579aaea482a1	VISA 16 digit	35.0299507791243485	-89.9842771615158767
47083	2020-08-23 02:56:12	2020-08-23	Governor Cormier	governor.cormier@geemail.com	New York	New York	3528589394099112258	ce41adf8ecfefb78a7345f1e12845112	Diners Club / Carte Blanche	40.6486775845512724	-73.9813114571280721
47084	2020-08-23 02:56:52	2020-08-23	Rosetta Wuckert	rosetta.wuckert@geemail.com	Laredo	Texas	54453333095996176	72eb7003db302f2d3bec54619303f43a	VISA 13 digit	27.6384402671080096	-99.4290778384085741
47085	2020-08-23 03:04:11	2020-08-23	Maddison Cole	maddison.cole@geemail.com	San Francisco	California	3418810374421198	6a94ce73a64f5dbc8c77940577e209d0	Discover	37.7590613536988471	-122.468974908570829
47086	2020-08-23 03:27:33	2020-08-23	Tena Zboncak	tena.zboncak@geemail.com	High Point	North Carolina	4991402677814054	74a76b90f2f381f841a48f0db4f2d239	VISA 13 digit	36.0494100744929185	-79.9303133214563104
47087	2020-08-23 03:30:49	2020-08-23	Ms. Lauryn Johns DDS	ms.lauryn.johns.dds@geemail.com	Fort Wayne	Indiana	6011165089091085880	494b778a4398ff05267d89ac3d2dc526	Maestro	41.0079964684572076	-85.1087423126898699
47088	2020-08-23 03:40:06	2020-08-23	Miss Virdie Tremblay	miss.virdie.tremblay@geemail.com	Hollywood	Florida	3088331649888363920	f443887fccac2d0084b2943325ec5e28	JCB 15 digit	26.0125491495188328	-80.1058699135020333
47089	2020-08-23 03:45:08	2020-08-23	Tea Graham	tea.graham@woohoo.com	Berkeley	California	55438799537580853	aa3366498170b582cecd4536f4e4207a	Diners Club / Carte Blanche	37.8575461284628858	-122.306746638611259
47090	2020-08-23 03:48:15	2020-08-23	Mathilde Auer	mathilde.auer@warmmail.com	Glendale	Arizona	869990620858750165	23a46a382362ed15cc916ba6ca216890	JCB 16 digit	33.4759931558038986	-112.219032279474277
47091	2020-08-23 03:53:17	2020-08-23	Gia Wilkinson	gia.wilkinson@geemail.com	Houston	Texas	3158594026604255411	695b6cce5fe47e440a59919a7089f92a	VISA 16 digit	29.709650516378133	-95.4727947909399859
47092	2020-08-23 04:11:45	2020-08-23	Ulysses Robel DVM	ulysses.robel.dvm@geemail.com	Los Angeles	California	869974938926094121	418b478f801da13bd3830dfd8bcbee8c	Voyager	33.9565573116630262	-118.360493661648775
47093	2020-08-23 04:18:47	2020-08-23	Akira Reynolds	akira.reynolds@geemail.com	Santa Clara	California	3406326036894973	735729c3621427a039953e4866228272	VISA 13 digit	37.4063489276267589	-121.950859766173735
47094	2020-08-23 04:21:10	2020-08-23	Wilson Reynolds	wilson.reynolds@geemail.com	Mesa	Arizona	6011286711475275589	1e64353a6cf319206759b1c12a250992	JCB 16 digit	33.3066810111194798	-111.703778215998412
47095	2020-08-23 04:21:12	2020-08-23	Beau Haley Jr.	beau.haley.jr.@geemail.com	Clovis	California	3473158073727487	8d58a7dea090f08d4b7c28c02eae3960	Mastercard	36.9132880070589522	-119.769347854384776
47096	2020-08-23 04:22:38	2020-08-23	Conrad Muller	conrad.muller@geemail.com	Anchorage	Alaska	4165729465279	4f7b6018880145e7d6de0b5550527d66	JCB 15 digit	61.2055541868537674	-149.243699588406088
47097	2020-08-23 04:27:30	2020-08-23	Marquise Kerluke DDS	marquise.kerluke.dds@geemail.com	McKinney	Texas	3025539575193992	22f7b1c76b3f49a4a836991d97eef014	JCB 16 digit	33.2336275926921516	-96.6854725634977257
47098	2020-08-23 04:33:03	2020-08-23	Jossie Ferry	jossie.ferry@geemail.com	Austin	Texas	869972527209603658	aa22b4ee7900672f5fa353169c82cd0e	Maestro	30.382975727891175	-97.8446558368165142
47099	2020-08-23 04:37:34	2020-08-23	Mr. Denzell Blick II	mr.denzell.blick.ii@geemail.com	Lakewood	New Jersey	676196500789811	a3b9eb7997b14cc06f011f86933887c8	Voyager	39.9977359981093556	-74.248524489188199
47100	2020-08-23 04:42:52	2020-08-23	Shyann Beatty	shyann.beatty@geemail.com	San Diego	California	4435530751831	72ab1d1b0eac324af8925b769dbc694f	Diners Club / Carte Blanche	32.8821339779600521	-117.069018384758394
47101	2020-08-23 04:49:24	2020-08-23	Karin Lowe DDS	karin.lowe.dds@geemail.com	San Francisco	California	180012568880628070	1d08adbfa031d837dadffaa7d745ab52	VISA 16 digit	37.7765149850183946	-122.438289568501972
47102	2020-08-23 05:00:02	2020-08-23	Dayanara Moore	dayanara.moore@geemail.com	Oakland	California	4964845308276	4b28b626d49c1af882f69a28b4f6a8fa	VISA 13 digit	37.8127054495144321	-122.235482669262808
47103	2020-08-23 05:05:14	2020-08-23	Carrol Schiller	carrol.schiller@woohoo.com	Las Vegas	Nevada	4268806840491325	b97a17f13989b92446a511c149d1ede7	JCB 16 digit	36.2607896238200382	-115.260158886362234
47104	2020-08-23 05:11:25	2020-08-23	Joe Effertz DVM	joe.effertz.dvm@geemail.com	New York	New York	4639043462089	81a33d2a84c4275d9bc4b15f0441fed0	JCB 15 digit	40.5651681316774315	-73.9689769212052255
47105	2020-08-23 05:15:14	2020-08-23	Doshie Lesch	doshie.lesch@geemail.com	Berkeley	California	6011301339515308599	5eca582c63bd3574995702b446e7c921	VISA 13 digit	37.8814585933011827	-122.277279520084122
47106	2020-08-23 05:18:59	2020-08-23	Cale Schuppe	cale.schuppe@geemail.com	San Francisco	California	4642908000779288	0ef96b6efbde0117776d169c9816d7ca	Voyager	37.8079675549784611	-122.405000396232836
47107	2020-08-23 05:20:28	2020-08-23	Maddux Wuckert	maddux.wuckert@woohoo.com	Portland	Oregon	3096926440462151209	c8d6dbea0250f51f3c2b19bf1eca1199	Voyager	45.6010955287031834	-122.675576915033162
47108	2020-08-23 05:34:14	2020-08-23	Billie Kassulke-Hessel	billie.kassulke.hessel@geemail.com	Dallas	Texas	675930487623271	39566616218b9888cfc730a54d360909	Maestro	32.7540172472868107	-96.8341319620571994
47109	2020-08-23 05:34:24	2020-08-23	Nikolas Olson	nikolas.olson@geemail.com	Long Beach	California	4448702596876	6a10f9eccdf867b2d7f8d37e8e5700c9	Discover	33.8439893267404273	-118.179544057480243
47110	2020-08-23 05:56:02	2020-08-23	Angelita McKenzie	angelita.mckenzie@geemail.com	New York	New York	3112124744571141286	c2701071eec2fa3dace2320f9a1b1068	VISA 16 digit	40.6981172519493839	-73.9261795245006681
47111	2020-08-23 06:14:29	2020-08-23	Delinda Dach	delinda.dach@geemail.com	Greeley	Colorado	3716537116892301	9c77bebd1089568c6ac847363712dc25	VISA 13 digit	40.3194010897140984	-104.860469387502221
47112	2020-08-23 06:15:26	2020-08-23	Cathrine Hammes	cathrine.hammes@warmmail.com	San Francisco	California	3036685580115337	f9f6c7ced7077d5cb6147614aad43804	American Express	37.8007097585071463	-122.40168110336603
47113	2020-08-23 06:18:08	2020-08-23	Mathilde Heaney-Casper	mathilde.heaney.casper@geemail.com	Houston	Texas	3158669997508782991	b95548e0058837afde53527deadf6ad0	VISA 16 digit	29.805194494229184	-95.3117738915622255
47114	2020-08-23 06:35:11	2020-08-23	Broderick Schaefer	broderick.schaefer@geemail.com	Phoenix	Arizona	4840053085931544	49d0a4998e76c73bded9fcc091deae4a	VISA 16 digit	33.6391034060090774	-112.14565422799663
47115	2020-08-23 06:48:19	2020-08-23	Ms. Carleigh Huels	ms.carleigh.huels@woohoo.com	Orange	California	630410094792859	4246e5a2d83bbb6e9f5cc9317f8e7e88	Discover	33.7738225583806653	-117.768044755897677
47116	2020-08-23 06:50:02	2020-08-23	Latrice Kshlerin	latrice.kshlerin@woohoo.com	Chicago	Illinois	55322416600635964	316b35e54bb38c3f93dc496b79dc101f	VISA 16 digit	41.8541932329837252	-87.7628315466020155
47117	2020-08-23 07:03:59	2020-08-23	Jonnie Osinski	jonnie.osinski@geemail.com	San Diego	California	3158394313521814591	6273314492b26985970de6c65d979451	VISA 16 digit	32.7593076180268099	-117.169878044947993
47118	2020-08-23 07:05:50	2020-08-23	Pamella Ratke	pamella.ratke@geemail.com	Milwaukee	Wisconsin	3049862885025886	3d33741713618bf733f6cdfcf9b85afc	Mastercard	43.1114998130213465	-88.0379370032910344
47119	2020-08-23 07:27:37	2020-08-23	Lani Gaylord	lani.gaylord@warmmail.com	Albuquerque	New Mexico	676360235529363	57db66ec74591806c0d7ad91d99c664f	Maestro	35.2051358082465882	-106.732093903895105
47120	2020-08-23 07:30:33	2020-08-23	Jamil Maggio-Schinner	jamil.maggio.schinner@geemail.com	Rochester	New York	4914662669218549	306b1638d739137c3c5b7bea62c9e4e3	JCB 16 digit	43.0811457947805536	-77.7011121621128211
47121	2020-08-23 07:31:06	2020-08-23	Graciela Bergstrom	graciela.bergstrom@warmmail.com	Pomona	California	869942472089555776	bff0155f71b4511a411790ffad9ef9fd	Diners Club / Carte Blanche	34.155205327089881	-117.689535643995185
47122	2020-08-23 07:40:22	2020-08-23	Kenan Dach IV	kenan.dach.iv@geemail.com	Renton	Washington	4978546992385492	18f66f921c7fd4d193d5fd1b6e96100b	Maestro	47.4974477642741064	-122.097372835183506
47123	2020-08-23 08:03:26	2020-08-23	Marcy Jakubowski	marcy.jakubowski@woohoo.com	Dallas	Texas	3425320515680505	c9d7142e28d4b7ce06e3e09dd6a69e46	Discover	32.6933566597096643	-96.8069837957117585
47124	2020-08-23 08:04:50	2020-08-23	Dr. Refugio Kertzmann DDS	dr.refugio.kertzmann.dds@geemail.com	Jacksonville	Florida	6011774108018716626	6f59df78a32502e5a25c5075e4fa4ed2	JCB 16 digit	30.3607585246261209	-81.7264875123821213
47125	2020-08-23 08:05:20	2020-08-23	Miss Mandy Farrell MD	miss.mandy.farrell.md@warmmail.com	Washington	District of Columbia	3337471337149297174	3cf4c8412f5f85541184f7edbabd6f44	Mastercard	38.9453569860927757	-77.0661355989266212
47126	2020-08-23 08:05:58	2020-08-23	Miss Darline Braun	miss.darline.braun@geemail.com	Costa Mesa	California	4619341449504761	8c885cf62a57f880eb3149f71fe738ed	Discover	33.7438912027530407	-117.946625195848938
47127	2020-08-23 08:08:32	2020-08-23	Jacqueline Upton	jacqueline.upton@woohoo.com	Philadelphia	Pennsylvania	6011527337967070533	2b0c906c43e405e6d80191f778a75c35	JCB 16 digit	39.9672563334885993	-75.0795622129358406
47128	2020-08-23 08:13:25	2020-08-23	Luigi Schamberger	luigi.schamberger@geemail.com	Sacramento	California	4285602254428732	bc395a7ba9e1aaf3a0496b3ac57baf21	American Express	38.5736759568829086	-121.421773364140094
47129	2020-08-23 08:19:34	2020-08-23	Maleah Altenwerth	maleah.altenwerth@geemail.com	Dallas	Texas	4521355467576276	7e7ef8c2ade6fca1de39cfbcf9cb5037	Discover	32.8217726506099154	-96.8652197575624996
47130	2020-08-23 08:21:55	2020-08-23	Jeptha Denesik	jeptha.denesik@woohoo.com	San Francisco	California	869902847431754995	d5252dc87fe6a7bf0412671cb8b9f592	American Express	37.7462521749868714	-122.432261310413182
47131	2020-08-23 08:22:17	2020-08-23	Honora Weimann	honora.weimann@warmmail.com	Clarksville	Tennessee	54051575026185800	07e3f0ed41c18571e5e3f43b187f8bb2	American Express	36.5355855507437184	-87.3335963536936788
47132	2020-08-23 08:25:22	2020-08-23	Sedrick Altenwerth	sedrick.altenwerth@geemail.com	Houston	Texas	3003429200630307	1401ea19bff3ea4b9be3e06b210d69c2	Discover	29.8023943045720472	-95.4906658791486223
47133	2020-08-23 08:34:29	2020-08-23	Mr. Dallas Fahey V	mr.dallas.fahey.v@geemail.com	Chicago	Illinois	4239719455282770	11903359e0a17768e2ba984f19684b1d	Mastercard	41.8088391669396344	-87.7627487755410272
47134	2020-08-23 08:40:25	2020-08-23	Alvis Barrows	alvis.barrows@geemail.com	Huntington Beach	California	3528966802545350424	3dc7a0f019b59282da63fe1d557886af	Discover	33.5913109678350423	-118.076839822543036
47135	2020-08-23 08:45:20	2020-08-23	Mr. Toma Turner III	mr.toma.turner.iii@geemail.com	Centennial	Colorado	869906618460895504	6727f7efc4b24b437e9066a6296774c6	Mastercard	39.5817739652976428	-104.916930131603408
47136	2020-08-23 08:45:30	2020-08-23	Thurman Wilderman	thurman.wilderman@geemail.com	San Francisco	California	3088684503276352412	77170a89fbae71fa4906bf9fcaac4785	Maestro	37.7922278083803747	-122.451954754427334
47137	2020-08-23 09:01:32	2020-08-23	Mrs. Alyvia Lemke	mrs.alyvia.lemke@geemail.com	Cleveland	Ohio	4772406726509	673c95b10cc09f88c0c105c6d04e09fb	Diners Club / Carte Blanche	41.4647849614117234	-81.6640708499360812
47138	2020-08-23 09:06:03	2020-08-23	Ms. Gussie Cremin DVM	ms.gussie.cremin.dvm@warmmail.com	Fort Worth	Texas	3096824367571645156	c1a6b33f04e242abfb0b2340681fb7d3	Diners Club / Carte Blanche	32.8244850519169162	-97.368364304658769
47139	2020-08-23 09:09:47	2020-08-23	Casen Mosciski	casen.mosciski@woohoo.com	Greensboro	North Carolina	4860208419594278	9322feb0e212cb3bc5d12aee451885a7	VISA 16 digit	36.1189106651697358	-79.8887378375027311
47140	2020-08-23 09:14:30	2020-08-23	Marge Klein-Becker	marge.klein.becker@geemail.com	Columbus	Ohio	210009975841160215	86ed57d0b26bf4aedfbfee4d9026e77a	Voyager	40.0754153974398974	-82.9283468252748293
47141	2020-08-23 09:19:12	2020-08-23	Denisha Bauch	denisha.bauch@geemail.com	Indianapolis	Indiana	210042579382236290	9cc7098800da3f851eef31fa97cb0537	JCB 16 digit	39.7828662201303942	-86.1006840754501468
47142	2020-08-23 09:26:15	2020-08-23	Mr. Mohamed Schaefer	mr.mohamed.schaefer@geemail.com	Albuquerque	New Mexico	3337250205930344033	98e3cb7cbfe23e5995edb3309b43e436	JCB 15 digit	35.1683065899781937	-106.641865866824617
47143	2020-08-23 09:29:08	2020-08-23	Christy Bode	christy.bode@woohoo.com	Garden Grove	California	51206176349096735	16c309b60f979d250dc7371ba5dc8432	JCB 16 digit	33.8621321617916209	-117.986503338908776
47144	2020-08-23 09:30:20	2020-08-23	Turner Pfannerstill	turner.pfannerstill@geemail.com	Berkeley	California	4837654655740	63044e8139c37d2b5ee681eca22f450f	Discover	37.8900327123288463	-122.276806858379587
47145	2020-08-23 09:30:20	2020-08-23	Madalynn McCullough	madalynn.mccullough@geemail.com	Antioch	California	4522287289468821	599629b1b89ac3c7e20a404bb0859f99	VISA 13 digit	38.0317212134398517	-121.846730947791414
47146	2020-08-23 09:42:37	2020-08-23	Juluis Carroll	juluis.carroll@woohoo.com	Tallahassee	Florida	869906518059372990	9ea419ecaebb9bf50ca083f630c9625d	Mastercard	30.4256669742077612	-84.2153957085698863
47147	2020-08-23 09:50:26	2020-08-23	Dr. Karim Kuhlman	dr.karim.kuhlman@warmmail.com	Jacksonville	Florida	180004572352857126	718f3027bec763a58a3539737b081108	JCB 15 digit	30.3513625756423906	-81.5782701060254141
47148	2020-08-23 09:50:26	2020-08-23	Roselyn Eichmann DDS	roselyn.eichmann.dds@woohoo.com	Los Angeles	California	3470351646296808	863c25844ccb9e7e122925bfc454ce39	JCB 16 digit	33.9661264520469999	-118.403602308220414
47149	2020-08-23 09:54:30	2020-08-23	Dr. Shea Rosenbaum MD	dr.shea.rosenbaum.md@warmmail.com	Louisville	Kentucky	4018197859508685	96152373b7673b5fd6daf808f4d7d989	VISA 16 digit	38.1274104422327085	-85.5981515167817548
47150	2020-08-23 09:59:17	2020-08-23	Jensen Bode	jensen.bode@geemail.com	San Francisco	California	869940061209260284	d68c5aa050c82b2997b1c022f008d551	VISA 16 digit	37.7761792332539272	-122.406242840676043
47151	2020-08-23 10:01:19	2020-08-23	Cassidy Wuckert	cassidy.wuckert@geemail.com	Saint Paul	Minnesota	54188264058174356	bda57b1ee133f6b0a5332a4081111410	JCB 15 digit	44.9136188614588221	-93.1384114104121892
47152	2020-08-23 10:03:42	2020-08-23	Rico Olson I	rico.olson.i@geemail.com	Providence	Rhode Island	3112150938534159396	47d0a3080010badb3ab6f45f85df0abc	Discover	41.728999920873342	-71.4683598488021659
47153	2020-08-23 10:03:54	2020-08-23	Jillian Walsh-Streich	jillian.walsh.streich@geemail.com	Los Angeles	California	869905637647721665	c7c2c1fea2afd5ea832b0a1d092aa90c	Voyager	34.0318406605958899	-118.34827864845208
47154	2020-08-23 10:06:13	2020-08-23	Kali Bosco	kali.bosco@geemail.com	New York	New York	3786592022464617	5a5c7cc2386ae4bf154de84b2903da72	Mastercard	40.6277417004331909	-73.9903112376935752
47155	2020-08-23 10:09:16	2020-08-23	Jaylin Adams	jaylin.adams@woohoo.com	San Jose	California	4959799774556169	86c8c4b8bb64fa9dd3c26f23c7da193c	VISA 16 digit	37.2924939940970432	-121.72099358725697
47156	2020-08-23 10:10:14	2020-08-23	Anton Gorczany	anton.gorczany@woohoo.com	Visalia	California	3337071998490293015	d28bbd3c49b11333b0dc2b4abb415656	VISA 13 digit	36.281790243969489	-119.284431668988987
47157	2020-08-23 10:14:19	2020-08-23	Florie Gutmann DDS	florie.gutmann.dds@geemail.com	Winston–Salem	North Carolina	4860123224252	56c371a695b560a60d31b59c22218af4	JCB 16 digit	36.0063729987245011	-80.2206326039172666
47158	2020-08-23 10:20:59	2020-08-23	Elle Prosacco	elle.prosacco@warmmail.com	Denton	Texas	4980679478340	bf964dfcc95890ff12a9f49edd1c8fa1	Voyager	33.1750913367405502	-97.1980363458987426
47159	2020-08-23 10:23:39	2020-08-23	Maudie Hyatt	maudie.hyatt@woohoo.com	Birmingham	Alabama	4375545075182	c7548bb4011aac46bacfa0f1db2fab61	Discover	33.4623410098046037	-86.7485351228863095
47160	2020-08-23 10:31:19	2020-08-23	Carissa Smith	carissa.smith@geemail.com	Tampa	Florida	869935888528849042	38459fb3dc0153f37141a04c766b755a	VISA 16 digit	27.9293981056775884	-82.4335419212680307
47161	2020-08-23 10:34:35	2020-08-23	Estefany Oberbrunner	estefany.oberbrunner@geemail.com	Columbus	Ohio	502082965943291	f96c860d883ddd425ed3abd7df6f1dd0	JCB 16 digit	39.8901440030939867	-82.9748195832364388
47162	2020-08-23 10:36:46	2020-08-23	Ollie VonRueden	ollie.vonrueden@warmmail.com	Jacksonville	Florida	3088721095827932565	c798781bd6a3ae872d572df6d2994790	JCB 16 digit	30.3103143311157837	-81.684076502414797
47163	2020-08-23 10:39:27	2020-08-23	Malachi Hilpert IV	malachi.hilpert.iv@warmmail.com	Nashville	Tennessee	3158489276166083176	80bafdc4782f8fe8894588eef6f8047d	Discover	36.1707976397715498	-86.7123137998767106
47164	2020-08-23 10:40:14	2020-08-23	Nia O'Connell	nia.o'connell@geemail.com	Aurora	Illinois	4962181357681844	94726e24a910c2d00dfb0c91d3626b58	JCB 16 digit	41.8384815001618122	-88.3022599626727356
47165	2020-08-23 11:00:29	2020-08-23	Jeb Denesik-Hyatt	jeb.denesik.hyatt@geemail.com	New York	New York	3466301391362483	4e7e28bb31e733b59e078dce85a056c4	Diners Club / Carte Blanche	40.6545967284347824	-74.0363758777163952
47166	2020-08-23 11:25:32	2020-08-23	Karl Rath	karl.rath@geemail.com	Oakland	California	3088614747752855787	04a23566bb6e580f4075873cfbae43da	JCB 16 digit	37.8264898058164221	-122.290256105364776
47167	2020-08-23 11:25:54	2020-08-23	Mr. Frazier McLaughlin II	mr.frazier.mclaughlin.ii@geemail.com	Jacksonville	Florida	4561819267396491	cf5ed289999e390de89570630f6b0da3	VISA 16 digit	30.3272296450153007	-81.5980094357472012
47168	2020-08-23 11:29:12	2020-08-23	Kristian Nicolas-Hoeger	kristian.nicolas.hoeger@geemail.com	Columbus	Georgia	869955527508748304	6a47ccf5efd23ea961a4ce2d5769181c	VISA 16 digit	32.5776678248353306	-84.8462470642920579
47169	2020-08-23 11:31:45	2020-08-23	Kayden Swaniawski	kayden.swaniawski@geemail.com	Los Angeles	California	3528940734932913871	cbffddb3e3f67af6467880a196714a8c	JCB 16 digit	34.0885158108413222	-118.327672953204427
47170	2020-08-23 11:33:03	2020-08-23	Evalena Thiel	evalena.thiel@geemail.com	Charlotte	North Carolina	4134697149549067	093ef4b0fd8b9cdd9f9b66c91e26e0c2	JCB 15 digit	35.2835441624533388	-80.7740643369909463
47171	2020-08-23 11:36:04	2020-08-23	Mart Rosenbaum	mart.rosenbaum@geemail.com	New York	New York	3401627060284956	03baa08c613b7be444d73a9f06d7d7f3	Discover	40.7162278042398356	-73.898796074314788
47172	2020-08-23 11:43:47	2020-08-23	Dr. Jules Orn	dr.jules.orn@geemail.com	Denton	Texas	3798764120617687	e2b7a299817ae8b64864aee770fe043d	VISA 16 digit	33.1249070252556379	-97.2343473956115645
47173	2020-08-23 11:45:36	2020-08-23	Damon White	damon.white@geemail.com	Tulsa	Oklahoma	3002533180144279	56c9c37508343d8e1568116cbe64292d	Discover	36.0516953380681571	-95.9358979640018106
47174	2020-08-23 11:48:06	2020-08-23	Hobson Huel-Smitham	hobson.huel.smitham@warmmail.com	St. Louis	Missouri	3096772486106379081	091fceb2423576eb53988218e781557f	VISA 16 digit	38.6472372297819717	-90.2419312607035096
47175	2020-08-23 11:51:20	2020-08-23	Laken Hegmann	laken.hegmann@warmmail.com	Chicago	Illinois	869947819834761015	8c1b8465f12da54a6be4dcb3fa3c5c3d	Diners Club / Carte Blanche	41.7930412676952798	-87.605670340455319
47176	2020-08-23 11:52:31	2020-08-23	Georgine Corkery	georgine.corkery@geemail.com	Los Angeles	California	210040080258926546	c05d389012b75fb126cc2fc11df213d8	Voyager	34.0315847211848919	-118.440550959388901
47177	2020-08-23 11:58:15	2020-08-23	Deetta Schuster	deetta.schuster@geemail.com	Denver	Colorado	6011573847809641070	0ac997c3717d7221f4a47d255a0ed5ac	Mastercard	39.7581542525958227	-104.926468738705296
47178	2020-08-23 12:08:09	2020-08-23	Isom Mueller	isom.mueller@geemail.com	San Francisco	California	3112570849689623114	567083464ef482be3033f531d0948f49	VISA 16 digit	37.7538678073159772	-122.418858073564778
47179	2020-08-23 12:20:31	2020-08-23	Elizabet Upton	elizabet.upton@geemail.com	Philadelphia	Pennsylvania	3158745321943188755	bf587f7c1723b2d9d52609131a28ee3c	JCB 16 digit	40.0361529625911245	-75.2057165650550274
47180	2020-08-23 12:25:05	2020-08-23	Thos Halvorson-Emmerich	thos.halvorson.emmerich@geemail.com	Scottsdale	Arizona	3088591912126339036	cead26a6cd8a52c7e6387cd0c383e192	JCB 16 digit	33.778041479422896	-111.795496008029573
47181	2020-08-23 12:31:18	2020-08-23	Kingston Willms	kingston.willms@geemail.com	Hollywood	Florida	210073859283925304	c98e357af28a3da2a2a670f0d4bd9e91	Discover	26.0123420800026501	-80.0753959228102019
47182	2020-08-23 12:33:47	2020-08-23	Yahaira Hackett	yahaira.hackett@geemail.com	Baltimore	Maryland	3773136732067834	1897b903268b90b49d7772ee6c9165e5	VISA 16 digit	39.2107751164585352	-76.5163292597997895
47183	2020-08-23 12:36:53	2020-08-23	Lillianna Schumm	lillianna.schumm@geemail.com	Boston	Massachusetts	3496014816149849	a62b96a86e526ed7ad3f7164d3be5efc	Discover	42.4041584401093417	-71.1097558941643655
47184	2020-08-23 12:52:51	2020-08-23	Ms. Chanie Boyer PhD	ms.chanie.boyer.phd@geemail.com	Davie	Florida	3088021438983887156	4d213bb930602f06e15b0b2916b37b93	VISA 13 digit	26.0647442660558966	-80.2647025017440257
47185	2020-08-23 13:19:58	2020-08-23	Mrs. Florence West DVM	mrs.florence.west.dvm@warmmail.com	Minneapolis	Minnesota	180016363652524400	7d7ba331cc36cd1bc364d1f18671b622	Diners Club / Carte Blanche	44.9346075727224346	-93.3463278345104328
47186	2020-08-23 13:26:39	2020-08-23	Beau Kerluke Sr.	beau.kerluke.sr.@woohoo.com	San Francisco	California	210023221857304021	300ee64872b9daf1dc826a03bbfb54e6	JCB 15 digit	37.7406201750335981	-122.422935929471635
47187	2020-08-23 13:28:24	2020-08-23	Herb Waters	herb.waters@geemail.com	Tampa	Florida	869961672805772896	cfd5ddba8677b3f8adbdd5896d5367c1	Discover	27.9799657679278404	-82.4970376948572692
47188	2020-08-23 13:31:49	2020-08-23	Miss Mabelle Lind	miss.mabelle.lind@warmmail.com	Rancho Cucamonga	California	6011808032106149500	9a83530d2913dc447c33b27e3ca51b1a	Maestro	34.0903278304722193	-117.511414298322791
47189	2020-08-23 13:38:01	2020-08-23	Bobbye Okuneva	bobbye.okuneva@geemail.com	Oklahoma City	Oklahoma	4816655214625704	39909481446c6921306e3f0a5aa65b19	American Express	35.5376940829124308	-97.534944160598144
47190	2020-08-23 13:40:50	2020-08-23	Mr. Caswell Anderson DVM	mr.caswell.anderson.dvm@geemail.com	Phoenix	Arizona	3055640084010394	0761c1fd54a09751884c41b7ed7da816	JCB 16 digit	33.5976107689019301	-112.119350447405509
47191	2020-08-23 13:41:01	2020-08-23	Maureen Metz DVM	maureen.metz.dvm@geemail.com	San Francisco	California	52657094514698017	5c12755c77d9bf3574dcabaa2c5657ec	JCB 15 digit	37.7602619391506877	-122.46267795927568
47192	2020-08-23 13:43:24	2020-08-23	Miss Delila Flatley DVM	miss.delila.flatley.dvm@geemail.com	Glendale	Arizona	3112392530361522065	988d1c0aaa05889811c797eb8786f049	American Express	33.5619646544329768	-112.09378888907618
47193	2020-08-23 13:45:39	2020-08-23	Maureen Dickens	maureen.dickens@geemail.com	Columbus	Ohio	3781350610855273	e9d5ac99a3899b529f48bf9e6302c406	JCB 16 digit	40.0109965938188097	-83.0303894490703982
47194	2020-08-23 13:54:23	2020-08-23	Creed Rogahn Sr.	creed.rogahn.sr.@geemail.com	New Haven	Connecticut	3158322753494745453	1ba0c7994c48cde5d49761b36c9f38da	JCB 16 digit	41.368738713813201	-72.8541355287190555
47195	2020-08-23 13:55:14	2020-08-23	Branch Crist	branch.crist@geemail.com	San Diego	California	869929128364489134	d1f7709b460650f8387dca19638adc04	Mastercard	32.840606250061839	-117.048545415177941
47196	2020-08-23 13:55:51	2020-08-23	Gayle Keebler-Greenfelder	gayle.keebler.greenfelder@woohoo.com	St. Petersburg	Florida	52961348153602933	52dde65709352e7d4b46fe399d9c6f78	VISA 16 digit	27.817124835623428	-82.71785126630067
47197	2020-08-23 14:00:50	2020-08-23	Amalie Collier	amalie.collier@geemail.com	Charlotte	North Carolina	060429475152541	2129c4a195db35201fc031bf16f94ee7	Diners Club / Carte Blanche	35.1948254490058829	-80.7739202154744476
47198	2020-08-23 14:03:50	2020-08-23	Sigrid Feil	sigrid.feil@warmmail.com	San Jose	California	3112827977221988702	5ac691e4f3b4c5c9970f6d54570ba030	VISA 16 digit	37.2525291263412726	-121.90176684914492
47199	2020-08-23 14:03:52	2020-08-23	Maryam Hudson DDS	maryam.hudson.dds@geemail.com	Lexington	Kentucky	3441276095080021	b5f113c4aee0087b183b1065166d8bcd	Maestro	37.9981257252272258	-84.5324953889839321
47200	2020-08-23 14:26:31	2020-08-23	Ah Schmidt	ah.schmidt@geemail.com	Indianapolis	Indiana	6011581317363397477	578dc1f03a07bd27dec5d8c6f7ccb735	Discover	39.7593757771894332	-86.1734110374204789
47201	2020-08-23 14:30:14	2020-08-23	Abb Yundt II	abb.yundt.ii@warmmail.com	West Covina	California	4558397902406376	5ac4e7d8250b7f966f4d60d7196dc459	Maestro	33.9877805983290102	-117.992996510590984
47202	2020-08-23 14:31:50	2020-08-23	Dr. Dillard O'Conner V	dr.dillard.o'conner.v@geemail.com	Gilbert	Arizona	4761979960550402	92aca3715c0cacd0e0ef961cebc01e94	VISA 16 digit	33.3336811100479196	-111.804049882492421
47203	2020-08-23 14:32:16	2020-08-23	Ewing Stoltenberg I	ewing.stoltenberg.i@warmmail.com	New York	New York	676268912146419	19e62055b53784c39817f0030180d2e1	VISA 13 digit	40.7350890847146516	-73.9877884215105297
47204	2020-08-23 14:37:58	2020-08-23	Mr. Harris Nitzsche	mr.harris.nitzsche@woohoo.com	San Francisco	California	675972235951844	027c77a179470bbc9d99a94fdaae6a43	American Express	37.7629961172250646	-122.484991507914799
47205	2020-08-23 14:42:11	2020-08-23	Sheron Batz	sheron.batz@woohoo.com	Charlotte	North Carolina	180007378335116672	76ad8c084c0a1a435af1ab2a94fa983f	Discover	35.1253872843712571	-80.7658944469820739
47206	2020-08-23 14:51:31	2020-08-23	Addie Rodriguez	addie.rodriguez@woohoo.com	Phoenix	Arizona	4866026257956373	a116a65f02d69136d929cc966b34a8db	VISA 16 digit	33.5899439655642951	-112.161308110032607
47207	2020-08-23 14:54:32	2020-08-23	Sibyl Mante	sibyl.mante@geemail.com	Yonkers	New York	6011541920934578852	6f9d0cbfeb964a417fbf35ea51c2fac7	Mastercard	40.9239715197324756	-73.8504109258648072
47208	2020-08-23 14:59:02	2020-08-23	Shaylee Turcotte	shaylee.turcotte@geemail.com	Kansas City	Missouri	6011132771628418011	e169a8a8ab25221f5031c669823141db	Mastercard	39.1808891482021693	-94.4685742348656134
47209	2020-08-23 15:00:37	2020-08-23	Dr. Osie Harris III	dr.osie.harris.iii@woohoo.com	Fullerton	California	3037392067854194	6c2d69ad0850698eea8384e4e8dff46c	VISA 13 digit	33.8826877971801892	-117.964881561670452
47210	2020-08-23 15:20:28	2020-08-23	Mrs. Angelique Shanahan	mrs.angelique.shanahan@woohoo.com	Chicago	Illinois	3000105631111801	1dd1f153d4e46f8934bbe5940d44b5b8	Discover	41.8333283673342322	-87.7774125861033809
47211	2020-08-23 15:23:36	2020-08-23	Karim Mayert Jr.	karim.mayert.jr.@woohoo.com	Berkeley	California	3006680376484476	b93ea869f5a52b8bf665c33763f25acd	Mastercard	37.8341289264951968	-122.272906045313263
47212	2020-08-23 15:25:02	2020-08-23	Esco Stamm	esco.stamm@warmmail.com	Tulsa	Oklahoma	3528645232921404653	6470e2f299f064bd62b5419ee2342e8f	Discover	36.1506342647965937	-95.8936810089230534
47213	2020-08-23 15:31:08	2020-08-23	Violet Moore	violet.moore@geemail.com	Colorado Springs	Colorado	3158397962014135240	33a41764a52105d5a1bd0d455a6860cc	JCB 15 digit	38.7834897473037259	-104.727590791803593
47214	2020-08-23 15:41:08	2020-08-23	Theodis Howell	theodis.howell@geemail.com	New York	New York	561284504874474	4cf41fb193dde459ff169cbad495d56a	JCB 16 digit	40.6235355968344933	-73.9791399169143205
47215	2020-08-23 15:42:13	2020-08-23	Dr. Drury Konopelski	dr.drury.konopelski@geemail.com	San Francisco	California	3776100542469611	cf4accb7c7a08e208a2da30966d18750	JCB 15 digit	37.7542400100303936	-122.447655064036908
47216	2020-08-23 15:54:21	2020-08-23	Mr. Darian Friesen	mr.darian.friesen@woohoo.com	Los Angeles	California	3005053799518430	084cee42fc7f93b6c6430379c5c27e35	VISA 13 digit	33.9204938562918414	-118.351302275805921
47217	2020-08-23 15:59:38	2020-08-23	Miss Lacey Gulgowski MD	miss.lacey.gulgowski.md@geemail.com	New York	New York	6011022268737326204	42948a21511859b79b3b6b7058b4a682	American Express	40.5994735724050528	-73.9246575125388716
47218	2020-08-23 16:00:54	2020-08-23	Mr. Erling Wunsch	mr.erling.wunsch@woohoo.com	Santa Clara	California	3730797260858589	fe8e1a19d071a9a06d7b0de3ca538386	VISA 16 digit	37.3800899701010465	-121.900920939864221
47219	2020-08-23 16:03:32	2020-08-23	Kinsey Huels DDS	kinsey.huels.dds@geemail.com	Austin	Texas	3037115691946874	57e906d92877829fa9e0372338f8c739	Voyager	30.211705897481739	-97.6607883804716153
47220	2020-08-23 16:03:40	2020-08-23	Mitch Nader	mitch.nader@warmmail.com	Lakewood	New Jersey	3096307097667750448	8a9b0a2b23ac9871d6ec54dd86f8f864	American Express	40.0654689483627706	-74.182264092033364
47221	2020-08-23 16:14:03	2020-08-23	Rosann Osinski	rosann.osinski@woohoo.com	Charleston	South Carolina	501849751906030	22d783c5371da05c0587c467cf84be36	JCB 16 digit	32.8888441018756481	-79.8591789290923657
47222	2020-08-23 16:15:26	2020-08-23	Bobby Schinner	bobby.schinner@geemail.com	New York	New York	3528401343045520029	e19f6a57d17c62824779d08657a8e975	Diners Club / Carte Blanche	40.6961465130317919	-73.9847094617214083
47223	2020-08-23 16:22:19	2020-08-23	Miss Jerusha Roob MD	miss.jerusha.roob.md@geemail.com	Houston	Texas	52319009546856409	cb0aade640c873d55ae940dce43421ca	Maestro	29.7722417863164104	-95.3665892979145013
47224	2020-08-23 16:31:00	2020-08-23	Candi Mayer DDS	candi.mayer.dds@geemail.com	San Francisco	California	4768209490857884	372a9a02f6f95415fa38d08085ed8cc6	VISA 13 digit	37.7870859972549482	-122.467866708917867
47225	2020-08-23 16:35:10	2020-08-23	Greggory Paucek-Roob	greggory.paucek.roob@geemail.com	Berkeley	California	4674448923576652	2f6c4fd7b84fa573d34d4cefb5617058	Mastercard	37.901787220614338	-122.292194349721285
47226	2020-08-23 16:44:24	2020-08-23	Bee Gusikowski	bee.gusikowski@geemail.com	San Francisco	California	4089308656798999	453935bb72621a6baf09c5a163e650ca	Voyager	37.7457264914466464	-122.449246708448314
47227	2020-08-23 16:48:19	2020-08-23	Marcelo Wilkinson	marcelo.wilkinson@warmmail.com	Las Cruces	New Mexico	6011207010272790759	1b20cd60239c202e941da7bacbb52bfc	JCB 16 digit	32.36117611974813	-106.88301252272241
47228	2020-08-23 16:59:07	2020-08-23	Dr. Ernesto Batz	dr.ernesto.batz@warmmail.com	Lafayette	Louisiana	503866813270270	599cf9701fbebec56bccc85e0be5f1b0	Mastercard	30.2953569389857336	-92.0189837812762619
47229	2020-08-23 17:21:33	2020-08-23	Blanch Aufderhar	blanch.aufderhar@geemail.com	Lincoln	Nebraska	51362938894019002	dc2a6457fcd2784c16dede4bf134ffb8	Discover	40.713581859927622	-96.6010345924805875
47230	2020-08-23 17:28:23	2020-08-23	Luvenia Johnston	luvenia.johnston@geemail.com	Philadelphia	Pennsylvania	4637557459163432	cc19ffbff1ea845b23af3b31f1d21177	Voyager	40.0849522491876016	-75.0703321061927937
47231	2020-08-23 17:28:49	2020-08-23	Tatyana Becker-Walsh	tatyana.becker.walsh@warmmail.com	Colorado Springs	Colorado	3112154827051925873	8ee4d257b63a9156f3e4b522c767b90e	Mastercard	38.8307219431784034	-104.834306071062386
47232	2020-08-23 17:30:44	2020-08-23	Ilah Smitham DVM	ilah.smitham.dvm@geemail.com	Seattle	Washington	3055790420960479	d90f0be0f7d6f00af6f4edc0d98580f2	VISA 16 digit	47.5480163354817762	-122.252351731007536
47233	2020-08-23 17:36:14	2020-08-23	Kenya Altenwerth	kenya.altenwerth@geemail.com	Tucson	Arizona	3018069780598956	20270099ebd143a4c5f332ee23001ac1	JCB 16 digit	32.0969387679401805	-110.852243900461488
47234	2020-08-23 17:45:11	2020-08-23	Katia Marquardt	katia.marquardt@geemail.com	Brownsville	Texas	4285688209987	e8967cc0e951f69c0328012d40243515	Discover	25.9152147123668328	-97.4044544669520036
47235	2020-08-23 17:52:39	2020-08-23	Ricky Durgan-Bogisich	ricky.durgan.bogisich@geemail.com	Oakland	California	869984040258698492	8931278b40322a29cd95b04f8de057ff	American Express	37.7825165234340403	-122.256748473054586
47236	2020-08-23 17:55:23	2020-08-23	Miss Stella Flatley DDS	miss.stella.flatley.dds@geemail.com	Los Angeles	California	4152698987642235	d3063356da1986f167f0604aef9076a0	Maestro	33.9583446004293847	-118.503741496660922
47237	2020-08-23 18:01:10	2020-08-23	Riya Robel DDS	riya.robel.dds@geemail.com	Renton	Washington	3096553204480240000	b9fb923a383b8ba22faf750f7788c7df	JCB 16 digit	47.5697205510981433	-122.281012753870328
47238	2020-08-23 18:01:12	2020-08-23	Dr. Demarco Hoppe I	dr.demarco.hoppe.i@geemail.com	Oakland	California	4041743655599310	b11d164bde750bba1795505c15f10b3a	JCB 16 digit	37.7908709338379225	-122.268002550998347
47239	2020-08-23 18:07:02	2020-08-23	Helen Torphy DVM	helen.torphy.dvm@geemail.com	Escondido	California	3043680819656501	bc767abd0f4cf715c0545e4b7f30fdab	JCB 16 digit	33.0715575593285251	-117.038831488020719
47240	2020-08-23 18:07:30	2020-08-23	Gracie Osinski	gracie.osinski@geemail.com	Houston	Texas	180081315665618256	d7e3194a76124d1625ae0e924a2d6cf7	Voyager	29.7093393141947679	-95.3136604298386771
47241	2020-08-23 18:11:04	2020-08-23	Wally Jacobs	wally.jacobs@geemail.com	Aurora	Illinois	3337752257227272032	7089cd9a5f763cc59ff1686a458b7b7a	VISA 16 digit	41.8206773282252229	-88.2602425808016164
47242	2020-08-23 18:11:32	2020-08-23	John Harber	john.harber@geemail.com	Indianapolis	Indiana	210004754848324420	5ee5b10d38512a6f9f25d4ccc61340bc	Discover	39.7163608106326294	-86.2040696834880862
47243	2020-08-23 18:12:46	2020-08-23	Nunzio Erdman	nunzio.erdman@woohoo.com	Providence	Rhode Island	869912747315812166	c852face4c24467f5781dfb9bdf925a3	JCB 16 digit	41.7440594942163656	-71.3414589144207554
47244	2020-08-23 18:12:57	2020-08-23	Mr. Dereck Ernser V	mr.dereck.ernser.v@geemail.com	San Francisco	California	210082849783070114	eb97c18f94e32f3eed0e91377ab90134	Diners Club / Carte Blanche	37.7800880524468923	-122.453299727203131
47245	2020-08-23 18:13:02	2020-08-23	Mr. Kenneth Carter	mr.kenneth.carter@warmmail.com	Memphis	Tennessee	4043567643432	eafa52e92417ade8f6b91b99692c23c5	Discover	35.1691059472106389	-89.8898294480774638
47246	2020-08-23 18:23:59	2020-08-23	Graydon Gulgowski MD	graydon.gulgowski.md@woohoo.com	Charlotte	North Carolina	869911289762304885	6146416eac317c125b496fd57f2f5561	VISA 13 digit	35.2006043354768323	-80.8345604292061211
47247	2020-08-23 18:26:08	2020-08-23	Dr. Jameel Hammes V	dr.jameel.hammes.v@geemail.com	Garland	Texas	3494354849726375	052380de69896ebf2ba11dcf4afa0823	American Express	32.8800655445784287	-96.7151217804916286
47248	2020-08-23 18:28:01	2020-08-23	Trevor Hoeger	trevor.hoeger@geemail.com	El Paso	Texas	3528534580031883297	f1efe294424f81add31eab5bb3fc37a8	JCB 16 digit	31.7615985135376455	-106.434922918861744
47249	2020-08-23 18:32:40	2020-08-23	Sigrid Will-Lindgren	sigrid.will.lindgren@geemail.com	San Francisco	California	4283730304351687	3426018cd116c344d9a195dedd57a6e3	Discover	37.7449599868153527	-122.425114097992889
47250	2020-08-23 18:41:18	2020-08-23	Blake Donnelly	blake.donnelly@geemail.com	Chicago	Illinois	4976780405601862	02d6826dae421da897975206b9b6c899	JCB 15 digit	41.9210079363383343	-87.6140755083907408
47251	2020-08-23 18:41:58	2020-08-23	Dr. Mansfield Lebsack I	dr.mansfield.lebsack.i@geemail.com	Berkeley	California	676194113948528	99023aa609bf2309fcf4ae52902b399b	Mastercard	37.9271925582758911	-122.300642126275008
47252	2020-08-23 18:44:02	2020-08-23	Edra Pouros	edra.pouros@geemail.com	Dallas	Texas	3700274905224706	04495fa9f8b7f6f9cde7b00b3ac05ff1	JCB 15 digit	32.7301571393657511	-96.6877279746774576
47253	2020-08-23 18:52:48	2020-08-23	Mr. Killian Kozey Sr.	mr.killian.kozey.sr.@warmmail.com	New York	New York	3528954439223072410	477755ca227c6cfe5348af19d0705409	VISA 16 digit	40.5686611657254375	-73.9993529706157744
47254	2020-08-23 18:53:11	2020-08-23	Noma Nicolas	noma.nicolas@geemail.com	Oakland	California	3774868133504614	e0b8ff72fec9b6412459833586db78b7	Maestro	37.8082360557974866	-122.27935036837313
47255	2020-08-23 18:53:28	2020-08-23	Ms. Lavelle Lubowitz MD	ms.lavelle.lubowitz.md@geemail.com	Los Angeles	California	3752247898525237	0808358db1d1273754a93d04af6f809c	VISA 16 digit	34.0154698092821945	-118.372921604895211
47256	2020-08-23 19:01:13	2020-08-23	Iva Nader-Cassin	iva.nader.cassin@geemail.com	Clovis	California	4708323127215	9a3ad930d7fb1fdf0da65c929248dc09	VISA 16 digit	36.7760243683930526	-119.659088948515802
47257	2020-08-23 19:05:47	2020-08-23	Rich Kuvalis-Wisozk	rich.kuvalis.wisozk@geemail.com	Jackson	Mississippi	4834322050313	8dd666343f4455bc7944bd4ce18082b1	VISA 16 digit	32.3024056177765146	-90.2631308535553529
47258	2020-08-23 19:09:21	2020-08-23	Ariana Bosco	ariana.bosco@geemail.com	Riverside	California	4559325809932	39ba1f8f859f4cfd17c68889baaadad6	Mastercard	33.9019327708467841	-117.445100998735796
47259	2020-08-23 19:18:00	2020-08-23	Daquan Kris	daquan.kris@warmmail.com	Bellevue	Washington	4128756854721085	ff79797482615f5fe307ced69b23077c	Voyager	47.5548464967586142	-122.250969848275176
47260	2020-08-23 19:28:12	2020-08-23	Mr. Theodis Hermiston	mr.theodis.hermiston@geemail.com	Gainesville	Florida	3020819941980818	01ad3cef4698b08a1e292022d98b8116	American Express	29.7719781922001374	-82.4291215431749862
47261	2020-08-23 19:28:17	2020-08-23	Walter Moen	walter.moen@geemail.com	Phoenix	Arizona	501826362591724	8b547913b6052114250a1605000b1664	Voyager	33.5019462035901867	-112.121563904725392
47262	2020-08-23 19:36:31	2020-08-23	Clemon Labadie II	clemon.labadie.ii@woohoo.com	Independence	Missouri	3010472607640407	d7a2bd9c28d7f31f9a926880440065a5	JCB 16 digit	39.1711258902233155	-94.286217751754819
47263	2020-08-23 19:38:25	2020-08-23	Chandra Leffler-Olson	chandra.leffler.olson@woohoo.com	New York	New York	3787391268516902	9646cf5b153a97fe156461470c1235d6	VISA 16 digit	40.727858180621638	-73.9733008888445767
47264	2020-08-23 19:38:27	2020-08-23	Beaulah Schamberger	beaulah.schamberger@geemail.com	Chattanooga	Tennessee	4022110942053	5ec18312d37cac538d0825488187e390	JCB 16 digit	35.1276270347964044	-85.2577511715065697
47265	2020-08-23 19:40:13	2020-08-23	Alexandr Jacobi	alexandr.jacobi@geemail.com	Fort Worth	Texas	3013283975942060	2ba3705827d5fe59c147d2ffc653aff3	JCB 16 digit	32.8554062471315262	-97.3965823858331845
47266	2020-08-23 19:43:11	2020-08-23	Miss Dolores Bechtelar	miss.dolores.bechtelar@geemail.com	Aurora	Colorado	210043059591899815	b3629d09a52e86df46e7b88d5db8e9e2	VISA 16 digit	39.7691480295378739	-104.685002909985187
47267	2020-08-23 19:44:29	2020-08-23	Kenan Hettinger	kenan.hettinger@geemail.com	Buffalo	New York	676220756759872	cbd73e0a0604cc5f63d2948ae8df033a	VISA 13 digit	42.9660555204562797	-78.8188148859821354
47268	2020-08-23 19:48:26	2020-08-23	Miss Dusty Harber PhD	miss.dusty.harber.phd@woohoo.com	Dallas	Texas	6011651644438394352	c25de3652743bf793a699cd2aade8adb	VISA 16 digit	32.7504323813404881	-96.8098855322189564
47269	2020-08-23 19:48:54	2020-08-23	Deann Kirlin	deann.kirlin@warmmail.com	North Charleston	South Carolina	3023873532231419	3b23ededfbe73ed8a2f8ef25e913f520	Maestro	32.9367814927056415	-80.1137683724611946
47270	2020-08-23 19:49:48	2020-08-23	Mamie Dach	mamie.dach@geemail.com	Portland	Oregon	869936246171156760	5dde4c006747bfc0d72ad298c38f2e5f	JCB 16 digit	45.4488090707808752	-122.635025652032354
47271	2020-08-23 19:52:42	2020-08-23	Alto Koss	alto.koss@geemail.com	Saint Paul	Minnesota	4589929996314	c5c102b9586aa3b0d81b53871c5bd05b	JCB 15 digit	45.0315022746507125	-93.1249917491603725
47272	2020-08-23 19:55:33	2020-08-23	Briley Senger	briley.senger@warmmail.com	Corpus Christi	Texas	6011444844856386623	0456e09192629a493c3dc875f3f681a9	Maestro	27.8262192610587924	-97.1783900979734909
47273	2020-08-23 20:01:20	2020-08-23	Kenzie Herzog-Cole	kenzie.herzog.cole@warmmail.com	Berkeley	California	869932409646738364	33b68b2f077bbb088fae15ee8fbfa7c1	JCB 16 digit	37.8721101314070268	-122.315859079658438
47274	2020-08-23 20:06:07	2020-08-23	Myrtle Runolfsdottir IV	myrtle.runolfsdottir.iv@geemail.com	Chicago	Illinois	4274272003475732	60029d05d17e6ac80376cbf4fb56e396	Diners Club / Carte Blanche	41.774152775651217	-87.6358099768433618
47275	2020-08-23 20:10:41	2020-08-23	Auston Pagac	auston.pagac@woohoo.com	Lexington	Kentucky	4387737398812115	6b6d392e1c5b7dcd91aa44a482d285a7	Mastercard	38.1164946338504578	-84.5044069917771878
47276	2020-08-23 20:15:07	2020-08-23	Bina Zboncak DDS	bina.zboncak.dds@geemail.com	Port St. Lucie	Florida	180022494445192999	bf108732f2fbaad33e1611fd96afe075	Discover	27.319077660575882	-80.4368652193892757
47277	2020-08-23 20:17:43	2020-08-23	Mrs. Isabel Baumbach	mrs.isabel.baumbach@geemail.com	Columbus	Ohio	6011592192066342964	19f0662220120d1e943f6de999b7475f	VISA 16 digit	39.922673312532531	-82.8878321145430306
47278	2020-08-23 20:24:00	2020-08-23	Dr. Michale Hudson IV	dr.michale.hudson.iv@geemail.com	San Francisco	California	6011577142902562613	a56a550bf7dade12e59ad5f4abe400f1	American Express	37.7526705620806737	-122.430165134054477
47279	2020-08-23 20:29:50	2020-08-23	Joycelyn Dibbert	joycelyn.dibbert@geemail.com	Baltimore	Maryland	55045096483197674	fd41367b870fd7e9ef60b84faf8f2be7	JCB 16 digit	39.2198628054000409	-76.7013459591213689
47280	2020-08-23 20:36:40	2020-08-23	Ottie Brown	ottie.brown@warmmail.com	San Jose	California	6011092366847012188	d0ac6794578b2efe8e7b68f42b15d80e	VISA 16 digit	37.3272684187449499	-121.760983213245495
47281	2020-08-23 20:41:03	2020-08-23	Braiden Emmerich	braiden.emmerich@geemail.com	Albuquerque	New Mexico	180075645055457446	6b27b42809d136dfe5f7c573874c7730	Diners Club / Carte Blanche	35.0601498141553307	-106.596156316723309
47282	2020-08-23 20:41:53	2020-08-23	Shae Howell-Buckridge	shae.howell.buckridge@geemail.com	Phoenix	Arizona	4739391929133206	e3f0f1a4dea8a66c2657206fafbf8ec0	JCB 15 digit	33.6494648370359144	-112.034481091836852
47283	2020-08-23 20:47:22	2020-08-23	Linnea Pollich	linnea.pollich@geemail.com	Saint Paul	Minnesota	4913350280725255	720c1586a9ab5c80dc62fd9e5c3032b5	VISA 16 digit	45.0121649101316947	-93.0057406003385836
47284	2020-08-23 20:49:52	2020-08-23	Neely Rice	neely.rice@geemail.com	Plano	Texas	4834467703749559	748843132fc3d37f1e436508696b9cbc	American Express	33.0071036769162873	-96.8168147358294533
47285	2020-08-23 20:50:32	2020-08-23	Janene Heidenreich	janene.heidenreich@geemail.com	Berkeley	California	3785187078903773	8748fef42106608f8dc6e721272abe9a	Maestro	37.8694001166620851	-122.252609423318432
47286	2020-08-23 20:55:21	2020-08-23	Dr. Risa Koelpin	dr.risa.koelpin@woohoo.com	San Francisco	California	869925268154910560	bf2db385d9002d6b906534632d20401e	Voyager	37.7856136881366993	-122.43256781130593
47287	2020-08-23 21:11:26	2020-08-23	Ell Legros II	ell.legros.ii@geemail.com	Ann Arbor	Michigan	6011896078169184093	331e3bdcb73720101527850cd1366a12	American Express	42.2409145337123419	-83.7690198422051964
47288	2020-08-23 21:12:29	2020-08-23	Timmie O'Keefe	timmie.o'keefe@geemail.com	New York	New York	869961224591609609	4277a8634704035ba53e246e1c2c3b52	Diners Club / Carte Blanche	40.7615423592030979	-73.9745500705100625
47289	2020-08-23 21:12:48	2020-08-23	Wheeler Lind	wheeler.lind@woohoo.com	San Francisco	California	52393329941405654	513f4339f717f4305056f1cda8123e25	VISA 16 digit	37.7818609863371719	-122.408983628560179
47290	2020-08-23 21:17:38	2020-08-23	Dr. Jamarcus Frami V	dr.jamarcus.frami.v@geemail.com	Charlotte	North Carolina	4731706367702196	4d4dc0bf23c0a62756a4e23843aa594e	Maestro	35.2959856697145824	-80.8562237250562816
47291	2020-08-23 21:20:00	2020-08-23	Tolbert Huels	tolbert.huels@geemail.com	New Haven	Connecticut	3112989325955027095	38b400d00a4799778eb0ccf6524330c7	JCB 16 digit	41.3330305173520003	-72.9918954410124599
47292	2020-08-23 21:26:30	2020-08-23	Rutherford Jacobson	rutherford.jacobson@geemail.com	Sacramento	California	3449667401824932	334d8195740129cb5ad01a0240da2ac6	VISA 16 digit	38.6261156665425744	-121.405570486864448
47293	2020-08-23 21:28:03	2020-08-23	Kristopher Roberts	kristopher.roberts@geemail.com	Reno	Nevada	180008071174001407	1df1018be29b34bdba81c9582a559d12	JCB 15 digit	39.646423185717687	-119.867516451531657
47294	2020-08-23 21:29:29	2020-08-23	Kandy Braun MD	kandy.braun.md@woohoo.com	Worcester	Massachusetts	3015173042600163	8567d1a89d47bd2b2586d37b7d40c9ee	VISA 16 digit	42.1726830307561897	-71.7773326608139968
47295	2020-08-23 21:44:27	2020-08-23	Gregorio Bode-Johnson	gregorio.bode.johnson@geemail.com	Topeka	Kansas	3011713514371803	b3882058dcd4fa3011785912dd0e2aeb	Discover	38.985286414011199	-95.6493690588221028
47296	2020-08-23 21:44:37	2020-08-23	Kristian Schinner	kristian.schinner@geemail.com	Fort Wayne	Indiana	3020382002023507	1fb6949a2b1bc616e052286db6f89928	JCB 16 digit	41.1603608212683341	-85.1331372356727769
47297	2020-08-23 21:50:18	2020-08-23	Branch Cassin	branch.cassin@warmmail.com	Houston	Texas	4290127295555	399038c2be2e0b53d087afee88c112e5	Discover	29.6869416690044119	-95.4066522182911712
47298	2020-08-23 21:59:40	2020-08-23	Chana Cremin	chana.cremin@geemail.com	Jersey City	New Jersey	3088916939930676327	1cb1420e5234c6952a4944048216ffa8	Mastercard	40.8056988221067911	-74.0491855277169577
47299	2020-08-23 21:59:41	2020-08-23	Orval Flatley	orval.flatley@woohoo.com	Orlando	Florida	3477739488383135	4eede9ef42b6c162edd00b198014f47c	Maestro	28.3419839464392496	-81.2301480071585615
47300	2020-08-23 22:00:41	2020-08-23	Therese Collins	therese.collins@geemail.com	Chicago	Illinois	3015363934493138	939ca4e1ed1c1bd9dd4a23793c3de37b	Discover	41.7651449929758911	-87.6026736637607115
47301	2020-08-23 22:08:15	2020-08-23	Miss Gianna Champlin	miss.gianna.champlin@geemail.com	Saint Paul	Minnesota	4763013308914	44e196746fb4a1ea3911415fb0edda62	Diners Club / Carte Blanche	44.9484996179990475	-93.1556863888897055
47302	2020-08-23 22:10:09	2020-08-23	Mahala Cummings	mahala.cummings@geemail.com	Columbia	South Carolina	55077678613200402	8d2bf3e6d1c7eb8bbfb05984d0332428	VISA 16 digit	33.9796570029374223	-80.9604581230338596
47303	2020-08-23 22:15:40	2020-08-23	Valeria Stark	valeria.stark@geemail.com	Billings	Montana	4083266403949198	c652c9a33355c2d31e16b925633e1559	VISA 16 digit	45.8408180134594403	-108.634070284587878
47304	2020-08-23 22:17:16	2020-08-23	Verdie Frami	verdie.frami@geemail.com	New York	New York	4613207445115	4858e5412d508e8fe745ed5c71225c7c	JCB 16 digit	40.6797866133265202	-73.9450130731694344
47305	2020-08-23 22:17:31	2020-08-23	Nicki Bergstrom	nicki.bergstrom@warmmail.com	Midland	Texas	3158720348208451163	f299b95de7d16a3d1c687223c8c885a2	American Express	32.0351393856298188	-102.126316157704224
47306	2020-08-23 22:30:09	2020-08-23	Yehuda Schiller DVM	yehuda.schiller.dvm@geemail.com	Boston	Massachusetts	3401930924778118	66404e0ba5d720d0efc31e3345d02eb4	JCB 16 digit	42.3899028010368326	-71.1034622484304037
47307	2020-08-23 22:48:10	2020-08-23	Chauncy Schoen	chauncy.schoen@geemail.com	Fayetteville	North Carolina	3032311038798236	4f339f99fd10a229c08e850fcd325a4f	JCB 15 digit	35.0432966192506257	-79.0615490761250328
47308	2020-08-23 22:53:09	2020-08-23	Mr. Bilal Tremblay	mr.bilal.tremblay@geemail.com	San Francisco	California	3158837084917139225	be3f3d5c1ec232d95f2dd2b8632d6da5	VISA 16 digit	37.8033011656089002	-122.47658209871814
47309	2020-08-23 22:58:06	2020-08-23	Tyrin Crona	tyrin.crona@geemail.com	Des Moines	Iowa	4333745768361	a50b8230cefc7bec5d51bd824c09f655	VISA 13 digit	41.628734503986685	-93.6825970701918038
47310	2020-08-23 23:03:05	2020-08-23	Mrs. Mandy Hahn MD	mrs.mandy.hahn.md@geemail.com	Corona	California	3528005530378218169	2dd176e30e9ff43007a7e6cbb0832f1f	VISA 13 digit	33.9393928293026974	-117.631476100880647
47311	2020-08-23 23:06:27	2020-08-23	Domonique Rowe	domonique.rowe@geemail.com	San Francisco	California	6011154322681121366	b84254b22bb06e39fc147f4b20476a61	JCB 16 digit	37.7924704970482495	-122.447129494855872
47312	2020-08-23 23:29:56	2020-08-23	Shea Rogahn	shea.rogahn@woohoo.com	Huntington Beach	California	4717718567601985	f09f4d80853cb1c505790526d7e52221	JCB 16 digit	33.6104466972447966	-117.960436456150561
47313	2020-08-23 23:31:53	2020-08-23	Cyrus Monahan	cyrus.monahan@geemail.com	Columbus	Ohio	3158124746265692052	2ea0c9b1a33e9face530738a40afef66	American Express	39.9498821382921179	-82.9726941067960126
47314	2020-08-23 23:33:20	2020-08-23	Yusuf Cormier	yusuf.cormier@geemail.com	Berkeley	California	3528432550296387493	4510853de287991867c771459adb9515	American Express	37.8380376161904266	-122.248247286595003
47315	2020-08-23 23:35:20	2020-08-23	Emogene Walter-Homenick	emogene.walter.homenick@woohoo.com	San Francisco	California	55649261803958201	c554bd2c1241c3381f3fc04e7a73cab9	American Express	37.7694986773257497	-122.420487069323556
47316	2020-08-23 23:42:58	2020-08-23	Pandora Torphy-Thompson	pandora.torphy.thompson@geemail.com	San Antonio	Texas	4356012677171	979b0b99b4cb87ed305645a8612fdb20	JCB 15 digit	29.5665733462736	-98.5824538173455664
47317	2020-08-23 23:44:24	2020-08-23	Mr. Berry O'Connell	mr.berry.o'connell@warmmail.com	Los Angeles	California	4055136943374	20b13909aec28772ae5fa885cda1159f	JCB 16 digit	34.0518880615342354	-118.332573859113452
47318	2020-08-23 23:46:25	2020-08-23	Sarahi Ankunding PhD	sarahi.ankunding.phd@warmmail.com	Cincinnati	Ohio	180032208679764861	b78f432770470d65cebb2784b21250ab	VISA 13 digit	39.1974048954200001	-84.5822829308260111
47319	2020-08-23 23:58:58	2020-08-23	Marietta Thompson	marietta.thompson@geemail.com	Antioch	California	6011844043917689655	ee07ba58b01e0b2248c6e5b7321e19f4	Mastercard	38.0025818215016287	-121.859559011430292
47320	2020-08-24 00:01:36	2020-08-24	Miss Catalina Lynch	miss.catalina.lynch@geemail.com	Columbus	Ohio	4855686692876834	aa7cdbc70f9243ff624c26eb1013f8b1	VISA 13 digit	39.9496687760621327	-83.0399389045082046
47321	2020-08-24 00:15:19	2020-08-24	Mr. Zain Quigley	mr.zain.quigley@geemail.com	El Paso	Texas	3789142724241124	8eb3bfdb36a5d129af27ff9d82f45282	VISA 16 digit	31.8040929658632727	-106.508869543436916
47322	2020-08-24 00:15:59	2020-08-24	Clemmie Hermiston	clemmie.hermiston@geemail.com	San Antonio	Texas	4639116215638	c80bb10632ad00a3e52bb12837469354	Maestro	29.3950768676191565	-98.5302265350077278
47323	2020-08-24 00:24:21	2020-08-24	Meggan Stark MD	meggan.stark.md@woohoo.com	Virginia Beach	Virginia	869907915024866727	7ced32d868ed1dd66fe06f3ffc022d00	JCB 16 digit	36.7457447362318632	-76.086413163519282
47324	2020-08-24 00:29:26	2020-08-24	Drury Mann	drury.mann@geemail.com	Portland	Oregon	869984952491159514	c77622c3373c8af4872fe7de4758f343	Voyager	45.4816553222369393	-122.684393944963816
47325	2020-08-24 00:29:54	2020-08-24	Lavern Jenkins	lavern.jenkins@geemail.com	Columbia	South Carolina	4871181123260	46555acfa810296cb1cbb0fb0067cc80	Voyager	34.0185368686713261	-80.9296876076627427
47326	2020-08-24 00:34:42	2020-08-24	Ayanna Eichmann	ayanna.eichmann@geemail.com	Plano	Texas	53126603737530758	5e340f1668f879ffa1db928dbda1ccd5	Diners Club / Carte Blanche	33.0720179611902694	-96.7503082587566183
47327	2020-08-24 01:01:20	2020-08-24	Ason Fay	ason.fay@geemail.com	Berkeley	California	210026404779479769	bd0a5c0ff9bce163878518200d3d6390	Maestro	37.8885936886044021	-122.344444164077657
47328	2020-08-24 01:15:25	2020-08-24	Alfie Emard	alfie.emard@woohoo.com	Cleveland	Ohio	6011924092833453301	979ab69823211e69206c41265062b6ed	VISA 16 digit	41.422369803240521	-81.5948297391883983
47329	2020-08-24 01:15:45	2020-08-24	Dr. Tariq Schamberger	dr.tariq.schamberger@geemail.com	Yonkers	New York	4454951672368458	1651413f40c4bec632fa3ec6bb8aab4f	Discover	41.005347150165214	-73.9112281198963501
47330	2020-08-24 01:32:45	2020-08-24	Dr. Marjory Schaefer DVM	dr.marjory.schaefer.dvm@geemail.com	Oakland	California	3014066799758633	c26a608af6d1c0f1a29ed7b025310c8b	VISA 16 digit	37.7978003032683674	-122.25751009482093
47331	2020-08-24 01:34:10	2020-08-24	Dr. Octave Heidenreich	dr.octave.heidenreich@geemail.com	Los Angeles	California	210088443939578420	ba936f723d51b639c81af0ef6f8621c5	Mastercard	33.9761265353631217	-118.49867356787361
47332	2020-08-24 01:34:56	2020-08-24	Corbin Schaden	corbin.schaden@woohoo.com	New York	New York	4455376823007	f7c66fa4be0af1215bca009beafd8629	Voyager	40.6229959341920903	-73.9224295554578248
47333	2020-08-24 01:38:35	2020-08-24	Grady Zboncak-Terry	grady.zboncak.terry@geemail.com	Oklahoma City	Oklahoma	210033420363612285	77de9d9ec47101cb98e395cedec2dd76	VISA 16 digit	35.4877312137190302	-97.4726476022869406
47334	2020-08-24 01:39:55	2020-08-24	Ms. Gracie Flatley DVM	ms.gracie.flatley.dvm@geemail.com	Seattle	Washington	6011105732497346504	ee80690c3a5cb56bfcc67bca2b67af20	VISA 16 digit	47.5520345697570619	-122.351366938270246
47335	2020-08-24 02:07:28	2020-08-24	Lulie Smitham	lulie.smitham@geemail.com	Burbank	California	6011494157328139077	10c32dd49cf4a986659e3932a6aa8806	JCB 16 digit	34.2681125205870742	-118.276677753360573
47336	2020-08-24 02:14:53	2020-08-24	Ms. Geri Pouros	ms.geri.pouros@geemail.com	Grand Rapids	Michigan	3158934528761199679	c2c2e41d63b8f057baf0746e477d5ef8	Discover	43.0575414793834099	-85.5760657902941233
47337	2020-08-24 02:29:53	2020-08-24	Sula Smith PhD	sula.smith.phd@geemail.com	Davie	Florida	4989326633365287	d0966fa9ae0efcc22b9fdbdfa22b79c6	Discover	26.0026343412496139	-80.2421706551592706
47338	2020-08-24 02:37:02	2020-08-24	Miss Fawn Parisian DDS	miss.fawn.parisian.dds@geemail.com	Sugar Land	Texas	502041723101345	2eebcaf7a7cfc264e4ed0c85d9748fa3	VISA 16 digit	29.656293524387852	-95.6086538740906775
47339	2020-08-24 02:46:34	2020-08-24	Ms. Tania Miller DDS	ms.tania.miller.dds@woohoo.com	Oklahoma City	Oklahoma	180086761984971881	27a24a6cb1542c051028c958aa432475	VISA 16 digit	35.5370878884013734	-97.5728302901972029
47340	2020-08-24 03:11:12	2020-08-24	Shae Leffler	shae.leffler@warmmail.com	Columbia	South Carolina	4094249976716	6bfe0ec6ca0a13234d71faa8935c74f2	Discover	34.0834000474572179	-80.8140500548314265
47341	2020-08-24 03:22:04	2020-08-24	Andrea Larson	andrea.larson@geemail.com	New York	New York	3158405182945103601	b92e4f2bec8fb115d2073a2bc6959a1f	VISA 16 digit	40.7064194004274924	-73.9088011091470634
47342	2020-08-24 03:30:25	2020-08-24	Tracy Baumbach	tracy.baumbach@warmmail.com	Clearwater	Florida	3096066369879188233	b4718b6abc216844410ffe9b7e60edd0	Maestro	27.8897759022783482	-82.7005256858453066
47343	2020-08-24 03:33:15	2020-08-24	Pierre Abbott V	pierre.abbott.v@geemail.com	San Francisco	California	676105568077845	00786f6143e49395c4d535df367fd260	VISA 16 digit	37.7479779241726732	-122.402029705619981
47344	2020-08-24 03:39:28	2020-08-24	Dr. Evelyne Parisian	dr.evelyne.parisian@geemail.com	San Francisco	California	869990869197281065	eb195e47c6f58e3785efc8f2fb408591	Voyager	37.7665189529449776	-122.443771167611317
47345	2020-08-24 03:43:27	2020-08-24	Douglass Rohan	douglass.rohan@woohoo.com	Oakland	California	6011383267095115137	438ae150ad7a8a45f050203b39af84c1	JCB 15 digit	37.7804317441993192	-122.252208188100738
47346	2020-08-24 03:46:33	2020-08-24	Stanislaus Monahan	stanislaus.monahan@geemail.com	Phoenix	Arizona	676215030364960	6574fba6eb222076852ad497bc977056	Diners Club / Carte Blanche	33.6114885009758169	-112.012703234928111
47347	2020-08-24 03:51:28	2020-08-24	Quincy Pollich	quincy.pollich@warmmail.com	Wichita Falls	Texas	4026933292075043	faaa71586894316bcc6b84a895a3be20	VISA 13 digit	33.8189539888601729	-98.4317828528970438
47348	2020-08-24 03:55:50	2020-08-24	Katherin Daugherty-Reynolds	katherin.daugherty.reynolds@warmmail.com	Long Beach	California	3112916061605765903	d42d84959bed8c24665ca0890876cd14	Discover	33.7925681684452996	-118.219892453651127
47349	2020-08-24 04:02:23	2020-08-24	Mr. Desmond Pfeffer V	mr.desmond.pfeffer.v@woohoo.com	San Francisco	California	180048961970724693	5cab02529cf90e426d4a227fb48d45b9	VISA 16 digit	37.7389545192562395	-122.43145391446231
47350	2020-08-24 04:02:30	2020-08-24	Dr. Eula Heller	dr.eula.heller@geemail.com	Houston	Texas	4018178590526194	2ab813a0319b40ab9c13334ab9a60883	JCB 15 digit	29.8173700479403152	-95.342123225053399
47351	2020-08-24 04:07:09	2020-08-24	Leanne Kiehn-Kuphal	leanne.kiehn.kuphal@geemail.com	St. Louis	Missouri	180046259143258125	e4ca5d5dd060ee77a3c3a19ee5bff364	Mastercard	38.697664457528667	-90.1700244362004213
47352	2020-08-24 04:08:21	2020-08-24	Nigel Mosciski II	nigel.mosciski.ii@geemail.com	Berkeley	California	54678015260011266	e76bf51fb04a51e910d5c35b0135b831	Maestro	37.8996391646230393	-122.295401256904142
47353	2020-08-24 04:09:25	2020-08-24	Mr. Kelvin Ledner	mr.kelvin.ledner@warmmail.com	Lowell	Massachusetts	3777527091797555	4383eae72cb806a2a653b93840bbaf70	JCB 16 digit	42.7062396520618393	-71.4144550490066479
47354	2020-08-24 04:17:12	2020-08-24	Mr. Braiden Collier DVM	mr.braiden.collier.dvm@geemail.com	Oakland	California	4182675484927958	4c0f02d82a4db4640aec6aac9d9e6baa	JCB 16 digit	37.8043743188189296	-122.229119641458354
47355	2020-08-24 04:17:32	2020-08-24	Kenyon Turcotte	kenyon.turcotte@geemail.com	Santa Rosa	California	4545617641463586	f402f48eb785d15e1e30ad180533996d	VISA 16 digit	38.3860421860713572	-122.762356567314271
47356	2020-08-24 04:29:22	2020-08-24	Dr. Ryder Huel II	dr.ryder.huel.ii@geemail.com	Santa Rosa	California	3096677101555514882	e3b29c4edfc5749f8caa4f0a10f67ae6	Voyager	38.3693301370024713	-122.691549038911617
47357	2020-08-24 04:34:54	2020-08-24	Miss Elna Ullrich	miss.elna.ullrich@geemail.com	Berkeley	California	3712355176112815	68a0ca12d80391c90ee0267588c5be1c	JCB 16 digit	37.8273303725557071	-122.269193268501482
47358	2020-08-24 04:49:02	2020-08-24	Wellington Fritsch	wellington.fritsch@geemail.com	Vacaville	California	180090852961392813	725c98e16ef2e6772e7db5d630f77dd5	Discover	38.4059522046368613	-121.9716095887471
47359	2020-08-24 04:49:05	2020-08-24	Cason Hoeger	cason.hoeger@woohoo.com	Lansing	Michigan	3029572009717611	e7121051d57ff7a22ee6642315ac09cb	VISA 13 digit	42.6703416877735435	-84.4614243310067678
47360	2020-08-24 04:49:20	2020-08-24	Mr. Khalid Hickle	mr.khalid.hickle@warmmail.com	Independence	Missouri	51864450040861157	41738c0c3124f78a1820d6c32561b3a6	Maestro	39.0147988492641602	-94.3486309615712599
47361	2020-08-24 04:50:40	2020-08-24	Roslyn Renner	roslyn.renner@geemail.com	Yonkers	New York	3728324763438894	8fe45aee84673440f5f81892fc0bab25	VISA 13 digit	40.8594975358542101	-73.8019297059509967
47362	2020-08-24 04:52:17	2020-08-24	Sie Marvin	sie.marvin@woohoo.com	Port St. Lucie	Florida	3713193169688528	41a6390cb8d7341fefd4f34df6e95302	VISA 16 digit	27.2654876150790599	-80.3227854108057926
47363	2020-08-24 05:21:24	2020-08-24	Enoch Emmerich	enoch.emmerich@geemail.com	Phoenix	Arizona	3337287413798622089	f04b8af248d6caaecf1fc8658120bacc	Mastercard	33.6248136748958402	-112.088351294344676
47364	2020-08-24 05:59:33	2020-08-24	Coral Gutkowski	coral.gutkowski@geemail.com	Berkeley	California	4371882991251226	36ae1fef0b8b77ec0037c430f65f329e	VISA 16 digit	37.8634118787593295	-122.282590580667829
47365	2020-08-24 06:01:55	2020-08-24	Haley Beatty	haley.beatty@geemail.com	San Francisco	California	676191866103590	eb97052a87213180b06b0c7a418aee78	American Express	37.7710298546540599	-122.436993520139367
47366	2020-08-24 06:16:19	2020-08-24	Rennie Okuneva	rennie.okuneva@geemail.com	Denver	Colorado	180068126548219163	b7cc5c76ecbb05a4861b436fb3e0d5bc	JCB 16 digit	39.7488528058450612	-104.867734089285506
47367	2020-08-24 06:24:34	2020-08-24	Arnetta Hayes DDS	arnetta.hayes.dds@geemail.com	Oakland	California	3409857915910941	e02c1c7097b01e700ea8d1e1094ea7a5	VISA 16 digit	37.7434601182261957	-122.267746663131589
47368	2020-08-24 06:39:52	2020-08-24	Nobie Durgan	nobie.durgan@geemail.com	Chattanooga	Tennessee	3337635124596865387	50ae2414426478b42e7548cc0a9a9322	Diners Club / Carte Blanche	34.972908542802557	-85.2166565922383228
47369	2020-08-24 06:47:22	2020-08-24	Reed Wehner	reed.wehner@geemail.com	Tallahassee	Florida	869960377367355921	57d17f8ae3b00bcd9bcd4384c6a29edf	JCB 16 digit	30.400380112233016	-84.2011601787075392
47370	2020-08-24 06:49:16	2020-08-24	Dr. Isabell Ledner	dr.isabell.ledner@geemail.com	San Jose	California	4555633775383307	176851375c397ffc840b1d9abeff0dbd	JCB 15 digit	37.2910573519587558	-121.896125741837167
47371	2020-08-24 06:53:58	2020-08-24	Shaquan Kassulke	shaquan.kassulke@geemail.com	Winston–Salem	North Carolina	51824691393629522	ce0c753ebf81baafd8570b889197bab7	Voyager	36.1838538159381571	-80.1780465791597976
47372	2020-08-24 07:00:00	2020-08-24	Mr. Joe Gislason I	mr.joe.gislason.i@geemail.com	Seattle	Washington	52979462318331948	e87c2791ec81194f9311861d399ae1f8	VISA 16 digit	47.5299929496292037	-122.358068147340418
47373	2020-08-24 07:00:08	2020-08-24	Fairy Jenkins-Schmidt	fairy.jenkins.schmidt@geemail.com	Kansas City	Missouri	210089666365391426	344f86d7148a0da8f57a34928c814205	Discover	39.1243498765699584	-94.6221567153222907
47374	2020-08-24 07:00:39	2020-08-24	Miss Adison Parisian MD	miss.adison.parisian.md@geemail.com	Riverside	California	4801509819679	36edeed5a6d0180874d178aca7eb182d	Maestro	33.8663783226110056	-117.466250427064296
47375	2020-08-24 07:02:43	2020-08-24	Mariano Schultz	mariano.schultz@geemail.com	New York	New York	869982565142579914	493f4bc1cbbd729e519e2e35edc0d983	Discover	40.6548501740433252	-73.8813079374738066
47376	2020-08-24 07:10:49	2020-08-24	Dr. Eathel Volkman DDS	dr.eathel.volkman.dds@geemail.com	Los Angeles	California	180096966860902854	454741bec2fe9f7d67d4c3ff3cc3d398	Voyager	34.0693156133737389	-118.505485935834415
47377	2020-08-24 07:10:52	2020-08-24	Dr. Tayler Mante	dr.tayler.mante@warmmail.com	Chesapeake	Virginia	3088089985743420396	7ca6a7e4e4e949c173daa3b52f813b83	Voyager	36.6944859207380603	-76.2721611004166249
47378	2020-08-24 07:11:17	2020-08-24	Milas Reichel	milas.reichel@woohoo.com	Newark	New Jersey	3014186703072291	0e97ae1e3132e5add609c8908f84a4ea	JCB 16 digit	40.8141551519658421	-74.2472666553430258
47379	2020-08-24 07:13:51	2020-08-24	Teagan Beahan	teagan.beahan@warmmail.com	Jurupa Valley	California	4345284907768133	ba54ae6eee8337ff795b762c011f012a	JCB 16 digit	34.0889545867148769	-117.43269046456777
47380	2020-08-24 07:27:57	2020-08-24	Dr. Hardy Emard	dr.hardy.emard@warmmail.com	Green Bay	Wisconsin	4704533252158	2b375930a317021170f63d4da6035e5c	VISA 16 digit	44.4603725823637106	-87.9662963204838348
47381	2020-08-24 07:49:02	2020-08-24	Gustie Mosciski	gustie.mosciski@geemail.com	San Jose	California	210084175406620632	991770ee9e75c062a4965c3531c8ced6	Discover	37.2331355532452477	-121.846778610882907
47382	2020-08-24 07:53:45	2020-08-24	Rowland Ernser PhD	rowland.ernser.phd@geemail.com	Yonkers	New York	4426066162519307	6ed19faa216bd66d0128d0b43bf7b3f3	JCB 16 digit	40.9000355427354592	-73.783822885050995
47383	2020-08-24 07:57:49	2020-08-24	Armando Will-Watsica	armando.will.watsica@warmmail.com	Austin	Texas	52103630220717912	179e194528a8433c5bf3bb4b6fa20c56	VISA 13 digit	30.3602473822083319	-97.7020979502011073
47384	2020-08-24 07:58:47	2020-08-24	Mrs. Eulah Bahringer	mrs.eulah.bahringer@geemail.com	Aurora	Illinois	4905181611362009	8c02136bdccbcbcdf06ea74ae81aff57	JCB 16 digit	41.7802108602821818	-88.2098902641259031
47385	2020-08-24 08:00:35	2020-08-24	Fernando Lehner	fernando.lehner@geemail.com	Seattle	Washington	869933574681391566	e43e1583d15a768d4a5456f3509f9f6a	Voyager	47.7194918122068046	-122.329496733137958
47386	2020-08-24 08:07:53	2020-08-24	Mrs. Debbra Sauer	mrs.debbra.sauer@warmmail.com	San Francisco	California	4966440857739908	6b8ebfba0c411eff970cf55e19afcd27	JCB 15 digit	37.8041088938908274	-122.439024400524104
47387	2020-08-24 08:38:15	2020-08-24	Arminta Hoeger	arminta.hoeger@geemail.com	New York	New York	3774488899957722	9407146ccbbe0ef46c9133bc9959eade	Discover	40.7247881834618752	-73.9125495324272634
47388	2020-08-24 08:48:58	2020-08-24	Cecile Witting	cecile.witting@geemail.com	Albuquerque	New Mexico	3088506763558307676	7e2367ad0503bbb3831bf1ec7315bc00	JCB 15 digit	35.1491554354917284	-106.588036256756268
47389	2020-08-24 08:59:37	2020-08-24	Michal Beahan	michal.beahan@geemail.com	New York	New York	180001492633717986	d599b0c800e9df3178de36fe5a4963fa	JCB 16 digit	40.6463830358106648	-73.9868381831690698
47390	2020-08-24 09:00:23	2020-08-24	Yoshiko Robel	yoshiko.robel@geemail.com	Chesapeake	Virginia	676371931036777	3a552d2f5e6d826cde11e86182872172	American Express	36.7128752752911325	-76.325675413928181
47391	2020-08-24 09:02:51	2020-08-24	Deion Heidenreich IV	deion.heidenreich.iv@geemail.com	San Jose	California	6011497791554756431	323fb103ae47a340a27ac0eb541c3f93	Diners Club / Carte Blanche	37.3831795884583187	-121.743111459746586
47392	2020-08-24 09:03:41	2020-08-24	Dominga Keebler	dominga.keebler@geemail.com	Phoenix	Arizona	869988019235401002	396ecd3b551b1bd9ca54de4e767b356e	VISA 16 digit	33.6139943723965473	-112.046484306121627
47393	2020-08-24 09:25:07	2020-08-24	Ms. Birdie Wilkinson	ms.birdie.wilkinson@geemail.com	Philadelphia	Pennsylvania	53857934473225070	6c0fd944fb1fb2ca6cd8b89db355cc46	VISA 16 digit	39.9671122911810883	-75.0725311871517533
47394	2020-08-24 09:32:05	2020-08-24	Dr. Burnett Keeling IV	dr.burnett.keeling.iv@warmmail.com	San Francisco	California	4406081130168172	bde971bfde73e9a7c9eafadbb59f4c7a	Discover	37.776732205916737	-122.435951012740034
47395	2020-08-24 09:48:55	2020-08-24	Boss Hansen	boss.hansen@geemail.com	San Francisco	California	53514540436822914	9c87b3ef0019481d31822038436adc20	Mastercard	37.7794682286031289	-122.420649393900192
47396	2020-08-24 10:08:46	2020-08-24	Ingeborg Harber	ingeborg.harber@geemail.com	Arvada	Colorado	3001757857238475	1ee77f661b6e5081a1849435e06cfcb6	Voyager	39.9159544226422938	-105.066474494568254
47397	2020-08-24 10:08:58	2020-08-24	Blair Olson-Hagenes	blair.olson.hagenes@woohoo.com	Santa Clarita	California	630473265464005	c4a475f0532516d0f1ddcf8595a18694	Discover	34.3422225128132865	-118.511260912856827
47398	2020-08-24 10:10:41	2020-08-24	Marjorie Stokes	marjorie.stokes@geemail.com	Omaha	Nebraska	3528365007126300759	ea2c1d2f1566ac812842851a0f041c0f	Mastercard	41.2638938401505371	-95.9765025076106184
47399	2020-08-24 10:15:03	2020-08-24	Matie McCullough	matie.mccullough@warmmail.com	Chicago	Illinois	4093387831279	abef90ea7fc6d501841c14d2c16b307a	JCB 16 digit	41.9341496105141971	-87.6874534741539406
47400	2020-08-24 10:16:53	2020-08-24	Santo Nitzsche III	santo.nitzsche.iii@geemail.com	New York	New York	54548655533538948	2dae54c7ee4aada3587c7e607c786a4a	Mastercard	40.593412408301603	-73.9791116624966207
47401	2020-08-24 10:30:49	2020-08-24	Janeen Ferry-Schulist	janeen.ferry.schulist@geemail.com	San Francisco	California	4518456450885792	909d324e2c861f1d143583525704c5b2	VISA 16 digit	37.7707839634531979	-122.430536434676867
47402	2020-08-24 10:38:48	2020-08-24	Christopher Kulas	christopher.kulas@woohoo.com	New York	New York	3740953322365398	e4f77ccf1b8a6ff7c6eaee1cc576e7ec	Discover	40.611512159997595	-73.8802920428000363
47403	2020-08-24 10:45:57	2020-08-24	Dr. Therman Leannon I	dr.therman.leannon.i@warmmail.com	San Francisco	California	4012492717824101	8a341a357ce3322a08457c9123495247	VISA 16 digit	37.7474482919496239	-122.463359440523263
47404	2020-08-24 10:59:17	2020-08-24	Denis Sanford	denis.sanford@geemail.com	New York	New York	4792052134014	3ac72567392779c70024b6d99b4df793	JCB 15 digit	40.6981578866708986	-73.9679303082067463
47405	2020-08-24 11:03:37	2020-08-24	Roena Wiegand-Roberts	roena.wiegand.roberts@geemail.com	Atlanta	Georgia	503842478515853	3a16899ec3bcbb9d8cb2c1793a88be97	VISA 13 digit	33.713152424739306	-84.4590594484049859
47406	2020-08-24 11:21:13	2020-08-24	Edgar Hessel	edgar.hessel@geemail.com	Miami Gardens	Florida	869980354280382437	ac59a100e9e36b31ad334910d67c37b5	Maestro	25.9793782097227854	-80.26244995196015
47407	2020-08-24 11:29:28	2020-08-24	Jed Johns PhD	jed.johns.phd@geemail.com	Las Vegas	Nevada	676233705202217	41d8a8d91a0b1fd4accc2457b4b59f9f	Maestro	36.250722050211202	-115.233800009565797
47408	2020-08-24 11:31:00	2020-08-24	Mr. Kerry Zboncak	mr.kerry.zboncak@geemail.com	Oakland	California	4135956545572	8a04aa20d279612bfae3b7a65d79b589	Maestro	37.7677629326466686	-122.283193621590158
47409	2020-08-24 11:32:21	2020-08-24	Gorden Sporer-Bahringer	gorden.sporer.bahringer@geemail.com	San Francisco	California	3494846679698970	d6ec9e4b758ff6e3d73d290ff8e2e124	Mastercard	37.7698767373739699	-122.407530438341681
47410	2020-08-24 11:46:36	2020-08-24	Miss Jonell Bahringer DDS	miss.jonell.bahringer.dds@geemail.com	Philadelphia	Pennsylvania	180054562663026676	ee08b03c05c74b715cce83dd778aa6fe	VISA 13 digit	39.9858119917061146	-75.1403715980138713
47411	2020-08-24 11:46:46	2020-08-24	Ludwig Tromp	ludwig.tromp@geemail.com	Houston	Texas	4182681214587690	13754f592074e0df7acea8a74fc0a099	VISA 13 digit	29.8510878209102906	-95.3234551006943036
47412	2020-08-24 11:50:20	2020-08-24	Miss Mickey Walker	miss.mickey.walker@geemail.com	Riverside	California	3337767432717386732	3a6ecaf45f31ee608a20bdf14bbc52fb	JCB 15 digit	33.8576158422458917	-117.356927193279191
47413	2020-08-24 11:55:35	2020-08-24	Sharon Quigley	sharon.quigley@woohoo.com	Omaha	Nebraska	869981096398386052	66294b2597ed3ced02c5739a5eeeec95	American Express	41.2396616250421886	-96.0775424570892085
47414	2020-08-24 12:01:05	2020-08-24	Dr. Alf Kub II	dr.alf.kub.ii@warmmail.com	Boston	Massachusetts	4577328132219	8056f3ff6dde80be7a1673a4e4cf6fcb	Discover	42.2427961644884178	-71.0873847304794992
47415	2020-08-24 12:17:48	2020-08-24	Linus Rutherford	linus.rutherford@geemail.com	San Francisco	California	869915110182369181	446cda871156ca3e7bc3db261ec882a5	VISA 16 digit	37.7802416398992662	-122.391741358379008
47416	2020-08-24 12:26:15	2020-08-24	Kathy Rempel DDS	kathy.rempel.dds@geemail.com	Las Vegas	Nevada	3528249581843121187	376da99cb253d397476c69f72bf1e6e3	JCB 15 digit	36.2073962210778149	-115.274101315133635
47417	2020-08-24 12:38:39	2020-08-24	Dr. Maximo Volkman	dr.maximo.volkman@geemail.com	Joliet	Illinois	869944292461134992	9ea255bac092347bfc6961758143b5aa	Voyager	41.5377149041134857	-88.1344425595935377
47418	2020-08-24 12:38:49	2020-08-24	Domingo Boyle	domingo.boyle@geemail.com	Philadelphia	Pennsylvania	6011947798301916586	d0c8fbc2848fe4300298b310e01bafd5	Voyager	40.0140340976841742	-75.177413560393461
47419	2020-08-24 12:41:14	2020-08-24	Curt Sauer	curt.sauer@geemail.com	San Francisco	California	210018432854142945	bf1282390092afbd6a112c4de2ed69ce	Diners Club / Carte Blanche	37.7775538208442896	-122.42815498542673
47420	2020-08-24 12:48:11	2020-08-24	Elvina Reinger-Oberbrunner	elvina.reinger.oberbrunner@geemail.com	Los Angeles	California	589315004105340	4f00894b09708b5d69b19e6b13a014cf	Mastercard	34.0361371422052343	-118.368701453832159
47421	2020-08-24 12:53:33	2020-08-24	Russ Simonis	russ.simonis@geemail.com	Washington	District of Columbia	51934682897071177	2fd1115776b274c3d6165656008b0c0c	Maestro	38.8170561976529669	-77.0489789942491825
47422	2020-08-24 13:01:05	2020-08-24	Michal Rice	michal.rice@geemail.com	Salinas	California	55483533859693604	3799b867a2c531d1dd37bd75fca1ab11	VISA 16 digit	36.662174268183108	-121.560359392705195
47423	2020-08-24 13:05:35	2020-08-24	Regis Schulist	regis.schulist@geemail.com	San Jose	California	3337143476193646643	04c8e713780fecf4d4af2f329881da65	Maestro	37.2013118649188428	-121.747116819604855
47424	2020-08-24 13:07:52	2020-08-24	Mykel Ortiz-Bauch	mykel.ortiz.bauch@geemail.com	Los Angeles	California	869903699352163410	016d69f10f190d78e6cb5ad882f4e3b1	JCB 15 digit	33.9636943801172038	-118.458752434793112
47425	2020-08-24 13:24:50	2020-08-24	Gardner King	gardner.king@geemail.com	San Jose	California	503890128029999	5aa0b5ce634223a3621462f0d64fa608	Diners Club / Carte Blanche	37.3900190138544914	-121.859253421168404
47426	2020-08-24 13:29:36	2020-08-24	Lessie Harvey	lessie.harvey@geemail.com	San Francisco	California	3042337596808307	d1d9d650f52f8b1aa82a09dbbf06735a	Diners Club / Carte Blanche	37.7595321058226716	-122.424841190427315
47427	2020-08-24 13:42:39	2020-08-24	Isam Thompson	isam.thompson@geemail.com	San Francisco	California	4276620009759	038a293d2e6c5399c57f290b64e4599a	Discover	37.7830353709804001	-122.432610381011131
47428	2020-08-24 13:42:49	2020-08-24	Mr. Zayden Swaniawski PhD	mr.zayden.swaniawski.phd@geemail.com	New York	New York	6011882459895505197	f039e7057af4a5e5426d0db4580bc724	Mastercard	40.6559570009577982	-73.8629707603145391
47429	2020-08-24 13:44:48	2020-08-24	Dabney Prohaska	dabney.prohaska@warmmail.com	Chicago	Illinois	3010345087983762	3266eedea47e9294e045707157720e7a	JCB 16 digit	41.864607625345144	-87.769152200131856
47430	2020-08-24 13:45:28	2020-08-24	Jeanette Prohaska DVM	jeanette.prohaska.dvm@geemail.com	Raleigh	North Carolina	210099866137622011	b72296205fa7267380cc9c9b36ff9637	Mastercard	35.8960784851707473	-78.5744583157759138
47431	2020-08-24 13:47:06	2020-08-24	Lilliana Jaskolski	lilliana.jaskolski@geemail.com	Berkeley	California	55495629201062104	1345c472bc0e18f0b93f7a64dc2ce503	JCB 16 digit	37.8436366040088927	-122.284913752627972
47432	2020-08-24 14:10:51	2020-08-24	Dr. Lizeth Rosenbaum	dr.lizeth.rosenbaum@geemail.com	McAllen	Texas	6011191725893657008	5c5b1632aa3a3e6b566fca1baca69e15	JCB 15 digit	26.1658099365260455	-98.240388342396912
47433	2020-08-24 14:10:53	2020-08-24	Triston Williamson	triston.williamson@woohoo.com	Joliet	Illinois	869959005121700552	12f1c2df1f553735b0a3e1606ddcd1c2	VISA 13 digit	41.5095650060892112	-88.168552264954144
47434	2020-08-24 14:14:59	2020-08-24	Lizbeth Romaguera	lizbeth.romaguera@geemail.com	Denton	Texas	3088088031862824380	ca4012aa17ef84416090f5eb7d7b9d91	JCB 15 digit	33.3085354985933719	-97.1003119305834161
47435	2020-08-24 14:47:21	2020-08-24	Cher Erdman	cher.erdman@geemail.com	New York	New York	3796719460072432	e70ef24ea3279798f9ad98935505a2ae	American Express	40.5947332972884141	-73.9264547679468933
47436	2020-08-24 15:12:02	2020-08-24	Jacques Boehm	jacques.boehm@geemail.com	San Francisco	California	180082941992457396	4b4588e7521081778d6305d01c3b5bc4	JCB 16 digit	37.7295321051512715	-122.44867419201745
47437	2020-08-24 15:17:50	2020-08-24	Fabiola Heaney	fabiola.heaney@geemail.com	Corona	California	3025131535159923	a1a836313593153525f70133e57502a3	Discover	33.9510832149423649	-117.62807203575224
47438	2020-08-24 15:20:51	2020-08-24	Dr. Leah Fadel DDS	dr.leah.fadel.dds@woohoo.com	Kansas City	Missouri	3733654179689273	41f9408b6a60c883767d61784ce10e59	VISA 13 digit	39.1836324088111567	-94.5723757195510046
47439	2020-08-24 15:40:24	2020-08-24	Ms. Albertha West	ms.albertha.west@geemail.com	Chandler	Arizona	3112153861128032968	bc42cfb4d684a9039c6f2eef852bea13	JCB 15 digit	33.2245830736212397	-111.766653056803719
47440	2020-08-24 15:45:23	2020-08-24	Darrien Brekke	darrien.brekke@geemail.com	Kenosha	Wisconsin	675995939850087	d5fb3f80b9d8141b9b46ee95b22166ad	JCB 16 digit	42.5335386163394915	-87.9372168576572193
47441	2020-08-24 15:49:59	2020-08-24	Brice Lehner	brice.lehner@geemail.com	Dayton	Ohio	869907597540482351	de69884955f5f69becb17a0fe81157f2	Mastercard	39.7312321528118133	-84.2086381870511929
47442	2020-08-24 15:53:16	2020-08-24	Ica Weissnat	ica.weissnat@warmmail.com	San Antonio	Texas	4664468406483897	7e70a62847c4855b714119640e3236ac	Mastercard	29.5292666179664423	-98.4446559707470215
47443	2020-08-24 15:58:59	2020-08-24	Adlai Collier	adlai.collier@geemail.com	Riverside	California	3088343572474918251	4e768d44afde3a191c829115cabe728a	JCB 15 digit	33.8890647774510043	-117.450237928467615
47444	2020-08-24 15:59:27	2020-08-24	Mr. Alberto Gorczany II	mr.alberto.gorczany.ii@geemail.com	Oakland	California	53436508487503829	af991fa55423b6711da112b5932e5bc8	American Express	37.7682225172017212	-122.264666194535195
47445	2020-08-24 16:19:54	2020-08-24	Mr. Orson Ratke MD	mr.orson.ratke.md@woohoo.com	New York	New York	4199096426713	aa2232ed3fed5848ae7fb8013f63a422	VISA 16 digit	40.6441650178041272	-73.9969048418931692
47446	2020-08-24 16:23:38	2020-08-24	Ms. Alyce Hirthe	ms.alyce.hirthe@woohoo.com	New York	New York	6011913958626070200	6ae6a4f81e45673fb95fe63be80c1db8	Mastercard	40.7355279484987278	-73.907192964981121
47447	2020-08-24 16:25:53	2020-08-24	Dr. Rutherford DuBuque II	dr.rutherford.dubuque.ii@geemail.com	Lowell	Massachusetts	4114463753129199	dc2ae8161f387851af0c0462edf660f5	Voyager	42.5553189069833664	-71.3943406261377049
47448	2020-08-24 16:39:14	2020-08-24	Hubbard Ankunding	hubbard.ankunding@warmmail.com	Tulsa	Oklahoma	51839272860725490	856a2b7a50d9047dffc6b712a9ad6950	Voyager	36.0989805730894204	-95.8743848358236193
47449	2020-08-24 16:46:11	2020-08-24	Frida Sporer	frida.sporer@geemail.com	Chicago	Illinois	3748803447458481	0e4a6d54868cfe3052bbe4d2b5734ae1	VISA 13 digit	41.8075777609668719	-87.594616538102926
47450	2020-08-24 16:48:09	2020-08-24	Mr. Margarito Bergnaum MD	mr.margarito.bergnaum.md@woohoo.com	Fayetteville	North Carolina	55556776737061641	35f7bc81178220d4bb0368a4105b2db1	JCB 16 digit	34.9874638317871813	-79.002267639258875
47451	2020-08-24 16:49:55	2020-08-24	Mr. Kristoffer Legros	mr.kristoffer.legros@geemail.com	San Francisco	California	51046543641945667	f8b46d818b6976afa8f1ceff7b98dbeb	JCB 16 digit	37.7587574116811808	-122.440031831625845
47452	2020-08-24 16:54:34	2020-08-24	Averi Schuster	averi.schuster@geemail.com	Anaheim	California	3052765493271015	5ab9fa902b36fcac92bbc6ed3d672a4f	Maestro	33.8091330773495145	-117.75036770326308
47453	2020-08-24 16:55:04	2020-08-24	Coolidge Nader	coolidge.nader@geemail.com	Berkeley	California	4018354058024226	4a75b0b57892865f7eee5ecd99409c00	American Express	37.8688546464636104	-122.259016124576561
47454	2020-08-24 17:05:48	2020-08-24	Shayna Murazik	shayna.murazik@geemail.com	Hillsboro	Oregon	4485572459617918	275a4262642a758318673bad6bc619b2	Discover	45.5602591547388585	-123.01974569299891
47455	2020-08-24 17:11:36	2020-08-24	Kerry Ortiz	kerry.ortiz@geemail.com	Hialeah	Florida	3000969629181591	38dcdcab499fcc8abea7aff6afdd60e8	JCB 16 digit	25.9047180592060116	-80.3823113989453759
47456	2020-08-24 17:14:04	2020-08-24	Lurline Beier DDS	lurline.beier.dds@geemail.com	Wilmington	North Carolina	869909073265401156	0ad8c0f7a99029194ffbbc35b71c7a80	JCB 15 digit	34.1653564058065413	-77.8771467453327091
47457	2020-08-24 17:17:39	2020-08-24	Dr. Destry Pfeffer	dr.destry.pfeffer@geemail.com	Philadelphia	Pennsylvania	869917083062235533	2ef96fec29bf0d16db3bfc881a02dfd2	JCB 15 digit	39.9779890690423514	-75.2310397558745052
47458	2020-08-24 17:19:41	2020-08-24	Alla Schumm	alla.schumm@geemail.com	Raleigh	North Carolina	3528235091612278727	f0bb5e0b7f9877a22399424ab5a3151b	JCB 15 digit	35.8437645132321805	-78.5577468366764577
47459	2020-08-24 17:32:50	2020-08-24	Richard Bartell	richard.bartell@warmmail.com	Pompano Beach	Florida	4207838666261767	41155c2f3546a76ad3f807d3dd4471f8	VISA 16 digit	26.2205978628978116	-80.1244778514221281
47460	2020-08-24 17:47:02	2020-08-24	Karley DuBuque DDS	karley.dubuque.dds@geemail.com	Chesapeake	Virginia	3088732308974443683	395df9985fd6d094e8a5ca0fe0ac211c	Discover	36.7200558587215866	-76.2870969852741752
47461	2020-08-24 18:02:48	2020-08-24	Mindi Daugherty	mindi.daugherty@woohoo.com	New York	New York	3744148666494765	114b0c04e9bb4a5a9209e3a615a7f5f1	American Express	40.6080774030871652	-74.0113318934000972
47462	2020-08-24 18:04:31	2020-08-24	Emery Witting-Schumm	emery.witting.schumm@geemail.com	San Francisco	California	4079692933680530	08663caae11290d37e0171d073132f48	VISA 13 digit	37.7549749388361633	-122.442330940142654
47463	2020-08-24 18:20:36	2020-08-24	Miss Gene Wisozk	miss.gene.wisozk@geemail.com	Detroit	Michigan	52242696849360139	d41dfdfb22b4caa180161434694337a2	Discover	42.4312308829203246	-83.035944404697787
47464	2020-08-24 18:28:36	2020-08-24	Mordechai Gleason	mordechai.gleason@geemail.com	Murrieta	California	180034107574725928	d89b8525c3c23e647a1f30fed4d91a86	Voyager	33.5960261977374515	-117.091446338910231
47465	2020-08-24 18:30:23	2020-08-24	Mr. Tandy Dare	mr.tandy.dare@woohoo.com	San Jose	California	4915098732299	e04f65b70634ea047fed9a3fdac11ab9	VISA 16 digit	37.3617153284892467	-121.916716916508605
47466	2020-08-24 18:31:56	2020-08-24	Case Aufderhar	case.aufderhar@geemail.com	San Jose	California	210019881383943950	917cce897d538f09174db3079fd745b2	Diners Club / Carte Blanche	37.2229586037162719	-121.738339844600858
47467	2020-08-24 18:32:09	2020-08-24	Lelar Torp	lelar.torp@warmmail.com	Lexington	Kentucky	3438576650969822	f3b140fd2e906740214002fe70b434a4	JCB 15 digit	38.1406033602420251	-84.4027877821486356
47468	2020-08-24 18:32:19	2020-08-24	Ms. Lisette Schroeder	ms.lisette.schroeder@geemail.com	San Antonio	Texas	6011913905851493243	79c44df6ef10bd39ec92d34129caf8f4	Maestro	29.4437288278784592	-98.5745862155988704
47469	2020-08-24 18:42:01	2020-08-24	Rich Mraz	rich.mraz@geemail.com	Aurora	Illinois	869921328401715040	7e6c103cb83d1cd75dc806dca68a5884	Mastercard	41.6859221504759034	-88.3054709935955628
47470	2020-08-24 19:01:09	2020-08-24	Terri Bartell	terri.bartell@geemail.com	Springfield	Massachusetts	4408837846853698	7763121a14d9ceb93ebd30e4a3f7ed6a	JCB 16 digit	42.103013832421972	-72.5920226444117844
47471	2020-08-24 19:05:01	2020-08-24	Dr. Keeley Gerlach PhD	dr.keeley.gerlach.phd@geemail.com	Lafayette	Louisiana	6011611110822981161	3521190a11dc30c8b6a306101d88234c	JCB 16 digit	30.1761427475582806	-92.1256266190986963
47472	2020-08-24 19:05:47	2020-08-24	Juluis Schaden-Barrows	juluis.schaden.barrows@warmmail.com	Jurupa Valley	California	6011996299053223024	b0cceff6505e2891bf7c00e054884ade	VISA 16 digit	33.9062382695660034	-117.445311850591011
47473	2020-08-24 19:11:57	2020-08-24	Dr. Rollo Rippin	dr.rollo.rippin@woohoo.com	Omaha	Nebraska	3096114738157626019	458b0df179e0858789527f40cd40555f	Mastercard	41.2227506558556129	-95.9900635990895381
47474	2020-08-24 19:44:50	2020-08-24	Mr. Boris Zieme III	mr.boris.zieme.iii@geemail.com	San Francisco	California	3438452606329091	4b26174e6191e3389f07a0a7036c69b8	JCB 16 digit	37.7968307711851352	-122.426301042636538
47475	2020-08-24 20:00:08	2020-08-24	Claudio Koelpin	claudio.koelpin@geemail.com	New York	New York	4183857081810337	6fe0342a47be002f3596869a90434ce8	JCB 16 digit	40.635996000630783	-73.8879894904222283
47476	2020-08-24 20:14:26	2020-08-24	Deirdre Morissette	deirdre.morissette@geemail.com	Providence	Rhode Island	4455028810774480	8841db0357dadacd7ebb31a52d362511	Discover	41.7432187537051718	-71.5075476289179193
47477	2020-08-24 20:17:02	2020-08-24	Dr. Randell VonRueden	dr.randell.vonrueden@geemail.com	Lubbock	Texas	4829705746248	3ff27c58961591a1cabad9ef934f1216	JCB 16 digit	33.5374487283214933	-101.864219667055465
47478	2020-08-24 20:28:23	2020-08-24	Atticus Funk	atticus.funk@geemail.com	Chula Vista	California	4779334618258323	30cd67bda22eed5d1d5c6cd187545283	VISA 16 digit	32.7096863225333365	-117.075416421633946
47479	2020-08-24 20:41:25	2020-08-24	Mabel Gutmann PhD	mabel.gutmann.phd@warmmail.com	Renton	Washington	3112008756909443649	a733450cf283d60f5ff59dbc196b22a7	VISA 16 digit	47.4966706960987324	-122.197112146399903
47480	2020-08-24 20:51:21	2020-08-24	Orlin Willms	orlin.willms@geemail.com	North Las Vegas	Nevada	210035405394082622	75fb0cfc0f514bdf24ec802453d46d4a	Mastercard	36.2651249927159398	-115.080584551928197
47481	2020-08-24 20:51:35	2020-08-24	Estevan Harvey	estevan.harvey@geemail.com	Long Beach	California	180024113082703938	8870fd33997601413fb7bf4a501d3cc0	VISA 16 digit	33.7271131324868634	-118.131956131492927
47482	2020-08-24 20:52:45	2020-08-24	Ricci Armstrong	ricci.armstrong@geemail.com	Buffalo	New York	3528070536381361441	1215f52666574a718900a13e1dc3c1b2	JCB 16 digit	42.9067043776344477	-78.7768472224872625
47483	2020-08-24 20:57:28	2020-08-24	Lindsay Rolfson I	lindsay.rolfson.i@geemail.com	Albuquerque	New Mexico	4149278063365559	515daf86c7c167d973d1d359afcae299	Mastercard	35.1699419240135711	-106.689544444258885
47484	2020-08-24 21:03:39	2020-08-24	Mr. Ephraim Hand II	mr.ephraim.hand.ii@geemail.com	Fort Wayne	Indiana	51510019304100343	b8dfb506fd734745cbd88ab95f46597a	Diners Club / Carte Blanche	41.0146822932425863	-85.0882665278144259
47485	2020-08-24 21:17:27	2020-08-24	Damian Spinka	damian.spinka@geemail.com	Orange	California	6011442894153990009	048be34a4e023b9da0cf64e96272c63a	VISA 16 digit	33.8740364562142631	-117.85788862943761
47486	2020-08-24 21:17:40	2020-08-24	Dr. Karina Boehm DDS	dr.karina.boehm.dds@geemail.com	Virginia Beach	Virginia	3058650016827036	69b61b137a056a4c283a19e583da0ef3	Diners Club / Carte Blanche	36.8671770107653032	-75.9575612704407348
47487	2020-08-24 21:19:17	2020-08-24	Jennie Greenholt MD	jennie.greenholt.md@geemail.com	Detroit	Michigan	6011361558666354485	811f7ed72f14319f00b6bed167eaae26	JCB 15 digit	42.4132471756469513	-83.0849529246918763
47488	2020-08-24 21:19:42	2020-08-24	Anthony Gleichner	anthony.gleichner@geemail.com	San Francisco	California	675905598098621	479c386f6dda503f6ee2f75a11c28cf1	VISA 13 digit	37.7854930709743329	-122.449096940507985
47489	2020-08-24 21:33:36	2020-08-24	Sherwood Haag	sherwood.haag@woohoo.com	Berkeley	California	3528644909133197263	b5ca50e601a30572fc504efa129a6efa	JCB 16 digit	37.8799176102032291	-122.280761730102881
47490	2020-08-24 21:38:34	2020-08-24	Magan Torp	magan.torp@geemail.com	Pueblo	Colorado	3430483215786254	633b18b5cbe6c7aee96b7e864fafef9a	Maestro	38.3038647102635323	-104.63168421437517
47491	2020-08-24 21:49:27	2020-08-24	Mrs. Ethie Lemke	mrs.ethie.lemke@geemail.com	Tacoma	Washington	869963571991805924	26e8f0ff204122be64bbdd6b5ec52a5e	VISA 13 digit	47.2181754438791472	-122.4420485906072
47492	2020-08-24 21:50:52	2020-08-24	Dr. Nikolas Ondricka II	dr.nikolas.ondricka.ii@woohoo.com	New Orleans	Louisiana	3054246398239843	4dd8d5352f10e37207ab99774b7d0d35	American Express	30.0770558301839976	-89.9601921445950836
47493	2020-08-24 21:53:05	2020-08-24	Nelson Jones	nelson.jones@geemail.com	Fort Wayne	Indiana	3088548710864183788	99c4a5548cfb181585aabf9f7251d517	JCB 15 digit	41.0140131156209833	-85.1325707514058792
47494	2020-08-24 21:54:29	2020-08-24	Dr. Leonard Rolfson MD	dr.leonard.rolfson.md@geemail.com	Elk Grove	California	4965200116143479	3217be9d5c26c654b551098952a65a71	Mastercard	38.4346463302433463	-121.469545136895036
47495	2020-08-24 21:58:18	2020-08-24	Ms. Kasie Halvorson	ms.kasie.halvorson@geemail.com	Grand Rapids	Michigan	51658427979443603	bd60ec2222906d18b842dd9867c4f722	JCB 16 digit	42.9287488410051878	-85.744519176394121
47496	2020-08-24 21:59:38	2020-08-24	Shelbi Kassulke MD	shelbi.kassulke.md@geemail.com	Ontario	California	3096504982848936688	89e7c460abdb17f10320ba10db49bba1	JCB 16 digit	34.0427037852030239	-117.556464255099002
47497	2020-08-24 22:03:59	2020-08-24	Ivan McGlynn	ivan.mcglynn@geemail.com	New York	New York	3528706177011246694	1d34d19d886e24e7648c141ebbdd3bca	JCB 16 digit	40.7215635939724763	-73.9793095309183002
47498	2020-08-24 22:31:52	2020-08-24	Maynard Legros	maynard.legros@geemail.com	Milwaukee	Wisconsin	210024295815426042	007297318ff56aec1e445dacdc095bb3	Maestro	43.0516102428168068	-88.0439496168967395
47499	2020-08-24 22:34:47	2020-08-24	Maud Bogisich	maud.bogisich@geemail.com	Paterson	New Jersey	3112781181366983933	4a2c16215acba427999bd2d77fd7819a	JCB 16 digit	40.887737810933217	-74.2422551441911622
47500	2020-08-24 22:37:02	2020-08-24	Belva Carter	belva.carter@warmmail.com	Berkeley	California	4948881397497064	a3e572378a18c168704e2826848556d4	JCB 16 digit	37.8621084115195856	-122.257929498475363
47501	2020-08-24 22:41:16	2020-08-24	Mr. Milton Bogisich MD	mr.milton.bogisich.md@geemail.com	Anaheim	California	869964695937303287	bf6140fcdde31cc43ca92bd057c039e5	VISA 16 digit	33.7855144701264791	-117.775224435303727
47502	2020-08-24 22:43:42	2020-08-24	Jamar Cormier	jamar.cormier@geemail.com	Victorville	California	180000033374187426	2c4d3ec6004e698ccf75885c57c46140	Mastercard	34.4836891932643965	-117.397981195353339
47503	2020-08-24 22:55:38	2020-08-24	Mr. Clifford Stehr	mr.clifford.stehr@woohoo.com	Inglewood	California	3096537579632572595	e471165882c79b7d1b72e07ed6c34526	Mastercard	33.9362610784139491	-118.435640658348063
47504	2020-08-24 23:06:37	2020-08-24	Ardyce Jenkins DDS	ardyce.jenkins.dds@geemail.com	Baton Rouge	Louisiana	4225445719258	fb672e61b964c6a4d9883ec93d332c0f	Voyager	30.3530687481842918	-91.071613079413396
47505	2020-08-24 23:14:38	2020-08-24	Avery Reichert	avery.reichert@geemail.com	Glendale	Arizona	4153567672024	a2334a1076d2214f0dec32e2f7a571bf	American Express	33.5563064116280501	-112.098791208888954
47506	2020-08-24 23:22:14	2020-08-24	Yvonne Smitham	yvonne.smitham@geemail.com	Allen	Texas	6011524556603396241	2e94a46c367536470e007af50982d94b	American Express	33.1417086946804034	-96.721227940539265
47507	2020-08-24 23:29:41	2020-08-24	Coen Kihn Sr.	coen.kihn.sr.@geemail.com	Santa Clara	California	869907685664582476	1aa7efc4216bd7ea839431c0d28a043d	Discover	37.3103802657037988	-121.902453958894682
47508	2020-08-24 23:30:33	2020-08-24	Florentino Waters	florentino.waters@geemail.com	Los Angeles	California	210020338656931946	e42a65533f825b49f325e039772d82e5	Maestro	34.0307280334509912	-118.388195983552549
47509	2020-08-24 23:31:02	2020-08-24	Jax Schinner I	jax.schinner.i@geemail.com	Los Angeles	California	3054364911363063	adb55f1c5b423c41fbf4a9d347eb5807	VISA 13 digit	33.9591944252472331	-118.417756465821711
47510	2020-08-24 23:35:52	2020-08-24	Elayne Skiles MD	elayne.skiles.md@geemail.com	Miramar	Florida	55640557295855832	0213ad6292752567529756626111071a	Voyager	26.0119815451074388	-80.3493764626786202
47511	2020-08-24 23:41:10	2020-08-24	Brenton Herzog	brenton.herzog@woohoo.com	Warren	Michigan	4350206550480817	5b47e44f4278f7220a83e1e32a740c8c	American Express	42.5008869711771595	-82.9500104589387774
47512	2020-08-24 23:45:20	2020-08-24	Stephenie Grant	stephenie.grant@geemail.com	Indianapolis	Indiana	3528544525028522000	ed592c5b05029fd8872c5561b7920da5	Voyager	39.8212069618988735	-86.0516276336010577
47513	2020-08-24 23:49:47	2020-08-24	Tyesha Braun	tyesha.braun@geemail.com	Murfreesboro	Tennessee	4440306001982601	44609e09efb7cfaaf39a27203af82a5f	Voyager	35.8452033626500537	-86.4136425536908206
47514	2020-08-25 00:03:44	2020-08-25	Green Shanahan	green.shanahan@geemail.com	San Bernardino	California	3528448819992551096	0730b0607160cd5226a81993f25b6b03	VISA 13 digit	34.1745862643964529	-117.348899976887182
47515	2020-08-25 00:10:08	2020-08-25	Babette Schiller	babette.schiller@woohoo.com	Miami	Florida	53753081044435930	f63a112da953008bb2a1babc8507985d	JCB 15 digit	25.8272491275936389	-80.1984890804499457
47516	2020-08-25 00:14:41	2020-08-25	Margarete McClure-Gibson	margarete.mcclure.gibson@geemail.com	Sunnyvale	California	676281460070386	2d59e0389d34aef8ae7835d8d6dc972e	American Express	37.3002072070252169	-121.986493310491753
47517	2020-08-25 00:22:44	2020-08-25	Miss Noreta Wiegand MD	miss.noreta.wiegand.md@geemail.com	Omaha	Nebraska	502054938443659	0c8d6c18b5a1949ce5a2362d3a7f35a8	JCB 16 digit	41.3107398090098101	-96.1386520450584641
47518	2020-08-25 00:24:01	2020-08-25	Dr. Stacy D'Amore	dr.stacy.d'amore@geemail.com	Pueblo	Colorado	4250699500843335	e529f965f96abb4ef3266b26159bdc44	Mastercard	38.2923824131000785	-104.549431967954348
47519	2020-08-25 00:25:31	2020-08-25	Ceola Bruen	ceola.bruen@woohoo.com	Las Vegas	Nevada	6011672121420870694	b6a38c798960732e7a3a415badc9a4b7	Diners Club / Carte Blanche	36.1581208384230735	-115.161615613449726
47520	2020-08-25 00:28:12	2020-08-25	Ricki Becker	ricki.becker@warmmail.com	New York	New York	3088408286740081040	ae922a4c57302dbeaa8c475fce127d2e	Voyager	40.6260445995014123	-73.8556788759201766
47521	2020-08-25 00:28:29	2020-08-25	Aaron Feest	aaron.feest@geemail.com	Denver	Colorado	4280297627753141	12d94c4b5847ac8a601517ff33a7da04	JCB 16 digit	39.7219482243113191	-104.905553528225425
47522	2020-08-25 00:30:12	2020-08-25	Laurel Tromp	laurel.tromp@geemail.com	Tulsa	Oklahoma	6011762396575624879	62247522f4b70b016f86e00f110cf0cf	VISA 16 digit	36.102297757695986	-95.8252449257720258
47523	2020-08-25 00:36:50	2020-08-25	Heather Heller	heather.heller@geemail.com	Saint Paul	Minnesota	3096321859269401536	fa8b5bbbeda7acb484c9a9a5a21773f9	American Express	44.8604885729901497	-93.0960913654215716
47524	2020-08-25 00:42:30	2020-08-25	Leone Gaylord DDS	leone.gaylord.dds@woohoo.com	San Francisco	California	869967039931767030	efbee5e373f7a943c1df504d15e37d8b	JCB 16 digit	37.7700500136840986	-122.452894342562843
47525	2020-08-25 00:46:38	2020-08-25	Cherish Zemlak	cherish.zemlak@woohoo.com	El Paso	Texas	3417446359083231	1fb72e726147b01275f30246f51423eb	Discover	31.8406318155877308	-106.3510618377924
47526	2020-08-25 00:50:36	2020-08-25	Patsy Purdy	patsy.purdy@warmmail.com	San Francisco	California	6011780950224764409	f28855411210cf65b95b2bb30ee07a44	JCB 15 digit	37.7722256176149145	-122.461572805050238
47527	2020-08-25 00:57:51	2020-08-25	Simon Lindgren I	simon.lindgren.i@woohoo.com	Fullerton	California	3013450562246417	48ad98e0a3a8bc2b0af3daf6f865a690	Mastercard	33.9537448515340685	-117.893561568038535
47528	2020-08-25 01:14:21	2020-08-25	Mckinley Harber-Connelly	mckinley.harber.connelly@geemail.com	Milwaukee	Wisconsin	3040055405929484	2d24beb2aafb647eebbe320285a1137a	American Express	42.9692500569943334	-87.869531555623567
47529	2020-08-25 01:15:40	2020-08-25	Darry Nolan	darry.nolan@geemail.com	Hollywood	Florida	180085168517512672	f32a53ad9361ce5e5c0aaba1e355a086	JCB 16 digit	26.0373273477368059	-80.1553461459282772
47530	2020-08-25 01:16:12	2020-08-25	Shayne Cummerata	shayne.cummerata@warmmail.com	Phoenix	Arizona	3488459481290792	e22d804404c445afe1313a058978c65e	JCB 16 digit	33.5987092009678534	-112.179137711825234
47531	2020-08-25 01:17:04	2020-08-25	Elena O'Reilly	elena.o'reilly@geemail.com	Houston	Texas	3002336349366258	6136def3611463139ff718f1fa6af2d9	Voyager	29.7472083838269121	-95.3711094388287535
47532	2020-08-25 01:19:45	2020-08-25	Dr. Missouri Mann	dr.missouri.mann@woohoo.com	New York	New York	4945453579456	73ba7bff7f0b76a78a62e4c587797341	American Express	40.7230666275825328	-74.0178484408080521
47533	2020-08-25 01:27:22	2020-08-25	Maurice Prosacco	maurice.prosacco@geemail.com	McKinney	Texas	4764943524379952	f2def266fc3a22a16ea733909e65f1bd	Discover	33.1343744405210074	-96.7045226896479733
47534	2020-08-25 01:40:21	2020-08-25	Braiden Glover Sr.	braiden.glover.sr.@geemail.com	Port St. Lucie	Florida	676357594194219	fb54a5deb2b2d7128406e194f331bf75	Maestro	27.241481161876024	-80.3115708618044835
47535	2020-08-25 01:45:45	2020-08-25	Mr. Otto Bogisich	mr.otto.bogisich@woohoo.com	Fresno	California	060452896529279	e8cb0c613b78d1dd661ddc1259545394	JCB 15 digit	36.8057330813132211	-119.759125212218251
47536	2020-08-25 01:45:47	2020-08-25	Harvie Waelchi	harvie.waelchi@warmmail.com	Virginia Beach	Virginia	4234910699814487	bb96e89ae4cb65caf4a9a8715a0ef66e	Discover	36.7698400528356473	-75.9778256639510374
47537	2020-08-25 01:50:30	2020-08-25	Candace Kilback	candace.kilback@warmmail.com	New York	New York	502052035859504	39256e5a0a5970e10a595421569533e7	Discover	40.7114339109268002	-74.0158940161473993
47538	2020-08-25 01:51:25	2020-08-25	Karie Parisian	karie.parisian@geemail.com	New York	New York	3437086000377933	fa4ae5ad1dc41d3a98eb53702ea6ee87	Diners Club / Carte Blanche	40.6224302748441701	-73.870481016336754
47539	2020-08-25 01:51:43	2020-08-25	Ms. Ardis Wilderman DVM	ms.ardis.wilderman.dvm@geemail.com	Memphis	Tennessee	210018790060145261	72fa6bea54a137163c053762d241ad81	JCB 15 digit	35.0701654629848889	-89.9428095593374195
47540	2020-08-25 02:00:06	2020-08-25	Garey Davis	garey.davis@warmmail.com	Saint Paul	Minnesota	3112804792456549864	ebac3b9e2abdcfcd0aaab17d18499580	VISA 16 digit	44.8692153102193032	-93.0262676795743459
47541	2020-08-25 02:01:27	2020-08-25	Jeramy Purdy	jeramy.purdy@warmmail.com	Mesquite	Texas	6011574286189224463	cbe71bdf4333ab4cfb5e00ba6eff01b0	Maestro	32.7637779364638035	-96.5560346948180381
47542	2020-08-25 02:02:59	2020-08-25	Leota Dickinson-Rolfson	leota.dickinson.rolfson@geemail.com	Greensboro	North Carolina	060413871964121	cabaaf04e2fb164c211dddfdf6f39fc6	Discover	36.0566791728720091	-79.8648748640418091
47543	2020-08-25 02:06:55	2020-08-25	Eugenia Dickinson	eugenia.dickinson@geemail.com	Springfield	Massachusetts	6011517281418178044	c23df6286b03e2037f97664ed9739cb7	VISA 16 digit	42.1663057733066324	-72.5399812059570195
47544	2020-08-25 02:10:27	2020-08-25	Kiana Schmeler	kiana.schmeler@woohoo.com	Omaha	Nebraska	4176490683405246	ac9b571ddf5b34617a5e2d4bc239e2d2	American Express	41.1857693659286994	-96.1014876485452163
47545	2020-08-25 02:15:19	2020-08-25	Brittni Russel	brittni.russel@warmmail.com	Warren	Michigan	3088103192440348887	b3f71f8bd87858ab19b6056a7479539d	Maestro	42.4100715387608815	-82.9947212151717508
47546	2020-08-25 02:25:44	2020-08-25	Aurthur Nikolaus	aurthur.nikolaus@geemail.com	Sunnyvale	California	4354092439801696	e9d36047123d44bdbda02365e290e1cc	VISA 16 digit	37.3742866109583574	-122.004534847774735
47547	2020-08-25 02:37:12	2020-08-25	Exa Mayer	exa.mayer@geemail.com	San Francisco	California	869993643943295134	a3257b93f99b314c30206c42a42f64ea	Maestro	37.785418776203386	-122.425779217016625
47548	2020-08-25 02:41:56	2020-08-25	Dr. Reynolds Bauch	dr.reynolds.bauch@geemail.com	Dayton	Ohio	54920924578180315	cd883135a1bbccb1c6ec4f3a7a43f610	JCB 16 digit	39.7946754519153387	-84.1229771437313474
47549	2020-08-25 02:42:01	2020-08-25	Nichelle McLaughlin	nichelle.mclaughlin@woohoo.com	Berkeley	California	3158012159159871953	70b7979d820397e462b033e643e6b46a	VISA 16 digit	37.8526545994605712	-122.247660253414097
47550	2020-08-25 02:46:18	2020-08-25	Tyrone Volkman	tyrone.volkman@woohoo.com	Sterling Heights	Michigan	6011953936618074837	78a0c583aab07c51b98845e0c9aa77b8	Maestro	42.5841697349760722	-83.0082231785330862
47551	2020-08-25 02:51:58	2020-08-25	Merrill Hoeger-Runte	merrill.hoeger.runte@geemail.com	Oakland	California	6011288295455471382	1b73296b6e45cbb1ef8e788bb7cf5938	VISA 16 digit	37.8072751038913566	-122.261805343352478
47552	2020-08-25 02:54:12	2020-08-25	Bartholomew Hessel-Abernathy	bartholomew.hessel.abernathy@geemail.com	Sacramento	California	869981642484740742	13372e66573b13d7d3769e5c92865416	VISA 16 digit	38.6510680909533093	-121.380790140504388
47553	2020-08-25 03:04:58	2020-08-25	Frankie Will	frankie.will@woohoo.com	Port St. Lucie	Florida	4124482090226482	2aef176e20efb310e67aa27e8ac77053	Maestro	27.3616426425654424	-80.3161055754955839
47554	2020-08-25 03:13:46	2020-08-25	Gayle Spinka	gayle.spinka@geemail.com	Oakland	California	4254328107795	cfc2f8745bc4cce092ba6526b5e7bb4b	Discover	37.7973060901241027	-122.2643940695433
47555	2020-08-25 03:16:58	2020-08-25	Maritza Wuckert-Gibson	maritza.wuckert.gibson@geemail.com	San Francisco	California	3096868850959558106	f42ba9cf155207d25381a2930cefccd8	Discover	37.7714886836859876	-122.428780818271136
47556	2020-08-25 03:22:58	2020-08-25	Miss Essie Upton	miss.essie.upton@geemail.com	Worcester	Massachusetts	502089364473309	976e9ce8401a7f26fb3c05596a2fef39	American Express	42.3448694728016832	-71.8369787698864997
47557	2020-08-25 03:23:46	2020-08-25	Aliza Spencer-Wolf	aliza.spencer.wolf@woohoo.com	Sugar Land	Texas	3158347835941204357	ff9d5876cfda868dfc3c261983d3ffbc	American Express	29.5730848576925673	-95.5441573475029315
47558	2020-08-25 03:24:24	2020-08-25	Gaylene Hyatt-Franecki	gaylene.hyatt.franecki@woohoo.com	Greensboro	North Carolina	180079572853007296	f65ba54c4a2f472da5aef4258503bbf0	JCB 16 digit	36.0789011492509388	-79.8445490536261389
47559	2020-08-25 03:24:33	2020-08-25	Hettie Watsica	hettie.watsica@geemail.com	Saint Paul	Minnesota	4386085756203332	7e7ba05a5170c7438c8576140c252686	American Express	44.9418249321110537	-93.0621460136290608
47560	2020-08-25 03:26:23	2020-08-25	Mrs. Joyce Brakus	mrs.joyce.brakus@geemail.com	Salt Lake City	Utah	4993838001000845	27edb2241b6bd0ade41a842a1d4e870e	VISA 16 digit	40.8097679925296433	-111.88532858681306
47561	2020-08-25 03:50:59	2020-08-25	Shira Koepp	shira.koepp@geemail.com	Fremont	California	3432065032079944	fb7cd3af0590fa78298ad7aba5f0dfce	VISA 16 digit	37.4796680653635406	-121.854846191358561
47562	2020-08-25 03:52:25	2020-08-25	Mr. Ross Beahan PhD	mr.ross.beahan.phd@warmmail.com	San Francisco	California	3050050559828608	580f11d65434fae4698cf0a7b7ec8103	American Express	37.7779229837556869	-122.4139162133675
47563	2020-08-25 03:55:36	2020-08-25	Siobhan Larkin PhD	siobhan.larkin.phd@geemail.com	Pomona	California	060479440585440	fe7bd7e807f3784de2f2fc6b17e616a5	JCB 15 digit	34.0335739187467894	-117.791264590524506
47564	2020-08-25 04:23:31	2020-08-25	Sheryl Mayert	sheryl.mayert@geemail.com	Downey	California	6011737214057080746	001153cc1401cac3572f3fa8a4a64e8a	JCB 16 digit	33.8618592278350192	-118.195378416414925
47565	2020-08-25 04:27:31	2020-08-25	Danniel Wyman	danniel.wyman@geemail.com	Washington	District of Columbia	3049761288870346	16c85ab6eea9c2bcb77df9e8634f5520	Maestro	38.9545409016109971	-77.0126182355199091
47566	2020-08-25 04:29:51	2020-08-25	Mustafa Runolfsson	mustafa.runolfsson@geemail.com	Atlanta	Georgia	180051181791291756	51d06a6dfa0f984e752ec3a3dee2f6a5	Diners Club / Carte Blanche	33.8515531321797525	-84.4136915505908547
47567	2020-08-25 04:40:40	2020-08-25	Honora Gislason	honora.gislason@geemail.com	Henderson	Nevada	3053835435725706	f018e963631e7df587f8c7de5cb7b227	JCB 15 digit	35.9402749105755248	-114.937557483433565
47568	2020-08-25 04:43:20	2020-08-25	Amie Schumm MD	amie.schumm.md@geemail.com	High Point	North Carolina	676197388502870	6e48d9d8a6b34e1b199cd908f8442c53	Voyager	36.0033845938835313	-80.0519780184347098
47569	2020-08-25 04:45:16	2020-08-25	Irving Renner	irving.renner@warmmail.com	New York	New York	54575791761569804	4cb8209051f552d7f0a4402c5b064d2b	VISA 16 digit	40.6713506934456532	-73.9536237141013117
47570	2020-08-25 04:47:54	2020-08-25	Judyth Thiel	judyth.thiel@woohoo.com	Springfield	Illinois	503878360029694	c166c12ac4f572390a6c25b08ea87079	JCB 16 digit	39.7381196966081873	-89.6695209755565941
47571	2020-08-25 04:59:40	2020-08-25	Rondal Price	rondal.price@geemail.com	Phoenix	Arizona	4735865969415338	2354d3247b36f4af9648997478af55ce	Diners Club / Carte Blanche	33.6385057475816467	-112.141535183826846
47572	2020-08-25 05:13:55	2020-08-25	Jacklyn Schoen	jacklyn.schoen@woohoo.com	New York	New York	4803486559861000	33fe7dc0098d2de20d7b7a8b48588740	Voyager	40.7474468767866469	-73.8912457374751597
47573	2020-08-25 05:18:50	2020-08-25	Miss Fronnie Shanahan	miss.fronnie.shanahan@geemail.com	New York	New York	4834953878920208	adff8a21f073029fa1d05ed6e3492e74	Maestro	40.6562072982769465	-74.0323293154954882
47574	2020-08-25 05:20:27	2020-08-25	Alpheus Gislason	alpheus.gislason@warmmail.com	Pompano Beach	Florida	3057913711326162	507f46b8948c92f49d65ba96f6db5ad1	Mastercard	26.2804459289912131	-80.2273949865564617
47575	2020-08-25 05:22:42	2020-08-25	Pearlene Kirlin	pearlene.kirlin@geemail.com	Rockford	Illinois	3441675277448221	54b66d5f669ef4a2ece69873dbeb6125	Discover	42.2395157210074359	-89.0216780158508527
47576	2020-08-25 05:22:48	2020-08-25	Venita Goyette	venita.goyette@geemail.com	Columbia	Missouri	4558536424036	80658867005384060428b13fa34d3843	JCB 16 digit	38.9844825669073174	-92.2976622176409762
47577	2020-08-25 05:25:17	2020-08-25	Stephaine Shanahan	stephaine.shanahan@warmmail.com	Richmond	Virginia	3337526245336611906	3dd8c948b97506aa35701f64e17717d9	American Express	37.540803123846274	-77.5366962056830573
47578	2020-08-25 05:39:22	2020-08-25	Luverne Hilpert-Stracke	luverne.hilpert.stracke@geemail.com	Louisville	Kentucky	55805830027687935	c8adc95639a3886ddb3f55de09e30a37	JCB 16 digit	38.1783784493707117	-85.5764161413606246
47579	2020-08-25 05:39:29	2020-08-25	Kathlyn Adams	kathlyn.adams@geemail.com	Chicago	Illinois	4542166643047081	4968a5b83a268b1fc1eaf960408bc72e	Voyager	41.7910608497750005	-87.6433090429782879
47580	2020-08-25 05:40:10	2020-08-25	Jerad Rodriguez	jerad.rodriguez@woohoo.com	Memphis	Tennessee	639044958131391	52cc296ca7dac5fba2b9ef432eafaa14	Maestro	35.1474470740716924	-89.9426084987144918
47581	2020-08-25 05:40:28	2020-08-25	Nanna Hansen	nanna.hansen@warmmail.com	Naperville	Illinois	3112001379281210812	f349cf79c655e04811d03ab2605b3f4a	VISA 13 digit	41.7462424675848354	-88.1388764192238483
47582	2020-08-25 05:41:36	2020-08-25	Summer Wuckert	summer.wuckert@geemail.com	Chicago	Illinois	4329765203305	1a801ac4c10f552b4ff568b193b0b0a5	JCB 15 digit	41.9313037194147711	-87.7240507697716367
47583	2020-08-25 05:45:28	2020-08-25	Mr. Wilfrid Towne	mr.wilfrid.towne@geemail.com	Akron	Ohio	869972169136867328	d208eabb3cc69ae3b3f649a01ae2781e	Mastercard	41.1412217819429955	-81.467696008490023
47584	2020-08-25 06:02:34	2020-08-25	Hattie Kuhlman PhD	hattie.kuhlman.phd@geemail.com	Oakland	California	3158432807789025869	6fbd92ae29c99297c146bfc73adfe9c0	JCB 15 digit	37.7931056956284266	-122.271784186853708
47585	2020-08-25 06:07:37	2020-08-25	Jahiem Schinner	jahiem.schinner@geemail.com	Huntington Beach	California	53231321129974920	36712da99aebd58b96df79dd30cce639	VISA 13 digit	33.6021523475687971	-117.959925097798177
47586	2020-08-25 06:07:52	2020-08-25	Mr. Jovanny Anderson	mr.jovanny.anderson@woohoo.com	Las Vegas	Nevada	4274536150239	b14cbfd6d901d0d9fb0aceed45eab734	JCB 15 digit	36.1505101741392139	-115.288907632438836
47587	2020-08-25 06:29:30	2020-08-25	Dr. Authur Predovic	dr.authur.predovic@woohoo.com	St. Louis	Missouri	4044366242749	b7bd0e6a6aa00c900f44dbfc394a3743	JCB 16 digit	38.5403009676065267	-90.3316933718979413
47588	2020-08-25 06:40:26	2020-08-25	Joel Ernser DDS	joel.ernser.dds@geemail.com	San Jose	California	3528630768324648013	2ad435318805ca7f33824b40d3421c44	VISA 13 digit	37.2373642796006052	-121.851266278301921
47589	2020-08-25 06:48:46	2020-08-25	Colon Luettgen	colon.luettgen@woohoo.com	Eugene	Oregon	6011954679981460931	030e857fa09aab7fffa3d9a5e1a5c520	JCB 15 digit	43.9751703587554417	-123.110939224063245
47590	2020-08-25 06:49:03	2020-08-25	Laurel Kerluke	laurel.kerluke@geemail.com	New York	New York	3337221107206282945	57cf134daaf953aa0cdcec6db8d0b8d6	Voyager	40.7282552157286517	-73.9685913402017121
47591	2020-08-25 06:56:37	2020-08-25	Mrs. Coral Steuber MD	mrs.coral.steuber.md@geemail.com	San Francisco	California	4699658212211	488563aac57ccad9b053bb9277ced696	JCB 16 digit	37.7714914094612695	-122.428791423428407
47592	2020-08-25 07:13:41	2020-08-25	Khiry Larkin	khiry.larkin@geemail.com	San Francisco	California	6011520966912610568	aa3d4bc1b1d70761ca1a116fe36cfd6e	VISA 16 digit	37.7603614071627689	-122.436189172669714
47593	2020-08-25 07:22:54	2020-08-25	Dalton Feil	dalton.feil@woohoo.com	Tucson	Arizona	4952057263156	3c3b1c6d6dddf2fff11b2941e0ea02cc	JCB 15 digit	32.0796136950183666	-110.842016553575547
47594	2020-08-25 07:55:58	2020-08-25	Mr. Kamari Smith II	mr.kamari.smith.ii@woohoo.com	San Francisco	California	3088394192917262791	695cf9b7c3a1ba116a8b6b75e5c30a3a	JCB 16 digit	37.7728321077942297	-122.450869177606052
47595	2020-08-25 07:57:57	2020-08-25	Dr. Lewis Willms	dr.lewis.willms@geemail.com	Tyler	Texas	3419347493252161	84d70e1cba9481147386813cc56d2c48	Diners Club / Carte Blanche	32.2804273420993297	-95.2673905355032531
47596	2020-08-25 08:00:15	2020-08-25	Mr. Trevion Krajcik III	mr.trevion.krajcik.iii@geemail.com	Columbus	Ohio	210059335636442188	9a8fd94e6c7c01040275930316ff2644	Maestro	40.0076735339172203	-83.0652228571243683
47597	2020-08-25 08:02:26	2020-08-25	Telly Volkman-Mohr	telly.volkman.mohr@warmmail.com	Houston	Texas	060487061697378	c42073cb97edc92822195d11d5c39028	Mastercard	29.6873477693259709	-95.4863150349367373
47598	2020-08-25 08:04:22	2020-08-25	Jennings Jacobson	jennings.jacobson@geemail.com	Phoenix	Arizona	676292624529373	1a46c73feaf0ea85b235a05805aefc66	Maestro	33.5215492823094152	-112.005495366540188
47599	2020-08-25 08:07:31	2020-08-25	Mr. Cortney Cassin DVM	mr.cortney.cassin.dvm@geemail.com	St. Louis	Missouri	3337988538303622299	f859b44058e98d385a12265e5be7e498	VISA 16 digit	38.7139245956826983	-90.1939933411315167
47600	2020-08-25 08:09:04	2020-08-25	Elida O'Hara	elida.o'hara@geemail.com	Cape Coral	Florida	55710754291637489	4b9ce0526941e8255e01fff10b19bb8b	VISA 16 digit	26.5448965655144313	-81.9636515438161837
47601	2020-08-25 08:23:49	2020-08-25	Ms. Nevaeh Zemlak DDS	ms.nevaeh.zemlak.dds@geemail.com	Fresno	California	4249591087187	7828b950780912ac56c1a6755689de85	VISA 16 digit	36.7968523102685836	-119.812263648222768
47602	2020-08-25 08:24:14	2020-08-25	Ms. Sunny McGlynn MD	ms.sunny.mcglynn.md@geemail.com	Bridgeport	Connecticut	180003168232828352	83ae318d45441e22c5cdd1a099b24573	VISA 16 digit	41.2341433982063066	-73.2496212675601299
47603	2020-08-25 08:33:55	2020-08-25	Alvah Price	alvah.price@geemail.com	Chicago	Illinois	55231174914335892	f4bd98da409eb6d1d943fee457edb90d	Diners Club / Carte Blanche	41.9001928631052394	-87.7047993847664458
47604	2020-08-25 08:38:30	2020-08-25	Dr. Brett Kuhn IV	dr.brett.kuhn.iv@geemail.com	Berkeley	California	3034824276208500	474674a646951c4dce171af1b2efab03	JCB 15 digit	37.8805736584437938	-122.259460941260841
47605	2020-08-25 08:39:01	2020-08-25	Trish Barrows	trish.barrows@geemail.com	Clearwater	Florida	4715189505495389	e51bdad6a24e51d51e58ce077d6e5763	VISA 16 digit	27.9691266319375487	-82.8540249078333346
47606	2020-08-25 08:54:19	2020-08-25	Laquita Tromp	laquita.tromp@geemail.com	Tulsa	Oklahoma	3158591220190164516	88ff64c25a5e1495f39858d6829f27a8	JCB 15 digit	36.1996916600871828	-95.9228145137850134
47607	2020-08-25 09:03:54	2020-08-25	Frankie Rogahn-Hermann	frankie.rogahn.hermann@woohoo.com	Newport News	Virginia	4169862464180	2952f8f08d82bc47c7dfa4d223eddb76	JCB 15 digit	37.1441780580569088	-76.5531062376480662
47608	2020-08-25 09:05:08	2020-08-25	Hassie Williamson	hassie.williamson@geemail.com	Minneapolis	Minnesota	869966922330462686	010267482a89639b1287809edd5ed253	Mastercard	44.8775653173301308	-93.3383103152077638
47609	2020-08-25 09:07:09	2020-08-25	Nallely Kemmer	nallely.kemmer@woohoo.com	Huntsville	Alabama	210051788456522612	d58b9073cfd787d459abe9d250192d28	Mastercard	34.6266576573029141	-86.6726209034230521
47610	2020-08-25 09:22:23	2020-08-25	Mr. Ryker Kuhic	mr.ryker.kuhic@geemail.com	Gresham	Oregon	180057900963961282	e85e645b804af252df4a7b77c4786a89	Diners Club / Carte Blanche	45.434256625496964	-122.386376309095311
47611	2020-08-25 09:22:25	2020-08-25	Orlo Padberg	orlo.padberg@geemail.com	Berkeley	California	4463308439277028	e33c35f481f8a3b60289319a6e4efbe3	JCB 15 digit	37.8507049554830033	-122.269008108497744
47612	2020-08-25 09:24:16	2020-08-25	Mr. Oliver Macejkovic	mr.oliver.macejkovic@warmmail.com	McAllen	Texas	675977538683150	d0cebfc37ac2723606d480af3d15898a	VISA 16 digit	26.1819848786413658	-98.3127982947356998
47613	2020-08-25 09:27:18	2020-08-25	Carly Krajcik DVM	carly.krajcik.dvm@geemail.com	Los Angeles	California	869971429207010104	b533021f8775412816843b13dd11cd15	VISA 16 digit	34.0653780653938654	-118.316010384260863
47614	2020-08-25 09:29:35	2020-08-25	Dr. Zula Hessel PhD	dr.zula.hessel.phd@woohoo.com	Hialeah	Florida	4243811564877	5b72abe05becfeca9a298138b6e8900c	JCB 15 digit	25.8565172684356597	-80.3053722717236695
47615	2020-08-25 09:31:35	2020-08-25	Mrs. Chana McLaughlin	mrs.chana.mclaughlin@geemail.com	Detroit	Michigan	6011266426028785364	91f88d14de3731aabd8f1a6c8371d5e3	American Express	42.4613388148527591	-83.0756951359685445
47616	2020-08-25 09:33:31	2020-08-25	Dr. Russ Grant	dr.russ.grant@geemail.com	New York	New York	4954457116989615	baac8fc1334bca8549d351854565c482	VISA 16 digit	40.672445864113044	-73.9548647424101802
47617	2020-08-25 10:05:53	2020-08-25	Minervia Stracke	minervia.stracke@geemail.com	Miami	Florida	6011005601163509797	5c37e97b1d34ead246aac81d58b83d0f	JCB 16 digit	25.7988470710020543	-80.147809558814771
47618	2020-08-25 10:06:10	2020-08-25	Cheyenne Renner II	cheyenne.renner.ii@geemail.com	Las Vegas	Nevada	3158943411112449201	718cdcb77e00ecf6ac2d645ad552f722	Mastercard	36.2940566450457993	-115.323333326282352
47619	2020-08-25 10:06:49	2020-08-25	Janessa Nader	janessa.nader@woohoo.com	Pasadena	Texas	869951873179590045	0efb5a24b05ce9e14205e43ca838ca99	JCB 16 digit	29.6608598901297889	-95.1531844776071551
47620	2020-08-25 10:11:19	2020-08-25	Golden Schoen	golden.schoen@geemail.com	Yonkers	New York	4642951277035489	ec387a1a61ed784d48b629ab6e582919	Discover	40.9323239176269666	-73.8426325524576015
47621	2020-08-25 10:12:03	2020-08-25	Stephany Schumm	stephany.schumm@woohoo.com	Salt Lake City	Utah	210021648966118680	f4fd83f54c24410a970b02a3f75365c9	Diners Club / Carte Blanche	40.852969600041952	-112.020072226034472
47622	2020-08-25 10:16:32	2020-08-25	Billie Rutherford Jr.	billie.rutherford.jr.@geemail.com	Los Angeles	California	3088680453211876113	6b80271e5d8540cb790e1b33c8bd30ed	Discover	33.9986733118869324	-118.367537121334294
47623	2020-08-25 10:27:49	2020-08-25	Dr. Len Boehm I	dr.len.boehm.i@woohoo.com	San Francisco	California	3784579854793363	87e5f33cace495c80137250051dc008d	VISA 16 digit	37.7608090015073046	-122.446514167604789
47624	2020-08-25 10:48:27	2020-08-25	Mayra Nolan	mayra.nolan@geemail.com	Norfolk	Virginia	3044356055218277	2802f877dc84e688251509a644e380e7	Diners Club / Carte Blanche	36.8957446550969053	-76.3247908979192431
47625	2020-08-25 10:49:31	2020-08-25	Dr. Julianne Rempel PhD	dr.julianne.rempel.phd@woohoo.com	San Francisco	California	6011933651141965477	dd86332d2f67f2aa0c29a5f2b05a4396	Maestro	37.7634059650800822	-122.454824751784244
47626	2020-08-25 11:03:14	2020-08-25	Rosalia Goodwin	rosalia.goodwin@geemail.com	Houston	Texas	6011054325261738211	f4e80a0f3f3ae8f9b086a3d10ec384e5	JCB 15 digit	29.8075829185158021	-95.4061431624941605
47627	2020-08-25 11:10:26	2020-08-25	Idella Ledner DVM	idella.ledner.dvm@geemail.com	New York	New York	4970961756495	03f9ba25ef13bd66ae27d56f99354d0c	VISA 16 digit	40.598930833511055	-74.0360069624975239
47628	2020-08-25 11:26:33	2020-08-25	Miss Marilla Becker	miss.marilla.becker@geemail.com	Tucson	Arizona	3042249008930944	2faea643c6c5f2ceb05a83e608e67c8a	Voyager	32.2228697645053259	-110.923390329791602
47629	2020-08-25 11:47:25	2020-08-25	Dr. Emilia Beier	dr.emilia.beier@woohoo.com	Norfolk	Virginia	503890787500108	40134f47b932a0a067a52f394af97036	VISA 16 digit	36.9608600326366741	-76.1581910043492911
47630	2020-08-25 11:52:48	2020-08-25	Dr. Stephon Mills DVM	dr.stephon.mills.dvm@warmmail.com	Virginia Beach	Virginia	869941830281133596	6e55ecc1405e77ff4029ca4062e5643e	Maestro	36.7688764153700305	-76.0031165935236999
47631	2020-08-25 12:04:31	2020-08-25	Ignatius Price	ignatius.price@geemail.com	San Bernardino	California	6011400192180101215	2efb9fadb2ddfba72096e8a23e91d12f	VISA 13 digit	34.1602731676105407	-117.380252826890342
47632	2020-08-25 12:04:44	2020-08-25	Ricci Langosh-Price	ricci.langosh.price@geemail.com	Detroit	Michigan	4511957337132636	ac2569e8ded974f00f83cddc9c9469af	Discover	42.2978402251303223	-83.0665877649214082
47633	2020-08-25 12:17:15	2020-08-25	Antwan Dach	antwan.dach@geemail.com	Oakland	California	4161021939886413	5925d5a3a12b4d257c334e17fe910c2a	JCB 15 digit	37.7818023431585814	-122.284004427927997
47634	2020-08-25 12:22:13	2020-08-25	Dr. Kavon Turner	dr.kavon.turner@geemail.com	Chicago	Illinois	3528980036980437063	08d4f28a7d4443595eab4ac56857e866	JCB 16 digit	41.928946553340559	-87.6739160621102798
47635	2020-08-25 12:22:15	2020-08-25	Domingo Hills	domingo.hills@warmmail.com	Jacksonville	Florida	3112642154076439891	5818f41c9553c07a1624acfdef0dadeb	JCB 16 digit	30.3564085382089033	-81.7234519566953281
47636	2020-08-25 12:23:59	2020-08-25	Miss Kayleigh Gorczany PhD	miss.kayleigh.gorczany.phd@geemail.com	Houston	Texas	3096599173338862016	646cf6f8976556a4dff134c1e6b35cc1	Discover	29.8420071927908808	-95.3186569351252189
47637	2020-08-25 12:28:01	2020-08-25	Ms. Malissie O'Reilly	ms.malissie.o'reilly@geemail.com	Tucson	Arizona	54033412442251748	84f910e83fea94d7754c1a339b32be8f	Voyager	32.217812629280985	-110.87494691063128
47638	2020-08-25 12:37:17	2020-08-25	Mr. Alejandro Johnston I	mr.alejandro.johnston.i@geemail.com	Wichita	Kansas	180061854483202186	a0fafdfacc7b48351c0df12ec6f944f3	Maestro	37.5917099867358786	-97.2746886802572703
47639	2020-08-25 12:46:53	2020-08-25	Clay Graham	clay.graham@geemail.com	Tulsa	Oklahoma	3088069752306277652	c3b664604f31d9f78792e3b1f235aba0	VISA 16 digit	36.2273053080677983	-95.8998791975855767
47640	2020-08-25 12:49:48	2020-08-25	Arrie Littel-Stehr	arrie.littel.stehr@geemail.com	Detroit	Michigan	4261051024919042	1576c8f7636a128cab777a64e9a8a99d	Voyager	42.3848418946303482	-83.0195599165398619
47641	2020-08-25 12:50:55	2020-08-25	Olene Hammes	olene.hammes@geemail.com	Savannah	Georgia	869919099785075137	778fe52319c3388dc0199418fbb45a9c	Maestro	31.9388164061680406	-81.1201006649214804
47642	2020-08-25 12:53:59	2020-08-25	Gena Lindgren	gena.lindgren@warmmail.com	Irvine	California	4540497533898	9c0f5156c54bf0b3bbda5d68cafd4f75	Mastercard	33.5888394707363105	-117.768880873873087
47643	2020-08-25 12:54:10	2020-08-25	Paxton Runolfsdottir	paxton.runolfsdottir@geemail.com	New York	New York	4219801056645441	0c0029642c8022b79fd35f88cb72622b	Maestro	40.7415964378733193	-73.9772717341210608
47644	2020-08-25 13:06:28	2020-08-25	Laylah Haley MD	laylah.haley.md@woohoo.com	Baltimore	Maryland	589334315244391	9ffb71ebe714239f553b74945e884d99	VISA 16 digit	39.2272389541380093	-76.6302974685113867
47645	2020-08-25 13:09:03	2020-08-25	Errol Ondricka DVM	errol.ondricka.dvm@geemail.com	San Antonio	Texas	3528961551214598285	dedc192f3c7cb46e31ec9990ce809757	JCB 16 digit	29.4129558319296684	-98.5976827237125377
47646	2020-08-25 13:18:50	2020-08-25	Kimberley Franecki	kimberley.franecki@geemail.com	Corona	California	54742120468783682	4f1ec60362feaebbf692a9690644f85b	Maestro	33.8890314983092296	-117.492128844300282
47647	2020-08-25 13:19:42	2020-08-25	Ms. Yareli Nienow	ms.yareli.nienow@warmmail.com	Jacksonville	Florida	52088264040183144	4abfc674ac50747159946ba9ed3768ba	VISA 13 digit	30.3764738651975996	-81.6364509659431974
47648	2020-08-25 13:24:13	2020-08-25	Shirl Wunsch	shirl.wunsch@geemail.com	Bakersfield	California	3158504137912275030	39186df253bd5112fd7a1e442a8c3462	Mastercard	35.2742945941805814	-119.04623166460469
47649	2020-08-25 13:32:21	2020-08-25	Mr. Ebb Ryan DDS	mr.ebb.ryan.dds@geemail.com	New York	New York	3158343497371562210	6e4390b40a670968e6bf4a5c40ebaad9	VISA 16 digit	40.6840546105280509	-73.9183785650309204
47650	2020-08-25 13:41:47	2020-08-25	Kimberely Anderson PhD	kimberely.anderson.phd@geemail.com	Honolulu	Hawaii	3701453515062404	846b0af98f2d29760c9762d73c6717ac	Diners Club / Carte Blanche	21.3125341148331771	-157.880940474124998
47651	2020-08-25 13:48:15	2020-08-25	Milas Aufderhar	milas.aufderhar@warmmail.com	Louisville	Kentucky	210090853905926989	284ee0349e5dc8c34e6fe0a169320230	Maestro	38.1566635678891046	-85.6569697188284351
47652	2020-08-25 13:51:33	2020-08-25	Keenen Shields V	keenen.shields.v@geemail.com	Phoenix	Arizona	210096911242473703	7699fe76de67648700b745d9c6867e56	VISA 16 digit	33.5367516417920584	-112.001988620816178
47653	2020-08-25 14:01:37	2020-08-25	Mr. Harrold Feest	mr.harrold.feest@warmmail.com	San Francisco	California	3048799678058388	3eb993e6505f4b217374f631505a6228	Mastercard	37.7438158950249587	-122.446055107573386
47654	2020-08-25 14:01:49	2020-08-25	Deena Stoltenberg DVM	deena.stoltenberg.dvm@geemail.com	Clearwater	Florida	3752413892293574	85e6c5f9f61d7508037d02a027e4b25c	Diners Club / Carte Blanche	28.0066967104222613	-82.6669614458721043
47655	2020-08-25 14:09:14	2020-08-25	Meadow Treutel DVM	meadow.treutel.dvm@geemail.com	New York	New York	3158549472318127833	e8c20b539fdc33aa0ed0dc51d4eab050	Discover	40.6684098401330374	-73.8744730254065161
47656	2020-08-25 14:13:39	2020-08-25	Shania Hahn	shania.hahn@warmmail.com	Houston	Texas	3057127626397073	ef26fcc004ed4c2f64151e1ae683ff4c	American Express	29.8169522373083993	-95.4599541313029789
47657	2020-08-25 14:14:57	2020-08-25	Coletta Hessel	coletta.hessel@geemail.com	San Jose	California	6011182044385089998	74292f0e2d80c53d957f24f5bf152b82	American Express	37.3296144087620121	-121.808029298506298
47658	2020-08-25 14:17:50	2020-08-25	Eola Pfannerstill	eola.pfannerstill@geemail.com	San Francisco	California	180045705413138729	cb9e8bbee34aec7dfa976b6693b88bbb	Maestro	37.7749013682668107	-122.46432475774273
47659	2020-08-25 14:28:02	2020-08-25	Hakeem Wiza I	hakeem.wiza.i@geemail.com	Long Beach	California	4060891637405910	e1243bae73691396c1db7b205f5b7014	Discover	33.7349441144436568	-118.089575814937419
47660	2020-08-25 14:43:16	2020-08-25	Mrs. Soledad Reynolds MD	mrs.soledad.reynolds.md@geemail.com	Rochester	Minnesota	52940344043503429	7f0acaaa59554fc2c36f3e0b4d4d72e1	JCB 16 digit	44.1008410614352684	-92.4160694741763109
47661	2020-08-25 14:54:16	2020-08-25	Ms. Justina Mueller DVM	ms.justina.mueller.dvm@geemail.com	New York	New York	3158250165481603684	04519f1bb7e915cbd9a638801c3de6c9	JCB 16 digit	40.5675473540779166	-73.8712236121192518
47662	2020-08-25 15:01:35	2020-08-25	Brennen Monahan	brennen.monahan@woohoo.com	Berkeley	California	869999430736842833	bf8aa99ba6a128d1103b5bbbcec90aae	Mastercard	37.8780284201480839	-122.277091148271623
47663	2020-08-25 15:23:10	2020-08-25	Nathanial Hettinger	nathanial.hettinger@geemail.com	Seattle	Washington	561252974689094	cdefbc012b575275dd34a0a32dd53582	American Express	47.7204747809953957	-122.43222544229738
47664	2020-08-25 15:23:41	2020-08-25	Ernestine Pacocha-Hane	ernestine.pacocha.hane@warmmail.com	New York	New York	4109952453834865	2ea77726d26b5e82a8f9f6b11ebdaecc	JCB 16 digit	40.6324721147064096	-73.9678281992103877
47665	2020-08-25 15:45:39	2020-08-25	Dr. Cleo Abshire	dr.cleo.abshire@geemail.com	Kansas City	Missouri	6011614262572182677	323ba8d845334b0cb22d7b0a4a415172	Voyager	39.0889202033005674	-94.5388118901047818
47666	2020-08-25 15:48:11	2020-08-25	Maeve Roob	maeve.roob@geemail.com	San Francisco	California	6011310708745992498	4200a82a45601323b5cf432794d94b82	VISA 16 digit	37.7840042140095207	-122.426921804285001
47667	2020-08-25 15:51:30	2020-08-25	French Schultz	french.schultz@geemail.com	Tucson	Arizona	3027688342857377	4ae7f6f6a0bd5e2fde23208bd89e32e2	VISA 16 digit	32.2513875753659747	-110.870874439807977
47668	2020-08-25 15:52:23	2020-08-25	Mrs. Lennie Hammes	mrs.lennie.hammes@geemail.com	Newark	New Jersey	53491639875186026	30e5906bf5eec6bfde67d9242e096f7e	JCB 16 digit	40.6698105820834641	-74.0841049296990093
47669	2020-08-25 16:05:16	2020-08-25	Bryan Rolfson MD	bryan.rolfson.md@geemail.com	Chicago	Illinois	869996238379860175	d6a2bebdd2e101531b5150971668716d	Mastercard	41.9243217679508078	-87.6726137637656109
47670	2020-08-25 16:12:17	2020-08-25	Vanesa Howell-Leuschke	vanesa.howell.leuschke@geemail.com	Raleigh	North Carolina	6011323774134534882	d7e1e0b953e425feff3649b9b601b73b	Diners Club / Carte Blanche	35.9159994063101706	-78.5826368105068838
47671	2020-08-25 16:31:01	2020-08-25	Ms. Cathryn Moen	ms.cathryn.moen@geemail.com	San Francisco	California	3741609802925213	f8ee32809d0fa4db2986862bf17d79ac	JCB 15 digit	37.782840464930679	-122.414988326639076
47754	2020-08-26 01:56:23	2020-08-26	Donnell Doyle	donnell.doyle@woohoo.com	San Jose	California	53293272353506513	79aa297f07a24af7a47031d52e7f0c76	VISA 16 digit	37.2563210279036312	-121.77761747899801
47672	2020-08-25 16:40:53	2020-08-25	Webster Dibbert III	webster.dibbert.iii@woohoo.com	San Francisco	California	54568736431577223	8ef463acbe08943ce083e796ce7367a8	JCB 16 digit	37.7747662920791285	-122.416970571768985
47673	2020-08-25 16:44:47	2020-08-25	Kierra McKenzie MD	kierra.mckenzie.md@geemail.com	Fresno	California	3112059586259048997	9efd97b0e46605315c69e5cc82b03912	VISA 16 digit	36.6867465188134432	-119.863150738982114
47674	2020-08-25 16:45:01	2020-08-25	Ewald Kuphal	ewald.kuphal@geemail.com	San Francisco	California	3112391947450590954	a1e343e33cdf80c1dddbb5307f325e9c	Voyager	37.7860278657813353	-122.452019904567535
47675	2020-08-25 16:52:40	2020-08-25	Dr. Tiffani Lockman DDS	dr.tiffani.lockman.dds@geemail.com	Oakland	California	180000628696158649	622213336bd80f52b88f220ed61d8945	JCB 15 digit	37.8100794352984195	-122.283347621972112
47676	2020-08-25 16:56:17	2020-08-25	Slade Stiedemann	slade.stiedemann@geemail.com	Philadelphia	Pennsylvania	3024443285360853	6460d92a028ee8239a6653e592f88f59	Voyager	40.0228214790537962	-75.0978877928007478
47677	2020-08-25 17:00:49	2020-08-25	Naima Schowalter	naima.schowalter@geemail.com	San Francisco	California	3088085351163255628	2705366c0235191bbf0161b78ad05066	American Express	37.7527320974994041	-122.440319971539068
47678	2020-08-25 17:03:07	2020-08-25	Stasia Padberg	stasia.padberg@warmmail.com	Lafayette	Louisiana	4686702105598629	a618e7f784b7b5bec5a3c9ccb28c28f9	JCB 16 digit	30.1341721100244655	-92.1234315801262795
47679	2020-08-25 17:09:14	2020-08-25	Dr. Dwaine Skiles V	dr.dwaine.skiles.v@geemail.com	San Francisco	California	3474348768723649	071569cab782d281039446311ab556ce	Voyager	37.7581766273316362	-122.447054154029502
47680	2020-08-25 17:10:28	2020-08-25	Aubrie Harris	aubrie.harris@warmmail.com	Boston	Massachusetts	503897667149138	0747c356741b4a1bb6ef329237b6ec50	Mastercard	42.3171615143008566	-71.0490965058047408
47681	2020-08-25 17:15:31	2020-08-25	Rosaline McKenzie MD	rosaline.mckenzie.md@woohoo.com	Charlotte	North Carolina	180066284029044667	3de4b16700c5252ae6b3b02038055e4f	Discover	35.136966767047717	-80.9177125790100575
47682	2020-08-25 17:22:50	2020-08-25	Antone Lakin	antone.lakin@geemail.com	Fort Collins	Colorado	869906948152527218	7856fccee3cbabc64e9bd88daa62e088	JCB 15 digit	40.5933505596749526	-105.079082127190389
47683	2020-08-25 17:22:57	2020-08-25	Idella Gusikowski	idella.gusikowski@geemail.com	San Angelo	Texas	53512985935749955	a3c99a872f240218d3bb530573f6b1f6	American Express	31.362887129202857	-100.519787559576343
47684	2020-08-25 17:32:15	2020-08-25	Antony Pacocha	antony.pacocha@warmmail.com	Charlotte	North Carolina	6011135222513425262	289b24d5185b7b196e876a568d87d57d	VISA 16 digit	35.2239912277806511	-80.9018650202024787
47685	2020-08-25 17:34:59	2020-08-25	Kitty Stoltenberg	kitty.stoltenberg@geemail.com	Mesa	Arizona	869903373591161052	6a158f9437984d300e7987cbb2f7e85a	Discover	33.3542891292978041	-111.797678272368017
47686	2020-08-25 17:36:36	2020-08-25	Jaiden Boyle	jaiden.boyle@geemail.com	Santa Clara	California	4106994790452269	75f3021beb2b90a3f810fbf019650740	JCB 15 digit	37.2943685425728617	-121.922757147904107
47687	2020-08-25 17:39:42	2020-08-25	Darryn Olson-Howe	darryn.olson.howe@geemail.com	Springfield	Missouri	4798177290284043	3a2b0469d5372dd37e5d4088898dc212	JCB 16 digit	37.1365581331502668	-93.2224775506939807
47688	2020-08-25 17:46:20	2020-08-25	Soledad Ziemann	soledad.ziemann@geemail.com	Nashville	Tennessee	3015405708498544	58748e4bd2aadff0381fb6a44333e2f9	Discover	36.2289631667669809	-86.790066422792151
47689	2020-08-25 17:51:37	2020-08-25	Erby Howell	erby.howell@geemail.com	Santa Ana	California	676306153540734	0eea1316f7177b90204afc438f6ee442	JCB 16 digit	33.6592682391509399	-117.971173403637479
47690	2020-08-25 18:13:53	2020-08-25	Isiah Ullrich	isiah.ullrich@geemail.com	Glendale	California	6011775186034185827	a27bbab61a3b8d42914c2ded365e126a	JCB 16 digit	34.1600193902138614	-118.32986481882557
47691	2020-08-25 18:15:38	2020-08-25	Mell Casper	mell.casper@warmmail.com	Las Vegas	Nevada	3528742414608081077	b953a63ac9f3d57fa321284fc8cd0372	JCB 16 digit	36.3094330941427472	-115.356359665861717
47692	2020-08-25 18:15:53	2020-08-25	Miss Cordelia Fadel MD	miss.cordelia.fadel.md@geemail.com	Sacramento	California	3096642026413112037	a603772cf0bbe1e132eb4274d237d844	JCB 16 digit	38.6279831080496336	-121.475648253901298
47693	2020-08-25 18:22:09	2020-08-25	Huey Kertzmann	huey.kertzmann@geemail.com	Garland	Texas	630498281654784	df189b2d3d3ff8965917a9316b8d23e2	Voyager	32.8355129428908228	-96.5352873667303584
47694	2020-08-25 18:24:53	2020-08-25	Miss Rosaline Williamson	miss.rosaline.williamson@geemail.com	Tulsa	Oklahoma	630484171930807	f090c7d02302a5ae78d6e76ec2be6a59	JCB 16 digit	36.1046706306651188	-95.8816965696822763
47695	2020-08-25 18:27:24	2020-08-25	Dr. Essa Lynch	dr.essa.lynch@geemail.com	Kansas City	Kansas	54368946723598934	8158731c809298fad0344cf2977a70ad	Discover	39.0397036640346045	-94.7731120716717044
47696	2020-08-25 18:29:53	2020-08-25	Miss Jenna Simonis PhD	miss.jenna.simonis.phd@geemail.com	San Antonio	Texas	53946459279531136	6af6404bc434b77b4f94ce4e0275b90d	Maestro	29.5438267291128653	-98.4891430118422875
47697	2020-08-25 18:36:33	2020-08-25	Zara Parker	zara.parker@woohoo.com	San Francisco	California	6011829685633725285	32d4b8cf2a8983434791a4db41cb0e08	Mastercard	37.8056404441220621	-122.422133079606624
47698	2020-08-25 18:55:47	2020-08-25	Mrs. Bertha Glover	mrs.bertha.glover@geemail.com	Manchester	New Hampshire	3158080646949804507	05d0dda9cae41a680ae3e932fdc908ea	Maestro	42.8992492571078259	-71.4272697822082847
47699	2020-08-25 19:06:03	2020-08-25	Tiarra Baumbach	tiarra.baumbach@geemail.com	Chicago	Illinois	6011209466359068899	cd1d0e1015e5001c299344b1bc3dcfb0	Discover	41.7403598800603319	-87.76388363330922
47700	2020-08-25 19:09:16	2020-08-25	Alecia Sanford DVM	alecia.sanford.dvm@warmmail.com	Corpus Christi	Texas	210085242436976563	d084df48d8a7710d1b5ee1b31aadb913	American Express	27.7856277479261173	-97.1757227834608415
47701	2020-08-25 19:30:49	2020-08-25	Levi Mante V	levi.mante.v@geemail.com	Milwaukee	Wisconsin	3031696805539347	b2b334a9f967971fb75604c6f1f23677	Mastercard	43.1516206584025142	-87.9106112794585499
47702	2020-08-25 19:35:09	2020-08-25	Jasmyne Veum MD	jasmyne.veum.md@geemail.com	Houston	Texas	676201236750715	c78d393f5ed384c39c53cfb5b4cf0333	Voyager	29.8455272508863345	-95.3131576166503152
47703	2020-08-25 19:37:21	2020-08-25	Demian Heathcote	demian.heathcote@woohoo.com	New Orleans	Louisiana	4353715107606	079999cf9bea57856205268621392c1c	JCB 16 digit	30.141121543014048	-90.0008510244805393
47704	2020-08-25 19:43:22	2020-08-25	Starla Dare	starla.dare@geemail.com	Charlotte	North Carolina	3096943002181658051	d6e7b8f9517907377fc717ec0e76f560	VISA 16 digit	35.1260968740817177	-80.8141307958811552
47705	2020-08-25 19:49:05	2020-08-25	Kali Bartell	kali.bartell@geemail.com	San Francisco	California	3158635958597058322	3e9964e472c9d5921833805accd4c903	American Express	37.784722225107636	-122.420751813952833
47706	2020-08-25 19:51:38	2020-08-25	Xander Durgan PhD	xander.durgan.phd@geemail.com	San Diego	California	3035894225884379	9f3eac831899532a27bd1c5f53f6fe8e	JCB 16 digit	32.7686801088109618	-117.043744020061567
47707	2020-08-25 19:52:44	2020-08-25	Artie Ortiz-Jacobs	artie.ortiz.jacobs@woohoo.com	Oakland	California	4040605475966493	aae31f0e7328805ce1268164743b7eb5	Discover	37.774324040410697	-122.292859071154197
47708	2020-08-25 19:56:30	2020-08-25	Regis Gottlieb	regis.gottlieb@woohoo.com	Killeen	Texas	180041639959110517	d52c7097a7b9a04ac66c4ed0c02982fb	Voyager	31.0214372061889634	-97.6426539692729705
47709	2020-08-25 20:22:37	2020-08-25	Conor Stanton II	conor.stanton.ii@geemail.com	Rochester	New York	4593967682378594	d11233f6c938a0ad5b3e29f90f4bced1	JCB 16 digit	43.1886237685546277	-77.7139928961876763
47710	2020-08-25 20:32:00	2020-08-25	Woodson Powlowski	woodson.powlowski@geemail.com	Riverside	California	210041619845285004	d11177d7a6adf4cbe679451f912c387b	VISA 16 digit	33.9982081324741259	-117.348811008591937
47711	2020-08-25 20:34:57	2020-08-25	Ether Corwin	ether.corwin@geemail.com	Charlotte	North Carolina	52155728124693176	4e65f072b7fd80cffe8b97669d085bb4	Discover	35.1419266470029967	-80.7865395543575318
47712	2020-08-25 20:37:56	2020-08-25	Albina Rogahn	albina.rogahn@geemail.com	New Haven	Connecticut	3158866753614198858	43570f22668523a76a61106f1524bcf1	JCB 16 digit	41.301876617175715	-72.903081817785278
47713	2020-08-25 20:45:18	2020-08-25	Miss Delfina Emard DDS	miss.delfina.emard.dds@geemail.com	Indianapolis	Indiana	4455068340052973	90901d4bca70a4f56227ad01a31def72	JCB 15 digit	39.6981613383635832	-86.1814665082577562
47714	2020-08-25 20:49:21	2020-08-25	Dr. Tal Romaguera	dr.tal.romaguera@geemail.com	New York	New York	180086173476935764	d7a63a47b5a07e3ec5783ae83cc0e10e	Diners Club / Carte Blanche	40.6404422122742943	-73.9591863474238664
47715	2020-08-25 20:54:23	2020-08-25	Reynaldo Runolfsson Sr.	reynaldo.runolfsson.sr.@geemail.com	Los Angeles	California	3337656784546438199	d040b30769eaf33bccbf9a299e85883e	Discover	33.9671741723414513	-118.390832641626886
47716	2020-08-25 20:56:47	2020-08-25	Jewel Howe	jewel.howe@warmmail.com	Tuscaloosa	Alabama	3088356374775878480	231e9176787507b7b1b9ef21e099e4c9	VISA 16 digit	33.1311993744745834	-87.4994705110419488
47717	2020-08-25 21:06:20	2020-08-25	Mr. Clabe Quigley	mr.clabe.quigley@geemail.com	Tallahassee	Florida	3043721580141354	2af052dcbc3ff5ac1ac16cfb90d9effd	VISA 16 digit	30.4368577077075848	-84.1720908790375972
47718	2020-08-25 21:12:27	2020-08-25	Kinte Berge I	kinte.berge.i@geemail.com	Fayetteville	North Carolina	54742868243628800	063edcfb886717c8bbcc207eed865641	JCB 16 digit	35.1184674668379131	-78.9282065719962134
47719	2020-08-25 21:41:23	2020-08-25	Cicero Blick	cicero.blick@geemail.com	Philadelphia	Pennsylvania	501895632956884	201c102353a63bcf7742d697ff2a624e	American Express	39.9342532200232156	-75.1235382007800041
47720	2020-08-25 21:43:07	2020-08-25	Mr. Adelard Medhurst IV	mr.adelard.medhurst.iv@geemail.com	Wilmington	North Carolina	180050711190785783	3ca521a299c6406bfea592fcb16b0cf8	VISA 16 digit	34.2775487473987042	-77.7948089352801446
47721	2020-08-25 22:16:04	2020-08-25	Sabastian Gleason	sabastian.gleason@geemail.com	San Jose	California	4826743664003	10465db7d358abbe0d113f67717bc618	JCB 16 digit	37.3954636737525448	-121.84150426790454
47722	2020-08-25 22:22:24	2020-08-25	Shelvia Kozey	shelvia.kozey@geemail.com	Chesapeake	Virginia	210021195544836920	5a5c4bbb8e7820c7c4309221487ca292	American Express	36.5825727606896294	-76.3599247877795193
47723	2020-08-25 22:43:11	2020-08-25	Enoch Kemmer	enoch.kemmer@geemail.com	Springfield	Illinois	6011886861410756757	1b70358da8efb12939d3c10f814ccf53	VISA 13 digit	39.8083122853342459	-89.586297031632057
47724	2020-08-25 22:44:02	2020-08-25	Ms. Melissia Thompson DVM	ms.melissia.thompson.dvm@geemail.com	Waco	Texas	6011912546957307696	9f25b35cc028d88af65ec39e82bc931f	JCB 16 digit	31.5391759238414444	-97.2715764999520047
47725	2020-08-25 22:53:03	2020-08-25	Marlyn Bogisich	marlyn.bogisich@geemail.com	Oakland	California	3112187232144320482	08f3bb7cee523538e4285c816a180008	JCB 16 digit	37.8008496028178698	-122.236794562102943
47726	2020-08-25 22:54:33	2020-08-25	Dr. Larue Wilkinson MD	dr.larue.wilkinson.md@warmmail.com	Broken Arrow	Oklahoma	3435536796835363	45c266f4b456d1236ee846f7c95d3bb5	JCB 16 digit	35.9636084104664562	-95.691540057718754
47727	2020-08-25 23:11:23	2020-08-25	Rahn Schaefer-Rohan	rahn.schaefer.rohan@woohoo.com	El Paso	Texas	3714029573015990	b9808dc614095fe3c2559109e6aee3e0	VISA 16 digit	31.7913993523284795	-106.45493414290064
47728	2020-08-25 23:13:17	2020-08-25	Codey Hessel	codey.hessel@geemail.com	Springfield	Massachusetts	6011706248488862311	7720913ceb7d3bebff969735d4c14a1d	Voyager	42.1097178293596954	-72.4583936047367843
47729	2020-08-25 23:13:52	2020-08-25	Dr. Spencer Lang	dr.spencer.lang@geemail.com	Gilbert	Arizona	676245887578321	f39de0bb77da1619bf5ed3b5d9c56c7f	VISA 16 digit	33.2614323154903957	-111.755635852752619
47730	2020-08-25 23:15:55	2020-08-25	Dr. Luc Senger	dr.luc.senger@warmmail.com	Richmond	California	3112281080497696387	b9bfadeaf66a8d4d9878fe7d39bd9a45	VISA 13 digit	37.920996541478857	-122.346154965771746
47731	2020-08-25 23:26:30	2020-08-25	Ruthann Senger	ruthann.senger@geemail.com	Billings	Montana	180047182571851436	d3fd76b6c1493542d27f77ac8c6a8281	JCB 16 digit	45.8882511382680391	-108.472044309757266
47732	2020-08-25 23:29:20	2020-08-25	Vito Ritchie III	vito.ritchie.iii@geemail.com	Overland Park	Kansas	53666163365919092	e33f3caf8f0197e599ff8e4529765b2f	Maestro	38.9551151396576358	-94.619865711270279
47733	2020-08-25 23:30:40	2020-08-25	Deyanira Johnson-Stiedemann	deyanira.johnson.stiedemann@geemail.com	San Diego	California	180051631910226612	1061ee2860290191082b39fd3879ad88	VISA 16 digit	32.8117717004913843	-117.09417750168592
47734	2020-08-25 23:33:49	2020-08-25	Mrs. Dallas Brakus DVM	mrs.dallas.brakus.dvm@geemail.com	San Francisco	California	3112494572459046224	25739c44fe9aa0873f0bd355d6ec7c30	American Express	37.7852973015635101	-122.446966079222847
47735	2020-08-25 23:50:03	2020-08-25	Mathew Walter	mathew.walter@warmmail.com	Beaumont	Texas	4610027536445336	49d18d752596862a78274e797442cc32	Voyager	29.9858363396558936	-94.2299131759230164
47736	2020-08-25 23:53:06	2020-08-25	Phil McKenzie	phil.mckenzie@geemail.com	San Francisco	California	4078410945048	2f67bb094ba1c285a7c821309d1e50b3	American Express	37.748003579673167	-122.443749048934592
47737	2020-08-26 00:04:55	2020-08-26	Dorinda Hilll	dorinda.hilll@warmmail.com	Evansville	Indiana	4288002815466619	e5b664eabb2d12e5d244fddb6563df80	VISA 13 digit	37.8906706831090148	-87.6307928648710259
47738	2020-08-26 00:16:57	2020-08-26	Sina McLaughlin	sina.mclaughlin@geemail.com	Chicago	Illinois	561287071865338	93ef6142c35232eae30f0fdbd1ba5f3b	VISA 16 digit	41.8347233342308584	-87.5965441634908331
47739	2020-08-26 00:22:50	2020-08-26	Ruie Powlowski-Swift	ruie.powlowski.swift@geemail.com	Ventura	California	6011899600164267651	18a4f78b07e0b7dfaff964068a8fd6ca	JCB 16 digit	34.2463098463296873	-119.244613641883063
47740	2020-08-26 00:28:20	2020-08-26	Addisyn Greenfelder	addisyn.greenfelder@warmmail.com	Irvine	California	3000666615846613	bd3bf824fa2a695ab90fb03eec3a05af	JCB 16 digit	33.768016275532176	-117.677130203741783
47741	2020-08-26 00:39:58	2020-08-26	Samson Ryan	samson.ryan@warmmail.com	New York	New York	4673479075328759	80724d1fe62e1d02ba2403663042afbe	VISA 13 digit	40.5924956514257929	-74.0242040275491746
47742	2020-08-26 00:42:17	2020-08-26	Dr. Hank Skiles	dr.hank.skiles@geemail.com	New York	New York	4422389585948844	46ec17651b93c71843acfc964cd5c15f	VISA 16 digit	40.7532914332337697	-73.9376678623154788
47743	2020-08-26 01:08:37	2020-08-26	Marshall Waters-Lockman	marshall.waters.lockman@geemail.com	San Francisco	California	4782937224715182	d7e065f6062bf1d6cdbeed237e3d65e2	JCB 16 digit	37.7887808416229376	-122.414831235004115
47744	2020-08-26 01:09:47	2020-08-26	Duff Macejkovic-Cassin	duff.macejkovic.cassin@geemail.com	Hartford	Connecticut	4016467509154541	608baf9eb032e1dbb74c9a1ddc14517e	Mastercard	41.7334630443263848	-72.6563475991956977
47745	2020-08-26 01:12:44	2020-08-26	Carl Borer	carl.borer@geemail.com	Santa Ana	California	3337456434472866789	dcabb3f4b9d61a4d554dd58ba386c25d	Discover	33.6745493394892677	-117.942612667327737
47746	2020-08-26 01:35:25	2020-08-26	Bobbie Hettinger	bobbie.hettinger@geemail.com	Stockton	California	3158267272374300476	46469f4b24e25a64ec6d2407873a8f14	JCB 16 digit	37.9024343310587142	-121.399110495680191
47747	2020-08-26 01:42:29	2020-08-26	Dr. Tammi Friesen	dr.tammi.friesen@geemail.com	Denver	Colorado	4308441358634249	9635676a77e50e74a3d8d870092e206a	American Express	39.6668245133530348	-104.867281201972077
47748	2020-08-26 01:43:38	2020-08-26	Keagan Feil	keagan.feil@geemail.com	Fontana	California	180013444000687553	d1e7b6c493e40f65c0f07ca3a96c1c87	American Express	34.0942143645752225	-117.531093256156524
47749	2020-08-26 01:44:15	2020-08-26	Miss Louvenia Grady	miss.louvenia.grady@geemail.com	Fort Worth	Texas	6011624078006252417	cd4c5e52e4293891c0f5b85d19ed1935	VISA 16 digit	32.7007980326246468	-97.3729965599074916
47750	2020-08-26 01:47:07	2020-08-26	Dr. Isai Anderson	dr.isai.anderson@geemail.com	Waco	Texas	4193801850374768	abbec242a667161c54e69d3c27bae5e5	Voyager	31.6233871347013853	-97.1273107542321128
47751	2020-08-26 01:49:35	2020-08-26	Marlo Funk IV	marlo.funk.iv@warmmail.com	Dayton	Ohio	53889366411501738	af6c02cba3733942efd778a05b088138	Voyager	39.7817782563414397	-84.1885613869600036
47752	2020-08-26 01:52:32	2020-08-26	Trena Bailey	trena.bailey@geemail.com	San Antonio	Texas	3528390878593856492	70d9912c4ecff61541d07f4c8ebc26d9	Diners Club / Carte Blanche	29.3888371652994316	-98.5275580013006902
47753	2020-08-26 01:53:35	2020-08-26	Dr. Coen Bernhard DVM	dr.coen.bernhard.dvm@geemail.com	Tucson	Arizona	3034626303010910	10f19aa1387e174e2a2cd4c99f72e797	VISA 16 digit	32.2130370705895146	-110.886328504909201
47755	2020-08-26 01:56:39	2020-08-26	Clarabelle Beatty	clarabelle.beatty@warmmail.com	Los Angeles	California	3158890024724348621	d3915d939abef290f634a5539c081932	Mastercard	34.1147621198888871	-118.433175357756383
47756	2020-08-26 02:04:22	2020-08-26	Isam Hand	isam.hand@geemail.com	Oakland	California	3337805366460480439	4686801e0a59caddcb57b38433f1e492	JCB 16 digit	37.8080751375019091	-122.271844291669296
47757	2020-08-26 02:07:57	2020-08-26	Selah Schumm	selah.schumm@geemail.com	Orlando	Florida	869918624567271090	69520fa7825fc8cc32c10c52131df54f	Diners Club / Carte Blanche	28.4158643500212555	-81.2901915978606837
47758	2020-08-26 02:17:35	2020-08-26	Tasha Considine DVM	tasha.considine.dvm@geemail.com	Louisville	Kentucky	3498477831111565	f21d609fd961bc7eaf3a6053074ccd82	Diners Club / Carte Blanche	38.066282931239904	-85.5791862403113441
47759	2020-08-26 02:22:56	2020-08-26	Albertha Wisoky MD	albertha.wisoky.md@geemail.com	Houston	Texas	4242086203130759	a6b45d66713dfcec4679d25d1a2d744c	VISA 16 digit	29.8262978337783373	-95.4541047726772689
47760	2020-08-26 02:24:35	2020-08-26	Sallie Schmitt DVM	sallie.schmitt.dvm@geemail.com	Fresno	California	4020763624863394	79081347605afc0487062e68f8b40a99	Mastercard	36.755979840025681	-119.83555754480102
47761	2020-08-26 02:38:23	2020-08-26	Jazmin Barton	jazmin.barton@geemail.com	Huntington Beach	California	6011803737452383181	115d75ac5787cd2c5cd176fc1d0b9ed2	JCB 16 digit	33.6499540186993826	-117.912333117996525
47762	2020-08-26 02:38:25	2020-08-26	Moses Greenholt I	moses.greenholt.i@woohoo.com	Los Angeles	California	51342588026441692	46777d8f34b30534d2419da4c419bb9b	VISA 16 digit	34.0911500068712954	-118.320673713692642
47763	2020-08-26 02:41:19	2020-08-26	Dr. Jerod Ullrich	dr.jerod.ullrich@geemail.com	Indianapolis	Indiana	3337081094704307524	87813a802621eb44b0e88986d2a35ba6	Mastercard	39.8640384055215833	-86.1383844394903662
47764	2020-08-26 02:41:35	2020-08-26	Dr. Rob Rath	dr.rob.rath@warmmail.com	Kenosha	Wisconsin	4175272872363571	487ee2cb0d426e019be25ab8bf5d0570	JCB 16 digit	42.5755192528784292	-87.8593316631153272
47765	2020-08-26 02:49:17	2020-08-26	Almira Conroy	almira.conroy@woohoo.com	Omaha	Nebraska	6011315092231635431	64c82d4263f73d324b2c3a78ca64085d	VISA 16 digit	41.2874066379066562	-96.0501264983903695
47766	2020-08-26 02:50:07	2020-08-26	Miriam Pagac	miriam.pagac@woohoo.com	Houston	Texas	4243943092102	1d8bbf57baa6484ccba40f97dac37084	VISA 16 digit	29.7678746128533049	-95.4268831237699828
47767	2020-08-26 02:52:33	2020-08-26	Kayleigh Howell PhD	kayleigh.howell.phd@woohoo.com	San Francisco	California	3052748522125816	8452dc29be2a163051119548d45c0381	VISA 16 digit	37.7693479955254858	-122.466992299299761
47768	2020-08-26 02:55:16	2020-08-26	Dr. Pink Howell	dr.pink.howell@geemail.com	Chicago	Illinois	4759105741506323	f26e1b21fd2c9cd5214ac555bb718e63	Diners Club / Carte Blanche	41.8932344502605503	-87.6502148450847614
47769	2020-08-26 03:07:34	2020-08-26	Dr. Vernelle Harris DVM	dr.vernelle.harris.dvm@geemail.com	Berkeley	California	4845224597763	3b54116c24e554e93a8c02fcb0e38985	VISA 16 digit	37.8354601058821842	-122.271733714634067
47770	2020-08-26 03:18:11	2020-08-26	Miss Lainey Kunze MD	miss.lainey.kunze.md@warmmail.com	Shreveport	Louisiana	3096646988722272669	5d6d8a2d39cdef332e112247889c082f	JCB 16 digit	32.550825225865097	-93.7696111896287618
47771	2020-08-26 03:25:08	2020-08-26	Larae Sanford	larae.sanford@warmmail.com	Tacoma	Washington	869955305244455249	010eec5134740d5db21e06a4e21cfda0	Mastercard	47.2367899964217131	-122.492687992728506
47772	2020-08-26 03:25:50	2020-08-26	Harrell Koch	harrell.koch@geemail.com	Hayward	California	4818849241752	ed8c61af143be808aae3df098df80630	Discover	37.6309095999680494	-122.194068125800797
47773	2020-08-26 03:27:43	2020-08-26	Brant Bode	brant.bode@geemail.com	Honolulu	Hawaii	869929492143740245	9b4d7b8f056e38c11339c9856946ec4a	JCB 16 digit	21.3151542756456891	-157.756160542576026
47774	2020-08-26 03:56:45	2020-08-26	Rocky Schoen DDS	rocky.schoen.dds@geemail.com	Miami	Florida	210017071886320334	67c714827ce1606c8e3c82ca55dc4d24	Discover	25.7955960237093294	-80.2041828906036898
47775	2020-08-26 03:59:48	2020-08-26	Offie Sawayn	offie.sawayn@geemail.com	Atlanta	Georgia	561218121864492	c013814b5a80756c86dd5d59d04c8424	JCB 16 digit	33.7811616406586026	-84.4795325289525181
47776	2020-08-26 04:08:52	2020-08-26	Gwen Hansen	gwen.hansen@geemail.com	New Haven	Connecticut	4626295042982	0fb0143a6fa33474819c13cf32c00b25	Maestro	41.2736308531828229	-72.8283477742690621
47777	2020-08-26 04:12:31	2020-08-26	Daxton Price Jr.	daxton.price.jr.@geemail.com	San Francisco	California	3337654458849809537	e3c73694496805b92492c00ac2352100	Mastercard	37.7318372277834442	-122.405854670619206
47778	2020-08-26 04:16:01	2020-08-26	Perry Beer II	perry.beer.ii@woohoo.com	Sugar Land	Texas	6011855391022945850	0cfeba82a6a3d435967d518dd0bbc185	VISA 13 digit	29.5465472157631055	-95.5426270153380841
47779	2020-08-26 04:18:21	2020-08-26	Miss Yaritza Mosciski	miss.yaritza.mosciski@geemail.com	New York	New York	869935536146201100	c9ac4df6bc0730cb878832414dd03bbf	Discover	40.6796692793481043	-74.0229511571478014
47780	2020-08-26 04:18:52	2020-08-26	Maleah Hettinger	maleah.hettinger@geemail.com	Pomona	California	4122526960323118	059d28de06b1e3617ddbd7d69138aadf	Voyager	34.127233392050492	-117.684795633281027
47781	2020-08-26 04:19:44	2020-08-26	Jacques Mitchell	jacques.mitchell@geemail.com	Baton Rouge	Louisiana	4804897132457	cc5ee13dc72dbe459fd9ad927f7de95e	Mastercard	30.4061479297213246	-91.1653892345368888
47782	2020-08-26 04:27:19	2020-08-26	Angel Murazik	angel.murazik@geemail.com	Memphis	Tennessee	54274489327466292	9f535f5cc2017dab2967212cba50913b	Mastercard	35.0743041120070984	-89.9373240497220365
47783	2020-08-26 04:27:52	2020-08-26	Werner Fadel	werner.fadel@geemail.com	Clarksville	Tennessee	3450136003959112	eff67d08a0f89a0002a8fe5a529cadf0	Mastercard	36.5949605119541275	-87.3831737085197204
47784	2020-08-26 04:28:29	2020-08-26	Jaheim Bartoletti	jaheim.bartoletti@geemail.com	New York	New York	4229515361885090	fd821decb39ababd99ce57060b8adf85	JCB 16 digit	40.6158222441319339	-73.9386593289103331
47785	2020-08-26 04:51:15	2020-08-26	Lavenia Lowe MD	lavenia.lowe.md@woohoo.com	Fort Lauderdale	Florida	4847170726156	9f6073bfc236dc00907c0bc2e115d5c9	Mastercard	26.1432508176181493	-80.1945799208533003
47786	2020-08-26 04:55:17	2020-08-26	Tia Crist	tia.crist@geemail.com	Ontario	California	4571001422310	0f8a69d216a973ade64953a8d25ccec0	Diners Club / Carte Blanche	34.1166584497462964	-117.622260331745082
47787	2020-08-26 04:55:26	2020-08-26	Brandi Ryan	brandi.ryan@geemail.com	Winston–Salem	North Carolina	4762347743919253	d83b2ce74e75fb3b0713e0c6b42009a9	VISA 13 digit	36.124244782724233	-80.2902852578218926
47788	2020-08-26 04:57:48	2020-08-26	Jermaine Graham-Wilderman	jermaine.graham.wilderman@geemail.com	San Diego	California	52937396837971829	64f5c39e8e8bb65771e51dbb201f83a4	Maestro	32.8892374382421409	-117.074326728368177
47789	2020-08-26 05:01:15	2020-08-26	Miss Maxie Ebert	miss.maxie.ebert@geemail.com	Chicago	Illinois	4966827741938623	ce2c9479ea11e67f742b3115889990fd	VISA 13 digit	41.8526714572984773	-87.7582987319707826
47790	2020-08-26 05:05:19	2020-08-26	Renard Kassulke	renard.kassulke@woohoo.com	Simi Valley	California	3775483103211031	2bbc349a3101abffb16c2dcab638449e	JCB 16 digit	34.2631135334033488	-118.815098613047979
47791	2020-08-26 05:13:25	2020-08-26	Lissie Smitham	lissie.smitham@warmmail.com	Phoenix	Arizona	4513067879769403	323fe9d79fbb96f4f266460d46a9b689	JCB 16 digit	33.5586076173398666	-112.092721523290876
47792	2020-08-26 05:19:06	2020-08-26	Trilby Heller	trilby.heller@warmmail.com	San Antonio	Texas	53373793170891013	82680378a798ddf8cd1ce39a08f41185	JCB 15 digit	29.4087657783716914	-98.4413194122094666
47793	2020-08-26 05:29:11	2020-08-26	Tomasa DuBuque	tomasa.dubuque@woohoo.com	Seattle	Washington	6011107601028097498	6799d3fde19022f0d8ccb383dd42bf08	Mastercard	47.6684131485801217	-122.383941623793532
47794	2020-08-26 05:34:21	2020-08-26	Dr. Vincenzo Larkin	dr.vincenzo.larkin@geemail.com	Denton	Texas	6011809141590567207	8f5c948fcb9f5a6baba294da7e11a09b	JCB 16 digit	33.286322737651318	-97.049974790041901
47795	2020-08-26 05:37:35	2020-08-26	Lenora Crooks-Kovacek	lenora.crooks.kovacek@geemail.com	El Paso	Texas	4862278949618705	2efd461415f01b4183039a85b979f303	Diners Club / Carte Blanche	31.8827733936082574	-106.465936450798068
47796	2020-08-26 05:51:29	2020-08-26	Jed Barrows DDS	jed.barrows.dds@geemail.com	Houston	Texas	3785967992614527	41576a518b9dcf6994d4c4ab15a6a92e	JCB 16 digit	29.8326313589777783	-95.3444737597383636
47797	2020-08-26 05:51:49	2020-08-26	Aldo Cormier DDS	aldo.cormier.dds@geemail.com	Nashville	Tennessee	3051650588910167	22b1df40bddb1376e1681b9b83cfe900	JCB 15 digit	36.1329028006300277	-86.7777285937126663
47798	2020-08-26 05:54:13	2020-08-26	Kaila Crist	kaila.crist@geemail.com	Oakland	California	180095312487494655	2f6f724fbd65e9b55ef6324e77c2be56	VISA 16 digit	37.8394783483947279	-122.234915508577174
47799	2020-08-26 06:03:01	2020-08-26	Jetta Rau-Weber	jetta.rau.weber@warmmail.com	Washington	District of Columbia	52325506938381930	d825b0f3b43bea55dd9f3a3f82de6496	Voyager	38.962150153730434	-77.074800535778337
47800	2020-08-26 06:05:45	2020-08-26	Baldwin Okuneva	baldwin.okuneva@warmmail.com	Los Angeles	California	3013432684111703	61239bc18d92586acea527e8267f4770	VISA 13 digit	34.0348232770670194	-118.391984251932428
47801	2020-08-26 06:13:09	2020-08-26	Jaden Halvorson	jaden.halvorson@geemail.com	New York	New York	869912387891278076	29f291283e26b3b8ce11b3080746915f	JCB 16 digit	40.7105637647435046	-73.9558685586217734
47802	2020-08-26 06:14:13	2020-08-26	Bree Gutmann	bree.gutmann@geemail.com	Moreno Valley	California	4998422747325306	8867f5a1a260ab3f6e68b83663fdda8a	JCB 16 digit	33.8240086176890884	-117.21445256927683
47803	2020-08-26 06:18:13	2020-08-26	Arlie Powlowski	arlie.powlowski@geemail.com	Arlington	Texas	6011521323426763245	ec38b62626dd168147dad8e828149bcc	Maestro	32.7504755280695861	-97.2231297639224721
47804	2020-08-26 06:22:31	2020-08-26	Dimitri Stark-Kautzer	dimitri.stark.kautzer@geemail.com	Lansing	Michigan	3432090185127480	fc465f9789e4366b776c2326540c1bd0	JCB 16 digit	42.745174809250237	-84.4999540035270087
47805	2020-08-26 06:48:24	2020-08-26	Dr. Jabez Jones	dr.jabez.jones@geemail.com	Oklahoma City	Oklahoma	3463930635954656	701c6d77e2a47ce64afe6af4880aed26	JCB 15 digit	35.4467201267279677	-97.4469573338411692
47806	2020-08-26 06:52:36	2020-08-26	Lavona Pagac	lavona.pagac@geemail.com	Durham	North Carolina	4559966988992621	5b69a444fe8f59b79e87653b30940e9f	VISA 16 digit	35.9891712656490483	-78.8080155855413551
47807	2020-08-26 06:53:26	2020-08-26	Posey Wintheiser	posey.wintheiser@warmmail.com	Chicago	Illinois	502099944581307	82c645359e97556051ff0ce9a7287f4f	JCB 16 digit	41.8107308294460225	-87.7260306535784053
47808	2020-08-26 07:01:31	2020-08-26	Linwood Gulgowski	linwood.gulgowski@geemail.com	San Francisco	California	6011624371692557946	975dd70aca9e504b9701907921a712f1	American Express	37.7716908377394276	-122.461193758523081
47809	2020-08-26 07:07:02	2020-08-26	Alayna Hudson	alayna.hudson@warmmail.com	Berkeley	California	3528120762214343741	5e0cba155257911380d5d45205d06715	JCB 16 digit	37.8881924920223838	-122.252937257338189
47810	2020-08-26 07:12:40	2020-08-26	Heidy Huel	heidy.huel@geemail.com	El Paso	Texas	060450668722338	26b17a8935a02683a51f2c598e38d77f	JCB 16 digit	31.8047093004748227	-106.398343120886025
47811	2020-08-26 07:13:37	2020-08-26	Brooke Armstrong-Watsica	brooke.armstrong.watsica@geemail.com	San Francisco	California	210024149187038184	89a5c206373fe9506fa8e46924116a24	Mastercard	37.7722341993774222	-122.438338727015235
47812	2020-08-26 07:14:06	2020-08-26	Elgin Trantow	elgin.trantow@geemail.com	Omaha	Nebraska	3096063110081972888	7cfa5c5b60b596edc1db45ef72d3c188	VISA 13 digit	41.2156026492040652	-95.9798128881141537
47813	2020-08-26 07:15:29	2020-08-26	Ulises Hudson	ulises.hudson@woohoo.com	West Jordan	Utah	55030853791875566	9d0f548094e45be1ff979c1164cba3a9	VISA 16 digit	40.6337165570609287	-112.017740674372021
47814	2020-08-26 07:17:36	2020-08-26	Tal Smith	tal.smith@geemail.com	San Francisco	California	180045277602273105	e9797f6b9a9ecd11c0d85a55f3f1068f	Maestro	37.7669896057777592	-122.438052262430162
47815	2020-08-26 07:32:17	2020-08-26	Marcie Hodkiewicz-Watsica	marcie.hodkiewicz.watsica@geemail.com	San Francisco	California	501830240043833	bd4706497eccacf6911801c7ebe33928	Maestro	37.7644022838772671	-122.420704743685718
47816	2020-08-26 07:33:35	2020-08-26	Coraima Schoen	coraima.schoen@warmmail.com	Charlotte	North Carolina	4304949639837179	20345488efd49504f3acd530fcf4cec0	VISA 13 digit	35.2960448531221616	-80.8449097561594101
47817	2020-08-26 07:52:01	2020-08-26	Artis Walsh MD	artis.walsh.md@geemail.com	Kenosha	Wisconsin	3462202008844919	7f2959e9231af56f94316f9654c87d61	JCB 16 digit	42.5402514481291192	-87.8279718709405586
47818	2020-08-26 08:00:16	2020-08-26	Tatyana Schinner	tatyana.schinner@geemail.com	Tampa	Florida	3528435845648911074	87d04d4082dd3446db950fe01115b6f9	Maestro	28.0639571984414005	-82.4306808124508592
47819	2020-08-26 08:06:27	2020-08-26	Vanesa Murray	vanesa.murray@geemail.com	San Francisco	California	4591217838319528	0b644714513c454a39fb8311cc624bb0	Discover	37.7742673623399554	-122.421775959149855
47820	2020-08-26 08:11:30	2020-08-26	Esther Crist	esther.crist@geemail.com	West Jordan	Utah	4211974160544	a2a905facedc5a5e03e54702369595f9	VISA 16 digit	40.5025552382484122	-111.936514904172341
47821	2020-08-26 08:13:47	2020-08-26	Amirah Wisozk	amirah.wisozk@woohoo.com	Long Beach	California	3428781506913519	a6a402d684ea452f6f08159c58b9d82c	Mastercard	33.9001773870371252	-118.253348744956028
47822	2020-08-26 08:20:07	2020-08-26	Ms. Mai Cummings DDS	ms.mai.cummings.dds@geemail.com	San Francisco	California	6011787988333724644	963a9d30326f644e7c5679a55368ef4f	VISA 16 digit	37.7570756671397589	-122.466450260804535
47823	2020-08-26 08:26:02	2020-08-26	Miss Bina Wintheiser DVM	miss.bina.wintheiser.dvm@geemail.com	New York	New York	4269546686144278	c4b97ddf93bf28551b8bdd1109a20c9a	Diners Club / Carte Blanche	40.7267388846483058	-73.9078580877173721
47824	2020-08-26 08:44:31	2020-08-26	Littleton Frami	littleton.frami@geemail.com	Oakland	California	3000348281513237	6fff869406a79db98eabb40fc6cb2bef	Diners Club / Carte Blanche	37.7725123339758042	-122.270865922382953
47825	2020-08-26 08:46:17	2020-08-26	Isadore Schamberger-Oberbrunner	isadore.schamberger.oberbrunner@woohoo.com	New York	New York	3158254688754233398	802c3315ac81fef541eaad1156bf360c	Maestro	40.7075975206904133	-73.977000031749526
47826	2020-08-26 08:50:56	2020-08-26	Racheal Schowalter	racheal.schowalter@geemail.com	San Diego	California	3476475717361599	1c487ab6cebe0ffc03bab504e49ba90a	JCB 15 digit	32.8147251086842289	-117.207772219823681
47827	2020-08-26 08:54:08	2020-08-26	Pershing Bode-Nienow	pershing.bode.nienow@geemail.com	Honolulu	Hawaii	6011098721398193528	8f78e03aabc94a68f6c47e716ba20fee	Voyager	21.2773653777997964	-157.934090512546163
47828	2020-08-26 09:02:00	2020-08-26	Carroll Champlin	carroll.champlin@geemail.com	Philadelphia	Pennsylvania	3096786921775499673	70e6591c45e321d370b3ed955f0dc553	JCB 15 digit	40.0113991350360223	-75.2056805466666844
47829	2020-08-26 09:16:08	2020-08-26	Miss Lara Johns PhD	miss.lara.johns.phd@geemail.com	Lancaster	California	4589084911173	b0ccc00de7b168bccc14212e435e7c79	JCB 16 digit	34.7841961820390111	-118.177233510694649
47830	2020-08-26 09:18:53	2020-08-26	Delphin Considine-Skiles	delphin.considine.skiles@woohoo.com	Chicago	Illinois	3005286604945576	9147223a0b7064eaa66a526d447ff8be	American Express	41.8538081649526958	-87.6147045500140536
47831	2020-08-26 09:39:31	2020-08-26	Dr. Attilio Hermann	dr.attilio.hermann@woohoo.com	Kansas City	Missouri	3112907916515060334	c9882ee103b9d06e23821ccb29db79e0	Mastercard	39.1283304240856324	-94.4644621195960781
47832	2020-08-26 09:49:37	2020-08-26	Ricardo Becker	ricardo.becker@woohoo.com	Philadelphia	Pennsylvania	180068747953857070	93852816b123ece61ebb547ce508eb3b	JCB 15 digit	40.0285964267753087	-75.0483723463390078
47833	2020-08-26 09:55:42	2020-08-26	Kimberley Hane	kimberley.hane@woohoo.com	Berkeley	California	55531581684221317	9a39c4a7e7d18e0be6c6062763851b0c	VISA 13 digit	37.8816639712162981	-122.279675804381327
47834	2020-08-26 10:01:00	2020-08-26	Hester Mosciski	hester.mosciski@warmmail.com	New York	New York	6011818666923751309	0a93ad31c57e7e49cfe85ccc5be1c800	American Express	40.7244349232632672	-73.9908525913849502
47835	2020-08-26 10:01:45	2020-08-26	Dulcie Koelpin PhD	dulcie.koelpin.phd@warmmail.com	New York	New York	3088786108269458825	b04e7ac916e234d9bfd48b57292db4ee	Maestro	40.5826868145484454	-73.9521158234577598
47836	2020-08-26 10:16:44	2020-08-26	Dr. Deante Hills	dr.deante.hills@geemail.com	Frisco	Texas	6011469164073306787	503d27e0d37406855836d1e0c10cd1aa	JCB 15 digit	33.0912761300332861	-96.7827111168041796
47837	2020-08-26 10:18:14	2020-08-26	Ms. May Wisoky DDS	ms.may.wisoky.dds@geemail.com	San Francisco	California	869939868396723616	bfadfbaa066661d54adb47c319d63157	Diners Club / Carte Blanche	37.7778005275269706	-122.421649914134306
47838	2020-08-26 10:21:22	2020-08-26	Stacey Leffler	stacey.leffler@geemail.com	Chula Vista	California	210095765750400719	272228989d924bc1df689a5ec083cfad	VISA 13 digit	32.6130059513959978	-117.025215082685264
47839	2020-08-26 10:22:57	2020-08-26	Billie Romaguera	billie.romaguera@warmmail.com	Port St. Lucie	Florida	180063671660159585	2d4a21dca5394be49211e4e15d9ce01a	VISA 13 digit	27.1902749158576142	-80.307136907017977
47840	2020-08-26 10:23:45	2020-08-26	Dr. Violeta Sporer MD	dr.violeta.sporer.md@geemail.com	Philadelphia	Pennsylvania	869927477628470261	3c08a2b890eb77aaf64eea825da4ed19	Maestro	40.0702517597429448	-75.0693811498016146
47841	2020-08-26 10:31:43	2020-08-26	Malvina Lang	malvina.lang@geemail.com	Houston	Texas	4808132861402613	26c460571d210b585e7c6443a5817b8d	Mastercard	29.869798036532849	-95.3397144565373651
47842	2020-08-26 10:33:36	2020-08-26	Mrs. Vonetta Metz MD	mrs.vonetta.metz.md@geemail.com	El Paso	Texas	4238204899906	e573a517f826586a54dc85abfe3225c4	Diners Club / Carte Blanche	31.8372945936225378	-106.37047012117506
47843	2020-08-26 11:15:10	2020-08-26	Monna Moore MD	monna.moore.md@geemail.com	Los Angeles	California	4255037200569519	4aab1338ce4128e0761e0df5f071510b	Maestro	34.0186466290481349	-118.451808884739123
47844	2020-08-26 11:19:39	2020-08-26	Melvin Carter MD	melvin.carter.md@geemail.com	Berkeley	California	4678773144685321	eee3748b9def71a6e75383c00100b2af	Mastercard	37.8757578742138392	-122.270951210913324
47845	2020-08-26 11:29:41	2020-08-26	Darryll Wilkinson III	darryll.wilkinson.iii@geemail.com	Waterbury	Connecticut	4779805056404	0b2dca234178198a15f3ddcf053c1a9b	JCB 16 digit	41.4658334713932177	-73.0984449109908212
47846	2020-08-26 11:30:11	2020-08-26	Dr. Daryl Konopelski DVM	dr.daryl.konopelski.dvm@geemail.com	Plano	Texas	4951845688728465	cdac3d73f3df48003318b614d214db5f	Mastercard	33.1061793270606586	-96.6891631227169199
47847	2020-08-26 11:31:35	2020-08-26	Rheta Runolfsson	rheta.runolfsson@geemail.com	Portland	Oregon	3456133079842920	c3fc8650905cec6c5b9b1004493798c8	Diners Club / Carte Blanche	45.5009815550297461	-122.554979956522587
47848	2020-08-26 11:31:45	2020-08-26	Dakoda Deckow-Stark	dakoda.deckow.stark@geemail.com	Rockford	Illinois	3765503760772561	acdaf78cd36f064ab3708746c35a29af	VISA 16 digit	42.2336048590496205	-89.0954519404381529
47849	2020-08-26 11:31:51	2020-08-26	Dr. Andy McDermott	dr.andy.mcdermott@geemail.com	Chicago	Illinois	3055314145965349	7bff81b518a4406bbf1008f3939703dd	Voyager	41.7964500629644888	-87.5840836301941437
47850	2020-08-26 11:56:45	2020-08-26	Carson Williamson	carson.williamson@warmmail.com	Chattanooga	Tennessee	3096293304877578171	5da0df9ffe68315d40fd1941fe962265	Mastercard	34.9713227281663563	-85.3062677896875954
47851	2020-08-26 12:21:51	2020-08-26	Miss Amy Dickens	miss.amy.dickens@woohoo.com	Oakland	California	502000379353923	670a07e605834470b36b365f3e4b5ece	Diners Club / Carte Blanche	37.8419248207639285	-122.258221454840495
47852	2020-08-26 12:24:20	2020-08-26	Woodroe Mohr	woodroe.mohr@geemail.com	Manchester	New Hampshire	3096387042481669930	11cc4372226cd09a609746b8e7c70374	JCB 16 digit	43.0800067149173529	-71.4892611194294005
47853	2020-08-26 12:25:59	2020-08-26	Mikel Schowalter	mikel.schowalter@warmmail.com	Indianapolis	Indiana	6011529764605138984	b0fc9b728ec9ee23390e4607a1148921	VISA 16 digit	39.7695099422715614	-86.1896650762964072
47854	2020-08-26 12:30:07	2020-08-26	Luberta Kassulke	luberta.kassulke@warmmail.com	San Francisco	California	4862524042675757	c41a26677cdd6aafd653dd70825ee726	JCB 16 digit	37.7653139565708216	-122.451429950778589
47855	2020-08-26 12:32:42	2020-08-26	Dr. Lanette Crooks	dr.lanette.crooks@woohoo.com	El Paso	Texas	4122277555612685	92e127824a98ab9d9e6190f374267ee0	VISA 16 digit	31.8566419907208562	-106.522762306079272
47856	2020-08-26 13:00:58	2020-08-26	Riya Kertzmann	riya.kertzmann@geemail.com	Charlotte	North Carolina	3013463416697438	664717a0d82b2c85bc56c6ebda48d551	VISA 16 digit	35.2858160923488455	-80.8574911171048853
47857	2020-08-26 13:03:06	2020-08-26	Dr. Astrid Bechtelar	dr.astrid.bechtelar@warmmail.com	New York	New York	3784015570615952	fea0dbed2b7bead8aa659561759586d6	Discover	40.642460443241518	-73.8407875049754949
47858	2020-08-26 13:16:58	2020-08-26	Shona Bogisich-Hamill	shona.bogisich.hamill@geemail.com	New York	New York	180076621806157006	8fa946b14d9f5b3e6b372f822a589104	JCB 16 digit	40.6027039705999186	-74.0092054446589174
47859	2020-08-26 13:23:12	2020-08-26	Jaeden Lebsack	jaeden.lebsack@geemail.com	Columbus	Ohio	3528242025402213289	af3f0697f5e6fd6ca57443406ba02928	JCB 16 digit	39.9299583739180122	-82.9962611702505626
47860	2020-08-26 13:24:08	2020-08-26	Goebel Romaguera-Rohan	goebel.romaguera.rohan@geemail.com	Rochester	New York	3158480086410080590	a4c988e4360c2e7b0c6ee64073f738a0	Maestro	43.2354969645828007	-77.6338586737640242
47861	2020-08-26 13:33:42	2020-08-26	Dr. Ely Bernier DVM	dr.ely.bernier.dvm@warmmail.com	New York	New York	3447655749122376	5f8280d2f48ce1612c66a29f7193e382	Mastercard	40.6546783472169153	-73.9569282771449537
47862	2020-08-26 13:35:24	2020-08-26	Haywood Howell	haywood.howell@woohoo.com	Henderson	Nevada	3096981112692061290	fb2642a0676d479c998be48eb921bf3a	Discover	36.0567403796993204	-115.040944697257885
47863	2020-08-26 13:39:03	2020-08-26	Mr. Iverson Olson DDS	mr.iverson.olson.dds@geemail.com	Colorado Springs	Colorado	6011457638616255241	5609e5f85feab36ad637979f13a8ea27	VISA 16 digit	38.9380418264355512	-104.848836279396707
47864	2020-08-26 13:40:13	2020-08-26	Darrius Koss	darrius.koss@geemail.com	Philadelphia	Pennsylvania	3112166865477048223	1fbd8f2bb04d98a485c4d9a2737b1650	Maestro	39.9632774335291217	-75.1250384174652481
47865	2020-08-26 13:51:50	2020-08-26	Cruz Gutmann	cruz.gutmann@warmmail.com	San Francisco	California	6011417017342725588	552d190915f16a64cf79165f7dd6df19	American Express	37.7804847867334601	-122.433020675716506
47866	2020-08-26 14:01:50	2020-08-26	Damari Schimmel-Oberbrunner	damari.schimmel.oberbrunner@warmmail.com	Irving	Texas	180025870353328674	ad923ba254fba005e2eebcb059a39cb3	Maestro	32.9384678848970722	-97.0280748038366454
47867	2020-08-26 14:02:11	2020-08-26	Atha Hartmann-Davis	atha.hartmann.davis@geemail.com	New York	New York	869928361812305419	0d953ef5d27147878f80336b89051237	American Express	40.6823056014943845	-73.9109941683139624
47868	2020-08-26 14:05:15	2020-08-26	Louie Williamson	louie.williamson@woohoo.com	Chicago	Illinois	210050913001489510	39deb7295f63d14fcc03da8d4fb3c03b	VISA 16 digit	41.8545278847985003	-87.7227138682764007
47869	2020-08-26 14:31:37	2020-08-26	Toivo Fritsch	toivo.fritsch@geemail.com	Jacksonville	Florida	4179757722758	073363d2ce6861b4d2760661f07e46bf	Voyager	30.3397154945466667	-81.5738157242149242
47870	2020-08-26 14:41:20	2020-08-26	Mrs. Fae Dietrich DDS	mrs.fae.dietrich.dds@geemail.com	Tulsa	Oklahoma	3016715861610290	37ccaec26908ca7024cc3bdc9769a752	VISA 13 digit	36.0367112016674085	-95.80974606391527
47871	2020-08-26 14:41:55	2020-08-26	Evelyn Farrell MD	evelyn.farrell.md@geemail.com	Ontario	California	3158758409759273284	e370e12ef5ef9a592accf8e2bd1cd7b0	VISA 16 digit	33.9415903735119855	-117.5966454159569
47872	2020-08-26 14:57:45	2020-08-26	Deron Huels	deron.huels@geemail.com	El Paso	Texas	4721446041796296	3b7565b070383eaeba497cf493864529	Diners Club / Carte Blanche	31.8509559885893019	-106.514880977196626
47873	2020-08-26 15:07:26	2020-08-26	Selah Cormier	selah.cormier@woohoo.com	Madison	Wisconsin	3449677112140304	abac34f179b3f4f082f9c558d485b080	Mastercard	43.056185816784577	-89.5123582132510904
47874	2020-08-26 15:08:14	2020-08-26	Dr. Evia Wunsch	dr.evia.wunsch@geemail.com	Berkeley	California	3791557388353186	b51cfeaaf52dea3cff9784939f294b18	VISA 16 digit	37.8474837906546995	-122.295414360163178
47875	2020-08-26 15:11:43	2020-08-26	Charla Russel	charla.russel@woohoo.com	San Antonio	Texas	3001622631024635	9c83f6e3e97f0d257760275dbeff604e	VISA 16 digit	29.477187625884639	-98.5604079039137702
47876	2020-08-26 15:29:00	2020-08-26	Rolland Stoltenberg	rolland.stoltenberg@woohoo.com	Oakland	California	210038355835979430	ee9a847680ae6d206bc37a3fed3dc982	VISA 16 digit	37.8243768973143304	-122.285211475844179
47877	2020-08-26 15:29:48	2020-08-26	Lute Gerlach-Crooks	lute.gerlach.crooks@geemail.com	Washington	District of Columbia	6011687618240053644	c23db6f52153fddfd4f305da816f2278	VISA 16 digit	38.9199184817526458	-77.0592826693996784
47878	2020-08-26 15:30:37	2020-08-26	Arlene Swaniawski	arlene.swaniawski@geemail.com	Springfield	Massachusetts	869962645266183364	6e9e2448b5596f208f4c5f134085ebf2	JCB 16 digit	42.131045321349049	-72.5333999552857165
47879	2020-08-26 15:37:50	2020-08-26	Merlene Lueilwitz-Spencer	merlene.lueilwitz.spencer@woohoo.com	Winston–Salem	North Carolina	3528590136776755447	d3b24b643a13c7be2c4c20f55c20ccdb	Discover	36.1893126749198899	-80.2986733466982798
47880	2020-08-26 15:43:12	2020-08-26	Sylvanus Dickinson	sylvanus.dickinson@woohoo.com	Rockford	Illinois	4815049415046921	64f62c2d1bef33b22de04d73ad5dd3f5	VISA 16 digit	42.1687806749727585	-88.9656534387081877
47881	2020-08-26 15:44:14	2020-08-26	Dr. Alec Braun Jr.	dr.alec.braun.jr.@warmmail.com	Denver	Colorado	52998163418190005	f7722921de5f6475b381ff22c232cb2f	American Express	39.7164850662048892	-104.946841227939728
47882	2020-08-26 15:47:29	2020-08-26	Yancy Klein	yancy.klein@geemail.com	Colorado Springs	Colorado	4455384073199	45482aecb75614479d759060c2888823	VISA 16 digit	38.8255614040002257	-104.844066588829079
47883	2020-08-26 16:06:10	2020-08-26	Beaulah Champlin	beaulah.champlin@geemail.com	Oakland	California	4048314070549596	f7d2cece68bd75c0ae45c545455fe3d9	JCB 15 digit	37.8110662275596852	-122.283797061950224
47884	2020-08-26 16:27:14	2020-08-26	Hamp Lakin	hamp.lakin@woohoo.com	Jersey City	New Jersey	6011361747519249691	6c873aeb6d8c041ae416c304b6f75b41	American Express	40.6436559312917254	-74.0473416650157503
47885	2020-08-26 16:30:58	2020-08-26	Denzil Parisian	denzil.parisian@warmmail.com	Jackson	Mississippi	4852973816683	af7b8eb6556c7997382a98bc7143578c	Diners Club / Carte Blanche	32.2413623316392304	-90.2705578274533167
47886	2020-08-26 16:35:45	2020-08-26	Mr. Misael Kuhic	mr.misael.kuhic@geemail.com	San Francisco	California	675954216467560	09e20dbff09ec928bac3002a86b5efad	VISA 16 digit	37.7748950613676016	-122.443058216325014
47887	2020-08-26 16:36:45	2020-08-26	Xander D'Amore	xander.d'amore@geemail.com	Minneapolis	Minnesota	869914958438502059	3ffe6c9842fc6e909e3458ba55530238	JCB 16 digit	44.9971450991548565	-93.2741737198822136
47888	2020-08-26 16:40:57	2020-08-26	Earl Haag-Boyle	earl.haag.boyle@geemail.com	New York	New York	3059111425924103	081288d67cac1ed3cab4f84f8301dec0	Mastercard	40.6558581636976442	-73.927031582210958
47889	2020-08-26 16:54:22	2020-08-26	Tiny Feil	tiny.feil@warmmail.com	Oakland	California	55570530681990335	722f080882f8b9ba8e640d506594d1c0	JCB 15 digit	37.7962995662963692	-122.292961225699173
47890	2020-08-26 16:57:23	2020-08-26	Jackson Ritchie	jackson.ritchie@geemail.com	Los Angeles	California	3040708980460982	796aac3dbb23dded854b3d5f87cf4456	VISA 16 digit	34.0749393894668628	-118.387225982965148
47891	2020-08-26 16:57:27	2020-08-26	Spencer Sawayn	spencer.sawayn@geemail.com	Jackson	Mississippi	6011340090830915930	1b0c2a4b822234946d5252911498f4b4	American Express	32.3187662598390162	-90.2430425152622178
47892	2020-08-26 17:12:29	2020-08-26	Starling Rolfson	starling.rolfson@woohoo.com	Philadelphia	Pennsylvania	3782425882506611	03b839afea38f108c26119112161b0b4	JCB 16 digit	40.092984480406713	-75.2307375378806142
47893	2020-08-26 17:21:56	2020-08-26	Mack Jacobson	mack.jacobson@warmmail.com	Berkeley	California	3049541038466474	fca9a417058acf6e03d2eeae5b64b9b8	VISA 13 digit	37.8595400067446661	-122.271934043123196
47894	2020-08-26 17:23:03	2020-08-26	Raven Orn	raven.orn@geemail.com	Henderson	Nevada	3463081012308122	051957dd42dce9fed1fa84665670d6e3	JCB 16 digit	35.9257988941323063	-115.115228742609546
47895	2020-08-26 17:26:22	2020-08-26	Acie Bauch-Gislason	acie.bauch.gislason@geemail.com	Tulsa	Oklahoma	210065455452334145	e3f97d6d1be34839aeeebe23ab5ac52e	Maestro	36.051696374350783	-95.8921121269419814
47896	2020-08-26 17:35:54	2020-08-26	Marjorie Murphy	marjorie.murphy@geemail.com	St. Petersburg	Florida	3158942308479443960	241228f74f4ea28be8da089195d4147a	JCB 16 digit	27.7685290766768169	-82.6422967892497695
47897	2020-08-26 17:42:55	2020-08-26	Meagan Morissette	meagan.morissette@geemail.com	Colorado Springs	Colorado	3795425085869803	e65e4fb4342aa6797e3e29fc4f4c7449	Discover	38.8302829413723174	-104.815212298805633
47898	2020-08-26 17:56:30	2020-08-26	Armani Greenfelder	armani.greenfelder@geemail.com	Houston	Texas	180087643744707970	d73defd73bf6cc71e802a476d7f57560	VISA 13 digit	29.8421375318974249	-95.3599680602099795
47899	2020-08-26 18:10:21	2020-08-26	Miss Marylouise Feest	miss.marylouise.feest@geemail.com	Seattle	Washington	3158855574972129134	6a0b0d7d562c8d3f754910ac19b53271	VISA 16 digit	47.6482494392357765	-122.431835556581234
47900	2020-08-26 18:14:09	2020-08-26	Ms. Delois Parker PhD	ms.delois.parker.phd@geemail.com	Carlsbad	California	676130625789083	16aa6ec253eee8bd3d035fde2bc16c7f	Maestro	33.1361546553146056	-117.364551096295187
47901	2020-08-26 18:15:38	2020-08-26	Sigmund O'Reilly-Heathcote	sigmund.o'reilly.heathcote@geemail.com	Los Angeles	California	6011162773139318436	9acc1d5b141f5af2f62b71dc6f491ba9	JCB 16 digit	33.993783846297859	-118.388445230991763
47902	2020-08-26 18:22:45	2020-08-26	Levi Russel	levi.russel@woohoo.com	New York	New York	3033921384301432	e0ddfc47bcd67bacf19874c45dae4a0f	JCB 16 digit	40.7619752282034611	-73.9015226385451882
47903	2020-08-26 18:33:58	2020-08-26	Bobbie Ebert-Muller	bobbie.ebert.muller@geemail.com	Corpus Christi	Texas	4334488404342994	151a13fe0c690f5d73bc02d366a11db0	Discover	27.7487722085259847	-97.2456948862705417
47904	2020-08-26 18:37:30	2020-08-26	Unknown Volkman	unknown.volkman@geemail.com	San Bernardino	California	676229217454403	347a49be5a3566941b3d16e291b56b91	JCB 15 digit	34.1905973327610582	-117.347955290159575
47905	2020-08-26 18:41:29	2020-08-26	Jodi Harber	jodi.harber@geemail.com	Los Angeles	California	3052463655504593	e4f40445a259e12b60cea50a12bdbc91	Voyager	34.0602227320294801	-118.444374952743942
47906	2020-08-26 18:42:23	2020-08-26	Rudolfo Willms	rudolfo.willms@warmmail.com	New York	New York	4157525549189329	0d97127de31fcc798e6e5ab5c0f7ae7c	JCB 16 digit	40.6972750807870156	-73.9030859699368392
47907	2020-08-26 18:59:06	2020-08-26	Yee Lind	yee.lind@geemail.com	Saint Paul	Minnesota	869975706589952219	04f2b8c716d0ea245aa08413756f9b5e	VISA 16 digit	45.0312492860887232	-93.1762816919278407
47908	2020-08-26 19:18:32	2020-08-26	Chalmer Reynolds II	chalmer.reynolds.ii@geemail.com	Simi Valley	California	4031841646609925	0431b72252893a06f0e30108741d6dc9	VISA 13 digit	34.1766620843909692	-118.846692121926708
47909	2020-08-26 19:21:44	2020-08-26	Dimitrios Dach	dimitrios.dach@geemail.com	Frisco	Texas	6011025486894744814	1dc2388c0e1ee27d40e6aea530594617	VISA 16 digit	33.1783556036181722	-96.824819752641389
47910	2020-08-26 19:22:26	2020-08-26	Dr. Brendan Heidenreich	dr.brendan.heidenreich@geemail.com	Tacoma	Washington	3463914044661458	0922cd2f1fd55f56897bc2dee7ef51b8	American Express	47.1918463440265512	-122.496902307984612
47911	2020-08-26 19:24:29	2020-08-26	Ms. Marjorie Mills PhD	ms.marjorie.mills.phd@geemail.com	Tucson	Arizona	6011895196204217719	2b5dfd14e67189424bd79dfe501f6272	Discover	32.0587897087022711	-110.819924316438289
47912	2020-08-26 19:32:45	2020-08-26	Dema Emmerich PhD	dema.emmerich.phd@geemail.com	Detroit	Michigan	869946879564054842	24678cd540464ec0a38fc6f484514cf5	Mastercard	42.3936475642416681	-83.1615777067493553
47913	2020-08-26 19:41:16	2020-08-26	Orville Lockman	orville.lockman@geemail.com	Evansville	Indiana	3008912164936526	637da0b06d735b785443b1f6a3203e19	JCB 16 digit	37.92510748465061	-87.6054165747415254
47914	2020-08-26 19:43:26	2020-08-26	Miss Dena Daniel PhD	miss.dena.daniel.phd@geemail.com	Raleigh	North Carolina	3020947965928973	b0e98debb0525f7b99c896ece847fb39	Voyager	35.7951726922899454	-78.5609963684279506
47915	2020-08-26 19:44:24	2020-08-26	May Towne	may.towne@geemail.com	Miami Gardens	Florida	180034101672138860	66410bcfa9e602d2103da21f6ad0dc7b	Maestro	26.027975636761262	-80.2515981223214396
47916	2020-08-26 19:49:04	2020-08-26	Ms. Merrilee Johns PhD	ms.merrilee.johns.phd@warmmail.com	Louisville	Kentucky	4878925317629	ff51198719d7fa186fc82266d8524504	JCB 16 digit	38.2439758468322424	-85.5665506978124455
47917	2020-08-26 19:51:56	2020-08-26	Rolf Schaden	rolf.schaden@geemail.com	San Francisco	California	4471974878819305	472ed20cf38a503b95e0c2a5e462b944	JCB 16 digit	37.7905643369848008	-122.457820728390487
47918	2020-08-26 19:53:02	2020-08-26	Kayson Herzog	kayson.herzog@geemail.com	San Francisco	California	3025963001605207	ec80f926ba65338420d5e7f940861b8d	Voyager	37.8003860623088883	-122.490409177827374
47919	2020-08-26 19:56:57	2020-08-26	Mr. Heath Koelpin IV	mr.heath.koelpin.iv@woohoo.com	Seattle	Washington	6011367546159041481	51e7729a9dea95d67a4a53bdf0bc6623	Diners Club / Carte Blanche	47.6840763098951399	-122.326595735216131
47920	2020-08-26 19:58:38	2020-08-26	Mrs. Corliss Raynor	mrs.corliss.raynor@geemail.com	Glendale	Arizona	54340101496541785	b92443475a792a3d5c32a64fc5ea9763	Discover	33.4626307124033531	-112.163140631120271
47921	2020-08-26 20:00:37	2020-08-26	Harper Bode	harper.bode@geemail.com	Saint Paul	Minnesota	4973251401833159	e9445b776c05a90f0e5762d96804522c	JCB 16 digit	44.8980775800008374	-93.1979609378412448
47922	2020-08-26 20:27:35	2020-08-26	Corinna Mayer	corinna.mayer@geemail.com	Los Angeles	California	3158392025479448840	647ad9a8be27d772cfab8fa46a924885	JCB 16 digit	33.993909591190139	-118.391177664463584
47923	2020-08-26 20:30:08	2020-08-26	Bryan West	bryan.west@warmmail.com	Oakland	California	869902985171365430	d865d76eae658916cb4f954bd2e30431	Maestro	37.8266180549776792	-122.280839862863715
47924	2020-08-26 20:36:59	2020-08-26	Mr. Diallo Pollich II	mr.diallo.pollich.ii@warmmail.com	Simi Valley	California	589374032107869	038a0919a3ffb153cac69f50522f9f72	Discover	34.3107495795242485	-118.693457995368178
47925	2020-08-26 20:38:39	2020-08-26	Ms. Burnice Nitzsche DDS	ms.burnice.nitzsche.dds@geemail.com	Detroit	Michigan	3088427002251251725	5988746a3677a6d784f0e909cdd7bb28	Diners Club / Carte Blanche	42.4777375896386857	-83.0126163297451996
47926	2020-08-26 20:43:24	2020-08-26	Forest Dickens	forest.dickens@geemail.com	Indianapolis	Indiana	869920264389855170	e3f1c45594b59cc8a178006414e338f1	Maestro	39.7570643241990354	-86.1867212732523598
47927	2020-08-26 20:45:32	2020-08-26	Dr. Cecile Block MD	dr.cecile.block.md@geemail.com	San Francisco	California	3088224416769974351	8f45d9b6ba762aae736d5c1115102ae1	Mastercard	37.7953886956751788	-122.409562148660996
47928	2020-08-26 20:46:56	2020-08-26	Marianna Adams	marianna.adams@geemail.com	Lafayette	Louisiana	869903111515160879	46461c4a7eefe2b6862919380fda643d	American Express	30.200493193462119	-92.0115676113720866
47929	2020-08-26 20:49:21	2020-08-26	Dr. Tanja Spinka	dr.tanja.spinka@geemail.com	San Francisco	California	3158064098014152976	402825ca42ff3bbe7f6a5cfd694ee7bc	Voyager	37.7347424966161995	-122.438923949085691
47930	2020-08-26 20:54:48	2020-08-26	Dr. Saniya Nicolas DVM	dr.saniya.nicolas.dvm@geemail.com	Kansas City	Missouri	210016444673307619	87437e7c5faf1cb19827285648692a24	Voyager	39.1335160912781959	-94.5102508764471878
47931	2020-08-26 20:58:22	2020-08-26	Pryor Bechtelar	pryor.bechtelar@geemail.com	San Francisco	California	4518955177043429	205a59c88db9f20a776650a1ede8088d	JCB 16 digit	37.7606450895095733	-122.470727255080817
47932	2020-08-26 21:12:31	2020-08-26	Yamilet Wunsch DVM	yamilet.wunsch.dvm@woohoo.com	Houston	Texas	060453010808995	cc8f5ceaa0a2b13c14be5bcbe52a07e8	JCB 16 digit	29.8489948115389794	-95.4070406651604941
47933	2020-08-26 21:17:13	2020-08-26	Ruben Johns	ruben.johns@woohoo.com	Green Bay	Wisconsin	3112225396388924939	459c3ddaed5e19295ab4f21d4446d6ee	Diners Club / Carte Blanche	44.6139529304642224	-87.9565475312814158
47934	2020-08-26 21:20:35	2020-08-26	Darlyne Gorczany-Daugherty	darlyne.gorczany.daugherty@warmmail.com	Elizabeth	New Jersey	869994916050970064	ddd239261292bfaf38cff3bb9d46f272	Voyager	40.6572956444822253	-74.137557908654216
47935	2020-08-26 21:21:48	2020-08-26	Yuliana Cremin	yuliana.cremin@woohoo.com	New York	New York	3495652502073145	a96762bd33c5cf8137a8aea753ef4d12	Diners Club / Carte Blanche	40.5849215365238507	-73.9431770862907172
47936	2020-08-26 21:21:56	2020-08-26	Miss Jayla Homenick	miss.jayla.homenick@geemail.com	Oklahoma City	Oklahoma	54564194082454074	efa51116a9cecea118e09291fabc8366	Maestro	35.5021040641613297	-97.4390367222845555
47937	2020-08-26 21:37:06	2020-08-26	Tavian Lockman	tavian.lockman@geemail.com	San Francisco	California	6011221160658210286	e53326d56fe3a0d75b1c1e664cbf7740	Discover	37.8033125357786233	-122.441078710304851
47938	2020-08-26 21:42:37	2020-08-26	Tate Dach	tate.dach@geemail.com	Virginia Beach	Virginia	3158600410248059201	dd1c887eaf9347a3a84a7d188cad7fed	VISA 13 digit	36.7942308541573624	-76.076069101379062
47939	2020-08-26 22:03:18	2020-08-26	Dayami Nicolas	dayami.nicolas@geemail.com	Escondido	California	869967885071586667	47df60a8a44ec654238fa0abc9fe24b0	Maestro	33.1857155090890785	-117.052497365675862
47940	2020-08-26 22:07:29	2020-08-26	Suzanna Lesch	suzanna.lesch@geemail.com	San Antonio	Texas	4574914346063	4e67bb5569b3c6a8e52b4432b3a55aac	JCB 16 digit	29.4103053934477288	-98.4805185121320079
47941	2020-08-26 22:12:00	2020-08-26	Terrell Kovacek MD	terrell.kovacek.md@geemail.com	San Francisco	California	3011824135546945	382ce6c10fac0ec5090410d1270c1a77	VISA 16 digit	37.7777654671668657	-122.419024316470129
47942	2020-08-26 22:22:31	2020-08-26	Leanna Braun	leanna.braun@geemail.com	Rockford	Illinois	6011857913723519268	f8df5fe9ccb38255e23cfc426ad9efaf	Discover	42.3563470864214011	-89.0916036917179781
47943	2020-08-26 22:30:07	2020-08-26	Ephram Mertz	ephram.mertz@geemail.com	New York	New York	869973747706824792	5d0cd976d780037c5e0ee78b3d3ff7ce	Diners Club / Carte Blanche	40.6148613358605672	-73.8466466490074964
47944	2020-08-26 22:30:34	2020-08-26	Rosabelle Lakin DDS	rosabelle.lakin.dds@woohoo.com	Dallas	Texas	3406486197110922	e577e4363e4e9891dd2a9d6fa081973b	Maestro	32.7174206177044695	-96.7520115944985264
47945	2020-08-26 22:30:40	2020-08-26	Gianni Ratke	gianni.ratke@geemail.com	Garden Grove	California	180079839960321724	eff71fc2a78c5f8bd941515a8e1f8021	JCB 16 digit	33.7286437854927001	-117.9497028956674
47946	2020-08-26 22:44:04	2020-08-26	Carry Lowe	carry.lowe@geemail.com	Louisville	Kentucky	3014184465771317	bcb1f79abb743f506b29a0a32550f3f2	VISA 13 digit	38.2446811605148014	-85.6808471990354406
47947	2020-08-26 22:49:45	2020-08-26	Dr. Enoch Feest	dr.enoch.feest@woohoo.com	Moreno Valley	California	4461872927261036	73894656bc57503163d186c8b24c1ca4	Discover	33.8816297435194258	-117.252191470420726
47948	2020-08-26 22:52:06	2020-08-26	Isaac McGlynn	isaac.mcglynn@geemail.com	Columbus	Ohio	4160164485225031	882afcbb74b63e08186df79656490727	Discover	39.9958631270609786	-83.006456921133406
47949	2020-08-26 22:52:24	2020-08-26	Mrs. Annika Little	mrs.annika.little@geemail.com	Vista	California	4870063857406826	fcd5e8fe5619e8bfd94a881f264c2f29	American Express	33.1465665987674143	-117.140207824163511
47950	2020-08-26 22:58:49	2020-08-26	Brenna Herman	brenna.herman@geemail.com	Garden Grove	California	3112343982626307909	9c845de2238785dad102f9be3a855089	VISA 16 digit	33.7225359714414878	-117.978572832608592
47951	2020-08-26 22:59:44	2020-08-26	Gary Skiles	gary.skiles@geemail.com	Seattle	Washington	3088915046294436768	a8534f06af95d42679022b8030e8b191	VISA 16 digit	47.6732589983772499	-122.278394897181158
47952	2020-08-26 23:09:27	2020-08-26	Danny Murray	danny.murray@geemail.com	Oklahoma City	Oklahoma	6011624327665550508	7d627f131eb10d9dbba3027bc16bfdf8	VISA 13 digit	35.455622999966522	-97.4431139130972355
47953	2020-08-26 23:09:38	2020-08-26	Elon O'Kon-Ruecker	elon.o'kon.ruecker@geemail.com	Los Angeles	California	676293284093981	e0970065709b99c28a20035509ed23a1	JCB 15 digit	33.9874551141034758	-118.468690855148424
47954	2020-08-26 23:19:56	2020-08-26	Arlo Nader-Wintheiser	arlo.nader.wintheiser@geemail.com	Meridian	Idaho	3486898608244004	1a11f6c5b07f16af5a0fcad6e445d9c0	American Express	43.6591099281337094	-116.404526252712685
47955	2020-08-26 23:26:02	2020-08-26	Trevion Quitzon	trevion.quitzon@warmmail.com	New York	New York	3096530137981856882	6c71842f42d39d765bea246da331d43d	JCB 15 digit	40.5928508606497189	-73.8413151577941989
47956	2020-08-26 23:27:21	2020-08-26	Mrs. Brianda Medhurst MD	mrs.brianda.medhurst.md@geemail.com	Omaha	Nebraska	3013418515344738	598a6bec94311fb977135c771c54e445	Maestro	41.307878694185618	-96.0433517818454732
47957	2020-08-26 23:36:09	2020-08-26	Santos Gusikowski	santos.gusikowski@geemail.com	Berkeley	California	3528330754800102983	a8e90d428b839e43810b2e4c2fd6a872	VISA 16 digit	37.8648682419085461	-122.268208597658244
47958	2020-08-26 23:42:23	2020-08-26	Dicie Maggio	dicie.maggio@woohoo.com	Chicago	Illinois	869917170290729815	e1b43ecf377325b75539a94f08e45f7c	Diners Club / Carte Blanche	41.8804480950184157	-87.7775604268100125
47959	2020-08-26 23:43:12	2020-08-26	Pallie Gleason	pallie.gleason@woohoo.com	Fresno	California	3477807834004810	68230fdb5cd69c2d7cab2d804c55257e	JCB 16 digit	36.8048110409513143	-119.871305074041345
47960	2020-08-26 23:47:42	2020-08-26	Arch Gutkowski	arch.gutkowski@geemail.com	Norfolk	Virginia	676260816737120	8cb46665b23240cec6b70c9de685fcf4	VISA 16 digit	36.8573379148747762	-76.1864267537839766
47961	2020-08-26 23:52:02	2020-08-26	Ryan Jacobson	ryan.jacobson@warmmail.com	Oxnard	California	6011938244051475847	75d88b5a08348995681c8ed5f8bac9bd	JCB 15 digit	34.2680625245396087	-119.283762767250096
47962	2020-08-27 00:06:43	2020-08-27	Alec Graham	alec.graham@geemail.com	Houston	Texas	6011397264253891900	919baafb70b021ac1d493d1e3e37284b	Voyager	29.7516453390087925	-95.2920146654374918
47963	2020-08-27 00:07:21	2020-08-27	Anatole Rippin DVM	anatole.rippin.dvm@geemail.com	Tampa	Florida	210012190204145176	115d56d03e995df62d7d8a06ea90a0cc	Maestro	27.8824483906965703	-82.5552046806298137
47964	2020-08-27 00:07:40	2020-08-27	Akeelah Feeney	akeelah.feeney@geemail.com	Laredo	Texas	4115173735995539	5e46bef03e46f508974e0efe418dd43f	Mastercard	27.498976714321973	-99.5312803317800103
47965	2020-08-27 00:14:01	2020-08-27	Theresa Rempel	theresa.rempel@geemail.com	Memphis	Tennessee	3096912464355241253	11c6748ce7e1278ef2d2fbbc3fc686f4	Discover	35.0872283486716441	-89.9085647050548431
47966	2020-08-27 00:18:42	2020-08-27	Mr. Linn Connelly II	mr.linn.connelly.ii@geemail.com	Colorado Springs	Colorado	210027910231549550	a00844277ea05f9f5b1ec20ce6a1f17d	JCB 15 digit	38.9617700845982853	-104.79520516029261
47967	2020-08-27 00:22:27	2020-08-27	Audra Boyle	audra.boyle@geemail.com	Corpus Christi	Texas	6011645520232213312	c7b96b3b35df12aa8478f6f4c48d79bf	VISA 16 digit	27.6647172495659461	-97.1163862356744687
47968	2020-08-27 00:25:49	2020-08-27	Enola Hartmann DDS	enola.hartmann.dds@geemail.com	San Francisco	California	6011286979970134995	9111878d586d60cf273322fc76dacfd4	VISA 13 digit	37.7673807401755468	-122.469614770396532
47969	2020-08-27 00:28:42	2020-08-27	Micky Huel-Pacocha	micky.huel.pacocha@geemail.com	Athens	Georgia	180066970222171196	6c74d90e60a61cac695b5a603f2d6448	JCB 15 digit	33.9117425376273687	-83.4265042272511863
47970	2020-08-27 00:37:39	2020-08-27	Lew VonRueden	lew.vonrueden@geemail.com	Houston	Texas	53920913339038185	826d194a60cc9773acc3053a167f6e18	JCB 15 digit	29.7191024086050675	-95.4152040226399976
47971	2020-08-27 00:47:51	2020-08-27	Gracelyn Friesen MD	gracelyn.friesen.md@geemail.com	New York	New York	4275830037539424	d28f3ff2e0b8f0a6f3b3f17ac0bba785	Discover	40.6255921079069395	-73.9793127466354434
47972	2020-08-27 00:48:48	2020-08-27	Dr. Brendan Steuber	dr.brendan.steuber@woohoo.com	Phoenix	Arizona	4774468861356	3db2339290801182602bf47002d115d2	Maestro	33.6414624148447103	-112.062826669907579
47973	2020-08-27 00:56:28	2020-08-27	Kolby DuBuque	kolby.dubuque@geemail.com	Memphis	Tennessee	210045942178543930	0412693e150eb38cda179cc11ad357bb	Diners Club / Carte Blanche	35.1862413975011563	-90.0600426849700568
47974	2020-08-27 01:26:32	2020-08-27	Dr. Bev Jakubowski	dr.bev.jakubowski@geemail.com	Montgomery	Alabama	639053342268256	67f609c5ddc167b0b7cf5761a01ab044	Mastercard	32.2883646053195008	-86.2118188935484682
47975	2020-08-27 01:51:57	2020-08-27	Lorinda Raynor	lorinda.raynor@geemail.com	Fort Worth	Texas	3002173573029538	c77460d7cf21caffc56b31e91edf1618	VISA 16 digit	32.8296038225349065	-97.2472361726041896
47976	2020-08-27 01:58:33	2020-08-27	Maliah Wunsch	maliah.wunsch@woohoo.com	New York	New York	4307421428817314	dfdaab32f2a8fb5fd894abcfa1be9acc	VISA 13 digit	40.7319140598867051	-74.0341334039241019
47977	2020-08-27 02:27:07	2020-08-27	Ember Kshlerin MD	ember.kshlerin.md@geemail.com	Las Cruces	New Mexico	3042640634623509	324e9b58c317631cba64823da75168f0	Maestro	32.3682182181660067	-106.703934658051281
47978	2020-08-27 02:30:32	2020-08-27	Tatyana Hammes-Lynch	tatyana.hammes.lynch@geemail.com	New York	New York	4158605406582482	ae115f57474ea18506c7300ad3e58b30	VISA 13 digit	40.639512396998704	-73.8765117060754477
47979	2020-08-27 02:31:13	2020-08-27	Phylicia Lindgren	phylicia.lindgren@geemail.com	Fremont	California	3088323179666455094	97c88061b16ac22685059d9b18fe464e	VISA 16 digit	37.3989764232356094	-121.913562229460851
47980	2020-08-27 02:40:59	2020-08-27	Janel Lockman MD	janel.lockman.md@geemail.com	San Francisco	California	630450088443069	10f500dc1b078df1387aebe713798f5e	VISA 16 digit	37.754617099683152	-122.422250930065019
47981	2020-08-27 02:52:44	2020-08-27	Mr. Geoffrey Hagenes	mr.geoffrey.hagenes@woohoo.com	New York	New York	4571558975849692	3f8c7835fabec0d59dd315e2bf5c54a3	American Express	40.6552715545743695	-74.0043636789441024
47982	2020-08-27 03:06:00	2020-08-27	Makai Runolfsson	makai.runolfsson@warmmail.com	Henderson	Nevada	639084076941990	2756427fb0e910044c75b5c37255e6fe	Voyager	36.0140365250341645	-115.051905492429441
47983	2020-08-27 03:07:39	2020-08-27	Olena Larkin	olena.larkin@geemail.com	Stamford	Connecticut	3054419050110038	b5257c6e35db1b9f58d2ca77880f15de	VISA 16 digit	40.9874114083942018	-73.6246674879025704
47984	2020-08-27 03:22:03	2020-08-27	Dink Erdman II	dink.erdman.ii@geemail.com	Omaha	Nebraska	3055758840043317	dc6eeb4cff0d24ba2a1c82025e554e9d	JCB 16 digit	41.2861957928776775	-96.0870644163921526
47985	2020-08-27 03:30:06	2020-08-27	Miss Caldonia Reynolds PhD	miss.caldonia.reynolds.phd@geemail.com	Concord	California	3027262457656964	ffab24d33580a3005b8957e57c83f77b	VISA 16 digit	37.8885551590405427	-121.930651534784957
47986	2020-08-27 03:33:22	2020-08-27	Clemon Schneider	clemon.schneider@geemail.com	Houston	Texas	676286163599516	10b38127bb627ce11f3373834a04cabd	JCB 16 digit	29.7943154383528963	-95.3625948296409121
47987	2020-08-27 03:39:55	2020-08-27	Monty Ondricka	monty.ondricka@geemail.com	Sandy Springs	Georgia	3000194824784798	97b0ce717ab32c75c60b4770b93fbcbe	VISA 16 digit	33.9316746878959208	-84.3019488378044315
47988	2020-08-27 03:44:21	2020-08-27	Deneen Langosh	deneen.langosh@geemail.com	New York	New York	869945874869635537	d412022ca34a27aed78a724ad3b111d4	VISA 16 digit	40.5810128430593764	-73.8865351856116206
47989	2020-08-27 03:48:56	2020-08-27	Mariam Mohr	mariam.mohr@geemail.com	Fort Worth	Texas	4500259519504879	5bd7d74795127a4c8e27efb06d6ab89a	Maestro	32.8767047695405807	-97.3493096719782756
47990	2020-08-27 03:56:13	2020-08-27	Shellie Leffler III	shellie.leffler.iii@geemail.com	St. Louis	Missouri	639048964019037	d8c3f9e2b3df287fb62eebd20bad2732	VISA 16 digit	38.5500676381092546	-90.2313515774443857
47991	2020-08-27 04:12:20	2020-08-27	Myrl Wehner DVM	myrl.wehner.dvm@warmmail.com	Madison	Wisconsin	3752614039744037	5e5bc4a300f6ea3df4ae18d1f2e24498	Diners Club / Carte Blanche	43.0894169139649748	-89.4435751539539581
47992	2020-08-27 04:20:49	2020-08-27	Manuelita Brown	manuelita.brown@geemail.com	Greeley	Colorado	676101010762761	068e110597566d452bebd42d8f21d8c7	VISA 16 digit	40.4490047349661594	-104.699319068326432
47993	2020-08-27 04:27:19	2020-08-27	Zina Zboncak	zina.zboncak@geemail.com	Philadelphia	Pennsylvania	869908796635640993	3a6a65528b53d52049c98c0df70e19b3	VISA 16 digit	40.0971962540369447	-75.1717779417887328
47994	2020-08-27 04:45:11	2020-08-27	Shyheim Kerluke-Murphy	shyheim.kerluke.murphy@geemail.com	San Diego	California	3790233968908655	297a2ebeb0222ad556ae9fb2426f9581	Mastercard	32.769429549860952	-117.178570594443016
47995	2020-08-27 04:49:43	2020-08-27	Muhammad Schneider	muhammad.schneider@geemail.com	Garland	Texas	55220516911555133	826af73ac81a15aa95cf8b757f8a4050	VISA 16 digit	32.8753015285592483	-96.6343703440085164
47996	2020-08-27 04:52:46	2020-08-27	Mr. Shoji Kling DDS	mr.shoji.kling.dds@geemail.com	San Antonio	Texas	210043988341193154	d067467929a19b00b4e455f3eee68fb2	Maestro	29.5031475568261001	-98.4414023004773924
47997	2020-08-27 04:58:54	2020-08-27	Doyle Shanahan	doyle.shanahan@geemail.com	Memphis	Tennessee	676308846346818	109335088aafde6b8b19b0fb64127e2a	VISA 16 digit	35.0660264439482248	-90.0283011021349608
47998	2020-08-27 05:02:49	2020-08-27	Raymond Waters	raymond.waters@geemail.com	Oceanside	California	53206819098137958	0162cfe3647e38a845f25d094e4a6948	Maestro	33.3103681295067062	-117.2658709500067
47999	2020-08-27 05:19:08	2020-08-27	Gay Wunsch	gay.wunsch@geemail.com	Washington	District of Columbia	869976292246397345	b55dec966a2ddb3cf95576005327b443	VISA 16 digit	38.8583428574059155	-77.0120393782600843
48000	2020-08-27 05:43:35	2020-08-27	Daisie Oberbrunner-Homenick	daisie.oberbrunner.homenick@geemail.com	Oxnard	California	676381733603971	50a45be53869520050fd3f1188535f49	Maestro	34.1907957782458496	-119.285500376802304
48001	2020-08-27 05:49:14	2020-08-27	Almyra Ebert	almyra.ebert@woohoo.com	New York	New York	55971394893093809	2dbf6f7afd48bdcb9e6b58f6d6700393	VISA 16 digit	40.7460573461595885	-73.9809895603347485
48002	2020-08-27 06:04:12	2020-08-27	Heyward Brakus	heyward.brakus@geemail.com	San Bernardino	California	869983149448167986	f87ce717ce1826b04258c7050db34950	JCB 16 digit	34.1495475290607615	-117.281631111285094
48003	2020-08-27 06:06:00	2020-08-27	Ms. Pat Hudson MD	ms.pat.hudson.md@woohoo.com	Buffalo	New York	52409768770734696	a00ccdc2b9b54a95e56bb21d9b9059ee	Voyager	42.8901989151444241	-78.9272230555702095
48004	2020-08-27 06:17:09	2020-08-27	Newton Farrell	newton.farrell@geemail.com	Mobile	Alabama	869974109827311713	7f21aa556c0c4d2a44996805e4af6318	VISA 13 digit	30.705255564871802	-88.0412855178255569
48005	2020-08-27 06:24:57	2020-08-27	Mrs. Georgeanna Zemlak PhD	mrs.georgeanna.zemlak.phd@geemail.com	San Jose	California	6011284042176200052	5ad98c32b428c3dcf03c71682c5efd4a	VISA 16 digit	37.2136960892293587	-121.916686311898374
48006	2020-08-27 06:29:41	2020-08-27	Archer Koch	archer.koch@geemail.com	Boston	Massachusetts	4859040314774223	ae1d6e7ca5eebcd95860b79d75317c13	Mastercard	42.3083908454682671	-71.0670229657504677
48007	2020-08-27 06:34:27	2020-08-27	Jeane Grant-Ward	jeane.grant.ward@geemail.com	Scottsdale	Arizona	3528376390413921835	75a4631fdd2f646c38b67f881dcb8f64	Diners Club / Carte Blanche	33.6714576632838671	-111.774182689885038
48008	2020-08-27 06:44:06	2020-08-27	Shayla Murphy	shayla.murphy@geemail.com	San Diego	California	869928099056203490	9c16b9265cc509e34c3a651a790d97d0	Maestro	32.8204626877859269	-117.215655607162049
48009	2020-08-27 06:55:38	2020-08-27	Cason Pagac II	cason.pagac.ii@geemail.com	Austin	Texas	869972497941343932	dfab5baff458fffaefab003bab1bea44	Maestro	30.324912726426124	-97.766938866372783
48010	2020-08-27 06:55:58	2020-08-27	Brianna Mertz	brianna.mertz@geemail.com	New York	New York	4664306223484625	dee6c59c1f64c4b00f7a19cba09f15ff	Diners Club / Carte Blanche	40.743509303567933	-73.8750988067489089
48011	2020-08-27 06:57:28	2020-08-27	Dr. Hardy Stroman	dr.hardy.stroman@geemail.com	New York	New York	4135072619033126	8da1b61efba9e99b20e18061a101f727	VISA 16 digit	40.6473650121353529	-74.0060963977489621
48012	2020-08-27 07:07:57	2020-08-27	Cena Borer	cena.borer@geemail.com	Paterson	New Jersey	3709597797707490	23487249c3e482bfe2b7bec7ac5bd123	JCB 16 digit	40.8300728505432602	-74.2322471099413974
48013	2020-08-27 07:11:46	2020-08-27	Aiyanna Bergstrom DDS	aiyanna.bergstrom.dds@woohoo.com	Lubbock	Texas	54356939005981625	4c87e6cccf0dafc67f1e19ee8d0fb153	VISA 13 digit	33.5829826865386281	-101.823189683529364
48014	2020-08-27 07:13:15	2020-08-27	Paralee Quigley	paralee.quigley@woohoo.com	Columbus	Ohio	676398581670837	0a410eb323e2181f49edb9b778257329	JCB 16 digit	40.0242277768950885	-83.0491847253173603
48015	2020-08-27 07:16:30	2020-08-27	Zelpha Yundt	zelpha.yundt@geemail.com	San Francisco	California	869988418580339306	468c59e03d38d3c7ff42e1fb709badc2	American Express	37.792028400732697	-122.425381508410624
48016	2020-08-27 07:17:36	2020-08-27	Dr. Katerina Stiedemann DDS	dr.katerina.stiedemann.dds@geemail.com	Jackson	Mississippi	3731594323787692	11e437d786bab9a7caf75e7fb3fa95ff	Maestro	32.3154127152349844	-90.2092798490051138
48017	2020-08-27 07:23:15	2020-08-27	Dr. Arnav Armstrong	dr.arnav.armstrong@warmmail.com	Knoxville	Tennessee	3468092479657088	f1d69e0106f20d077182f86be5f2e76b	JCB 15 digit	35.982360538567228	-83.8880505902443048
48018	2020-08-27 07:34:32	2020-08-27	Arlington Sawayn	arlington.sawayn@geemail.com	San Antonio	Texas	4805524379536	b1f6dd7351ba30551df5ba91f7ddd020	JCB 16 digit	29.4434502787027519	-98.5922793549787144
48019	2020-08-27 07:48:02	2020-08-27	Mr. Conway Batz	mr.conway.batz@geemail.com	Minneapolis	Minnesota	869980422111987573	6a482b1d6a1c03dcc1026f56fdb739bb	VISA 13 digit	44.8952678143132431	-93.1688556124262419
48020	2020-08-27 08:06:26	2020-08-27	Cordelia Volkman	cordelia.volkman@geemail.com	San Mateo	California	4497418461237731	c624e16528e73fe10ef89ff9156d50f9	Mastercard	37.6082515976272518	-122.243210474666569
48021	2020-08-27 08:07:55	2020-08-27	Mrs. Eudora Tromp	mrs.eudora.tromp@geemail.com	Oakland	California	4792803222966755	281396f5e6c2b9bb8fa58da8577750ef	VISA 13 digit	37.8443213169154546	-122.284504578028773
48022	2020-08-27 08:16:45	2020-08-27	Linsey Feil	linsey.feil@warmmail.com	Pittsburgh	Pennsylvania	869938799649487389	7e9c75331c12a9876bfe02b7280c14b7	Voyager	40.4841160722497833	-80.009658380195873
48023	2020-08-27 08:18:33	2020-08-27	Juanita Ward PhD	juanita.ward.phd@woohoo.com	Jersey City	New Jersey	51136417073196506	0289b27563cb44f40f96c522516eaaf7	VISA 16 digit	40.7457647853005653	-73.9763445841569478
48024	2020-08-27 08:20:02	2020-08-27	Vinson Lemke	vinson.lemke@geemail.com	Houston	Texas	3528222012377930133	c840c5ea7f0c4bdfa2f29312175e8d3c	Diners Club / Carte Blanche	29.8302573433224119	-95.3671361355125953
48025	2020-08-27 08:23:53	2020-08-27	Joana Marvin	joana.marvin@geemail.com	Fargo	North Dakota	3096047996814730614	2abecb6da89d834084cf267d690fd6e4	JCB 15 digit	46.8590262860756397	-96.887791294926771
48026	2020-08-27 08:24:39	2020-08-27	Aliya Padberg	aliya.padberg@geemail.com	San Francisco	California	3112265142315849653	703c54005a04cb9459279683ab7c2237	JCB 16 digit	37.7541855173402681	-122.43761997253263
48027	2020-08-27 08:30:52	2020-08-27	Meg Runte-Durgan	meg.runte.durgan@warmmail.com	Charleston	South Carolina	501828584180922	f82fb5574d4b7c154fd885fda0531448	JCB 15 digit	32.89433411210738	-80.0583748609907957
48028	2020-08-27 08:38:32	2020-08-27	Bobbie Beatty	bobbie.beatty@geemail.com	Lancaster	California	4738753303648	655cfe72d30f2fa2dbc7e492eac85210	Maestro	34.6044767382800629	-118.264220700550069
48029	2020-08-27 08:42:38	2020-08-27	Jaxson Rutherford DDS	jaxson.rutherford.dds@geemail.com	Scottsdale	Arizona	3096932037287362243	aa8113e12e257b845d11facda99da8f7	Maestro	33.6664248730644573	-111.916228984898325
48030	2020-08-27 08:46:13	2020-08-27	Mrs. Ashanti Wolff	mrs.ashanti.wolff@woohoo.com	Henderson	Nevada	54727880472775557	02fe66b2784e7a0eeee5fabe16068d97	Maestro	36.0525639244288243	-115.017859642409533
48031	2020-08-27 08:47:39	2020-08-27	Enrico Ankunding MD	enrico.ankunding.md@geemail.com	Athens	Georgia	676127195786523	7316f2270bc6cee3a1712f27ea20850a	Diners Club / Carte Blanche	34.0295558771774154	-83.3183670678291435
48032	2020-08-27 08:50:46	2020-08-27	Mrs. Samiyah Heidenreich	mrs.samiyah.heidenreich@geemail.com	Oklahoma City	Oklahoma	4660679012708360	25978c76c0adfad3bbb80bfc54b66747	Mastercard	35.4001319473519942	-97.4685681896179972
48033	2020-08-27 08:56:00	2020-08-27	Dr. Kaeden Weimann	dr.kaeden.weimann@geemail.com	Ann Arbor	Michigan	4499759380795715	fb7b1147facd64de9a63d11195086131	JCB 16 digit	42.3044433844335401	-83.6993603144880467
48034	2020-08-27 09:00:44	2020-08-27	Miss Fronia Johnston DVM	miss.fronia.johnston.dvm@geemail.com	Pasadena	California	869961020651172698	49076e3bf2c7964f6bcf414ca5afd5b5	Mastercard	34.1553183662559832	-118.140152752939983
48035	2020-08-27 09:10:26	2020-08-27	Marty Bailey	marty.bailey@warmmail.com	Berkeley	California	3024502252869202	4ce1078cbe44eb7090761ba17014683d	VISA 16 digit	37.9061230768702728	-122.303214420998884
48036	2020-08-27 09:13:36	2020-08-27	Miss Eugenie Morissette DDS	miss.eugenie.morissette.dds@warmmail.com	Dayton	Ohio	3096930917492760830	6701e9c3815a22169cf8c7d85a617929	VISA 16 digit	39.7473855440761881	-84.2964920693732864
48037	2020-08-27 09:24:04	2020-08-27	Mr. Isaias Reinger	mr.isaias.reinger@geemail.com	Everett	Washington	4864777375544614	cfb06d0cf1537371694bec06f0e0f90c	Mastercard	47.9475102680627288	-122.094749154861645
48038	2020-08-27 09:25:45	2020-08-27	Vicente Spinka	vicente.spinka@woohoo.com	Savannah	Georgia	869982411543236475	4974e891d5706bea7ebcae383003e334	Mastercard	31.9772634910978368	-81.2350774325117442
48039	2020-08-27 09:26:46	2020-08-27	Johnnie Beier	johnnie.beier@geemail.com	Los Angeles	California	210026674711864738	e4d42183e6254164c7a830f1b5d572e9	Maestro	34.1021688932418812	-118.339728079688911
48040	2020-08-27 09:26:55	2020-08-27	Cleda Wilderman	cleda.wilderman@geemail.com	Aurora	Colorado	3096512902229269418	f7b6df33394e2015646b4f2a105c1d8d	American Express	39.7819445531927087	-104.671139165258779
48041	2020-08-27 09:33:48	2020-08-27	Marcelina Weimann	marcelina.weimann@geemail.com	Detroit	Michigan	3112683554160334736	45c0d89dfff52bb2b384c6002615393b	VISA 16 digit	42.4405158042367603	-83.1889242073640247
48042	2020-08-27 09:40:36	2020-08-27	Miss Jeffie O'Conner PhD	miss.jeffie.o'conner.phd@woohoo.com	Concord	California	4063623864518785	49be3f65bac6aa7228e21199c10e2a52	VISA 13 digit	37.875385835015031	-121.978085385466358
48043	2020-08-27 09:49:40	2020-08-27	Kyler Wilderman	kyler.wilderman@geemail.com	Orange	California	3017823002923611	6db7b6ee73af0fb7a78082363c255201	JCB 16 digit	33.8435885273274053	-117.827239593361696
48044	2020-08-27 09:55:44	2020-08-27	Qiana Mitchell-Kuvalis	qiana.mitchell.kuvalis@geemail.com	Little Rock	Arkansas	4182474305055	a26fefc352557ce50c1fa8cac7839190	VISA 16 digit	34.646574591593442	-92.3141867153685496
48045	2020-08-27 09:59:54	2020-08-27	Laron Bruen	laron.bruen@geemail.com	San Francisco	California	639058026395994	3cac14f0aac38fb6b80c85186085caae	JCB 16 digit	37.7688877953087072	-122.457233055791264
48046	2020-08-27 10:10:45	2020-08-27	Hennie Rosenbaum	hennie.rosenbaum@geemail.com	San Francisco	California	502083490169618	3460280237d1db96b9de8f15e5bbeaa7	Discover	37.7546342150138443	-122.411266322230006
48047	2020-08-27 10:11:57	2020-08-27	Dustin Bins	dustin.bins@warmmail.com	Salt Lake City	Utah	869974804430298410	b17626d0038a7376e5b7bf021a428624	VISA 16 digit	40.695225015576554	-111.899473049532617
48048	2020-08-27 10:13:12	2020-08-27	Ashton Ziemann	ashton.ziemann@geemail.com	Los Angeles	California	210077903149480561	a37695b9cddef57c3246db7900df948f	JCB 16 digit	33.9745778226159487	-118.429532554651786
48049	2020-08-27 10:33:28	2020-08-27	Albion Oberbrunner	albion.oberbrunner@geemail.com	Eugene	Oregon	3450031927024061	3d810353e61fff53e40b3210738df30c	JCB 16 digit	44.1055712980877601	-123.172592716662962
48050	2020-08-27 10:35:12	2020-08-27	Coby Leannon	coby.leannon@warmmail.com	San Francisco	California	676159827168945	4a0f88a11c82e7307c4523fa2a8e4136	Maestro	37.7645402364694931	-122.396646864884218
48051	2020-08-27 10:41:51	2020-08-27	Jovany Corkery	jovany.corkery@geemail.com	Lancaster	California	3711109898806472	e617a4b7424c6cc235cc6c638437222d	JCB 15 digit	34.6472305097397424	-118.111083403459929
48052	2020-08-27 10:49:24	2020-08-27	Tavaris Kautzer-Stanton	tavaris.kautzer.stanton@geemail.com	San Diego	California	4187030150658377	2d0beab7a2776934b261251edc00c049	Diners Club / Carte Blanche	32.8205681492175927	-117.166495062029
48053	2020-08-27 10:52:23	2020-08-27	Bobby Kshlerin	bobby.kshlerin@geemail.com	Philadelphia	Pennsylvania	3409048122601685	eda0ed3d2198b2f36a5a64f156c5aa15	JCB 15 digit	40.0384856109466369	-75.0458305016990863
48054	2020-08-27 10:52:55	2020-08-27	Dr. Ethyl Heathcote MD	dr.ethyl.heathcote.md@geemail.com	San Francisco	California	4079423311227292	c6570526d7c3acf5702027822849795d	Diners Club / Carte Blanche	37.7921948845658093	-122.421906179847653
48055	2020-08-27 10:59:50	2020-08-27	Mr. Garey Bernier DVM	mr.garey.bernier.dvm@geemail.com	Berkeley	California	4327640456717908	1c4d89b1c468ecd3e6c0764b8e028a48	Discover	37.8550130491420163	-122.287248368869896
48056	2020-08-27 11:17:09	2020-08-27	Steve Heaney	steve.heaney@warmmail.com	Cleveland	Ohio	6011603268525710962	44ed14e51d944ad8ae7accf8a074dedf	Discover	41.5389203299153564	-81.7372643593005819
48057	2020-08-27 11:21:59	2020-08-27	Wendell Conroy	wendell.conroy@geemail.com	New York	New York	55144612715275136	630ea9684de0516193d0098599037ef1	VISA 16 digit	40.6485214967038502	-73.9291861376155168
48058	2020-08-27 11:23:16	2020-08-27	Kasen Cormier	kasen.cormier@geemail.com	San Antonio	Texas	4987152951156	aa9331beb210fc4c2f0bd94703f14bea	JCB 16 digit	29.4274878788344552	-98.4415031297434098
48059	2020-08-27 11:23:24	2020-08-27	Louie Flatley	louie.flatley@geemail.com	Columbus	Ohio	869936336334511660	4b51a67cbfd520ba5be1d064e162d502	Discover	40.049412826872242	-83.0793128183346283
48060	2020-08-27 11:31:51	2020-08-27	Lewis Reichel	lewis.reichel@warmmail.com	Chicago	Illinois	869901319155189742	5db2e3698681cf899b8e2031c54bf390	VISA 13 digit	41.7520150147214579	-87.708751778540389
48061	2020-08-27 11:40:52	2020-08-27	Dr. Gladstone O'Conner Sr.	dr.gladstone.o'conner.sr.@geemail.com	Fairfield	California	3049649304523074	8e1341cadbb988fa376957b0b26929e5	VISA 16 digit	38.274624888750914	-121.954235228430846
48062	2020-08-27 11:52:33	2020-08-27	Brandyn Kunde-Little	brandyn.kunde.little@woohoo.com	Seattle	Washington	3088612590548717701	4e9c4c41e798441d00a84abc0a049458	Mastercard	47.6110226675793555	-122.264433788593479
48063	2020-08-27 11:53:18	2020-08-27	Tavian Monahan	tavian.monahan@geemail.com	Boulder	Colorado	3158458485709512362	35cb0326dcc46a1c90ecb15bb3d5be79	JCB 16 digit	39.9607527187541152	-105.31453597980142
48064	2020-08-27 11:56:49	2020-08-27	Randy Heidenreich	randy.heidenreich@warmmail.com	San Francisco	California	4140017368947169	8eb376bf13fc0baa1f712e379e144e9c	JCB 16 digit	37.7778767667194089	-122.418526085183899
48065	2020-08-27 11:57:21	2020-08-27	Hayward Rempel	hayward.rempel@geemail.com	Port St. Lucie	Florida	180024698865278777	f1a569305412165c21e545ea2754a673	Mastercard	27.226623746859282	-80.4394444865260283
48066	2020-08-27 11:59:19	2020-08-27	Miles Nader	miles.nader@woohoo.com	Minneapolis	Minnesota	869917061024353446	e505c04ca12466b9cc523a115b043222	Diners Club / Carte Blanche	44.8638869596265195	-93.2141432627841766
48067	2020-08-27 12:10:57	2020-08-27	Sandra Trantow	sandra.trantow@warmmail.com	Oxnard	California	180042539474375836	ee4aa92090fd4e26e3035ce81fae3c51	Discover	34.2015749636061486	-119.244759588214009
48068	2020-08-27 12:16:58	2020-08-27	Pat Blick II	pat.blick.ii@geemail.com	Wilmington	North Carolina	180084721423971704	589787b89c7382ee8552e784ab1d7757	Voyager	34.2316806147161898	-77.8453562303904505
48069	2020-08-27 12:21:24	2020-08-27	Wilfredo Blanda PhD	wilfredo.blanda.phd@warmmail.com	West Jordan	Utah	6011997485585619156	1f0d2abb3ba8083dd962e4e787fea5e7	JCB 15 digit	40.5874059954449535	-112.058748650652547
48070	2020-08-27 12:49:01	2020-08-27	Hedy Shanahan	hedy.shanahan@geemail.com	San Francisco	California	869917070902160831	3dc2ac8f1e519408f27f74aaa5ae80bd	JCB 16 digit	37.7439393660850726	-122.41518458440126
48071	2020-08-27 12:54:54	2020-08-27	Iverson Boyle	iverson.boyle@geemail.com	League City	Texas	3088272637598997476	0c527f6e777e5e9344f481e24cc8f21b	Mastercard	29.5773631695121537	-95.1923025499083053
48072	2020-08-27 12:58:04	2020-08-27	Dr. Norene Hammes	dr.norene.hammes@geemail.com	Lakeland	Florida	3435673653596901	e8313099c81e1751e4016662c7251295	Discover	28.0811289549171903	-81.9718504631776312
48073	2020-08-27 13:07:44	2020-08-27	Margarito Batz	margarito.batz@geemail.com	Houston	Texas	3528029162867943156	91c9f710a2bee7366656b46d03e70a2f	American Express	29.7128172241695232	-95.3560792978867937
48074	2020-08-27 13:08:04	2020-08-27	Malvin Emmerich-Larkin	malvin.emmerich.larkin@geemail.com	Houston	Texas	3781531847950652	6153c6fed755db2a3053a97f9f6566be	Maestro	29.8049329201769098	-95.3641696077786349
48075	2020-08-27 13:14:40	2020-08-27	Kunta Braun	kunta.braun@geemail.com	Tulsa	Oklahoma	4277626414947679	f19bd11f61eb1c46b297b3602780a43f	JCB 15 digit	36.1279423534307611	-95.8557770531114102
48076	2020-08-27 13:21:19	2020-08-27	Miss Joretta Hermann	miss.joretta.hermann@geemail.com	Anaheim	California	4267407924993756	5473bd5f8419bc16d0ed4dbc179ff569	Discover	33.8190350998025409	-117.77881111039072
48077	2020-08-27 13:27:08	2020-08-27	Conner Leffler-Tremblay	conner.leffler.tremblay@geemail.com	New York	New York	210051604928133088	7c06a335544466cb77426c600f2c7c37	Maestro	40.6668586561679817	-74.0190010535426381
48078	2020-08-27 13:32:59	2020-08-27	Loda Waelchi	loda.waelchi@geemail.com	Buffalo	New York	4877094234037	14e21cf6a57869ba9dae0f3f8e1526a4	JCB 16 digit	42.8345309321489154	-78.9012812686551399
48079	2020-08-27 13:36:40	2020-08-27	Dr. Renaldo Kessler MD	dr.renaldo.kessler.md@geemail.com	San Francisco	California	51158555561869499	de30da0367e046d377812b003b904f98	Voyager	37.7884003008400526	-122.432098173359648
48080	2020-08-27 13:47:37	2020-08-27	Earnestine Runolfsson DVM	earnestine.runolfsson.dvm@geemail.com	San Francisco	California	4810468934334870	41baf22b66b8604880c204df375db919	Maestro	37.760835391501125	-122.479014916800935
48081	2020-08-27 13:48:49	2020-08-27	Marni Jerde PhD	marni.jerde.phd@geemail.com	San Diego	California	4320688202477522	8486522b6322ee7e79ee4df3f6caf537	VISA 16 digit	32.8385381673064103	-117.132196142794569
48082	2020-08-27 13:50:15	2020-08-27	Karel McGlynn	karel.mcglynn@warmmail.com	Phoenix	Arizona	3469555533456365	80947f676971014d9ad3984bbd8eaf26	Mastercard	33.6370146438878024	-112.182109270936252
48083	2020-08-27 13:50:17	2020-08-27	Giana Prohaska	giana.prohaska@geemail.com	Colorado Springs	Colorado	54549240738887595	300e50f18332705e09dcb7e0d581f650	Voyager	38.7833434353165316	-104.730309007705003
48084	2020-08-27 13:54:50	2020-08-27	Miss Emilia Hauck	miss.emilia.hauck@warmmail.com	San Jose	California	6011383484466927855	5ed479f968f28d3419751877b859dd77	JCB 15 digit	37.2698860691215828	-121.825881402682143
48085	2020-08-27 13:56:22	2020-08-27	Genevra Jaskolski PhD	genevra.jaskolski.phd@geemail.com	New York	New York	6011389972447488736	dd94146963c0928d4aca2efdd69e10f2	Mastercard	40.5906327019203417	-74.0293533984467302
48086	2020-08-27 14:04:13	2020-08-27	Tatyana Moen	tatyana.moen@geemail.com	Nashville	Tennessee	3025329410212714	517bbb4feccbf4ebafe316a219b7e529	VISA 13 digit	36.2361997087143308	-86.8543062688689673
48087	2020-08-27 14:07:46	2020-08-27	Dr. Rolla Gaylord	dr.rolla.gaylord@warmmail.com	Indianapolis	Indiana	52289255898188265	0a56bfd4d351bf2a468534b4879f35c8	Voyager	39.8112437868498219	-86.0807506108857723
48088	2020-08-27 14:08:35	2020-08-27	Dr. Leslie Wuckert PhD	dr.leslie.wuckert.phd@geemail.com	Edison	New Jersey	6011063782579898187	c7a16cf7cd95befbebad6b2f454f5a2e	JCB 15 digit	40.5305006531961212	-74.3127957816753622
48089	2020-08-27 14:08:46	2020-08-27	Antony Goodwin Jr.	antony.goodwin.jr.@woohoo.com	Denver	Colorado	3528909237984333385	a74a12bfa42dab686fc7299f51e9b6bf	VISA 16 digit	39.8304588466003509	-104.858839922096962
48090	2020-08-27 14:24:39	2020-08-27	Krissy Rippin	krissy.rippin@warmmail.com	Winston–Salem	North Carolina	4236797649191142	b933c317405b7d2d6457c21ecbaa5e5f	JCB 15 digit	36.163432162557541	-80.218830059388651
48091	2020-08-27 14:32:24	2020-08-27	Dr. Jaydon Hills	dr.jaydon.hills@geemail.com	Centennial	Colorado	4790471008629	3f455a18731c34f1f9fa1164ed0c0af3	Mastercard	39.6832711524836768	-104.904073833523697
48092	2020-08-27 14:46:09	2020-08-27	Evelena Streich PhD	evelena.streich.phd@geemail.com	Houston	Texas	3112364097103127854	076a35a7815acf91752355811a072960	American Express	29.6950365454502396	-95.4803852858502466
48093	2020-08-27 14:49:51	2020-08-27	Elliana Graham	elliana.graham@geemail.com	Los Angeles	California	869974111491334914	85ed4ef0ab5ed40acbd64a413d2a7e3f	Voyager	33.9214754297729542	-118.465587375964219
48094	2020-08-27 15:08:47	2020-08-27	Alfredo Maggio	alfredo.maggio@geemail.com	Tacoma	Washington	869927280933948991	60fc5040b2a05a69b2fb5e3e1cd37c69	VISA 16 digit	47.2085758702017415	-122.484579246794056
48095	2020-08-27 15:12:51	2020-08-27	Dr. Mordechai Harvey DVM	dr.mordechai.harvey.dvm@warmmail.com	Long Beach	California	3528213997870540077	80583696666e3506672d52e329c76f39	VISA 16 digit	33.7896681200999751	-118.087899903922519
48096	2020-08-27 15:12:57	2020-08-27	Hal Medhurst DDS	hal.medhurst.dds@geemail.com	El Paso	Texas	869961694562217089	cf57babc067d77e6302ca171391d169e	JCB 16 digit	31.7492631243836136	-106.5148685886506
48097	2020-08-27 15:21:48	2020-08-27	Kendall Herman	kendall.herman@geemail.com	Berkeley	California	869968975350667129	96152b80d52fbce29319656342655b20	VISA 13 digit	37.899524515314738	-122.279357481789432
48098	2020-08-27 15:25:57	2020-08-27	Melodee Feeney DDS	melodee.feeney.dds@warmmail.com	Syracuse	New York	3158251043450906009	1f87811a431b8e7d1cd493732f38151d	VISA 13 digit	42.9929304975401578	-76.220932012308765
48099	2020-08-27 15:27:39	2020-08-27	Kathaleen Gibson	kathaleen.gibson@warmmail.com	Salem	Oregon	6011498232101073235	e230f4cf41c06d534582d5878432e299	Maestro	44.8660743735533174	-122.986868236648661
48100	2020-08-27 15:32:09	2020-08-27	Angeline Wunsch	angeline.wunsch@woohoo.com	San Antonio	Texas	6011061550608232435	23e734b41029f3c7b6fc3a965fa8a135	Mastercard	29.4579150923132893	-98.5012016964446673
48101	2020-08-27 15:38:26	2020-08-27	Blake Anderson	blake.anderson@geemail.com	New York	New York	4236994210003687	224927c199de32c76803c27e30347492	Discover	40.7346336660664505	-73.8991897485580296
48102	2020-08-27 15:40:14	2020-08-27	Tennessee Mueller MD	tennessee.mueller.md@warmmail.com	Fort Worth	Texas	3011128242256038	d3c4d7644d40217de09040452447ad41	JCB 16 digit	32.7680016409196	-97.3817987010169759
48103	2020-08-27 15:44:00	2020-08-27	Cloyd Graham	cloyd.graham@geemail.com	Lubbock	Texas	4846196572545	154604ded16551c82bfb59df8bd7259c	Maestro	33.5247981859877768	-101.804900812628503
48104	2020-08-27 15:55:42	2020-08-27	Isabella Dickens-Schneider	isabella.dickens.schneider@geemail.com	San Francisco	California	3088300085074030329	b97a3397a6dff78db8fb1a2fc7834f1d	Diners Club / Carte Blanche	37.7596367349239372	-122.432629213038922
48105	2020-08-27 16:05:58	2020-08-27	Cael Wisozk	cael.wisozk@geemail.com	Detroit	Michigan	4075161228497319	15fb3c6422623851fdb5cac681c714f8	JCB 15 digit	42.3014610371943576	-83.0888678932216038
48106	2020-08-27 16:17:11	2020-08-27	Anitra Dare	anitra.dare@geemail.com	Chicago	Illinois	4315790406419	f1bf1ee4b484fc524706d131b834df9a	JCB 15 digit	41.9158569930888731	-87.6131576091080859
48107	2020-08-27 16:40:17	2020-08-27	Autumn McDermott MD	autumn.mcdermott.md@geemail.com	Columbus	Ohio	3337704865609394809	1b78a98d136bcaee7100dac9a1fb8e71	Maestro	39.9645115388136318	-83.0188827136300631
48108	2020-08-27 16:45:23	2020-08-27	Kiana Keebler	kiana.keebler@woohoo.com	Arlington	Texas	4188446279765	59539ad139b244e8ed88f95bbfb82602	Voyager	32.7978275907009831	-97.1412011279284968
48109	2020-08-27 16:45:52	2020-08-27	Mrs. Kayden McCullough	mrs.kayden.mccullough@geemail.com	New York	New York	4015672113968589	d46ea262d29d47ec77edf0d853ca05c0	Mastercard	40.7016733851507269	-73.913204957906899
48110	2020-08-27 16:48:23	2020-08-27	Leighton Gottlieb	leighton.gottlieb@geemail.com	Lakeland	Florida	210029509396000066	3333c92930194da4c1a9842c2ff850fe	Maestro	28.0241894034035504	-81.9860456331051779
48111	2020-08-27 16:50:46	2020-08-27	Regis Lowe	regis.lowe@geemail.com	Antioch	California	503883734894088	eb2f8423eabb3a5578dfff7f6491cd00	VISA 16 digit	37.8939447095882187	-121.877200057375063
48112	2020-08-27 16:55:03	2020-08-27	Rilla Sanford	rilla.sanford@warmmail.com	Concord	California	3158013232879662249	3eac80a8dc22a856372b7f4271a098f5	JCB 15 digit	38.0158914816964426	-121.994561119860407
48113	2020-08-27 16:55:19	2020-08-27	Yaritza Kuphal	yaritza.kuphal@woohoo.com	San Francisco	California	6011949437094696893	b16cdb94abbe5e9740dfd4b295a859ad	JCB 16 digit	37.7848807298019054	-122.42648821111888
48114	2020-08-27 16:57:58	2020-08-27	Hervey Herman-Will	hervey.herman.will@geemail.com	Cleveland	Ohio	060495474045259	7e1fd5ed7ee5804dc22c8169e8ebe8ee	JCB 15 digit	41.4620465291514932	-81.6780548779997986
48115	2020-08-27 17:03:49	2020-08-27	Mrs. Lois Torp PhD	mrs.lois.torp.phd@geemail.com	New York	New York	3047771040914961	763a6808d2dbcbd480d6211d31b3e948	JCB 16 digit	40.6129402735959744	-73.9076795418642405
48116	2020-08-27 17:18:06	2020-08-27	Mr. Beckett Lowe IV	mr.beckett.lowe.iv@geemail.com	Phoenix	Arizona	180016333947815129	97a484d2c87a0a4df668b3dae0d16c3c	JCB 15 digit	33.5014036268394477	-112.041830230730028
48117	2020-08-27 17:19:19	2020-08-27	Mrs. Alena Brakus	mrs.alena.brakus@warmmail.com	Woodbridge	New Jersey	54228013095255088	6e06f7cef96ced409a69e8c54a5bc784	Discover	40.5399375210206898	-74.1989360138632321
48118	2020-08-27 17:20:00	2020-08-27	Asbury Considine	asbury.considine@geemail.com	Charlotte	North Carolina	3528284232272216298	c6fcd923ea4cc2dfc0c90f28625713fa	VISA 16 digit	35.2819129922680546	-80.8292177318073897
48119	2020-08-27 17:29:00	2020-08-27	Gustie Prosacco	gustie.prosacco@woohoo.com	Laredo	Texas	210025600396422659	0d67e3445611ababcc212677fa2de29a	VISA 13 digit	27.4607819510806372	-99.5868594624575252
48120	2020-08-27 17:29:00	2020-08-27	Rubye Gutmann	rubye.gutmann@geemail.com	Los Angeles	California	6011604116633125491	d9680b52d40f55f4f0bb8737e47a6c21	American Express	34.0890657926309828	-118.49952988927177
48121	2020-08-27 17:34:21	2020-08-27	Dr. Alec Streich PhD	dr.alec.streich.phd@geemail.com	North Charleston	South Carolina	869945659178580833	19dd28e9cee64087b35e70f5ff46f06a	Diners Club / Carte Blanche	32.8982290607105909	-79.9820813947450375
48122	2020-08-27 17:36:26	2020-08-27	Mr. Juston Sporer IV	mr.juston.sporer.iv@geemail.com	Reno	Nevada	4461312037180552	811a8bc7cc76e9e507a1b4cbea1addec	Voyager	39.530979230169585	-119.774826891364157
48123	2020-08-27 17:39:30	2020-08-27	Haylee Daniel PhD	haylee.daniel.phd@geemail.com	Bakersfield	California	3024485335695911	25e972270a6e0a6f643fc1d5968391b1	VISA 16 digit	35.2871948975779119	-118.987257155710083
48124	2020-08-27 17:50:49	2020-08-27	Elvis Bailey	elvis.bailey@geemail.com	Clearwater	Florida	4545002608344675	0828d49624e4206ad328b63f4edb04da	Voyager	27.9358550750777113	-82.6962424881089504
48125	2020-08-27 17:56:19	2020-08-27	Dr. Buffy Bergnaum	dr.buffy.bergnaum@geemail.com	St. Petersburg	Florida	4370643535891203	9e8af8edcee04e8ec359d17f53f11bc6	JCB 15 digit	27.6962790148686615	-82.6910801293220317
48126	2020-08-27 17:57:16	2020-08-27	Mr. Boris Quitzon Jr.	mr.boris.quitzon.jr.@geemail.com	Clinton	Michigan	51617388628746186	725b7e79481a3ef3812af0fbf7df9ac1	American Express	42.560396424641084	-82.9020082796998281
48127	2020-08-27 18:03:57	2020-08-27	Domenick Schowalter	domenick.schowalter@woohoo.com	San Francisco	California	4667894298583	fc41720069d2b23251c740171c332856	VISA 16 digit	37.7661227871076974	-122.435644221000118
48128	2020-08-27 18:07:00	2020-08-27	Gertrude Stamm	gertrude.stamm@geemail.com	Oklahoma City	Oklahoma	869960105865961548	ff91e9f8caf89ceeaaac4b45c84202b0	Mastercard	35.383747872794423	-97.504606911762437
48129	2020-08-27 18:11:45	2020-08-27	Rube Kshlerin	rube.kshlerin@warmmail.com	San Francisco	California	6011756133187133405	3766283de9fd932e2b147f06bac555f7	Discover	37.7844895813459445	-122.43347665225086
48130	2020-08-27 18:30:26	2020-08-27	Geraldine Bradtke	geraldine.bradtke@geemail.com	San Francisco	California	869952835037770118	59b42cbb7e750cc8d6d07080284b1cad	VISA 13 digit	37.7806096209242597	-122.439986543020098
48131	2020-08-27 18:37:34	2020-08-27	Kayleen Fritsch-Runolfsdottir	kayleen.fritsch.runolfsdottir@geemail.com	Midland	Texas	4747528082873199	83f0862a44966362d9f6f91079ce386a	JCB 16 digit	32.0095289447069149	-102.101906254258012
48132	2020-08-27 18:43:11	2020-08-27	Mr. Niles Jaskolski DVM	mr.niles.jaskolski.dvm@geemail.com	Rochester	New York	4536144821611	0be1cd2ada8c3610b49dfc3a8ce05445	JCB 16 digit	43.1865506819426983	-77.5415031178161485
48133	2020-08-27 18:56:22	2020-08-27	Olga Graham	olga.graham@geemail.com	San Francisco	California	4290757014260016	dce12bdbd5d2c7d9bf09d396502a1662	JCB 16 digit	37.7633887500520089	-122.417581161233088
48134	2020-08-27 19:06:42	2020-08-27	Nico Rice-McDermott	nico.rice.mcdermott@geemail.com	McAllen	Texas	3405389375875749	9529c6d10a033810e6b8ca22964c7c3f	Diners Club / Carte Blanche	26.3108639706231635	-98.2868497306328237
48135	2020-08-27 19:08:39	2020-08-27	Mr. Edd Roob IV	mr.edd.roob.iv@geemail.com	San Francisco	California	3043515103913079	f01c60de5786472c66c64c3d1be33198	VISA 16 digit	37.7961139465075888	-122.442280128289966
48136	2020-08-27 19:10:05	2020-08-27	Shasta Auer	shasta.auer@geemail.com	Fort Worth	Texas	4827819159134	d9d88437db6e5d317ce39efcad121df5	Discover	32.8639118609540191	-97.4425374918438507
48137	2020-08-27 19:22:30	2020-08-27	Fredericka Hickle	fredericka.hickle@geemail.com	Akron	Ohio	869990624785002484	b7d8dcbfa1f7c8f8e69bcb9cb9a02408	JCB 16 digit	41.0296417735349408	-81.477978156026083
48138	2020-08-27 19:30:29	2020-08-27	Adell Rau	adell.rau@geemail.com	Orange	California	3528110757606704379	252955993cac971be273cb7f10a22af9	Discover	33.6896627223007386	-117.939573483971131
48139	2020-08-27 19:36:25	2020-08-27	Mr. Ulises Gottlieb	mr.ulises.gottlieb@geemail.com	Scottsdale	Arizona	3437273717925051	8387c6adef655c6f4245f1afccd4b4af	Mastercard	33.70929370262958	-111.898951363327342
48140	2020-08-27 19:53:05	2020-08-27	Michial Toy	michial.toy@geemail.com	San Francisco	California	3018624916456410	db895c48cd847ca66be46507317e4d9e	Diners Club / Carte Blanche	37.8032067443565722	-122.422877187192867
48141	2020-08-27 20:01:30	2020-08-27	Ms. Roberta McLaughlin	ms.roberta.mclaughlin@geemail.com	Washington	District of Columbia	3054372906921456	76b9f5817a6b736e1a77ae0486ff2a9d	Discover	38.8385294785521893	-77.0363163072828172
48142	2020-08-27 20:04:44	2020-08-27	Adamaris Metz	adamaris.metz@geemail.com	San Diego	California	6011460338102801393	2696fd25542c6a06d292984664b831ea	JCB 16 digit	32.8274349466498947	-117.141817974336448
48143	2020-08-27 20:13:07	2020-08-27	Ms. Ashlyn Reynolds	ms.ashlyn.reynolds@woohoo.com	New York	New York	210060087382344947	5142d1ff1017c330616c46c63b3384c8	Discover	40.6619038779046349	-73.9396101943578543
48144	2020-08-27 20:18:02	2020-08-27	Betsey Watsica	betsey.watsica@geemail.com	Omaha	Nebraska	4201194621946	48fd6e487d0c99a4b4b64cb9c3f55f1c	Maestro	41.2498924266692271	-96.0269357472308087
48145	2020-08-27 20:19:59	2020-08-27	Breonna Emard DVM	breonna.emard.dvm@geemail.com	El Paso	Texas	4115993003282140	48ff83377d789e099e8e0c6155f02831	VISA 16 digit	31.8417431074488917	-106.394675054445869
48146	2020-08-27 20:38:07	2020-08-27	Dr. Effa Heathcote MD	dr.effa.heathcote.md@geemail.com	Fresno	California	676223296027065	3b5c4f6d37047201190cf243bcd31a7b	American Express	36.6873747499998686	-119.890555104763806
48147	2020-08-27 20:43:10	2020-08-27	Kaela O'Conner	kaela.o'conner@geemail.com	San Francisco	California	3112434623211706762	7179eff83d9c042ed8d3f74ce086e63b	Maestro	37.7697004663225115	-122.393821030579758
48148	2020-08-27 20:43:36	2020-08-27	Mr. Elliot Bartoletti Jr.	mr.elliot.bartoletti.jr.@geemail.com	Sioux Falls	South Dakota	3528343283310964810	d807e7f69e0b52559b2d9fd328130289	American Express	43.5921381588179599	-96.8147545105945255
48149	2020-08-27 20:45:54	2020-08-27	Tanika Bergstrom	tanika.bergstrom@warmmail.com	Seattle	Washington	3096864108417028525	34af73dcd16277071bd32036b147c376	Mastercard	47.5270626564435688	-122.443659797442706
48150	2020-08-27 20:48:05	2020-08-27	Newman Abbott	newman.abbott@warmmail.com	Savannah	Georgia	3430045591691885	85c74d3b86578d41ce09801cae8f8efe	Maestro	32.0466583009902379	-81.0844763531967914
48151	2020-08-27 20:48:30	2020-08-27	Loraine Gerlach	loraine.gerlach@woohoo.com	New York	New York	3158547132041596413	c92c68916c86c15209e05440f81b7fdf	Diners Club / Carte Blanche	40.7214360000789171	-74.036346269062534
48152	2020-08-27 20:55:47	2020-08-27	Christeen Toy	christeen.toy@geemail.com	Berkeley	California	869957073543865835	43d3ab09c5678f81e725482e8aaee995	VISA 16 digit	37.8690468850140078	-122.288281344828675
48153	2020-08-27 21:09:22	2020-08-27	Texas Cormier	texas.cormier@geemail.com	Virginia Beach	Virginia	3495090585687871	83cdbdfdcc1a2c1c7505f4c591debc07	Mastercard	36.6999974201153947	-76.1066587445463938
48154	2020-08-27 21:19:34	2020-08-27	Cristian Kautzer	cristian.kautzer@geemail.com	New York	New York	3799515444385578	96bde825f4914dd2ee5a2899719d7fca	VISA 16 digit	40.6014185487050554	-73.9018248334422623
48155	2020-08-27 21:20:40	2020-08-27	Nan Beatty	nan.beatty@warmmail.com	Mesquite	Texas	4659439798350132	8b760da696e7c95bf45acf139b024891	JCB 15 digit	32.7348942163210381	-96.5217831708222747
48156	2020-08-27 21:22:11	2020-08-27	Alivia Keeling-Hoeger	alivia.keeling.hoeger@geemail.com	Escondido	California	55390146707793641	57f52ceefa019e145e2d2a58d9da8fb8	JCB 16 digit	33.1652439365856324	-117.067673861166455
48157	2020-08-27 21:23:57	2020-08-27	Erle Powlowski	erle.powlowski@warmmail.com	Chicago	Illinois	869950579123618508	4cac1f78bdc20b2cfdd0527ac0754345	JCB 15 digit	41.9242438743192736	-87.7423048224329847
48158	2020-08-27 21:32:39	2020-08-27	Charlie Cummings	charlie.cummings@woohoo.com	Denver	Colorado	3158805690519412386	632ce192b304783a14b0247cc824c202	VISA 16 digit	39.8386184719908982	-104.848216480087871
48159	2020-08-27 21:37:28	2020-08-27	Netta Hahn	netta.hahn@geemail.com	San Francisco	California	180011439777151942	8132e8c151ffa410b2a3d693bbc8172a	VISA 16 digit	37.7781259780119498	-122.43812852098533
48160	2020-08-27 21:43:58	2020-08-27	Ms. Hildur Kilback	ms.hildur.kilback@geemail.com	Oakland	California	6011158087718891507	084df1f918c320dc3fb5f2216217e70d	Diners Club / Carte Blanche	37.8389702335171307	-122.285018142520187
48161	2020-08-27 21:47:07	2020-08-27	Dr. Squire Haag	dr.squire.haag@woohoo.com	Philadelphia	Pennsylvania	3088248935916448656	d45e5ed60e2f53e1554b69fac06d2264	Mastercard	39.9874826240777992	-75.1776073770497106
48162	2020-08-27 22:00:57	2020-08-27	Lesia Graham	lesia.graham@geemail.com	Oakland	California	4612154432493190	d18a912e23adba0177fa0f3f64f731ea	Discover	37.7818426315883187	-122.286189420343732
48163	2020-08-27 22:02:44	2020-08-27	Savanna Dibbert-Reinger	savanna.dibbert.reinger@warmmail.com	Santa Ana	California	4454361647989117	34e2eef0fde654240868cdee64821357	Discover	33.7931642022553831	-117.92437832559645
48164	2020-08-27 22:27:36	2020-08-27	Kiefer White-Windler	kiefer.white.windler@geemail.com	Fayetteville	North Carolina	3053697431410968	537b5daca595c5b2c6d70eef48bf7a2a	Maestro	35.0780969703357641	-79.0700122313704412
48165	2020-08-27 22:39:13	2020-08-27	Pearlie Wisozk	pearlie.wisozk@geemail.com	Berkeley	California	210026065228858059	673d13601ebff62342a37764824de42a	Maestro	37.8895344626095678	-122.282940542144473
48166	2020-08-27 22:47:23	2020-08-27	Sherryl O'Connell	sherryl.o'connell@warmmail.com	Arlington	Texas	6011285190615834772	849b3653ce592196a846f9a0d8a8886f	JCB 16 digit	32.6388025158800161	-97.1689271136678769
48167	2020-08-27 22:47:43	2020-08-27	Alexandria Bogan	alexandria.bogan@geemail.com	Frisco	Texas	060483836428900	24e9dc6ca66be2a687466871a4107253	JCB 15 digit	33.1219656801313178	-96.7731425910931051
48168	2020-08-27 22:54:27	2020-08-27	Reinaldo Miller-Reynolds	reinaldo.miller.reynolds@woohoo.com	Lewisville	Texas	3412214898433639	037dc6808072a38a69d4c55d18cdcece	JCB 15 digit	33.0215156143981972	-96.9396359274193742
48169	2020-08-27 22:55:12	2020-08-27	Mr. Edd Schimmel	mr.edd.schimmel@geemail.com	Buffalo	New York	3158007833744428779	4d9e88588ee88ef685937018f8bc5c01	JCB 16 digit	42.9271094572450949	-78.8979462803740148
48170	2020-08-27 22:59:06	2020-08-27	Rosario Parisian PhD	rosario.parisian.phd@geemail.com	Bakersfield	California	4459937475265	3ebba40d7e796aa2a9b018720759f9a4	Voyager	35.2606039511680578	-119.041301860314974
48171	2020-08-27 23:05:13	2020-08-27	Ms. Trinidad Jacobson DDS	ms.trinidad.jacobson.dds@geemail.com	Visalia	California	3031061395979637	446146a600b0817da0cb7d5eaea37c8a	JCB 15 digit	36.229941101507471	-119.310534724140169
48172	2020-08-27 23:21:57	2020-08-27	Ewell Parker	ewell.parker@warmmail.com	Los Angeles	California	6011812215227976422	d925693ebe76feb0c417b0bfa9aeccff	Maestro	34.1145101282145831	-118.37072484972812
48173	2020-08-27 23:24:32	2020-08-27	Latrice Kertzmann-Lindgren	latrice.kertzmann.lindgren@geemail.com	Riverside	California	6011655033541066329	d6ebae247aa087bee366906a4e0915ea	JCB 16 digit	33.8911929492320851	-117.358381681141253
48174	2020-08-27 23:25:23	2020-08-27	Ed Lind	ed.lind@warmmail.com	Charleston	South Carolina	4278336417037218	29b9c2cd63d44e4523320e79862de3c8	Diners Club / Carte Blanche	32.7568840022195147	-79.9606024143435121
48175	2020-08-27 23:26:31	2020-08-27	Jocelynn Armstrong	jocelynn.armstrong@geemail.com	Los Angeles	California	3726079481351439	199bc88e870377a2d297c025b5a051e3	JCB 15 digit	34.0962857444170808	-118.375853999656812
48176	2020-08-27 23:39:41	2020-08-27	Mrs. Christina Schulist MD	mrs.christina.schulist.md@woohoo.com	Lakeland	Florida	3015990183953899	acc8e4455d9f4b8c21a2115bf14e34af	VISA 16 digit	27.9594515956770628	-81.994466301135347
48177	2020-08-27 23:42:48	2020-08-27	Idamae Nitzsche	idamae.nitzsche@geemail.com	Santa Clarita	California	869973667223525559	064dd84eab6c366f1f429528ba629b57	VISA 16 digit	34.4200597048942001	-118.561169561753786
48178	2020-08-27 23:48:15	2020-08-27	Florie Hudson-Wyman	florie.hudson.wyman@geemail.com	Kansas City	Missouri	3733618930311584	1d18e7d6c9f8fd7e287f97f229fc8165	JCB 16 digit	39.0474685572855194	-94.5803370289262375
48179	2020-08-27 23:48:53	2020-08-27	Loyd Wunsch-Paucek	loyd.wunsch.paucek@warmmail.com	San Francisco	California	3158261509450970045	e5ed59b7f69a3c55ac6af802d52bf297	Discover	37.7642328073422178	-122.40189407322471
48180	2020-08-27 23:50:10	2020-08-27	Elwin Tillman	elwin.tillman@geemail.com	Columbus	Ohio	676383453399160	49e9b235e381dc9c9ed083d07a479fa3	Maestro	39.9912710049234335	-82.9728952561739845
48181	2020-08-27 23:56:50	2020-08-27	Minna Skiles	minna.skiles@geemail.com	New York	New York	3112996201896161692	73afce0fac50ad8e9cab963243c9cdfd	Mastercard	40.6713429334796928	-73.8651438381884162
48182	2020-08-27 23:58:12	2020-08-27	Christina Gottlieb	christina.gottlieb@geemail.com	Glendale	California	4814107281131986	faee50e948dac6347d214941dc179de3	Mastercard	34.2056587380111168	-118.303946554604181
48183	2020-08-27 23:59:24	2020-08-27	Jannette Reichel	jannette.reichel@warmmail.com	Los Angeles	California	3528379139312693616	a14e54d8354ee5b3919b891ff783be16	Maestro	34.1058869407378111	-118.363096998770899
48184	2020-08-28 00:03:11	2020-08-28	Raquan Dare	raquan.dare@geemail.com	McAllen	Texas	3096879523562576370	2ff3ad194bb5d6a8b57ef9fe3b7ef590	American Express	26.3230166174776841	-98.2409410653017403
48185	2020-08-28 00:10:56	2020-08-28	Llewellyn Botsford	llewellyn.botsford@geemail.com	New York	New York	3096553572047051049	68fd416e87cf6f3adc2c66aad2aab2fc	Voyager	40.7451837478894703	-73.9881203843176394
48186	2020-08-28 00:16:52	2020-08-28	Callie Veum	callie.veum@geemail.com	Phoenix	Arizona	630474268887598	ec533d9bb42db216e4488a5d10ea49aa	Maestro	33.6180031543064857	-112.008205510249738
48187	2020-08-28 00:20:35	2020-08-28	Elmo Koss	elmo.koss@warmmail.com	Raleigh	North Carolina	6011678792924596300	2cbb965882fcdb284992c266fbf41133	Maestro	35.8064031153585702	-78.6584280358564172
48188	2020-08-28 00:36:36	2020-08-28	Dr. Bryan Batz I	dr.bryan.batz.i@geemail.com	Philadelphia	Pennsylvania	53854306454625391	62c31cec9d2f429e7e13930556b72615	VISA 13 digit	40.0220315171364689	-75.2303139696728493
48189	2020-08-28 00:42:41	2020-08-28	Ms. Blanche Lakin PhD	ms.blanche.lakin.phd@geemail.com	Philadelphia	Pennsylvania	4815078295356860	914539e2d3d5a5273a426679634eab10	JCB 15 digit	40.0692040008917445	-75.0562100795462754
48190	2020-08-28 00:43:56	2020-08-28	Tisa Ebert	tisa.ebert@geemail.com	San Antonio	Texas	3088664238153360295	42f84ff958b536b95d3085a05401575e	American Express	29.4601462667413045	-98.446525638115034
48191	2020-08-28 00:53:26	2020-08-28	Nereida Streich-Walter	nereida.streich.walter@geemail.com	Oakland	California	3484699868031665	07b29470cea8fe856d9a6ce1bef174f9	Discover	37.80181629408699	-122.272456615333269
48192	2020-08-28 00:54:15	2020-08-28	Mr. Montana Bogan PhD	mr.montana.bogan.phd@geemail.com	San Francisco	California	3112133800498425118	fc3d021a75fcb95337dcb76fa97d43b2	Discover	37.7704324672463301	-122.422243193776353
48193	2020-08-28 01:06:46	2020-08-28	Gianna Corwin-Robel	gianna.corwin.robel@woohoo.com	Fremont	California	4166169032070362	12a3fda6019a8dce23a9a9f2d4daf162	JCB 15 digit	37.4032606582790663	-122.011433629131687
48194	2020-08-28 01:12:14	2020-08-28	Kellee O'Reilly	kellee.o'reilly@geemail.com	Waco	Texas	52357290080692128	4e2e60feabfc474f19a6b4ca7a8bee4a	Discover	31.5289336314633459	-97.2210095605012157
48195	2020-08-28 01:14:53	2020-08-28	Lauri Schmidt	lauri.schmidt@geemail.com	Honolulu	Hawaii	869980133469744538	6518ead7b533959892758a2e38f5a7ad	VISA 16 digit	21.2702902242291714	-157.912261487750698
48196	2020-08-28 01:18:04	2020-08-28	Princess Gleichner	princess.gleichner@woohoo.com	Oklahoma City	Oklahoma	6011038678707715149	c34495f49f84b343b10aa8ccc97d0880	JCB 15 digit	35.5424869297914228	-97.4504093212436828
48197	2020-08-28 01:24:07	2020-08-28	Freddy Johnson	freddy.johnson@geemail.com	Memphis	Tennessee	869914079207016393	8bffc8dfb403dc2b0d05b5cb434a8a03	Mastercard	35.1786023499045513	-90.0752327833581745
48198	2020-08-28 01:31:13	2020-08-28	Odis Legros	odis.legros@geemail.com	Fayetteville	North Carolina	4117071930113122	47dba08543eb868717a913c76fe8ad58	JCB 16 digit	35.1236756161574277	-78.9547873620539917
48199	2020-08-28 01:35:35	2020-08-28	Rube Hahn MD	rube.hahn.md@geemail.com	San Bernardino	California	676241534783760	08b4a65026bfe76af9297ad73fa9ad86	VISA 16 digit	34.1252960976012005	-117.231500398019705
48200	2020-08-28 01:36:57	2020-08-28	Cyndi Klein	cyndi.klein@geemail.com	Austin	Texas	55710530900941508	98ef1fa50e712c440229b9ffbd3211b2	VISA 16 digit	30.34068685990162	-97.699863219145314
48201	2020-08-28 01:41:46	2020-08-28	Gustavus Haley-Grant	gustavus.haley.grant@geemail.com	Madison	Wisconsin	3744527887080141	24a78aa34cefdb15a2cfeabf354ccfc1	JCB 16 digit	43.0240734338734327	-89.5276174020372366
48202	2020-08-28 01:41:47	2020-08-28	Briana Wilderman	briana.wilderman@woohoo.com	Naperville	Illinois	4513263267322	a719ece325fbbfe68477308460f212fb	Voyager	41.7092130969658541	-88.1897517255861345
48203	2020-08-28 01:44:58	2020-08-28	Dr. Londyn Schamberger	dr.londyn.schamberger@geemail.com	New York	New York	4834464496875048	2431a2e2ec05896d4fa409b3151fe058	Voyager	40.6190043397005667	-73.8533462175995083
48204	2020-08-28 01:45:49	2020-08-28	Margeret Lesch	margeret.lesch@woohoo.com	New York	New York	4549879900358289	c26b1bec11006a20a0f54f0bfc003a60	VISA 16 digit	40.5983573939409084	-73.9022092496871892
48205	2020-08-28 01:47:36	2020-08-28	Jacque Wisoky	jacque.wisoky@geemail.com	New York	New York	3337419990292835763	3fe27db167e2efe7dc45efd12a6065f8	American Express	40.7065111997760809	-74.0040267625719252
48206	2020-08-28 01:55:39	2020-08-28	Miss Cannie Murazik DVM	miss.cannie.murazik.dvm@geemail.com	San Francisco	California	3158662017395506101	c2dc2a033283c39a05c0a7e3d916d38d	JCB 15 digit	37.7679025280157816	-122.417869120636681
48207	2020-08-28 02:14:45	2020-08-28	Amirah Pfeffer	amirah.pfeffer@geemail.com	Orlando	Florida	4303264255246312	6be1b8c897778bd8000bab3778c000d6	American Express	28.3886032784156477	-81.1768740941736837
48208	2020-08-28 02:17:06	2020-08-28	Dr. Vincenzo Robel DVM	dr.vincenzo.robel.dvm@woohoo.com	Los Angeles	California	3337800934916702170	206bd6bfea8e16ac47ff5b13762a0a33	VISA 16 digit	33.9568552092980553	-118.382014068355033
48209	2020-08-28 02:18:10	2020-08-28	Luisa Wiegand	luisa.wiegand@geemail.com	New Orleans	Louisiana	4991761732113053	e7659af513d99a558bb8503c00cad0b3	Diners Club / Carte Blanche	30.1348307300373897	-90.0115438229199469
48210	2020-08-28 02:22:07	2020-08-28	Trina Cummerata-Krajcik	trina.cummerata.krajcik@geemail.com	San Francisco	California	180095426041459234	753475f6a2d23ec2c01fedf140d3082a	American Express	37.7530986956412562	-122.427201089125873
48211	2020-08-28 02:31:58	2020-08-28	Karl Conn	karl.conn@geemail.com	Louisville	Kentucky	52622423941670756	1c27600a744e9341b8bfc0cabebaae12	JCB 15 digit	38.0952347025178355	-85.7422418180923955
48212	2020-08-28 02:42:17	2020-08-28	Rolland Treutel	rolland.treutel@geemail.com	San Bernardino	California	180005514363727889	725e9f0c8530467db343c5112b0257d1	Maestro	34.2112048299316314	-117.261086086487765
48213	2020-08-28 02:42:46	2020-08-28	Mal Vandervort	mal.vandervort@geemail.com	Aurora	Colorado	3112940978576167035	120f274336a395c936ff43c848d6dcd9	VISA 13 digit	39.7092480878923126	-104.745334858878337
48214	2020-08-28 02:45:16	2020-08-28	Madaline Bogan	madaline.bogan@geemail.com	New York	New York	3490259022071842	afe66aca90c64c2afa0574b14bb715e2	American Express	40.6476844637878258	-73.8857801645424246
48215	2020-08-28 02:45:46	2020-08-28	Lulu Bogisich	lulu.bogisich@geemail.com	Arlington	Texas	869915801784096947	fc6ccf02246f8bad12c1eb53db0989ae	Maestro	32.7306871567636719	-97.196038255982856
48216	2020-08-28 02:52:35	2020-08-28	Clotilde Strosin-Larkin	clotilde.strosin.larkin@geemail.com	Glendale	Arizona	561231909139235	09d7b4e962a58c28b2362cc773a6b9d0	Mastercard	33.4620107673335809	-112.242038185687363
48217	2020-08-28 02:54:05	2020-08-28	Mrs. Michaela Hoppe	mrs.michaela.hoppe@woohoo.com	Des Moines	Iowa	3439162637131361	7069b283652e886f801db03c8599379e	American Express	41.5797729203686117	-93.6376230079259813
48218	2020-08-28 03:18:02	2020-08-28	Lafayette Ratke	lafayette.ratke@geemail.com	Columbus	Ohio	3734909499254540	54b105833688942dc9b1a4bdc02bec08	American Express	40.0488616472154817	-83.0349943615730979
48219	2020-08-28 03:42:17	2020-08-28	Artelia Koss	artelia.koss@geemail.com	Chula Vista	California	3035470789324860	1239097b978e1ef59d6daee11147fcb2	JCB 15 digit	32.6691420243352653	-117.000997445429476
48220	2020-08-28 03:58:15	2020-08-28	Boris Braun	boris.braun@woohoo.com	New Haven	Connecticut	4980904274993	88902f15cd73c0cb5a39d79a1ce7f2af	Maestro	41.3953290879718949	-72.9055982833728109
48221	2020-08-28 04:02:32	2020-08-28	Hortencia Connelly	hortencia.connelly@geemail.com	Peoria	Illinois	3096867361090022987	959ae366633a57357399b00cfe328379	Discover	40.8429085192605825	-89.6586774746771908
48222	2020-08-28 04:02:32	2020-08-28	Javon Kiehn-Kris	javon.kiehn.kris@geemail.com	San Mateo	California	869928781141179096	38b5b71845fbf2c115d68a08d818b0a1	Voyager	37.5232077071323999	-122.352485776910925
48223	2020-08-28 04:11:42	2020-08-28	Andra Green	andra.green@woohoo.com	Philadelphia	Pennsylvania	869904950035755067	ddf38b431841f4975eaac5955a24a1a0	VISA 16 digit	40.0768222867004553	-75.2304904144622384
48224	2020-08-28 04:16:41	2020-08-28	Mr. Roland Kemmer DDS	mr.roland.kemmer.dds@warmmail.com	Seattle	Washington	55639584304949235	3300cbb13f5788e96bc6acb64fe09fc1	JCB 16 digit	47.6382637972403344	-122.340702239043637
48225	2020-08-28 04:27:37	2020-08-28	Dr. Tiffani Blick PhD	dr.tiffani.blick.phd@warmmail.com	San Francisco	California	3055561898414848	315004577f3d5cd45c1b059e59a57c36	VISA 16 digit	37.7442169150954925	-122.412696896708795
48226	2020-08-28 04:29:45	2020-08-28	Mr. Nickolas Kris	mr.nickolas.kris@warmmail.com	Tulsa	Oklahoma	210057531847287535	619ae2fe7c59a3f5e9c0eaf5d732daf4	VISA 16 digit	36.0918550454914566	-95.8854645276863096
48227	2020-08-28 04:31:37	2020-08-28	Dr. Mamie Klein	dr.mamie.klein@woohoo.com	Fort Worth	Texas	3741693394743796	3c0bb84251fbf473ff2d3cca128b2467	JCB 16 digit	32.7245249608587514	-97.3164009391616958
48228	2020-08-28 04:34:29	2020-08-28	Janyce VonRueden-Volkman	janyce.vonrueden.volkman@geemail.com	San Francisco	California	180075025864036907	c4a7a0bc9ec0d7e08ba8a5c72cb0c29a	VISA 16 digit	37.7801970172630774	-122.452041400206241
48229	2020-08-28 04:46:53	2020-08-28	Tula Kreiger	tula.kreiger@geemail.com	Los Angeles	California	3337399427795808363	b86f1658ed8729ca01ecbe8ceaceb528	JCB 15 digit	34.1034754094067907	-118.338395741720859
48230	2020-08-28 04:49:50	2020-08-28	Willam Torphy	willam.torphy@woohoo.com	Phoenix	Arizona	869961850813757162	3d7b1a8f9db1361d54178fd5d7bdbfca	VISA 13 digit	33.6688664225328722	-112.043131828813259
48231	2020-08-28 05:00:02	2020-08-28	Stuart Hand PhD	stuart.hand.phd@geemail.com	San Francisco	California	180036984051165150	582487e2f2fe87762225ced588338f7f	JCB 15 digit	37.7692245733964924	-122.442360160359911
48232	2020-08-28 05:04:59	2020-08-28	Kasandra Schoen	kasandra.schoen@geemail.com	Las Vegas	Nevada	4386085611844155	fd86a01c7a3260e29f6233826e6157ed	Diners Club / Carte Blanche	36.2544722299192088	-115.170213025922322
48233	2020-08-28 05:10:34	2020-08-28	Savion O'Conner	savion.o'conner@geemail.com	Chicago	Illinois	4122284544162012	9fe4135c27bc9e7d81c40d82548778a8	Discover	41.7480896815959355	-87.6827005338884788
48234	2020-08-28 05:11:40	2020-08-28	Mrs. Jayla Ondricka DDS	mrs.jayla.ondricka.dds@geemail.com	Rockford	Illinois	503883289021616	e0d6cb9fb712607db18efc98825e2185	American Express	42.2165885691542186	-89.0853633631303836
48235	2020-08-28 05:14:01	2020-08-28	Lavern Kerluke	lavern.kerluke@geemail.com	San Francisco	California	3416540377930992	87f0ce9be5ea59e3a0e71347b7b5aeff	JCB 16 digit	37.7640681089214851	-122.472532957126305
48236	2020-08-28 05:15:40	2020-08-28	Joshua Kovacek	joshua.kovacek@geemail.com	San Francisco	California	3738131941431545	d35427404d514a9e18041e33cf6fbecb	Diners Club / Carte Blanche	37.7825357522981022	-122.446433389145341
48237	2020-08-28 05:17:06	2020-08-28	Dr. Alaya Bartell	dr.alaya.bartell@geemail.com	Nashville	Tennessee	3494702998255408	c4e2509ce1886381c1a4fdeb9dcd4bfd	JCB 15 digit	36.1566834922537197	-86.8003695892076905
48238	2020-08-28 05:18:58	2020-08-28	Claribel Terry	claribel.terry@geemail.com	New York	New York	869976733357868178	a12e0ab782615c3561be4c5d2a455084	Mastercard	40.6015917314440031	-73.922995087400821
48239	2020-08-28 05:25:01	2020-08-28	Lulie Berge	lulie.berge@geemail.com	El Cajon	California	3112522160752476870	4d8ab0954dbadca7aa0dd09de370d7e2	Voyager	32.8149899736985518	-117.010204806383328
48240	2020-08-28 05:43:16	2020-08-28	Bebe Will-Swaniawski	bebe.will.swaniawski@warmmail.com	Grand Rapids	Michigan	3112844331112334049	d7377d0ff2d4ec49cee420ee0fa0a54e	VISA 13 digit	42.9919587716262797	-85.5850728730339654
48241	2020-08-28 05:50:10	2020-08-28	Lilah Deckow DVM	lilah.deckow.dvm@geemail.com	Winston–Salem	North Carolina	210028426938372310	716757818de31369420babadf84e8325	Diners Club / Carte Blanche	36.106264378665756	-80.1666453090626732
48242	2020-08-28 05:58:19	2020-08-28	Delos Hauck	delos.hauck@warmmail.com	Lewisville	Texas	869987511007474804	500d398547790497df2bdb73fb101e35	Mastercard	33.0634895092327099	-97.0300696826104172
48243	2020-08-28 05:58:34	2020-08-28	Dr. Kyle Flatley	dr.kyle.flatley@geemail.com	Lakewood	Colorado	060439886968252	253d91a14aea3073afd41d9685de3f2c	JCB 15 digit	39.6592257400915074	-105.094394779254117
48244	2020-08-28 05:58:48	2020-08-28	Esau Waelchi V	esau.waelchi.v@geemail.com	Dallas	Texas	3088816511702518275	7768b0bc6b291ef1f0297fd32567631c	JCB 16 digit	32.7343145680885783	-96.7407197717539873
48245	2020-08-28 06:06:23	2020-08-28	Ahmad Mills	ahmad.mills@geemail.com	New York	New York	4768467756190115	7dc7a54ce1692b74d8a5423c1b83600d	JCB 15 digit	40.6004250792078665	-73.9187272936932658
48246	2020-08-28 06:15:19	2020-08-28	Miss Lettie Wintheiser	miss.lettie.wintheiser@geemail.com	Tucson	Arizona	676225691378019	90fe44033339b9fbe12168834fa81640	JCB 15 digit	32.1846812901593751	-110.935633617476
48247	2020-08-28 06:24:47	2020-08-28	Liston Ratke	liston.ratke@woohoo.com	Carlsbad	California	3053383552111392	ed826ced09321909c420eb982fa32cc2	JCB 16 digit	33.1222267601113742	-117.221206848488364
48248	2020-08-28 06:31:10	2020-08-28	Daryl Kling	daryl.kling@woohoo.com	San Francisco	California	3042083516288465	635d9e7059ac8134cd687de40fc568ca	JCB 16 digit	37.7702561412406723	-122.423023134182316
48249	2020-08-28 06:33:52	2020-08-28	Hattie Gulgowski PhD	hattie.gulgowski.phd@geemail.com	League City	Texas	180060432085121681	5315287ce1db3882ea827340fc79ebc2	JCB 16 digit	29.5860160000085841	-95.1266293910782821
48250	2020-08-28 06:58:30	2020-08-28	Belle Bayer	belle.bayer@warmmail.com	Reno	Nevada	4576545038068	a09c7b5256ea62c00c249a8dcb92d5d1	Voyager	39.5863740554157673	-119.826798662513127
48251	2020-08-28 07:09:07	2020-08-28	Dr. Leda Carter DVM	dr.leda.carter.dvm@geemail.com	New Orleans	Louisiana	3037916182233882	df5b599245f7f71aca20e876b2ea1894	Diners Club / Carte Blanche	29.9909094304326906	-90.0010054997429307
48252	2020-08-28 07:10:43	2020-08-28	Dr. Frederick Swaniawski Jr.	dr.frederick.swaniawski.jr.@geemail.com	Portland	Oregon	3024542539344793	39fb7f6d0e0794ae39eef2069a581bd1	Diners Club / Carte Blanche	45.4906553165875351	-122.69467907431536
48253	2020-08-28 07:16:28	2020-08-28	Sincere Kreiger	sincere.kreiger@geemail.com	Roseville	California	180027411171543331	573b2c0d186605fb861e0fe561636425	VISA 13 digit	38.6819263387527315	-121.384376877661424
48254	2020-08-28 07:21:34	2020-08-28	Finnegan Green	finnegan.green@geemail.com	New York	New York	210074064982333236	c8c34da01c8b4f03dfb8f3608b145cb2	Discover	40.599030208563434	-73.9332662889163856
48255	2020-08-28 07:27:53	2020-08-28	Dakota Ullrich	dakota.ullrich@geemail.com	Los Angeles	California	6011675256860781469	99d48e867437db8f28c7b3f725ac8303	VISA 13 digit	34.1111599033098614	-118.413631593668086
48256	2020-08-28 07:34:14	2020-08-28	Dr. Bose Von Jr.	dr.bose.von.jr.@geemail.com	Fresno	California	4993527911102987	a64fa53074d54547866462e47cf10482	Mastercard	36.827236235315354	-119.833959385158124
48257	2020-08-28 07:36:13	2020-08-28	Celine Franecki	celine.franecki@warmmail.com	Odessa	Texas	3088034656010339587	f46efe1832c4d0f090a86021b196d59d	Diners Club / Carte Blanche	31.8324623841337875	-102.30106149987914
48258	2020-08-28 07:53:33	2020-08-28	Oris Bode	oris.bode@geemail.com	Round Rock	Texas	4578654849676172	0848d011465330b41ee6f589a4775066	JCB 16 digit	30.4515458041474254	-97.5821699123680588
48259	2020-08-28 08:02:40	2020-08-28	Hellen Wyman	hellen.wyman@geemail.com	Chula Vista	California	3028073309691078	b0a39872fbd20bc338f5a063f8a70f90	VISA 13 digit	32.6780540245816056	-117.007259769714238
48260	2020-08-28 08:03:24	2020-08-28	Oren Tromp	oren.tromp@woohoo.com	El Paso	Texas	869914484575991864	fcb165d79555e1c08f29caf66607b2f9	JCB 15 digit	31.8998536477625372	-106.372343559002516
48261	2020-08-28 08:03:43	2020-08-28	Shane Block	shane.block@geemail.com	San Antonio	Texas	869913850773743623	22f704f77abcc6c6f645dee031bf86e2	JCB 16 digit	29.4034339095536623	-98.5783371146138734
48262	2020-08-28 08:08:36	2020-08-28	Dimitrios Hodkiewicz	dimitrios.hodkiewicz@geemail.com	San Jose	California	6011928383330359463	f691ca461625b15eb2d722f8f78a6c10	Diners Club / Carte Blanche	37.3338726502198739	-121.910462488162892
48263	2020-08-28 08:20:22	2020-08-28	Phillip Williamson I	phillip.williamson.i@warmmail.com	New York	New York	54708489947828869	ca942fd058eddd1058dd2899220a76bf	JCB 16 digit	40.7347023661937584	-73.8700502853270535
48264	2020-08-28 08:22:00	2020-08-28	Camryn Strosin	camryn.strosin@warmmail.com	Los Angeles	California	180052743433912708	1127f7327ebb6d418ddded34ecbb537f	Voyager	34.0541353748977187	-118.346893963077292
48265	2020-08-28 08:31:56	2020-08-28	Elam Pagac	elam.pagac@geemail.com	Peoria	Arizona	4098987129254646	3c586f72796d093c4f2bf54209ef4fe4	Mastercard	33.7981477182161072	-112.210957012038691
48266	2020-08-28 08:48:48	2020-08-28	Miss Laisha Hermiston	miss.laisha.hermiston@geemail.com	El Monte	California	51736367315562656	9bb4de943fb9bd9fda3d030f5db49588	Mastercard	34.1444850974906231	-118.088898772260549
48267	2020-08-28 08:49:09	2020-08-28	Mendy Rosenbaum	mendy.rosenbaum@geemail.com	Augusta	Georgia	53939119184456881	b8c97014716edcefa441a7b7157a585d	Mastercard	33.3444182920940193	-82.0270472383420923
48268	2020-08-28 08:50:26	2020-08-28	Amelia Hoeger PhD	amelia.hoeger.phd@geemail.com	Nashville	Tennessee	4076540412277	20092ef61f6d96f3ececa8cb8bd3ba85	JCB 15 digit	36.2361703570123765	-86.7039805197063771
48269	2020-08-28 08:52:30	2020-08-28	Brant McGlynn	brant.mcglynn@geemail.com	Las Vegas	Nevada	3528673028169845978	d9d5129f6ca62c749bf53af2dfbae7a4	Mastercard	36.1491687082786086	-115.177411852471892
48270	2020-08-28 08:53:36	2020-08-28	Sable Mann	sable.mann@geemail.com	San Antonio	Texas	4955045651846	b1e6a792b4b45ce1cac74ffa724150f5	Mastercard	29.3760123262252648	-98.5316504958387469
48271	2020-08-28 08:53:57	2020-08-28	Lynnette Hessel	lynnette.hessel@geemail.com	San Jose	California	3088974251385914206	f2d38b52b7ef4f5e760b0b45168c6d63	JCB 15 digit	37.262934996821734	-121.813627718969812
48272	2020-08-28 09:07:33	2020-08-28	Jaidyn Larkin MD	jaidyn.larkin.md@warmmail.com	Amarillo	Texas	502071334122711	4b31ca68fa337ac492779e5b0954c04a	American Express	35.2324229525100421	-101.757268645274266
48273	2020-08-28 09:20:29	2020-08-28	Kymani Stanton	kymani.stanton@woohoo.com	Cleveland	Ohio	3528881449459151927	2c2486efbd8ca492c927fe7159eca738	JCB 16 digit	41.4043166707586465	-81.6624833186395449
48274	2020-08-28 09:21:11	2020-08-28	Maud Ferry	maud.ferry@woohoo.com	Boston	Massachusetts	4718492248486	d12c9ae98615000c320fb580f3949118	Mastercard	42.3057579492386466	-70.9241547348860735
48275	2020-08-28 09:23:08	2020-08-28	Gaynell Reinger	gaynell.reinger@geemail.com	Providence	Rhode Island	4498471721759	6143011e5f572e99c46e577f51387401	VISA 16 digit	41.8307491773594151	-71.473359486126526
48276	2020-08-28 09:27:28	2020-08-28	June Dietrich	june.dietrich@warmmail.com	San Francisco	California	3012144569806452	be2c6abbff65a91cbecc5c0f7719efa2	JCB 15 digit	37.8025850520655595	-122.454886181490608
48277	2020-08-28 09:31:05	2020-08-28	Selmer Zemlak DDS	selmer.zemlak.dds@geemail.com	Worcester	Massachusetts	3022901089088352	ce2b5debea3bfe998ce0637d622fe5c2	Maestro	42.3203741425350302	-71.8539256805341751
48278	2020-08-28 09:35:45	2020-08-28	Jadyn Shields I	jadyn.shields.i@geemail.com	Santa Clarita	California	3407275669036981	fd10a2b810038780b968b14dcd5c83f0	Diners Club / Carte Blanche	34.4815834035836133	-118.589915351672843
48279	2020-08-28 09:42:02	2020-08-28	Haley Mohr PhD	haley.mohr.phd@geemail.com	Boston	Massachusetts	4970216552840793	1b4afa9f0da94d9e15f6676cb5486afc	VISA 13 digit	42.329212514001874	-71.0819301515303579
48280	2020-08-28 09:53:03	2020-08-28	Pink Senger	pink.senger@geemail.com	San Francisco	California	3404015798773226	cefe2b603f1b4eca5b5624afabfabb7a	VISA 16 digit	37.7651153217584081	-122.458480525376245
48281	2020-08-28 09:53:04	2020-08-28	Dr. Audie Harber	dr.audie.harber@geemail.com	San Francisco	California	6011187337101246255	ff93817d47876c320b2208f4b322ad0d	VISA 13 digit	37.754565853556322	-122.428627323071751
48282	2020-08-28 09:54:29	2020-08-28	London Boehm	london.boehm@geemail.com	Gainesville	Florida	3436369281010253	1d6d3b2e50b78e4440a0378d3cc556f6	JCB 15 digit	29.6264481182966364	-82.3284362766299438
48283	2020-08-28 09:55:55	2020-08-28	Mrs. Carlie Kerluke DDS	mrs.carlie.kerluke.dds@geemail.com	El Paso	Texas	55929386430229691	2a1266f3ca457ea2f0517eea1bd988fc	Discover	31.8611336179837608	-106.366572502952081
48284	2020-08-28 09:58:15	2020-08-28	Adolphus McGlynn	adolphus.mcglynn@geemail.com	Chicago	Illinois	4560207196401296	bbf8aad733c10df51f15e553762ecbc0	Mastercard	41.7909801048528422	-87.6653937551688358
48285	2020-08-28 09:59:34	2020-08-28	Kellie Lowe	kellie.lowe@geemail.com	San Diego	California	869992397431461861	529149f2ffb1e916afbc0ad66fb8b58a	JCB 16 digit	32.7597041567854603	-117.224693724783137
48286	2020-08-28 10:01:54	2020-08-28	Shelvia Bradtke	shelvia.bradtke@geemail.com	Jurupa Valley	California	3158557912732678936	4d01404b82cf98004896cedfebe8ad01	VISA 16 digit	34.0133765784487139	-117.368183941396325
48287	2020-08-28 10:02:16	2020-08-28	Delma Steuber MD	delma.steuber.md@warmmail.com	San Francisco	California	3702744305621766	61e67f96f78947d3f8273ec1d324ad78	Diners Club / Carte Blanche	37.7878579884133998	-122.45335574914003
48288	2020-08-28 10:05:08	2020-08-28	Mr. Isiah Aufderhar DDS	mr.isiah.aufderhar.dds@geemail.com	Denton	Texas	561265896191155	f9c30b49649381cf881668ccf579aaf4	Mastercard	33.3135374688807886	-97.1169093681626094
48289	2020-08-28 10:19:26	2020-08-28	Manila Bosco	manila.bosco@warmmail.com	Gilbert	Arizona	3049911908711590	c4c999c343ea273fe53a67fb0d5840fd	Maestro	33.3683245504155721	-111.666131698493288
48290	2020-08-28 10:19:36	2020-08-28	Larkin Schumm-Rodriguez	larkin.schumm.rodriguez@geemail.com	Elk Grove	California	3416383839138197	4fc53d05e81943d502c8f0c8a0a8c1e4	Voyager	38.3741182854216518	-121.332894001845276
48291	2020-08-28 10:22:08	2020-08-28	Mrs. Danyel Kirlin PhD	mrs.danyel.kirlin.phd@geemail.com	Knoxville	Tennessee	869923502865631178	91eecb474771c889d478e6b0ac8715f2	VISA 16 digit	35.9980900135420256	-83.9083689550619454
48292	2020-08-28 10:30:41	2020-08-28	Mr. Jefferey Wilderman	mr.jefferey.wilderman@geemail.com	San Francisco	California	4619848676729	843ef6bc246cf666c3930ab82c22c6ca	Diners Club / Carte Blanche	37.7997938617128142	-122.42324902793213
48293	2020-08-28 10:31:45	2020-08-28	Khalil Mann	khalil.mann@geemail.com	Jacksonville	Florida	869935800588023962	c95858809240860b1f48b8e4df47dee2	Maestro	30.3624266562569893	-81.6551141856316605
48294	2020-08-28 10:35:23	2020-08-28	Emerson Torp-Sawayn	emerson.torp.sawayn@woohoo.com	New York	New York	3006177038738233	16cc35486a133b760c281cc13bb93ac8	VISA 13 digit	40.7364235741309813	-73.9828408006474376
48295	2020-08-28 10:40:44	2020-08-28	Dr. Marilee Anderson PhD	dr.marilee.anderson.phd@geemail.com	Kenosha	Wisconsin	869915929318528331	83e6f9d84f119b98a2207ac9f7dd84f6	JCB 15 digit	42.6122839032977794	-87.8006842219498083
48296	2020-08-28 10:43:08	2020-08-28	Ms. Susan Wilkinson PhD	ms.susan.wilkinson.phd@geemail.com	Detroit	Michigan	869961190023944767	989a420e7a0903952a1236a0fe6ad1e4	Maestro	42.3305371332373497	-83.1317165241695903
48297	2020-08-28 10:45:58	2020-08-28	Manda Padberg-Rowe	manda.padberg.rowe@geemail.com	Berkeley	California	869954473703887335	5517e420c2d209e7de20d3cc5ea87e1c	Maestro	37.8724386866239016	-122.280178720363168
48298	2020-08-28 10:55:02	2020-08-28	Ariella Franecki	ariella.franecki@geemail.com	Dayton	Ohio	54478387516532862	57cb1198bea20f010072e46299f0c1fe	Maestro	39.7149440471339972	-84.2315141628220658
48299	2020-08-28 11:09:30	2020-08-28	Debi Abbott MD	debi.abbott.md@warmmail.com	Virginia Beach	Virginia	502025494428888	39289cc419a09de4a7294325b72195e7	VISA 16 digit	36.8229079323541413	-76.0971863573554828
48300	2020-08-28 11:12:45	2020-08-28	Almedia Heaney-Schoen	almedia.heaney.schoen@warmmail.com	Phoenix	Arizona	3088969607218689678	8521c97f2f692ed022617fd8294274bc	VISA 16 digit	33.5074794011589177	-112.13556016789974
48301	2020-08-28 11:13:34	2020-08-28	Ms. Jessye Armstrong DDS	ms.jessye.armstrong.dds@warmmail.com	Long Beach	California	3034673509899175	4708149b977be35aa024b8847d50f73f	Diners Club / Carte Blanche	33.7776547272510825	-118.229443823748454
48302	2020-08-28 11:17:39	2020-08-28	Mrs. Nelda Altenwerth	mrs.nelda.altenwerth@geemail.com	San Francisco	California	639040788585640	f0614615a3d4060e6eaa1dc7a13d012d	JCB 15 digit	37.7950704823618437	-122.411695410660712
48303	2020-08-28 11:27:12	2020-08-28	Lenny Kuvalis	lenny.kuvalis@geemail.com	Los Angeles	California	4560997118256733	7617b06f88ade374badb3c512fbdfa13	VISA 16 digit	34.0486415799573052	-118.450428558885307
48304	2020-08-28 11:35:58	2020-08-28	Niko Schroeder-Toy	niko.schroeder.toy@geemail.com	New York	New York	3528653158626221242	666f53c3051c3e08d09fe295b42b263f	American Express	40.6767811798248431	-73.8949810801900924
48305	2020-08-28 11:39:22	2020-08-28	Mazie Hermann	mazie.hermann@woohoo.com	Memphis	Tennessee	3799566656218114	5116c23172bad07c2501246dfdd902a9	American Express	35.1787423171170062	-89.9514498991683098
48306	2020-08-28 11:49:35	2020-08-28	Sanaa Nitzsche MD	sanaa.nitzsche.md@geemail.com	Elgin	Illinois	589390805823599	b31c31fe80733d4a059ecaad7dbe32ae	JCB 15 digit	42.1239079261016087	-88.3335370329961194
48307	2020-08-28 11:55:22	2020-08-28	Sonja Kshlerin	sonja.kshlerin@geemail.com	Los Angeles	California	53852299362460450	1338875c89eebf25fb7d55c53f54763a	JCB 16 digit	33.9825511052604767	-118.428331295632944
48308	2020-08-28 11:59:05	2020-08-28	Destini Durgan-Roob	destini.durgan.roob@geemail.com	Cary	North Carolina	3096301529444739225	e99b33a4aeda1e48d86ff8bdd0dc1218	VISA 13 digit	35.6867153093326834	-78.7687154624696859
48309	2020-08-28 12:09:07	2020-08-28	Althea Ratke	althea.ratke@geemail.com	Los Angeles	California	6011318258499438779	1542968d42ffdaec6da15c1c9b6f4364	VISA 16 digit	33.9947333461936552	-118.456139308679099
48310	2020-08-28 12:13:55	2020-08-28	Wilfredo Nader	wilfredo.nader@geemail.com	McKinney	Texas	3112272992953097325	fe8665d69fffff0e0e54e82a1463f3ac	VISA 13 digit	33.2950127598028658	-96.6716431307438882
48311	2020-08-28 12:14:14	2020-08-28	Enos Murazik DVM	enos.murazik.dvm@geemail.com	New York	New York	4836612752412454	90cbd0251e084a6df377a16077cdc19c	VISA 16 digit	40.6103299400992697	-73.8801093464612961
48312	2020-08-28 12:15:53	2020-08-28	Erika Kuhic	erika.kuhic@geemail.com	San Francisco	California	3400896241225631	85e1e2414cd14353cc0c5602d6b9ce8f	Maestro	37.7833667359027814	-122.436907040308441
48313	2020-08-28 12:18:31	2020-08-28	Mrs. Kinsey Maggio	mrs.kinsey.maggio@geemail.com	Jurupa Valley	California	4982749433578	85614cb3aff9c16187969798c9ca857b	VISA 16 digit	33.9511828114673477	-117.475789721824611
48314	2020-08-28 12:44:56	2020-08-28	Kenyatta Cormier PhD	kenyatta.cormier.phd@woohoo.com	Paterson	New Jersey	6011465349027768547	6dd5ce34f87f0ce25d31f96612939c98	Discover	40.8808776475910065	-74.1738938117373721
48315	2020-08-28 12:45:21	2020-08-28	Mrs. Kiyoko Krajcik	mrs.kiyoko.krajcik@woohoo.com	Fort Worth	Texas	6011532231875100289	5c0792c91291ed8454da1ac95ee1cc03	Mastercard	32.7310075496844988	-97.2764444889787541
48316	2020-08-28 12:46:51	2020-08-28	Alvaro Gutkowski	alvaro.gutkowski@geemail.com	San Francisco	California	4088367413825	7c128cbfbaf5ac0e28211f449f86545b	Diners Club / Carte Blanche	37.7821312013404622	-122.412216855638093
48317	2020-08-28 12:55:13	2020-08-28	Miss Aryanna Grady	miss.aryanna.grady@geemail.com	Long Beach	California	3009984907627737	10a16a64b308357dd91f064859caff4a	Diners Club / Carte Blanche	33.7265924663104073	-118.235203999017543
48318	2020-08-28 12:59:54	2020-08-28	Hosea Kohler	hosea.kohler@geemail.com	Tulsa	Oklahoma	4816301676077	f33c33f56c4c538b64faa849251eed73	VISA 16 digit	36.0784203245673325	-95.9053835744924754
48319	2020-08-28 13:03:50	2020-08-28	Bishop Oberbrunner	bishop.oberbrunner@geemail.com	New York	New York	6011317265571951737	5266dafbf08671c6a1bb781ba1b1828f	JCB 16 digit	40.6942899754960052	-73.8644070865947668
48320	2020-08-28 13:06:02	2020-08-28	Olaf Pollich III	olaf.pollich.iii@geemail.com	New York	New York	3112213730256055745	3b67e253f4405e36566912bba4078e74	VISA 16 digit	40.6259541992787234	-74.0298734863184364
48321	2020-08-28 13:13:40	2020-08-28	Dr. Kamden Bechtelar V	dr.kamden.bechtelar.v@woohoo.com	Olathe	Kansas	4708499160347	8bf31f81b130a4e5cbbe559405454455	Mastercard	38.9321124464396391	-94.7712780063673961
48322	2020-08-28 13:17:04	2020-08-28	Jered Rau	jered.rau@woohoo.com	Phoenix	Arizona	4174779681433602	7c57e8a4709deb3b45850f4ef255421b	Mastercard	33.5249825137134678	-112.047360699616746
48323	2020-08-28 13:17:32	2020-08-28	Mareli Shields-King	mareli.shields.king@geemail.com	Chicago	Illinois	3158448072782284276	7c15a9653b5a8facec48feab4ad1d20e	JCB 15 digit	41.7446700355805476	-87.5989069183386846
48324	2020-08-28 13:18:30	2020-08-28	Alton Hammes	alton.hammes@geemail.com	Seattle	Washington	6011931326786532906	aceac9e32be95944138d7bbb78a3aae4	Mastercard	47.5221287482809274	-122.273434020291631
48325	2020-08-28 13:19:10	2020-08-28	Taft Beier DDS	taft.beier.dds@warmmail.com	Tucson	Arizona	630458790228629	49b44ec6d686507759ec08c036780930	Voyager	32.201381955253332	-110.941732260374721
48326	2020-08-28 13:22:56	2020-08-28	Duke Schroeder	duke.schroeder@geemail.com	Phoenix	Arizona	869962824120045701	d220982166d24685019de8c4abf8c2bc	Mastercard	33.5467905742514887	-112.104102351416287
48368	2020-08-28 16:53:46	2020-08-28	Theola Heaney	theola.heaney@geemail.com	Vista	California	4050239104607729	63aee2b5bac82c814db0eedcbff5e767	VISA 13 digit	33.0921326192077245	-117.337824070739003
48327	2020-08-28 13:33:03	2020-08-28	Tennille Schowalter DDS	tennille.schowalter.dds@warmmail.com	Mesa	Arizona	6011227730414084458	c0f434faccd9d367b09d3be811a8ac75	Voyager	33.4436958145029806	-111.744371709728242
48328	2020-08-28 13:49:23	2020-08-28	Thomasina Adams	thomasina.adams@warmmail.com	Portland	Oregon	4958565564985	39274bbe620fb9b22b3978cabf73ed1e	JCB 16 digit	45.4905317049361742	-122.628669655928391
48329	2020-08-28 13:56:30	2020-08-28	Mrs. Imelda Harris DDS	mrs.imelda.harris.dds@warmmail.com	New York	New York	4614975009067	2ff4a3e65fa32eb238c0aded7f2196f4	VISA 16 digit	40.6367204829808344	-74.0077480877179568
48330	2020-08-28 13:59:38	2020-08-28	Mykel Rolfson-McGlynn	mykel.rolfson.mcglynn@geemail.com	Nashville	Tennessee	676239111677306	be17a23ad0180c64eee3af72f0834c4c	Diners Club / Carte Blanche	36.0812446084462053	-86.7224692196026439
48331	2020-08-28 14:16:05	2020-08-28	Regena Denesik	regena.denesik@woohoo.com	Cedar Rapids	Iowa	3158126895961142298	6882c440761565039d457fdb4a4ef609	Discover	41.9325585651751567	-91.5834344149634347
48332	2020-08-28 14:16:14	2020-08-28	Holland Considine	holland.considine@geemail.com	New Orleans	Louisiana	3112295186493480322	5a030e7ed8b9457b3c900c7bbc688c26	Diners Club / Carte Blanche	29.9784854235608123	-89.9594327962752374
48333	2020-08-28 14:17:47	2020-08-28	Dr. Simone Witting PhD	dr.simone.witting.phd@geemail.com	Davie	Florida	4119353658278222	079edcf4d3984fc853b031645fd84f46	VISA 13 digit	25.9989270410764952	-80.3001564517989692
48334	2020-08-28 14:20:32	2020-08-28	Elam Bashirian	elam.bashirian@geemail.com	Chicago	Illinois	3088821925468179648	f6e031280966914434ee2a2ec0fd7912	Mastercard	41.8738756471149642	-87.7345550101745886
48335	2020-08-28 14:23:45	2020-08-28	Selina Bechtelar	selina.bechtelar@geemail.com	Chandler	Arizona	51568067998381035	c54d9ea917e171efbb74261d659b9577	VISA 16 digit	33.290588717823475	-111.910825411358474
48336	2020-08-28 14:30:07	2020-08-28	Miss Euna Frami DDS	miss.euna.frami.dds@geemail.com	Philadelphia	Pennsylvania	3777511621700990	4a0c373f827fd78656737bd43ec6eaaf	Mastercard	39.9413055688101792	-75.1639393085513348
48337	2020-08-28 14:37:04	2020-08-28	Francine Hermiston	francine.hermiston@warmmail.com	Phoenix	Arizona	869974901002446649	c0756fa56ed6dc85b485063089d015c5	American Express	33.5610253984041549	-112.02636767238603
48338	2020-08-28 14:45:56	2020-08-28	Chelsey Nolan	chelsey.nolan@geemail.com	Washington	District of Columbia	561220537210724	a2f6a033b7fe35aa5dc58768e5031f03	Diners Club / Carte Blanche	38.9612696518920387	-77.0474628785371749
48339	2020-08-28 14:47:39	2020-08-28	Justine Rogahn-Kuhic	justine.rogahn.kuhic@woohoo.com	Las Vegas	Nevada	4082523452173	9d56700bd100fa203544c715a583ced7	JCB 16 digit	36.2627362028796227	-115.208961764511088
48340	2020-08-28 14:50:45	2020-08-28	Amara Schuster	amara.schuster@woohoo.com	Glendale	Arizona	180049327124208760	bd6e8e11ba6e30cb695109bf42dbf3c3	JCB 16 digit	33.5779872334323812	-112.22210199961215
48341	2020-08-28 14:52:05	2020-08-28	Ford Breitenberg	ford.breitenberg@geemail.com	Moreno Valley	California	4929778679648559	f64956ba7da395d3dd6f86e2962af3f9	JCB 15 digit	34.0165114352006412	-117.144066468483572
48342	2020-08-28 14:54:31	2020-08-28	Tyron Powlowski	tyron.powlowski@warmmail.com	Mesa	Arizona	210021366124804493	ce441906d25c08756c40020ada8b3cdd	VISA 13 digit	33.4968424223974353	-111.659480728104342
48343	2020-08-28 14:59:34	2020-08-28	Karson Batz	karson.batz@geemail.com	Phoenix	Arizona	4177715349130674	e42f7bc7c28d8027e03bc0f441b424b4	Discover	33.62969281616882	-112.074369149834297
48344	2020-08-28 15:01:06	2020-08-28	Mrs. Althea Effertz	mrs.althea.effertz@geemail.com	Charlotte	North Carolina	54220843259616776	870a3624c984964ff8c6e01728b94e95	Diners Club / Carte Blanche	35.1904335727237125	-80.8931878242120206
48345	2020-08-28 15:02:33	2020-08-28	Mannie Purdy	mannie.purdy@geemail.com	San Francisco	California	4156350558511060	f2c1333d6008ce282880159021f38788	JCB 16 digit	37.7692375418401767	-122.445696897185684
48346	2020-08-28 15:08:56	2020-08-28	Icey Keebler	icey.keebler@woohoo.com	Columbus	Ohio	3158866291127929659	c4d920d3fd802210ba358ec7a61a8394	Diners Club / Carte Blanche	39.9016201435632993	-82.9173269486289541
48347	2020-08-28 15:18:53	2020-08-28	Mr. Braylen Murazik	mr.braylen.murazik@geemail.com	Berkeley	California	4548999572844506	24876202004149ea5d5a6d7df5288e09	Diners Club / Carte Blanche	37.8878888538873397	-122.272915360709391
48348	2020-08-28 15:21:20	2020-08-28	Enrico Bechtelar	enrico.bechtelar@geemail.com	Berkeley	California	54208994726580206	55134d47cf723cc7b410291d641a49d6	JCB 16 digit	37.8613074543425583	-122.278399268314956
48349	2020-08-28 15:24:42	2020-08-28	Bernadine Morissette	bernadine.morissette@geemail.com	Beaumont	Texas	4438580746748501	323bc42bb8ba51af47330e064cdafcf8	Diners Club / Carte Blanche	30.0444586354378629	-94.1885323181536052
48350	2020-08-28 15:28:09	2020-08-28	Mr. Octavius Bauch	mr.octavius.bauch@geemail.com	Stockton	California	4285242311858967	b66f44c446ce549d27b69ab7c422e36f	JCB 16 digit	37.8897176515042773	-121.326237064189456
48351	2020-08-28 15:40:53	2020-08-28	Mrs. Dellia Effertz DDS	mrs.dellia.effertz.dds@geemail.com	Paterson	New Jersey	180098947620281480	8843fb234106e36190257b764d6030a7	Discover	40.9176703198302505	-74.1970382335569809
48352	2020-08-28 15:43:02	2020-08-28	Selma Kihn	selma.kihn@geemail.com	Stockton	California	6011922359383119190	85dda63e31ffa6c2546944540e65c3b6	American Express	37.8808768819749346	-121.314335887189202
48353	2020-08-28 15:49:36	2020-08-28	Zelda Leannon MD	zelda.leannon.md@geemail.com	Los Angeles	California	6011546000977519793	cff5bb2c977c6a97fa712f6dc6865a27	Voyager	34.020857730680703	-118.462147140176214
48354	2020-08-28 15:52:08	2020-08-28	Loy Green	loy.green@geemail.com	Los Angeles	California	55315557547630730	61d5b0282588e2b3c54d05b789f00e85	Mastercard	33.9577332079742078	-118.345277057028554
48355	2020-08-28 15:52:47	2020-08-28	Dr. Gregg Kling MD	dr.gregg.kling.md@geemail.com	Hartford	Connecticut	4148727207839110	a6c143894ca95fc5131c20b61ba65c78	Maestro	41.8095804868280894	-72.7594431941289486
48356	2020-08-28 15:52:54	2020-08-28	Chase Lindgren	chase.lindgren@geemail.com	Ann Arbor	Michigan	51284109029854607	a0aa3c451667a1c3ff26e4cf31605b2e	American Express	42.2645717938024532	-83.7478986517168664
48357	2020-08-28 15:59:29	2020-08-28	Aliana Corkery	aliana.corkery@geemail.com	Gilbert	Arizona	3032431819258695	a713e5a9b2d3b537c549d011b8b7210d	Diners Club / Carte Blanche	33.4083779228731999	-111.720496976156156
48358	2020-08-28 16:01:52	2020-08-28	Eusebio Durgan	eusebio.durgan@geemail.com	El Cajon	California	4573542638669	3486e0ac32a73c7ec89a29fe4e26cfbb	VISA 13 digit	32.7340162740096403	-117.014059478202469
48359	2020-08-28 16:05:24	2020-08-28	Emilie Schuppe	emilie.schuppe@geemail.com	Phoenix	Arizona	4374252617179	bb04bec4ff1103eadfe010876cf6a61d	VISA 16 digit	33.5059742693722242	-112.016245926909534
48360	2020-08-28 16:13:27	2020-08-28	Hattie Schneider DVM	hattie.schneider.dvm@woohoo.com	Chicago	Illinois	630421123182699	e9e35ef267fe44b4d236ebdf833e8556	JCB 16 digit	41.888445619337638	-87.668877211821453
48361	2020-08-28 16:25:13	2020-08-28	Mr. Ramsey O'Keefe	mr.ramsey.o'keefe@woohoo.com	Austin	Texas	3001372112356136	f6ae80af43e29873ff33c1a26e66c530	Mastercard	30.3219436358321452	-97.6576563842367449
48362	2020-08-28 16:28:59	2020-08-28	Floretta Lind	floretta.lind@woohoo.com	Indianapolis	Indiana	4308088452799	01e36da74d85f7e65a8711ed22e7549d	Diners Club / Carte Blanche	39.7300153975848076	-86.096914098897571
48363	2020-08-28 16:32:21	2020-08-28	Kamari Hills	kamari.hills@geemail.com	Berkeley	California	3158058721199847072	dd322f3bc3f655018897b7fffe9ea90d	Diners Club / Carte Blanche	37.8726380132173759	-122.263362915046699
48364	2020-08-28 16:36:47	2020-08-28	Ford Schroeder-Ritchie	ford.schroeder.ritchie@woohoo.com	Grand Prairie	Texas	3038484141540284	dde4e81816311fb14203609dd88d2e93	Voyager	32.704407506301628	-96.9969859026245871
48365	2020-08-28 16:39:03	2020-08-28	Hale Connelly	hale.connelly@geemail.com	Denton	Texas	4341685594085777	89c012dbd5bb99d56f162513d8ea1fc2	American Express	33.1204761013187436	-97.0904397136192756
48366	2020-08-28 16:43:26	2020-08-28	Omer Trantow III	omer.trantow.iii@geemail.com	Tucson	Arizona	180071921742433320	7b1527ea03a4bc884f34ae7513dbf2f4	JCB 15 digit	32.2091111220926081	-110.831444049463045
48367	2020-08-28 16:44:07	2020-08-28	Keenan Gleichner	keenan.gleichner@geemail.com	New York	New York	869968597713817181	f63d144bad6b67bd99704f687aa43d15	Maestro	40.6370712953377478	-73.9136472472816735
48369	2020-08-28 17:03:00	2020-08-28	Brittney Johnston	brittney.johnston@warmmail.com	El Paso	Texas	55422611859697744	3e6e345dc2960257153b28f75959ed64	VISA 13 digit	31.8841267909217656	-106.428474896166477
48370	2020-08-28 17:10:27	2020-08-28	Ami Barton	ami.barton@geemail.com	San Francisco	California	676157065866535	87c2d10d31f4cb8cbdecfe308584bd1b	JCB 16 digit	37.7627455339695288	-122.446678592815616
48371	2020-08-28 17:18:44	2020-08-28	Parker Konopelski	parker.konopelski@geemail.com	San Francisco	California	3003579040468936	f38614441fd20a19e3705be56828fe40	JCB 16 digit	37.7867594520804531	-122.468500049534825
48372	2020-08-28 17:44:40	2020-08-28	Donny Green	donny.green@geemail.com	Vacaville	California	3483885589887243	49f0850be7dca95712390f67706c1912	Voyager	38.321943250869964	-122.036449038597951
48373	2020-08-28 17:52:56	2020-08-28	Tamya McCullough	tamya.mccullough@geemail.com	Washington	District of Columbia	55211840296419348	d3e44172b6d3751d1b1dcfe8903e3915	American Express	39.0016253760814635	-76.9940463899381484
48374	2020-08-28 17:59:36	2020-08-28	Mora Yundt	mora.yundt@geemail.com	Los Angeles	California	6011969755796851770	6ba173e9b5c468c81769d323c377fdbb	JCB 16 digit	34.1191026451863308	-118.314768074731518
48375	2020-08-28 18:06:05	2020-08-28	Ms. Amparo Aufderhar DDS	ms.amparo.aufderhar.dds@warmmail.com	Houston	Texas	3112615121959675621	e77cc8b59b3a4055c1c236f7fbda58e5	VISA 13 digit	29.747908737378566	-95.2969956939589196
48376	2020-08-28 18:09:18	2020-08-28	Mark Gulgowski-Rodriguez	mark.gulgowski.rodriguez@geemail.com	Berkeley	California	3794803557821596	0415b6f12926e3c53d440348320887af	VISA 13 digit	37.8856180867753878	-122.258055982273348
48377	2020-08-28 18:10:36	2020-08-28	Mr. Branson Beatty DVM	mr.branson.beatty.dvm@woohoo.com	San Francisco	California	3451611707468650	4b8ac51059b52214b96e577973425f67	VISA 16 digit	37.8035311819900954	-122.444631764000817
48378	2020-08-28 18:10:37	2020-08-28	Jedidiah Collins	jedidiah.collins@woohoo.com	Plano	Texas	6011074838965471141	139eaea557fc7651989a40c73d637076	VISA 16 digit	33.0948447131171832	-96.7038743416961353
48379	2020-08-28 18:27:07	2020-08-28	Tamera Haley	tamera.haley@geemail.com	Oakland	California	3415683874308626	d899406c1f8ce179ea03fdaf3b527ea9	JCB 15 digit	37.8037018477880906	-122.29069843479877
48380	2020-08-28 18:43:13	2020-08-28	Brody Fay	brody.fay@geemail.com	Fort Worth	Texas	869913672459462900	b0c2a1ddc96e98e2ffa00f07e7ce9d65	VISA 16 digit	32.8753809841405626	-97.4180916055392458
48381	2020-08-28 18:46:37	2020-08-28	Ms. Kris Thiel	ms.kris.thiel@geemail.com	Orlando	Florida	3036909035943196	ad7f61d695b80bf8c47a0206b544bc14	Mastercard	28.3881731665026393	-81.3388950016781678
48382	2020-08-28 19:06:23	2020-08-28	Mr. Lon Hilpert	mr.lon.hilpert@woohoo.com	Lakewood	Colorado	3337507337358684698	dfc2bb67103b15328984cd8bc120406b	VISA 16 digit	39.6848209652990107	-105.099828915719314
48383	2020-08-28 19:15:34	2020-08-28	Waino Rice-McLaughlin	waino.rice.mclaughlin@geemail.com	Sterling Heights	Michigan	869989112472946158	fd2cd2095efec391876feceb0eeb5d58	Diners Club / Carte Blanche	42.5690467068076188	-83.0728397925544471
48384	2020-08-28 19:19:57	2020-08-28	Ardith Hyatt	ardith.hyatt@geemail.com	Akron	Ohio	6011209687558880277	f182966bc1c83a2fbc79ae820d5d947d	Maestro	41.1730332922488458	-81.4648267225209679
48385	2020-08-28 19:20:15	2020-08-28	Cherrelle Ryan-Crooks	cherrelle.ryan.crooks@warmmail.com	Houston	Texas	3096599955312994090	cbf85246bf5fa8e4e858d621b5643f81	Maestro	29.7220964098427451	-95.3803823407754265
48386	2020-08-28 19:20:44	2020-08-28	Ammon Kemmer MD	ammon.kemmer.md@geemail.com	Tucson	Arizona	869997678959454569	ced0a8ee3e8527e010ec9f46dd3d9ddf	Diners Club / Carte Blanche	32.1040553157258799	-110.958100954559072
48387	2020-08-28 19:26:55	2020-08-28	Audrina O'Kon	audrina.o'kon@warmmail.com	New York	New York	4852393549436382	23076201dd7b85202fc2222190bd07ee	VISA 16 digit	40.5836559100765726	-73.9812552019849363
48388	2020-08-28 19:34:10	2020-08-28	Lee Lockman	lee.lockman@geemail.com	Tallahassee	Florida	55222855854717781	925d7a80a108151e590a06b5155a9e0b	JCB 16 digit	30.4743413360346125	-84.3094051335021817
48389	2020-08-28 19:35:10	2020-08-28	Crete Jerde	crete.jerde@geemail.com	New York	New York	4048422239833486	9406a4bd455d3a0cfd30ac58ebcb92f0	VISA 13 digit	40.701569123355668	-73.9423651779897426
48390	2020-08-28 19:40:03	2020-08-28	Jarrett Bartoletti	jarrett.bartoletti@geemail.com	St. Louis	Missouri	3112904607421416602	9498b26b5e2ab8d04bb0ce620517b9a9	VISA 16 digit	38.5524067075148196	-90.1809937492948137
48391	2020-08-28 19:40:07	2020-08-28	Miss Leslee Corwin MD	miss.leslee.corwin.md@geemail.com	Irving	Texas	6011267526269034056	ef2d4dabc2b448748325d905e43faef1	VISA 16 digit	32.8983303607858701	-96.8955838633049211
48392	2020-08-28 19:54:19	2020-08-28	Blanca Wolff	blanca.wolff@geemail.com	San Francisco	California	869995397732943903	a18e74fd6ebb4762a43cf5760b4e8697	American Express	37.7706017305622126	-122.432321208207156
48393	2020-08-28 20:04:46	2020-08-28	Cambria Reilly	cambria.reilly@geemail.com	Round Rock	Texas	6011841181411933022	6502689786ef1807230e295db3d8be5a	Voyager	30.4546743332080574	-97.6475401293337342
48394	2020-08-28 20:08:58	2020-08-28	Toshio Breitenberg-Rath	toshio.breitenberg.rath@geemail.com	San Francisco	California	6011185990093437738	28e3f2a70097aa0878a9739e52941c06	JCB 15 digit	37.7868993572652414	-122.428604637639623
48395	2020-08-28 20:09:10	2020-08-28	Charle Reynolds	charle.reynolds@geemail.com	Ventura	California	639003391709718	17f1a4c8703a3e5c3eab25794d1b9a8d	American Express	34.3599305857133146	-119.230964032710347
48396	2020-08-28 20:15:38	2020-08-28	Gillian Toy	gillian.toy@geemail.com	Pomona	California	180047607646990744	bee14884c2b7aa0b4c656a808e402d8f	Voyager	34.0338617868293127	-117.828836513447015
48397	2020-08-28 20:21:42	2020-08-28	Mr. Hilmer Schulist IV	mr.hilmer.schulist.iv@geemail.com	Philadelphia	Pennsylvania	3038849201565266	a5f6f7960490ac95bb46be4da989c798	Voyager	39.9679827216971688	-75.0983105470791514
48398	2020-08-28 20:26:01	2020-08-28	Isai Klein	isai.klein@geemail.com	Philadelphia	Pennsylvania	52466819669280802	d0030ea6bebf90ee80776147efc64f24	JCB 16 digit	40.0172325902111794	-75.0690191118877408
48399	2020-08-28 20:26:02	2020-08-28	Dolphus Hagenes	dolphus.hagenes@geemail.com	Hialeah	Florida	4128154972326	ef1082906e840f6d1b96b476036481f8	VISA 16 digit	25.7795545960288521	-80.2444281326975641
48400	2020-08-28 20:36:37	2020-08-28	Romello Waelchi	romello.waelchi@geemail.com	San Diego	California	4122429993596844	90d6f2591c5c34b1fbc3c05775fe1a02	Voyager	32.9017217919763212	-117.111753290044149
48401	2020-08-28 20:41:35	2020-08-28	Aleck Buckridge	aleck.buckridge@geemail.com	Columbus	Georgia	180079793219950090	fec99fa60e1af902c275c5f9cd972e32	VISA 13 digit	32.4336145438764234	-84.8290346688289105
48402	2020-08-28 20:50:10	2020-08-28	Eleonore Dare	eleonore.dare@geemail.com	Akron	Ohio	55081352077953435	eace0bdfbe1f98c4451cbd8d1a433a9a	JCB 16 digit	41.0002982793673851	-81.444873284160721
48403	2020-08-28 21:00:17	2020-08-28	Georgie Berge	georgie.berge@warmmail.com	Long Beach	California	6011122300083248291	e6144ff8fa2adb4c1e4239284322decd	Mastercard	33.7889408178448676	-118.078813343930236
48404	2020-08-28 21:16:55	2020-08-28	Ms. Lydia Padberg MD	ms.lydia.padberg.md@warmmail.com	Pasadena	California	4609440756164524	acc1d67247d12fffeaada6e692ae07fc	VISA 16 digit	34.1682240489259357	-118.20513871696815
48405	2020-08-28 21:25:16	2020-08-28	Andres Tromp	andres.tromp@geemail.com	Los Angeles	California	4338390814323794	8fae34fcdb6d639cb38839fabf52ad45	VISA 16 digit	33.9911088666278829	-118.44089978509507
48406	2020-08-28 21:27:15	2020-08-28	Mordechai Predovic	mordechai.predovic@woohoo.com	New York	New York	3158404850108949157	78aa5c8f9930558af34ed265872a2fe5	JCB 15 digit	40.6198802727963795	-73.8940316517267348
48407	2020-08-28 21:31:12	2020-08-28	Mertie O'Keefe	mertie.o'keefe@woohoo.com	Fresno	California	503864665912339	4f08dd54f74198da232d0671fc0a097f	American Express	36.8776810923930256	-119.793770425591248
48408	2020-08-28 21:39:28	2020-08-28	Faye Lubowitz-Shields	faye.lubowitz.shields@geemail.com	San Francisco	California	3016413598571296	278b1adbc46855f89dada13af589d37c	VISA 16 digit	37.7936224089717356	-122.442062419053357
48409	2020-08-28 21:43:56	2020-08-28	Roderic Skiles	roderic.skiles@geemail.com	San Francisco	California	3112697529679421707	494481e663ee1d91934bdc9ed03569dd	VISA 16 digit	37.7798436583834985	-122.409342860919935
48410	2020-08-28 21:46:47	2020-08-28	Ludwig Lemke	ludwig.lemke@geemail.com	Fayetteville	North Carolina	3043407403190428	e9ba91f04f0bfed28a82932566dcf9e5	Mastercard	35.1750613607253868	-78.9568714296575678
48411	2020-08-28 21:48:03	2020-08-28	Mr. Darion McCullough	mr.darion.mccullough@woohoo.com	San Antonio	Texas	4422352468711978	7359723a90dd3cd50eb851bf958ee275	JCB 15 digit	29.5623337186478068	-98.4546836397912273
48412	2020-08-28 21:49:05	2020-08-28	Ms. Roberta Bartoletti DVM	ms.roberta.bartoletti.dvm@geemail.com	Jacksonville	Florida	869958765041371492	aa13e8c70948c4d5ad65f14ab80ca464	Voyager	30.2528253140445784	-81.5748699176203473
48413	2020-08-28 21:49:37	2020-08-28	Toshio Swift	toshio.swift@geemail.com	Phoenix	Arizona	4329300928427986	1778a2c3b155dfa8e12c0c35a2b372cd	JCB 16 digit	33.6089150199599587	-112.162573983466629
48414	2020-08-28 21:51:02	2020-08-28	Mr. Tobe Aufderhar	mr.tobe.aufderhar@geemail.com	Phoenix	Arizona	060403451252757	361cdd207ed27e10d01e16d0866c66b0	VISA 16 digit	33.5140186164926774	-111.99105022749157
48415	2020-08-28 21:52:45	2020-08-28	Fidencio Miller II	fidencio.miller.ii@geemail.com	Virginia Beach	Virginia	53327637703146592	8a4e46c06db6c233268c65a3712ad32d	Diners Club / Carte Blanche	36.803491576034574	-75.9474569967619999
48416	2020-08-28 21:52:54	2020-08-28	Samira Denesik PhD	samira.denesik.phd@geemail.com	San Francisco	California	869956608594290549	8d5011a537e72c271b795dbb34c6eed6	Maestro	37.781724052852816	-122.418766164513343
48417	2020-08-28 21:53:04	2020-08-28	Caswell Heaney	caswell.heaney@warmmail.com	Wichita	Kansas	3013704015660743	21b56af03fb55e254230284a787c1678	VISA 13 digit	37.666954751021045	-97.4321314512953194
48418	2020-08-28 21:55:43	2020-08-28	Mable Kris	mable.kris@warmmail.com	Los Angeles	California	3428371920229344	f0bb5c4303457eb578d904118d2bb4ce	VISA 16 digit	33.9209894223004582	-118.493222796171153
48419	2020-08-28 22:00:37	2020-08-28	Dr. Chastity Ruecker PhD	dr.chastity.ruecker.phd@geemail.com	Denver	Colorado	55893761388278266	19f6ac5918abb444d22e947c58d83e19	JCB 16 digit	39.7862392786011085	-104.938335682429752
48420	2020-08-28 22:09:00	2020-08-28	Maebelle Dickinson	maebelle.dickinson@geemail.com	New Orleans	Louisiana	3088083961437405841	2000d3ec6ec0886209e1f8da52223a12	JCB 16 digit	29.9960331519149257	-89.9348519783727767
48421	2020-08-28 22:19:44	2020-08-28	Dr. Volney Torphy I	dr.volney.torphy.i@geemail.com	Columbus	Georgia	3528173016675417312	2cbc8b1bdae252cdfd34921b0ac3908c	Mastercard	32.4952545092485821	-84.8083108072332976
48422	2020-08-28 22:21:46	2020-08-28	Carrol Mohr	carrol.mohr@geemail.com	San Francisco	California	51207914123323753	d45ffa29a45a3eda82028ec844b118cf	Voyager	37.7431643643055708	-122.428422490190684
48423	2020-08-28 22:22:44	2020-08-28	Ms. Zenobia White	ms.zenobia.white@warmmail.com	Fresno	California	3158153275906941623	0e761455beb9c9e65c7b9bd1b70927b1	JCB 16 digit	36.7022021969653665	-119.769724136508628
48424	2020-08-28 22:31:23	2020-08-28	Dafne Paucek	dafne.paucek@geemail.com	Centennial	Colorado	3112317828585554548	ee1b071f2e743cb5e3e3f59fd78261b7	Voyager	39.6655713380821098	-104.840021943429861
48425	2020-08-28 22:34:25	2020-08-28	Susanne Wintheiser	susanne.wintheiser@woohoo.com	Mobile	Alabama	3434168713036718	5e0e44bc02ce9f63697f46be6fab5948	JCB 16 digit	30.580343191057068	-88.0760650115225445
48426	2020-08-28 22:35:46	2020-08-28	Ms. Jennifer Steuber PhD	ms.jennifer.steuber.phd@geemail.com	Dallas	Texas	210068202590264421	061f3b0cd7cd5628c9db636ff33e86b6	Voyager	32.7062837940912701	-96.7771048209126974
48427	2020-08-28 22:37:48	2020-08-28	Tisa Cassin	tisa.cassin@woohoo.com	Gainesville	Florida	3088503329781037531	f33bdf358fb0189b005a9758759b9177	Maestro	29.6211471957445127	-82.3816965438764583
48428	2020-08-28 22:38:46	2020-08-28	Eric Morissette-Kohler	eric.morissette.kohler@warmmail.com	Charlotte	North Carolina	55101128557109235	bb41832303bf95515048adb662286ff5	VISA 16 digit	35.2125561361920063	-80.9169157654456797
48429	2020-08-28 22:43:14	2020-08-28	Mr. Gideon Schimmel	mr.gideon.schimmel@geemail.com	Fort Lauderdale	Florida	589396673964100	2c5145cdec1338a727c523e50703aa29	American Express	26.0744431850023588	-80.0642609285477533
48430	2020-08-28 22:43:30	2020-08-28	Mortimer Harris IV	mortimer.harris.iv@warmmail.com	Concord	California	3112472900531973410	616bf30778e8ff2d6c55a150b7cbf985	VISA 13 digit	37.9317679751131678	-121.957306315301352
48431	2020-08-28 22:50:25	2020-08-28	Elizebeth Klocko	elizebeth.klocko@geemail.com	Philadelphia	Pennsylvania	4368425043495	84ca74d702997f8ca73b3a718655d628	VISA 13 digit	39.9925079440657072	-75.1552782503787427
48432	2020-08-28 22:56:01	2020-08-28	Maximiliano Fadel	maximiliano.fadel@geemail.com	Everett	Washington	6011595279850553349	db14885688919ff71c5d8deab609895b	Voyager	47.9117862481050238	-122.105274596264209
48433	2020-08-28 22:57:50	2020-08-28	Cristal Jaskolski	cristal.jaskolski@woohoo.com	San Francisco	California	4164025224818574	a1503f1d4f2b75e01a136ced10f467b3	Voyager	37.7911812378686491	-122.438027123663815
48434	2020-08-28 23:02:09	2020-08-28	Lyman Macejkovic-O'Keefe	lyman.macejkovic.o'keefe@geemail.com	San Diego	California	502011017831493	9787efed0af4517ca65ebc0d66510008	JCB 16 digit	32.8021513214867539	-117.055529248844834
48435	2020-08-28 23:17:15	2020-08-28	Wheeler Toy	wheeler.toy@warmmail.com	New York	New York	869951370627678415	dc9a82fb4c4547e677425f23d30efffd	Diners Club / Carte Blanche	40.6549460968226199	-73.8825007190357894
48436	2020-08-28 23:19:30	2020-08-28	Boston Waelchi	boston.waelchi@geemail.com	San Francisco	California	3759381821113408	c91a20ec940b4d4b2aabab2b4166ad8b	Voyager	37.7566868418573378	-122.438318017031406
48437	2020-08-28 23:23:26	2020-08-28	Devin Rau	devin.rau@geemail.com	Berkeley	California	639005229838221	709b7aa34e3928fd38d13e4e744eeb32	Maestro	37.8518329322082678	-122.263121519636215
48438	2020-08-28 23:25:15	2020-08-28	Zaiden McCullough	zaiden.mccullough@geemail.com	San Francisco	California	4585568245111694	8b032ecc6c05e8aac8784e5f67cd175f	Voyager	37.8033702697354244	-122.42125448413401
48439	2020-08-28 23:27:07	2020-08-28	Alyssa Veum	alyssa.veum@woohoo.com	New York	New York	3036066072840296	94c4122434d06331710b3f88c288212e	Diners Club / Carte Blanche	40.6565537741631289	-73.8842122196581244
48440	2020-08-28 23:48:54	2020-08-28	Dr. Leland Gislason I	dr.leland.gislason.i@geemail.com	San Francisco	California	54429606737972858	855427a04e1d725a0de19c4b19fbcabe	JCB 16 digit	37.7614654427489	-122.420448501075029
48441	2020-08-28 23:50:38	2020-08-28	Torrance Walker	torrance.walker@woohoo.com	Oakland	California	639093876153854	33cff44543a3ccefc7ccf068e9b4384c	Voyager	37.8002590782902175	-122.273875147649633
48442	2020-08-29 00:01:53	2020-08-29	Dr. Unknown Erdman MD	dr.unknown.erdman.md@warmmail.com	Aurora	Colorado	4912569238927405	5c362705609db4fa3c56b535cd91238f	JCB 15 digit	39.7648653103150451	-104.665257804433637
48443	2020-08-29 00:03:54	2020-08-29	Abbie Hilll	abbie.hilll@warmmail.com	Philadelphia	Pennsylvania	060423454871114	8b7f4eee89e29b93d5b3604afa853b9e	Mastercard	39.9464329506229632	-75.188750502457097
48444	2020-08-29 00:05:33	2020-08-29	Reyes Gaylord	reyes.gaylord@warmmail.com	Columbus	Ohio	4802621936773079	a0e70ee3907737307f61c260915de05d	American Express	40.0648179028227887	-83.0067430197030376
48445	2020-08-29 00:11:21	2020-08-29	Gennie Buckridge DVM	gennie.buckridge.dvm@woohoo.com	Springfield	Massachusetts	4418478718472149	87a0ba7de176459faafe5eb65a1ce72c	Diners Club / Carte Blanche	42.086647806197405	-72.5694617119711012
48446	2020-08-29 00:12:52	2020-08-29	Nealie Becker-Conn	nealie.becker.conn@geemail.com	Washington	District of Columbia	3088913145552019381	ceee85c76d99d03a10004a7e6821be9d	JCB 15 digit	38.9619793953172859	-76.9224283921744671
48447	2020-08-29 00:13:48	2020-08-29	Theodosia Schroeder	theodosia.schroeder@geemail.com	Berkeley	California	869976284309213550	fcfa48d7d22ff2804d539e72bd5d4ad4	JCB 16 digit	37.877485048360434	-122.297027158902367
48448	2020-08-29 00:16:53	2020-08-29	Mrs. Zeta Crist	mrs.zeta.crist@warmmail.com	New York	New York	55121282054846603	303d85739d69dbcdcb72044931ff1be0	VISA 16 digit	40.6246166357528438	-73.9433890982892308
48449	2020-08-29 00:19:58	2020-08-29	Mr. Damarion Dickens	mr.damarion.dickens@geemail.com	Dallas	Texas	060471765421228	e058151e0db722dbec55e1bb407ec218	JCB 15 digit	32.7829286548580967	-96.7456513376869225
48450	2020-08-29 00:22:23	2020-08-29	Steve Collier	steve.collier@woohoo.com	New York	New York	6011781099837205571	f57518707557c1d91bf48004248e86b8	American Express	40.5889718257579943	-74.0166109147842946
48451	2020-08-29 00:24:14	2020-08-29	Dr. Elsie Parisian	dr.elsie.parisian@geemail.com	Raleigh	North Carolina	589354507002639	493af80faaaaeba8724c61920b1ecc10	Discover	35.9208786915190501	-78.710377732099218
48452	2020-08-29 00:26:14	2020-08-29	Domenic Goldner	domenic.goldner@geemail.com	San Francisco	California	4898083346366249	a462ca662e09af951e8612ee0b481b90	VISA 13 digit	37.7697516024363438	-122.458112504800837
48453	2020-08-29 00:28:24	2020-08-29	Diandra Smitham	diandra.smitham@geemail.com	Phoenix	Arizona	675979121650836	f82aad126b0b6e0a9e18e28a47ae8f30	VISA 13 digit	33.4932043074097479	-112.118523074260366
48454	2020-08-29 00:28:42	2020-08-29	Ben Hilpert	ben.hilpert@geemail.com	Jacksonville	Florida	869952551311321532	e7333a658a1b070b0b060da02ad09b97	JCB 16 digit	30.25587931196727	-81.731626163244627
48455	2020-08-29 00:32:50	2020-08-29	Ms. Almedia Parisian	ms.almedia.parisian@geemail.com	San Francisco	California	869937391996940300	dd7b15e23f3e7c11e14aa3c89f8410ca	Mastercard	37.7935215275123682	-122.461783168058375
48456	2020-08-29 00:33:27	2020-08-29	Gaylord Purdy	gaylord.purdy@geemail.com	Glendale	Arizona	676107306052791	c2bf325699e8acc48d0f723de8d3bb21	Mastercard	33.5784994511160946	-112.211502121368042
48457	2020-08-29 00:34:42	2020-08-29	Bonita Fadel DVM	bonita.fadel.dvm@geemail.com	Atlanta	Georgia	3088923277177685631	e90d32c093036dcf7fc06be73a595306	American Express	33.7968364627841851	-84.3231882249515508
48458	2020-08-29 00:35:08	2020-08-29	Wyatt Bechtelar	wyatt.bechtelar@geemail.com	Concord	California	869952852281395567	e6723fad5840b4277f76aedfa7b3cdac	VISA 16 digit	38.0189286685481704	-121.924269695317747
48459	2020-08-29 00:37:55	2020-08-29	Dr. Cody Bins V	dr.cody.bins.v@geemail.com	San Francisco	California	4173035334600217	1155d4006ce4326c6a98b70123b8b40a	Mastercard	37.7795148727378916	-122.436913985921407
48460	2020-08-29 00:40:10	2020-08-29	Grayson Haag	grayson.haag@warmmail.com	Lincoln	Nebraska	4538501053908958	3c95d9778a91c0977b00bc0d5371e636	Maestro	40.8316655272170905	-96.6573978400949443
48461	2020-08-29 00:55:09	2020-08-29	Florence Pacocha	florence.pacocha@warmmail.com	Oakland	California	3528607538014609487	cd2f552b170e50488fcf77d93b831a56	Diners Club / Carte Blanche	37.8362670150040259	-122.247850753735037
48462	2020-08-29 01:00:09	2020-08-29	Dimitri Grady MD	dimitri.grady.md@geemail.com	New York	New York	639098493542827	5403fb8a2f4e1bbb0e825517b8c61048	VISA 13 digit	40.6845473514161995	-73.9020877570740851
48463	2020-08-29 01:04:11	2020-08-29	Jenny Sipes-Hansen	jenny.sipes.hansen@geemail.com	New York	New York	210030201866161142	95a072b9f79470acb2469205d5b77f31	Maestro	40.7571659721191963	-73.8609783419303625
48464	2020-08-29 01:04:18	2020-08-29	Don Reichert	don.reichert@woohoo.com	Jackson	Mississippi	4116017802497128	d26d29bec27997d0760141ff7895da77	Voyager	32.3594134707648351	-90.1769679423395587
48465	2020-08-29 01:05:25	2020-08-29	Cami Reinger DVM	cami.reinger.dvm@geemail.com	Phoenix	Arizona	3096716266227975317	15b0f92be195215b4ce99da8475b41be	American Express	33.5253071234494442	-112.122912472200028
48466	2020-08-29 01:08:40	2020-08-29	Casey Vandervort-Dickens	casey.vandervort.dickens@warmmail.com	San Francisco	California	3013363939701412	bf8e5ea926c61d6cb764b10efff2f84f	Diners Club / Carte Blanche	37.7431911683882646	-122.40570687125124
48467	2020-08-29 01:08:51	2020-08-29	Randle Hoppe-Miller	randle.hoppe.miller@geemail.com	Columbus	Ohio	869959963408767506	0045fe4c3ee79eb9613a3aae3cfc9d78	JCB 16 digit	39.9872407605916251	-82.918677210505308
48468	2020-08-29 01:20:02	2020-08-29	Kandice Murray	kandice.murray@warmmail.com	Louisville	Kentucky	55239549167537165	9e05da1f83f658405dfe942ee81f5129	VISA 16 digit	38.1587876541443123	-85.626694196376576
48469	2020-08-29 01:22:49	2020-08-29	Mr. Della Shanahan II	mr.della.shanahan.ii@geemail.com	Baltimore	Maryland	210050127512506411	cd312231d171e9e7df39237e553f127f	JCB 16 digit	39.2736971707548932	-76.7058315884340516
48470	2020-08-29 01:26:37	2020-08-29	Leif Russel-Kulas	leif.russel.kulas@geemail.com	San Francisco	California	3713200593270086	ed28a4d21116c321fd86591039c5b2d0	Mastercard	37.7664517129858766	-122.434351343303518
48471	2020-08-29 01:29:18	2020-08-29	Clair Rippin-McGlynn	clair.rippin.mcglynn@geemail.com	San Francisco	California	3528241608729216217	665117a75f74a7f6bfed60359fdafe3b	VISA 16 digit	37.7590861515766036	-122.447057412703714
48472	2020-08-29 01:35:31	2020-08-29	Noel Glover V	noel.glover.v@geemail.com	Nashville	Tennessee	3088742221855577271	9ddbdb69498bf31823cefba441971d30	JCB 16 digit	36.1853062813758797	-86.7484409511927481
48473	2020-08-29 01:48:33	2020-08-29	Lavern Berge	lavern.berge@woohoo.com	San Diego	California	3046223362823967	4cfd631b24759ef85f05722c1fd89bfe	JCB 16 digit	32.8682583831783361	-117.152305735126149
48474	2020-08-29 01:49:00	2020-08-29	Sheron Mills	sheron.mills@geemail.com	San Francisco	California	52683143937602177	b4b1a1b07c417f0e1a27a643ae15e154	VISA 13 digit	37.7321375162423678	-122.439522231377154
48475	2020-08-29 01:52:23	2020-08-29	Kyla Morar PhD	kyla.morar.phd@geemail.com	Elk Grove	California	4097516644069063	f032515b2a2690a2fb92675d1dafbec2	American Express	38.3259971706479803	-121.385481220148506
48476	2020-08-29 01:58:33	2020-08-29	Thalia Treutel	thalia.treutel@woohoo.com	Las Vegas	Nevada	4702880576031518	816f87b2af61e2ae11d86ed7be2e9f90	Maestro	36.1715257172573317	-115.239372744664919
48477	2020-08-29 02:00:11	2020-08-29	Johnathan Rowe IV	johnathan.rowe.iv@geemail.com	Broken Arrow	Oklahoma	3096918298755323764	31c6b094f65695fc9915ff124367f320	JCB 16 digit	36.1259385601393817	-95.7477068336159078
48478	2020-08-29 02:02:56	2020-08-29	Dr. Stephenie Roberts DVM	dr.stephenie.roberts.dvm@geemail.com	Winston–Salem	North Carolina	502010782555576	848140d20d2d09d3bc8fa43851bdd8e4	Mastercard	36.0631272280354054	-80.3439366832971587
48479	2020-08-29 02:07:08	2020-08-29	Lisbeth Stroman	lisbeth.stroman@woohoo.com	New York	New York	3337536505499211044	346c5e785d5e455528583f9c3085c56d	JCB 16 digit	40.7535544020347302	-73.9652675501897932
48480	2020-08-29 02:07:20	2020-08-29	Dr. Janell Johns MD	dr.janell.johns.md@geemail.com	Coral Springs	Florida	3034603090139343	f271f6a2ec1614e2a3982880c6ca9c7b	VISA 13 digit	26.3069306443508744	-80.2173606363247984
48481	2020-08-29 02:15:50	2020-08-29	Frona Lubowitz DVM	frona.lubowitz.dvm@warmmail.com	Eugene	Oregon	4248069912009	2fb12778a046cc2ea0d434ec084c4ece	Maestro	44.105190712745113	-123.072081181173033
48482	2020-08-29 02:18:13	2020-08-29	Jesse Osinski	jesse.osinski@geemail.com	Phoenix	Arizona	55765876144668256	09be8a7a7eb8b2bf9d1e09042fb41ef2	VISA 16 digit	33.5993534688770765	-112.092257796313987
48483	2020-08-29 02:18:40	2020-08-29	Courtland Roberts	courtland.roberts@geemail.com	Oakland	California	52067035351124157	a45b87a1d02c4ae527148b32d9a0dcae	JCB 15 digit	37.8261072196742631	-122.275676163322842
48484	2020-08-29 02:23:35	2020-08-29	Marisela Yundt	marisela.yundt@geemail.com	Philadelphia	Pennsylvania	3528498519099058610	6e5aa097b3b681b3dbbc31318b597219	American Express	40.0075932702939951	-75.1232960931390608
48485	2020-08-29 02:30:27	2020-08-29	Maribeth Senger	maribeth.senger@woohoo.com	Los Angeles	California	51595588080118750	f284fcefcff4bcc1c7203cd56484c95b	Maestro	34.0414158948562999	-118.378946511353547
48486	2020-08-29 02:37:38	2020-08-29	Edmon Abernathy	edmon.abernathy@woohoo.com	Denver	Colorado	210020732910742372	f066a1e38aac0ba36a8b617abe91216c	American Express	39.7296422740496666	-104.797638862185551
48487	2020-08-29 02:46:19	2020-08-29	Arly Tremblay	arly.tremblay@woohoo.com	Atlanta	Georgia	4975007524004856	b4098b2acb18c6e042f114939a6a551d	JCB 16 digit	33.6690718655750203	-84.4512707705188603
48488	2020-08-29 02:50:45	2020-08-29	Velvet Walsh	velvet.walsh@geemail.com	Houston	Texas	3158212779318385005	604aa37275547a0ee7d566a6f1b04319	VISA 16 digit	29.7533788264341652	-95.2977413707427701
48489	2020-08-29 02:53:42	2020-08-29	Theodora Bode MD	theodora.bode.md@geemail.com	Pueblo	Colorado	3096288624765247895	498fcb9730e0c590c66781faf976564d	JCB 16 digit	38.3102123918455106	-104.55050137702861
48490	2020-08-29 03:02:39	2020-08-29	Len Emard-Schaden	len.emard.schaden@woohoo.com	Clovis	California	502030358722889	b0451f61a519ffe3927ce3bae7b95b51	JCB 16 digit	36.9158199161168241	-119.653218053148692
48491	2020-08-29 03:06:02	2020-08-29	Erich Sipes	erich.sipes@geemail.com	Jersey City	New Jersey	3112329151062571307	5504171343a2f419634f55992d406357	VISA 16 digit	40.7383885641522667	-74.1274533274073235
48492	2020-08-29 03:06:27	2020-08-29	Luther Yost	luther.yost@warmmail.com	New York	New York	4387775707115424	c43127c1aff754e8aa2af34dfd91caeb	VISA 13 digit	40.6036144478004388	-73.9925888262584834
48493	2020-08-29 03:10:32	2020-08-29	Docia Marks-Langworth	docia.marks.langworth@warmmail.com	Richmond	Virginia	869980509940118352	b80b817fc7cd6641b137cdc2e0a37724	JCB 15 digit	37.4632038460332879	-77.410117210749533
48494	2020-08-29 03:13:18	2020-08-29	Ell Dare	ell.dare@woohoo.com	Fort Worth	Texas	3731369743541494	ca95927aa2774f0c20867c805f85f371	Discover	32.8366682895980802	-97.3752029087215618
48495	2020-08-29 03:14:15	2020-08-29	Edythe Walker	edythe.walker@warmmail.com	Philadelphia	Pennsylvania	060468949061714	bee75a281c5c7dcc705b2f0c2777c9b3	Diners Club / Carte Blanche	39.9358283007942134	-75.091490737292176
48496	2020-08-29 03:16:34	2020-08-29	Noelle Schroeder	noelle.schroeder@geemail.com	Bakersfield	California	4761388460306747	4c91b4b3f3067625a7250cda008cc647	JCB 16 digit	35.3104894556745847	-119.111530721680438
48497	2020-08-29 03:28:40	2020-08-29	Ruth Douglas-Swaniawski	ruth.douglas.swaniawski@geemail.com	Virginia Beach	Virginia	060494132004527	15250943ce4faace6c92d061d47970d5	VISA 13 digit	36.7751684355735762	-76.1152396353565166
48498	2020-08-29 03:31:56	2020-08-29	Jere Wiegand PhD	jere.wiegand.phd@geemail.com	Boston	Massachusetts	4844816917679	bf615913f913160ca16a9c55e7ab956f	VISA 16 digit	42.2365508791226887	-71.068122115260735
48499	2020-08-29 03:41:05	2020-08-29	Dr. Ariana Jones	dr.ariana.jones@geemail.com	Dallas	Texas	4579856825343649	a6cb44060be1d1937ca2d67ff71a6609	JCB 15 digit	32.8879944923605763	-96.7749479260258312
48500	2020-08-29 03:45:14	2020-08-29	Dani Sporer-Morar	dani.sporer.morar@geemail.com	Dallas	Texas	4278890603753483	31039532d7ab8fe2f7c4e34dc20c5a1d	VISA 16 digit	32.815855583436047	-96.7838147574532712
48501	2020-08-29 04:04:14	2020-08-29	Mrs. Orra Green	mrs.orra.green@geemail.com	Minneapolis	Minnesota	3337139455389553421	c1f2c692a9ec959301fabe4f5daf886d	JCB 15 digit	44.9806665305599509	-93.2438273064598349
48502	2020-08-29 04:06:50	2020-08-29	Joanna Spinka	joanna.spinka@geemail.com	New York	New York	869947152688941859	7cbc2cbe06679915865d059312951575	Voyager	40.7080641324389703	-73.9968577358301758
48503	2020-08-29 04:10:03	2020-08-29	Missy Stracke	missy.stracke@woohoo.com	New Orleans	Louisiana	869948441517195632	88192a3a8bead24168d56a90cc4c542f	VISA 16 digit	29.9875841633897267	-89.970905112547797
48504	2020-08-29 04:18:25	2020-08-29	Montana Krajcik	montana.krajcik@geemail.com	West Palm Beach	Florida	676380673310670	19c127fe9ab7086247e14d3ef006c32c	JCB 15 digit	26.7666110210899291	-80.1258805868051951
48505	2020-08-29 04:22:55	2020-08-29	Ali Fadel	ali.fadel@geemail.com	Miami	Florida	52161619960094862	92203bba2b7b48b3e3cb24485ad2cdcf	JCB 15 digit	25.8099841155249656	-80.1352474323347224
48506	2020-08-29 04:25:01	2020-08-29	Dr. Mikal Bernhard Sr.	dr.mikal.bernhard.sr.@woohoo.com	Grand Prairie	Texas	502097672838725	bf31556ce592e9519f5f20e0fa72ef77	JCB 15 digit	32.7395733121369048	-97.0847563312727999
48507	2020-08-29 04:26:35	2020-08-29	Cosmo Wiegand	cosmo.wiegand@geemail.com	Wichita	Kansas	3088350202641352073	cf8f35b41e4a7e0fbb5e895bcc9f5a38	Mastercard	37.5982456789229076	-97.2768821368195091
48508	2020-08-29 04:29:00	2020-08-29	Zain Funk	zain.funk@geemail.com	Philadelphia	Pennsylvania	3423249380040895	5d0374e3e96b4294f5e1aa50a634cbb4	JCB 16 digit	40.0075040425132968	-75.189117339429643
48509	2020-08-29 04:33:31	2020-08-29	Jannie Senger-Kemmer	jannie.senger.kemmer@geemail.com	San Antonio	Texas	3158432732066602794	994148bc27ac3894e86193aecebd3f13	VISA 16 digit	29.5632002933021631	-98.5104120962157737
48510	2020-08-29 04:40:50	2020-08-29	Dr. Malaki Weber	dr.malaki.weber@geemail.com	Dallas	Texas	4695155723197	24a56c9c2a8e7b835e380fcbb3c2f0aa	JCB 16 digit	32.7509481659896693	-96.7772992134988215
48511	2020-08-29 04:46:35	2020-08-29	Flor West	flor.west@geemail.com	New York	New York	3721956482668405	c76137d805283ad2648f2cad7464a5fd	VISA 16 digit	40.7580620950777046	-73.8963356017962099
48512	2020-08-29 04:50:21	2020-08-29	Biddie Volkman	biddie.volkman@geemail.com	Glendale	Arizona	4696264711703554	78bab4f1406cdcae38969a40e7672441	Maestro	33.4456685585197064	-112.237109151228879
48513	2020-08-29 04:51:05	2020-08-29	Dr. Berenice Champlin	dr.berenice.champlin@geemail.com	Manchester	New Hampshire	180084339888127587	82c6e744170f6d0edeb23d75217e11ff	JCB 16 digit	43.0645468142420071	-71.5012783210616618
48514	2020-08-29 04:58:17	2020-08-29	Mrs. Sibyl Pacocha PhD	mrs.sibyl.pacocha.phd@geemail.com	San Francisco	California	676101817037466	093153d6d12f5f6efc2e2f2460b60977	American Express	37.7681860659454927	-122.415405221774108
48515	2020-08-29 05:02:58	2020-08-29	Delphin Raynor-Kreiger	delphin.raynor.kreiger@geemail.com	Berkeley	California	53301776423050062	4bbf354fb9f8d3dabaaf902abfffe9dd	Mastercard	37.8506789137153561	-122.256591612366549
48516	2020-08-29 05:17:41	2020-08-29	Mr. Dann Wiegand V	mr.dann.wiegand.v@geemail.com	San Diego	California	6011537284934734460	645f9ad9f350e8515f2cfe9da4a5fc53	Discover	32.7187292535856358	-117.142684239698582
48517	2020-08-29 05:20:47	2020-08-29	Maritza Hayes	maritza.hayes@warmmail.com	Fullerton	California	180067915576302649	00a25291ff49c1a14a295132d6ab16a9	JCB 16 digit	33.8431713734909891	-117.914849988065654
48518	2020-08-29 05:26:57	2020-08-29	Belva Denesik	belva.denesik@geemail.com	Providence	Rhode Island	6011463881542565455	e7e9cafbd0d77b041b8d8fec8a02f271	JCB 15 digit	41.765923966313153	-71.3746935335837378
48519	2020-08-29 05:28:10	2020-08-29	Bertie McClure	bertie.mcclure@warmmail.com	Torrance	California	4475411392071366	02972944d5d61542f19ade843a84e249	Maestro	33.9180915031954626	-118.302813219477969
48520	2020-08-29 05:33:27	2020-08-29	Rosario Sipes	rosario.sipes@warmmail.com	Chicago	Illinois	4951044007410480	17cccffa53be8920e5ac2e266db6cca3	JCB 16 digit	41.8300395006615702	-87.6899024535465941
48521	2020-08-29 05:33:37	2020-08-29	Miss Deborrah Mayert	miss.deborrah.mayert@geemail.com	Hartford	Connecticut	6011682240617154544	26871ac092b84ae325b53c36491bb27c	Diners Club / Carte Blanche	41.6766886674348314	-72.7512428961586295
48522	2020-08-29 05:36:27	2020-08-29	Adron Kerluke	adron.kerluke@warmmail.com	Tucson	Arizona	53063687793827237	001e00a016b5e554a964515067d52a77	JCB 16 digit	32.2047515105497126	-110.81016968025304
48523	2020-08-29 05:41:27	2020-08-29	Alan Nolan	alan.nolan@geemail.com	San Bernardino	California	869956257932517013	731e5c8213aea7a9d9dac1e62d1048f6	Mastercard	34.0468114942111058	-117.338265665179492
48524	2020-08-29 05:43:37	2020-08-29	Hertha Stehr	hertha.stehr@geemail.com	Lancaster	California	3337650964875884561	a9f471241682592066dfbb74a078e2b5	Maestro	34.747133810237429	-118.234457957555719
48525	2020-08-29 05:44:34	2020-08-29	Cristian Emard DVM	cristian.emard.dvm@woohoo.com	Dallas	Texas	3112721128677732973	b12ae0f6f13d22c18377eec46db5663a	Mastercard	32.7613071513168563	-96.8478801516313013
48526	2020-08-29 05:45:56	2020-08-29	Bethel Sawayn	bethel.sawayn@geemail.com	San Jose	California	3734809554241004	7269ebbe4c18e1285e1c612f72edcb1b	JCB 16 digit	37.3360753344658747	-121.865350634021311
48527	2020-08-29 05:51:12	2020-08-29	Nealy Wolf	nealy.wolf@geemail.com	Grand Rapids	Michigan	4948564024883	ce4286f6fe05de62799d7755751f8c54	JCB 16 digit	43.0159806660644719	-85.5935239515401491
48528	2020-08-29 05:51:40	2020-08-29	Dr. Shana Nicolas	dr.shana.nicolas@geemail.com	Virginia Beach	Virginia	3034382338190463	7376bd26b3ac86732ade35669ce2d5f1	Maestro	36.7834724336583179	-76.0769771035432854
48529	2020-08-29 05:52:35	2020-08-29	River Huel	river.huel@woohoo.com	Raleigh	North Carolina	4000096648799961	e17f3494ba1f2d09ad4ffe4ce2199232	Voyager	35.9040695063903925	-78.7217228469375527
48530	2020-08-29 05:56:31	2020-08-29	Filomena Padberg	filomena.padberg@geemail.com	Phoenix	Arizona	3025782250871538	dba3b00bdf17970de4be1f373120b1ea	JCB 16 digit	33.60515519622043	-112.169026149290062
48531	2020-08-29 05:59:41	2020-08-29	Maranda Wisoky	maranda.wisoky@geemail.com	Chicago	Illinois	6011105933044315113	c34965a4c2dd4f48322fb2d2bc6ad2a6	Maestro	41.864405069344123	-87.6550939785346372
48532	2020-08-29 06:00:21	2020-08-29	Winfred Conn	winfred.conn@geemail.com	Atlanta	Georgia	55721094519215801	dc80ae0f56d7aa3b9ae4259e2cd8dc97	VISA 16 digit	33.7101277285996872	-84.4082554333888027
48533	2020-08-29 06:08:13	2020-08-29	Simona Hansen	simona.hansen@geemail.com	Westminster	Colorado	6011242901443886244	309f739eb426ea99fd2e909c082f6026	Voyager	39.8289064497526724	-104.978282852811375
48534	2020-08-29 06:09:45	2020-08-29	Davis Strosin	davis.strosin@geemail.com	Frisco	Texas	869991458944465947	24af764da292e3263e13fb9c5a0bfd73	JCB 16 digit	33.190633889753002	-96.774560770972073
48535	2020-08-29 06:11:35	2020-08-29	Dr. Azalee Jacobs DDS	dr.azalee.jacobs.dds@geemail.com	Pittsburgh	Pennsylvania	4224553998309	2770cebf697741d2ab6487c1ba8d2bb8	JCB 15 digit	40.3743617119222833	-80.0028617027852675
48536	2020-08-29 06:14:26	2020-08-29	Bessie Armstrong	bessie.armstrong@geemail.com	St. Petersburg	Florida	6011521001219270541	4a674aab83b37a7a3643d297854b40e1	JCB 16 digit	27.860372603813186	-82.6335020568113663
48537	2020-08-29 06:19:34	2020-08-29	Marcell Stark PhD	marcell.stark.phd@geemail.com	San Diego	California	180090476285835735	eba0e73e8717cc8bd0079dccc79fea8d	JCB 15 digit	32.901876112732289	-117.167117644371473
48538	2020-08-29 06:23:37	2020-08-29	Terri Swift	terri.swift@warmmail.com	Hampton	Virginia	869929859878970975	17d26a88e5122ee831e20fe3fe207e2d	VISA 16 digit	36.9852708098031613	-76.3371524817407163
48539	2020-08-29 06:37:37	2020-08-29	Tressa Oberbrunner MD	tressa.oberbrunner.md@warmmail.com	Colorado Springs	Colorado	502088546371142	7da763e33ea4df133b4b3b0246e11dc6	JCB 16 digit	38.8673881984829919	-104.778294877071673
48540	2020-08-29 07:01:00	2020-08-29	Yael Beier	yael.beier@woohoo.com	Providence	Rhode Island	210004085758282393	4f22e3a20237cf275d577b7abc830c54	VISA 13 digit	41.7546681776963169	-71.3344625390518559
48541	2020-08-29 07:13:42	2020-08-29	Mr. Randall Schulist I	mr.randall.schulist.i@geemail.com	Louisville	Kentucky	3000922224626346	f831c84877916f4533525b7ba9720c31	Mastercard	38.1717928643707154	-85.5845004172600881
48542	2020-08-29 07:14:20	2020-08-29	Verdell Gulgowski	verdell.gulgowski@geemail.com	Fresno	California	3337834475911840417	81d61b6f40aeb40efb6b4565b9a28d41	Maestro	36.7650554444048581	-119.757678586301964
48543	2020-08-29 07:20:14	2020-08-29	Deondre Windler	deondre.windler@geemail.com	Kansas City	Kansas	3023671072944593	72577c7cabc15ccd69e9d1e29bf363e6	Discover	39.209153078487148	-94.7500954022102064
48544	2020-08-29 07:50:57	2020-08-29	Hosteen McLaughlin-Schinner	hosteen.mclaughlin.schinner@geemail.com	Austin	Texas	6011475761998257599	c75c887c561b04e14dd3b244d9a2660e	Diners Club / Carte Blanche	30.3718511820897454	-97.8428448912460453
48545	2020-08-29 07:56:05	2020-08-29	Hailie Becker	hailie.becker@geemail.com	Kansas City	Kansas	51411112249038940	f0f720b63e9edbe90ab2f3ba7b943855	Diners Club / Carte Blanche	39.1236401019990438	-94.7805604093644689
48546	2020-08-29 07:59:29	2020-08-29	Lavon Hayes	lavon.hayes@geemail.com	Anaheim	California	869939367365301157	d7aa62d06847fb84f6f1896a2a1d4821	Maestro	33.9512825932186075	-117.740452402897546
48547	2020-08-29 07:59:48	2020-08-29	Irene Hegmann-Hoppe	irene.hegmann.hoppe@geemail.com	Orlando	Florida	210013546781142010	750c5561b4e4f3ea75cc592c9c3b0e2c	American Express	28.4615092716909928	-81.361964325882866
48548	2020-08-29 08:00:26	2020-08-29	Renita Hegmann	renita.hegmann@geemail.com	New York	New York	6011437480376530199	e9c1cfd0fb163cc911e055aa22fe2988	VISA 16 digit	40.6252807117756447	-73.9147156176518649
48549	2020-08-29 08:07:36	2020-08-29	Bernetta Adams	bernetta.adams@warmmail.com	Phoenix	Arizona	4653307806425970	fc99922925365147813df2bbeef2d872	American Express	33.4880053073566444	-112.09214862453976
48550	2020-08-29 08:08:02	2020-08-29	Donia Langosh	donia.langosh@woohoo.com	Oakland	California	3096465975834630783	44a1e1bcf9c2f18ae31320e3d1a2df39	VISA 13 digit	37.7733297016504679	-122.321590187717732
48551	2020-08-29 08:11:34	2020-08-29	Atha Ward-Reichel	atha.ward.reichel@warmmail.com	Chicago	Illinois	3053131820703361	83886289c360fd574696a5d673712022	Mastercard	41.7975744643550371	-87.7667769243970497
48552	2020-08-29 08:26:39	2020-08-29	Cliff Prohaska I	cliff.prohaska.i@geemail.com	Portland	Oregon	55155286993767712	a1da019ba96086bb089d71155e3c5775	Maestro	45.6054957833960657	-122.736791975330561
48553	2020-08-29 08:28:29	2020-08-29	Mr. Della Gaylord	mr.della.gaylord@geemail.com	Los Angeles	California	4706138354461639	8adfcc2e130e8ebc8abf06c0ecc6c8ad	American Express	34.0060425296291697	-118.491177283832059
48554	2020-08-29 08:31:49	2020-08-29	Dr. Terrell Schinner III	dr.terrell.schinner.iii@geemail.com	Oakland	California	4466113242836037	9d9bf27ca0c48caac95b85e83c098728	Diners Club / Carte Blanche	37.8021871757806807	-122.295073502334688
48555	2020-08-29 08:35:45	2020-08-29	Alonza Tromp-Deckow	alonza.tromp.deckow@geemail.com	Los Angeles	California	6011505472452022560	10880ef553d78df3aa806fb448b43307	VISA 16 digit	34.0611279069311905	-118.442278073028845
48556	2020-08-29 08:38:36	2020-08-29	Kassandra Wyman DVM	kassandra.wyman.dvm@woohoo.com	San Francisco	California	52472267866638194	e8cad011b44c4d8cca0aff7e231329d3	VISA 16 digit	37.8020312006179537	-122.410352615227367
48557	2020-08-29 08:40:59	2020-08-29	Octavius Gutmann-Streich	octavius.gutmann.streich@geemail.com	Boise	Idaho	4190887895459238	bf1e089d23c59a601e4aae731441c9ae	Discover	43.5403507004629802	-116.323223794876412
48558	2020-08-29 08:43:02	2020-08-29	Miss Ilah Dicki MD	miss.ilah.dicki.md@geemail.com	Arvada	Colorado	3013697657705000	de3ecdecba8b6488165ca1e132746632	VISA 16 digit	39.7983899926941831	-105.234841613329209
48559	2020-08-29 08:53:17	2020-08-29	Peyton Botsford	peyton.botsford@geemail.com	Raleigh	North Carolina	53926191771302047	361b8472d096ba870a425b3a00ec5297	Maestro	35.7907802525110483	-78.6105732131686068
48560	2020-08-29 08:59:34	2020-08-29	Daniele Miller MD	daniele.miller.md@geemail.com	Fort Worth	Texas	53817302529544283	20d247f0212258b2d89c4df905c4f05b	JCB 16 digit	32.7461591971628394	-97.3972191076081231
48561	2020-08-29 09:01:40	2020-08-29	Dorene Corkery	dorene.corkery@warmmail.com	Richmond	Virginia	676343922407978	99f857ca09eaa49f6972ab72cc4ada44	Diners Club / Carte Blanche	37.5217463128954165	-77.4102960474546933
48562	2020-08-29 09:06:51	2020-08-29	Senora Bergstrom	senora.bergstrom@geemail.com	Montgomery	Alabama	4589674798361029	8849a3bc92c241367ae47be133131137	Mastercard	32.2906875309932957	-86.2274168306182958
48563	2020-08-29 09:15:30	2020-08-29	Mr. Lennon Abbott	mr.lennon.abbott@geemail.com	Carrollton	Texas	4456878940622515	5719d87e39982a2b78b854e5d4ea8dd1	JCB 16 digit	33.0603441018067272	-96.9940087177652828
48564	2020-08-29 09:18:38	2020-08-29	Ms. Sloane Emard PhD	ms.sloane.emard.phd@woohoo.com	San Antonio	Texas	6011433494903277491	e24763112dee8ea20ee85c63a7203261	VISA 13 digit	29.3940359283775088	-98.5615036871120225
48565	2020-08-29 09:22:27	2020-08-29	Dr. Stetson Botsford DVM	dr.stetson.botsford.dvm@woohoo.com	Louisville	Kentucky	3337496186978583738	f2ce7e9c9e7a80f7d9823bdc064e7a07	Discover	38.1468517708960917	-85.7109496313683792
48566	2020-08-29 09:26:21	2020-08-29	Dudley Beahan-Tillman	dudley.beahan.tillman@geemail.com	Los Angeles	California	3158640959800082334	eb3308db3d3e8d8b0ec8293460346a69	JCB 16 digit	34.0922860203642344	-118.327964497822521
48567	2020-08-29 09:29:08	2020-08-29	Sondra Frami-Witting	sondra.frami.witting@geemail.com	Berkeley	California	3528744650092415473	e088730715451c7226ca3fa632b222ad	JCB 16 digit	37.8847300633519453	-122.262289621863872
48568	2020-08-29 09:34:35	2020-08-29	Kassie Nicolas	kassie.nicolas@geemail.com	Glendale	Arizona	3773661838402320	821ff9c114f17dfa52d53b02d0f3d7bb	JCB 16 digit	33.5204855177313092	-112.259677662819243
48569	2020-08-29 09:36:38	2020-08-29	Renae O'Reilly	renae.o'reilly@geemail.com	El Paso	Texas	3054065651613159	03daae1daf252c500e9d6eb7026ceed9	American Express	31.8372572664465778	-106.327979394000025
48570	2020-08-29 09:39:27	2020-08-29	Rolf Anderson	rolf.anderson@geemail.com	Saint Paul	Minnesota	3158133831848962690	d5b6a9ea02471827d523e2fe2bb0dbda	JCB 16 digit	45.0386717930842195	-93.0101820025857506
48571	2020-08-29 09:43:51	2020-08-29	Sol Kunze	sol.kunze@geemail.com	Topeka	Kansas	210006354527060854	ec24082ec596cd5b9dfbf7015066b660	Maestro	39.0167817315951027	-95.6440333453647895
48572	2020-08-29 09:46:04	2020-08-29	Miss Gussie Lubowitz	miss.gussie.lubowitz@woohoo.com	Fresno	California	4207574727446770	63704f5ca8cafa3eb85d71acb665edc1	JCB 15 digit	36.8110180331267429	-119.885975315199801
48573	2020-08-29 09:50:18	2020-08-29	Lynn Emard	lynn.emard@geemail.com	Chicago	Illinois	210019778735339186	5d6e9edcb406b139f133963e0a99c82f	Discover	41.8735675552696023	-87.5842988103657945
48574	2020-08-29 09:53:06	2020-08-29	Candy Huel	candy.huel@geemail.com	Mobile	Alabama	561257840327266	c059189067a16987e86ec75b5f8f01dc	VISA 16 digit	30.766147292323037	-88.1410033255487662
48575	2020-08-29 09:57:22	2020-08-29	Marianna Dickinson	marianna.dickinson@geemail.com	Los Angeles	California	3011716929708931	cf78c04bf4af78cba0236c9841a73979	JCB 15 digit	34.0300668647378686	-118.406453245504935
48576	2020-08-29 09:59:15	2020-08-29	Dr. Harlan Goyette II	dr.harlan.goyette.ii@geemail.com	Dallas	Texas	210079236749910408	f99da94cb828a6094894f30e6080cf77	JCB 16 digit	32.719314458341529	-96.6691980722323052
48577	2020-08-29 10:00:05	2020-08-29	Kelis Lynch	kelis.lynch@geemail.com	Philadelphia	Pennsylvania	3112734440535652599	31f0ec462db362d2869eafe76896e2c1	JCB 16 digit	40.0075625794433023	-75.1250892006225968
48578	2020-08-29 10:05:46	2020-08-29	Izabella Bayer PhD	izabella.bayer.phd@geemail.com	Chicago	Illinois	3096820999465302892	ed19894b36e41698abe6f3c6bc583ebf	VISA 13 digit	41.7772081511396962	-87.7770515826094879
48579	2020-08-29 10:14:59	2020-08-29	Kiyoshi Hessel-Bruen	kiyoshi.hessel.bruen@woohoo.com	New York	New York	3088999142971219749	833a19ecbcbb6b8775ae2a66e167497e	JCB 16 digit	40.6430754242222747	-74.0184910802997678
48580	2020-08-29 10:16:20	2020-08-29	Dorian Nitzsche	dorian.nitzsche@woohoo.com	Los Angeles	California	55724301796679295	fe8f2c4bff8005fb17e631b375eb38d6	JCB 16 digit	33.9447466553986033	-118.498284821444372
48581	2020-08-29 10:31:20	2020-08-29	Dr. Susanna Yundt DDS	dr.susanna.yundt.dds@geemail.com	Green Bay	Wisconsin	210046390849462388	de37a50ac38f4497aca73dc23505efbd	Diners Club / Carte Blanche	44.4686887958150336	-87.8878589926108731
48582	2020-08-29 10:33:57	2020-08-29	Pierre Mueller	pierre.mueller@geemail.com	Houston	Texas	180079325727981315	6c7f141b26b7cb513abf909caa67c503	Maestro	29.8000732283186167	-95.3198075606502613
48583	2020-08-29 10:35:41	2020-08-29	Dr. Braxton Beatty Jr.	dr.braxton.beatty.jr.@geemail.com	Augusta	Georgia	6011869170103695533	811defa22d2f28e8a0aceaff1f49bb2e	VISA 16 digit	33.2840134108643966	-82.1084263496860984
48584	2020-08-29 10:42:32	2020-08-29	Hilah Predovic-Yost	hilah.predovic.yost@geemail.com	Davenport	Iowa	51569313231179060	3bcc4a0c1efd23fa17b7ba35c34c4ee8	JCB 16 digit	41.614908089328928	-90.6009836725853432
48585	2020-08-29 10:47:53	2020-08-29	Octave Ullrich	octave.ullrich@geemail.com	Cedar Rapids	Iowa	3418884706833016	88703117422dc8701e6c6353e9f2deaf	JCB 16 digit	42.0047777268178777	-91.7099024220902521
48586	2020-08-29 10:53:31	2020-08-29	Brianne Mayer	brianne.mayer@geemail.com	Fort Wayne	Indiana	060464141842860	b78f38a8f1725fae2c72f2d16a483fa3	Discover	41.1761238973837322	-85.1512400194756651
48587	2020-08-29 10:59:50	2020-08-29	Memphis Hermiston	memphis.hermiston@geemail.com	San Francisco	California	180052583516958461	7219660c729571c2eee33dfe08dfad18	Voyager	37.7593314908275559	-122.44710429163429
48588	2020-08-29 11:01:40	2020-08-29	Sarina Ritchie PhD	sarina.ritchie.phd@geemail.com	Raleigh	North Carolina	51464164394027406	12f828c01b97383ac7a0197fa19e00fa	Diners Club / Carte Blanche	35.8077913842763706	-78.5688633955020492
48589	2020-08-29 11:01:53	2020-08-29	Admiral Jerde	admiral.jerde@woohoo.com	Phoenix	Arizona	4034328587485801	ceb3324749dac7d1662c11a4f27b5cb3	VISA 13 digit	33.5708400605645068	-112.102230371853722
48590	2020-08-29 11:02:51	2020-08-29	Elzada Zboncak	elzada.zboncak@geemail.com	New York	New York	869941399515672647	dd7053392291a5b3593ef0375fd668b7	VISA 13 digit	40.6282133721504337	-74.0313404020749033
48591	2020-08-29 11:20:12	2020-08-29	Weaver Fritsch	weaver.fritsch@woohoo.com	Madison	Wisconsin	3402760441871198	cf919fcab99394087b0d70d82e48dec8	VISA 13 digit	43.1767389910269515	-89.5144776558388031
48592	2020-08-29 11:32:52	2020-08-29	Missouri Beer	missouri.beer@geemail.com	New York	New York	3480541511834935	e1cf47e16261a3af978b5ddd79f8b2ee	VISA 16 digit	40.6443333049062616	-73.939592046233642
48593	2020-08-29 11:33:18	2020-08-29	Symone Hodkiewicz	symone.hodkiewicz@geemail.com	New York	New York	210039265183511082	3bcd637295674fe2e1ecf891a7f125bc	Maestro	40.6848933074381165	-74.0272000059846818
48594	2020-08-29 11:33:29	2020-08-29	Ceylon Moore	ceylon.moore@woohoo.com	Fort Worth	Texas	4554034249884	5e1b251bcc4666c7f7a76ceaeeaf615c	VISA 16 digit	32.7761909841150043	-97.3853824829969597
48595	2020-08-29 11:46:07	2020-08-29	Mafalda Pagac	mafalda.pagac@warmmail.com	New York	New York	4404947369663194	8bdc33b2ae8fbec77727634f08e0433d	Discover	40.7411310611981889	-73.8994847988139867
48596	2020-08-29 11:48:15	2020-08-29	Garrett Klocko V	garrett.klocko.v@woohoo.com	Austin	Texas	3426941033712527	424c6c5afbb50f42f135118316942e0f	JCB 16 digit	30.3743878111835564	-97.8242923436924912
48597	2020-08-29 11:52:00	2020-08-29	Donn Armstrong	donn.armstrong@geemail.com	Hartford	Connecticut	3449623797620236	dc6d2e7258e24274a225732c0d9e4e77	VISA 16 digit	41.8291079902105025	-72.7811880693197253
48598	2020-08-29 11:54:02	2020-08-29	Elnora Trantow	elnora.trantow@geemail.com	Boise	Idaho	6011978247599360414	8979524d853258494bfbf959ec1c4b49	VISA 16 digit	43.5098564389765272	-116.228750273697827
48599	2020-08-29 11:56:39	2020-08-29	Mr. Samuel Gleason	mr.samuel.gleason@geemail.com	Mesa	Arizona	639087773500845	429cdc9c70cfb357fdb3b597bbdbce60	Mastercard	33.3193525646027169	-111.741022477846215
48600	2020-08-29 12:00:06	2020-08-29	Marylou Wintheiser-Bechtelar	marylou.wintheiser.bechtelar@warmmail.com	San Francisco	California	3758076896824415	b1248fa9e579aa52ac0b43e1335b4d10	Voyager	37.7390406435492594	-122.424438770950843
48601	2020-08-29 12:01:00	2020-08-29	Jair Zboncak	jair.zboncak@geemail.com	San Angelo	Texas	3491085257811332	4aa10bee984cee5a701e3188a0e74fc1	JCB 16 digit	31.3603921534646304	-100.400346765538686
48602	2020-08-29 12:02:26	2020-08-29	Dr. Lorenzo Tremblay	dr.lorenzo.tremblay@woohoo.com	Oakland	California	4686441740132359	731be6d5a6c7b3592bd5a27127d34950	VISA 16 digit	37.8097554467343997	-122.282399658770743
48603	2020-08-29 12:10:42	2020-08-29	Myron Gottlieb	myron.gottlieb@geemail.com	San Francisco	California	3417615629385176	bea733617f3b2d22a3e19edacbf80d8e	JCB 15 digit	37.7957223149903143	-122.439349941404956
48604	2020-08-29 12:15:45	2020-08-29	Dr. Leora Schmeler DDS	dr.leora.schmeler.dds@warmmail.com	Midland	Texas	4752536749874460	9ec6f3e83b31f1550464aa4b234a41f4	Maestro	32.1022387400459479	-102.162522500589489
48605	2020-08-29 12:16:42	2020-08-29	Eusebio Harber-McLaughlin	eusebio.harber.mclaughlin@geemail.com	Los Angeles	California	210003849580556857	33476e0ab6e0f2e90da1b2967aaa892a	Voyager	34.0362843233492214	-118.409801793144268
48606	2020-08-29 12:29:04	2020-08-29	Ardella Batz	ardella.batz@geemail.com	Phoenix	Arizona	4639388731343917	1e2e733fa05fb67a8ba45a15cbc65ac4	Mastercard	33.5580606984373233	-112.149697211238006
48607	2020-08-29 12:35:44	2020-08-29	Miss Geraldine Nolan MD	miss.geraldine.nolan.md@warmmail.com	Portland	Oregon	210017652516627691	28fc9de5da24a1a3d903d56d778f7abe	Voyager	45.6002197531871474	-122.74820873020218
48608	2020-08-29 12:37:52	2020-08-29	Miss Carmella McDermott PhD	miss.carmella.mcdermott.phd@warmmail.com	San Francisco	California	55727509262387386	918cc99b08d1adb337db029392246c7d	VISA 16 digit	37.7403075723015462	-122.411781100487232
48609	2020-08-29 12:38:44	2020-08-29	Myrtle Feil	myrtle.feil@geemail.com	Berkeley	California	3432361987790167	e09be3c08ce358f10c89fe2463c4afbf	JCB 16 digit	37.8892243096200332	-122.261148911897379
48610	2020-08-29 12:47:11	2020-08-29	Aiyanna Wintheiser-Oberbrunner	aiyanna.wintheiser.oberbrunner@warmmail.com	Los Angeles	California	3488146343644650	a9ad07829956ad27da4c1d7bdc2d6e67	JCB 16 digit	33.9652173292689028	-118.468313313693926
48611	2020-08-29 12:52:30	2020-08-29	Elberta O'Hara-Hilpert	elberta.o'hara.hilpert@geemail.com	Long Beach	California	4667051325294921	e96507c2bb00d93f797e66be429cf93c	VISA 13 digit	33.7410181901238815	-118.16596377516835
48612	2020-08-29 12:53:02	2020-08-29	Diamond Bahringer	diamond.bahringer@geemail.com	Chicago	Illinois	869959742169494983	235d82e5ed3a96b9e4ad4dd1ee155552	VISA 16 digit	41.7931503121577208	-87.6215125631570828
48613	2020-08-29 12:54:17	2020-08-29	Ms. Rinda Cronin	ms.rinda.cronin@geemail.com	Athens	Georgia	3736424629758111	b98b69aef3c82d583688000ccc7305cd	JCB 16 digit	34.0413017670348239	-83.367773515137273
48614	2020-08-29 12:59:04	2020-08-29	Dr. Dink Keebler III	dr.dink.keebler.iii@geemail.com	San Francisco	California	3727104840886336	b7e7b392cc15eedd92e9ab4d71d284ce	VISA 13 digit	37.788290987625814	-122.429036622549461
48615	2020-08-29 13:13:20	2020-08-29	Alani Jacobs-Lesch	alani.jacobs.lesch@warmmail.com	Corpus Christi	Texas	6011302709100700427	fe1f37c35d6bb9efc65c164ecba52dff	Diners Club / Carte Blanche	27.8417651972670122	-97.1596406933214496
48616	2020-08-29 13:14:25	2020-08-29	Ms. Gayla Barrows MD	ms.gayla.barrows.md@geemail.com	Virginia Beach	Virginia	3018366937527213	f6da031f766720c74e1c3848788f7d95	Mastercard	36.8610346985235822	-75.9976814116023434
48617	2020-08-29 13:15:27	2020-08-29	Makena Crooks	makena.crooks@geemail.com	Pembroke Pines	Florida	3400060802968309	2dba579c660da7db93efc66428db5948	Mastercard	26.0105296199712903	-80.2447591901194386
48618	2020-08-29 13:15:57	2020-08-29	Noreen Kovacek	noreen.kovacek@geemail.com	Los Angeles	California	3158675268489750874	8c0a22a67a63c902207f53112c4532d0	JCB 15 digit	34.0261690492141966	-118.493365281493581
48619	2020-08-29 13:17:02	2020-08-29	Alois Jast	alois.jast@geemail.com	Irving	Texas	4479676225010	397815d960571024179ac195893fc5f6	Diners Club / Carte Blanche	32.7632757396388783	-97.0154063259065111
48620	2020-08-29 13:17:35	2020-08-29	Shirleyann Schneider	shirleyann.schneider@warmmail.com	Los Angeles	California	869906614423911868	39ea7da77806c85c9a13e6fe4220aa18	Discover	34.0434939046721894	-118.324631631559868
48621	2020-08-29 13:21:09	2020-08-29	Mr. Refugio Aufderhar	mr.refugio.aufderhar@warmmail.com	Mobile	Alabama	4786610875167666	159e5ad40c3a579536398b7eb9f1c2f6	Mastercard	30.7353055355712748	-88.1401668261874534
48622	2020-08-29 13:28:04	2020-08-29	Jennette Sipes-Beer	jennette.sipes.beer@geemail.com	Lexington	Kentucky	4309037670085	e937bda0fef51adaef0d5d6160762d6c	Maestro	38.0602965618826445	-84.3939405055616021
48623	2020-08-29 13:52:31	2020-08-29	Lincoln Brekke	lincoln.brekke@woohoo.com	Houston	Texas	3460737170899227	f58e83592a2317eaf11b0d6dc3b94665	Discover	29.8861417398400597	-95.486305499730264
48624	2020-08-29 13:57:53	2020-08-29	Macy Leffler	macy.leffler@geemail.com	Visalia	California	4083144600076935	7bce46524fd01a3f65cc91640187c8ee	Mastercard	36.2714418487578669	-119.243170262513317
48625	2020-08-29 13:59:17	2020-08-29	Michaele Tillman	michaele.tillman@geemail.com	Boston	Massachusetts	4585063398900721	01b5455de184d5389584992d365d4261	JCB 15 digit	42.2534337328914589	-70.9532486608203499
48626	2020-08-29 14:02:41	2020-08-29	Ms. Tishie Heaney	ms.tishie.heaney@geemail.com	Baltimore	Maryland	3026850791640263	7afd8cdd1a07f361f306c261a0c69f25	VISA 13 digit	39.3175986376591027	-76.5118629974331697
48627	2020-08-29 14:04:41	2020-08-29	Mr. Savon Jenkins Jr.	mr.savon.jenkins.jr.@geemail.com	Chicago	Illinois	869999608014393575	b47d419488a65f81e8af11becc0b12fb	JCB 15 digit	41.8990128220360774	-87.6156312593754336
48628	2020-08-29 14:23:05	2020-08-29	Elenor Waelchi	elenor.waelchi@geemail.com	Los Angeles	California	4225173984181	47047c05a395789f707d5eb8b24661f3	JCB 16 digit	33.9213976171664839	-118.417634478164089
48629	2020-08-29 14:32:17	2020-08-29	Mandi Stanton	mandi.stanton@warmmail.com	New York	New York	210043298425146551	6815dde4b24f39f41b76655a9a25d064	JCB 16 digit	40.5845225232876814	-73.9366694196488652
48630	2020-08-29 14:58:12	2020-08-29	Mr. Crawford Goyette	mr.crawford.goyette@geemail.com	Arlington	Texas	3528472568882230662	253581bc0f80ed2114e7d163a9bb3816	JCB 16 digit	32.7868590550281098	-97.1978368184555421
48631	2020-08-29 14:58:13	2020-08-29	Evans Shanahan	evans.shanahan@woohoo.com	Miami	Florida	3736592890604683	f6502721c940869bcbd0a7cc113be440	VISA 13 digit	25.841845565489308	-80.2429391356524064
48632	2020-08-29 14:58:22	2020-08-29	Dr. Hailee Moen PhD	dr.hailee.moen.phd@geemail.com	Sacramento	California	3001460763653313	417f9b8b9958861404f32ca63bcf5a50	JCB 15 digit	38.6036620744768513	-121.453041002458335
48633	2020-08-29 14:58:26	2020-08-29	Mr. Hymen Bosco	mr.hymen.bosco@geemail.com	Fresno	California	869915028019514300	62539546218b78eff9d69a02b73d35f3	VISA 16 digit	36.8283780564427374	-119.888453884899249
48634	2020-08-29 15:04:42	2020-08-29	Savilla Lindgren	savilla.lindgren@geemail.com	Louisville	Kentucky	4784825782971	41887ab750a33f1d0e1211e7448adf34	JCB 16 digit	38.0864432928055479	-85.5798483362957825
48635	2020-08-29 15:07:45	2020-08-29	Stafford Steuber	stafford.steuber@geemail.com	Oakland	California	3096036279364224269	73110f2176f10f03a2aaa52e6c910fa3	VISA 16 digit	37.8257161899208754	-122.2488189353856
48636	2020-08-29 15:08:09	2020-08-29	Karlie Rohan-Larson	karlie.rohan.larson@geemail.com	Chicago	Illinois	3733811053236841	abdd03bf6c2944f7a6dc0336c74a1003	VISA 16 digit	41.7508656615227451	-87.706927482973029
48637	2020-08-29 15:11:38	2020-08-29	Prosper Runolfsdottir	prosper.runolfsdottir@woohoo.com	San Francisco	California	4804658626978	54516f4d4da39a1c6a7f0c2a8cc4b870	Maestro	37.8033399380973663	-122.431234372122276
48638	2020-08-29 15:15:41	2020-08-29	Kathi King-Carroll	kathi.king.carroll@warmmail.com	Moreno Valley	California	3088301123090067105	c951396af3f9d66473f0f3e0ffdd2c3a	VISA 16 digit	33.9901335019610826	-117.277304967908933
48639	2020-08-29 15:31:23	2020-08-29	Kendrick Watsica	kendrick.watsica@woohoo.com	Colorado Springs	Colorado	3337478814130533232	be45292f22b667b1c2750f21c1367998	Discover	38.8422861159361901	-104.793700324340534
48640	2020-08-29 15:32:59	2020-08-29	Montana Waelchi-Kulas	montana.waelchi.kulas@geemail.com	Honolulu	Hawaii	54020050482148526	e29f7b07ab65e05990396b2a53bb6e1d	JCB 15 digit	21.3177381777420649	-157.79073464770093
48641	2020-08-29 15:35:24	2020-08-29	Ms. Ninnie Rolfson	ms.ninnie.rolfson@geemail.com	North Las Vegas	Nevada	3001197823512242	facf5d1d5a73b295c1b584abecb0943e	JCB 16 digit	36.2503815767046049	-115.141912541141366
48642	2020-08-29 15:37:07	2020-08-29	Hiroshi Johns	hiroshi.johns@geemail.com	St. Petersburg	Florida	3158995415039861650	6c435804b1e51c3eddf2d24d5c99be86	JCB 16 digit	27.7477134963385765	-82.7315797951895746
48643	2020-08-29 15:48:11	2020-08-29	Ms. Trudy Christiansen PhD	ms.trudy.christiansen.phd@geemail.com	Birmingham	Alabama	4204024741545002	bccfcb0e72b534d4a9b46810ef1d74f2	JCB 16 digit	33.6158190749377042	-86.8510194454118647
48644	2020-08-29 15:50:44	2020-08-29	Danna Rath	danna.rath@geemail.com	Memphis	Tennessee	6011922566795144752	371bb79f4dca9377c007871713950cf8	Maestro	35.1105853749971857	-89.9531196016609726
48645	2020-08-29 16:00:40	2020-08-29	Paris Nitzsche	paris.nitzsche@geemail.com	Denver	Colorado	6011382381162936183	7ba74c08f18b9c49d46d9b89d734830e	JCB 16 digit	39.6908368721190783	-104.942275010865558
48646	2020-08-29 16:05:16	2020-08-29	Kayli Hudson	kayli.hudson@geemail.com	Denver	Colorado	3010526414676043	d28b64b882cf34c20a9d2d788f94e689	American Express	39.7923979999084025	-104.932365836786488
48647	2020-08-29 16:15:49	2020-08-29	Kyle Rutherford-Fisher	kyle.rutherford.fisher@geemail.com	Kansas City	Kansas	3112498296326588863	769e4d9190b18b899213f81631cd7b1c	Discover	39.1859414113592379	-94.6953617855377416
48648	2020-08-29 16:16:43	2020-08-29	Dr. Hurley Daugherty IV	dr.hurley.daugherty.iv@geemail.com	Aurora	Illinois	3528177754476228829	c78874d6757bc7ede8a8dd5d9962e05b	American Express	41.7804270690530544	-88.2825372993875277
48649	2020-08-29 16:28:47	2020-08-29	Dr. Alfie Graham	dr.alfie.graham@geemail.com	New York	New York	3047837265982379	38196ca38a3700a6b61710eda51384fe	VISA 16 digit	40.6122097008153773	-73.9930518073856831
48650	2020-08-29 16:42:05	2020-08-29	Maribel Hammes	maribel.hammes@geemail.com	Tulsa	Oklahoma	3029252196985111	edd1aba9d10190dc3d5cf30a4a0eb3d6	VISA 16 digit	36.0283736787639555	-95.8764118009202093
48651	2020-08-29 16:53:29	2020-08-29	Dejon Bergnaum	dejon.bergnaum@geemail.com	Austin	Texas	3158546592866645051	cf0efe7d164b3c558715c5b008e36325	Discover	30.2613086070992026	-97.6902919482212582
48652	2020-08-29 16:54:19	2020-08-29	Syed Nicolas IV	syed.nicolas.iv@woohoo.com	San Francisco	California	3001932839006932	05d0805797b2fca89eead87b85fb0b20	VISA 13 digit	37.7705648227946753	-122.447720013511983
48653	2020-08-29 16:54:32	2020-08-29	Dr. Hildegarde Kub	dr.hildegarde.kub@geemail.com	Tempe	Arizona	3096631777908915853	ce437599e8c71cde37be913368c9fd9b	VISA 16 digit	33.3039433439649599	-111.993602447540681
48654	2020-08-29 16:58:51	2020-08-29	Delilah Marvin	delilah.marvin@warmmail.com	Virginia Beach	Virginia	869948366294040240	34fad3fe4a9399c3107be23e2b891699	JCB 15 digit	36.6844365230016436	-76.0373987306978592
48655	2020-08-29 16:58:51	2020-08-29	Vonetta Volkman DVM	vonetta.volkman.dvm@geemail.com	San Francisco	California	869950417296055408	85802c0eafbec9b51c39c9cc195591d8	JCB 16 digit	37.7781886829077322	-122.447548183188417
48656	2020-08-29 17:03:11	2020-08-29	Oscar Kub	oscar.kub@geemail.com	Long Beach	California	4022794319182756	cb9f38fecac5b4c8b287f285319cdd7f	VISA 16 digit	33.7427949899628743	-118.082963947409013
48657	2020-08-29 17:07:36	2020-08-29	Christina Kshlerin MD	christina.kshlerin.md@geemail.com	Los Angeles	California	4338211447557097	c7800ebf5ea9a57f4141adec582c7b70	VISA 16 digit	33.9684112589672154	-118.321180519740281
48658	2020-08-29 17:10:05	2020-08-29	Jettie Feest	jettie.feest@geemail.com	New York	New York	060456456281643	ebe23f6ca2503ff2392b9505de677a2c	Maestro	40.671823434786873	-73.9914775533962938
48659	2020-08-29 17:13:53	2020-08-29	Mr. Colby Jenkins II	mr.colby.jenkins.ii@geemail.com	Nashville	Tennessee	180082226083267528	3fbfa63ac8f6d1682a1e6bdcf7c229f6	JCB 15 digit	36.1964474371291658	-86.7704408020619269
48660	2020-08-29 17:17:13	2020-08-29	Luetta Kuvalis	luetta.kuvalis@geemail.com	San Jose	California	4535487902997868	5f3cacb7fa7f14cdb3b96b67e5e11d23	VISA 13 digit	37.2624784089911714	-121.874857094905892
48661	2020-08-29 17:31:30	2020-08-29	Brenton Homenick-Wilkinson	brenton.homenick.wilkinson@geemail.com	Moreno Valley	California	6011246028287535855	041a3b3884df186d2993471a635c2552	JCB 15 digit	33.8643107108298693	-117.286932477258887
48662	2020-08-29 17:41:34	2020-08-29	Shira Corwin	shira.corwin@geemail.com	Fort Worth	Texas	210005973473178377	1d686f74f6f4ea00bddda3ba759e279c	Discover	32.8458917263485475	-97.316542816051097
48663	2020-08-29 17:43:37	2020-08-29	Darby Beahan	darby.beahan@woohoo.com	San Diego	California	3112134037455955402	e58f954c1f95b9a7bc22b2fa581102a9	Voyager	32.7346561416584976	-117.18785998131149
48664	2020-08-29 17:45:48	2020-08-29	Talia Beahan	talia.beahan@geemail.com	Kansas City	Missouri	4526045544170749	c9a7754abe72d60f3550497970b05080	Maestro	39.0510994916617875	-94.5066587877683304
48665	2020-08-29 17:50:21	2020-08-29	Worley Gibson	worley.gibson@geemail.com	Antioch	California	3337184612630714509	26132c8392105100218f6566c2b32354	JCB 16 digit	38.0548679470814761	-121.894418114953481
48666	2020-08-29 18:06:11	2020-08-29	Mirna Bashirian	mirna.bashirian@warmmail.com	Berkeley	California	4147676953322451	43ac4d337e0c97f2f3f970df086185af	Discover	37.8291320366010524	-122.293859232782225
48667	2020-08-29 18:25:52	2020-08-29	Zaida Jaskolski DDS	zaida.jaskolski.dds@geemail.com	Ventura	California	4139607269509	326feae16c8acd53fa919473412cf8ba	VISA 16 digit	34.2566689049985271	-119.342550911159066
48668	2020-08-29 18:41:27	2020-08-29	Elaine Hartmann	elaine.hartmann@geemail.com	Orlando	Florida	4595234118636832	ddea906fbbfce124a67fbbe71b70fb2c	JCB 16 digit	28.4749230576477927	-81.2336209773052502
48669	2020-08-29 18:45:44	2020-08-29	Dr. Oren Maggio	dr.oren.maggio@geemail.com	San Francisco	California	6011350338652768037	d780b7d28b43da4b4973994be57e9501	VISA 16 digit	37.7918464422271398	-122.41252138930966
48670	2020-08-29 18:46:13	2020-08-29	Benson Mayert-Kunze	benson.mayert.kunze@geemail.com	San Francisco	California	3700989266583941	09e423bde7160f1d7af155467a294432	VISA 16 digit	37.7542067453889842	-122.399164851551632
48671	2020-08-29 18:48:30	2020-08-29	Mac Bruen	mac.bruen@geemail.com	Columbus	Ohio	3158917659949735992	abe614cadc92dc364e93d4e091a89485	Mastercard	40.0386480280242836	-82.9321992608953309
48672	2020-08-29 18:48:50	2020-08-29	Garnett Lynch III	garnett.lynch.iii@geemail.com	Birmingham	Alabama	3030379375320387	ec1bf3ea0b420c0f243030595f359676	Voyager	33.4360830161511871	-86.8528814561441607
48673	2020-08-29 18:51:26	2020-08-29	Ms. Ashleigh Johnston	ms.ashleigh.johnston@geemail.com	Nashville	Tennessee	675900047044771	996269412c41e71f6b59957ed96b5393	Mastercard	36.1072709666687999	-86.8396747622080056
48674	2020-08-29 18:51:50	2020-08-29	Jayce Barrows	jayce.barrows@woohoo.com	Memphis	Tennessee	180067599094543445	69029b2394c1196b9428134b41a88be6	American Express	35.0604186539139633	-90.0242025494366942
48675	2020-08-29 18:54:43	2020-08-29	Randy Nitzsche	randy.nitzsche@geemail.com	Phoenix	Arizona	180073472964719754	9b14d780da9ad2c0387de3b06c7ce351	JCB 16 digit	33.5215915598839516	-112.166629714697976
48676	2020-08-29 18:55:53	2020-08-29	Trever Braun-Funk	trever.braun.funk@geemail.com	Murfreesboro	Tennessee	3528320164627992271	52e0630f7b9eb63c5aeef9517944ae49	VISA 16 digit	35.8427618730001214	-86.3292218363229154
48677	2020-08-29 18:57:20	2020-08-29	Ms. Stacey Ryan	ms.stacey.ryan@geemail.com	San Francisco	California	3476970515176470	f478528053bd9c5e50508782ab2dd9a2	American Express	37.7731787966124344	-122.426005034812817
48678	2020-08-29 19:06:30	2020-08-29	Mr. Bedford Carter	mr.bedford.carter@warmmail.com	San Francisco	California	51208632299860650	c863d81e114412f3447b7e2bb2451da1	VISA 16 digit	37.7757000792482387	-122.431672643455499
48679	2020-08-29 19:13:12	2020-08-29	Dr. Kunta Friesen DVM	dr.kunta.friesen.dvm@geemail.com	Toledo	Ohio	675960883884656	0c08c73004e122b6bf54d57647adfdac	Mastercard	41.6203776162289074	-83.5058666577894257
48680	2020-08-29 19:16:11	2020-08-29	Mr. Harlow Schiller	mr.harlow.schiller@geemail.com	Augusta	Georgia	54255549020476428	bcf15e4ffab4ef44e69984d652a121f3	VISA 16 digit	33.4247875517439041	-82.0192919661585336
48681	2020-08-29 19:16:29	2020-08-29	Mr. Wheeler Pfeffer DDS	mr.wheeler.pfeffer.dds@geemail.com	Simi Valley	California	4300054684312485	7e1418bbe1637cc9f053bd1257c191bf	VISA 16 digit	34.2678935799054827	-118.79108906459436
48682	2020-08-29 19:22:36	2020-08-29	Orin Mitchell	orin.mitchell@warmmail.com	Philadelphia	Pennsylvania	180069617488845594	dbcc744dfaad04afbb4e9f83d6095fee	Mastercard	39.9999617632437463	-75.1137519849829403
48683	2020-08-29 19:33:08	2020-08-29	Tory Krajcik	tory.krajcik@geemail.com	New York	New York	3422054599780518	f97cf2401aaa98c4c76cbe81c80fd888	VISA 16 digit	40.7364179696645579	-73.8508068504173281
48684	2020-08-29 19:35:34	2020-08-29	Dr. Elmyra Schuster MD	dr.elmyra.schuster.md@geemail.com	Montgomery	Alabama	3700631911697763	cc5eb588f9112f0d1d8ed50db2006f9e	Discover	32.3453078587938094	-86.2792388738751299
48685	2020-08-29 19:38:29	2020-08-29	Savannah Lockman	savannah.lockman@geemail.com	Jacksonville	Florida	180012162971543123	99fb7f399880e0f5377d5b408015581e	JCB 15 digit	30.3629265928693108	-81.6088666023299112
48686	2020-08-29 19:40:08	2020-08-29	Dr. Rhett Rolfson	dr.rhett.rolfson@woohoo.com	Chula Vista	California	639047971367645	5073352d6fff128389b17daa99e6f6e7	Voyager	32.5300811759427191	-117.086428161035101
48687	2020-08-29 19:41:42	2020-08-29	Ms. Christen Harvey DDS	ms.christen.harvey.dds@geemail.com	Chicago	Illinois	3528586569418746034	557b0f391669b6d0a34c33aae0e267ae	Mastercard	41.7855984282981652	-87.7311985728826329
48688	2020-08-29 19:45:40	2020-08-29	Irving Schuppe Sr.	irving.schuppe.sr.@geemail.com	Houston	Texas	3158230772933058089	6dd79ba38327ade389f0cc9ff9db8214	VISA 16 digit	29.8808888579796985	-95.4646637232057742
48689	2020-08-29 19:45:54	2020-08-29	Cohen Ondricka	cohen.ondricka@geemail.com	Norfolk	Virginia	53284278792334509	62bc52d9eecb150628da6553abc288ba	VISA 13 digit	36.9950832078717653	-76.164594459673765
48690	2020-08-29 19:52:46	2020-08-29	Roxana Daugherty-Upton	roxana.daugherty.upton@woohoo.com	New Orleans	Louisiana	3755713012933539	2fb8da4dc12fc967a21e070128d7bb71	VISA 16 digit	30.0415398173049084	-89.842972281601277
48691	2020-08-29 19:54:44	2020-08-29	Hilah Kuvalis	hilah.kuvalis@woohoo.com	San Antonio	Texas	3112745882139461900	62aa183e28a15401e94d3da16be4be25	Discover	29.5559603334940988	-98.5806040656588891
48692	2020-08-29 19:56:00	2020-08-29	Miss Jillian Hirthe	miss.jillian.hirthe@geemail.com	Salinas	California	4255918910696	4489394f1d91a7c707786421a960cf29	Mastercard	36.5983985503435107	-121.617267177737133
48693	2020-08-29 19:59:20	2020-08-29	Kanye Hamill-Rohan	kanye.hamill.rohan@geemail.com	San Francisco	California	4079701265455013	9d6e37306163d1b091cdc8c99cb51f9e	American Express	37.7764642495328999	-122.428124241703301
48694	2020-08-29 20:04:55	2020-08-29	Madilyn Feest-Buckridge	madilyn.feest.buckridge@geemail.com	Kansas City	Missouri	6011012075448384659	0c421e800f44e182e65812dd9e7e0052	VISA 16 digit	39.036955648178612	-94.4928873509857823
48695	2020-08-29 20:07:36	2020-08-29	Nylah Bradtke	nylah.bradtke@woohoo.com	Seattle	Washington	4076666965579	975160c2d5debd1358ce7c49edc5dbaa	Discover	47.6906359416823804	-122.405445148322357
48696	2020-08-29 20:14:58	2020-08-29	Ms. Devon Hyatt	ms.devon.hyatt@geemail.com	Berkeley	California	51189117909741600	66f27c552cd40901597763e448468e9c	VISA 16 digit	37.8698169346157272	-122.281968674822977
48697	2020-08-29 20:17:20	2020-08-29	Baylee Wilkinson	baylee.wilkinson@geemail.com	Tyler	Texas	4418898517158005	cd51612fc6d859e23876560c6d47c920	VISA 16 digit	32.2875978173270823	-95.3178011443573894
48698	2020-08-29 20:18:52	2020-08-29	Ms. Dorthea Russel	ms.dorthea.russel@warmmail.com	Greensboro	North Carolina	6011676064442244603	53a9774a71452f4e7886f0e2160de3e0	Voyager	36.0238739336956328	-79.7824768729954883
48699	2020-08-29 20:20:31	2020-08-29	Devonta Parisian-Streich	devonta.parisian.streich@geemail.com	Los Angeles	California	6011327654618487573	e8997c08de0680ef69a04e39159d40be	JCB 15 digit	34.0457226767536199	-118.423591737727818
48700	2020-08-29 20:22:30	2020-08-29	General Watsica	general.watsica@geemail.com	Montgomery	Alabama	869986891749486311	766dbabd6185b6a8f150c9953cb5a6ec	Maestro	32.3923818987261498	-86.1792824880838282
48701	2020-08-29 20:22:54	2020-08-29	Jaquan Heaney-Klein	jaquan.heaney.klein@warmmail.com	Oakland	California	3088359427487886212	09b967f1566c26b5d7e642d7357e934a	Voyager	37.7678504708972653	-122.27009076730431
48702	2020-08-29 20:25:29	2020-08-29	Candice Schmeler-Rutherford	candice.schmeler.rutherford@geemail.com	San Diego	California	180035512768492962	1844fa0eb7261ae39b3836fb044f8b3e	Mastercard	32.7815511739414163	-117.11590791008436
48703	2020-08-29 20:30:16	2020-08-29	Jorja Feeney	jorja.feeney@geemail.com	San Diego	California	210015857243160401	0f74870ae1aeae7c6ececc75ac0b2fdc	Mastercard	32.8058854112468694	-117.071780314287182
48704	2020-08-29 20:31:24	2020-08-29	Kelvin Lakin II	kelvin.lakin.ii@warmmail.com	Dallas	Texas	4529732631192242	e3c1b41d8e752d7cc4fd6797f60fffee	VISA 13 digit	32.8268892869159572	-96.7108053381983126
48705	2020-08-29 20:31:31	2020-08-29	Tonda Grant	tonda.grant@geemail.com	Philadelphia	Pennsylvania	3096325271835025458	39619f4cdff7aede782ccd6402e92e0e	VISA 16 digit	40.0959759524051123	-75.128704750388124
48706	2020-08-29 20:34:59	2020-08-29	Son Wiegand	son.wiegand@geemail.com	Santa Clarita	California	6011546576969297860	a5577faa5e3d02ecc17a8157f9810111	Mastercard	34.4372210173141227	-118.541782715554163
48707	2020-08-29 20:37:19	2020-08-29	Miss Irena Ward	miss.irena.ward@geemail.com	San Francisco	California	060475995330752	8156123c778462945f3de2ae1e5ffcb4	VISA 13 digit	37.7926795015982719	-122.412879831055719
48708	2020-08-29 20:40:53	2020-08-29	Royal Gislason	royal.gislason@geemail.com	Chicago	Illinois	639010511918764	05e89bde9b2ea2ed9df2442e54556856	VISA 16 digit	41.8757570815108764	-87.7720576777152672
48709	2020-08-29 20:54:30	2020-08-29	Miss Josie Thompson PhD	miss.josie.thompson.phd@geemail.com	Atlanta	Georgia	589362452414154	cd9871feebce20322e45468d65b05dd6	JCB 15 digit	33.8579244977604645	-84.5029163484506398
48710	2020-08-29 21:00:10	2020-08-29	Darl Heidenreich DVM	darl.heidenreich.dvm@geemail.com	Louisville	Kentucky	4483739919684	e9b2ed94c013c3e1bc04a38edb1c0868	American Express	38.2061125655095992	-85.6462503274973557
48711	2020-08-29 21:01:48	2020-08-29	Lovina Crona MD	lovina.crona.md@warmmail.com	Palm Bay	Florida	3088192307778492642	81136a4631aa7caaefc0c2fd1d7468ba	Maestro	28.0658205251064174	-80.7385275699034253
48712	2020-08-29 21:05:58	2020-08-29	Mrs. Anissa Rippin PhD	mrs.anissa.rippin.phd@geemail.com	Provo	Utah	3158987581813949993	f16b0b41e534f33ee813f50b6f29dc1a	VISA 13 digit	40.223011485372858	-111.567506858301542
48713	2020-08-29 21:18:32	2020-08-29	Nancy Marks DVM	nancy.marks.dvm@geemail.com	Hampton	Virginia	3002409829778605	eaa36e9873b8e9c6f02bcd89c47431ad	Diners Club / Carte Blanche	37.0871813319642101	-76.2419053854052038
48714	2020-08-29 21:23:16	2020-08-29	Marty Runolfsson	marty.runolfsson@warmmail.com	Chicago	Illinois	3158448113542664793	3eee04c5cd98bc500b306a608ec0107b	JCB 15 digit	41.8917341232601572	-87.635397308276211
48715	2020-08-29 21:36:30	2020-08-29	Carleigh Herman	carleigh.herman@woohoo.com	New York	New York	501854964385501	2cbc4bd271824b0870a2b2eac3467d85	VISA 16 digit	40.5913919689822933	-73.9289377940248613
48716	2020-08-29 21:41:01	2020-08-29	Melton Williamson	melton.williamson@woohoo.com	Charlotte	North Carolina	4745648725923441	44c10804b7f1d1f9f5526ff93249c433	JCB 15 digit	35.2438912466887402	-80.750874019920829
48717	2020-08-29 21:43:30	2020-08-29	Kristian Stracke MD	kristian.stracke.md@geemail.com	San Francisco	California	4239394027589	649cc11d7d22043e2035c9242e895844	VISA 13 digit	37.7879626756479539	-122.423399522933494
48718	2020-08-29 21:50:28	2020-08-29	Dr. Alvis Bogisich	dr.alvis.bogisich@warmmail.com	Oakland	California	4663773302514591	e79181e39e3873606873b794c2130f61	JCB 16 digit	37.819171786112328	-122.232521954394599
48719	2020-08-29 21:52:19	2020-08-29	Miss Amaris Kirlin	miss.amaris.kirlin@geemail.com	San Francisco	California	561289138982064	44fd01850a23f74de66ab3382ac2e915	Voyager	37.766357411644023	-122.43158806326052
48720	2020-08-29 21:52:31	2020-08-29	Elias Auer	elias.auer@geemail.com	Denver	Colorado	4789771174777246	2b890386a2a01c06d0a038067e10008d	JCB 16 digit	39.7695222587376804	-104.901816153830296
48721	2020-08-29 21:56:20	2020-08-29	Mr. Dusty Wiza Sr.	mr.dusty.wiza.sr.@geemail.com	Elizabeth	New Jersey	3059915839158631	c0fd8dbddbedc4ffc609a46a0ac485e3	Discover	40.6415306993886887	-74.12890073810145
48722	2020-08-29 22:08:04	2020-08-29	Aryana Schoen	aryana.schoen@geemail.com	Phoenix	Arizona	55906258698254843	592cd523211b948dad0b369597764ddd	Discover	33.654803333704173	-112.131303302051876
48723	2020-08-29 22:13:40	2020-08-29	Ewell Haag	ewell.haag@woohoo.com	Milwaukee	Wisconsin	4126455778679410	29720bd7288a57083cfb4394b30d3088	Diners Club / Carte Blanche	43.1202749728776524	-88.0130702560868201
48724	2020-08-29 22:17:16	2020-08-29	Benita Gulgowski	benita.gulgowski@geemail.com	Jacksonville	Florida	52467072396647492	50cee8ba071724952cc12df3a4834076	JCB 16 digit	30.2427436286170028	-81.7547372791994462
48725	2020-08-29 22:17:31	2020-08-29	Mabelle Emmerich	mabelle.emmerich@geemail.com	Rockford	Illinois	52078725727439522	f6ab9a0dca68174650bb9894ad9bfa72	VISA 13 digit	42.2184542612183833	-88.971318484824522
48726	2020-08-29 22:20:19	2020-08-29	Jacky Bernhard	jacky.bernhard@geemail.com	Nashville	Tennessee	3731097569401093	e9bc16979a67fe0571fd821197fe54a0	Maestro	36.1401394043240671	-86.6889288870058863
48727	2020-08-29 22:21:22	2020-08-29	Sunday Blick	sunday.blick@geemail.com	Berkeley	California	4100156881330525	91d89eb19f414a9e92060b44b4d33ff5	Mastercard	37.8591477601104955	-122.258104557607695
48728	2020-08-29 22:23:31	2020-08-29	Thelma Koelpin	thelma.koelpin@geemail.com	Los Angeles	California	869993957888139200	df6644186e089f08dcb9438008ff9b90	JCB 16 digit	33.9928659260138843	-118.366726366476342
48729	2020-08-29 22:25:48	2020-08-29	Lakendra Kris-Marquardt	lakendra.kris.marquardt@geemail.com	Chandler	Arizona	3112157501607576376	6281aa80df28922bc5e8db3fa08a2490	Voyager	33.2753765071831609	-111.792565618630121
48730	2020-08-29 22:30:34	2020-08-29	Dillard Kuvalis	dillard.kuvalis@woohoo.com	Laredo	Texas	869911177758212792	3540b80fffb91487b5bd4cc65055f33b	JCB 15 digit	27.4618926406554884	-99.5142904249027396
48731	2020-08-29 22:38:05	2020-08-29	Austen Rath	austen.rath@woohoo.com	Abilene	Texas	503872507006103	66f03998b3f474b932677ffd88ea3095	Discover	32.4924388201981813	-99.7743880882807161
48732	2020-08-29 22:48:12	2020-08-29	Lyric Reynolds	lyric.reynolds@geemail.com	Boulder	Colorado	3158599768767716201	6258fa3980eddc5697fb4fcdb1f410c2	JCB 15 digit	40.0647459528856018	-105.2850029300578
48733	2020-08-29 22:53:18	2020-08-29	Ms. Delle Gutmann	ms.delle.gutmann@geemail.com	Indianapolis	Indiana	869945791997040119	fc800331fb105811bad4fa4753ec4fef	Discover	39.7252203736461666	-86.2369986001137647
48734	2020-08-29 22:59:08	2020-08-29	Shelli Ritchie DVM	shelli.ritchie.dvm@geemail.com	San Antonio	Texas	3528313165685484258	e27f636834efb2ed98792ff1f0b7ccc4	VISA 16 digit	29.4873344197940099	-98.5940937544986582
48735	2020-08-29 23:03:15	2020-08-29	Sibbie Hyatt DDS	sibbie.hyatt.dds@geemail.com	Corpus Christi	Texas	180022063914483815	3b1c912fcf3531438ee705b7dffd0f06	Maestro	27.7259166693251586	-97.2400089002043018
48736	2020-08-29 23:06:26	2020-08-29	Miss Brynn Crona	miss.brynn.crona@geemail.com	San Francisco	California	4763752933062849	e465607cdbc4a30b2f12197fb5d974c6	VISA 16 digit	37.7659689705332866	-122.442856044544641
48737	2020-08-29 23:13:07	2020-08-29	Dani Rempel-Bauch	dani.rempel.bauch@woohoo.com	Aurora	Colorado	6011008618204998919	5dd1ae697f50d0018fd9f015f636ee21	Diners Club / Carte Blanche	39.6801005808282667	-104.616111530282353
48738	2020-08-29 23:13:58	2020-08-29	January Torphy DVM	january.torphy.dvm@geemail.com	Oakland	California	3786883495575132	d6ee450a8a0833364282e80864451226	VISA 16 digit	37.8275901797920895	-122.274623429024473
48739	2020-08-29 23:14:36	2020-08-29	Daphne Stoltenberg DDS	daphne.stoltenberg.dds@geemail.com	Wichita	Kansas	4554711467410488	e42b817e75582fc7b69cbf55b1e1254b	JCB 15 digit	37.738407687225191	-97.2900747698001567
48740	2020-08-29 23:17:22	2020-08-29	Obe Friesen-Hickle	obe.friesen.hickle@geemail.com	Seattle	Washington	3096550902025725608	c409c1637148a1a43ef1f9eeae1d8539	VISA 16 digit	47.6043584425859123	-122.303438812719278
48741	2020-08-29 23:24:14	2020-08-29	Olga Moen	olga.moen@geemail.com	Boston	Massachusetts	6011713420345665085	660840baf00113d4d114037a319d4d59	Voyager	42.3951980927195393	-71.0450400202021086
48742	2020-08-29 23:27:26	2020-08-29	Morgan Gaylord	morgan.gaylord@geemail.com	Salt Lake City	Utah	869987275267886228	3abe841dfa198bfd5a5f6d9ccc1c8f1d	JCB 15 digit	40.7002746713027364	-111.93088664505072
48743	2020-08-29 23:31:06	2020-08-29	Miss Aiyanna Balistreri	miss.aiyanna.balistreri@geemail.com	Chula Vista	California	3710493832108877	0fda445b18d7b8f03ad0bd1fe357e366	Discover	32.6943039207018913	-117.077999345608788
48744	2020-08-29 23:33:04	2020-08-29	Ella Pouros	ella.pouros@geemail.com	Mesa	Arizona	4052765101465123	5e54096cadebac461a29424d32060d4b	VISA 16 digit	33.3607311144616432	-111.797961550101263
48745	2020-08-29 23:41:11	2020-08-29	Coleton Feest Jr.	coleton.feest.jr.@geemail.com	Los Angeles	California	4578137328237625	5c936c533bb56dda27b31bdf1ef1011a	Diners Club / Carte Blanche	34.0894956147629742	-118.313551184394584
48746	2020-08-29 23:43:30	2020-08-29	Orlin Pouros-Bergnaum	orlin.pouros.bergnaum@geemail.com	Aurora	Colorado	180036267890672523	71aa11c264a7d275a326cc6fc6f0a23f	VISA 13 digit	39.7144083717018361	-104.707893835113197
48747	2020-08-29 23:52:51	2020-08-29	Huldah Hyatt	huldah.hyatt@geemail.com	Little Rock	Arkansas	180014270114044772	d7fd58c4ccf592f8e3c42d79b2aabbb7	JCB 16 digit	34.7664767011344438	-92.4436427764002246
48748	2020-08-29 23:53:53	2020-08-29	Bryton Hamill-White	bryton.hamill.white@warmmail.com	Oakland	California	4699993775514211	c426f4b05f6adebe1d184fbeadc486d5	Discover	37.7812978721278654	-122.289561451883742
48749	2020-08-29 23:55:53	2020-08-29	Dr. Millicent McKenzie PhD	dr.millicent.mckenzie.phd@woohoo.com	Denver	Colorado	210044537600525330	705645869900e6f764631b79ee6c2349	VISA 13 digit	39.7742171079903812	-104.790455782112105
48750	2020-08-30 00:01:03	2020-08-30	Monte Greenfelder	monte.greenfelder@geemail.com	North Las Vegas	Nevada	869901505926014116	4687886c6edb3b97ce8b131591450648	Maestro	36.3489050832267822	-115.017203960543128
48751	2020-08-30 00:01:06	2020-08-30	Kamari Beier	kamari.beier@warmmail.com	Atlanta	Georgia	4251110004594811	2217271ebdc6b8c12713cec879aef5cd	VISA 16 digit	33.7954734865851734	-84.4634992076128839
48752	2020-08-30 00:05:39	2020-08-30	Dr. Courtland Swaniawski IV	dr.courtland.swaniawski.iv@geemail.com	Los Angeles	California	3112261665876440557	b2236e5625ba0e8c4fbdb0e0ed3ecb34	Mastercard	33.9244940827932169	-118.381445305979994
48753	2020-08-30 00:08:01	2020-08-30	Scarlet Bahringer	scarlet.bahringer@woohoo.com	Grand Rapids	Michigan	6011979731332547618	f09fc9092c789de707e2433be4a25f04	VISA 16 digit	43.0600343213684837	-85.6855177144654192
48754	2020-08-30 00:09:16	2020-08-30	Louisiana Stanton-Walker	louisiana.stanton.walker@geemail.com	Seattle	Washington	3112213050541806962	00af68933bc6530d595123f2f13ff31c	American Express	47.7067581120803936	-122.299202024323492
48755	2020-08-30 00:12:20	2020-08-30	Miss Khloe Nader	miss.khloe.nader@geemail.com	New York	New York	4093209738871404	726357a186049f153e6edf23c38bad22	JCB 16 digit	40.7058407405614844	-73.8391628368187725
48756	2020-08-30 00:12:40	2020-08-30	Miss Blair Koch	miss.blair.koch@geemail.com	Los Angeles	California	4184834857344444	7b4187f6f7e97bd7088d8720f4eacf40	JCB 15 digit	33.9469517034809982	-118.354806052799518
48757	2020-08-30 00:31:48	2020-08-30	Brock Dooley	brock.dooley@geemail.com	Berkeley	California	51991402303581606	a435ed813007161bdc1a7e484bbeddc6	VISA 16 digit	37.8149309265601588	-122.263299813390134
48758	2020-08-30 00:52:39	2020-08-30	Ms. Beckie Weber	ms.beckie.weber@geemail.com	Berkeley	California	3000059190500765	f05b969299ecedfa2271cf74c484fd98	Discover	37.8783473731067701	-122.262957673506776
48759	2020-08-30 00:55:48	2020-08-30	Mr. Lincoln Kautzer	mr.lincoln.kautzer@geemail.com	Chandler	Arizona	53882165908658309	726bc73ab0f806408a4c0beb1e0eb25c	Diners Club / Carte Blanche	33.2034728586763137	-111.865260013926402
48760	2020-08-30 01:00:52	2020-08-30	Lorrie Conroy-Smitham	lorrie.conroy.smitham@geemail.com	North Las Vegas	Nevada	210016402825738396	2ce3986281b2f245a62b116b19b2a874	Mastercard	36.3095191539421691	-115.165758972590424
48761	2020-08-30 01:01:08	2020-08-30	Ms. Ilma Romaguera	ms.ilma.romaguera@geemail.com	Charlotte	North Carolina	55281441853432678	d9ab119923d99a69eb096dab0f3784a9	JCB 15 digit	35.2839173185892392	-80.9160163408555064
48762	2020-08-30 01:07:23	2020-08-30	Anastacia Schultz	anastacia.schultz@geemail.com	Jacksonville	Florida	210055372310600454	2ad741a6762b3907592c2d775e86b01e	Voyager	30.4067247111402459	-81.6819198361676229
48763	2020-08-30 01:16:05	2020-08-30	Ms. Alda Bergnaum PhD	ms.alda.bergnaum.phd@geemail.com	Fontana	California	4156246469897731	9c5c20b3a98ab26802f8b28ab3ea5cdb	JCB 15 digit	34.190218803487717	-117.517417353791743
48764	2020-08-30 01:18:17	2020-08-30	Daphne Hyatt	daphne.hyatt@geemail.com	San Francisco	California	3013954136348161	f58aad4402ceb9a22eb820b3a004477d	VISA 13 digit	37.7755218563190667	-122.423077113814188
48765	2020-08-30 01:18:35	2020-08-30	Hardie O'Connell	hardie.o'connell@warmmail.com	Port St. Lucie	Florida	3471064693224156	4267cbd9f048c08e0d27942bafe59c18	VISA 13 digit	27.2330145090486866	-80.3380330775484452
48766	2020-08-30 01:20:20	2020-08-30	Kaela Satterfield	kaela.satterfield@woohoo.com	San Antonio	Texas	675937054189818	0637b4102b8ec3eb4929bca35a8d14d6	Diners Club / Carte Blanche	29.3934413458757113	-98.5346910217612901
48767	2020-08-30 01:21:56	2020-08-30	Retha Boehm	retha.boehm@geemail.com	Philadelphia	Pennsylvania	6011059122681423325	8f4cc70d9d5a8d1648dac9bf9b2a79f6	VISA 16 digit	39.9257018213119323	-75.1130850738745295
48768	2020-08-30 01:22:24	2020-08-30	Marty Hettinger	marty.hettinger@woohoo.com	Rancho Cucamonga	California	180065126336484063	1fa77dcd4c61bf9da52a56a9ebaa5df3	JCB 16 digit	34.0890043299172092	-117.546534555638956
48769	2020-08-30 01:23:22	2020-08-30	Jemal Willms	jemal.willms@warmmail.com	Odessa	Texas	3747848457335732	077de8528ef0565e332b6532353dbba3	JCB 15 digit	31.8123005238372834	-102.427973918073249
48770	2020-08-30 01:31:48	2020-08-30	Aubrie Johnston	aubrie.johnston@geemail.com	San Francisco	California	561241984830889	000f09fc9a31168d9aa7b9db0e657644	VISA 13 digit	37.7865300936936919	-122.450810643499608
48771	2020-08-30 01:42:01	2020-08-30	Mrs. Edla Dietrich MD	mrs.edla.dietrich.md@woohoo.com	Oklahoma City	Oklahoma	3046099095711186	0254aca14bc14f2e2a5c90bbca380ee1	JCB 15 digit	35.4814783392384641	-97.5056381372164935
48772	2020-08-30 01:42:17	2020-08-30	Tobe Senger	tobe.senger@woohoo.com	Phoenix	Arizona	501896306374339	b50c59e4b47fecb8639d836d745b735d	Voyager	33.486503669845689	-112.138897933850444
48773	2020-08-30 01:42:58	2020-08-30	Reed Conroy	reed.conroy@warmmail.com	San Francisco	California	54367641412168948	a84529967283ff4dfc826906f5017c09	JCB 15 digit	37.7646176378488008	-122.447984675667314
48774	2020-08-30 01:50:02	2020-08-30	Miss Myrtice Kihn MD	miss.myrtice.kihn.md@warmmail.com	Overland Park	Kansas	4985954051597	f0dc752184d03374c5838b45c58a4221	JCB 15 digit	38.8958104981910466	-94.7279284582048717
48775	2020-08-30 01:52:46	2020-08-30	Gus Schoen	gus.schoen@geemail.com	New York	New York	3096087234887910074	cde1dfd8d6643814e80b29abbb175596	Mastercard	40.6705553948171428	-73.9021507811162621
48776	2020-08-30 02:03:02	2020-08-30	Georgene Lindgren PhD	georgene.lindgren.phd@warmmail.com	Berkeley	California	3019481499999889	3cb78627ce11e4b989fc4f6b2797a236	Diners Club / Carte Blanche	37.8652334395157126	-122.252330599889049
48777	2020-08-30 02:06:54	2020-08-30	Dr. Howard Bogan DDS	dr.howard.bogan.dds@geemail.com	Cedar Rapids	Iowa	6011536701246000448	28e7573ccfbfaed03d2d96fd27a61a2d	VISA 13 digit	41.9632659511249528	-91.7608733984708778
48778	2020-08-30 02:07:08	2020-08-30	Natalia Hoeger	natalia.hoeger@geemail.com	Oakland	California	3088372513546710445	5d496b53f59430f20cf8ccce1259bf57	JCB 15 digit	37.7808645195738393	-122.284498938642457
48779	2020-08-30 02:10:23	2020-08-30	Dr. Faustino Mante	dr.faustino.mante@geemail.com	Rancho Cucamonga	California	4388033302661	670dbbb4e51ce17a45c334fa3f42f37b	Diners Club / Carte Blanche	34.1230332980390614	-117.587479798077425
48780	2020-08-30 02:18:37	2020-08-30	Meaghan Shields-Feest	meaghan.shields.feest@woohoo.com	Killeen	Texas	180098820668752391	fd70995b84c037ce1488aa4aae9755c8	Discover	31.0511735945239664	-97.730726510256531
48781	2020-08-30 02:24:23	2020-08-30	Bruno Smith	bruno.smith@geemail.com	Chula Vista	California	3487084438011991	6a80507c00c24290c70fefe0d3ab750b	JCB 16 digit	32.5295182165455046	-116.93471388684101
48782	2020-08-30 02:37:16	2020-08-30	Dr. Joeseph Gulgowski DVM	dr.joeseph.gulgowski.dvm@geemail.com	Plano	Texas	3437927135906551	bccc651d92a641f009d0c3650b4f5359	JCB 16 digit	33.010894323335215	-96.8463348109923317
48783	2020-08-30 02:45:21	2020-08-30	Ludwig Hickle	ludwig.hickle@geemail.com	Madison	Wisconsin	210069356924837457	71099bc2cfa91795b66731c1aa58163d	American Express	43.0906233320917949	-89.348844805068893
48784	2020-08-30 02:49:08	2020-08-30	Dr. Wells Dibbert	dr.wells.dibbert@woohoo.com	Boston	Massachusetts	210053072664109506	5a5d95cd82b247dd8998a88293ea86dd	American Express	42.3891168702561387	-70.9482600837897479
48785	2020-08-30 02:49:35	2020-08-30	Miss Wanita Macejkovic PhD	miss.wanita.macejkovic.phd@geemail.com	Oklahoma City	Oklahoma	561286953317939	5908bd83a8053a33b3b48e2e7139d067	American Express	35.4942447292063434	-97.5178248151101172
48786	2020-08-30 02:50:43	2020-08-30	Almer Koepp	almer.koepp@woohoo.com	Jacksonville	Florida	4583771108334	564765acc95d8dd9eeaed5606f2048a1	JCB 16 digit	30.366349211340399	-81.665175366828592
48787	2020-08-30 02:51:50	2020-08-30	Moody Ledner	moody.ledner@geemail.com	New York	New York	4375910056132779	bb917bab01277cb875a7f0b773693e86	JCB 16 digit	40.6741161783915004	-73.9867977034661948
48788	2020-08-30 02:55:03	2020-08-30	Giuseppe Gulgowski	giuseppe.gulgowski@woohoo.com	Orange	California	3096194757322309304	ef8980d600e5a8673cec83c97d6c69bc	JCB 16 digit	33.860791723465546	-117.897334789541731
48789	2020-08-30 02:55:32	2020-08-30	Laverne Kuhlman	laverne.kuhlman@geemail.com	Charlotte	North Carolina	210003871961021509	8a98e16c2dc6d53e8439fbecd7d9a329	VISA 13 digit	35.2274110596414616	-80.9307038609813958
48790	2020-08-30 02:56:02	2020-08-30	Buford Bashirian	buford.bashirian@geemail.com	Corona	California	210077653858599222	c13f7c4c559e28c54f990f5e9701fa7c	VISA 16 digit	33.9037380824685144	-117.5936481242273
48791	2020-08-30 02:57:00	2020-08-30	Gage Collins	gage.collins@geemail.com	Charlotte	North Carolina	54966902820729761	c221908e02ed0a0e038a5678ca5402cd	Maestro	35.1111749590627866	-80.7745192593373389
48792	2020-08-30 03:04:44	2020-08-30	Nova Erdman	nova.erdman@geemail.com	Round Rock	Texas	869916048652860652	84e90a75272a3c5ed8fe60651302ab01	Discover	30.5919094255797575	-97.601894669592383
48793	2020-08-30 03:06:02	2020-08-30	Lynette Mohr	lynette.mohr@warmmail.com	Vallejo	California	4870282081118649	b73fae5dce62eb1881f72eae181a0ffb	JCB 16 digit	38.1977604001384208	-122.329452663693573
48794	2020-08-30 03:11:00	2020-08-30	Bertram Howell	bertram.howell@woohoo.com	San Francisco	California	4193966583533269	22e252102c0cdd5f63154401bc8d14cc	JCB 16 digit	37.7946320335162724	-122.425994190099843
48795	2020-08-30 03:11:37	2020-08-30	Annie Auer	annie.auer@woohoo.com	Indianapolis	Indiana	210084402191069050	e67423a3174952851c65bd8c1ce379e2	VISA 16 digit	39.7621694529902143	-86.1583576439149681
48796	2020-08-30 03:14:21	2020-08-30	Maxie Wintheiser	maxie.wintheiser@geemail.com	Phoenix	Arizona	3088247177597589919	576799a2a0820094f042559fb67baaf6	JCB 16 digit	33.5123771400589519	-112.065123906026045
48797	2020-08-30 03:23:29	2020-08-30	Lora Kunde	lora.kunde@woohoo.com	Oakland	California	3052987571358635	c568b44a12d042e20107b417d43da87a	VISA 16 digit	37.8054867050017123	-122.246470440368
48798	2020-08-30 03:28:17	2020-08-30	Debera Kuvalis	debera.kuvalis@geemail.com	Portland	Oregon	676188679381496	faec5ce0c2f6643ce6d7bf76e29ac4ca	JCB 16 digit	45.6329876831620922	-122.639932589232927
48799	2020-08-30 03:30:12	2020-08-30	Chessie Smitham MD	chessie.smitham.md@geemail.com	Kent	Washington	3039996015506629	9c89b959a9441bd98df18aa07be25238	Mastercard	47.4046512423194955	-122.230602511823918
48800	2020-08-30 03:35:58	2020-08-30	Dr. Albertus Dickinson DDS	dr.albertus.dickinson.dds@geemail.com	Houston	Texas	3754883497449920	d39880d06baf2bbc370b470d3403d30a	VISA 16 digit	29.8270008101206265	-95.409745007894557
48801	2020-08-30 03:37:36	2020-08-30	Yetta Schimmel-Dickens	yetta.schimmel.dickens@geemail.com	New York	New York	3158330846593673582	1ba33d889d6e57bcd204c633ca987dc1	Diners Club / Carte Blanche	40.6997108039669655	-73.8706553117267788
48802	2020-08-30 03:37:44	2020-08-30	Mrs. Parker Hermiston	mrs.parker.hermiston@geemail.com	Tampa	Florida	4043927868843403	8f96aba6e14c2577c983d9e9ff9fac6c	Maestro	27.9790894904755056	-82.4562112014021693
48803	2020-08-30 03:42:46	2020-08-30	Latosha Hamill	latosha.hamill@geemail.com	Cape Coral	Florida	4092097765329904	3cf66225bfd45f8265944bf90e561ed5	VISA 16 digit	26.7042691557172702	-81.9243495333544871
48804	2020-08-30 03:44:10	2020-08-30	Mrs. Monnie Raynor DVM	mrs.monnie.raynor.dvm@warmmail.com	San Francisco	California	3096867870106132713	50141f33b9c0af4ba6b8d1ca904ce462	Mastercard	37.7812098133068233	-122.453054227518393
48805	2020-08-30 03:46:12	2020-08-30	Verdell Olson	verdell.olson@woohoo.com	Boise	Idaho	3491955289796695	bc2dff8b88e4ace2dd153f6e651c687b	JCB 15 digit	43.5623205016970658	-116.269492710587386
48806	2020-08-30 03:48:37	2020-08-30	Jeramiah Lindgren	jeramiah.lindgren@geemail.com	San Francisco	California	3528331461087699199	374e97cbe10badcec6484d60eea606a7	Voyager	37.773838551546568	-122.387930608333718
48807	2020-08-30 03:51:21	2020-08-30	Mr. Manson Veum	mr.manson.veum@geemail.com	Minneapolis	Minnesota	51279695070781621	df875d6ab6858cc1473a8dc49c76b6ac	Maestro	44.8833296384282363	-93.2264221013795549
48808	2020-08-30 04:00:42	2020-08-30	Lillie Hills	lillie.hills@geemail.com	Jacksonville	Florida	869963009316990220	eb92e566c5034b4a9f225d0992878718	JCB 16 digit	30.2981188632600009	-81.6220673392139418
48809	2020-08-30 04:05:04	2020-08-30	Mr. Crockett Keeling	mr.crockett.keeling@geemail.com	Los Angeles	California	4017055350791	e574930495eb8a7bfd294d8eab8535dd	Voyager	33.9437204668629917	-118.375306046753366
48810	2020-08-30 04:06:01	2020-08-30	Ernestine Quitzon	ernestine.quitzon@warmmail.com	Phoenix	Arizona	3158596596304653311	5a2bbab032c7ecabe19d6c3d7be30de0	Maestro	33.6693424650400885	-112.187275134904695
48811	2020-08-30 04:06:30	2020-08-30	Melody Wuckert	melody.wuckert@geemail.com	Anaheim	California	3031733041055398	5ff90da0f177aae1ec035f3b0446406d	JCB 15 digit	33.9296176142357311	-117.803970066106316
48812	2020-08-30 04:06:46	2020-08-30	Job Turner	job.turner@warmmail.com	San Antonio	Texas	6011172938591917375	e5e400854028276195093370a7592928	Discover	29.5300363809406754	-98.55177404762469
48813	2020-08-30 04:09:06	2020-08-30	Skip Mertz	skip.mertz@geemail.com	Fort Worth	Texas	3088655904393144366	3de20a6738b344c2846884af44b7dcd4	Mastercard	32.6945358702968818	-97.4009763365432661
48814	2020-08-30 04:27:50	2020-08-30	Dr. Liston Abbott	dr.liston.abbott@warmmail.com	Minneapolis	Minnesota	3466992044486727	fcbb1fa14396f817db41c32a0a4be8f8	JCB 16 digit	44.9504291673276555	-93.3229669256407703
48815	2020-08-30 04:27:53	2020-08-30	Elizabeth Koepp	elizabeth.koepp@geemail.com	Odessa	Texas	4431810269633302	593f262fef98aa565000c02c0301e9ef	Diners Club / Carte Blanche	31.9358322938915364	-102.40226847121157
48816	2020-08-30 04:29:00	2020-08-30	Duwayne Runte-Little	duwayne.runte.little@warmmail.com	San Francisco	California	3052386664574655	b9daca49ee4083c247a127e95a2e45cb	VISA 13 digit	37.8211816994090029	-122.421680273766185
48817	2020-08-30 04:31:51	2020-08-30	Philomena Schoen	philomena.schoen@geemail.com	Lakewood	Colorado	3337931861610129024	a5a3893e138ff6737d25c76f33fbe1c4	JCB 16 digit	39.7785263915486667	-105.093690618642043
48818	2020-08-30 04:32:19	2020-08-30	Shonda Kuhlman	shonda.kuhlman@geemail.com	Lincoln	Nebraska	4188126258329	719890c80a1cc7a62e4dfbc71cbe42cd	JCB 16 digit	40.7966859980504921	-96.6833911591369741
48819	2020-08-30 04:34:49	2020-08-30	Talia Hauck MD	talia.hauck.md@geemail.com	Honolulu	Hawaii	060430669093210	219c47254a9bd5f359e000ea026e8d6a	JCB 15 digit	21.3590884630784394	-157.910442916976649
48820	2020-08-30 04:36:26	2020-08-30	Anthoney Howell	anthoney.howell@geemail.com	San Francisco	California	4129228079927292	ff199863f56ea6273eb3ad11e36abf01	Diners Club / Carte Blanche	37.7738499200548503	-122.435269708125261
48821	2020-08-30 04:38:44	2020-08-30	Kari Shields DDS	kari.shields.dds@geemail.com	Corpus Christi	Texas	675928842224553	2c3abb677ea485f5a36e7f8241172bf9	JCB 16 digit	27.6908037933923303	-97.1386417231351089
48822	2020-08-30 04:39:34	2020-08-30	Orma Lubowitz MD	orma.lubowitz.md@geemail.com	San Francisco	California	3096776517949349356	1d94ed4fcb3aeb5f2c9b52e56d46f6d1	JCB 15 digit	37.7744432607945413	-122.427110385329883
48823	2020-08-30 04:44:07	2020-08-30	Mr. Orvis Runolfsdottir	mr.orvis.runolfsdottir@geemail.com	Albuquerque	New Mexico	6011426842672873594	e6cad9165ba80319048210357044516b	VISA 16 digit	35.0966908403806386	-106.65678936374151
48824	2020-08-30 04:51:12	2020-08-30	Grover Weissnat-Lakin	grover.weissnat.lakin@geemail.com	Sterling Heights	Michigan	54441560850699976	d3b64e0fdacc62caa995c423e7c24b00	VISA 13 digit	42.6759238032240447	-82.9977587796442151
48825	2020-08-30 04:59:42	2020-08-30	Andria Muller-Kovacek	andria.muller.kovacek@geemail.com	Albuquerque	New Mexico	4080179387811008	64413c78e20c9dc4c6f154edc2ee9baa	VISA 13 digit	35.0078536120843182	-106.646661700827636
48826	2020-08-30 05:04:43	2020-08-30	Mr. Jake Herzog Jr.	mr.jake.herzog.jr.@geemail.com	Boston	Massachusetts	3048020030045223	999778687427b8b61f456a3192b6a823	Discover	42.3789787107780569	-71.0396432382471943
48827	2020-08-30 05:08:54	2020-08-30	Mr. Kenya Tillman DVM	mr.kenya.tillman.dvm@geemail.com	Buffalo	New York	6011635500241605270	1a71b27780aae6165bedf45d7f6b727e	VISA 16 digit	42.8297166856192035	-78.909059769793231
48828	2020-08-30 05:16:20	2020-08-30	Giovanna Glover	giovanna.glover@geemail.com	Berkeley	California	3463668655704797	bcb1169a44dbe9133705f0b49bc25d3a	JCB 16 digit	37.8790489421453529	-122.307564484258705
48829	2020-08-30 05:16:23	2020-08-30	Lindbergh Schroeder	lindbergh.schroeder@geemail.com	Philadelphia	Pennsylvania	3470430038423632	d973390083f26e138842cd11b5fe1ec6	Discover	40.0740731682587423	-75.0373185828693323
48830	2020-08-30 05:17:36	2020-08-30	Tyree Heidenreich	tyree.heidenreich@geemail.com	Stockton	California	4770683250501427	1a312a83845eb7dce3caa4eee9858c53	Maestro	38.0675677830085206	-121.285365621055661
48831	2020-08-30 05:18:23	2020-08-30	Candis Hane	candis.hane@woohoo.com	Raleigh	North Carolina	3528824433006959719	5b2d4c0beded9baf05fe9e5588e1d4d8	American Express	35.8006452991295561	-78.7099806846987491
48832	2020-08-30 05:27:36	2020-08-30	Candis Schmitt	candis.schmitt@geemail.com	Winston–Salem	North Carolina	3158134573623875924	ab96d414fd20e1b0b8afa4304f253acb	JCB 16 digit	36.1084692045345861	-80.3039515428375381
48833	2020-08-30 05:29:57	2020-08-30	Lewis Cummerata-Cormier	lewis.cummerata.cormier@geemail.com	Los Angeles	California	52578043303949277	b0047d0e60dc4e98c26a71f9990ac063	Mastercard	34.1149735945608441	-118.429917508130146
48834	2020-08-30 05:37:27	2020-08-30	Altha McDermott	altha.mcdermott@warmmail.com	Springfield	Massachusetts	3158702163713570718	d84953ce6a0d891eec3c47d994c76882	VISA 16 digit	42.0701710540074814	-72.5978910989221191
48835	2020-08-30 05:46:08	2020-08-30	Alanna Stracke	alanna.stracke@geemail.com	New Orleans	Louisiana	4683138669372	ad23ea130894a73e9989df9e6d7c3cf5	VISA 16 digit	30.0878555905088767	-89.8862423389479517
48836	2020-08-30 05:46:48	2020-08-30	Mr. Blanchard Jenkins	mr.blanchard.jenkins@geemail.com	Los Angeles	California	180025054828000008	6ca1c44bf6f78113eba9be1e41841f4f	VISA 13 digit	33.9583841217081996	-118.315571998943753
48837	2020-08-30 05:53:06	2020-08-30	Coralie Maggio	coralie.maggio@woohoo.com	Henderson	Nevada	3457338866224179	fdd75dc8cc92aa909dc7d30948129a8a	Voyager	36.0719363753616804	-115.056045205394554
48838	2020-08-30 06:02:20	2020-08-30	Dr. Conley Pfeffer	dr.conley.pfeffer@warmmail.com	San Francisco	California	53494999965291483	a59f1d8bb37e2c9f80d0d6b9009cfffe	Mastercard	37.7509117168200916	-122.43770957134403
48839	2020-08-30 06:02:39	2020-08-30	Manerva Leuschke	manerva.leuschke@warmmail.com	Irvine	California	4085490056164743	f736582dd9230e55e6ca09c5021f6070	JCB 16 digit	33.6077965224642341	-117.765839086800071
48840	2020-08-30 06:09:52	2020-08-30	Joyce Shields	joyce.shields@warmmail.com	Detroit	Michigan	180089124675002622	5ecf60f3222873c06debdf9cf807bf9e	Discover	42.4136191631592823	-83.0564398719582613
48841	2020-08-30 06:11:44	2020-08-30	Lockie Koss DVM	lockie.koss.dvm@warmmail.com	Los Angeles	California	3088967995452591128	3af575696fc7bd30756da259130e48c7	JCB 16 digit	34.0897951759263833	-118.45454796063639
48842	2020-08-30 06:16:09	2020-08-30	Lena Hansen-Buckridge	lena.hansen.buckridge@geemail.com	New York	New York	6011972313600248463	5adf2621e8904ff44617117a1b9ef39e	Diners Club / Carte Blanche	40.5825814418252548	-73.9103651897411709
48843	2020-08-30 06:22:21	2020-08-30	Pattie Welch	pattie.welch@geemail.com	Buffalo	New York	639048139939408	cd35d45ea2df0589fe175b9fba9618b9	American Express	42.8120667134132233	-78.9322624174345293
48844	2020-08-30 06:22:22	2020-08-30	Ayleen Metz-Yost	ayleen.metz.yost@geemail.com	Boston	Massachusetts	4573661589040	60992af94d8152b78c8575bf570e60d7	JCB 16 digit	42.2628481840416796	-70.9567427919197797
48845	2020-08-30 06:22:51	2020-08-30	Albina Stanton-Tillman	albina.stanton.tillman@geemail.com	Washington	District of Columbia	4015775048863492	27d48bad4710f949a6cdee090d5b32af	VISA 16 digit	38.9006421214234095	-76.9305208924438801
48846	2020-08-30 06:24:14	2020-08-30	Pryor Steuber	pryor.steuber@geemail.com	Chicago	Illinois	4953548459734773	519df5993f385d5839e52a439c2751bf	Voyager	41.7986780154820536	-87.623803800859676
48847	2020-08-30 06:27:56	2020-08-30	Ms. Juli Lemke	ms.juli.lemke@geemail.com	Lakewood	Colorado	3038823577515460	af307c844e2e1d41fdfd73f02ab531a4	JCB 15 digit	39.7985617691591429	-105.197670298071941
48848	2020-08-30 06:33:51	2020-08-30	Lessie Stokes	lessie.stokes@geemail.com	Baton Rouge	Louisiana	3012776977450744	c3f693188a64d5200cd52ffb6bb6baa0	Discover	30.3462650514420105	-91.1852703433591785
48849	2020-08-30 06:44:59	2020-08-30	Rube Windler	rube.windler@geemail.com	Phoenix	Arizona	3528310600806217693	836b757e30186ca2f702f95c98b637bb	VISA 13 digit	33.6383596569698327	-112.12558358390109
48850	2020-08-30 06:46:37	2020-08-30	Hildred Kunze	hildred.kunze@geemail.com	Charlotte	North Carolina	54159639796072977	a5507272567e72c90aaee065f333023b	Diners Club / Carte Blanche	35.1936128851745238	-80.79551632655226
48851	2020-08-30 06:46:43	2020-08-30	Dr. Katy Smith DVM	dr.katy.smith.dvm@geemail.com	Oklahoma City	Oklahoma	6011755945382561440	c13ed62626bd8b70342e1c27d0c062b8	JCB 15 digit	35.540049449578305	-97.4407644479431241
48852	2020-08-30 06:51:40	2020-08-30	Vic Rohan	vic.rohan@woohoo.com	Fort Lauderdale	Florida	3337722959975817622	8d7972517db0b3edd835ccc29b111847	VISA 16 digit	26.2173471754405654	-80.1054959835305738
48853	2020-08-30 06:53:28	2020-08-30	Dr. Kanesha Rolfson DDS	dr.kanesha.rolfson.dds@geemail.com	Chicago	Illinois	3454126978916714	d1a3943403b4a970d640030eaf08a3d2	Diners Club / Carte Blanche	41.904776989465951	-87.64387779478281
48854	2020-08-30 06:57:50	2020-08-30	Lott Howe	lott.howe@geemail.com	Anaheim	California	6011483258383377322	04018354aacdf84d67481533e863dc14	Diners Club / Carte Blanche	33.846615839686244	-117.803288241263843
48855	2020-08-30 07:04:47	2020-08-30	Jeannette Kunze MD	jeannette.kunze.md@geemail.com	Tucson	Arizona	4362333170420290	bdc15d9397c6eca1e86e298824dea47e	Maestro	32.1950239401817342	-110.873251889948165
48856	2020-08-30 07:08:48	2020-08-30	Mrs. Madaline Bruen DVM	mrs.madaline.bruen.dvm@geemail.com	San Jose	California	6011828401122468515	1186f7ed4a7c6194949da8d8980015c6	Maestro	37.2340237465973942	-121.863321172281729
48857	2020-08-30 07:12:04	2020-08-30	Mrs. Bernice Dickinson PhD	mrs.bernice.dickinson.phd@geemail.com	High Point	North Carolina	52943579549761438	49a671257e9539eeeef5c3bc74b9847d	American Express	35.9472272378020037	-80.0850437699556323
48858	2020-08-30 07:15:03	2020-08-30	Latoyia Gerhold DDS	latoyia.gerhold.dds@geemail.com	New York	New York	4684051259738	a70408555e2da98867057243b4e954c6	JCB 16 digit	40.6403102613743386	-73.9711450112413615
48859	2020-08-30 07:21:20	2020-08-30	Sharonda Little	sharonda.little@geemail.com	New York	New York	4686020058410084	c7f4a060959a06b4363b036ee69d170d	Maestro	40.7623672485575099	-74.0251732893649432
48860	2020-08-30 07:33:44	2020-08-30	Kiana Kshlerin	kiana.kshlerin@geemail.com	Allentown	Pennsylvania	180040128086102879	c355cd94a0a5e95dda0a54bfb0668a2a	JCB 16 digit	40.5387782024931198	-75.4827507811613287
48861	2020-08-30 07:37:00	2020-08-30	Norton Schumm II	norton.schumm.ii@geemail.com	San Francisco	California	51257402080269127	ad1b3214a7e98f625862a5710fd4dbf1	Maestro	37.7846554315647012	-122.421209024783494
48862	2020-08-30 07:38:30	2020-08-30	Miss Cristi Yundt MD	miss.cristi.yundt.md@geemail.com	Santa Clarita	California	4815258649377933	e684d9271a732b84ae75786b6886d715	American Express	34.4944110659155996	-118.421834801054374
48863	2020-08-30 07:38:47	2020-08-30	Dema Medhurst	dema.medhurst@geemail.com	Chicago	Illinois	54662668616950906	4b568c849b1fcc8eae40eb9a18552b39	Maestro	41.8113355155404705	-87.730112147753303
48864	2020-08-30 08:04:00	2020-08-30	Kandy Wiegand-Nicolas	kandy.wiegand.nicolas@geemail.com	Boston	Massachusetts	4280854485438734	09874ce72efc7e63fca6ccd3cec836db	JCB 16 digit	42.291472309798003	-71.0068283316165179
48865	2020-08-30 08:04:54	2020-08-30	Ginny Leffler	ginny.leffler@warmmail.com	Joliet	Illinois	4068620874200490	af877fd1f847b6b9567f8adbae4ef830	Diners Club / Carte Blanche	41.4695748447298982	-88.1112657445121528
48866	2020-08-30 08:10:53	2020-08-30	Salvador Fahey	salvador.fahey@geemail.com	Raleigh	North Carolina	4009656436431571	44f20a0311f3affb2be336e26898d1ba	American Express	35.7360288902785612	-78.5679141682975057
48867	2020-08-30 08:25:55	2020-08-30	Linette Nicolas	linette.nicolas@geemail.com	Phoenix	Arizona	3096022849558043927	302f39c5560214a14dddd359dba00832	JCB 16 digit	33.4853413885392257	-112.021927738508595
48868	2020-08-30 08:28:14	2020-08-30	Pearl Huel	pearl.huel@geemail.com	Chicago	Illinois	4236834038063663	44e3c5519339ad527469a66fa9056ae3	JCB 16 digit	41.927174244339021	-87.7004775890644623
48869	2020-08-30 08:29:49	2020-08-30	Miner Streich	miner.streich@geemail.com	Waco	Texas	51471908379802956	9db7e608d8ad034f2c3122c0ba21cadb	Discover	31.5783270566467174	-97.2723683099858505
48870	2020-08-30 08:32:28	2020-08-30	Albina Murazik	albina.murazik@warmmail.com	Boston	Massachusetts	3112520208843230830	b72cb902835568ac2f2b9d517d85b322	JCB 15 digit	42.3946509806606926	-71.1001637090414818
48871	2020-08-30 08:46:43	2020-08-30	Gabriela Ortiz	gabriela.ortiz@geemail.com	San Jose	California	3088026510767379926	020e1ebc955f49776640de93cd7cde25	JCB 16 digit	37.3488848211530637	-121.873991080907729
48872	2020-08-30 08:55:14	2020-08-30	Ms. Rosalyn Durgan MD	ms.rosalyn.durgan.md@geemail.com	San Francisco	California	6011682634491892494	7ea0bba6d9f1fa33956f4da5d391726b	Discover	37.8005151766269094	-122.436581629617251
48873	2020-08-30 08:56:36	2020-08-30	Lurena Sanford DDS	lurena.sanford.dds@woohoo.com	Vancouver	Washington	4255784674389722	f59d59bbbce7e9a9ee2698d7045a10e5	Maestro	45.6131169184181857	-122.555641972931838
48874	2020-08-30 09:04:01	2020-08-30	Anissa Hermiston	anissa.hermiston@geemail.com	Las Vegas	Nevada	4659992614563	4eba84bca5249d4f8c5afd1d3be5ab13	JCB 16 digit	36.1323368922442185	-115.179375932759044
48875	2020-08-30 09:17:03	2020-08-30	Dr. Dino Schroeder	dr.dino.schroeder@geemail.com	Scottsdale	Arizona	4237321619090850	baf5522c38674920e5e352587b9ce61d	VISA 13 digit	33.6959248985752495	-111.891050116807591
48876	2020-08-30 09:24:57	2020-08-30	Gary Olson V	gary.olson.v@geemail.com	Austin	Texas	3158327612336465610	92dad4d6e3f99e9d3a1fc7d77d33b3a8	VISA 13 digit	30.2669157554987791	-97.8112867487367339
48877	2020-08-30 09:35:45	2020-08-30	Isidro Krajcik PhD	isidro.krajcik.phd@warmmail.com	Aurora	Colorado	502049107393792	670e58fc3b2c1183a2a2cfd0b97a0b50	JCB 16 digit	39.779563203092664	-104.684297598444672
48878	2020-08-30 09:44:21	2020-08-30	Dr. Reyna Heathcote	dr.reyna.heathcote@geemail.com	Phoenix	Arizona	869921942332319290	704b315730239d9b9855c95d0732a3da	VISA 16 digit	33.4916172820542002	-112.136985221917186
48879	2020-08-30 09:48:35	2020-08-30	Gilbert Hickle	gilbert.hickle@warmmail.com	Columbus	Ohio	6011053770526918465	6ac9a0e519452511a4d48b1ec28a73ba	JCB 16 digit	39.9892684812702228	-82.9341651115801284
48880	2020-08-30 09:48:54	2020-08-30	Brianna Dickinson-Greenholt	brianna.dickinson.greenholt@warmmail.com	Anchorage	Alaska	4602868096780889	9669aa91440a2f275d6065e5375a4e24	VISA 16 digit	61.2645527958620377	-149.357645205280932
48881	2020-08-30 10:02:12	2020-08-30	Judyth Wiza	judyth.wiza@geemail.com	San Francisco	California	180062410453989374	8d807ff31b5b3a0da728f9cadcd7efca	Maestro	37.7658445466700456	-122.440454032377701
48882	2020-08-30 10:02:43	2020-08-30	Dr. Arline Senger MD	dr.arline.senger.md@geemail.com	Philadelphia	Pennsylvania	180044131819966061	7b8a477d4a9f07bdb8dc614acb16a280	VISA 16 digit	40.017938437262174	-75.1012036890156622
48883	2020-08-30 10:06:07	2020-08-30	Mr. Jiles Brekke	mr.jiles.brekke@woohoo.com	Charlotte	North Carolina	869914589668949056	ff3abd21469408cf0eaacd758338bcbb	American Express	35.1895709704395401	-80.8448988432940183
48884	2020-08-30 10:09:17	2020-08-30	Joella Krajcik	joella.krajcik@warmmail.com	Sugar Land	Texas	4314639403725456	83c59993018905cda8402b74db77e849	Discover	29.6092435252904878	-95.5372958230793472
48885	2020-08-30 10:11:51	2020-08-30	Mrs. Fleta Walter DVM	mrs.fleta.walter.dvm@geemail.com	Macon	Georgia	4503829706067745	60a89fe12c6bce5062bc6c146c037a56	VISA 13 digit	32.7278712422598161	-83.7393331577729327
48886	2020-08-30 10:19:45	2020-08-30	Cal Ward-O'Connell	cal.ward.o'connell@geemail.com	Boise	Idaho	3112091964223027381	65b72b53258c2c105af8056472fcaefc	Diners Club / Carte Blanche	43.5509555388379823	-116.315573706869785
48887	2020-08-30 10:28:46	2020-08-30	Dr. Lyric Heller DVM	dr.lyric.heller.dvm@woohoo.com	San Francisco	California	3005755518353341	43c42f6f774aa47160253060cc6bc08a	Voyager	37.7720099005405459	-122.390163659549344
48888	2020-08-30 10:30:31	2020-08-30	Dr. Alfonso Gaylord	dr.alfonso.gaylord@geemail.com	Los Angeles	California	6011502841900538281	b20305478610fb310e3e3cb45f0ce20a	VISA 13 digit	33.9344906279683087	-118.472085686772317
48889	2020-08-30 10:58:00	2020-08-30	Dr. Jaleel Adams	dr.jaleel.adams@geemail.com	Berkeley	California	4966019317418095	a0a0b0a1fb8322f68225590c0d0e847e	Voyager	37.8918741714595768	-122.284058978672618
48890	2020-08-30 10:59:38	2020-08-30	Marlie Kuhic	marlie.kuhic@geemail.com	Los Angeles	California	3031365115857571	254716586831dd27c5061095b3763767	VISA 13 digit	34.1078105520788526	-118.467186338733129
48891	2020-08-30 11:00:51	2020-08-30	Mammie Halvorson DVM	mammie.halvorson.dvm@geemail.com	St. Louis	Missouri	3733131402222818	a8bbe9d7407568aa57ed452635a3d507	Discover	38.6085488583117709	-90.1847999317575244
48892	2020-08-30 11:01:53	2020-08-30	Leland Spencer	leland.spencer@woohoo.com	Clearwater	Florida	3528417141769881904	e7876d46eb15376193a718e79af7422c	JCB 15 digit	28.0005162198223161	-82.8401387404449281
48893	2020-08-30 11:17:42	2020-08-30	Freda Hermiston DDS	freda.hermiston.dds@warmmail.com	Bridgeport	Connecticut	3158691810973147867	370955fef1dadc47b2287bf5d0bb356e	Voyager	41.211109831340238	-73.1651669993896121
48894	2020-08-30 11:20:33	2020-08-30	Eleonore Little-Hintz	eleonore.little.hintz@warmmail.com	New York	New York	4775418188881	0f2ec7d242e5f23b4f9f02929d7d2d26	Diners Club / Carte Blanche	40.7277043743748237	-73.8999707158550621
48895	2020-08-30 11:21:07	2020-08-30	Eldred Kessler	eldred.kessler@warmmail.com	Fremont	California	869949245369426691	2dea5f2258b3cebfe37bb3d951c3aebe	Discover	37.5724564406257144	-121.890802522933853
48896	2020-08-30 11:27:53	2020-08-30	Authur Doyle	authur.doyle@warmmail.com	Wichita Falls	Texas	4816429805244	045d7feef3ebc5ed994233b605d814ec	JCB 16 digit	33.863982941602174	-98.600796031524979
48897	2020-08-30 11:41:45	2020-08-30	Tori Barton	tori.barton@geemail.com	San Francisco	California	3337137660170207267	4ca3e87a11a74cc0b3cf5dea6344a7e2	VISA 13 digit	37.7796484674574771	-122.408857767424394
48898	2020-08-30 11:46:24	2020-08-30	Ardelle Baumbach	ardelle.baumbach@geemail.com	New Orleans	Louisiana	4921519727991	17cb7ab8900b95d42234ce024cde8886	Mastercard	29.9538797545261666	-90.0076613203417537
48899	2020-08-30 11:53:05	2020-08-30	Jasen D'Amore I	jasen.d'amore.i@geemail.com	Lubbock	Texas	6011461181435968433	d731f6b94270bae33689f6d73e68c18a	Maestro	33.5955190318211976	-101.850836338094254
48900	2020-08-30 12:07:48	2020-08-30	Vinson Thiel	vinson.thiel@woohoo.com	Berkeley	California	3337354186462749747	fe18f684bd83c210a166f135b6503382	VISA 13 digit	37.8573571959664719	-122.271335325007556
48901	2020-08-30 12:12:11	2020-08-30	Germaine Raynor DVM	germaine.raynor.dvm@warmmail.com	Portland	Oregon	3528408700297359153	e70a1c75a56c64aae20b8192035cf2ab	Diners Club / Carte Blanche	45.5646299261022349	-122.746107499441138
48902	2020-08-30 12:12:34	2020-08-30	Doloris Schowalter-Zboncak	doloris.schowalter.zboncak@geemail.com	San Diego	California	3779725054178452	f8c0615bbeca37eb4f9525e4c2046b99	VISA 13 digit	32.7376220793064689	-117.084840111844244
48903	2020-08-30 12:30:38	2020-08-30	Jeffrey Romaguera	jeffrey.romaguera@warmmail.com	Tulsa	Oklahoma	52709554698922986	dc05b522cf3a9d71d045a5a86fb4a9f7	Voyager	36.0362411057945309	-95.9654503747776175
48904	2020-08-30 12:35:00	2020-08-30	Charles Hessel-Murphy	charles.hessel.murphy@geemail.com	Chandler	Arizona	3088579688215474183	e4164bd1ce79ed2e0cf24ba494f16674	JCB 16 digit	33.3131990379277596	-111.767473173269636
48905	2020-08-30 12:37:23	2020-08-30	Kaylan Wolff	kaylan.wolff@geemail.com	Berkeley	California	3766611589943526	f1fd89fb04c2566af0c0d6c7a00f988f	American Express	37.8613983389473105	-122.274954283790862
48906	2020-08-30 12:38:58	2020-08-30	Price Harvey-Krajcik	price.harvey.krajcik@woohoo.com	Jersey City	New Jersey	869999350093221357	92642db77d1dc7977ef0babda3ff110a	VISA 16 digit	40.7785338942367588	-74.1085774215359265
48907	2020-08-30 12:40:07	2020-08-30	Jadyn Heidenreich	jadyn.heidenreich@geemail.com	Atlanta	Georgia	3088882176000105396	e960098527dab9fd61277bc5d370048a	JCB 15 digit	33.720642717163642	-84.4684198121119323
48908	2020-08-30 12:55:15	2020-08-30	Sherryl Kutch	sherryl.kutch@warmmail.com	Oklahoma City	Oklahoma	4857591031617907	8e666524f640da5ad7077640e841ba38	Discover	35.4491553451310892	-97.5521931925684243
48909	2020-08-30 13:01:03	2020-08-30	Shonna Haag	shonna.haag@woohoo.com	Grand Prairie	Texas	4373182202052	d6699cd61edd9ffb678d78a0870cc62d	Mastercard	32.7614639465283588	-96.9658408610023628
48910	2020-08-30 13:03:28	2020-08-30	Caiden Bins	caiden.bins@geemail.com	Reno	Nevada	180070768290147633	2ea6b4b6d4be6dad8de30168e54107d3	VISA 13 digit	39.5645115147888689	-119.842654900362348
48911	2020-08-30 13:05:17	2020-08-30	Lemuel Grady	lemuel.grady@geemail.com	Saint Paul	Minnesota	210076421168219597	5d0c70f2d90ae2876a01d6a7a4824e2d	JCB 16 digit	44.9005746833920512	-93.1075652988892131
48912	2020-08-30 13:09:18	2020-08-30	Ibrahim Schulist II	ibrahim.schulist.ii@geemail.com	Tampa	Florida	3013097565113092	6d246daefa5cb08e538e1adc31ad0767	Maestro	28.0283191458903254	-82.4408850003711819
48913	2020-08-30 13:16:51	2020-08-30	Reno Schamberger	reno.schamberger@geemail.com	Chicago	Illinois	3158033216440207515	45bc3dcf67c9273ab5e6ddf312301f5e	JCB 16 digit	41.8235847491141399	-87.6065132939752118
48914	2020-08-30 13:25:27	2020-08-30	Cristal Connelly	cristal.connelly@woohoo.com	Baltimore	Maryland	51960304458222035	f172b2a0218a7e435ac4bc462023b8a5	Discover	39.3921213326510014	-76.618394786400728
48915	2020-08-30 13:31:33	2020-08-30	Aidan Hansen	aidan.hansen@geemail.com	Santa Maria	California	4813460358304270	96449a6bb68b9f93e4e7be466f5f1ec7	American Express	35.0290716974593721	-120.363663016810264
48916	2020-08-30 13:33:57	2020-08-30	Shawanda Windler-O'Conner	shawanda.windler.o'conner@geemail.com	Saint Paul	Minnesota	869961867425014097	54ac021e627b78932c3cc025e4ac4f4c	JCB 15 digit	44.940288526977973	-93.1408067448329149
48917	2020-08-30 13:35:44	2020-08-30	Curtiss Ernser	curtiss.ernser@geemail.com	Oakland	California	4975387977245	23333e50eaf222f2c7282ac5b8d7de2f	American Express	37.8275029709931232	-122.27310932431449
48918	2020-08-30 13:41:33	2020-08-30	Alfonse Ullrich-Rath	alfonse.ullrich.rath@geemail.com	Anchorage	Alaska	51527918871684376	bf1d00d312600d10b031a7ff2d605817	Mastercard	61.1190680696379403	-149.192890153791012
48919	2020-08-30 13:42:04	2020-08-30	Porter Krajcik-Prohaska	porter.krajcik.prohaska@geemail.com	Washington	District of Columbia	3112932948032777727	16fa0eda49156f507f6ca4a04b3e1e6f	Maestro	38.8575960523713348	-77.1168309530455645
48920	2020-08-30 13:42:41	2020-08-30	Beckham Botsford	beckham.botsford@geemail.com	Rancho Cucamonga	California	4266980716967056	c09053d8bfdfd6a20e7d32e34530261f	JCB 15 digit	34.200898522929478	-117.621066961438203
48921	2020-08-30 13:57:22	2020-08-30	Dr. Janel Boyle	dr.janel.boyle@geemail.com	Provo	Utah	52193693879289659	e2f499c0a185caac067bcde9a4d585bb	JCB 16 digit	40.2289003051605079	-111.57405684181974
48922	2020-08-30 14:00:29	2020-08-30	Madora McClure MD	madora.mcclure.md@woohoo.com	Plano	Texas	869990099595424170	16d2624d493fe5d1e330e35de8c8a5ed	Maestro	32.9822471921883533	-96.6888084771294132
48923	2020-08-30 14:01:24	2020-08-30	Dr. Ted Mitchell	dr.ted.mitchell@geemail.com	Atlanta	Georgia	4953513279525629	8726ab3286c4b14470a1ecef24477c6e	Voyager	33.7321784526385358	-84.4457180133134244
48924	2020-08-30 14:11:27	2020-08-30	Ilona Torphy DDS	ilona.torphy.dds@geemail.com	Newark	New Jersey	4794251115895889	29ebb6e4ea2a9123ad74fb960f127d93	Maestro	40.7948328941974836	-74.2672234194561867
48925	2020-08-30 14:13:07	2020-08-30	Ayden Abernathy-Cremin	ayden.abernathy.cremin@geemail.com	Waco	Texas	51330161810887449	31c4174dfa71e5931717724d64faa79a	Diners Club / Carte Blanche	31.5737506930459269	-97.1939538770951401
48926	2020-08-30 14:13:26	2020-08-30	Kaela Schoen	kaela.schoen@geemail.com	Killeen	Texas	4878710079439629	f12d4cef4ad7adbf0da5a49f7ccc4360	VISA 16 digit	31.1232762845464066	-97.7815537972543325
48927	2020-08-30 14:16:50	2020-08-30	Mr. Helmer Baumbach MD	mr.helmer.baumbach.md@geemail.com	Bellevue	Washington	501891805473377	efd2871fb85ba79b42cd8e65075f94d9	American Express	47.6532170845378218	-122.255158405849699
48928	2020-08-30 14:18:48	2020-08-30	Glendora Thiel DVM	glendora.thiel.dvm@warmmail.com	Philadelphia	Pennsylvania	180022541202727431	841aaada6cbb13e77f01423cf8c36c8b	Diners Club / Carte Blanche	39.9242957714438447	-75.1983812927167889
48929	2020-08-30 14:19:50	2020-08-30	Ms. Sharlene Fadel DVM	ms.sharlene.fadel.dvm@warmmail.com	Tempe	Arizona	3032611831863651	763fdf2dbe1aec6a2a4c9b46bd8ef453	Diners Club / Carte Blanche	33.3344359226912204	-111.85684442310891
48930	2020-08-30 14:21:26	2020-08-30	Louie Purdy	louie.purdy@geemail.com	Boston	Massachusetts	53540035937174723	a45f7d56be42e4673d8b665e63c0a631	JCB 15 digit	42.3166148711163572	-70.9491444359019425
48931	2020-08-30 14:22:20	2020-08-30	Mrs. Tilla Waters	mrs.tilla.waters@warmmail.com	San Francisco	California	3096744103081005368	3b12e0c2ff97bc42234f46731f7f1c4d	Discover	37.7594158813873264	-122.42155785998564
48932	2020-08-30 14:28:27	2020-08-30	Loda Balistreri	loda.balistreri@geemail.com	Augusta	Georgia	6011900567733315021	b6d543cff64257b6234001ef45f8b121	Voyager	33.4343578956760439	-82.1072552557863418
48933	2020-08-30 14:31:43	2020-08-30	Media Buckridge-Wintheiser	media.buckridge.wintheiser@geemail.com	Chicago	Illinois	3158370506610937276	8812c1c534c7f4064f6888e62a5d3051	Diners Club / Carte Blanche	41.7976271024275619	-87.7176592086937177
48934	2020-08-30 14:37:17	2020-08-30	Cody Skiles	cody.skiles@geemail.com	Los Angeles	California	561214958881220	bfe0209e8f84cbc6e7a166ea165b4f38	JCB 16 digit	34.1160185313183817	-118.366028617833919
48935	2020-08-30 14:38:21	2020-08-30	Felicitas Koepp-Wehner	felicitas.koepp.wehner@geemail.com	Austin	Texas	3785862436870449	e47fb20da118c8e05c3a58b429565e2f	Maestro	30.3735849436499166	-97.7289982150081613
48936	2020-08-30 14:53:50	2020-08-30	Nathaly Wisoky	nathaly.wisoky@geemail.com	Long Beach	California	210078054734957800	6a26edc3dd86349a6c0c58d794b231d4	Voyager	33.7575029217924865	-118.087474606947225
48937	2020-08-30 15:00:09	2020-08-30	Lindy Lindgren MD	lindy.lindgren.md@woohoo.com	Charlotte	North Carolina	3337891878547163981	c5b14639be3d9e307ad04681f47bcf48	VISA 13 digit	35.2525050381451805	-80.8796497394740612
48938	2020-08-30 15:02:50	2020-08-30	Erastus DuBuque	erastus.dubuque@warmmail.com	Anchorage	Alaska	6011130788321403712	74d82c0a6f477c31a9eb1b4e03b3c720	VISA 16 digit	61.2713357421785645	-149.223223899503438
48939	2020-08-30 15:04:04	2020-08-30	Mrs. Latonia Huel	mrs.latonia.huel@warmmail.com	Lafayette	Louisiana	3442285354992098	44d1da0f33b680d83d31ed7817542542	Discover	30.1288383330196154	-91.9702078618891505
48940	2020-08-30 15:05:45	2020-08-30	Dr. Bess Thompson	dr.bess.thompson@geemail.com	Berkeley	California	3490230930272327	b368bb182d87a32b20fb943983737e10	Mastercard	37.9096085572952362	-122.282398793722706
48941	2020-08-30 15:09:42	2020-08-30	Mr. Soren Klein PhD	mr.soren.klein.phd@woohoo.com	Scottsdale	Arizona	639039039326358	7f9a8c447d596620c119354d07fd0731	Voyager	33.5864036441437932	-111.951108626272898
48942	2020-08-30 15:11:10	2020-08-30	Moriah Vandervort	moriah.vandervort@geemail.com	Milwaukee	Wisconsin	3416165470488878	35ec5c22d2a8219b15941a5605573c7b	JCB 15 digit	43.0250960765957799	-88.058789019622651
48943	2020-08-30 15:13:30	2020-08-30	Ryan Dickinson	ryan.dickinson@geemail.com	Indianapolis	Indiana	210074189566021111	31c7e9cd1d205ceb6e4e687323aebd1e	Maestro	39.676755415928362	-86.0616855266705159
48944	2020-08-30 15:17:41	2020-08-30	Mr. Squire Stanton	mr.squire.stanton@warmmail.com	Boston	Massachusetts	6011434918406505163	b2091c8e94071af118589abfd2b7c024	VISA 16 digit	42.4178869008719914	-70.9372663445722367
48945	2020-08-30 15:34:32	2020-08-30	Shawnte Jones	shawnte.jones@warmmail.com	Charleston	South Carolina	6011495668348175171	b3a592e719f6c39e2237a04afc20f3f6	JCB 15 digit	32.8608168990813212	-79.932939086077738
48946	2020-08-30 15:35:40	2020-08-30	Ryne Jaskolski	ryne.jaskolski@geemail.com	San Diego	California	4614041699776	a502c7a3b59710e634ee3f7f6e46d488	Mastercard	32.8697993394985772	-117.165377862136822
48947	2020-08-30 15:51:04	2020-08-30	Rick Lang	rick.lang@geemail.com	Oakland	California	3036260117918585	f7a108fa3255d8c29ead75bc027206b5	VISA 16 digit	37.7888277351836948	-122.306088447981693
48948	2020-08-30 15:51:55	2020-08-30	Giovanny Hamill-Homenick	giovanny.hamill.homenick@geemail.com	Indianapolis	Indiana	51032451285584758	7f5616a63fe8e2ebf84a4889b71bbd9b	JCB 15 digit	39.7440843041527998	-86.1654535385981148
48949	2020-08-30 15:58:16	2020-08-30	Rayfield Armstrong	rayfield.armstrong@geemail.com	Lewisville	Texas	4023928834052	bf979245e5b7a7ef2354fbd4abea9468	Mastercard	32.9920755576327451	-97.0387480239879352
48950	2020-08-30 16:01:07	2020-08-30	Jarret Trantow MD	jarret.trantow.md@geemail.com	Boston	Massachusetts	6011261026354020249	3a277b999284f46f5cd039187f4d1bbb	Discover	42.4193005532659626	-70.9295973945360601
48951	2020-08-30 16:01:51	2020-08-30	Roswell Von	roswell.von@geemail.com	New York	New York	6011997497465631391	578923c9c5e354f6c6030bdb5f7fba3a	Mastercard	40.757006267154587	-73.9799196493707569
48952	2020-08-30 16:05:27	2020-08-30	Amelie Raynor-Hintz	amelie.raynor.hintz@geemail.com	Scottsdale	Arizona	3112471931398208104	e86a20ad1827f48909caf409250ce17d	Maestro	33.6830518004607384	-111.835552900560572
48953	2020-08-30 16:08:14	2020-08-30	Quincy Kautzer	quincy.kautzer@warmmail.com	Wichita	Kansas	3058888486954878	324be38b90af8842dd2aa35f3aa67da4	JCB 16 digit	37.7654208689339441	-97.4016912135962372
48954	2020-08-30 16:27:43	2020-08-30	Lanny Larson-Welch	lanny.larson.welch@warmmail.com	Sacramento	California	3049968696722106	01d08867368547d00e46719745f2e95e	VISA 13 digit	38.6132316359117667	-121.395559706004704
48955	2020-08-30 16:30:50	2020-08-30	Farah Gulgowski-Hansen	farah.gulgowski.hansen@geemail.com	Sacramento	California	55895044437846260	95148168f94016bee55939236bdc0f70	JCB 15 digit	38.583312683485822	-121.46776447615251
48956	2020-08-30 16:34:52	2020-08-30	Zackary Rogahn	zackary.rogahn@warmmail.com	Lakewood	Colorado	53255353658709527	77a04eb2644358b1a438dabea7584d40	VISA 16 digit	39.6910055132057522	-105.099209670305626
48957	2020-08-30 16:49:45	2020-08-30	Dr. Gerda Mosciski	dr.gerda.mosciski@geemail.com	Vista	California	3440348439794889	2c37042559e7e9eb2fc3287dfb1e5918	Discover	33.1260209707524638	-117.290545112412801
48958	2020-08-30 16:57:27	2020-08-30	Tomasa Beier-Purdy	tomasa.beier.purdy@geemail.com	Lubbock	Texas	869994696516027085	503886a6da2f617ce1928e146c5ae81c	Voyager	33.6573887742165496	-101.814087756342076
48959	2020-08-30 17:02:00	2020-08-30	Romie Sporer	romie.sporer@geemail.com	Pomona	California	4098676236494	7d41a8e6423833b9eef81c29976161b4	Mastercard	33.9630257997233471	-117.671747327685722
48960	2020-08-30 17:04:26	2020-08-30	Zion Dietrich	zion.dietrich@warmmail.com	Jacksonville	Florida	503818065806970	35719a63b4871d00cf3e34bb39e20d9c	JCB 15 digit	30.3867189321719096	-81.7374880692999852
48961	2020-08-30 17:07:07	2020-08-30	Logan Konopelski	logan.konopelski@warmmail.com	Gainesville	Florida	3088750243831814445	8139ccc3eb2d26b9317ab83c47986a8c	JCB 16 digit	29.7225627711798985	-82.2878827429249924
48962	2020-08-30 17:11:41	2020-08-30	Dorinda Hackett	dorinda.hackett@geemail.com	San Francisco	California	676391959781922	2a0735e78f4cb7a63ce08bbbd06403c5	VISA 16 digit	37.7849055302213799	-122.439494031294501
48963	2020-08-30 17:21:50	2020-08-30	Madden Crist	madden.crist@warmmail.com	San Diego	California	3096260611761407674	f88df431a222d380e651b9d3756267dc	VISA 13 digit	32.8011437580522127	-117.085245816726243
48964	2020-08-30 17:36:58	2020-08-30	Ms. Hildur Ernser	ms.hildur.ernser@geemail.com	Chesapeake	Virginia	6011090778940066543	7b552c694fcafd7b8a2a3f4ed4c89c37	JCB 16 digit	36.5825493606045882	-76.2504844371538582
48965	2020-08-30 17:37:06	2020-08-30	Annis O'Reilly	annis.o'reilly@warmmail.com	Omaha	Nebraska	4386123487485264	e2967e0049ff7653472dfc0b1a06cb53	VISA 16 digit	41.2166031389176837	-95.9931760416016004
48966	2020-08-30 17:45:03	2020-08-30	Cole Renner	cole.renner@geemail.com	San Jose	California	3784528343351333	7025bcad348f31c1c332bf53fc1be710	Discover	37.3442589458830696	-121.783407665531712
48967	2020-08-30 17:46:33	2020-08-30	Jaimie Reichel	jaimie.reichel@warmmail.com	San Francisco	California	180046872908701202	4e0f43e6d7e45fcffa7a2ea6106c4095	VISA 13 digit	37.7557846726036317	-122.425518637699639
48968	2020-08-30 17:46:49	2020-08-30	Birtha Mayert	birtha.mayert@geemail.com	San Francisco	California	53933305214261617	13d911df7ec3aa64beaa9e8ac8db1a0e	American Express	37.7663659066511386	-122.425816072400252
48969	2020-08-30 17:49:08	2020-08-30	Dorris Ernser Jr.	dorris.ernser.jr.@warmmail.com	Colorado Springs	Colorado	4368678802795	3117988eaf26f01b27dc737512804f58	Diners Club / Carte Blanche	38.8124226560398924	-104.811666923916718
48970	2020-08-30 17:54:47	2020-08-30	Miss Teri Blanda PhD	miss.teri.blanda.phd@geemail.com	Philadelphia	Pennsylvania	4628826372498543	0bbf2c3dd8315f2b8b54ef1640c83408	Mastercard	40.0556601268198307	-75.1952438298512362
48971	2020-08-30 17:55:59	2020-08-30	Mr. John Baumbach III	mr.john.baumbach.iii@geemail.com	Berkeley	California	4406142286191499	6adf59789d1542cb987a494cf0135b2f	JCB 16 digit	37.8922437767824576	-122.244964333607896
48972	2020-08-30 18:04:45	2020-08-30	Mr. Thad Bechtelar DDS	mr.thad.bechtelar.dds@geemail.com	Hayward	California	3445633965856243	9f231b6795337c4527c300e1c6c998f7	JCB 15 digit	37.5863868594158461	-122.165782425205791
48973	2020-08-30 18:10:48	2020-08-30	Ms. Blanca Adams DDS	ms.blanca.adams.dds@geemail.com	Chesapeake	Virginia	869948419924396134	173eb46961d7e32a974af4b6bb10df1f	Mastercard	36.757655651285873	-76.362184075436744
48974	2020-08-30 18:11:52	2020-08-30	Mr. Gussie Nienow DDS	mr.gussie.nienow.dds@geemail.com	Elgin	Illinois	3743141178554037	072c989a95e1e80f0992d6bda78caaab	American Express	41.9775313387908042	-88.4169400069683888
48975	2020-08-30 18:24:06	2020-08-30	Sina Brekke-Simonis	sina.brekke.simonis@geemail.com	San Francisco	California	3158174694236676821	03043e3d7f82d8dea0e73850b3c9db87	JCB 16 digit	37.7861704699228866	-122.425613701230574
48976	2020-08-30 18:24:33	2020-08-30	Willard Williamson II	willard.williamson.ii@woohoo.com	San Francisco	California	180034581936215291	8bbd8a45ca9590565f09b8049e808eaf	VISA 16 digit	37.7614733368189022	-122.40448881095773
48977	2020-08-30 18:25:10	2020-08-30	Clarance Klocko	clarance.klocko@geemail.com	Simi Valley	California	4494377292176299	96bd8b455c02252e5d660d7ca108a873	Voyager	34.2464532889198523	-118.834196272365759
48978	2020-08-30 18:49:42	2020-08-30	Torrence Hintz	torrence.hintz@woohoo.com	San Francisco	California	210010473643917542	055cf78b81c66d1ad1cd3548599a8c55	Discover	37.7556248429442718	-122.432807291802661
48979	2020-08-30 18:53:55	2020-08-30	Pink Orn	pink.orn@geemail.com	Macon	Georgia	3703396737952043	b6c54430e65352e1e9ada9571fc3d4ad	JCB 16 digit	32.812376157428325	-83.7293066775619934
48980	2020-08-30 19:04:01	2020-08-30	Craig Rohan PhD	craig.rohan.phd@geemail.com	Phoenix	Arizona	676128344701678	5644d77ffc2ef01c9f503502511afc4e	Discover	33.4900691001609019	-112.008459615653763
48981	2020-08-30 19:04:55	2020-08-30	Imogene Kuhlman PhD	imogene.kuhlman.phd@geemail.com	Berkeley	California	180073636802795438	903e60400a44f85764ebf1441ccd8cd5	American Express	37.8785679852834747	-122.258031948639825
48982	2020-08-30 19:13:04	2020-08-30	Austyn Koss-Nader	austyn.koss.nader@geemail.com	South Bend	Indiana	51076981946351442	0d9de602de8901cb55e267acdf70e716	Mastercard	41.7113237027689863	-86.2022307717762999
48983	2020-08-30 19:26:05	2020-08-30	Ferman Goldner	ferman.goldner@geemail.com	Oklahoma City	Oklahoma	3056131030390956	4b5262e0227888a99db668a70fc7290b	VISA 16 digit	35.445743437940628	-97.4369677790336368
48984	2020-08-30 19:30:02	2020-08-30	Murphy Kuhic IV	murphy.kuhic.iv@geemail.com	Houston	Texas	6011368059282025412	514108ea34025a54920153d80c4248f3	Diners Club / Carte Blanche	29.7013897253278643	-95.3157705739155432
48985	2020-08-30 19:31:02	2020-08-30	Aleck Lang-Reinger	aleck.lang.reinger@geemail.com	New York	New York	4256255952936459	f27bd740fcbdfeed4bbd0085d06c5082	JCB 16 digit	40.6664172524344139	-73.9612559832528262
48986	2020-08-30 19:35:08	2020-08-30	Domenic Keebler	domenic.keebler@warmmail.com	Charlotte	North Carolina	4856604257290	60bd8d569fec48d9336073e182866c93	Maestro	35.1434198220513778	-80.8099517177268893
48987	2020-08-30 19:40:48	2020-08-30	Ewing Bailey IV	ewing.bailey.iv@geemail.com	Jacksonville	Florida	503821073788354	bcc19399fb49fe0815a87328af6f434c	American Express	30.3626446855306611	-81.6328529389653426
48988	2020-08-30 19:42:28	2020-08-30	Ahmed Wiza	ahmed.wiza@geemail.com	Rancho Cucamonga	California	210073417586295865	58aac4642b6baa75385a987384a5ad2c	Mastercard	34.2208363919511456	-117.634616458975529
48989	2020-08-30 19:56:04	2020-08-30	Keven Senger-Wiegand	keven.senger.wiegand@geemail.com	Garden Grove	California	3025311322624913	762b7e67b5a50f98ba299dcc2cfcdf72	Discover	33.7062555849842695	-117.962156314916911
48990	2020-08-30 19:58:30	2020-08-30	Mr. Eben Kshlerin	mr.eben.kshlerin@geemail.com	Newark	New Jersey	869913510941500186	a260f956659450f68f8fce21435f4e84	VISA 16 digit	40.8082805390849757	-74.1100324473552377
48991	2020-08-30 19:59:12	2020-08-30	Rutherford Klein	rutherford.klein@warmmail.com	Tyler	Texas	3158186369395926517	368d107d04700f4dd82b97b7ac10cccc	JCB 15 digit	32.2375479474246518	-95.2260247657649188
48992	2020-08-30 20:02:48	2020-08-30	Stewart Krajcik	stewart.krajcik@warmmail.com	Orlando	Florida	3051788152025093	892d0aa42e4826e296f0fe8cd1c51ffb	American Express	28.4092419809926291	-81.296167738778891
48993	2020-08-30 20:03:10	2020-08-30	Damion Waters	damion.waters@warmmail.com	Durham	North Carolina	869920891076566122	2a3ecc04809f0778f0845c7f6e99fb36	VISA 16 digit	35.9844283576834911	-78.9464809427406635
48994	2020-08-30 20:03:40	2020-08-30	Esmeralda Raynor	esmeralda.raynor@geemail.com	Amarillo	Texas	4453084074138	b328eebb6cacaa94f2d6902222243916	Diners Club / Carte Blanche	35.2134420219972739	-101.785627894135942
48995	2020-08-30 20:05:39	2020-08-30	Jaheem Nader	jaheem.nader@geemail.com	New York	New York	4568533776767	a3fd2f1c28ee2befdb1c0b342c714f70	American Express	40.6368729600906349	-73.9636841725919396
48996	2020-08-30 20:12:24	2020-08-30	Ova Marquardt	ova.marquardt@geemail.com	San Diego	California	4838356131938759	94cf1f7c0e94426a2b75be2b2c68208f	JCB 16 digit	32.8404615402288727	-117.213455168521037
48997	2020-08-30 20:14:22	2020-08-30	Daquan Casper Sr.	daquan.casper.sr.@geemail.com	Odessa	Texas	3112445240994021686	3b2c2d42eb2e2d8f6900c56780be55fe	Maestro	31.874674249907212	-102.333060917785758
48998	2020-08-30 20:16:01	2020-08-30	Janie Kling	janie.kling@geemail.com	Charlotte	North Carolina	52781416437708517	ce5fb07e5c0a13fc5cbd7796c13bd8d1	Discover	35.1615322137970452	-80.7530131297595801
48999	2020-08-30 20:16:33	2020-08-30	Fredric Ernser	fredric.ernser@geemail.com	Elgin	Illinois	3158717089408579958	e1f0564b1ff9bd28d0e000e12b69b86d	Mastercard	42.0248562082000063	-88.4095172476310296
49000	2020-08-30 20:24:03	2020-08-30	Ephram Cummerata V	ephram.cummerata.v@geemail.com	Miami	Florida	3337818917309613237	3586f180cb8bbb063fe975c8c18b24e8	JCB 16 digit	25.7832364159774059	-80.1764341171704302
49001	2020-08-30 20:29:41	2020-08-30	Kristal Morissette	kristal.morissette@woohoo.com	San Francisco	California	6011132148019387602	ce583f88291fd95c6d626d2740ac3dc2	Mastercard	37.7953543436348056	-122.440333920713158
49002	2020-08-30 20:30:00	2020-08-30	Ms. Makala Lesch PhD	ms.makala.lesch.phd@warmmail.com	San Francisco	California	869911520927205827	d0b60a9de39473dc1af06e5d957dcc07	JCB 16 digit	37.7775496196968703	-122.420955765205946
49003	2020-08-30 20:30:18	2020-08-30	Samie Reichert	samie.reichert@geemail.com	Colorado Springs	Colorado	6011492266257909277	92f9b5bf9bd85ddf27cbc59bfff0a320	VISA 16 digit	38.7734583537142754	-104.718533901839336
49004	2020-08-30 20:32:49	2020-08-30	Ms. Tabatha Wolf PhD	ms.tabatha.wolf.phd@geemail.com	Scottsdale	Arizona	561292728238590	fa697caf91a7f027ad7029693c911a1a	Voyager	33.735181568109617	-111.931400842961295
49005	2020-08-30 20:38:37	2020-08-30	Dr. Vander Jerde	dr.vander.jerde@geemail.com	Clearwater	Florida	54946984342702927	2ad96cbe4173f4833e3bd9e7613275e6	VISA 16 digit	27.9706208212893443	-82.6872960073672232
49006	2020-08-30 20:41:47	2020-08-30	Mr. Anibal Halvorson	mr.anibal.halvorson@geemail.com	Tempe	Arizona	180075862873030459	b255cfb10b3bdf4b7e54d4a4c375a54c	JCB 16 digit	33.4027356732092784	-111.870263185634457
49007	2020-08-30 20:41:54	2020-08-30	Dr. Dana Beahan MD	dr.dana.beahan.md@geemail.com	Lafayette	Louisiana	3021150415987256	8bcc2599b92746181fded49d82a92ca4	Maestro	30.2344086063072091	-92.1204598310720115
49008	2020-08-30 20:42:13	2020-08-30	Verla Bailey	verla.bailey@geemail.com	Los Angeles	California	180069204934404498	ad146d5aa723a08cb437a8aa272acf3d	JCB 15 digit	34.0425242476031187	-118.369175912718475
49009	2020-08-30 20:58:18	2020-08-30	Mr. Destin Abshire DDS	mr.destin.abshire.dds@geemail.com	Fremont	California	4342147997171	324cab9f83df0ce21d99b64152c11b2a	VISA 16 digit	37.5374537132382429	-121.845805936212457
49010	2020-08-30 21:02:59	2020-08-30	Karol Lowe-Rolfson	karol.lowe.rolfson@geemail.com	New York	New York	630404083109407	c216f2778c577064c86de8afe6ab827c	Voyager	40.7388509176429352	-73.8721156429860741
49011	2020-08-30 21:10:10	2020-08-30	Forrest Quitzon-Towne	forrest.quitzon.towne@geemail.com	Houston	Texas	3337585312295621553	a245651be523fd358e6216d5564564f0	American Express	29.8598650910504162	-95.4386827213239002
49012	2020-08-30 21:25:35	2020-08-30	Paulina Hermann-Bode	paulina.hermann.bode@geemail.com	Oakland	California	52925444970712792	31f22710b8362ab684b7dc833738a4f0	JCB 16 digit	37.8119231227647674	-122.245237794153041
49013	2020-08-30 21:29:58	2020-08-30	Mr. Keandre Wolf	mr.keandre.wolf@warmmail.com	Cincinnati	Ohio	3765424731336743	40cad1d47483f25d42a12c6504a2f7ae	Voyager	39.0581121692199247	-84.5332348957464035
49014	2020-08-30 21:31:22	2020-08-30	Marry Runolfsdottir	marry.runolfsdottir@geemail.com	Albuquerque	New Mexico	869951904645905119	9dd783623093f2e46d10b410ede41412	Discover	35.1743552034854901	-106.56767525319718
49015	2020-08-30 21:33:19	2020-08-30	Americo Watsica	americo.watsica@woohoo.com	San Francisco	California	3017035341599479	186d1a1650f2ee53850c279f8ea969ff	Maestro	37.7707808977642756	-122.429181747988054
49016	2020-08-30 21:38:01	2020-08-30	Miss Crysta Gerhold DDS	miss.crysta.gerhold.dds@woohoo.com	Cincinnati	Ohio	3777656814837032	7e09818a8269cd2e4592f93d74bc0933	Diners Club / Carte Blanche	39.1279927583642291	-84.4645720697745617
49017	2020-08-30 21:57:00	2020-08-30	Eleanor Stanton DVM	eleanor.stanton.dvm@woohoo.com	Los Angeles	California	55158345452456808	da33e0f6e6a0f79af30de22ce4d4a41f	VISA 13 digit	33.9329316536296162	-118.335811053169138
49018	2020-08-30 22:02:49	2020-08-30	Mr. Stone Walter	mr.stone.walter@woohoo.com	Tyler	Texas	3794989148697650	acaa5592b0580ce209ad29b436bd3f9c	JCB 15 digit	32.3403408508796275	-95.2442107537869305
49019	2020-08-30 22:05:20	2020-08-30	Pansy Wilderman	pansy.wilderman@geemail.com	Joliet	Illinois	3755993620411298	9e013207311d4a15076ab5b4d7e192cb	VISA 16 digit	41.5796092808570705	-88.0728234893281012
49020	2020-08-30 22:17:22	2020-08-30	Shauna Wisozk	shauna.wisozk@geemail.com	San Diego	California	3096375005993542147	a379e88a746ef8c6563999057d13ca46	JCB 16 digit	32.8912021049365393	-117.168892977843072
49021	2020-08-30 22:25:00	2020-08-30	Jaheim Lemke	jaheim.lemke@geemail.com	Concord	California	3112478775486824014	c60bcf0287cedadd203b653704906752	JCB 15 digit	37.8973432402990795	-121.983602929272124
49022	2020-08-30 22:29:39	2020-08-30	Bev Hand-Schmitt	bev.hand.schmitt@geemail.com	Las Cruces	New Mexico	6011791492518961356	3563ee37b70904afc67261ce4903c33b	Maestro	32.2361255996894087	-106.775317175698277
49023	2020-08-30 22:31:00	2020-08-30	Kenia Paucek PhD	kenia.paucek.phd@geemail.com	Nashville	Tennessee	210047770995639526	995e36c51332c281fb79df2adb60ac48	VISA 16 digit	36.2135009874712637	-86.7496981260739233
49024	2020-08-30 22:45:54	2020-08-30	Abel Roberts	abel.roberts@geemail.com	Oklahoma City	Oklahoma	53577124677891351	eb58e8b651ebe6a06d7ee6924b8d6327	Mastercard	35.4979508004993249	-97.5017803583189817
49025	2020-08-30 22:56:50	2020-08-30	Sydell Graham DDS	sydell.graham.dds@geemail.com	Tucson	Arizona	4297325962811	79167daede98cdce32de5f0a509e230e	American Express	32.1203660253476357	-110.900690188933538
49026	2020-08-30 22:59:57	2020-08-30	Caitlyn Schmidt MD	caitlyn.schmidt.md@geemail.com	Columbus	Ohio	3472467704667827	edb939b7bf449b21e90a9f43464717a7	VISA 16 digit	39.9067471761766797	-83.0041684280850092
49027	2020-08-30 23:03:33	2020-08-30	Kolten McDermott	kolten.mcdermott@geemail.com	Chicago	Illinois	639052997945366	96916e787ec78370c0b349e5e8bd7566	American Express	41.758170769626652	-87.6447591889213697
49028	2020-08-30 23:06:43	2020-08-30	Adele Kautzer	adele.kautzer@geemail.com	New York	New York	3761344553299270	6ffb203c8a99371708cff16b59ead71c	JCB 16 digit	40.5915541479587532	-73.9366672444052995
49029	2020-08-30 23:07:17	2020-08-30	Heber Ledner-Considine	heber.ledner.considine@geemail.com	San Francisco	California	3096826476963138551	90c0daeac6a1b83a0c7d3c0983aec044	VISA 13 digit	37.7536956113537912	-122.433593028893483
49030	2020-08-30 23:14:04	2020-08-30	Damian Altenwerth	damian.altenwerth@geemail.com	Philadelphia	Pennsylvania	51096918802794691	2fc0a7dcb217c622d0fb98115d6b0047	JCB 15 digit	39.9688952528364965	-75.0376708601035176
49031	2020-08-30 23:20:23	2020-08-30	Idabelle Ward	idabelle.ward@geemail.com	Los Angeles	California	3088076577335397184	5d5eec1ea6366f33b0f5d3356732ee59	VISA 16 digit	33.9352123954664862	-118.485025025158365
49032	2020-08-30 23:21:12	2020-08-30	Clint Collier	clint.collier@woohoo.com	Kansas City	Kansas	4451103146546102	d41c5da0ef2f22e6fa118bb30c87e164	VISA 16 digit	39.1797799987625339	-94.6656272115588138
49033	2020-08-30 23:24:20	2020-08-30	Kirt Oberbrunner	kirt.oberbrunner@geemail.com	Hollywood	Florida	3026914502566975	bcf60071cbee8f830003bba5d557a73c	American Express	25.9818807003498051	-80.1927670102383843
49034	2020-08-30 23:29:42	2020-08-30	Kieran Stokes	kieran.stokes@geemail.com	Colorado Springs	Colorado	4757676272462997	6ee2f7d69c1eecdc2697476e150a0eb2	Maestro	38.9016931693583743	-104.692485386009139
49035	2020-08-30 23:29:56	2020-08-30	Miss Estefania Collins	miss.estefania.collins@geemail.com	Vallejo	California	3096290414871927663	a7db889312aedf01cfe36b3432a216eb	JCB 16 digit	38.1464495309252314	-122.261247349843373
49036	2020-08-30 23:37:41	2020-08-30	Dr. Dakotah Rau PhD	dr.dakotah.rau.phd@warmmail.com	San Jose	California	3112339075516798901	2fcd3aa4df2d2a9ac30b3260a7f3bafb	JCB 15 digit	37.3507339689236133	-121.908291393586993
49037	2020-08-30 23:37:43	2020-08-30	Illya Moore I	illya.moore.i@geemail.com	Fresno	California	060476135481950	666a625b049ee8c42b565ad34ba3e0cd	VISA 13 digit	36.6953296961136175	-119.762070328473683
49038	2020-08-30 23:46:16	2020-08-30	Rennie Bechtelar	rennie.bechtelar@geemail.com	Warren	Michigan	4101230547977257	b2eb49166941ed59b46a6514a5964db0	Maestro	42.4523656369183229	-83.0744127083104189
49039	2020-08-30 23:54:02	2020-08-30	Octavie Dietrich	octavie.dietrich@woohoo.com	Fort Collins	Colorado	3096263585135849182	46d81c173a228dbeb11b36184587d121	Discover	40.6181250036850585	-105.118618930266436
49040	2020-08-31 00:06:54	2020-08-31	Rollin Green	rollin.green@geemail.com	Oakland	California	3007410913666529	502f2a574c8b94f94964f48b345f2465	Voyager	37.809233088898452	-122.262933434710646
49041	2020-08-31 00:15:05	2020-08-31	Trista Heller-Koepp	trista.heller.koepp@geemail.com	Berkeley	California	869934855615972905	9942db741ce6e6f4e7b5c1d26a359584	VISA 16 digit	37.8671892449234377	-122.264153189512498
49042	2020-08-31 00:22:36	2020-08-31	Stanley Rosenbaum	stanley.rosenbaum@warmmail.com	Louisville	Kentucky	869936096676181643	8d2db039ed56a99cb60a7bbeede127be	Discover	38.2394448113065195	-85.6332744777739094
49043	2020-08-31 00:22:39	2020-08-31	Jerry Beier	jerry.beier@warmmail.com	Houston	Texas	676278056961598	f3aa636fd563754b2e3cfdc3f1b0cf02	JCB 16 digit	29.7875756044019013	-95.3475537776961914
49044	2020-08-31 00:29:53	2020-08-31	Pearlene Mraz	pearlene.mraz@geemail.com	Fort Worth	Texas	4549319533268514	0d4226b073fa4958df7706f960ad70ee	JCB 15 digit	32.6845437493231188	-97.2829021199893162
49045	2020-08-31 00:29:58	2020-08-31	Broderick Schulist	broderick.schulist@geemail.com	Chattanooga	Tennessee	676339981061953	839d9db5629e284563b4bf162a325689	VISA 16 digit	34.9672231246568259	-85.159442585922406
49046	2020-08-31 00:30:19	2020-08-31	Halley Block	halley.block@warmmail.com	Brownsville	Texas	4308957015679996	4f21fd3b4ff10fc2b7d7f6c9912996bf	American Express	26.0300307562187285	-97.5521268147230103
49047	2020-08-31 00:32:51	2020-08-31	Hiroshi Upton	hiroshi.upton@geemail.com	Charlotte	North Carolina	4178664513312107	204ad41ec9badb9679e0157ff179fdfd	VISA 16 digit	35.1229693600695541	-80.825579540565613
49048	2020-08-31 00:47:00	2020-08-31	Kolten Wunsch	kolten.wunsch@geemail.com	Round Rock	Texas	6011383049925869491	f89ff17e9b073caef0d40f5e28ff9aef	Discover	30.5759572146132612	-97.6538538017626792
49049	2020-08-31 00:56:09	2020-08-31	Le Fritsch	le.fritsch@warmmail.com	Cincinnati	Ohio	869913257481822402	aa34c847a0593f9a27d1d5c5df22ee67	Voyager	39.1032556760821493	-84.5110131242584401
49050	2020-08-31 01:11:53	2020-08-31	Irven McDermott	irven.mcdermott@geemail.com	Denver	Colorado	3096135865210316729	8332668bba18bf8154e6bc020567d1fd	JCB 15 digit	39.7603583350829766	-104.852880123142526
49051	2020-08-31 01:16:01	2020-08-31	Ciara Schmidt	ciara.schmidt@woohoo.com	New York	New York	869921910524977654	ba04ac8827031095ef93b9237b87aebd	Voyager	40.7627258381098514	-74.0008455658227149
49052	2020-08-31 01:16:45	2020-08-31	Jaylon Krajcik	jaylon.krajcik@geemail.com	Louisville	Kentucky	503826287738749	89717fa35647a415ad428f066b0be66f	Discover	38.2198417418073859	-85.7369904018543707
49053	2020-08-31 01:17:14	2020-08-31	Ermine Macejkovic-Williamson	ermine.macejkovic.williamson@geemail.com	Coral Springs	Florida	4980960867094	4ae74a9da0b8fb23bcad21e497bd17e3	JCB 15 digit	26.1933294681895532	-80.301355880697443
49054	2020-08-31 01:34:16	2020-08-31	Mathilde Lemke-D'Amore	mathilde.lemke.d'amore@warmmail.com	Berkeley	California	4892043558623329	d0dda47cbe54be85895f4578603a6ad8	Voyager	37.8376752590330767	-122.276523078763418
49055	2020-08-31 01:43:18	2020-08-31	Dominga Harris	dominga.harris@geemail.com	Los Angeles	California	869955141464066733	5dd774f0c86503ed190732a651d34eb6	VISA 13 digit	34.0687776405230167	-118.342541290632624
49056	2020-08-31 01:46:11	2020-08-31	Dr. Lessie Rolfson	dr.lessie.rolfson@geemail.com	Houston	Texas	4791100873866736	767081bf4b2e1027edf99e14db586a7d	Maestro	29.7216882492028169	-95.4592781344909298
49057	2020-08-31 02:08:59	2020-08-31	Mr. Plummer Roberts	mr.plummer.roberts@warmmail.com	Berkeley	California	3096988703182250246	908e454818032fa232fbd58de8699b9a	Mastercard	37.8420161783441458	-122.27453511316331
49058	2020-08-31 02:09:17	2020-08-31	Pierce Lowe-Von	pierce.lowe.von@geemail.com	Clearwater	Florida	53780159863392072	0f82bf1d506f9d80338b72bc934a9778	Maestro	27.928113113542647	-82.7925290485177214
49059	2020-08-31 02:09:48	2020-08-31	Diego Gleichner-Metz	diego.gleichner.metz@geemail.com	San Francisco	California	4812518570302025	43139e4b0a3a8e7db5567b1a489a4de1	Diners Club / Carte Blanche	37.7763397081422951	-122.457528933087616
49060	2020-08-31 02:15:23	2020-08-31	Hughey O'Kon	hughey.o'kon@geemail.com	Joliet	Illinois	3112122067418945020	28bcf2fa4ce38a9a4067ae5542458d2f	JCB 16 digit	41.5768003488283568	-88.0529787052992674
49061	2020-08-31 02:17:38	2020-08-31	Iva Stroman	iva.stroman@geemail.com	Fort Wayne	Indiana	4163788519375	bc68c2138b6c627e81f52504135563cf	JCB 15 digit	41.0825136815913012	-85.1260608326397801
49062	2020-08-31 02:17:39	2020-08-31	Elon Blick	elon.blick@woohoo.com	San Francisco	California	869971614881059721	f5712461e916d2b945401add4a472b37	JCB 16 digit	37.7264354034248655	-122.452881174150107
49063	2020-08-31 02:25:55	2020-08-31	Ahmad Weimann	ahmad.weimann@geemail.com	Pasadena	Texas	180057022595816212	79636de52be177ff1011651bbd09edc3	VISA 16 digit	29.6557993412822469	-95.2109722765576123
49064	2020-08-31 02:27:43	2020-08-31	Reino Gulgowski-Hand	reino.gulgowski.hand@geemail.com	Virginia Beach	Virginia	51344795711115345	62381e5e663db29598eb51514d73f1fd	JCB 16 digit	36.7193479864113073	-76.0020863140605343
49065	2020-08-31 02:27:43	2020-08-31	Deetta Klein DVM	deetta.klein.dvm@geemail.com	San Diego	California	3030960526394114	353f51918a17ad62074151fa34f702d7	American Express	32.811722427706421	-117.195839728033178
49066	2020-08-31 02:28:53	2020-08-31	Jake Schmeler Jr.	jake.schmeler.jr.@geemail.com	New York	New York	3528384942698935284	e03b355548db72b450e4b7ce35a10bdc	JCB 16 digit	40.6193123806025795	-73.9395952377829673
49067	2020-08-31 02:29:36	2020-08-31	Dr. Jazlynn Bartell MD	dr.jazlynn.bartell.md@warmmail.com	Las Vegas	Nevada	53271743519854324	d0c8b5f451441638ecd8fb566fed4230	Discover	36.1349773123029578	-115.320913236329702
49068	2020-08-31 02:47:48	2020-08-31	Miss Keshia Waters MD	miss.keshia.waters.md@geemail.com	Woodbridge	New Jersey	869931161855776301	705bc78618958f21d3c6fb1742e19db1	VISA 16 digit	40.6303207883302093	-74.2209540661748406
49069	2020-08-31 02:50:19	2020-08-31	Justina Herman DVM	justina.herman.dvm@geemail.com	Little Rock	Arkansas	180002367447889669	6a553b2fb0b7e57bee263c3bc17c9191	Diners Club / Carte Blanche	34.7069935740713049	-92.3953389746941554
49070	2020-08-31 03:09:16	2020-08-31	Dr. Rance Luettgen	dr.rance.luettgen@woohoo.com	Baltimore	Maryland	869965740346871067	1a4d1f6e6ca1ba2d0ea2aa279ef3e158	JCB 16 digit	39.3393337333574848	-76.7091933833919484
49071	2020-08-31 03:35:50	2020-08-31	Ed Crona-Harris	ed.crona.harris@geemail.com	Saint Paul	Minnesota	6011801299275185857	e281fa9252ffbf9f2b552cf4b82a7d28	Maestro	44.9477956834655288	-93.0899118561562204
49072	2020-08-31 03:40:25	2020-08-31	Mr. Halsey Ward V	mr.halsey.ward.v@woohoo.com	San Francisco	California	3023346817494200	2c1c3a69f2761ff4775ac42592b0ba97	Discover	37.7749650546923803	-122.432805135276638
49073	2020-08-31 03:43:42	2020-08-31	Wellington VonRueden	wellington.vonrueden@geemail.com	Chattanooga	Tennessee	4622585673555163	18e009158fdc700a7601d9936c61f435	American Express	35.1200456249844279	-85.334301469038806
49074	2020-08-31 03:45:27	2020-08-31	Amberly Hettinger	amberly.hettinger@geemail.com	Dallas	Texas	3038309511038298	073fdbb5db72cd18716e32322fb5fcf5	Diners Club / Carte Blanche	32.8539119452975683	-96.8400469490755285
49075	2020-08-31 03:47:43	2020-08-31	Dalton Gottlieb	dalton.gottlieb@geemail.com	Murfreesboro	Tennessee	869906086029808071	96f1e3ce53c3fb089da9f0b03ea049f3	Discover	35.9438746118571615	-86.3564341266956177
49076	2020-08-31 03:51:23	2020-08-31	Marcelino Schiller	marcelino.schiller@geemail.com	Columbus	Ohio	3466519505765917	a9b64437f33d1bd0a08c638f448a4948	Diners Club / Carte Blanche	39.8967406113676688	-83.0021751648049815
49077	2020-08-31 03:59:15	2020-08-31	Ruthann Sawayn	ruthann.sawayn@geemail.com	Tucson	Arizona	4367378582384	953f781712550720831338e41c5c18d0	Voyager	32.1071934747550642	-110.9633473725751
49078	2020-08-31 04:00:23	2020-08-31	Rishi Funk-Bernhard	rishi.funk.bernhard@geemail.com	Bridgeport	Connecticut	4373350577843376	eb2b37575915db8e720926db21e5a627	JCB 15 digit	41.1557306477032583	-73.1963473425611966
49079	2020-08-31 04:21:25	2020-08-31	Nell Spinka-Huel	nell.spinka.huel@warmmail.com	Mobile	Alabama	3022045237023356	d5d7bcf550efb3cf876f2b29880f3943	Diners Club / Carte Blanche	30.6986514528390018	-88.145330607439206
49080	2020-08-31 04:22:08	2020-08-31	Braeden Mann	braeden.mann@woohoo.com	New York	New York	6011396688404535464	c6cc3b63a8b932c34bb7951dfb88090a	Voyager	40.7026817663796265	-74.019747718646002
49081	2020-08-31 04:24:05	2020-08-31	Dione Kemmer	dione.kemmer@warmmail.com	Oakland	California	6011999808568643000	df4ddd40d7f80fb965100b9472cd2613	VISA 16 digit	37.8231409546047459	-122.274326910595818
49082	2020-08-31 04:52:47	2020-08-31	Dr. Jedidiah Beer	dr.jedidiah.beer@woohoo.com	Norman	Oklahoma	6011261941739615101	6dc15bb9f4682bfacf30b9b3732e6dbc	JCB 16 digit	35.1465305962175165	-97.3983383329372856
49083	2020-08-31 04:53:57	2020-08-31	Dr. Debby Hettinger DVM	dr.debby.hettinger.dvm@geemail.com	Glendale	Arizona	4546614092055168	0dbdcfa6b83aebf2e7c3d13318bc3442	VISA 16 digit	33.5854031121585521	-112.136266955060506
49084	2020-08-31 04:55:01	2020-08-31	Alvia Barton	alvia.barton@geemail.com	San Francisco	California	3088611927482971236	80b019b7d8d88e93a505b8e918edac1c	JCB 16 digit	37.7613033002905141	-122.459857356768524
49085	2020-08-31 04:58:17	2020-08-31	Helena Wilkinson-Sporer	helena.wilkinson.sporer@geemail.com	Fort Worth	Texas	52024977129001328	23aa76d241af9b4b45f938264bd5d8ce	Voyager	32.8498547154068987	-97.4448194000225527
49086	2020-08-31 05:00:35	2020-08-31	Ras Hudson	ras.hudson@geemail.com	Houston	Texas	4380811879408	42a34a1baab27ded516621be149f0047	Voyager	29.7693877440024153	-95.3958401882104567
49087	2020-08-31 05:05:43	2020-08-31	Jamaal Hauck-Maggio	jamaal.hauck.maggio@geemail.com	Houston	Texas	4900312311484	7ffb237834dd21c032d70e4bed331288	American Express	29.8382918850597001	-95.4510923796348294
49088	2020-08-31 05:15:06	2020-08-31	Gaston Stanton	gaston.stanton@warmmail.com	San Antonio	Texas	676377878755543	daac78934e03f0763b9445c54b809512	JCB 16 digit	29.5109727660730492	-98.5350012203048919
49089	2020-08-31 05:15:22	2020-08-31	Dr. Mikaila Von	dr.mikaila.von@woohoo.com	Santa Ana	California	3337002075312429079	dcf3f21d99be5341655bee98366cb8fb	Voyager	33.7575817180901794	-117.813920100398363
49090	2020-08-31 05:18:03	2020-08-31	Gerda Stroman	gerda.stroman@geemail.com	Cambridge	Massachusetts	6011996103920397971	4c86a103026fe95413a66a742ac0a630	Mastercard	42.4250320431999839	-71.1436276159331271
49091	2020-08-31 05:27:02	2020-08-31	Danica Haag	danica.haag@geemail.com	Fresno	California	4792723211851919	ea3bc6b75be037cc7aabfc01af444439	Voyager	36.7640999226238563	-119.716021182445445
49092	2020-08-31 05:28:56	2020-08-31	Trish Hagenes	trish.hagenes@geemail.com	Cleveland	Ohio	3096942041760053434	a73fa57b6a254e112ce9df1e1218d81a	VISA 13 digit	41.5416138730328512	-81.5855434420757035
49093	2020-08-31 05:32:55	2020-08-31	Davis Rogahn	davis.rogahn@geemail.com	Austin	Texas	3528491789312230844	2160a456674e4135511a4aed10115336	Discover	30.2165416247338037	-97.830998947914324
49094	2020-08-31 05:36:46	2020-08-31	Aleen Auer DVM	aleen.auer.dvm@geemail.com	Mesa	Arizona	869929704157496948	9ff06873a43f37177c06e5d2aa7feb9d	VISA 16 digit	33.4951290709577449	-111.674345884367455
49095	2020-08-31 05:40:22	2020-08-31	Evert Mohr	evert.mohr@geemail.com	Columbus	Ohio	55970325914116832	db61ed8e9aa37f4b2f82f4f00cd03774	VISA 13 digit	39.9919462352104489	-82.9564765163932094
49096	2020-08-31 05:42:43	2020-08-31	Orlin Weber-Larson	orlin.weber.larson@geemail.com	Fresno	California	3088402484166161281	9eb4d42e1471973d018ae2cd46e624ca	JCB 16 digit	36.7166139313358784	-119.885313998546081
49097	2020-08-31 05:49:57	2020-08-31	Eva Rogahn MD	eva.rogahn.md@geemail.com	Omaha	Nebraska	869969007728422539	200377c3e978a01894bfe7575f7500c3	Mastercard	41.2992560683429275	-96.0477976197026777
49098	2020-08-31 05:52:28	2020-08-31	Lavera Dibbert	lavera.dibbert@geemail.com	Reno	Nevada	4346298624585405	4d2c65593efdd019fbf6d0994d808bfe	Mastercard	39.5132940408386304	-119.774416030307862
49099	2020-08-31 05:55:44	2020-08-31	Marry Dicki	marry.dicki@geemail.com	New Haven	Connecticut	3042640038222254	add333655e643bae97a495a3a0a6f632	Voyager	41.2394627922207135	-72.9994342447724165
49100	2020-08-31 06:04:35	2020-08-31	Rush Von	rush.von@geemail.com	Charlotte	North Carolina	3037984719767764	c470b6956d052cacd2c5baeab00030ed	Discover	35.1222246002659162	-80.743124822288749
49101	2020-08-31 06:12:41	2020-08-31	Jodi Funk	jodi.funk@warmmail.com	Phoenix	Arizona	55763928983530733	fa6f4ed9012eef7dfd6a0d836e389d0a	Mastercard	33.5790514039274299	-112.123088047832624
49102	2020-08-31 06:13:10	2020-08-31	Freddy Abernathy	freddy.abernathy@geemail.com	Washington	District of Columbia	4118601420179032	69e0590be66a4994fb1a493b50a416c9	VISA 16 digit	38.8432642431262849	-76.9363346415784264
49103	2020-08-31 06:17:49	2020-08-31	Dr. Melton Monahan	dr.melton.monahan@geemail.com	New York	New York	3058562369528691	abacc6c59746edf4af29c82601054057	VISA 13 digit	40.7242708970084806	-73.8821572614729405
49104	2020-08-31 06:17:52	2020-08-31	Mr. Enzo Volkman III	mr.enzo.volkman.iii@geemail.com	Birmingham	Alabama	6011966999018614599	1e0b91588d01693f801d2d28a412ce87	VISA 13 digit	33.5705923805736006	-86.7245303576123092
49105	2020-08-31 06:19:59	2020-08-31	Johnathan Lehner-Jerde	johnathan.lehner.jerde@warmmail.com	Boston	Massachusetts	4922578471281	7e3c3297f41b5fdf869e09fb97b79d8b	JCB 15 digit	42.2979574825316647	-71.0810037123456624
49106	2020-08-31 06:22:04	2020-08-31	Huldah Rodriguez	huldah.rodriguez@geemail.com	Glendale	California	52866836183069699	b0cf359870540fb7a5235d4d91728e9f	American Express	34.1938696989078039	-118.208204979718857
49107	2020-08-31 06:24:28	2020-08-31	Brycen Krajcik III	brycen.krajcik.iii@geemail.com	Columbia	South Carolina	6011301015887789810	3ce44737113934f17530bb0d54bd4bf8	Maestro	33.9311995797123771	-80.9788433699887236
49108	2020-08-31 06:29:34	2020-08-31	Rosco Padberg	rosco.padberg@geemail.com	San Francisco	California	4525188104241806	d51a48a8befe06b6186e0afe48058bd6	VISA 16 digit	37.8003285440741905	-122.411085033506509
49109	2020-08-31 06:32:32	2020-08-31	Dominga O'Keefe	dominga.o'keefe@woohoo.com	Shreveport	Louisiana	4176248480371056	75f348c8eca0a662d1c1c060fbc9ee5f	VISA 16 digit	32.4761448189388986	-93.8175998809959708
49110	2020-08-31 06:38:24	2020-08-31	Mikeal Fritsch	mikeal.fritsch@geemail.com	Houston	Texas	180004562379198448	56bfc5094b7bb6cd36d42640448fd32c	JCB 16 digit	29.7421000340566053	-95.3343044180903547
49111	2020-08-31 06:42:49	2020-08-31	Pearle Herman	pearle.herman@geemail.com	San Francisco	California	4627164881831	c98b94f88f1bafa667d360dab86c1e2a	Maestro	37.761811793176463	-122.447086376526741
49112	2020-08-31 06:46:58	2020-08-31	Lesta Jast-Huel	lesta.jast.huel@woohoo.com	New Orleans	Louisiana	53763418487636566	361abd24dea1b36017646e967ac90898	JCB 15 digit	30.0274400655660791	-89.9035441803541033
49113	2020-08-31 06:51:29	2020-08-31	Bluford Moen	bluford.moen@geemail.com	Milwaukee	Wisconsin	4655783297137555	45e92f4db7b3ccb1375f1b7fcaa5d313	JCB 16 digit	43.1122998955279542	-87.9977186256188872
49114	2020-08-31 06:58:38	2020-08-31	Mr. Leighton Crooks IV	mr.leighton.crooks.iv@warmmail.com	Jacksonville	Florida	869923524967926066	138620b06a94b7d4da9ec52faa324c52	Mastercard	30.2683373678062111	-81.7409088542297582
49115	2020-08-31 07:01:41	2020-08-31	Vinnie Hoppe	vinnie.hoppe@geemail.com	Houston	Texas	51502752404216094	4f81df68918601515df52cadd152fc6f	VISA 16 digit	29.8307769789438701	-95.2980861512493362
49116	2020-08-31 07:03:06	2020-08-31	Mikala Gerhold	mikala.gerhold@woohoo.com	Lubbock	Texas	210049712250343996	92070d7c96c9b18d623b791d1f9e88ce	VISA 16 digit	33.6217039232648958	-101.868013970172782
49117	2020-08-31 07:06:45	2020-08-31	Elinor Skiles	elinor.skiles@woohoo.com	St. Louis	Missouri	4964394628660	d29cd01cd220ac49aab82b667f38ad09	VISA 13 digit	38.620560553313048	-90.2543287437412971
49118	2020-08-31 07:12:40	2020-08-31	Roswell Crona	roswell.crona@geemail.com	Plano	Texas	3528842627030352456	efb983832ce3c05c35a122766c99ad57	Voyager	32.9905433998994582	-96.6710847126968247
49119	2020-08-31 07:18:35	2020-08-31	Emmitt Spinka	emmitt.spinka@geemail.com	New York	New York	3158985324114361333	eea55681f002d1a0e33f87921333cc44	VISA 13 digit	40.7526945905517763	-74.0327915930550517
49120	2020-08-31 07:29:22	2020-08-31	Miss Marin Barrows PhD	miss.marin.barrows.phd@woohoo.com	San Bernardino	California	3011223973527242	348a09421f2fe98b923a1974172ac9a4	Discover	34.072378845539312	-117.22452552390881
49121	2020-08-31 07:35:07	2020-08-31	Gerri Ebert	gerri.ebert@geemail.com	Corona	California	3528057310798095316	990f71f8a58e4a1d0e4f99f053f67b75	VISA 13 digit	33.921587589185684	-117.543915655996656
49122	2020-08-31 07:54:47	2020-08-31	Romeo Wiegand	romeo.wiegand@geemail.com	Wichita	Kansas	869919825238628779	372f857187366fa2bb041b1af0226fa4	Maestro	37.6183250492781411	-97.3836979490440342
49123	2020-08-31 08:06:15	2020-08-31	Claudius Leffler	claudius.leffler@geemail.com	Los Angeles	California	3088684162134784751	ded085518985e62f9c0236299da3e6d8	Maestro	33.9940534376870787	-118.319836250738419
49124	2020-08-31 08:08:51	2020-08-31	Beverly Schroeder-Gislason	beverly.schroeder.gislason@geemail.com	Oceanside	California	54182661304734600	d99a40c5dc0de8f16a7aefb2ec879432	JCB 15 digit	33.3044422744195927	-117.379158118701355
49125	2020-08-31 08:17:02	2020-08-31	Anthoney Hirthe	anthoney.hirthe@woohoo.com	Cleveland	Ohio	55763284333988902	566f395ced5b27691ed10408d940c063	Mastercard	41.478232088483864	-81.6418467906076444
49126	2020-08-31 08:21:21	2020-08-31	Hervey Cummings	hervey.cummings@geemail.com	Pittsburgh	Pennsylvania	4572927635621	3a350c3fd5c6c9c07c92c41d0213fc49	Diners Club / Carte Blanche	40.3739653943061825	-79.8926438178107219
49127	2020-08-31 08:22:19	2020-08-31	Dominik Schmitt	dominik.schmitt@geemail.com	Berkeley	California	3112907020399725854	f00e2e80a5ca8397df6f167008d8a5b5	JCB 16 digit	37.8810804466671627	-122.304805032752171
49128	2020-08-31 08:48:36	2020-08-31	Rolando Ryan	rolando.ryan@geemail.com	Tulsa	Oklahoma	501877301943245	9b70d08bc7a594610a7ab4dcbdaee388	JCB 15 digit	36.1420912282444533	-95.8691946496676621
49129	2020-08-31 08:57:11	2020-08-31	Samira Vandervort	samira.vandervort@geemail.com	Phoenix	Arizona	180044292135602507	3d994b2efd4992d312549b4bfd2be16b	Mastercard	33.4859673517689131	-112.126332863226907
49130	2020-08-31 09:16:08	2020-08-31	Delilah Berge	delilah.berge@geemail.com	Miami	Florida	3477662576119528	6d09cde4d3a73fe70d6f7810f0291d0e	VISA 16 digit	25.8558450532283643	-80.2248301134318211
49131	2020-08-31 09:17:20	2020-08-31	Ms. Edla Jast	ms.edla.jast@geemail.com	Houston	Texas	3765351422789908	1d71322f0a6c10d92cb21bb6ffe7235a	Mastercard	29.6978414300441749	-95.3673763915445676
49132	2020-08-31 09:18:01	2020-08-31	Dr. Edwina Davis PhD	dr.edwina.davis.phd@warmmail.com	New York	New York	6011542216987042188	a00f135e8e27d59341b2506f185a0cd8	VISA 16 digit	40.7551799191385484	-73.9168948473304539
49133	2020-08-31 09:21:13	2020-08-31	Mr. Delos Skiles	mr.delos.skiles@warmmail.com	Miami Gardens	Florida	3337056021364787555	2953f87929461ce8f3f9bd6b0a4d14d0	JCB 16 digit	25.9406552875820537	-80.2851356423240219
49134	2020-08-31 09:23:02	2020-08-31	Bryton Windler	bryton.windler@warmmail.com	Oakland	California	52655934826251165	af62aab137df83965d3b3b6c8f320e30	Maestro	37.8288748972091255	-122.286792017105185
49135	2020-08-31 09:26:36	2020-08-31	Wilbur Toy	wilbur.toy@warmmail.com	Plano	Texas	869935047753146943	02f8a34d86befab2b9c35e6b45e1333f	JCB 16 digit	33.0097023564476544	-96.840097464592759
49136	2020-08-31 09:26:48	2020-08-31	Caryl Connelly	caryl.connelly@geemail.com	San Francisco	California	210029642682716390	d2596efbc832d387a1c4ac6fefc6f3c1	American Express	37.7763046346655003	-122.391505351776445
49137	2020-08-31 09:51:37	2020-08-31	Mr. Thurman Kunde DDS	mr.thurman.kunde.dds@warmmail.com	San Francisco	California	630490316351221	95cda8ddb033f883133bbcf04a68ec9f	American Express	37.7325256860409581	-122.446494512148149
49138	2020-08-31 10:01:13	2020-08-31	Jaclyn Larkin	jaclyn.larkin@geemail.com	Chicago	Illinois	869918768046391787	654ac82aa66f91472bbfb6c70cad0abe	Voyager	41.8517695614904213	-87.699209128462897
49139	2020-08-31 10:03:04	2020-08-31	Nehemiah Roberts	nehemiah.roberts@geemail.com	Concord	California	3112252473263293767	295867ba74990f9f8a08cd4d15b528ef	JCB 16 digit	37.8911075074624293	-122.05804289269112
49140	2020-08-31 10:05:22	2020-08-31	Adam Brown	adam.brown@geemail.com	Los Angeles	California	3158795847197502944	040b9ffd2f811fdece350494d180ca7f	Maestro	34.0581798135168796	-118.415105666731662
49141	2020-08-31 10:10:27	2020-08-31	Jamey Waelchi	jamey.waelchi@warmmail.com	Houston	Texas	3036298876702543	ac2a321a0423822fdfc5da9b6cd10fd6	Discover	29.8244116137813791	-95.4322245567120575
49142	2020-08-31 10:19:01	2020-08-31	Louvenia Lesch-Nienow	louvenia.lesch.nienow@geemail.com	Fresno	California	53982299828473710	e79ba375984fc0ff8bbe25c910ab37b8	JCB 16 digit	36.8327430824156821	-119.88763135863617
49143	2020-08-31 10:21:08	2020-08-31	Keisha Becker	keisha.becker@warmmail.com	Houston	Texas	3704598288766107	faeb7d1e3f09ef536f1355d08ce94e24	VISA 13 digit	29.6910054128229604	-95.4558003453552715
49144	2020-08-31 10:30:13	2020-08-31	Cleta Satterfield	cleta.satterfield@warmmail.com	San Diego	California	210005582543416996	35b0dfbcf39589eebdaad84c7126c084	Diners Club / Carte Blanche	32.8404753770746325	-117.04636236549355
49145	2020-08-31 10:35:19	2020-08-31	Skip Bins-Kuphal	skip.bins.kuphal@geemail.com	New York	New York	3337342740214418699	68f388ee3188f0f80fb31455b39cfdc9	Diners Club / Carte Blanche	40.6725354229789247	-73.9473232150904778
49146	2020-08-31 10:47:38	2020-08-31	Elizabet Hane MD	elizabet.hane.md@warmmail.com	Hillsboro	Oregon	3158199546490903989	e31526ec5591a55334392cfa6f67bb5e	VISA 13 digit	45.5889624937176663	-122.973363852330294
49147	2020-08-31 10:48:53	2020-08-31	Hayleigh Mohr	hayleigh.mohr@geemail.com	Lafayette	Louisiana	210021124116678973	ecff0b1bb75188492ca175052b3add59	VISA 16 digit	30.286168951026724	-92.0240568019766272
49148	2020-08-31 10:52:22	2020-08-31	Abelardo Gottlieb	abelardo.gottlieb@geemail.com	Dayton	Ohio	3528566675307924527	8864c7347a580e212c0f91083ec56c3c	Voyager	39.8284480572469519	-84.186747814501075
49149	2020-08-31 10:53:45	2020-08-31	Malia Waters	malia.waters@woohoo.com	Stockton	California	4501854176198871	0be3c7b6d77bdb1a6b0a8cb82a110f3f	Maestro	38.0218222521908586	-121.292528236898775
49150	2020-08-31 10:57:15	2020-08-31	Buell Sanford-Jacobson	buell.sanford.jacobson@geemail.com	Everett	Washington	869975943754220227	e26b76afadb8a40cb38316e436110ad2	JCB 15 digit	47.9578934457510755	-122.275186658430471
49151	2020-08-31 11:04:12	2020-08-31	Mr. Clifford Bode V	mr.clifford.bode.v@woohoo.com	Centennial	Colorado	869904546921611776	d7cbea13b706fcb8a74c7ea97d2597ab	Voyager	39.6136077395215622	-104.949768037990111
49152	2020-08-31 11:09:43	2020-08-31	Mr. Watt Lubowitz Jr.	mr.watt.lubowitz.jr.@geemail.com	Lakeland	Florida	180048227455614910	caa745fb2fdf920a14255b50e4efed01	Mastercard	28.0264999399259658	-81.8803975070245542
49153	2020-08-31 11:13:06	2020-08-31	Caleb Stamm Jr.	caleb.stamm.jr.@warmmail.com	South Bend	Indiana	4884456433232597	53a78003cf050b89388ee5877bd9a58f	VISA 13 digit	41.6735259983833899	-86.3679018551074051
49154	2020-08-31 11:14:50	2020-08-31	Leanne Dicki	leanne.dicki@geemail.com	Los Angeles	California	4360858917837168	da4baa9276519c07af3c0534ebeeb1a3	Diners Club / Carte Blanche	33.9661948726844045	-118.389829695456839
49155	2020-08-31 11:31:17	2020-08-31	Elliot Welch	elliot.welch@geemail.com	Houston	Texas	676355864129501	1c5c5f4052969cc0b7fa527ae4358402	VISA 16 digit	29.8771078094918288	-95.3478348116870933
49156	2020-08-31 11:43:31	2020-08-31	Olive Sawayn	olive.sawayn@woohoo.com	New York	New York	4527653107609	c5f64102b3d76cfd245e045de6af0c4a	American Express	40.6336587595045557	-73.8981121333211632
49157	2020-08-31 11:47:11	2020-08-31	Shan Reinger	shan.reinger@woohoo.com	El Paso	Texas	4007849133413	c7cd077a9f259c856f65fc2b6bb417e9	JCB 16 digit	31.915681314963475	-106.497760693261412
49158	2020-08-31 11:50:23	2020-08-31	Rube Kutch	rube.kutch@geemail.com	Rockford	Illinois	54599192605766213	a25001b23b882b1dece45cb76b3148b0	VISA 13 digit	42.3111336095735453	-89.1403073924876708
49159	2020-08-31 11:53:08	2020-08-31	Rustin Toy	rustin.toy@woohoo.com	Port St. Lucie	Florida	4058575467269	645b3bf33baf2f0efe47bd6364e16c58	Voyager	27.2876161562412989	-80.3714482958514225
49160	2020-08-31 12:00:07	2020-08-31	Ms. Tamera Bernier	ms.tamera.bernier@woohoo.com	Miramar	Florida	180003254690771951	1c54ac4b980e979809a0c7e7882159ff	Discover	26.0175934553127739	-80.3389091957353116
49161	2020-08-31 12:02:20	2020-08-31	Jones Greenfelder II	jones.greenfelder.ii@warmmail.com	Kansas City	Kansas	4246851424046001	26e36cac4cbf7efd6aa0966466d0f3a6	Maestro	39.1776648712717019	-94.7084616822592835
49162	2020-08-31 12:09:03	2020-08-31	Breanne Lebsack	breanne.lebsack@woohoo.com	New York	New York	3096978953846070678	adf054bc7d8094c3cac2a49a64b81c06	Mastercard	40.7113312654420696	-73.9826726895187079
49163	2020-08-31 12:10:53	2020-08-31	Brielle Mohr	brielle.mohr@geemail.com	Chicago	Illinois	3026039440650721	f67cf90b15974d77b472d16977cc9af2	Maestro	41.9001135993584981	-87.6692134673271255
49164	2020-08-31 12:15:58	2020-08-31	Littleton Jones	littleton.jones@geemail.com	New York	New York	4387714879272879	317d9c67bd1c11fcbed05e71324126fc	VISA 16 digit	40.6108972532432517	-74.0124333063967441
49165	2020-08-31 12:16:22	2020-08-31	Lawson Hilpert	lawson.hilpert@geemail.com	San Jose	California	630488979600520	38b168d41138c69ee4f6208a7a04a715	VISA 16 digit	37.2662737057365518	-121.770195090373605
49166	2020-08-31 12:16:55	2020-08-31	Mrs. Jeri Ward DDS	mrs.jeri.ward.dds@geemail.com	Philadelphia	Pennsylvania	3043739933441164	80e0013313155d2abdbf207b0f4d245a	Mastercard	40.0014473935548196	-75.0991694920595734
49167	2020-08-31 12:16:58	2020-08-31	Darby Donnelly PhD	darby.donnelly.phd@woohoo.com	Detroit	Michigan	180024397011692078	5d8365dabef6c59d7fe6a3b0f4aea7d5	Maestro	42.338855474621063	-83.0293094829309695
49168	2020-08-31 12:24:09	2020-08-31	Felicie Stroman	felicie.stroman@geemail.com	Houston	Texas	3528731652514718893	dca187064b218bc5e0f430ee57a1b7a9	Diners Club / Carte Blanche	29.800457761258258	-95.4544885022115039
49169	2020-08-31 12:25:08	2020-08-31	Mr. Jarrod Murray	mr.jarrod.murray@geemail.com	Billings	Montana	676369893589833	c3c3e5ea8214eba4120df5f42eb971fb	VISA 16 digit	45.7723528365362426	-108.64722088288292
49170	2020-08-31 12:26:27	2020-08-31	Zula Bartell	zula.bartell@geemail.com	Milwaukee	Wisconsin	3088094195799833772	fdb654522e54354722e60278b462df16	VISA 16 digit	43.0805489619348165	-87.8909794665042341
49171	2020-08-31 12:27:52	2020-08-31	Keith Durgan	keith.durgan@geemail.com	Norfolk	Virginia	4615309411165493	576f55336357b6b5919412a803328227	Voyager	36.9586789126060893	-76.2884411165960188
49172	2020-08-31 12:38:45	2020-08-31	Kiarra Fay	kiarra.fay@warmmail.com	Carrollton	Texas	6011756989250871050	a8761da79620977f88ab8eb114a530ed	VISA 16 digit	33.0237374241385595	-96.8342245105516213
49173	2020-08-31 12:39:38	2020-08-31	Dr. Theta Hickle	dr.theta.hickle@woohoo.com	Gilbert	Arizona	3158612447293886282	e73755db254042348c6b9e125eaa38d0	JCB 16 digit	33.2895835274245542	-111.807165659279008
49174	2020-08-31 12:41:28	2020-08-31	Maralyn O'Kon	maralyn.o'kon@geemail.com	New York	New York	3058231340262388	25423c042b016c4bd30184382f659828	VISA 16 digit	40.7535499556213594	-73.9520637554012268
49175	2020-08-31 12:49:30	2020-08-31	Hall Bruen-Torp	hall.bruen.torp@geemail.com	New York	New York	3008020758452924	dd495404deebe92b47c43d98b0bf54ad	Diners Club / Carte Blanche	40.7429917352963216	-74.0247448140651017
49176	2020-08-31 12:52:19	2020-08-31	Anjali Bergnaum DVM	anjali.bergnaum.dvm@geemail.com	Dallas	Texas	4723431750717	b20df6a6791333e438a7fc5cdeecd6a2	VISA 16 digit	32.7944625924147672	-96.8450643640439921
49177	2020-08-31 12:52:39	2020-08-31	Levar Bayer	levar.bayer@geemail.com	Macon	Georgia	4150583165219240	30d4418ea04e19d9bdaa3ed350cd6e30	Discover	32.7926993330951788	-83.6885902751430848
49178	2020-08-31 13:03:13	2020-08-31	Joi Reynolds DDS	joi.reynolds.dds@woohoo.com	San Francisco	California	3018065533419813	aaf47ae31470ccd861bca86de6efc72c	Discover	37.7673985256485878	-122.408436282091316
49179	2020-08-31 13:04:44	2020-08-31	Lavon Gusikowski	lavon.gusikowski@warmmail.com	New York	New York	3752607299292671	f5aab6b339e8796c6370db5bc6ab78cc	Discover	40.6654354725256582	-73.8703047251224518
49180	2020-08-31 13:08:04	2020-08-31	Mr. Harry Mayert	mr.harry.mayert@warmmail.com	Lexington	Kentucky	3711762552256614	ad080407a0bdbccf5388a91688283a27	Maestro	38.0118871963925642	-84.4845034413404647
49181	2020-08-31 13:18:18	2020-08-31	Ananias Dickinson	ananias.dickinson@warmmail.com	North Charleston	South Carolina	3050333391670317	ae995894caf609295d4a5deee0e367d8	Diners Club / Carte Blanche	33.0011051221445229	-79.9896028233785188
49182	2020-08-31 13:27:41	2020-08-31	Mabel Cruickshank	mabel.cruickshank@geemail.com	Louisville	Kentucky	869974888176956067	886b5fbeeed559f8f994c5bddc680785	JCB 15 digit	38.1040241270694864	-85.6022120058607356
49183	2020-08-31 13:28:15	2020-08-31	Tanja Muller	tanja.muller@geemail.com	Westminster	Colorado	180049894133945781	b271d8741516f4a8f70e15372cebdd4d	American Express	39.8856372711554172	-105.020196253122393
49184	2020-08-31 13:33:18	2020-08-31	Beckham Larson-Stehr	beckham.larson.stehr@geemail.com	San Francisco	California	3337505206929493404	cc33aa2bdfc463a1cba0f337ec06dc2f	VISA 16 digit	37.7967542949442716	-122.383750105681997
49185	2020-08-31 13:41:30	2020-08-31	Verlene Zulauf DVM	verlene.zulauf.dvm@geemail.com	Chicago	Illinois	4869561976444100	501f015a58d5455e18548984ed8d5613	VISA 16 digit	41.8013244851328452	-87.687609692759068
49186	2020-08-31 13:43:10	2020-08-31	Treyton Lueilwitz	treyton.lueilwitz@warmmail.com	Lansing	Michigan	3023581517978363	32a40074253f1bd24a454d78932a984d	VISA 13 digit	42.7202186035301565	-84.6270250696346125
49187	2020-08-31 13:47:29	2020-08-31	Roby Wehner	roby.wehner@geemail.com	Des Moines	Iowa	4860677546530	27d2264da05a023cb3821b32c205b741	Voyager	41.6330047431144905	-93.5807772364977808
49188	2020-08-31 13:48:07	2020-08-31	Dr. Brendon Leannon	dr.brendon.leannon@geemail.com	Lubbock	Texas	3048241049167432	4cf605256c35afd8b3a5a7ec068f7d16	JCB 15 digit	33.6389167446218451	-101.917024075697
49189	2020-08-31 13:50:05	2020-08-31	Yulisa Gleichner-Lockman	yulisa.gleichner.lockman@woohoo.com	Oklahoma City	Oklahoma	6011885154579405783	17d8c9def378823752aeb7be1318a2da	American Express	35.4075301270376883	-97.5686541605636535
49190	2020-08-31 13:51:29	2020-08-31	Shedrick Moore-Frami	shedrick.moore.frami@geemail.com	Detroit	Michigan	3096174982270315954	fce3950c29a4b6e0807ac90230a7b597	Mastercard	42.4674499806873555	-83.1216791152141923
49191	2020-08-31 13:59:16	2020-08-31	Lidia Yost	lidia.yost@warmmail.com	Los Angeles	California	55463132734209597	8e6188bf19bc4a69c74e0a5d575d790f	Voyager	34.007661114293704	-118.479161301627002
49192	2020-08-31 14:11:38	2020-08-31	Alton Mertz	alton.mertz@geemail.com	Las Cruces	New Mexico	4381164178139351	f3a97695a34dbca32d8970f8866f9f81	VISA 13 digit	32.3524766582563501	-106.747793913691112
49193	2020-08-31 14:14:15	2020-08-31	Jaylynn Littel MD	jaylynn.littel.md@warmmail.com	Roseville	California	3025043299904362	5a6691b467d3e59e28445f05a7c59b50	Maestro	38.7651988010443702	-121.395925542361667
49194	2020-08-31 14:23:42	2020-08-31	Mr. Hosie Langosh	mr.hosie.langosh@warmmail.com	Lexington	Kentucky	639055134123029	c8519bf1ac3f33ed9be5d9d70e4587c7	Maestro	38.0541329142048994	-84.522004047910869
49195	2020-08-31 14:29:25	2020-08-31	Kari Conroy-Hills	kari.conroy.hills@geemail.com	Tucson	Arizona	676104458944784	a3c0fd6ff464d755217afd87a48a9994	American Express	32.1425778320565811	-110.811472023953115
49196	2020-08-31 14:46:21	2020-08-31	Ether Macejkovic	ether.macejkovic@geemail.com	Killeen	Texas	4427108477065961	a82939b68fae6e4451302269a6e7be49	JCB 16 digit	31.1727054157525316	-97.78061895693466
49197	2020-08-31 14:51:40	2020-08-31	Irvine Moen	irvine.moen@geemail.com	Kansas City	Missouri	3088827569456734859	3df073e463ac9f43d9a21fad895d8fe2	JCB 16 digit	39.2099712486214997	-94.4713662735410082
49198	2020-08-31 14:57:01	2020-08-31	Laken Reynolds	laken.reynolds@geemail.com	New York	New York	501869430668355	4e1727ee3a9b83cb0c6537a3f7c34419	Mastercard	40.6405742092747246	-73.9398601915117268
49199	2020-08-31 15:01:40	2020-08-31	Reyna Fadel	reyna.fadel@warmmail.com	Tampa	Florida	3337580443462138090	d609e2da643512b7c9be61a9d9339dc2	JCB 16 digit	27.8840408768620343	-82.4898270432583871
49200	2020-08-31 15:04:49	2020-08-31	Dr. Buddy O'Conner PhD	dr.buddy.o'conner.phd@geemail.com	Portland	Oregon	4184384044948921	aab717a62af7c6eff624997c46382d3d	Diners Club / Carte Blanche	45.5031258668638756	-122.560889372136444
49201	2020-08-31 15:12:19	2020-08-31	Dr. Tawanda Heidenreich	dr.tawanda.heidenreich@geemail.com	Pittsburgh	Pennsylvania	4011242475272808	5df9ec1ee3d8e539949098c048b6c4e3	Diners Club / Carte Blanche	40.3921319072555747	-79.9853067501619535
49202	2020-08-31 15:20:48	2020-08-31	Vince Hills	vince.hills@geemail.com	Richmond	California	180006826593802863	75e85e15e9cc67bce6f09c8a7bc579d6	VISA 13 digit	38.0281110313210675	-122.416455574691668
49203	2020-08-31 15:22:41	2020-08-31	Sherree Schoen	sherree.schoen@warmmail.com	Fresno	California	4209824640062099	09b8eb444fbfdb2390dfc6693744272c	JCB 16 digit	36.8794651615772366	-119.767323972435307
49204	2020-08-31 15:28:02	2020-08-31	Brien Goyette II	brien.goyette.ii@warmmail.com	Huntsville	Alabama	4928197255356696	25c8c52aeb7c61f5fd0fac2c52c5b53e	JCB 16 digit	34.742658544542266	-86.5902357176896231
49205	2020-08-31 15:37:29	2020-08-31	Rylie Stracke	rylie.stracke@geemail.com	Phoenix	Arizona	676323168368860	0b17c5a8b737b0f4c6f4eb36dde8f289	Maestro	33.4900262439556471	-112.020568171648691
49206	2020-08-31 15:40:48	2020-08-31	Maxie Farrell	maxie.farrell@geemail.com	Indianapolis	Indiana	53872256218610015	83f837db627103ca58fb34c19a4dac83	Voyager	39.7183051959153275	-86.1330359674259967
49207	2020-08-31 15:46:58	2020-08-31	Otis Mayert	otis.mayert@geemail.com	McAllen	Texas	4254962837621220	e7146623fca65fef3edd987e4ecd6dab	Diners Club / Carte Blanche	26.2657106629878285	-98.2874616193432331
49208	2020-08-31 16:03:25	2020-08-31	Burk Gleichner	burk.gleichner@geemail.com	Des Moines	Iowa	6011604687461598876	e870d09b4bb6dc50041d3a8d765d9d9b	Voyager	41.5078661328855887	-93.522454571169618
49209	2020-08-31 16:04:01	2020-08-31	Orrie Deckow PhD	orrie.deckow.phd@geemail.com	Athens	Georgia	6011250453260862766	bb6813e58e4cb05e9752458862e00593	American Express	33.970307464683799	-83.4678182541508136
49210	2020-08-31 16:05:36	2020-08-31	Che Weber	che.weber@warmmail.com	San Francisco	California	3762778675189530	117ffed44182a747e540b7b5cf7e5af1	VISA 16 digit	37.7789492402455238	-122.432374266721368
49211	2020-08-31 16:08:58	2020-08-31	Mrs. Alanna Carroll	mrs.alanna.carroll@geemail.com	Minneapolis	Minnesota	3058489178264088	adf96b84c6e8820b3713793073a053e3	VISA 16 digit	44.9213835104919923	-93.3326555016722494
49212	2020-08-31 16:09:34	2020-08-31	Martell Roberts	martell.roberts@geemail.com	Louisville	Kentucky	6011106276471252105	9fafda9cb00fd417100de17c2aa1d554	Maestro	38.1651190637979667	-85.5989514279250159
49213	2020-08-31 16:15:49	2020-08-31	Mr. Colten Lockman DVM	mr.colten.lockman.dvm@geemail.com	Seattle	Washington	55595883023588197	11176d30300d2d6ab80d6ee63ccd43c9	VISA 16 digit	47.5375315766707089	-122.359036090682821
49214	2020-08-31 16:20:20	2020-08-31	Maryjo Yundt	maryjo.yundt@geemail.com	Richmond	California	869925608135859503	d0cd1d965c00de3a6123693fc773999b	Maestro	37.9197506151117381	-122.360427870260935
49215	2020-08-31 16:22:46	2020-08-31	Ms. Celesta Hahn	ms.celesta.hahn@woohoo.com	Dallas	Texas	4441784656759	37efce9a5cd42c9e0f9961ac81edb5d2	Discover	32.8054978620067246	-96.8211244711615109
49216	2020-08-31 16:24:10	2020-08-31	Jarred Kuhic	jarred.kuhic@geemail.com	Oxnard	California	6011509818473631571	610d49b9f28fbf262a5de74f5096303b	American Express	34.1881277522027531	-119.198874111324926
49217	2020-08-31 16:24:50	2020-08-31	Emmer Rodriguez	emmer.rodriguez@geemail.com	San Francisco	California	4322001921020	2adec2e0427f7841ec20e7642030f4a5	JCB 15 digit	37.7558587781489692	-122.439686118418962
49218	2020-08-31 16:33:15	2020-08-31	Tye Hodkiewicz	tye.hodkiewicz@warmmail.com	Elgin	Illinois	3096935136893859167	a5804596a501b50abefbf46f39df8f09	VISA 16 digit	42.0236079115238041	-88.4009597703635706
49219	2020-08-31 16:33:35	2020-08-31	Cheryl Bruen	cheryl.bruen@geemail.com	Jacksonville	Florida	3112849036344161665	57273163434b1253b867df46305422a6	Maestro	30.2574993449315421	-81.5694114754520427
49220	2020-08-31 16:34:43	2020-08-31	Casey Abbott	casey.abbott@woohoo.com	Austin	Texas	3026069187551352	8701490495cdc66456ec9702d12302b7	JCB 16 digit	30.2956552362196128	-97.7205147500853997
49221	2020-08-31 16:38:37	2020-08-31	Brennen Deckow	brennen.deckow@geemail.com	San Diego	California	210007728291179173	a1b30fd6d6ba09078805fabf4b090934	Voyager	32.7519136061958989	-117.170930241690954
49222	2020-08-31 16:41:56	2020-08-31	Braden Gutkowski	braden.gutkowski@woohoo.com	San Francisco	California	3042014458593505	f037a6fd32b64751b074cd28089e92a1	Diners Club / Carte Blanche	37.7811160047935815	-122.410691742422358
49223	2020-08-31 16:55:57	2020-08-31	Leslie Upton	leslie.upton@geemail.com	Little Rock	Arkansas	3004170391389118	95e7827515a2e787536a70983119307d	Voyager	34.70959720418751	-92.3158330803610312
49224	2020-08-31 17:05:30	2020-08-31	Paul Ratke	paul.ratke@geemail.com	Richmond	Virginia	3709877096313533	8cfb4b4354850d469e8ba4c86bb13f4d	JCB 16 digit	37.4395619407050262	-77.4686934007555266
49225	2020-08-31 17:05:41	2020-08-31	Treyton Kiehn	treyton.kiehn@warmmail.com	Huntsville	Alabama	501889495394374	46c5e04c531a78fc51932adf22435370	Diners Club / Carte Blanche	34.6410595733448829	-86.6949009822234586
49226	2020-08-31 17:12:15	2020-08-31	Sylvester Walsh	sylvester.walsh@geemail.com	Berkeley	California	3112754652408400329	6390bf958d641efa7ca324533020ff71	VISA 16 digit	37.8663903456620616	-122.265162795849307
49227	2020-08-31 17:24:55	2020-08-31	Vinton Feeney V	vinton.feeney.v@geemail.com	Los Angeles	California	869903833833913875	3205422ce39088fd6afc7fa1d0a0be18	Mastercard	34.1097052000794534	-118.426643363106251
49228	2020-08-31 17:36:38	2020-08-31	Agatha Doyle	agatha.doyle@geemail.com	San Francisco	California	3037853445274637	011bc3f79bad41fc18eb0d5d7aaa5189	Voyager	37.7828824620477874	-122.430648444858392
49229	2020-08-31 17:37:20	2020-08-31	Tiny Tremblay	tiny.tremblay@geemail.com	Miami	Florida	51612189449334607	4543b08c787801648cc597071040725e	Maestro	25.6788276524886498	-80.2722582416948001
49230	2020-08-31 17:41:29	2020-08-31	Maddux Donnelly	maddux.donnelly@geemail.com	Brownsville	Texas	503871339551633	42e8a37eae2beff97c46d9cef8e72346	Diners Club / Carte Blanche	25.9472506941374377	-97.4041402774117842
49231	2020-08-31 17:44:47	2020-08-31	Dr. Refugio Armstrong	dr.refugio.armstrong@geemail.com	Westminster	Colorado	869977721913726336	d03b0e8f779fa3c05a57829e1857c6fe	Voyager	39.8400939789440471	-105.113153227945418
49232	2020-08-31 17:50:47	2020-08-31	Janessa Herman	janessa.herman@geemail.com	New York	New York	3000707628761132	40d18ff8125e24aa43782a8ff25275e1	JCB 16 digit	40.5684315107986322	-73.9761885608907761
49233	2020-08-31 17:51:42	2020-08-31	Katelyn Herman	katelyn.herman@geemail.com	Athens	Georgia	3054241409994189	4da0b598a0d6bcda2b82fd73c5da775d	American Express	33.9011724715776737	-83.3913400544900441
49234	2020-08-31 17:52:16	2020-08-31	Damari Johns	damari.johns@geemail.com	San Francisco	California	3088147222327642850	e105dfd7aa9282ce998087a09bf0e2c2	Maestro	37.7512571922773574	-122.454383199124635
49235	2020-08-31 17:57:28	2020-08-31	Eston Waters PhD	eston.waters.phd@woohoo.com	Santa Clara	California	869908979279776683	9e38b40f13b6b1570aab8ae081c0a65a	JCB 15 digit	37.4378082515023678	-121.880710326972974
49236	2020-08-31 17:59:01	2020-08-31	Aloma Zemlak	aloma.zemlak@woohoo.com	Vallejo	California	3337544344999191120	3089391bce04bc66c5cb924f165fc317	Voyager	38.0442134305458524	-122.16664005851932
49237	2020-08-31 18:08:34	2020-08-31	America Bahringer PhD	america.bahringer.phd@geemail.com	San Francisco	California	3454166170853729	52dabfc0236aad5b1d1d372d77357ce0	JCB 16 digit	37.7751124596356647	-122.433452208576924
49238	2020-08-31 18:24:46	2020-08-31	Kittie Dach	kittie.dach@geemail.com	Houston	Texas	3468453598890895	cb4d6adcd8a019a71b2e0bdaba128f27	VISA 13 digit	29.7744768423106514	-95.3608626254849128
49239	2020-08-31 18:25:49	2020-08-31	Hunt Rutherford	hunt.rutherford@geemail.com	Chicago	Illinois	6011145769043426986	896292db03878c1fbb444fe1a7d37cba	Diners Club / Carte Blanche	41.8165508343674261	-87.6087789688289149
49240	2020-08-31 18:38:30	2020-08-31	Dr. Coretta Monahan DDS	dr.coretta.monahan.dds@warmmail.com	Phoenix	Arizona	4497627312950	b7f35c857dab876a0787a0771956da8e	Discover	33.5284098997179427	-112.018884313984216
49241	2020-08-31 18:38:36	2020-08-31	Linzy Spinka Sr.	linzy.spinka.sr.@geemail.com	Chandler	Arizona	3337583422573598381	93db09f056fb6cccaa37e223f131cc64	VISA 16 digit	33.1884617980659016	-111.951289927342529
49242	2020-08-31 18:50:52	2020-08-31	Lindsey Windler	lindsey.windler@warmmail.com	Newark	New Jersey	4795517523084095	c1ffb9c32f5928deade7c3034c6a61d6	Discover	40.6442095778796855	-74.0875730912409693
49243	2020-08-31 18:52:08	2020-08-31	Miss Keli Ziemann PhD	miss.keli.ziemann.phd@geemail.com	Chicago	Illinois	4239503971883	621b5e6d20d46ad4c92e995da3d7ec25	JCB 16 digit	41.7641903403516892	-87.6832135360252067
49244	2020-08-31 19:00:29	2020-08-31	Unnamed Green	unnamed.green@geemail.com	New York	New York	869951266416324577	a17d41d06ac4c177ea580a800c225d17	VISA 16 digit	40.6196299453955163	-74.0164081257663611
49245	2020-08-31 19:01:42	2020-08-31	Jerilyn Carroll DDS	jerilyn.carroll.dds@geemail.com	New York	New York	6011458611871294832	817314f63c226f70a1b9b921d5637ee6	VISA 16 digit	40.7068586238883441	-74.0285108027875367
49246	2020-08-31 19:13:17	2020-08-31	Evelena Gislason	evelena.gislason@geemail.com	Syracuse	New York	4815826918980973	d1602cb6e7fd67560efe5ff07fc798f0	Maestro	43.0338105606231807	-76.2394051368128629
49247	2020-08-31 19:16:10	2020-08-31	Tyesha Welch-Braun	tyesha.welch.braun@geemail.com	Manchester	New Hampshire	4936242724430035	4b90a73758a125df15f9b5c653910e25	VISA 16 digit	42.9434938043426726	-71.4566680561643182
49248	2020-08-31 19:16:24	2020-08-31	Tatsuo Ernser	tatsuo.ernser@geemail.com	San Francisco	California	180009647752586080	05b31517ba486e27cffdadff9cb690ed	Maestro	37.7581988677628786	-122.40472390540117
49249	2020-08-31 19:19:10	2020-08-31	Samuel Kilback	samuel.kilback@woohoo.com	Nashville	Tennessee	3001805770970151	3c5fb31ef2b84b2283c992e4dc66252b	JCB 16 digit	36.1378457262303669	-86.8687590599898272
49250	2020-08-31 19:20:21	2020-08-31	Toby Beatty	toby.beatty@geemail.com	Chicago	Illinois	3464808428300734	b373a5043ee717b75cdc1f36f7f3709c	VISA 16 digit	41.8218986315954524	-87.7748137279909031
49251	2020-08-31 19:30:13	2020-08-31	Minoru Trantow	minoru.trantow@woohoo.com	Port St. Lucie	Florida	53434525368764397	dbbc8d12c8dea7e4f233e07ce6efc789	VISA 13 digit	27.2688603502366682	-80.4532365351069672
49252	2020-08-31 19:39:24	2020-08-31	Rogers Marvin	rogers.marvin@geemail.com	San Antonio	Texas	4518273560046300	5ad812b1a0a715c8f447dd48afb12853	JCB 16 digit	29.4616262612935174	-98.5180915027692805
49253	2020-08-31 19:42:15	2020-08-31	Miss Onnie Leffler	miss.onnie.leffler@geemail.com	Berkeley	California	3015409988750350	52363d468ad49e6f0adfba534624957a	JCB 16 digit	37.8663983719641308	-122.295320749146981
49254	2020-08-31 19:43:48	2020-08-31	Genie Kuhic-Gerlach	genie.kuhic.gerlach@geemail.com	Spokane	Washington	3112815605490607265	39fa88df668fd00aebb64fb09820952e	American Express	47.5740590420789999	-117.395697973146298
49255	2020-08-31 19:54:28	2020-08-31	Mr. Kennth Leannon I	mr.kennth.leannon.i@warmmail.com	New York	New York	4416669131505968	7d1f75d2e65021c213cc32b76a627b8d	Maestro	40.5718404493983797	-73.9927213711559801
49256	2020-08-31 19:56:59	2020-08-31	Autumn Green	autumn.green@geemail.com	Bellevue	Washington	3158856268331531044	1ea6dde0fbd4a84b9d41f0db59624d12	VISA 16 digit	47.6348697035755961	-122.150104218307874
49257	2020-08-31 19:57:57	2020-08-31	Kenny Lind	kenny.lind@geemail.com	Phoenix	Arizona	51705646906471287	6d0c1fddddd93006b1a25d35593ee816	VISA 13 digit	33.6375823087923251	-112.016898723731202
49258	2020-08-31 20:20:27	2020-08-31	Birdella Gusikowski	birdella.gusikowski@geemail.com	Lincoln	Nebraska	4609482532666562	f889c2d3c38cb7ceb686120bb2415cc1	Maestro	40.7919340351615105	-96.5820042699735666
49259	2020-08-31 20:27:57	2020-08-31	Misael Gleichner-Ortiz	misael.gleichner.ortiz@warmmail.com	Lincoln	Nebraska	676120467619464	d21e386d3f2cd859d6426ac572d3c1cd	JCB 16 digit	40.8848879304733117	-96.7030516956627366
49260	2020-08-31 20:32:03	2020-08-31	Mr. Ramiro Brown MD	mr.ramiro.brown.md@geemail.com	Fresno	California	4837509886722031	a8fcd62514213467d3b3a1bc971cbaa2	Voyager	36.7544601071964934	-119.775905139149728
49261	2020-08-31 20:33:09	2020-08-31	Jaidyn Mitchell-Metz	jaidyn.mitchell.metz@geemail.com	Berkeley	California	4186682812745	f2bd32ceddc724a4e74d5d527028a434	Diners Club / Carte Blanche	37.8752194317334769	-122.270087370441999
49262	2020-08-31 20:33:17	2020-08-31	Dr. Irwin O'Kon	dr.irwin.o'kon@geemail.com	San Francisco	California	4825721426208355	2b39d02b7ba585590e0fce8fdd072356	JCB 16 digit	37.760912939224724	-122.41160049269844
49263	2020-08-31 20:34:44	2020-08-31	Nolia Nolan	nolia.nolan@woohoo.com	Houston	Texas	4418522774096548	9c870f3594bbd087207db856dfcc1209	Voyager	29.8460459126703448	-95.4247496546260976
49264	2020-08-31 20:43:33	2020-08-31	Dr. Myrtis Stark DDS	dr.myrtis.stark.dds@geemail.com	Columbus	Georgia	4102367308339	a07af4b4d26b54fda7f3bc4f3987bb55	Discover	32.556318803787974	-84.9208297434892501
49265	2020-08-31 20:55:30	2020-08-31	Dr. Morris Waters	dr.morris.waters@geemail.com	Berkeley	California	4386988030161301	beecfa9d65f788831ca79a5d0b72dda7	VISA 16 digit	37.8512228231062409	-122.259502633705509
49266	2020-08-31 20:56:29	2020-08-31	Ruffin Metz	ruffin.metz@geemail.com	Cleveland	Ohio	869946621647945137	04334ca4f5bb6784278c9695ffb2acd0	VISA 16 digit	41.452661455733697	-81.7080647510249207
49267	2020-08-31 21:02:48	2020-08-31	Susannah Lubowitz-Leuschke	susannah.lubowitz.leuschke@geemail.com	Chicago	Illinois	3415135617685489	f6658ab47f1f89f64bf529269020698e	JCB 16 digit	41.7953913095708955	-87.6400907329313412
49268	2020-08-31 21:15:35	2020-08-31	Iris Bauch	iris.bauch@geemail.com	Los Angeles	California	180016256478497126	ffe7ef38dff73254f01a4ac8fabd49b1	JCB 15 digit	34.080969277849043	-118.335719993150974
49269	2020-08-31 21:15:43	2020-08-31	Miss Kiana Hamill	miss.kiana.hamill@geemail.com	Joliet	Illinois	4985345341848	be03338aefff3e780207308a385c91c6	JCB 15 digit	41.4620369517568506	-88.112476625769574
49270	2020-08-31 21:22:22	2020-08-31	Emilee Schaefer-Wolff	emilee.schaefer.wolff@geemail.com	Clinton	Michigan	3007391381025218	62951408f42b63510693d400cf44daf0	Maestro	42.4997693155027889	-82.9714975649565503
49271	2020-08-31 21:24:30	2020-08-31	Jeb Schaefer-Waelchi	jeb.schaefer.waelchi@geemail.com	Jacksonville	Florida	501815459343206	a8aff29e1d6c383c0b8ffc7d96db7c2f	VISA 16 digit	30.3278716298803701	-81.6214934595938786
49272	2020-08-31 21:45:08	2020-08-31	Anne Rodriguez MD	anne.rodriguez.md@warmmail.com	Tempe	Arizona	4571194083077	042f909c7cd1c5b7fd07d06e646f2612	JCB 16 digit	33.4570897384002777	-112.010527321419858
49273	2020-08-31 21:53:27	2020-08-31	Miss Daijah Huel DVM	miss.daijah.huel.dvm@warmmail.com	Miami	Florida	6011230803958329707	4f5b59c513c1ee327cf10df888eec8d6	Mastercard	25.7144580129671851	-80.1096502021294157
49274	2020-08-31 21:53:30	2020-08-31	Randi Predovic	randi.predovic@woohoo.com	Moreno Valley	California	3768445015756550	6292ea4cf47a8b6f2f26f8d8a72d953d	Maestro	33.9460943037170892	-117.185870391360297
49275	2020-08-31 22:05:18	2020-08-31	Barry Toy	barry.toy@woohoo.com	San Francisco	California	3473513402711042	45290b8b92f6aabb2ceadd083d854315	VISA 16 digit	37.8008693574476737	-122.443064198952854
49276	2020-08-31 22:10:18	2020-08-31	Benedict Hills	benedict.hills@warmmail.com	Moreno Valley	California	869974501232358992	e3451a7a3f158da54edc8b936195856b	Maestro	34.0088388527736072	-117.263772885777797
49277	2020-08-31 22:12:07	2020-08-31	Giovanni Larson	giovanni.larson@warmmail.com	Arlington	Texas	54340889107476710	9824de31c7b2878c4cf49b79015b48ec	JCB 15 digit	32.7599294822447007	-97.1186838960766892
49278	2020-08-31 22:22:39	2020-08-31	Kamari Ziemann	kamari.ziemann@geemail.com	Las Cruces	New Mexico	060449781575144	17d9706ef9eb3d6ca1c440e36f5bef2f	American Express	32.2452651307020304	-106.811639589176323
49279	2020-08-31 22:24:59	2020-08-31	Mrs. Sheila Quitzon MD	mrs.sheila.quitzon.md@geemail.com	Raleigh	North Carolina	4516138862580748	43545f051883d89405114b761ba4436b	VISA 13 digit	35.8635256200231609	-78.5451533324953175
49280	2020-08-31 22:29:19	2020-08-31	Kayden Pfannerstill	kayden.pfannerstill@woohoo.com	Detroit	Michigan	676213964261294	1cf6a4930d0916980a66ddf392d9c492	Diners Club / Carte Blanche	42.4533146608080756	-83.185589917155724
49281	2020-08-31 22:38:41	2020-08-31	Sage Mayer	sage.mayer@geemail.com	Rialto	California	3112802956580559295	9cec22fc69fede1e74d91d23641fd91e	Mastercard	34.1089225439570853	-117.325654371184484
49282	2020-08-31 22:45:19	2020-08-31	Doss Hackett IV	doss.hackett.iv@geemail.com	Los Angeles	California	4092604892503929	5055f7518971c61c1d6c2489e981ed0a	VISA 16 digit	33.9529102600045505	-118.369290501716733
49283	2020-08-31 23:10:16	2020-08-31	Lillianna Hettinger	lillianna.hettinger@geemail.com	San Francisco	California	4292143442118233	59efb46c381b4b216da938e28cd7d171	American Express	37.7733965495540147	-122.439927328382581
49284	2020-08-31 23:13:51	2020-08-31	Sigurd Block	sigurd.block@warmmail.com	Stockton	California	3088999504124978630	a07ed97568c3305c8ef5c4cd070e0b1d	American Express	37.9095197614479815	-121.357327972780169
49285	2020-08-31 23:17:09	2020-08-31	Rashad Turner IV	rashad.turner.iv@warmmail.com	Torrance	California	180075101236416190	b7e6174949bc9e949ae79fe2971a519a	JCB 15 digit	33.8288161225058133	-118.312834671245511
49286	2020-08-31 23:21:05	2020-08-31	Alwin Gleason-Yundt	alwin.gleason.yundt@geemail.com	San Francisco	California	3088870313804000523	b701d7364e4a33ea59917bfeca010188	JCB 16 digit	37.7993020889035449	-122.423544505007854
49287	2020-08-31 23:28:20	2020-08-31	Elfie Heidenreich DDS	elfie.heidenreich.dds@geemail.com	Olathe	Kansas	3088073923290265433	cfea0935a8a363c0228d0e9a10b50643	JCB 16 digit	38.9150417246513101	-94.7583536022976034
49288	2020-08-31 23:36:11	2020-08-31	Dr. Buddie Ebert I	dr.buddie.ebert.i@woohoo.com	Los Angeles	California	3449500321210157	9ffb45a9cec542aeed20a2b9569981f9	American Express	34.0597079227078652	-118.494928916403268
49289	2020-08-31 23:36:50	2020-08-31	Marlon Schmidt	marlon.schmidt@geemail.com	Philadelphia	Pennsylvania	3158790434419324632	c6f8844d455b6bac6dc53a63d5f56f2d	JCB 15 digit	39.9310518766712406	-75.0955606143821086
49290	2020-08-31 23:40:10	2020-08-31	Rhonda Langosh	rhonda.langosh@woohoo.com	Berkeley	California	4304353904248834	2a9c606a30c268c272affa71ce202f43	Diners Club / Carte Blanche	37.8803425821419069	-122.272470343095122
49291	2020-08-31 23:46:32	2020-08-31	Lex Bauch	lex.bauch@warmmail.com	Pembroke Pines	Florida	6011579634703796430	5c7158360a73dfb8bf3977eb26c60263	VISA 13 digit	26.0911796778943383	-80.4040100820731425
49292	2020-08-31 23:59:20	2020-08-31	Mrs. Josiephine Berge	mrs.josiephine.berge@geemail.com	Odessa	Texas	3467618975051862	8e7abddc15c272f82967f401c47aa230	JCB 16 digit	31.7880579778004453	-102.436977871382979
49293	2020-09-01 00:05:24	2020-09-01	Jacquelyn O'Hara	jacquelyn.o'hara@woohoo.com	Saint Paul	Minnesota	3096231241718358345	530ffd2731e754817c43353d278df8e1	JCB 16 digit	44.9844000388808567	-93.1187185190416926
49294	2020-09-01 00:06:17	2020-09-01	Mr. Hilton Sipes	mr.hilton.sipes@geemail.com	New York	New York	3096875710730764087	1d3f89601606d5c0f4dd3ffea7b9f5ce	JCB 16 digit	40.5739141092859228	-74.0106594716560124
49295	2020-09-01 00:11:20	2020-09-01	Trudi Koch-Hudson	trudi.koch.hudson@geemail.com	New York	New York	54660327323966588	ca1747c0f6516f725b80be6063b68515	American Express	40.7604029075931749	-73.9389929477952421
49296	2020-09-01 00:12:14	2020-09-01	Gwyn Rippin	gwyn.rippin@geemail.com	Oakland	California	6011309609679941431	07e7e0828d9668110ce63d42caa823cd	VISA 16 digit	37.7928628938640045	-122.304090628474057
49297	2020-09-01 00:24:51	2020-09-01	May Kuhn PhD	may.kuhn.phd@geemail.com	Portland	Oregon	3002562147152554	4bfc4ee35e67bda93ce158d70b449c7b	Diners Club / Carte Blanche	45.483230953186748	-122.704248283850035
49298	2020-09-01 00:28:50	2020-09-01	Tyrik Maggio I	tyrik.maggio.i@geemail.com	Houston	Texas	6011868286137362873	1faeeef655761d9fe8c8362ce76eeac6	JCB 15 digit	29.7466621527992174	-95.2917840342052358
49299	2020-09-01 00:31:15	2020-09-01	Willie Bartoletti	willie.bartoletti@woohoo.com	McKinney	Texas	3096035497031609115	7fc9fd983c6ceef3f3b354ea30f01682	Diners Club / Carte Blanche	33.2221987140961019	-96.7389156140219484
49300	2020-09-01 00:37:11	2020-09-01	Sophronia Mitchell	sophronia.mitchell@geemail.com	Shreveport	Louisiana	3337730877443584550	0f5955d31cc1e47eabc75cbdacef86c4	JCB 15 digit	32.4986828062921802	-93.7754380017265561
49301	2020-09-01 00:38:35	2020-09-01	Elvis Dibbert	elvis.dibbert@geemail.com	Pasadena	California	3455854690507722	6f3e2f45b98027a99f43945389202371	Diners Club / Carte Blanche	34.1597484999191039	-118.068110042792185
49302	2020-09-01 00:41:30	2020-09-01	Marlin Kessler-Zulauf	marlin.kessler.zulauf@geemail.com	Bakersfield	California	3088091261597850609	9ded05d1cf52f90c6c280889afe86be2	Diners Club / Carte Blanche	35.3470968314621601	-118.996191444228586
49303	2020-09-01 00:46:31	2020-09-01	Weaver Zboncak	weaver.zboncak@geemail.com	Columbus	Georgia	3337672230446632309	5ae8800212bda0e20935491905e9c131	Maestro	32.5511227381460344	-84.9508999142959738
49304	2020-09-01 00:49:33	2020-09-01	Lanette Willms	lanette.willms@geemail.com	New York	New York	3158798369044855505	ed8b92439755efac21d464346f7bf059	Diners Club / Carte Blanche	40.6834687452986827	-73.9562154574681045
49305	2020-09-01 00:49:39	2020-09-01	Axel D'Amore IV	axel.d'amore.iv@geemail.com	Norfolk	Virginia	4494315744081	07a479f8c8d2b1ff0d8d920ea823a8e8	Mastercard	36.8775861192978951	-76.2240520205352539
49306	2020-09-01 00:56:59	2020-09-01	Franklin Reynolds	franklin.reynolds@geemail.com	Columbus	Ohio	869902947248271058	72004da6c1517d82e8998b7cf010ceea	American Express	40.0642956553537388	-83.0508124220885406
49307	2020-09-01 00:57:16	2020-09-01	Breonna Beer	breonna.beer@geemail.com	Yonkers	New York	3414025635978522	7a4e05c20a8a20bf76b168fa2cf61186	Mastercard	41.0120719797179092	-73.855303267983345
49308	2020-09-01 01:02:15	2020-09-01	Leatha Emmerich	leatha.emmerich@woohoo.com	Fort Lauderdale	Florida	3013366396339998	756413c98cc24435c7be2d922dc21945	Maestro	26.0909930774465231	-80.0824498285360562
49309	2020-09-01 01:14:48	2020-09-01	Mr. Travis Bernhard	mr.travis.bernhard@geemail.com	Victorville	California	4198232589352930	f2392d1e066ce9ef362c3e2582c8e7fa	VISA 16 digit	34.5222931710302845	-117.389471636355296
49310	2020-09-01 01:16:07	2020-09-01	Mrs. Marian Kuphal MD	mrs.marian.kuphal.md@geemail.com	Mesquite	Texas	53014098874038456	ca8ceeed9a52ed62cdc6442ff0cc1f12	JCB 15 digit	32.7785063823029432	-96.5233930354669809
49311	2020-09-01 01:18:26	2020-09-01	Tobe Leannon-Kohler	tobe.leannon.kohler@geemail.com	San Francisco	California	630405978616349	a3a4719c7787ec7f641acaf8f822d246	JCB 15 digit	37.7537064737511727	-122.429924946867956
49312	2020-09-01 01:20:33	2020-09-01	Judson Feest	judson.feest@woohoo.com	Buffalo	New York	54998779870016733	6caf22ea918c915283b23919b8317bde	Mastercard	42.9141369313187866	-78.8618813585888603
49313	2020-09-01 01:22:23	2020-09-01	Trudie Bashirian	trudie.bashirian@geemail.com	Nashville	Tennessee	3031181361486407	4326901a9864208bf9e376cababc2034	Mastercard	36.1888022425241758	-86.7194074510037893
49314	2020-09-01 01:22:38	2020-09-01	Fuller Lehner-Grimes	fuller.lehner.grimes@geemail.com	Chicago	Illinois	3473658463608544	7c83d1bea907cbf04cc6eb0b403e0969	VISA 13 digit	41.7872004206594099	-87.7450933356333422
49315	2020-09-01 01:24:05	2020-09-01	Mr. Newt Franecki	mr.newt.franecki@geemail.com	Carlsbad	California	3023957282765195	fe35894dc5a30211069e42fb8eec30af	Voyager	33.170349030656368	-117.382455932188023
49316	2020-09-01 01:26:13	2020-09-01	Kamron Lakin IV	kamron.lakin.iv@geemail.com	Charlotte	North Carolina	3750457344066346	3d8e9c21b40d6f185ee0c700fbc0e105	Diners Club / Carte Blanche	35.2850279818076658	-80.9192560974918393
49317	2020-09-01 01:29:57	2020-09-01	Ms. Josefina Johnston	ms.josefina.johnston@geemail.com	Milwaukee	Wisconsin	3720065524647541	6d45a49e71eccb02e4ea90701d091e56	JCB 15 digit	43.1441446687646177	-88.0415238992877391
49318	2020-09-01 01:35:28	2020-09-01	Coolidge Balistreri-Maggio	coolidge.balistreri.maggio@warmmail.com	Spokane	Washington	54469704775201891	df598c6c5dcfce66adabe22847bd854b	JCB 15 digit	47.6018858117289838	-117.464516962169853
49319	2020-09-01 01:38:03	2020-09-01	Ms. Lorayne Kulas MD	ms.lorayne.kulas.md@geemail.com	Omaha	Nebraska	55503832415971561	95e75d9a2b87a98108022c9f4f384705	Voyager	41.167554289675877	-96.0685781062696122
49320	2020-09-01 01:38:41	2020-09-01	Kami Ullrich	kami.ullrich@geemail.com	New York	New York	869934587100441894	12d8c77ad60c52fd9af29ea604d760fa	American Express	40.7152932042945181	-73.8874587444484234
49321	2020-09-01 01:41:35	2020-09-01	Kenney Kilback	kenney.kilback@geemail.com	Milwaukee	Wisconsin	6011955629342143949	790e7697a81eceac603d09959dcca320	VISA 16 digit	43.106953916707262	-87.9746027429688695
49322	2020-09-01 01:48:56	2020-09-01	Bentley Rempel	bentley.rempel@woohoo.com	Anaheim	California	4342999339167	6ae67093015a9eedc22512f0c4dae611	VISA 16 digit	33.9024336422625936	-117.850856849572054
49323	2020-09-01 01:49:20	2020-09-01	Lonna D'Amore	lonna.d'amore@geemail.com	Jackson	Mississippi	6011399226318347606	a31504bebcfe564b2243375592cc13a8	American Express	32.3139160495430247	-90.312764862922208
49324	2020-09-01 01:52:30	2020-09-01	Gaines McCullough-Doyle	gaines.mccullough.doyle@woohoo.com	Oakland	California	3096692374066029994	7913d2921256796c3b25a0b34b872d72	Discover	37.8073764397261698	-122.253318515141473
49325	2020-09-01 01:54:27	2020-09-01	Almyra Hayes	almyra.hayes@geemail.com	Durham	North Carolina	3711096380932926	8d609d142986906dad3f04ba22ff8278	American Express	35.9683129570692728	-78.8326285375650997
49326	2020-09-01 01:55:24	2020-09-01	Huy Ritchie II	huy.ritchie.ii@geemail.com	New York	New York	3725113427779006	aa9159b85190ca3f59e1c93f6437e68c	VISA 13 digit	40.7356409741789065	-73.9637272422097567
49327	2020-09-01 01:56:20	2020-09-01	Phillis Blick	phillis.blick@geemail.com	Oklahoma City	Oklahoma	6011146810082925105	45d1cc1c81168c77370a12865c466c8d	Voyager	35.4685809297397725	-97.4305540226761195
49328	2020-09-01 01:57:51	2020-09-01	Mr. Deshaun Carroll Jr.	mr.deshaun.carroll.jr.@geemail.com	Stockton	California	3337853541175805937	a2160c9c79ae5a7b05f315042b934591	Maestro	37.8965769924420854	-121.218768942318107
49329	2020-09-01 02:09:15	2020-09-01	Tula Sanford	tula.sanford@geemail.com	South Bend	Indiana	4783685513488685	00a3557224f67960179d7e9d8f09187f	JCB 16 digit	41.6832021479174557	-86.2176241018399594
49330	2020-09-01 02:11:48	2020-09-01	Maxwell Schuppe-Harber	maxwell.schuppe.harber@warmmail.com	Sioux Falls	South Dakota	3337888255168039888	17395c20859d818d687a0c7a09474e4b	Maestro	43.5368804722644356	-96.7290682773739121
49331	2020-09-01 02:23:59	2020-09-01	Julio Heaney	julio.heaney@geemail.com	McKinney	Texas	3096807467309668024	383544e19f1fb2fdd14c84cbf2d3be10	Mastercard	33.1685441436376465	-96.7308583199810244
49332	2020-09-01 02:24:41	2020-09-01	Tod Luettgen-Vandervort	tod.luettgen.vandervort@geemail.com	San Francisco	California	3088364575504629099	d91c2c81f961966233ff23894837801e	JCB 16 digit	37.7713872644651261	-122.433690172712005
49333	2020-09-01 02:25:12	2020-09-01	Iva Oberbrunner	iva.oberbrunner@geemail.com	Atlanta	Georgia	51279690612953804	54e7a3d9a88d80d03c18eb043ddc31ab	JCB 16 digit	33.7909080667696884	-84.3520529303278863
49334	2020-09-01 02:32:05	2020-09-01	Candy Heaney-Reinger	candy.heaney.reinger@geemail.com	Springfield	Illinois	3088161836057929913	44f40f74205e43f8d5e0d386c13dd6df	JCB 16 digit	39.8165011984914514	-89.5879724220376374
49335	2020-09-01 02:32:58	2020-09-01	Christophe Leuschke	christophe.leuschke@geemail.com	San Francisco	California	869914961196496290	cca5aae72eac733306da6dc110f69556	VISA 16 digit	37.7844851125097065	-122.411623097433917
49336	2020-09-01 02:37:52	2020-09-01	Angelita Konopelski-Batz	angelita.konopelski.batz@geemail.com	Overland Park	Kansas	4036788539892	e29da1fdc42014c626660df90a01461b	VISA 13 digit	38.8203047635834722	-94.6185089179821404
49337	2020-09-01 02:41:20	2020-09-01	Fernando Cummerata	fernando.cummerata@geemail.com	Fargo	North Dakota	51763011033235064	a64d1ac956231a03a0b829d631b46506	JCB 16 digit	46.8396481440633536	-96.7824184973686812
49338	2020-09-01 02:41:34	2020-09-01	Abbigail Ortiz-Yundt	abbigail.ortiz.yundt@geemail.com	Chicago	Illinois	3528586621086216939	01f90e463cbbe213fe4b833dbf24e3cf	Mastercard	41.8898022166755055	-87.7792209766369211
49339	2020-09-01 02:45:48	2020-09-01	Marina Schmeler	marina.schmeler@geemail.com	Victorville	California	210088320666773236	81f893494bf8723e0914370b69a78db7	American Express	34.4795445563037006	-117.406690090164915
49340	2020-09-01 02:46:41	2020-09-01	Lular Ebert	lular.ebert@geemail.com	Colorado Springs	Colorado	3015914745489895	4b120a884c17fb2afc5b36bd687831e6	VISA 13 digit	38.8846628462944182	-104.687513830574972
49341	2020-09-01 02:52:36	2020-09-01	Miss Roseanna Ruecker DVM	miss.roseanna.ruecker.dvm@woohoo.com	Daly City	California	4595737276534	8acaf88055dca7c1cd5b11b8bd46f35f	American Express	37.6842055543247554	-122.457540942970667
49342	2020-09-01 02:53:19	2020-09-01	Edgar Kassulke	edgar.kassulke@geemail.com	New York	New York	55090363732269983	52694fffcfc886030d17dee0707cf23c	Diners Club / Carte Blanche	40.5692774612214393	-73.9996171831980263
49343	2020-09-01 02:57:14	2020-09-01	Hazelle Goyette DDS	hazelle.goyette.dds@woohoo.com	Chicago	Illinois	6011961620339377725	1e16d1998ae94694fd6cb0195efc6c27	Voyager	41.8629410689067143	-87.6942040523543938
49344	2020-09-01 03:00:34	2020-09-01	Pandora Lubowitz	pandora.lubowitz@woohoo.com	Los Angeles	California	3407748620414216	e873f864888e5aff6af0e6a862220794	VISA 16 digit	34.1032514604140076	-118.468640874651442
49345	2020-09-01 03:23:46	2020-09-01	Imogene Tromp	imogene.tromp@geemail.com	Virginia Beach	Virginia	502053670145035	aeb3b801fc59839e2578b37df2186442	American Express	36.6897677545156355	-76.0999746914159516
49346	2020-09-01 03:25:37	2020-09-01	Quinton Collins-Gusikowski	quinton.collins.gusikowski@woohoo.com	Los Angeles	California	4179421355704910	f937eadc4994e90d27ae697ab43267f4	Mastercard	33.9881809465452989	-118.31603590641096
49347	2020-09-01 03:27:40	2020-09-01	Adel Buckridge	adel.buckridge@geemail.com	Pasadena	California	180003296542479036	80675787ec6d05a7a8e8c9e8ccffe164	Voyager	34.2444289115577973	-118.058562560035284
49348	2020-09-01 03:28:02	2020-09-01	Mr. Messiah Ledner DDS	mr.messiah.ledner.dds@woohoo.com	Mesa	Arizona	676334390731882	1ac58445aa35bc75836f0f0f5477372a	Diners Club / Carte Blanche	33.3594706036761366	-111.801411877933518
49349	2020-09-01 03:29:39	2020-09-01	Jamil Heathcote	jamil.heathcote@warmmail.com	Houston	Texas	4891582370165432	330e1ac9c1f0c8d80c617d4b600e79c0	Diners Club / Carte Blanche	29.7523017544377595	-95.3649861526690472
49350	2020-09-01 03:46:52	2020-09-01	Lovina Tillman-Jones	lovina.tillman.jones@geemail.com	Fayetteville	North Carolina	4033229350778458	eb55c2d1cae7d534a8eaf1fca6dc4b0c	JCB 15 digit	35.1089376429349187	-79.01053829040751
49351	2020-09-01 03:51:21	2020-09-01	Riya Beatty	riya.beatty@geemail.com	New York	New York	3766144232249075	c794f118bc4c196ddb3352f254a59902	Voyager	40.7398151973485909	-73.9501104443695425
49352	2020-09-01 03:51:21	2020-09-01	Lori Hansen	lori.hansen@geemail.com	Los Angeles	California	3750282490552943	e8e1cb6815f5836152ff08eb34c87776	Voyager	34.1000164751295003	-118.464217716734112
49353	2020-09-01 03:52:59	2020-09-01	Elijah Huel	elijah.huel@geemail.com	Los Angeles	California	869920733546250699	01249fed43baf13467eb1a8de22983b7	Maestro	33.9301904343400125	-118.400275571271024
49354	2020-09-01 03:53:32	2020-09-01	Dannie Rippin-McCullough	dannie.rippin.mccullough@geemail.com	Clovis	California	3337259249502791800	3c417ef9be542314ad98a4dfc8477e7f	JCB 16 digit	36.8329421356663147	-119.668661919708924
49355	2020-09-01 03:54:11	2020-09-01	Rustin Trantow	rustin.trantow@geemail.com	Chicago	Illinois	3043789287981158	6e092968ecf371a834028d0493444f42	VISA 16 digit	41.8962765492334981	-87.6749095309089768
49356	2020-09-01 03:55:15	2020-09-01	Dr. Harlan Sipes MD	dr.harlan.sipes.md@geemail.com	Philadelphia	Pennsylvania	54665089057095944	8a764d0d1b706e2009108b07903a063a	Mastercard	40.0062861386645565	-75.1308437287241304
49357	2020-09-01 04:04:47	2020-09-01	Miss Tabitha Rau	miss.tabitha.rau@geemail.com	Downey	California	3406151634048313	3afcf226176bf7f78c80d86fed6dc57b	JCB 16 digit	33.8745888151012409	-118.099559275304529
49358	2020-09-01 04:04:51	2020-09-01	Bailey Upton	bailey.upton@geemail.com	San Antonio	Texas	4446909279676	3574bd0524ff086a38b8a4993f10ef8d	Diners Club / Carte Blanche	29.5541698527127501	-98.5561754972975592
49359	2020-09-01 04:10:34	2020-09-01	Clemma Quitzon-Rolfson	clemma.quitzon.rolfson@geemail.com	Jackson	Mississippi	502036390202145	172035136af519d330e1c2b4ffd0b23d	JCB 16 digit	32.2525190194316238	-90.2275956076543793
49360	2020-09-01 04:20:42	2020-09-01	Harlow Swift	harlow.swift@geemail.com	Seattle	Washington	4525871471873687	625fc2fcd7a2a790977d39beb305da46	Mastercard	47.5846502528917057	-122.423880173677205
49361	2020-09-01 04:21:54	2020-09-01	Miss Zoa Morar	miss.zoa.morar@warmmail.com	San Francisco	California	4240764390659812	af88d3b80dfe48de10a48733990c6551	Diners Club / Carte Blanche	37.8047119609118667	-122.396329518218522
49362	2020-09-01 04:25:10	2020-09-01	Khalil Schneider	khalil.schneider@woohoo.com	Kent	Washington	3096317698985493534	2699b4bf99d7e2e75f0c94783d6dda85	American Express	47.347386584861205	-122.13368462171853
49363	2020-09-01 04:30:47	2020-09-01	Nathen Abbott	nathen.abbott@geemail.com	Warren	Michigan	3420845235819822	b1760d3d2ba4a1736d87a984c5c04873	American Express	42.5164500792507098	-83.0087000939995079
49364	2020-09-01 04:31:07	2020-09-01	Dr. Darrel Jast II	dr.darrel.jast.ii@woohoo.com	Wichita	Kansas	3770129812837658	82734e9f811698e0e80e4b12ed0ba113	American Express	37.7253586768049729	-97.3102912529107158
49365	2020-09-01 04:46:49	2020-09-01	Velma Konopelski DVM	velma.konopelski.dvm@geemail.com	Los Angeles	California	6011150507962506681	8e488d5569ef034906ba4778f0fd0c62	Diners Club / Carte Blanche	33.974806471947204	-118.410007298364491
49366	2020-09-01 04:49:45	2020-09-01	Nichelle Williamson-Wiza	nichelle.williamson.wiza@geemail.com	Los Angeles	California	676204303349080	3aa4e4888c95c6cbe1351a3171cebb6c	Discover	34.0604667587071646	-118.3750067185603
49367	2020-09-01 04:52:47	2020-09-01	Dr. Vince Schuster III	dr.vince.schuster.iii@warmmail.com	Dayton	Ohio	6011701301554872378	0d40a000a1316570335d13e7b8b59a1b	JCB 15 digit	39.7113102967642249	-84.1788218118440454
49368	2020-09-01 04:59:19	2020-09-01	Clemence Parisian	clemence.parisian@geemail.com	Indianapolis	Indiana	4113754453437713	9a2f6bd5abb6feb576d87b2d1989023f	JCB 16 digit	39.8027215274058292	-86.1471675370555374
49369	2020-09-01 05:05:59	2020-09-01	Arvid Roberts	arvid.roberts@geemail.com	Houston	Texas	210000668290597420	15aeffb6468c9fa091bf9af83875fb12	Maestro	29.8215982299376279	-95.4226727359943112
49370	2020-09-01 05:15:28	2020-09-01	Mr. Rowan Feil Jr.	mr.rowan.feil.jr.@geemail.com	Nashville	Tennessee	869965564475771231	e8746b1cc726ed401be237d9501ed06f	Maestro	36.0757688528515388	-86.8744291410688305
49371	2020-09-01 05:17:25	2020-09-01	Jaylon Marks	jaylon.marks@geemail.com	New York	New York	3745853117176551	06f550fbdb28575bf29f55aead636c5b	Discover	40.6442117115706196	-73.8578271900199326
49372	2020-09-01 05:20:21	2020-09-01	Mrs. Jeana Reinger	mrs.jeana.reinger@geemail.com	Jacksonville	Florida	180042269538459547	51759ea136e372d2f77c95055186984d	Discover	30.3881303848750903	-81.7002536681093403
49373	2020-09-01 05:21:00	2020-09-01	Jameel Balistreri	jameel.balistreri@geemail.com	Phoenix	Arizona	3000787918878564	ffd94b049588ca936db972dba7a51569	American Express	33.6655323780074767	-112.017351775655897
49374	2020-09-01 05:22:58	2020-09-01	Leticia Rosenbaum PhD	leticia.rosenbaum.phd@geemail.com	Omaha	Nebraska	4535434368709999	fc4ca720e2514fc93cecfa726cd37565	JCB 16 digit	41.35670824089609	-95.9930959794785821
49375	2020-09-01 05:23:41	2020-09-01	Arthur Anderson	arthur.anderson@warmmail.com	Santa Clarita	California	3413234084016310	05cb0a5b1034abcf6b331489dd53bb27	VISA 13 digit	34.4211379045359749	-118.572231679000708
49376	2020-09-01 05:26:36	2020-09-01	Dr. Waymon Lesch	dr.waymon.lesch@geemail.com	San Jose	California	869973968272488669	50e1e5c53cc07218ffab24b13cac2ad2	American Express	37.3183412307694553	-121.725522360832983
49377	2020-09-01 05:34:15	2020-09-01	Elvie Schneider	elvie.schneider@geemail.com	Raleigh	North Carolina	4628295080137	43d5252a1210ac9d943fa5a259652563	JCB 16 digit	35.7719146866951121	-78.7180655466329284
49378	2020-09-01 05:34:17	2020-09-01	Vena Swift-Wuckert	vena.swift.wuckert@geemail.com	Tucson	Arizona	52989482123113990	9b39191a90da11b8add373fe50377331	VISA 13 digit	32.1957360731478772	-110.895398750784238
49379	2020-09-01 05:35:23	2020-09-01	Mitchel Sawayn	mitchel.sawayn@geemail.com	Colorado Springs	Colorado	3337021840066502547	41fc4db9c4921b6938768389424954e2	Discover	38.8028427394155386	-104.783456205499178
49380	2020-09-01 05:35:41	2020-09-01	Lum Kshlerin	lum.kshlerin@geemail.com	Modesto	California	210027944655894580	74c4d1be89d02b47f92f5d880902c8d9	JCB 15 digit	37.6119546487461776	-121.004987840840599
49381	2020-09-01 05:40:23	2020-09-01	Esmeralda Franecki	esmeralda.franecki@geemail.com	Little Rock	Arkansas	589373990746783	d025a4c06fcc4ba4e386abda9e4d844b	Discover	34.6285533249653881	-92.3224437696266875
49382	2020-09-01 05:43:32	2020-09-01	Hideo Corkery-Ullrich	hideo.corkery.ullrich@geemail.com	Dallas	Texas	4316920485114027	0cb3aa1df02add8cedfdf6bf29d4d3df	American Express	32.8377637092761745	-96.7182359497491149
49383	2020-09-01 05:53:05	2020-09-01	Colton Funk	colton.funk@warmmail.com	Hialeah	Florida	3007808963718753	bce6eb8bb77602735ccb57471b5b73b0	VISA 16 digit	25.9113204543456455	-80.2675658416371789
49384	2020-09-01 06:07:35	2020-09-01	Knox Hamill-Hoppe	knox.hamill.hoppe@geemail.com	Irvine	California	589335835755147	cd086ea733ef1bc55baa3041a2719431	JCB 16 digit	33.6669360066313317	-117.683216937492787
49385	2020-09-01 06:10:23	2020-09-01	Marshal Price-Marks	marshal.price.marks@warmmail.com	Tulsa	Oklahoma	4681484899162848	bff6ba76696876fba4a332f288b88f0d	VISA 13 digit	36.1682734699357269	-95.8153469113588301
49386	2020-09-01 06:12:09	2020-09-01	Ansel Schumm-Jakubowski	ansel.schumm.jakubowski@geemail.com	San Francisco	California	52271745896770098	ab7db90e819effd50870d09304ca2ed5	VISA 16 digit	37.7807105921250468	-122.417264234237066
49387	2020-09-01 06:31:05	2020-09-01	Cesar Hoeger	cesar.hoeger@geemail.com	Saint Paul	Minnesota	51270848639671085	7e126daf4ba813075fc7b747f051db7a	Discover	44.9231288871668326	-93.1111550254080527
49388	2020-09-01 06:32:16	2020-09-01	Dennis Wilkinson	dennis.wilkinson@geemail.com	Chicago	Illinois	180025576445852338	91196f59bcf913010f7d486f51bc37be	Diners Club / Carte Blanche	41.7999404346406465	-87.58726409841627
49389	2020-09-01 06:33:49	2020-09-01	Dr. Toriano McClure	dr.toriano.mcclure@geemail.com	Vallejo	California	3112882415028938119	aaeada9af50eb64b8d27eca4e97dac34	JCB 15 digit	38.098607449242472	-122.240468763779845
49390	2020-09-01 06:34:24	2020-09-01	Uriel Jerde-Klocko	uriel.jerde.klocko@geemail.com	Chicago	Illinois	3158098413852722774	a8e1502fbc2b6aad400f93c82481929a	VISA 16 digit	41.7927353636197765	-87.5841505578283233
49391	2020-09-01 06:40:51	2020-09-01	Miss Flossie Dietrich	miss.flossie.dietrich@geemail.com	Pembroke Pines	Florida	210014230562011418	f2d6a5396aa01e3c17a6f6287a82773d	Voyager	26.0358106931708768	-80.247079574493327
49392	2020-09-01 06:42:00	2020-09-01	Sheree Schroeder	sheree.schroeder@woohoo.com	Pembroke Pines	Florida	869924455464153350	b8406a619fabaafe296e13e9e2ead3a0	Diners Club / Carte Blanche	25.9878438737280675	-80.3135447415426427
49393	2020-09-01 06:46:48	2020-09-01	Clotilde Mertz	clotilde.mertz@geemail.com	Dallas	Texas	3701450254727056	e8d23f49bc196466464f6e10806d520e	JCB 16 digit	32.8298109074395157	-96.7283157176766508
49394	2020-09-01 06:48:55	2020-09-01	Golden Hudson	golden.hudson@geemail.com	El Paso	Texas	210036218776509172	82972a874618869bf7e80be0f1c5c7b8	Maestro	31.7987152726683782	-106.401648197274667
49395	2020-09-01 06:49:12	2020-09-01	Susanna Pagac	susanna.pagac@geemail.com	Glendale	Arizona	4312307065697	4557842fa9f2d149b412c41f08cb5118	JCB 16 digit	33.4350523744471317	-112.131213303774217
49396	2020-09-01 06:51:44	2020-09-01	Lu Klein	lu.klein@geemail.com	San Francisco	California	676177291945960	e6547d79124bd6de3ed8bac98541fb98	VISA 16 digit	37.7522844285648134	-122.471677065493012
49397	2020-09-01 07:02:57	2020-09-01	Dr. Rakeem Jacobs DVM	dr.rakeem.jacobs.dvm@geemail.com	Los Angeles	California	869986861314239551	5bb6f18dd8cf4f7b03991835343cf84e	Maestro	33.9902701456896921	-118.342152880503974
49398	2020-09-01 07:04:31	2020-09-01	Atlas Borer MD	atlas.borer.md@geemail.com	Omaha	Nebraska	4595955829089	69cc4c0041f3947de6619db10bcef4b6	VISA 16 digit	41.1678205666277606	-95.947058960201602
49399	2020-09-01 07:06:55	2020-09-01	Guido Zulauf	guido.zulauf@geemail.com	Aurora	Colorado	060499522628637	e741abf74c79095539ec37b15f3f9bf5	Discover	39.703665005007764	-104.664880298928168
49400	2020-09-01 07:11:46	2020-09-01	Taryn Quitzon	taryn.quitzon@geemail.com	Toledo	Ohio	3019925749565833	10e336004005b73b122f8c1cb762ae93	Mastercard	41.7521109064746625	-83.6032085851166471
49401	2020-09-01 07:19:08	2020-09-01	Mr. Zed Stark	mr.zed.stark@geemail.com	San Francisco	California	53272382778250418	f77a2f393c38105f2385fc6a29f3ba05	Discover	37.7328260554447823	-122.391966838942224
49402	2020-09-01 07:29:10	2020-09-01	Hennie Abbott	hennie.abbott@woohoo.com	Baltimore	Maryland	3528872108536672096	99a3e8e7e97542033da334793596bd77	JCB 16 digit	39.2829277477692784	-76.6073847352080008
49403	2020-09-01 07:47:19	2020-09-01	Lilburn Bergstrom Jr.	lilburn.bergstrom.jr.@woohoo.com	Murrieta	California	3765980742410363	255ed5b7ec75fa8968c13bb7585b31d1	VISA 16 digit	33.5313628905083974	-117.178402429017794
49404	2020-09-01 07:49:19	2020-09-01	Ballard Orn	ballard.orn@woohoo.com	New York	New York	53092163932427615	a808a4fb26dc435328bf52e863764abb	VISA 13 digit	40.6611992328185607	-73.8859046149894567
49405	2020-09-01 07:52:25	2020-09-01	Daryl Keeling	daryl.keeling@geemail.com	Riverside	California	3492905391669917	13e258ef525e68abd312a2def6875763	Diners Club / Carte Blanche	33.9747404145490393	-117.320874935245882
49406	2020-09-01 07:52:46	2020-09-01	Corrina Schumm-Hayes	corrina.schumm.hayes@geemail.com	Oakland	California	4776279179476090	b6aa95fd15b9036ce6ab7a2274e99d3e	VISA 13 digit	37.7990061789527871	-122.274500695105601
49407	2020-09-01 07:54:51	2020-09-01	Libby Blanda	libby.blanda@geemail.com	Philadelphia	Pennsylvania	4125610193085699	c382cc739848f6e2f7575bcc618422ed	VISA 16 digit	39.9616887974046193	-75.1030241992689724
49408	2020-09-01 07:56:00	2020-09-01	Ardeth McCullough	ardeth.mccullough@geemail.com	Hayward	California	3709950533395924	dded62099d542e1691d4f22b9e26e2e3	Maestro	37.6340677370306125	-122.1484286569316
49409	2020-09-01 07:56:06	2020-09-01	Gilbert Gottlieb III	gilbert.gottlieb.iii@woohoo.com	Cleveland	Ohio	54871051053327267	96148448bb2bb007ebd4d6cb8a4045b0	American Express	41.4243880465011998	-81.7179741957463364
49410	2020-09-01 08:16:35	2020-09-01	Danna Hintz	danna.hintz@woohoo.com	Berkeley	California	4549521542122	beb642d207d58c95e25e346ca2c1c700	VISA 16 digit	37.8897975137953154	-122.263266827798461
49411	2020-09-01 08:25:30	2020-09-01	Danny Carroll	danny.carroll@woohoo.com	Los Angeles	California	3112592935325744457	bafa97f060a964ede6185e164a422d4a	JCB 16 digit	34.007987504159658	-118.416239206026489
49412	2020-09-01 08:25:51	2020-09-01	Dr. Esau Schiller PhD	dr.esau.schiller.phd@geemail.com	Los Angeles	California	210098171502382825	8a63acd2da68ad21ca823d1c756bf076	VISA 13 digit	33.9618883320927623	-118.341688654338185
49413	2020-09-01 08:26:03	2020-09-01	Zaid Schuster-Reichel	zaid.schuster.reichel@geemail.com	Oakland	California	561228057431299	5e67944a4f2ab7e8964e4771e0a55b5e	VISA 13 digit	37.8543021737772776	-122.292451021921295
49414	2020-09-01 08:30:54	2020-09-01	Shamar Weissnat PhD	shamar.weissnat.phd@geemail.com	Madison	Wisconsin	3088077229826285598	cbcc245299a1c8107ad3ad012f273c41	VISA 16 digit	43.0425990483697518	-89.3933698968380668
49415	2020-09-01 08:33:02	2020-09-01	Jettie Olson	jettie.olson@geemail.com	West Covina	California	3096161145781625189	3e852611c78b2bf8c853d7cd599b74ec	VISA 13 digit	34.1332930548690285	-117.949763337436679
49416	2020-09-01 08:36:34	2020-09-01	Mr. Dequan Hane	mr.dequan.hane@geemail.com	Garland	Texas	4033934212655865	abd614592c1901d3e5d76edd6a5c751e	American Express	32.905994473048672	-96.6493489332657418
49417	2020-09-01 08:41:12	2020-09-01	Ms. Hanna Balistreri	ms.hanna.balistreri@geemail.com	Akron	Ohio	55169549843329841	be69560a5e240d4326679517b88c949f	Voyager	41.1009750002361827	-81.4827215729594201
49418	2020-09-01 08:42:33	2020-09-01	Ether Bahringer	ether.bahringer@geemail.com	Miami	Florida	676158942456102	1a05f023d1557c0dc6bd74b8ffb15bd9	VISA 16 digit	25.680343813230099	-80.2943078046537977
49419	2020-09-01 08:46:46	2020-09-01	Ms. Carlotta McLaughlin	ms.carlotta.mclaughlin@geemail.com	Indianapolis	Indiana	3028973475686929	ea8932e1218a88b08d8a9967b44645b6	Diners Club / Carte Blanche	39.6784613544128817	-86.2255288607176311
49420	2020-09-01 08:52:41	2020-09-01	Reggie Nicolas	reggie.nicolas@woohoo.com	North Charleston	South Carolina	6011282008408989137	e1482501a328fc28cf6246c42689ff4b	Diners Club / Carte Blanche	32.8520453460674702	-79.9819278331100918
49421	2020-09-01 09:03:18	2020-09-01	Hazen Hoppe	hazen.hoppe@geemail.com	Houston	Texas	3096206951944496765	998a0d31491f72ae350a6cd09f57318f	Mastercard	29.8865129546806223	-95.4191693555113005
49422	2020-09-01 09:06:55	2020-09-01	Burns Steuber	burns.steuber@geemail.com	New York	New York	180086349756886881	4c1814b52bd71a1c7a7ffd179d2b8a4d	VISA 16 digit	40.6345981885436913	-73.9064708952221991
49423	2020-09-01 09:18:32	2020-09-01	Dr. Shad Prosacco V	dr.shad.prosacco.v@geemail.com	Stockton	California	3768586268876460	75447920637a1a66ee56157fe95ca6d0	JCB 16 digit	38.044970833064248	-121.255953286969287
49424	2020-09-01 09:19:06	2020-09-01	Imo Barrows-Boyle	imo.barrows.boyle@warmmail.com	New York	New York	3112683347583301204	afe61e76116af8417c322cb88cee4a92	VISA 16 digit	40.6412960531413532	-73.8861133554380416
49425	2020-09-01 09:23:42	2020-09-01	Monica Purdy	monica.purdy@woohoo.com	San Francisco	California	180096831769809412	5c5b4e4d786ea03ed52f288304457583	VISA 16 digit	37.7842108554649911	-122.428314097590089
49426	2020-09-01 09:28:10	2020-09-01	Channing Graham	channing.graham@woohoo.com	Macon	Georgia	869993372837364000	7baaacfc853e9f0805c6128e4a90ce20	JCB 16 digit	32.8634289391349981	-83.7595189905919142
49427	2020-09-01 09:31:20	2020-09-01	Anastacio Lubowitz PhD	anastacio.lubowitz.phd@woohoo.com	El Paso	Texas	4486640744651163	c9a68103f68b2e7d2df389a0ddbbf967	Discover	31.9250332264989645	-106.339912112614144
49428	2020-09-01 09:33:08	2020-09-01	Adonis Williamson	adonis.williamson@geemail.com	San Diego	California	4307624114400	1b5eb92d28d390d1e3f39600b8249615	American Express	32.7434389069743474	-117.203959496589377
49429	2020-09-01 09:34:28	2020-09-01	Lauryn Davis MD	lauryn.davis.md@geemail.com	Athens	Georgia	4086742330878236	d4de9fb9a6835a0b427d1158e6fc561f	JCB 15 digit	33.9237318895015818	-83.3605350802767902
49430	2020-09-01 09:45:46	2020-09-01	Dr. Allena Ullrich	dr.allena.ullrich@geemail.com	Boston	Massachusetts	3337761648549702897	82ca6c7faf1111e6836482ff6e27af6e	Mastercard	42.4249686178453302	-71.0935817888889545
49431	2020-09-01 09:46:11	2020-09-01	Joella Nitzsche	joella.nitzsche@geemail.com	Orlando	Florida	3022156332272408	189388a1e5c259b98a6a4ba2b8b5914f	VISA 13 digit	28.3171845114588727	-81.2392833861023149
49432	2020-09-01 10:06:28	2020-09-01	Vernice Koelpin	vernice.koelpin@warmmail.com	Fort Worth	Texas	53946122529321282	a38eac88b0b3937070307b5e7fbe724b	VISA 16 digit	32.8339690481834126	-97.3116416849017156
49433	2020-09-01 10:10:10	2020-09-01	Dylon Keeling	dylon.keeling@geemail.com	Jersey City	New Jersey	675908474527804	58627060b1126e7462747795496851a0	Discover	40.772460719005764	-74.0552273542575534
49434	2020-09-01 10:20:11	2020-09-01	Orie Auer	orie.auer@woohoo.com	Escondido	California	869961165719541333	cf468ef2ea1271c689833fcbee31ce23	Voyager	33.0349249203450981	-117.061159136217086
49435	2020-09-01 10:28:59	2020-09-01	Dr. Anya Roob	dr.anya.roob@geemail.com	Wichita	Kansas	210005178796407822	33873307a1e95aa0164c39f7ffb7aea9	VISA 13 digit	37.7799808544915194	-97.2541050349097702
49436	2020-09-01 10:31:22	2020-09-01	Zachery Kassulke	zachery.kassulke@geemail.com	Fort Lauderdale	Florida	53572189790631393	b3cfe5715fb278bbc33dcc34560a168a	VISA 13 digit	26.1748828938219695	-80.1119233867440386
49437	2020-09-01 10:32:57	2020-09-01	Sylva Kuhic	sylva.kuhic@geemail.com	Los Angeles	California	3764415110006486	2a1f6c7cbf7b581ed782ae097673a3a0	Diners Club / Carte Blanche	34.0101591772265692	-118.490859598805372
49438	2020-09-01 10:34:04	2020-09-01	Augustine Little	augustine.little@woohoo.com	Springfield	Illinois	3528491560791038598	86937e1f6676803a01866e5712d286ec	Voyager	39.7752922898311141	-89.5923686566766264
49439	2020-09-01 10:34:41	2020-09-01	Dejon Ruecker	dejon.ruecker@geemail.com	San Jose	California	4506259273908	31996a7cbad2c818a6fbb149abeea810	Diners Club / Carte Blanche	37.2282412186551852	-121.81249014499933
49440	2020-09-01 10:36:03	2020-09-01	Mr. Shirley Grant III	mr.shirley.grant.iii@warmmail.com	New York	New York	3096374605343819797	a335ffda8c67ae8569d1a0ec01c0c43b	VISA 13 digit	40.7580239846128976	-73.9669048229128094
49441	2020-09-01 10:45:17	2020-09-01	Vita Johnston	vita.johnston@woohoo.com	New York	New York	6011743001485519995	9a055dce3b271310e3367c4c77b4610a	American Express	40.7398068331871173	-73.892987590645248
49442	2020-09-01 10:46:42	2020-09-01	Cari Ortiz	cari.ortiz@woohoo.com	Memphis	Tennessee	4576997691450374	297fe981dd8af913103942f1ad967df3	Mastercard	35.1843579124260728	-89.9497257787059965
49443	2020-09-01 10:48:18	2020-09-01	Miss Dorthey Reinger DDS	miss.dorthey.reinger.dds@geemail.com	Houston	Texas	6011088455854854263	9b1a21cfc0ef65d3a580a45fbbe58304	Maestro	29.7600387110918767	-95.3306436282131813
49444	2020-09-01 10:48:28	2020-09-01	Christal Lemke	christal.lemke@geemail.com	New York	New York	869993151030989874	211926fa4466341ff274cdbaf47571f8	JCB 16 digit	40.7155463773515081	-74.0014885529771362
49445	2020-09-01 10:48:33	2020-09-01	Manervia Quigley	manervia.quigley@geemail.com	Indianapolis	Indiana	4235800696490457	4c2f6b48952824285cefaf3d8ccc4a0f	Discover	39.7958377753857491	-86.2364916974879776
49446	2020-09-01 10:51:37	2020-09-01	Nelie Runolfsdottir	nelie.runolfsdottir@geemail.com	Spokane	Washington	3043235338322729	bc287b11c1bbd3870ae065b21778b858	Discover	47.6075504041980935	-117.36882314843983
49447	2020-09-01 11:00:14	2020-09-01	Verena Luettgen-Prosacco	verena.luettgen.prosacco@geemail.com	Cape Coral	Florida	3495102594033821	5bbd90143eed076393b1d4ccc5fe906b	Diners Club / Carte Blanche	26.5761231127630921	-81.9895752112917648
49448	2020-09-01 11:00:50	2020-09-01	Millicent Beer-Kautzer	millicent.beer.kautzer@geemail.com	Minneapolis	Minnesota	3030000784443301	46207b44f305e319906f60e1560fc23c	VISA 16 digit	45.0252701858144206	-93.2870270550057228
49449	2020-09-01 11:16:01	2020-09-01	Madie Oberbrunner	madie.oberbrunner@geemail.com	San Francisco	California	3429263764974243	9f8835f4b87521b1e1a298b3b2da2775	VISA 16 digit	37.783159061689787	-122.437006799951348
49450	2020-09-01 11:18:52	2020-09-01	Tracie Shanahan	tracie.shanahan@geemail.com	Chandler	Arizona	4749517214216383	5e8b196d3b019b506efeefd76da43102	VISA 16 digit	33.3086663812488268	-111.840552581695462
49451	2020-09-01 11:29:35	2020-09-01	January Gerlach	january.gerlach@warmmail.com	Pembroke Pines	Florida	180000374607430922	5cb9785cd90fea50cbff082a83ccf38e	Mastercard	26.1048798737153405	-80.3577290266655382
49452	2020-09-01 11:32:00	2020-09-01	Foy Langosh	foy.langosh@geemail.com	Houston	Texas	3337347407671046281	5c0597aa0cdc57150ffe2de35a47dace	VISA 13 digit	29.8708979849316165	-95.4685659960392883
49453	2020-09-01 11:34:01	2020-09-01	Kimberly Hirthe	kimberly.hirthe@woohoo.com	Billings	Montana	6011623082839123010	7532856bdd3981ff3ddcf80900d88a79	JCB 15 digit	45.7293017752692066	-108.533944603677455
49454	2020-09-01 11:34:30	2020-09-01	Corbin Wehner	corbin.wehner@geemail.com	Fullerton	California	54654851520243754	94449d74ed54f452a9fd467ae21ffe47	VISA 16 digit	33.7921893361180992	-117.896110779114068
49455	2020-09-01 11:47:16	2020-09-01	Anjelica Welch	anjelica.welch@woohoo.com	Arlington	Texas	4594163125802	1cea0ef6bd0feff9c3eb2e1e50eb921d	VISA 16 digit	32.6416374612849154	-97.0276802824836295
49456	2020-09-01 11:50:08	2020-09-01	Claiborne Stiedemann	claiborne.stiedemann@geemail.com	Houston	Texas	4980624615375368	1dc713000482c3c969a81f3b0ebb1a67	JCB 16 digit	29.7534747903779149	-95.3741453933078844
49457	2020-09-01 11:56:14	2020-09-01	Delmas Schinner	delmas.schinner@geemail.com	Carlsbad	California	51963701434091094	67781d392c52e59c49a0084f253178fe	Maestro	33.0708819424673877	-117.358489430953924
49458	2020-09-01 12:04:28	2020-09-01	Miss Sussie Rolfson	miss.sussie.rolfson@woohoo.com	Fayetteville	North Carolina	6011994947822878799	1342c34d11089e6c13e5c6e6896a6c7c	VISA 16 digit	35.1394047189757188	-78.944038949593903
49459	2020-09-01 12:09:19	2020-09-01	Brady Fadel PhD	brady.fadel.phd@geemail.com	Savannah	Georgia	3096624182029709492	52221faf79d14b5ab5630031da6dcaf5	Voyager	32.021292077153916	-81.0911026418361729
49460	2020-09-01 12:10:18	2020-09-01	Tom Luettgen	tom.luettgen@geemail.com	San Francisco	California	3528169355993817985	cbd13494d5fb2513bd02b47a26669658	Diners Club / Carte Blanche	37.7604114592855069	-122.463218607641807
49461	2020-09-01 12:14:43	2020-09-01	Nolan Wisozk DDS	nolan.wisozk.dds@geemail.com	New York	New York	4197346325941	d7a85751d720ce320c89e34533e02d67	VISA 16 digit	40.7111866182405464	-73.8926429150987332
49462	2020-09-01 12:14:52	2020-09-01	Cena Hodkiewicz MD	cena.hodkiewicz.md@warmmail.com	Laredo	Texas	3006565885882049	17ca7bd77e7f311eaa950b2068e2eac6	JCB 16 digit	27.5048511810317642	-99.4068937856711443
49463	2020-09-01 12:20:29	2020-09-01	Alex Pfannerstill	alex.pfannerstill@geemail.com	Anchorage	Alaska	3791986666043708	3a3d7a95b73e4cecc455fa2d6959ac39	Maestro	61.1454439341772371	-149.238635773736235
49464	2020-09-01 12:31:07	2020-09-01	Karissa Tromp	karissa.tromp@geemail.com	Denver	Colorado	3158245775353669791	61194547a1ead31a8fdb58de3d57ab19	JCB 15 digit	39.8307341314438688	-104.855258842768521
49465	2020-09-01 12:39:46	2020-09-01	Lera Dare	lera.dare@geemail.com	Los Angeles	California	4347780181998948	3cbd52e45212b9ff87de6555b6517e35	JCB 16 digit	34.105584896016488	-118.411981704970074
49466	2020-09-01 12:42:25	2020-09-01	Marisa Crona	marisa.crona@warmmail.com	Garland	Texas	3774679893567638	81bdfa3d3486cf407a60b131bf35d0cf	VISA 13 digit	32.8861216656632678	-96.6804285433769337
49467	2020-09-01 12:47:23	2020-09-01	Ossie Funk	ossie.funk@geemail.com	Columbus	Georgia	6011915342812096345	6976f68abd77b5c52c6688a54da2d865	Diners Club / Carte Blanche	32.5883167136505207	-84.9279581556260581
49468	2020-09-01 12:52:06	2020-09-01	Casen Dach	casen.dach@geemail.com	Irvine	California	3750199144784229	6624fc8d5b446880cfa1440793ee0e3c	American Express	33.5878854882918318	-117.823169897544375
49469	2020-09-01 12:52:06	2020-09-01	Mr. Kent Kuhn PhD	mr.kent.kuhn.phd@geemail.com	Laredo	Texas	4487804698362	ebe8c636a0f48f5d7f4742f5e83911e3	Diners Club / Carte Blanche	27.4861563934661461	-99.4374166463974802
49470	2020-09-01 12:53:29	2020-09-01	Kyleigh Hartmann	kyleigh.hartmann@geemail.com	Indianapolis	Indiana	6011071906319338416	bcd9f0563ba592a05345de760445b40a	VISA 16 digit	39.7363551924943934	-86.1538699785448614
49471	2020-09-01 13:00:45	2020-09-01	Orlo Kerluke-Kulas	orlo.kerluke.kulas@geemail.com	Omaha	Nebraska	4694891389702	7874d28163ac724d4dd7d10677750e27	VISA 13 digit	41.2976366218790432	-96.1127191730424784
49472	2020-09-01 13:00:56	2020-09-01	Lyla Tillman	lyla.tillman@warmmail.com	Akron	Ohio	6011609906815604817	634ac9fb706316f5cdc8c5b1dcfcd740	VISA 16 digit	41.0037135225553087	-81.4309403923653008
49473	2020-09-01 13:05:04	2020-09-01	Eldred Hagenes-Gottlieb	eldred.hagenes.gottlieb@geemail.com	San Francisco	California	6011537600211910012	6c7cd4f2b975f05866a4ba63dad48af9	Mastercard	37.7924868339689155	-122.441384244670928
49474	2020-09-01 13:11:30	2020-09-01	Brandan Crist	brandan.crist@geemail.com	El Paso	Texas	4031024209536856	a6b25b39f7326e972ebe3815aa673d6f	Discover	31.7607291001189509	-106.399083352832136
49475	2020-09-01 13:33:33	2020-09-01	Benita Kulas MD	benita.kulas.md@geemail.com	Kenosha	Wisconsin	4295294518218	833d47963c381f2ddaf60c53e4bc64cc	Discover	42.4937604649763543	-87.8799332106713251
49476	2020-09-01 13:34:13	2020-09-01	Dr. Rashad Watsica	dr.rashad.watsica@geemail.com	Louisville	Kentucky	3088035999727565584	d6ccefc759fe549158daa4f8d7f12a69	VISA 16 digit	38.163020777692644	-85.5885169341299701
49477	2020-09-01 13:34:38	2020-09-01	Carmelo Douglas	carmelo.douglas@geemail.com	Chicago	Illinois	3112072292868393840	1780d19fa98bc3f07b5ef15f37d4626e	VISA 13 digit	41.796914391016962	-87.6373850434582664
49478	2020-09-01 13:37:18	2020-09-01	Jacey Nitzsche	jacey.nitzsche@warmmail.com	Houston	Texas	060443991931304	747fa34bb577e8ae2f621a07a826ca21	JCB 16 digit	29.8104894002512104	-95.2958591116607181
49479	2020-09-01 13:37:32	2020-09-01	Dr. Osbaldo Kemmer II	dr.osbaldo.kemmer.ii@geemail.com	San Antonio	Texas	3035576721599003	7c3d35a4be5c709eb7367a39ace2b43e	VISA 16 digit	29.3863266159851122	-98.504412371602271
49480	2020-09-01 13:38:22	2020-09-01	Mr. Estel Bode DVM	mr.estel.bode.dvm@warmmail.com	Concord	California	503853753833564	f1bb59ce10fc6702b623e3347e9eba41	JCB 15 digit	37.8930814914338328	-121.922876887226849
49481	2020-09-01 13:38:43	2020-09-01	Carmen Considine I	carmen.considine.i@warmmail.com	Tucson	Arizona	869965373910629149	a3f699b5e7315645d0dfd19c973ac648	VISA 16 digit	32.2245860485401039	-110.770600028219064
49482	2020-09-01 13:39:04	2020-09-01	Annamae Lindgren	annamae.lindgren@geemail.com	Atlanta	Georgia	4975074054534587	1636876a602ea7a671526c4d0f9591d3	JCB 15 digit	33.8198555947091464	-84.4732486538168104
49483	2020-09-01 13:47:21	2020-09-01	Jedediah Smitham	jedediah.smitham@geemail.com	Birmingham	Alabama	3044966155158890	d4b3389eff743e1801b83993d0f095e9	Mastercard	33.5364348024386913	-86.7656474382393128
49484	2020-09-01 13:53:57	2020-09-01	Ms. Deandra Smith	ms.deandra.smith@geemail.com	Tallahassee	Florida	3790731473053198	3dff611ef56e39e313f8e27fe7118e63	JCB 15 digit	30.3780221795219951	-84.3441582873012834
49485	2020-09-01 13:55:41	2020-09-01	Ishaan Quigley II	ishaan.quigley.ii@geemail.com	San Francisco	California	4126374679053429	2b427a60849708f35c2ddadf02887a44	VISA 16 digit	37.7421435249633319	-122.410734527482234
49486	2020-09-01 13:55:55	2020-09-01	Aniya Rempel DVM	aniya.rempel.dvm@geemail.com	Springfield	Illinois	3450625063605912	7f4d1ea0660711c8d6a2f852f5b23cb6	Voyager	39.8080478779193001	-89.6662440834105041
49487	2020-09-01 13:56:28	2020-09-01	Eben Olson	eben.olson@geemail.com	San Francisco	California	630482690567241	4d57de23c699261d61050ee007ffa0a0	Discover	37.7890854960802827	-122.406310754469899
49488	2020-09-01 14:03:50	2020-09-01	Daniel Buckridge	daniel.buckridge@woohoo.com	San Francisco	California	6011007501821293610	c571a6c57029286f4b15e64454fdd12a	VISA 16 digit	37.7736597864524626	-122.43751979229215
49489	2020-09-01 14:07:04	2020-09-01	Delina Tromp	delina.tromp@geemail.com	New York	New York	4720733821312464	c2c6da5abd13036ebdbe21f551461142	Voyager	40.6207503197938209	-73.8724275736033889
49490	2020-09-01 14:10:18	2020-09-01	Miss Maira Auer	miss.maira.auer@geemail.com	San Francisco	California	3158532984782759841	4fc28211d0645af8cb511ce7838f9f3a	Mastercard	37.8445663354993016	-122.411315016874113
49491	2020-09-01 14:12:13	2020-09-01	Elizbeth Stracke	elizbeth.stracke@geemail.com	Lubbock	Texas	3158796888075796256	8cd58c2471e0968a8bdb7e6dce0013e6	Discover	33.4871407418552849	-101.947070054375388
49492	2020-09-01 14:26:46	2020-09-01	Almira Kovacek DDS	almira.kovacek.dds@geemail.com	Nashville	Tennessee	210036029797360994	00abc39684911a24b6330d76ba202f25	Diners Club / Carte Blanche	36.1134585851926317	-86.8312992397137009
49493	2020-09-01 14:28:39	2020-09-01	Simpson Schmeler	simpson.schmeler@geemail.com	San Francisco	California	4191632077105657	89a78036e6197340e5c650f44931321c	JCB 15 digit	37.8075440226898607	-122.416054965197105
49494	2020-09-01 14:34:48	2020-09-01	Mr. Linden Morar Jr.	mr.linden.morar.jr.@geemail.com	Phoenix	Arizona	4686768356887995	1d1cd84645fafc3692e56917328c63b0	Diners Club / Carte Blanche	33.5101506921395682	-112.184137367962308
49495	2020-09-01 14:35:14	2020-09-01	Matilde Herman	matilde.herman@geemail.com	Portland	Oregon	3434654442391169	9da9a2ba52bf7fa9097708604dd2d788	Maestro	45.5867816641349322	-122.557630103733402
49496	2020-09-01 14:38:55	2020-09-01	Mrs. Iona Yost DVM	mrs.iona.yost.dvm@geemail.com	Berkeley	California	4599461420399991	92da87efef4005c79dd2cdc1af59c975	Discover	37.8503933285967662	-122.277020083290509
49497	2020-09-01 14:47:04	2020-09-01	Dr. Lynwood Schumm	dr.lynwood.schumm@geemail.com	High Point	North Carolina	55911170204417884	ade0310ff6291af537e78a5fa040c2fc	VISA 16 digit	36.0101728582382208	-79.959252538552505
49498	2020-09-01 14:49:50	2020-09-01	Eithel Skiles	eithel.skiles@woohoo.com	Minneapolis	Minnesota	6011600312144411017	eef366aa7d043506ce4899dcabf106d4	JCB 16 digit	44.953356213503703	-93.2317514751378411
49499	2020-09-01 14:51:36	2020-09-01	Jelani Lindgren Jr.	jelani.lindgren.jr.@geemail.com	San Francisco	California	3096505386175414880	249daa09d17045647954b4a59a37b140	VISA 13 digit	37.7722755179027132	-122.3796790635256
49500	2020-09-01 14:53:30	2020-09-01	Maia Gerlach	maia.gerlach@geemail.com	San Francisco	California	3337926384874509432	08265d163f7963ec590c3c5846cd8e79	VISA 16 digit	37.7830901694753862	-122.424272972643706
49501	2020-09-01 15:05:51	2020-09-01	Alphons Abernathy	alphons.abernathy@geemail.com	New York	New York	3041737703146478	e5fd1283e3e4b50e9f0cf99595c1fa0d	Diners Club / Carte Blanche	40.7012464964520149	-73.9933275679487679
49502	2020-09-01 15:07:11	2020-09-01	Dr. Champ Sauer DVM	dr.champ.sauer.dvm@geemail.com	Syracuse	New York	4222999803505	c3749ded09a6ce985edd1d3da512c878	Diners Club / Carte Blanche	42.9830626685488966	-76.0687853706780857
49503	2020-09-01 15:09:02	2020-09-01	Demetrios Pouros V	demetrios.pouros.v@geemail.com	Carlsbad	California	3158800921696016111	4905adf7b90afe198d218cdf38813a4b	JCB 16 digit	33.2103098151680101	-117.2890980981078
49504	2020-09-01 15:11:54	2020-09-01	Earley Wisoky II	earley.wisoky.ii@geemail.com	New York	New York	4675666216834541	1e5e1d1b1cf8f44696e6b73d88af311c	American Express	40.689707360159602	-73.8615057683911118
49505	2020-09-01 15:13:47	2020-09-01	Miss Delisa Hettinger PhD	miss.delisa.hettinger.phd@geemail.com	Warren	Michigan	180098820299502967	b3bc7294fa3f0549c799f378611b6a46	Maestro	42.4861295878417806	-83.056491621676841
49506	2020-09-01 15:18:39	2020-09-01	Regenia Wilderman	regenia.wilderman@geemail.com	Toledo	Ohio	3019562796671899	8dba044698a8148c6a03095d13552bb4	Diners Club / Carte Blanche	41.7053874418310784	-83.5604616012290222
49507	2020-09-01 15:21:08	2020-09-01	Phoenix Kilback	phoenix.kilback@woohoo.com	Fort Worth	Texas	4491273853557816	10031f082868db3287e23db311077c97	Voyager	32.8580364969614891	-97.3273491523049756
49508	2020-09-01 15:25:17	2020-09-01	Marrion Pfannerstill	marrion.pfannerstill@warmmail.com	West Valley City	Utah	3528848298754893804	30d79b650621e2b15fba12a390b3b32d	JCB 16 digit	40.7402103968188172	-111.984896456332123
49509	2020-09-01 15:34:00	2020-09-01	Georgetta Kessler PhD	georgetta.kessler.phd@woohoo.com	Houston	Texas	4802581261780	86d5018c32e5f658ebb1b96973e1e53d	VISA 13 digit	29.84522404149957	-95.3278309162721058
49510	2020-09-01 15:34:45	2020-09-01	Pluma O'Reilly	pluma.o'reilly@geemail.com	San Antonio	Texas	3528644266166118595	3e9c0c48b688c8eeb745aa242f93cf5f	American Express	29.3921795012500127	-98.5534582054544188
49511	2020-09-01 15:39:58	2020-09-01	Niki Fay DDS	niki.fay.dds@geemail.com	Memphis	Tennessee	52461782851127642	117d72dc8cd09e2c2ff58ef8f738257d	Maestro	35.0484793071236496	-89.9675489314623178
49512	2020-09-01 15:42:19	2020-09-01	Delora Stroman	delora.stroman@geemail.com	San Francisco	California	4513263828248694	4d3a4b036dfc79139fdb09a23015e4cb	Mastercard	37.8012726038771945	-122.448071802729075
49513	2020-09-01 15:44:05	2020-09-01	Ms. Josefa Welch PhD	ms.josefa.welch.phd@woohoo.com	Irving	Texas	676368393201501	d6c4863c04043e850e8aa64c98b3f443	JCB 16 digit	32.9138776841525029	-97.0403277017921226
49514	2020-09-01 15:52:43	2020-09-01	Felicia Runolfsson-Jaskolski	felicia.runolfsson.jaskolski@geemail.com	Fort Worth	Texas	3112487445702959098	339c4d342319f4b73dbec9822ff826fb	American Express	32.8501615844722821	-97.410893796087052
49515	2020-09-01 15:59:41	2020-09-01	Mittie Kling	mittie.kling@geemail.com	Minneapolis	Minnesota	4527622919589916	f8e7983d081fdacefae89a854265f157	Maestro	45.0216195952232923	-93.3608930951721874
49516	2020-09-01 16:02:48	2020-09-01	Hjalmer Huels III	hjalmer.huels.iii@geemail.com	Philadelphia	Pennsylvania	869977145922909966	ac0885387245fa38ef45b442bda4c631	Maestro	40.0411055449821021	-75.2210976932097282
49517	2020-09-01 16:05:39	2020-09-01	Aurilla Kilback-Lueilwitz	aurilla.kilback.lueilwitz@geemail.com	Roseville	California	3158098483308621409	acc1f956f144121c6eb1a6c25ecd4a81	VISA 16 digit	38.7150501902271031	-121.358290621194612
49518	2020-09-01 16:12:21	2020-09-01	Scot Conn	scot.conn@geemail.com	San Francisco	California	3112172903358670534	187d804aac36af4e27235e4b5dcec134	VISA 16 digit	37.7753020164578217	-122.447769182031351
49519	2020-09-01 16:12:43	2020-09-01	Dale Schroeder-Bednar	dale.schroeder.bednar@warmmail.com	Las Vegas	Nevada	869989183483269245	a5171181201d72b4a390b8b0a8e4c70c	JCB 16 digit	36.2235095070775586	-115.348439505949983
49520	2020-09-01 16:13:32	2020-09-01	Gerry Balistreri-Koch	gerry.balistreri.koch@geemail.com	Phoenix	Arizona	180091291506642821	3fcfd4f76207b7ede48dbd493d6fdd16	Mastercard	33.4847594395678527	-112.105409475641707
49521	2020-09-01 16:22:09	2020-09-01	Woodroe Sanford	woodroe.sanford@geemail.com	San Francisco	California	3034651653875639	52040aea68f204408f2d9dd056bee108	JCB 16 digit	37.7540696614611093	-122.447800876600922
49522	2020-09-01 16:31:24	2020-09-01	Freddie Rutherford-Wunsch	freddie.rutherford.wunsch@geemail.com	Round Rock	Texas	210032066447409874	a12ffc7d34224787f5774147d71ece95	VISA 16 digit	30.5593677933000052	-97.7186076974812892
49523	2020-09-01 16:33:16	2020-09-01	Mr. Lindell Hamill III	mr.lindell.hamill.iii@woohoo.com	San Jose	California	869965816063934161	77292a773eaed3ab6c871efeeddc564b	Maestro	37.2018981728058336	-121.725151781200992
49524	2020-09-01 16:53:01	2020-09-01	Alexandr Romaguera	alexandr.romaguera@geemail.com	Austin	Texas	561284586808697	524dee115f0f5213c2a60d24b4828b80	Voyager	30.3644886254925268	-97.784673723695434
49525	2020-09-01 16:53:12	2020-09-01	Laney Hansen	laney.hansen@geemail.com	San Francisco	California	3112611364365827782	286b4f81a4ad3032ddb766b83fd6b177	Discover	37.7931516704279105	-122.418627137778401
49526	2020-09-01 16:56:52	2020-09-01	Daneen Sawayn	daneen.sawayn@geemail.com	Cedar Rapids	Iowa	3025371179491121	99b793cf9d492f8077e47265b19038bd	JCB 16 digit	41.9505248094052092	-91.6149983653865831
49527	2020-09-01 17:06:55	2020-09-01	Mr. Britt King MD	mr.britt.king.md@geemail.com	Columbus	Ohio	4647660038973368	008072c4b8850e2c10b048e657385874	Discover	39.996185696967693	-83.0660300828751303
49528	2020-09-01 17:07:30	2020-09-01	Donal Thiel DDS	donal.thiel.dds@geemail.com	Evansville	Indiana	3037413221299868	ec718f01287d8f0416ba797262fb16be	JCB 16 digit	37.9442251878928332	-87.5813896871104873
49529	2020-09-01 17:12:57	2020-09-01	Mr. Hermann Gutkowski IV	mr.hermann.gutkowski.iv@geemail.com	Jersey City	New Jersey	3528741420001415888	f86ed759946db92321bc6d10ee8e69c7	Discover	40.6426924532685376	-74.0296523370735429
49530	2020-09-01 17:14:52	2020-09-01	Dustan Okuneva	dustan.okuneva@geemail.com	Huntington Beach	California	210064257451479306	877e01d2bc34a33a78dac9b06ed73ce3	VISA 16 digit	33.6872983328107765	-118.029212877120074
49531	2020-09-01 17:22:00	2020-09-01	Nichelle Shanahan	nichelle.shanahan@warmmail.com	New York	New York	3746922753686741	18d8513a9b6bd1cefb3e64a7212ef823	JCB 16 digit	40.636139986686409	-73.8809163262031916
49532	2020-09-01 17:24:31	2020-09-01	Kamren Leffler	kamren.leffler@geemail.com	Fort Wayne	Indiana	3088877342099316735	d0cf16384fac8fb91084ccbe857ee83b	VISA 16 digit	41.1121295480307225	-85.2142846755437517
49533	2020-09-01 17:34:18	2020-09-01	Arthor Williamson-Fahey	arthor.williamson.fahey@woohoo.com	Anaheim	California	4526773114600841	dc014e42bc90f283544cc275b2bb2291	Mastercard	33.952638583706694	-117.810379884273175
49534	2020-09-01 17:38:00	2020-09-01	Savanna Klein	savanna.klein@geemail.com	San Antonio	Texas	4945171340843	5668f9e309c3c7aeadc4533d00003976	American Express	29.5365026094090197	-98.5659034216146921
49535	2020-09-01 17:42:13	2020-09-01	Mitzi McKenzie	mitzi.mckenzie@warmmail.com	Richardson	Texas	180004118003599731	f2081aa191f0c26f4f856dff12471a40	Maestro	32.8968148492045671	-96.6796182177256753
49536	2020-09-01 17:42:48	2020-09-01	Slade Konopelski II	slade.konopelski.ii@geemail.com	Lewisville	Texas	3022589480061464	5448499975e6c6450598cbd76c3257be	Discover	32.9806603919699768	-97.0812536776561359
49537	2020-09-01 17:47:24	2020-09-01	Sharif Swaniawski	sharif.swaniawski@geemail.com	San Francisco	California	3059006852127552	0db0fbde065410985058b3123f9d0b29	JCB 16 digit	37.7819199519361888	-122.415337744015105
49538	2020-09-01 17:51:49	2020-09-01	Clemma Brekke	clemma.brekke@geemail.com	New York	New York	3003071561422609	577dde4d82dc3e136cda6f11737f81dd	Voyager	40.7430823010150363	-73.8952636361483428
49539	2020-09-01 17:54:59	2020-09-01	Selina Harber MD	selina.harber.md@geemail.com	Sacramento	California	3528848910693778611	c4543eaf953ee253cc96d9bf3fe7709c	Mastercard	38.6346531106889231	-121.525161820302159
49540	2020-09-01 18:02:34	2020-09-01	Hannah Cassin	hannah.cassin@warmmail.com	Tempe	Arizona	4583996034877	12aad353c3848e52721627f452267a7e	VISA 16 digit	33.3831273599915193	-111.896118167045714
49541	2020-09-01 18:13:03	2020-09-01	Henriette Bartell-Von	henriette.bartell.von@woohoo.com	New York	New York	869979311398933751	6867e6bc99295175e17df6d6c6b4c667	Diners Club / Carte Blanche	40.6656871740929802	-73.8950676995690827
49542	2020-09-01 18:19:18	2020-09-01	Leva Corwin-Boyle	leva.corwin.boyle@geemail.com	New York	New York	869937635494283427	3fed72ec81ebc4965b2cb18c4443a510	VISA 16 digit	40.5675886157657928	-73.9346322284441442
49543	2020-09-01 18:20:03	2020-09-01	Mr. Douglass Volkman	mr.douglass.volkman@geemail.com	Jacksonville	Florida	6011866917135393419	27d9c84478b9d87df0dc7cb503f98557	VISA 16 digit	30.2572598935622707	-81.67978761029282
49544	2020-09-01 18:28:59	2020-09-01	Isaak Auer	isaak.auer@warmmail.com	Colorado Springs	Colorado	3472555895419832	b4d0d4b1762dc534fc9c1b1ffe2d5ca0	Voyager	38.8148422762334349	-104.66226626058743
49545	2020-09-01 18:42:50	2020-09-01	Leslie Moen	leslie.moen@geemail.com	Albuquerque	New Mexico	3096094381233711333	ae6f7f3d1bbd2479723346334bb403cd	Mastercard	35.1404309793043907	-106.703256722453617
49546	2020-09-01 18:43:16	2020-09-01	Symone Kunze	symone.kunze@geemail.com	Frisco	Texas	4608364698738	a90ba5129ae905e91930d50803a031a7	JCB 16 digit	33.235945869842169	-96.7999232859093581
49547	2020-09-01 18:44:55	2020-09-01	Dr. Etna Lockman	dr.etna.lockman@woohoo.com	New York	New York	4027919453914343	ddc3e97252bebf2d5302f59b6a14765f	Mastercard	40.7091197480205409	-73.8827174330957206
49548	2020-09-01 18:47:33	2020-09-01	Luberta Hodkiewicz	luberta.hodkiewicz@geemail.com	Kansas City	Kansas	3008779118198119	b98c91a9e02082440ab248b1c924ec28	Voyager	39.0347929492499688	-94.7700812604214917
49549	2020-09-01 18:53:41	2020-09-01	Joey Ondricka	joey.ondricka@geemail.com	Jacksonville	Florida	4221582790223721	042202b147eadc8c32c7eda79815b676	Mastercard	30.430905658803507	-81.6321589532386582
49550	2020-09-01 18:57:38	2020-09-01	Caryl Champlin	caryl.champlin@woohoo.com	Aurora	Colorado	6011248536154907419	db5d5bd40b790a7209a344a160166304	VISA 13 digit	39.7611082122772928	-104.7560076593075
49551	2020-09-01 18:58:49	2020-09-01	Dr. Leatha Schinner	dr.leatha.schinner@geemail.com	San Antonio	Texas	210032247728193649	fc699f1f8a73c98f3b4a31c568547fb1	JCB 15 digit	29.5212384804222729	-98.4302444202661491
49552	2020-09-01 18:59:29	2020-09-01	Roger Wolff-Strosin	roger.wolff.strosin@geemail.com	Jacksonville	Florida	502038382102085	a279beb23eba352518792906e3e4d620	VISA 16 digit	30.3097821657132371	-81.6961537497196417
49553	2020-09-01 19:00:53	2020-09-01	Hymen McDermott	hymen.mcdermott@warmmail.com	Lewisville	Texas	3419154460865292	67724c04abf88822e621ddfa93bc04af	JCB 16 digit	32.9849653870318065	-96.9556758271560142
49554	2020-09-01 19:03:05	2020-09-01	Romello Brekke-Lehner	romello.brekke.lehner@geemail.com	Honolulu	Hawaii	3337717965328538184	f26fd9f9361b5a03a62d28588e084639	Discover	21.2531609849289076	-157.932111395869782
49555	2020-09-01 19:03:44	2020-09-01	Sheryl Kuhn	sheryl.kuhn@woohoo.com	Miami	Florida	3088046592823518933	68f0a87640fa0c098e51da88e39b59af	VISA 16 digit	25.7793392009239675	-80.3000447904564538
49556	2020-09-01 19:08:15	2020-09-01	Brandin Torphy	brandin.torphy@woohoo.com	Arlington	Texas	6011303733732264783	03ccc266ef35663b30c6716a23b28c09	JCB 16 digit	32.6180486375715546	-97.0450519343398526
49557	2020-09-01 19:14:08	2020-09-01	Brandt Herman	brandt.herman@geemail.com	New York	New York	060456473333153	084e970226662cc8286744126b667589	VISA 13 digit	40.6644260826744102	-73.8658034956909688
49558	2020-09-01 19:14:12	2020-09-01	Mr. Maury Hahn II	mr.maury.hahn.ii@geemail.com	Provo	Utah	676113649195735	a036302d68751bd04a37f9ff4cdac055	JCB 15 digit	40.2864583433859025	-111.584911822215844
49559	2020-09-01 19:32:54	2020-09-01	Dewey Franecki	dewey.franecki@geemail.com	Stockton	California	3041382065169931	928a246d8b919e320720e9c3b2f6bb27	Diners Club / Carte Blanche	37.9745772861141759	-121.372967523624368
49560	2020-09-01 19:33:19	2020-09-01	Gladys Mayer DDS	gladys.mayer.dds@geemail.com	Milwaukee	Wisconsin	3112062368049087154	a195520498fecb78a57cb5f52327419b	JCB 16 digit	43.1597160036761309	-87.9597635503027675
49561	2020-09-01 19:33:27	2020-09-01	Edison Jakubowski-Schultz	edison.jakubowski.schultz@geemail.com	Dallas	Texas	54953891519754963	140db15e9751cc88974a345b0caa2edf	American Express	32.8736746446035824	-96.8170470364354543
49562	2020-09-01 19:34:34	2020-09-01	Kylee Prohaska-Purdy	kylee.prohaska.purdy@geemail.com	Baltimore	Maryland	4497093308816276	dd27dfcd0e41290994dea205665360c6	JCB 16 digit	39.207355179823935	-76.6977381329536456
49563	2020-09-01 19:49:48	2020-09-01	Mrs. Brigette Treutel MD	mrs.brigette.treutel.md@warmmail.com	New York	New York	210031604696834094	32c9754d9e8b5c1e7483a60242d15f6b	Diners Club / Carte Blanche	40.6992688967604153	-74.0147177638847324
49564	2020-09-01 19:50:55	2020-09-01	Ismael Haag-Hauck	ismael.haag.hauck@woohoo.com	Columbus	Ohio	589336267142465	931b415cc08af2cfebf4736ffb2eb9d8	Diners Club / Carte Blanche	40.0470067871313518	-82.9107141319897067
49565	2020-09-01 19:59:54	2020-09-01	Mr. Tobe Borer III	mr.tobe.borer.iii@geemail.com	Des Moines	Iowa	3440519786464249	de7fd5e3da1212e86ba6f8757f481db5	Discover	41.5806206622369601	-93.6894806321289479
49566	2020-09-01 19:59:59	2020-09-01	Anfernee Pouros	anfernee.pouros@geemail.com	Dayton	Ohio	3010351053967722	61efea22faee694e0bf86fe0522d3f68	Diners Club / Carte Blanche	39.7305699672341319	-84.1870279300682256
49567	2020-09-01 20:04:20	2020-09-01	Burgess Farrell-Kuhic	burgess.farrell.kuhic@geemail.com	Corpus Christi	Texas	4489244313438	7f74e08c3c4cc09add1878c88fedc6e4	VISA 16 digit	27.7989430921088925	-97.1019291649866858
49568	2020-09-01 20:09:27	2020-09-01	Pearley Langosh	pearley.langosh@warmmail.com	Philadelphia	Pennsylvania	4320385023479098	4176b26a7400d945e72bb442ffa8fcb0	JCB 16 digit	40.0365842477843188	-75.0990108165323846
49569	2020-09-01 20:12:12	2020-09-01	Lionel Casper	lionel.casper@geemail.com	Daly City	California	4527231507171317	43857b30507f9977ba0acc2f40613883	JCB 16 digit	37.7683611922353464	-122.413139404319224
49570	2020-09-01 20:15:25	2020-09-01	Marlana Graham-Hickle	marlana.graham.hickle@geemail.com	Las Vegas	Nevada	869961808597214339	37008430a5cedbdb4e25ba7d682880d9	Voyager	36.2666435344710933	-115.205805861644819
49571	2020-09-01 20:19:19	2020-09-01	Alanzo Crist	alanzo.crist@geemail.com	Clarksville	Tennessee	3027151930181726	cb03e6f8927673517457273e9c994a7b	VISA 16 digit	36.483281413850932	-87.4360096875995509
49572	2020-09-01 20:20:15	2020-09-01	Sharde Sawayn	sharde.sawayn@geemail.com	Gainesville	Florida	4443589719253	8e0067b22fcafbd334ccafe803e903ee	VISA 16 digit	29.7768685370508557	-82.3457877822093707
49573	2020-09-01 20:22:55	2020-09-01	Kamryn Hills	kamryn.hills@geemail.com	Wichita Falls	Texas	3790788487123565	a611fa4a7c68c09b81c0b492103c0fda	JCB 16 digit	33.953668287276102	-98.4399542823355631
49574	2020-09-01 20:24:18	2020-09-01	Ms. Calista Sanford PhD	ms.calista.sanford.phd@geemail.com	Dallas	Texas	3096753738548059140	c9b42259f65373d58299b9f6494cb0cb	JCB 16 digit	32.8894870187893531	-96.8618631042037066
49575	2020-09-01 20:26:05	2020-09-01	Belva Larson-Kuphal	belva.larson.kuphal@geemail.com	San Antonio	Texas	3045259071935313	a8ea892a85294c8bae3dab65a1293f6a	JCB 16 digit	29.5378311930760731	-98.4788108877673665
49576	2020-09-01 20:26:31	2020-09-01	Geo Bosco	geo.bosco@warmmail.com	Denver	Colorado	3750715326723691	e08e132a496e0e5109a06579073eca67	JCB 16 digit	39.7629415661614374	-104.82128120854162
49577	2020-09-01 20:29:25	2020-09-01	Mr. Zion Ferry	mr.zion.ferry@geemail.com	Las Vegas	Nevada	3010842393235333	4f4991ae58e2d8297d4797b80f7af711	Discover	36.2751566230420011	-115.259228308612848
49578	2020-09-01 20:37:09	2020-09-01	Leon Smith	leon.smith@woohoo.com	Tulsa	Oklahoma	3003952095597844	f4e6783a6a2b3c90a7b93658755bc8c5	American Express	36.1309646088998733	-95.8935888760678381
49579	2020-09-01 20:51:07	2020-09-01	Jesus Corkery-Zulauf	jesus.corkery.zulauf@woohoo.com	Chicago	Illinois	4903826387677	c3ed9496c78dd60cd0d4c890fc7a6bc3	Mastercard	41.8208171901594881	-87.7191468273319259
49580	2020-09-01 20:52:14	2020-09-01	Ishaan Pfeffer III	ishaan.pfeffer.iii@warmmail.com	Mesa	Arizona	3037319141669108	f8f7372cebdadc6bfc842bbce553001c	Mastercard	33.4916183415479907	-111.800407157314567
49581	2020-09-01 20:54:14	2020-09-01	Steve Kutch	steve.kutch@geemail.com	New York	New York	3088606126534054177	cc7f75ba2ae10855fc154f77bce14774	Discover	40.6816023141834862	-74.0349282032705815
49582	2020-09-01 20:55:09	2020-09-01	Mrs. Florene Lowe	mrs.florene.lowe@geemail.com	Indianapolis	Indiana	53810685838195079	01c14150fe1b44539ba21e9cb5011c11	VISA 16 digit	39.7534741939518597	-86.0561196510415556
49583	2020-09-01 21:01:32	2020-09-01	Mr. Merlyn Stroman I	mr.merlyn.stroman.i@geemail.com	San Antonio	Texas	3011663711880132	b4da5710669256b1a6c373df5564f6b3	Mastercard	29.4847917148914185	-98.49456247783489
49584	2020-09-01 21:01:45	2020-09-01	Odelia Simonis	odelia.simonis@woohoo.com	San Antonio	Texas	6011896293835399583	af4ed46a74815c10b668cfe5aa2d1a97	Diners Club / Carte Blanche	29.3895480855438862	-98.4435247458819305
49585	2020-09-01 21:06:51	2020-09-01	Mrs. Dove Osinski DVM	mrs.dove.osinski.dvm@warmmail.com	Indianapolis	Indiana	869996678900600899	0fc42aaaf21c3f8b2f96035a31e37a61	Maestro	39.8590238363489462	-86.1793255743771738
49586	2020-09-01 21:10:11	2020-09-01	Ciera Wyman	ciera.wyman@geemail.com	Rancho Cucamonga	California	3029380410943622	03f2478f079f08b53796494e5bff65e0	Mastercard	34.1098428972058016	-117.610444236128401
49587	2020-09-01 21:11:44	2020-09-01	Miss Anie Christiansen DDS	miss.anie.christiansen.dds@geemail.com	Indianapolis	Indiana	502050954103441	e7f669cc3ed9d1e56d9800740337eac7	Maestro	39.7399321280427245	-86.198598894683272
49588	2020-09-01 21:14:07	2020-09-01	Rosanne Jones-Torp	rosanne.jones.torp@geemail.com	Memphis	Tennessee	3112086611479719826	80291b1d08e4fe983f85e65caeed0649	VISA 16 digit	35.1946111647479256	-90.0764354313049438
49589	2020-09-01 21:23:53	2020-09-01	Ms. Myrl Langworth PhD	ms.myrl.langworth.phd@geemail.com	Oakland	California	6011398216241874355	df6f6ff1450bcd229f0318e2d1a0ab74	Maestro	37.7991074867289782	-122.281131961265501
49590	2020-09-01 21:30:57	2020-09-01	Iver Smitham-Aufderhar	iver.smitham.aufderhar@geemail.com	Las Vegas	Nevada	180011998058892789	2521e5eda87b1b69aa4ed9e24febb0a4	VISA 16 digit	36.3084959436308594	-115.328770471478251
49591	2020-09-01 21:35:36	2020-09-01	Gregorio Daniel-Aufderhar	gregorio.daniel.aufderhar@geemail.com	Omaha	Nebraska	3096771451089249793	3b8d6ba29096bb36d088d65fe17caad3	JCB 16 digit	41.3122015254717354	-96.0694958699051398
49592	2020-09-01 21:36:44	2020-09-01	Cason Padberg	cason.padberg@geemail.com	Durham	North Carolina	4639675805902	e2deb4961e6ae1ca6b3c4a6cdd45248f	Voyager	36.0481654591172926	-78.8764926081892099
49593	2020-09-01 21:36:59	2020-09-01	Randolph Leuschke	randolph.leuschke@geemail.com	Phoenix	Arizona	4017940449283942	d1134e90e39d4f50bdd66208a1824e67	Diners Club / Carte Blanche	33.5327226183310145	-112.180478249483187
49594	2020-09-01 21:41:42	2020-09-01	Manuel Lebsack	manuel.lebsack@geemail.com	Fort Worth	Texas	3096807064951275982	b81c82a27f29f6ee87e999b6965021db	VISA 16 digit	32.7491741446368394	-97.3164063213214234
49595	2020-09-01 21:43:00	2020-09-01	Almina Strosin	almina.strosin@geemail.com	Houston	Texas	4393858447139441	ae45fbee03e41e1c4fcdc5a9182c4da6	Maestro	29.8320877896700054	-95.4722926113303743
49596	2020-09-01 21:46:33	2020-09-01	Dr. Shelby Barton Jr.	dr.shelby.barton.jr.@woohoo.com	Albuquerque	New Mexico	3029311426549897	55dbd5897cc608e05afa9dabe5f0c61d	Diners Club / Carte Blanche	35.1834895865660187	-106.595237389260532
49597	2020-09-01 21:55:16	2020-09-01	Anderson Pacocha-Runolfsdottir	anderson.pacocha.runolfsdottir@geemail.com	Arlington	Texas	3528687377330344740	014f1db421cea92d28d002e2d1c8bd1b	JCB 16 digit	32.786841336429859	-97.2201427263699571
49598	2020-09-01 21:55:52	2020-09-01	Bonnie Cole	bonnie.cole@woohoo.com	New York	New York	676256159340670	a30a0ab4d10bfb7a7aea02126e7c1e85	Voyager	40.7285742667261488	-74.0290284689411493
49599	2020-09-01 22:05:57	2020-09-01	Jeremiah Schmitt	jeremiah.schmitt@geemail.com	San Francisco	California	4111637300950	db174689d0947fe37327a409ef1de660	Diners Club / Carte Blanche	37.747125950077546	-122.387709210569952
49600	2020-09-01 22:14:08	2020-09-01	Carter Nienow	carter.nienow@geemail.com	Wichita	Kansas	3528574429164955160	da33e5672ea6b4074738663e02e38fd3	VISA 16 digit	37.603606085653233	-97.3434507826544291
49601	2020-09-01 22:15:02	2020-09-01	Mr. Wilton Jerde DVM	mr.wilton.jerde.dvm@woohoo.com	San Jose	California	3096555757074140223	5f18f99f6ff395217de977c90854fc0e	Diners Club / Carte Blanche	37.2315072090651853	-121.827281430711594
49602	2020-09-01 22:20:13	2020-09-01	Jeffery Kunde-Schinner	jeffery.kunde.schinner@geemail.com	Berkeley	California	6011133306952694736	4bc249658fcb7ee38ea56513f92eba5f	Mastercard	37.8954482315877996	-122.293543471940424
49603	2020-09-01 22:21:36	2020-09-01	Mr. Cornelius Johnston	mr.cornelius.johnston@geemail.com	Milwaukee	Wisconsin	869912380568265815	7429439652e6a3fc4beb7cafc221b8b0	Mastercard	43.0835905156649659	-88.0650378540724574
49604	2020-09-01 22:21:47	2020-09-01	Rube Kreiger-Bruen	rube.kreiger.bruen@geemail.com	Los Angeles	California	6011852014704394824	3adbf2a72ff874eb00bed20a1fb93bce	Discover	34.0228373595844928	-118.475760318943486
49605	2020-09-01 22:22:13	2020-09-01	Cindi Stoltenberg	cindi.stoltenberg@geemail.com	New York	New York	4089035397200	34a1b1172592c88e85712f151702ffed	Diners Club / Carte Blanche	40.7051496445890493	-73.9810004147596629
49606	2020-09-01 22:25:24	2020-09-01	Nikita Okuneva	nikita.okuneva@warmmail.com	Baltimore	Maryland	3796924417546054	9a08f5138516103d935ecdbd858d76e0	Maestro	39.2175848903134465	-76.5168162715174276
49607	2020-09-01 22:25:40	2020-09-01	Rowena Batz	rowena.batz@geemail.com	Odessa	Texas	6011403116328275307	ae9dc9805b6cf59efbccf33c7dd4489d	JCB 16 digit	31.786444723746925	-102.241995961699999
49608	2020-09-01 22:34:34	2020-09-01	Garret Nader	garret.nader@geemail.com	Jackson	Mississippi	4064526805250	176266c92d99e18bc199749f9182ab0f	JCB 16 digit	32.3651416221346722	-90.1408417597852605
49609	2020-09-01 22:37:21	2020-09-01	Jenna Gerlach-Stoltenberg	jenna.gerlach.stoltenberg@geemail.com	Chicago	Illinois	869930613100458383	a8ca227f1634ffc838ba48d886b31779	JCB 15 digit	41.9171583515428026	-87.593835077204929
49610	2020-09-01 22:46:08	2020-09-01	Hence Christiansen-Emard	hence.christiansen.emard@woohoo.com	Huntington Beach	California	6011346459513634957	7d5a2151b65f8c7356d89ba2b0d49841	Voyager	33.7622730252839673	-118.061422590970238
49611	2020-09-01 22:54:43	2020-09-01	Thurlow Eichmann	thurlow.eichmann@geemail.com	Washington	District of Columbia	3479764085962386	bc06114a1aebbd0e1db23154763cf587	VISA 13 digit	38.8920354591015709	-77.0456563430584964
49612	2020-09-01 22:54:43	2020-09-01	Jade O'Connell-Kshlerin	jade.o'connell.kshlerin@geemail.com	Modesto	California	210082252831922669	be3d5167671f58137ec7acc7aa019b7d	VISA 16 digit	37.6554248892236529	-121.022057183386764
49613	2020-09-01 22:54:53	2020-09-01	Nicholas Bayer	nicholas.bayer@woohoo.com	Greensboro	North Carolina	52184576238496811	e932d6b84bcac813c9af5d54adeaab2d	VISA 13 digit	36.0869239080812818	-79.7281206299066554
49614	2020-09-01 22:59:02	2020-09-01	Lora Haley-Lehner	lora.haley.lehner@geemail.com	Louisville	Kentucky	869948841304203376	6cb3a67f64f074b1d26442409f53df3d	VISA 16 digit	38.237561843674257	-85.7004148586724028
49615	2020-09-01 23:01:44	2020-09-01	Miss Adela Walker DVM	miss.adela.walker.dvm@woohoo.com	Pasadena	California	4427561758306	3dcc62fb469d8a807c594b4d0340df0e	Maestro	34.12720822313279	-118.234170764107631
49616	2020-09-01 23:04:46	2020-09-01	Zayden Wilderman	zayden.wilderman@geemail.com	San Francisco	California	676374803443758	4f19550dae7f5dc42dfce56e6e68867a	Diners Club / Carte Blanche	37.7795971082380362	-122.435926540088374
49617	2020-09-01 23:06:52	2020-09-01	Dr. Cyrus Ritchie Jr.	dr.cyrus.ritchie.jr.@geemail.com	Miami	Florida	3158567411779374457	2893b4ce20f54fc15f816a1440057e81	JCB 16 digit	25.6778957498863356	-80.121145842397965
49618	2020-09-01 23:24:19	2020-09-01	Antionette Lueilwitz DDS	antionette.lueilwitz.dds@woohoo.com	Tucson	Arizona	3027828052031561	9ee03900c928a10fb7714dd2c686842f	Diners Club / Carte Blanche	32.0851642344187979	-110.869317596568166
49619	2020-09-01 23:27:45	2020-09-01	Adelbert Moen	adelbert.moen@woohoo.com	San Antonio	Texas	060427883937073	d7bd911fe0773346d3495c1afb31f0f5	VISA 16 digit	29.5382523847348999	-98.5489565907347895
49620	2020-09-01 23:34:32	2020-09-01	London Zboncak	london.zboncak@geemail.com	Oklahoma City	Oklahoma	589329081895582	6532ad5498a9b5d82644f07f5908f948	Discover	35.4797795511692797	-97.4839709685545444
49621	2020-09-01 23:35:51	2020-09-01	Urijah Aufderhar I	urijah.aufderhar.i@geemail.com	Milwaukee	Wisconsin	3158906876109566495	3fb47f8d677ce60a609e336ea53c3bf5	Diners Club / Carte Blanche	42.9959247221324574	-87.868818150470787
49622	2020-09-01 23:36:48	2020-09-01	Geoff Dach	geoff.dach@geemail.com	Springfield	Massachusetts	4437984489298	8c370b4c2aea2d1b6a5843b942fd0561	Discover	42.1410054967477876	-72.5239946928899855
49623	2020-09-01 23:37:36	2020-09-01	Maureen Reinger	maureen.reinger@warmmail.com	Oakland	California	3337561091390650018	3d82d2d213bda20c62fe9503ed10b535	VISA 16 digit	37.8090932469854195	-122.279669333353993
49624	2020-09-01 23:43:23	2020-09-01	Miss Jenny Okuneva	miss.jenny.okuneva@geemail.com	Louisville	Kentucky	3010155114246194	cd03429e76dc6ba670f1984749cd84e0	Diners Club / Carte Blanche	38.1036836396340277	-85.6999266349315718
49625	2020-09-01 23:43:23	2020-09-01	Carnell Reichel	carnell.reichel@geemail.com	Fayetteville	North Carolina	3112950931384268781	61609d528c13fe0ace281c311a2b47d0	VISA 16 digit	35.0408617112107592	-78.9756716171409892
49626	2020-09-01 23:45:06	2020-09-01	Roll Maggio	roll.maggio@geemail.com	Elizabeth	New Jersey	4121652484068038	c437084c94f7e25c0b3b1878f8b18e7a	American Express	40.6595295653805167	-74.2913929165285083
49627	2020-09-01 23:45:18	2020-09-01	Bettylou Hansen	bettylou.hansen@geemail.com	Kansas City	Missouri	3032130588546492	16c2bc0332a33b3a1ba65e8921a5d56e	Discover	39.1975715952295829	-94.6130134648401366
\.


--
-- Name: menu menu_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.menu
    ADD CONSTRAINT menu_pkey PRIMARY KEY (id_menu);


--
-- Name: orders orders_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.orders
    ADD CONSTRAINT orders_pkey PRIMARY KEY (id_order);


--
-- Name: reviews reviews_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.reviews
    ADD CONSTRAINT reviews_pkey PRIMARY KEY (id_review);


--
-- Name: users users_pkey; Type: CONSTRAINT; Schema: public; Owner: -
--

ALTER TABLE ONLY public.users
    ADD CONSTRAINT users_pkey PRIMARY KEY (id_user);


--
-- Name: SCHEMA public; Type: ACL; Schema: -; Owner: -
--

REVOKE ALL ON SCHEMA public FROM rdsadmin;
REVOKE ALL ON SCHEMA public FROM PUBLIC;
GRANT ALL ON SCHEMA public TO postgres;
GRANT ALL ON SCHEMA public TO PUBLIC;


--
-- PostgreSQL database dump complete
--

